# coding=utf-8

import json


class CityCoordinator():

    city_list= None
    
    def __init__(self, *args, **kwargs):
        self.city_list = CITY_LIST
    
    def get_city(self, city_name, country_code_iso):
        """
        Get the city_name and country code in ISO 3166-1 alpha-2 format and returns the city coordination as a dict()
        :params city_name: City name
        :params country_code_iso: Country code in ISO 3166-1 alpha-2 format (DE, TN, US, FR, LI...)
        returns: dict()
            {
                "country_iso_code": country code,
                "city_name": city name,
                "location": {
                    "lon": city longitude,
                    "lat": city lattitude
                }
            }
        """

        if not isinstance(city_name, str) or city_name is None:
            raise ValueError("city_name: has to be a string.")

        if len(country_code_iso) != 2 or country_code_iso is None:
            raise ValueError("country_code_iso: has to be a string of 2 caracters.")

        try:
            for city in self.city_list:
                if city["name"].lower() == city_name.lower() and city["country"].lower() == country_code_iso.lower():
                    return {
                        "country_iso_code": city.get("country"),
                        "city_name": city.get("name"),
                        "location": {
                            "lon": city["lng"],
                            "lat": city["lat"]
                        }
                    }

            return None
        except BaseException as e:
            print(e)
            return None
    
    def get_country_cities(self, country_code_iso):
        """
        Get the country code in ISO 3166-1 alpha-2 format and returns a list cities' names and coordinations in a list of dict()
        :params country_code_iso: Country code in ISO 3166-1 alpha-2 format (DE, TN, US, FR, LI...)
        returns: 
        [
            {
                "country_iso_code": country code,
                "city_name": city name,
                    "location": {
                        "lon": city longitude,
                        "lat": city lattitude
                    }
            },
            ....
            ]
        """

        if len(country_code_iso) != 2 or country_code_iso is None:
            raise ValueError("country_code_iso: has to be a string of 2 caracters.")
        try:
            city_list=[]
            for city in self.city_list:
                if city["country"].lower() == country_code_iso.lower():
                    city_list.append({
                        "country_iso_code": city.get("country"),
                        "city_name": city.get("name"),
                        "location": {
                            "lon": city["lng"],
                            "lat": city["lat"]
                        }
                    })

            return city_list

            return None
        except BaseException as e :
            print(e)
            return None




CITY_LIST=[
  {
    "country": "AD",
    "name": "Sant Julià de Lòria",
    "lat": "42.46372",
    "lng": "1.49129"
  },
  {
    "country": "AD",
    "name": "Pas de la Casa",
    "lat": "42.54277",
    "lng": "1.73361"
  },
  {
    "country": "AD",
    "name": "Ordino",
    "lat": "42.55623",
    "lng": "1.53319"
  },
  {
    "country": "AD",
    "name": "les Escaldes",
    "lat": "42.50729",
    "lng": "1.53414"
  },
  {
    "country": "AD",
    "name": "la Massana",
    "lat": "42.54499",
    "lng": "1.51483"
  },
  {
    "country": "AD",
    "name": "Encamp",
    "lat": "42.53474",
    "lng": "1.58014"
  },
  {
    "country": "AD",
    "name": "Canillo",
    "lat": "42.5676",
    "lng": "1.59756"
  },
  {
    "country": "AD",
    "name": "Arinsal",
    "lat": "42.57205",
    "lng": "1.48453"
  },
  {
    "country": "AD",
    "name": "Andorra la Vella",
    "lat": "42.50779",
    "lng": "1.52109"
  },
  {
    "country": "AE",
    "name": "Umm al Qaywayn",
    "lat": "25.56473",
    "lng": "55.55517"
  },
  {
    "country": "AE",
    "name": "Ras al-Khaimah",
    "lat": "25.78953",
    "lng": "55.9432"
  },
  {
    "country": "AE",
    "name": "Muzayri‘",
    "lat": "23.14355",
    "lng": "53.7881"
  },
  {
    "country": "AE",
    "name": "Murbaḩ",
    "lat": "25.27623",
    "lng": "56.36256"
  },
  {
    "country": "AE",
    "name": "Khawr Fakkān",
    "lat": "25.33132",
    "lng": "56.34199"
  },
  {
    "country": "AE",
    "name": "Dubai",
    "lat": "25.0657",
    "lng": "55.17128"
  },
  {
    "country": "AE",
    "name": "Dibba Al-Fujairah",
    "lat": "25.59246",
    "lng": "56.26176"
  },
  {
    "country": "AE",
    "name": "Dibba Al-Hisn",
    "lat": "25.61955",
    "lng": "56.27291"
  },
  {
    "country": "AE",
    "name": "Sharjah",
    "lat": "25.33737",
    "lng": "55.41206"
  },
  {
    "country": "AE",
    "name": "Ar Ruways",
    "lat": "24.11028",
    "lng": "52.73056"
  },
  {
    "country": "AE",
    "name": "Al Fujayrah",
    "lat": "25.11641",
    "lng": "56.34141"
  },
  {
    "country": "AE",
    "name": "Al Ain",
    "lat": "24.19167",
    "lng": "55.76056"
  },
  {
    "country": "AE",
    "name": "Ajman",
    "lat": "25.41111",
    "lng": "55.43504"
  },
  {
    "country": "AE",
    "name": "Adh Dhayd",
    "lat": "25.28812",
    "lng": "55.88157"
  },
  {
    "country": "AE",
    "name": "Abu Dhabi",
    "lat": "24.46667",
    "lng": "54.36667"
  },
  {
    "country": "AF",
    "name": "Zorkot",
    "lat": "33.54149",
    "lng": "69.73446"
  },
  {
    "country": "AF",
    "name": "Wulêswālī Bihsūd",
    "lat": "34.3436",
    "lng": "67.90567"
  },
  {
    "country": "AF",
    "name": "Kuhsān",
    "lat": "34.65389",
    "lng": "61.19778"
  },
  {
    "country": "AF",
    "name": "Lāsh",
    "lat": "35.3782",
    "lng": "64.77457"
  },
  {
    "country": "AF",
    "name": "Tukzār",
    "lat": "35.94831",
    "lng": "66.42132"
  },
  {
    "country": "AF",
    "name": "Mīray",
    "lat": "33.32462",
    "lng": "68.44068"
  },
  {
    "country": "AF",
    "name": "Āq Kupruk",
    "lat": "36.08352",
    "lng": "66.84029"
  },
  {
    "country": "AF",
    "name": "Zurmat",
    "lat": "33.43778",
    "lng": "69.02774"
  },
  {
    "country": "AF",
    "name": "Zaybāk",
    "lat": "36.52947",
    "lng": "71.3441"
  },
  {
    "country": "AF",
    "name": "Zīārat-e Shāh Maqşūd",
    "lat": "31.9848",
    "lng": "65.4736"
  },
  {
    "country": "AF",
    "name": "Zindah Jān",
    "lat": "34.34264",
    "lng": "61.74675"
  },
  {
    "country": "AF",
    "name": "Zarghūn Shahr",
    "lat": "32.84734",
    "lng": "68.44573"
  },
  {
    "country": "AF",
    "name": "Zaṟah Sharan",
    "lat": "33.14641",
    "lng": "68.79213"
  },
  {
    "country": "AF",
    "name": "Zaranj",
    "lat": "30.95962",
    "lng": "61.86037"
  },
  {
    "country": "AF",
    "name": "Zamtō Kêlay",
    "lat": "32.3726",
    "lng": "66.17708"
  },
  {
    "country": "AF",
    "name": "Yangī Qal‘ah",
    "lat": "37.46572",
    "lng": "69.61131"
  },
  {
    "country": "AF",
    "name": "Yaḩyá Khēl",
    "lat": "32.93742",
    "lng": "68.64622"
  },
  {
    "country": "AF",
    "name": "Wāshēr",
    "lat": "32.25122",
    "lng": "63.85553"
  },
  {
    "country": "AF",
    "name": "Tōrmay",
    "lat": "33.68847",
    "lng": "68.40205"
  },
  {
    "country": "AF",
    "name": "Tūlak",
    "lat": "33.97509",
    "lng": "63.72868"
  },
  {
    "country": "AF",
    "name": "Tītān",
    "lat": "33.69032",
    "lng": "63.86361"
  },
  {
    "country": "AF",
    "name": "Tīr Pul",
    "lat": "34.59431",
    "lng": "61.26895"
  },
  {
    "country": "AF",
    "name": "Taywarah",
    "lat": "33.52118",
    "lng": "64.42116"
  },
  {
    "country": "AF",
    "name": "Bāzār-e Tashkān",
    "lat": "36.88168",
    "lng": "70.27674"
  },
  {
    "country": "AF",
    "name": "Tarinkot",
    "lat": "32.62998",
    "lng": "65.87806"
  },
  {
    "country": "AF",
    "name": "Taloqan",
    "lat": "36.73605",
    "lng": "69.53451"
  },
  {
    "country": "AF",
    "name": "Tagāw-Bāy",
    "lat": "35.69941",
    "lng": "66.06164"
  },
  {
    "country": "AF",
    "name": "Tagāb",
    "lat": "34.85501",
    "lng": "69.64917"
  },
  {
    "country": "AF",
    "name": "Markaz-e Ḩukūmat-e Sulţān-e Bakwāh",
    "lat": "32.24139",
    "lng": "62.94936"
  },
  {
    "country": "AF",
    "name": "Spīn Bōldak",
    "lat": "31.00575",
    "lng": "66.40001"
  },
  {
    "country": "AF",
    "name": "Spērah",
    "lat": "33.20204",
    "lng": "69.5152"
  },
  {
    "country": "AF",
    "name": "Sōzmah Qal‘ah",
    "lat": "36.09916",
    "lng": "66.20823"
  },
  {
    "country": "AF",
    "name": "Siyāhgird",
    "lat": "35.00553",
    "lng": "68.85578"
  },
  {
    "country": "AF",
    "name": "Sheywah",
    "lat": "34.57169",
    "lng": "70.58859"
  },
  {
    "country": "AF",
    "name": "Shīnḏanḏ",
    "lat": "33.30294",
    "lng": "62.1474"
  },
  {
    "country": "AF",
    "name": "Shaykh Amīr Kêlay",
    "lat": "33.28744",
    "lng": "69.91283"
  },
  {
    "country": "AF",
    "name": "Qāshqāl",
    "lat": "35.03975",
    "lng": "69.00685"
  },
  {
    "country": "AF",
    "name": "Shibirghān",
    "lat": "36.66757",
    "lng": "65.7529"
  },
  {
    "country": "AF",
    "name": "Shwāk",
    "lat": "33.42386",
    "lng": "69.37684"
  },
  {
    "country": "AF",
    "name": "Shahr-e Şafā",
    "lat": "31.80347",
    "lng": "66.32376"
  },
  {
    "country": "AF",
    "name": "Shahrān",
    "lat": "36.97984",
    "lng": "70.73928"
  },
  {
    "country": "AF",
    "name": "Shahrak",
    "lat": "34.10737",
    "lng": "64.3052"
  },
  {
    "country": "AF",
    "name": "‘Alāqahdārī Shāh Jōy",
    "lat": "32.52154",
    "lng": "67.41315"
  },
  {
    "country": "AF",
    "name": "Wulêswālī Sayyid Karam",
    "lat": "33.69056",
    "lng": "69.36881"
  },
  {
    "country": "AF",
    "name": "Markaz-e Sayyidābād",
    "lat": "34.00037",
    "lng": "68.71346"
  },
  {
    "country": "AF",
    "name": "Şayād",
    "lat": "36.13529",
    "lng": "65.8297"
  },
  {
    "country": "AF",
    "name": "Sidqābād",
    "lat": "35.02298",
    "lng": "69.35112"
  },
  {
    "country": "AF",
    "name": "Sāyagaz",
    "lat": "32.56521",
    "lng": "67.03324"
  },
  {
    "country": "AF",
    "name": "Sar-e Tayghān",
    "lat": "33.50998",
    "lng": "65.67632"
  },
  {
    "country": "AF",
    "name": "Sarōbī",
    "lat": "34.58962",
    "lng": "69.76005"
  },
  {
    "country": "AF",
    "name": "Sar Kāṉī",
    "lat": "34.79023",
    "lng": "71.10962"
  },
  {
    "country": "AF",
    "name": "Sarfirāz Kalā",
    "lat": "32.98333",
    "lng": "67.96517"
  },
  {
    "country": "AF",
    "name": "Sar-e Pul",
    "lat": "36.21544",
    "lng": "65.93249"
  },
  {
    "country": "AF",
    "name": "Sar Chakān",
    "lat": "35.70177",
    "lng": "65.23055"
  },
  {
    "country": "AF",
    "name": "Sangīn",
    "lat": "32.07275",
    "lng": "64.8359"
  },
  {
    "country": "AF",
    "name": "Sang-e Māshah",
    "lat": "33.1396",
    "lng": "67.44046"
  },
  {
    "country": "AF",
    "name": "Sang-e Chārak",
    "lat": "35.84972",
    "lng": "66.43694"
  },
  {
    "country": "AF",
    "name": "Sang Atesh",
    "lat": "35.248",
    "lng": "63.0044"
  },
  {
    "country": "AF",
    "name": "Sangar Sarāy",
    "lat": "34.40744",
    "lng": "70.63937"
  },
  {
    "country": "AF",
    "name": "Aībak",
    "lat": "36.26468",
    "lng": "68.01551"
  },
  {
    "country": "AF",
    "name": "Rū-ye Sang",
    "lat": "35.31999",
    "lng": "67.63387"
  },
  {
    "country": "AF",
    "name": "Rūdbār",
    "lat": "30.15",
    "lng": "62.6"
  },
  {
    "country": "AF",
    "name": "Rustāq",
    "lat": "37.12604",
    "lng": "69.83045"
  },
  {
    "country": "AF",
    "name": "Rabāţ-e Sangī-ye Pā’īn",
    "lat": "34.79951",
    "lng": "62.13917"
  },
  {
    "country": "AF",
    "name": "Rāmak",
    "lat": "33.52234",
    "lng": "68.6264"
  },
  {
    "country": "AF",
    "name": "Qurghān",
    "lat": "36.91939",
    "lng": "65.0649"
  },
  {
    "country": "AF",
    "name": "Quchanghī",
    "lat": "34.06183",
    "lng": "66.27801"
  },
  {
    "country": "AF",
    "name": "Sangalak-i-Kaisar",
    "lat": "35.68747",
    "lng": "64.29318"
  },
  {
    "country": "AF",
    "name": "Qarqīn",
    "lat": "37.41853",
    "lng": "66.04358"
  },
  {
    "country": "AF",
    "name": "Qarghah’ī",
    "lat": "34.55402",
    "lng": "70.24292"
  },
  {
    "country": "AF",
    "name": "Qarchī Gak",
    "lat": "37.03999",
    "lng": "66.78891"
  },
  {
    "country": "AF",
    "name": "Qarāwul",
    "lat": "37.21959",
    "lng": "68.7802"
  },
  {
    "country": "AF",
    "name": "Qarah Bāgh",
    "lat": "34.94023",
    "lng": "61.77589"
  },
  {
    "country": "AF",
    "name": "Qarah Bāgh",
    "lat": "33.19801",
    "lng": "68.10798"
  },
  {
    "country": "AF",
    "name": "Qala i Naw",
    "lat": "34.98735",
    "lng": "63.12891"
  },
  {
    "country": "AF",
    "name": "Qal‘ah-ye Kūf",
    "lat": "38.04119",
    "lng": "70.47298"
  },
  {
    "country": "AF",
    "name": "Qal‘ah-ye Kuhnah",
    "lat": "32.61591",
    "lng": "63.66681"
  },
  {
    "country": "AF",
    "name": "Qal‘ah-ye Shahr",
    "lat": "35.54729",
    "lng": "65.5676"
  },
  {
    "country": "AF",
    "name": "Qalāt",
    "lat": "32.10575",
    "lng": "66.90833"
  },
  {
    "country": "AF",
    "name": "Qal‘ah-ye Shāhī",
    "lat": "34.64921",
    "lng": "70.5914"
  },
  {
    "country": "AF",
    "name": "Qādis",
    "lat": "34.8085",
    "lng": "63.43003"
  },
  {
    "country": "AF",
    "name": "Pārūn",
    "lat": "35.42064",
    "lng": "70.92261"
  },
  {
    "country": "AF",
    "name": "Pul-e Khumrī",
    "lat": "35.94458",
    "lng": "68.71512"
  },
  {
    "country": "AF",
    "name": "Pul-e ‘Alam",
    "lat": "33.99529",
    "lng": "69.02274"
  },
  {
    "country": "AF",
    "name": "Pasnay",
    "lat": "35.76664",
    "lng": "65.76486"
  },
  {
    "country": "AF",
    "name": "Pāshmūl",
    "lat": "31.5572",
    "lng": "65.4343"
  },
  {
    "country": "AF",
    "name": "Pasāband",
    "lat": "33.68956",
    "lng": "64.8531"
  },
  {
    "country": "AF",
    "name": "Panjāb",
    "lat": "34.38795",
    "lng": "67.02327"
  },
  {
    "country": "AF",
    "name": "Paghmān",
    "lat": "34.58787",
    "lng": "68.95091"
  },
  {
    "country": "AF",
    "name": "Ōmnah",
    "lat": "32.90029",
    "lng": "68.79627"
  },
  {
    "country": "AF",
    "name": "Qaryeh-ye Owbeh",
    "lat": "34.36972",
    "lng": "63.17639"
  },
  {
    "country": "AF",
    "name": "Uruzgān",
    "lat": "32.92775",
    "lng": "66.63253"
  },
  {
    "country": "AF",
    "name": "Urgun",
    "lat": "32.9515",
    "lng": "69.1828"
  },
  {
    "country": "AF",
    "name": "Nūsay",
    "lat": "38.4435",
    "lng": "70.80413"
  },
  {
    "country": "AF",
    "name": "Nūrgal",
    "lat": "34.61341",
    "lng": "70.76498"
  },
  {
    "country": "AF",
    "name": "Now Zād",
    "lat": "32.40315",
    "lng": "64.46959"
  },
  {
    "country": "AF",
    "name": "Nīlī",
    "lat": "33.72178",
    "lng": "66.13023"
  },
  {
    "country": "AF",
    "name": "Nayak",
    "lat": "34.73414",
    "lng": "66.95292"
  },
  {
    "country": "AF",
    "name": "Nāyak",
    "lat": "32.5723",
    "lng": "66.77403"
  },
  {
    "country": "AF",
    "name": "Now Dahānak",
    "lat": "35.62398",
    "lng": "70.00511"
  },
  {
    "country": "AF",
    "name": "Ōkak",
    "lat": "33.89793",
    "lng": "67.95652"
  },
  {
    "country": "AF",
    "name": "Nāṟay",
    "lat": "35.21995",
    "lng": "71.52284"
  },
  {
    "country": "AF",
    "name": "Narang",
    "lat": "34.76009",
    "lng": "71.04738"
  },
  {
    "country": "AF",
    "name": "Nīkêh",
    "lat": "33.18934",
    "lng": "69.27179"
  },
  {
    "country": "AF",
    "name": "Nahrīn",
    "lat": "36.0649",
    "lng": "69.13343"
  },
  {
    "country": "AF",
    "name": "Ḩukūmat-e Nād ‘Alī",
    "lat": "31.64286",
    "lng": "64.23982"
  },
  {
    "country": "AF",
    "name": "Mūsá Qal‘ah",
    "lat": "32.44565",
    "lng": "64.74486"
  },
  {
    "country": "AF",
    "name": "Bala Murghab",
    "lat": "35.58408",
    "lng": "63.32886"
  },
  {
    "country": "AF",
    "name": "Muqêr",
    "lat": "32.82009",
    "lng": "67.76934"
  },
  {
    "country": "AF",
    "name": "Muḩammad Āghah Wuluswālī",
    "lat": "34.21422",
    "lng": "69.10026"
  },
  {
    "country": "AF",
    "name": "Mīzān ‘Alāqahdārī",
    "lat": "32.17635",
    "lng": "66.51271"
  },
  {
    "country": "AF",
    "name": "Mīr Bachah Kōṯ",
    "lat": "34.74999",
    "lng": "69.11899"
  },
  {
    "country": "AF",
    "name": "Mīrān",
    "lat": "34.22037",
    "lng": "68.31259"
  },
  {
    "country": "AF",
    "name": "Mīrābād",
    "lat": "30.43624",
    "lng": "61.8383"
  },
  {
    "country": "AF",
    "name": "Maymana",
    "lat": "35.92139",
    "lng": "64.78361"
  },
  {
    "country": "AF",
    "name": "Maīdān Khūlah",
    "lat": "33.64916",
    "lng": "69.7812"
  },
  {
    "country": "AF",
    "name": "Mingajik",
    "lat": "37.0279",
    "lng": "66.12817"
  },
  {
    "country": "AF",
    "name": "Mehtar Lām",
    "lat": "34.67139",
    "lng": "70.20944"
  },
  {
    "country": "AF",
    "name": "Mazār-e Sharīf",
    "lat": "36.70904",
    "lng": "67.11087"
  },
  {
    "country": "AF",
    "name": "Māymay",
    "lat": "38.40856",
    "lng": "71.03839"
  },
  {
    "country": "AF",
    "name": "Mutā Khān",
    "lat": "33.24001",
    "lng": "68.8663"
  },
  {
    "country": "AF",
    "name": "Mashhad",
    "lat": "36.81665",
    "lng": "70.10211"
  },
  {
    "country": "AF",
    "name": "Mardīān",
    "lat": "36.99252",
    "lng": "66.29654"
  },
  {
    "country": "AF",
    "name": "Mandōl",
    "lat": "35.28403",
    "lng": "70.17017"
  },
  {
    "country": "AF",
    "name": "Māmā Khēl",
    "lat": "34.24494",
    "lng": "69.9968"
  },
  {
    "country": "AF",
    "name": "Lashkar Gāh",
    "lat": "31.59382",
    "lng": "64.37161"
  },
  {
    "country": "AF",
    "name": "Lāsh-e Juwayn",
    "lat": "31.71382",
    "lng": "61.62272"
  },
  {
    "country": "AF",
    "name": "Larkird",
    "lat": "35.48936",
    "lng": "66.66409"
  },
  {
    "country": "AF",
    "name": "La‘l",
    "lat": "34.50141",
    "lng": "66.27997"
  },
  {
    "country": "AF",
    "name": "Kushk",
    "lat": "33.29565",
    "lng": "61.95221"
  },
  {
    "country": "AF",
    "name": "Kōṯowāl",
    "lat": "34.10319",
    "lng": "70.46073"
  },
  {
    "country": "AF",
    "name": "Kushk-e Kuhnah",
    "lat": "34.8711",
    "lng": "62.54762"
  },
  {
    "country": "AF",
    "name": "Kuran wa Munjan",
    "lat": "36.02866",
    "lng": "70.77258"
  },
  {
    "country": "AF",
    "name": "Kunduz",
    "lat": "36.72895",
    "lng": "68.857"
  },
  {
    "country": "AF",
    "name": "Khōshī",
    "lat": "33.99916",
    "lng": "69.21582"
  },
  {
    "country": "AF",
    "name": "Khōshāmand",
    "lat": "32.68567",
    "lng": "68.23801"
  },
  {
    "country": "AF",
    "name": "Khwājah Ghār",
    "lat": "37.06588",
    "lng": "69.42126"
  },
  {
    "country": "AF",
    "name": "Khwājah Dū Kōh",
    "lat": "36.82881",
    "lng": "65.62432"
  },
  {
    "country": "AF",
    "name": "Deh Khwāhān",
    "lat": "37.88965",
    "lng": "70.21875"
  },
  {
    "country": "AF",
    "name": "Khulbisāt",
    "lat": "33.4948",
    "lng": "70.00605"
  },
  {
    "country": "AF",
    "name": "Khūgyāṉī",
    "lat": "31.56267",
    "lng": "66.5814"
  },
  {
    "country": "AF",
    "name": "Khōst",
    "lat": "33.33951",
    "lng": "69.92041"
  },
  {
    "country": "AF",
    "name": "Khulm",
    "lat": "36.69736",
    "lng": "67.69826"
  },
  {
    "country": "AF",
    "name": "Khudāydād Khēl",
    "lat": "35.17835",
    "lng": "67.68758"
  },
  {
    "country": "AF",
    "name": "Khinjān",
    "lat": "35.58908",
    "lng": "68.90093"
  },
  {
    "country": "AF",
    "name": "Khinj",
    "lat": "35.42898",
    "lng": "69.73482"
  },
  {
    "country": "AF",
    "name": "Khāsh",
    "lat": "31.52919",
    "lng": "62.79055"
  },
  {
    "country": "AF",
    "name": "Khān Neshīn",
    "lat": "30.5488",
    "lng": "63.7888"
  },
  {
    "country": "AF",
    "name": "Khānaqāh",
    "lat": "36.62587",
    "lng": "69.53695"
  },
  {
    "country": "AF",
    "name": "Chahār Bāgh",
    "lat": "37.00108",
    "lng": "65.22392"
  },
  {
    "country": "AF",
    "name": "Khandūd",
    "lat": "36.95127",
    "lng": "72.318"
  },
  {
    "country": "AF",
    "name": "Khānaqāh",
    "lat": "36.86279",
    "lng": "66.16656"
  },
  {
    "country": "AF",
    "name": "Khanabad",
    "lat": "36.6825",
    "lng": "69.11556"
  },
  {
    "country": "AF",
    "name": "Khamyāb",
    "lat": "37.5275",
    "lng": "65.75833"
  },
  {
    "country": "AF",
    "name": "Khākirān",
    "lat": "32.8385",
    "lng": "67.07377"
  },
  {
    "country": "AF",
    "name": "Kaz̲h̲ah",
    "lat": "34.24088",
    "lng": "70.18274"
  },
  {
    "country": "AF",
    "name": "Kishk-e Nakhūd",
    "lat": "31.62519",
    "lng": "65.05511"
  },
  {
    "country": "AF",
    "name": "Karukh",
    "lat": "34.48108",
    "lng": "62.5863"
  },
  {
    "country": "AF",
    "name": "Kanḏay",
    "lat": "34.9536",
    "lng": "70.77897"
  },
  {
    "country": "AF",
    "name": "Kandahār",
    "lat": "31.61332",
    "lng": "65.71013"
  },
  {
    "country": "AF",
    "name": "Kalān Deh",
    "lat": "33.83676",
    "lng": "68.40233"
  },
  {
    "country": "AF",
    "name": "Kalakān",
    "lat": "34.78371",
    "lng": "69.15001"
  },
  {
    "country": "AF",
    "name": "Kalafgān",
    "lat": "36.77226",
    "lng": "69.94489"
  },
  {
    "country": "AF",
    "name": "Kajrān",
    "lat": "33.20357",
    "lng": "65.47311"
  },
  {
    "country": "AF",
    "name": "Kai",
    "lat": "34.12819",
    "lng": "70.71828"
  },
  {
    "country": "AF",
    "name": "Kabul",
    "lat": "34.52813",
    "lng": "69.17233"
  },
  {
    "country": "AF",
    "name": "Jurm",
    "lat": "36.86477",
    "lng": "70.83421"
  },
  {
    "country": "AF",
    "name": "Jawand",
    "lat": "35.06361",
    "lng": "64.14917"
  },
  {
    "country": "AF",
    "name": "Jānī Khēl",
    "lat": "32.76315",
    "lng": "68.39722"
  },
  {
    "country": "AF",
    "name": "Jalrēz",
    "lat": "34.4708",
    "lng": "68.65438"
  },
  {
    "country": "AF",
    "name": "Jalālābād",
    "lat": "34.42647",
    "lng": "70.45153"
  },
  {
    "country": "AF",
    "name": "Jabal os Saraj",
    "lat": "35.11833",
    "lng": "69.23778"
  },
  {
    "country": "AF",
    "name": "Ḩukūmat-e Shīnkaī",
    "lat": "31.98303",
    "lng": "67.33558"
  },
  {
    "country": "AF",
    "name": "Herāt",
    "lat": "34.34817",
    "lng": "62.19967"
  },
  {
    "country": "AF",
    "name": "Ḩājī Khēl",
    "lat": "35.10922",
    "lng": "69.43341"
  },
  {
    "country": "AF",
    "name": "Ḩāfiz̧ Moghul",
    "lat": "37.05643",
    "lng": "70.40061"
  },
  {
    "country": "AF",
    "name": "Khafizan",
    "lat": "34.28665",
    "lng": "70.37247"
  },
  {
    "country": "AF",
    "name": "Guz̄arah",
    "lat": "34.21223",
    "lng": "62.21235"
  },
  {
    "country": "AF",
    "name": "Gōshtah",
    "lat": "34.35822",
    "lng": "70.76264"
  },
  {
    "country": "AF",
    "name": "Gōmal Kêlay",
    "lat": "32.50989",
    "lng": "68.85598"
  },
  {
    "country": "AF",
    "name": "‘Alāqahdārī Gēlān",
    "lat": "32.72692",
    "lng": "67.63696"
  },
  {
    "country": "AF",
    "name": "Ghōriyān",
    "lat": "34.3448",
    "lng": "61.49321"
  },
  {
    "country": "AF",
    "name": "Ghormach",
    "lat": "35.73062",
    "lng": "63.78264"
  },
  {
    "country": "AF",
    "name": "Ghurayd Gharamē",
    "lat": "36.5222",
    "lng": "70.79063"
  },
  {
    "country": "AF",
    "name": "Ghazni",
    "lat": "33.55391",
    "lng": "68.42096"
  },
  {
    "country": "AF",
    "name": "Gereshk",
    "lat": "31.82089",
    "lng": "64.57005"
  },
  {
    "country": "AF",
    "name": "Gardez",
    "lat": "33.59744",
    "lng": "69.22592"
  },
  {
    "country": "AF",
    "name": "Fayzabad",
    "lat": "37.11664",
    "lng": "70.58002"
  },
  {
    "country": "AF",
    "name": "Faīẕābād",
    "lat": "36.82091",
    "lng": "66.45921"
  },
  {
    "country": "AF",
    "name": "Fayẕābād",
    "lat": "36.29111",
    "lng": "64.86222"
  },
  {
    "country": "AF",
    "name": "Qal‘ah-ye Fārsī",
    "lat": "33.78529",
    "lng": "63.24735"
  },
  {
    "country": "AF",
    "name": "Farkhār",
    "lat": "36.57288",
    "lng": "69.85783"
  },
  {
    "country": "AF",
    "name": "Farah",
    "lat": "32.37451",
    "lng": "62.11638"
  },
  {
    "country": "AF",
    "name": "Istālif",
    "lat": "34.83268",
    "lng": "69.07756"
  },
  {
    "country": "AF",
    "name": "Kafir Qala",
    "lat": "34.66667",
    "lng": "61.06667"
  },
  {
    "country": "AF",
    "name": "Injīl",
    "lat": "34.30157",
    "lng": "62.2465"
  },
  {
    "country": "AF",
    "name": "Imām Şāḩib",
    "lat": "37.18897",
    "lng": "68.93644"
  },
  {
    "country": "AF",
    "name": "Dōshī",
    "lat": "35.60918",
    "lng": "68.68473"
  },
  {
    "country": "AF",
    "name": "Dowlatyār",
    "lat": "34.55132",
    "lng": "65.79302"
  },
  {
    "country": "AF",
    "name": "Dowlat Shāh",
    "lat": "34.9504",
    "lng": "70.07102"
  },
  {
    "country": "AF",
    "name": "Dowlatābād",
    "lat": "36.98821",
    "lng": "66.82069"
  },
  {
    "country": "AF",
    "name": "Dowlatābād",
    "lat": "36.43259",
    "lng": "64.92071"
  },
  {
    "country": "AF",
    "name": "Dū Qal‘ah",
    "lat": "32.14237",
    "lng": "61.4469"
  },
  {
    "country": "AF",
    "name": "Dūāb",
    "lat": "35.56277",
    "lng": "67.82191"
  },
  {
    "country": "AF",
    "name": "Dê Nārkhēl Kêlay",
    "lat": "32.43205",
    "lng": "65.63484"
  },
  {
    "country": "AF",
    "name": "Dehī",
    "lat": "35.95806",
    "lng": "67.27998"
  },
  {
    "country": "AF",
    "name": "Deh-e Şalāḩ",
    "lat": "35.69031",
    "lng": "69.31511"
  },
  {
    "country": "AF",
    "name": "Deh-e Now",
    "lat": "34.74767",
    "lng": "69.04784"
  },
  {
    "country": "AF",
    "name": "Dehdādī",
    "lat": "36.66319",
    "lng": "66.99339"
  },
  {
    "country": "AF",
    "name": "Dwah Manḏay",
    "lat": "33.28159",
    "lng": "69.58531"
  },
  {
    "country": "AF",
    "name": "Dasht-e Qal‘ah",
    "lat": "37.1539",
    "lng": "69.4435"
  },
  {
    "country": "AF",
    "name": "Dasht-e Qal‘ah",
    "lat": "33.02978",
    "lng": "63.8395"
  },
  {
    "country": "AF",
    "name": "Dasht-e Archī",
    "lat": "37.13333",
    "lng": "69.16667"
  },
  {
    "country": "AF",
    "name": "Darzāb",
    "lat": "35.97744",
    "lng": "65.37828"
  },
  {
    "country": "AF",
    "name": "Markaz-e Ḩukūmat-e Darwēshān",
    "lat": "31.13231",
    "lng": "64.1934"
  },
  {
    "country": "AF",
    "name": "Darqad",
    "lat": "37.38414",
    "lng": "69.45294"
  },
  {
    "country": "AF",
    "name": "Darāyim",
    "lat": "36.86667",
    "lng": "70.38333"
  },
  {
    "country": "AF",
    "name": "Dāngām",
    "lat": "34.99249",
    "lng": "71.41935"
  },
  {
    "country": "AF",
    "name": "Ḏanḏar",
    "lat": "34.79095",
    "lng": "69.47504"
  },
  {
    "country": "AF",
    "name": "Ḩukūmatī Dahanah-ye Ghōrī",
    "lat": "35.90617",
    "lng": "68.48869"
  },
  {
    "country": "AF",
    "name": "Tsowkêy",
    "lat": "34.69246",
    "lng": "70.92688"
  },
  {
    "country": "AF",
    "name": "Chīras",
    "lat": "35.41674",
    "lng": "65.98234"
  },
  {
    "country": "AF",
    "name": "Chisht-e Sharīf",
    "lat": "34.34731",
    "lng": "63.73966"
  },
  {
    "country": "AF",
    "name": "Chinār",
    "lat": "32.01583",
    "lng": "65.10721"
  },
  {
    "country": "AF",
    "name": "Chimtāl",
    "lat": "36.67818",
    "lng": "66.80325"
  },
  {
    "country": "AF",
    "name": "Charkh",
    "lat": "33.79712",
    "lng": "68.93749"
  },
  {
    "country": "AF",
    "name": "Charikar",
    "lat": "35.01361",
    "lng": "69.17139"
  },
  {
    "country": "AF",
    "name": "Dowr-e Rabāţ",
    "lat": "36.69132",
    "lng": "68.79093"
  },
  {
    "country": "AF",
    "name": "Tsapêraī",
    "lat": "33.83003",
    "lng": "69.9192"
  },
  {
    "country": "AF",
    "name": "Tsamkanī",
    "lat": "33.80298",
    "lng": "69.81671"
  },
  {
    "country": "AF",
    "name": "Chakaray",
    "lat": "34.34099",
    "lng": "69.4377"
  },
  {
    "country": "AF",
    "name": "Chākarān",
    "lat": "36.91112",
    "lng": "71.0688"
  },
  {
    "country": "AF",
    "name": "Chahār Qal‘ah",
    "lat": "33.55267",
    "lng": "68.29828"
  },
  {
    "country": "AF",
    "name": "Chahār Burj",
    "lat": "34.24475",
    "lng": "62.19165"
  },
  {
    "country": "AF",
    "name": "Chāh Āb",
    "lat": "37.39773",
    "lng": "69.81464"
  },
  {
    "country": "AF",
    "name": "Fayrōz Kōh",
    "lat": "34.51952",
    "lng": "65.25093"
  },
  {
    "country": "AF",
    "name": "Bulōlah",
    "lat": "34.87706",
    "lng": "68.0879"
  },
  {
    "country": "AF",
    "name": "Bal Chirāgh",
    "lat": "35.84026",
    "lng": "65.2309"
  },
  {
    "country": "AF",
    "name": "Bāzār-e Tālah",
    "lat": "35.39205",
    "lng": "68.22317"
  },
  {
    "country": "AF",
    "name": "Bāsawul",
    "lat": "34.24749",
    "lng": "70.87218"
  },
  {
    "country": "AF",
    "name": "Būrkah",
    "lat": "36.22242",
    "lng": "69.15037"
  },
  {
    "country": "AF",
    "name": "Barg-e Matāl",
    "lat": "35.67283",
    "lng": "71.34339"
  },
  {
    "country": "AF",
    "name": "Baraki Barak",
    "lat": "33.96744",
    "lng": "68.9492"
  },
  {
    "country": "AF",
    "name": "Banū",
    "lat": "35.63348",
    "lng": "69.26019"
  },
  {
    "country": "AF",
    "name": "Bāmyān",
    "lat": "34.82156",
    "lng": "67.82734"
  },
  {
    "country": "AF",
    "name": "Balkh",
    "lat": "36.75635",
    "lng": "66.8972"
  },
  {
    "country": "AF",
    "name": "Bahārak",
    "lat": "37.00254",
    "lng": "70.90664"
  },
  {
    "country": "AF",
    "name": "Bagrāmī",
    "lat": "34.49376",
    "lng": "69.27427"
  },
  {
    "country": "AF",
    "name": "Baghlān",
    "lat": "36.13068",
    "lng": "68.70829"
  },
  {
    "country": "AF",
    "name": "Ḩukūmatī Azrah",
    "lat": "34.17355",
    "lng": "69.64573"
  },
  {
    "country": "AF",
    "name": "Ārt Khwājah",
    "lat": "37.08571",
    "lng": "69.47958"
  },
  {
    "country": "AF",
    "name": "‘Alāqahdārī Aṯghar",
    "lat": "31.73506",
    "lng": "67.3574"
  },
  {
    "country": "AF",
    "name": "Āsmār",
    "lat": "35.03333",
    "lng": "71.35809"
  },
  {
    "country": "AF",
    "name": "Ashkāsham",
    "lat": "36.68333",
    "lng": "71.53333"
  },
  {
    "country": "AF",
    "name": "Asadābād",
    "lat": "34.87311",
    "lng": "71.14697"
  },
  {
    "country": "AF",
    "name": "Āqchah",
    "lat": "36.905",
    "lng": "66.18341"
  },
  {
    "country": "AF",
    "name": "Andkhōy",
    "lat": "36.95293",
    "lng": "65.12376"
  },
  {
    "country": "AF",
    "name": "’Unābah",
    "lat": "35.23251",
    "lng": "69.37719"
  },
  {
    "country": "AF",
    "name": "Anār Darah",
    "lat": "32.7587",
    "lng": "61.65397"
  },
  {
    "country": "AF",
    "name": "Amānzī",
    "lat": "30.21144",
    "lng": "66.04765"
  },
  {
    "country": "AF",
    "name": "‘Alāqahdārī-ye Almār",
    "lat": "35.84616",
    "lng": "64.53074"
  },
  {
    "country": "AF",
    "name": "‘Alī Shēr ‘Alāqahdārī",
    "lat": "33.4362",
    "lng": "70.06711"
  },
  {
    "country": "AF",
    "name": "Wuluswālī ‘Alīngār",
    "lat": "34.83529",
    "lng": "70.3593"
  },
  {
    "country": "AF",
    "name": "‘Alī Khēl",
    "lat": "33.94253",
    "lng": "69.71908"
  },
  {
    "country": "AF",
    "name": "‘Alāqahdārī Yōsuf Khēl",
    "lat": "33.05195",
    "lng": "68.65"
  },
  {
    "country": "AF",
    "name": "‘Alāqahdārī Dīshū",
    "lat": "30.43206",
    "lng": "63.29802"
  },
  {
    "country": "AF",
    "name": "Alah Sāy",
    "lat": "34.8965",
    "lng": "69.72049"
  },
  {
    "country": "AF",
    "name": "Pachīr wa Āgām",
    "lat": "34.20011",
    "lng": "70.27806"
  },
  {
    "country": "AF",
    "name": "Afaki",
    "lat": "36.66172",
    "lng": "69.35095"
  },
  {
    "country": "AF",
    "name": "Adraskan",
    "lat": "33.64573",
    "lng": "62.26959"
  },
  {
    "country": "AF",
    "name": "Āb-e Kamarī",
    "lat": "35.08796",
    "lng": "63.0678"
  },
  {
    "country": "AF",
    "name": "Khadīr",
    "lat": "33.92232",
    "lng": "65.93398"
  },
  {
    "country": "AF",
    "name": "Ghulām ‘Alī",
    "lat": "34.95076",
    "lng": "69.2287"
  },
  {
    "country": "AF",
    "name": "Qarah Bāgh Bāzār",
    "lat": "34.8529",
    "lng": "69.17062"
  },
  {
    "country": "AF",
    "name": "Zargarān",
    "lat": "34.78764",
    "lng": "69.05878"
  },
  {
    "country": "AF",
    "name": "Surkh Bilandī",
    "lat": "34.68474",
    "lng": "69.02863"
  },
  {
    "country": "AF",
    "name": "Pul-e Sangī",
    "lat": "34.59972",
    "lng": "69.25993"
  },
  {
    "country": "AF",
    "name": "Langar",
    "lat": "35.99474",
    "lng": "68.05081"
  },
  {
    "country": "AF",
    "name": "Bāgh-e Maīdān",
    "lat": "35.22156",
    "lng": "69.21397"
  },
  {
    "country": "AF",
    "name": "Ibrāhīm Khān",
    "lat": "35.05352",
    "lng": "69.25654"
  },
  {
    "country": "AF",
    "name": "Qaranghū Tōghaī",
    "lat": "37.21528",
    "lng": "67.63972"
  },
  {
    "country": "AF",
    "name": "Bāzārak",
    "lat": "35.31292",
    "lng": "69.51519"
  },
  {
    "country": "AF",
    "name": "Shērwānī-ye Bālā",
    "lat": "35.01468",
    "lng": "69.59934"
  },
  {
    "country": "AF",
    "name": "Kirāmān",
    "lat": "35.2973",
    "lng": "69.68125"
  },
  {
    "country": "AF",
    "name": "‘Alāqahdārī Saṟōbī",
    "lat": "32.79331",
    "lng": "69.0866"
  },
  {
    "country": "AF",
    "name": "Zerok-Alakadari",
    "lat": "33.15806",
    "lng": "69.31278"
  },
  {
    "country": "AF",
    "name": "Kushkak",
    "lat": "32.28991",
    "lng": "61.52194"
  },
  {
    "country": "AF",
    "name": "Khayr Kōṯ",
    "lat": "32.85355",
    "lng": "68.44971"
  },
  {
    "country": "AF",
    "name": "Chowṉêy",
    "lat": "33.38278",
    "lng": "66.27233"
  },
  {
    "country": "AF",
    "name": "Wuṯahpūr",
    "lat": "34.91914",
    "lng": "71.09863"
  },
  {
    "country": "AF",
    "name": "Karbori",
    "lat": "34.96597",
    "lng": "71.2746"
  },
  {
    "country": "AF",
    "name": "Sulţānpūr-e ‘Ulyā",
    "lat": "34.41204",
    "lng": "70.29634"
  },
  {
    "country": "AF",
    "name": "Babasakhib",
    "lat": "31.66144",
    "lng": "65.66098"
  },
  {
    "country": "AF",
    "name": "Chandal Bā’ī",
    "lat": "34.58469",
    "lng": "68.95524"
  },
  {
    "country": "AF",
    "name": "Dahan-e Jarf",
    "lat": "34.92891",
    "lng": "68.46273"
  },
  {
    "country": "AF",
    "name": "Maydanshakhr",
    "lat": "34.39561",
    "lng": "68.86618"
  },
  {
    "country": "AF",
    "name": "Dū Laīnah",
    "lat": "34.15599",
    "lng": "64.78566"
  },
  {
    "country": "AF",
    "name": "Qaram Qōl",
    "lat": "36.83006",
    "lng": "65.04299"
  },
  {
    "country": "AF",
    "name": "Pul-e Ḩişār",
    "lat": "35.61794",
    "lng": "69.47134"
  },
  {
    "country": "AF",
    "name": "Lab-Sar",
    "lat": "36.02634",
    "lng": "66.83799"
  },
  {
    "country": "AF",
    "name": "Ţāqchah Khānah",
    "lat": "36.61922",
    "lng": "69.62805"
  },
  {
    "country": "AF",
    "name": "March",
    "lat": "37.52845",
    "lng": "70.4482"
  },
  {
    "country": "AF",
    "name": "Zīrakī",
    "lat": "37.59233",
    "lng": "70.55814"
  },
  {
    "country": "AF",
    "name": "Aliabad",
    "lat": "36.52115",
    "lng": "68.89985"
  },
  {
    "country": "AF",
    "name": "Pas Pul",
    "lat": "37.47355",
    "lng": "70.61617"
  },
  {
    "country": "AF",
    "name": "Qal‘ah-ye Na‘īm",
    "lat": "34.39951",
    "lng": "69.16705"
  },
  {
    "country": "AF",
    "name": "Markaz-e Woluswalī-ye Āchīn",
    "lat": "34.12583",
    "lng": "70.70778"
  },
  {
    "country": "AF",
    "name": "Manogay",
    "lat": "34.99015",
    "lng": "70.91302"
  },
  {
    "country": "AF",
    "name": "Stêr Giyān",
    "lat": "32.97704",
    "lng": "69.37308"
  },
  {
    "country": "AF",
    "name": "Sharan",
    "lat": "33.17568",
    "lng": "68.73045"
  },
  {
    "country": "AF",
    "name": "Salām Khēl",
    "lat": "33.67067",
    "lng": "69.32983"
  },
  {
    "country": "AG",
    "name": "Saint John’s",
    "lat": "17.12096",
    "lng": "-61.84329"
  },
  {
    "country": "AG",
    "name": "Potters Village",
    "lat": "17.11337",
    "lng": "-61.81962"
  },
  {
    "country": "AG",
    "name": "Piggotts",
    "lat": "17.11667",
    "lng": "-61.8"
  },
  {
    "country": "AG",
    "name": "Parham",
    "lat": "17.09682",
    "lng": "-61.77046"
  },
  {
    "country": "AG",
    "name": "Liberta",
    "lat": "17.04141",
    "lng": "-61.79052"
  },
  {
    "country": "AG",
    "name": "Falmouth",
    "lat": "17.02741",
    "lng": "-61.78136"
  },
  {
    "country": "AG",
    "name": "Codrington",
    "lat": "17.63333",
    "lng": "-61.83333"
  },
  {
    "country": "AG",
    "name": "Bolands",
    "lat": "17.06565",
    "lng": "-61.87466"
  },
  {
    "country": "AG",
    "name": "All Saints",
    "lat": "17.06671",
    "lng": "-61.79303"
  },
  {
    "country": "AI",
    "name": "West End Village",
    "lat": "18.17191",
    "lng": "-63.14941"
  },
  {
    "country": "AI",
    "name": "The Valley",
    "lat": "18.21704",
    "lng": "-63.05783"
  },
  {
    "country": "AI",
    "name": "The Quarter",
    "lat": "18.20799",
    "lng": "-63.04178"
  },
  {
    "country": "AI",
    "name": "Farrington",
    "lat": "18.215",
    "lng": "-63.02238"
  },
  {
    "country": "AI",
    "name": "Stoney Ground",
    "lat": "18.22026",
    "lng": "-63.04607"
  },
  {
    "country": "AI",
    "name": "South Hill Village",
    "lat": "18.19201",
    "lng": "-63.08779"
  },
  {
    "country": "AI",
    "name": "Sandy Ground Village",
    "lat": "18.20118",
    "lng": "-63.08998"
  },
  {
    "country": "AI",
    "name": "North Side",
    "lat": "18.22919",
    "lng": "-63.04401"
  },
  {
    "country": "AI",
    "name": "North Hill Village",
    "lat": "18.20542",
    "lng": "-63.07847"
  },
  {
    "country": "AI",
    "name": "Island Harbour",
    "lat": "18.25601",
    "lng": "-63.0102"
  },
  {
    "country": "AI",
    "name": "George Hill",
    "lat": "18.19939",
    "lng": "-63.0665"
  },
  {
    "country": "AI",
    "name": "East End Village",
    "lat": "18.23333",
    "lng": "-63"
  },
  {
    "country": "AI",
    "name": "Blowing Point Village",
    "lat": "18.17648",
    "lng": "-63.09375"
  },
  {
    "country": "AI",
    "name": "Sandy Hill",
    "lat": "18.22104",
    "lng": "-63.01329"
  },
  {
    "country": "AL",
    "name": "Xarrë",
    "lat": "39.72833",
    "lng": "20.05444"
  },
  {
    "country": "AL",
    "name": "Sarandë",
    "lat": "39.87534",
    "lng": "20.00477"
  },
  {
    "country": "AL",
    "name": "Mesopotam",
    "lat": "39.91028",
    "lng": "20.09222"
  },
  {
    "country": "AL",
    "name": "Markat",
    "lat": "39.73278",
    "lng": "20.19528"
  },
  {
    "country": "AL",
    "name": "Livadhja",
    "lat": "39.78917",
    "lng": "20.12194"
  },
  {
    "country": "AL",
    "name": "Konispol",
    "lat": "39.65889",
    "lng": "20.18139"
  },
  {
    "country": "AL",
    "name": "Kakavijë",
    "lat": "39.90778",
    "lng": "20.35833"
  },
  {
    "country": "AL",
    "name": "Finiq",
    "lat": "39.90639",
    "lng": "20.05833"
  },
  {
    "country": "AL",
    "name": "Dhivër",
    "lat": "39.83611",
    "lng": "20.16861"
  },
  {
    "country": "AL",
    "name": "Delvinë",
    "lat": "39.95111",
    "lng": "20.09778"
  },
  {
    "country": "AL",
    "name": "Aliko",
    "lat": "39.85861",
    "lng": "20.07917"
  },
  {
    "country": "AL",
    "name": "Buçimas",
    "lat": "40.89139",
    "lng": "20.68139"
  },
  {
    "country": "AL",
    "name": "Zhepë",
    "lat": "40.67778",
    "lng": "20.28694"
  },
  {
    "country": "AL",
    "name": "Zerqan",
    "lat": "41.50222",
    "lng": "20.36056"
  },
  {
    "country": "AL",
    "name": "Zavalinë",
    "lat": "40.98083",
    "lng": "20.28083"
  },
  {
    "country": "AL",
    "name": "Zapod",
    "lat": "42.05056",
    "lng": "20.5525"
  },
  {
    "country": "AL",
    "name": "Zall-Reç",
    "lat": "41.87611",
    "lng": "20.32"
  },
  {
    "country": "AL",
    "name": "Zall-Dardhë",
    "lat": "41.80667",
    "lng": "20.33611"
  },
  {
    "country": "AL",
    "name": "Xibër-Murrizë",
    "lat": "41.45472",
    "lng": "20.02556"
  },
  {
    "country": "AL",
    "name": "Vreshtas",
    "lat": "40.79694",
    "lng": "20.77694"
  },
  {
    "country": "AL",
    "name": "Voskopojë",
    "lat": "40.63306",
    "lng": "20.58889"
  },
  {
    "country": "AL",
    "name": "Voskop",
    "lat": "40.61194",
    "lng": "20.69028"
  },
  {
    "country": "AL",
    "name": "Vithkuq",
    "lat": "40.525",
    "lng": "20.5825"
  },
  {
    "country": "AL",
    "name": "Vithkuq",
    "lat": "40.20472",
    "lng": "20.25944"
  },
  {
    "country": "AL",
    "name": "Vërtop",
    "lat": "40.62889",
    "lng": "20.05389"
  },
  {
    "country": "AL",
    "name": "Vergo",
    "lat": "40.00667",
    "lng": "20.00889"
  },
  {
    "country": "AL",
    "name": "Vendresha e Vogël",
    "lat": "40.50722",
    "lng": "20.13472"
  },
  {
    "country": "AL",
    "name": "Velçan",
    "lat": "40.95472",
    "lng": "20.46222"
  },
  {
    "country": "AL",
    "name": "Ujmisht",
    "lat": "41.90833",
    "lng": "20.34694"
  },
  {
    "country": "AL",
    "name": "Udënisht",
    "lat": "40.96333",
    "lng": "20.63917"
  },
  {
    "country": "AL",
    "name": "Tunjë",
    "lat": "40.83417",
    "lng": "20.11194"
  },
  {
    "country": "AL",
    "name": "Tregan",
    "lat": "41.02472",
    "lng": "20.07833"
  },
  {
    "country": "AL",
    "name": "Trebisht-Muçinë",
    "lat": "41.41111",
    "lng": "20.53556"
  },
  {
    "country": "AL",
    "name": "Trebinjë",
    "lat": "40.91333",
    "lng": "20.55306"
  },
  {
    "country": "AL",
    "name": "Topojan",
    "lat": "40.37722",
    "lng": "20.21333"
  },
  {
    "country": "AL",
    "name": "Tomin",
    "lat": "41.69083",
    "lng": "20.42167"
  },
  {
    "country": "AL",
    "name": "Tepelenë",
    "lat": "40.29583",
    "lng": "20.01917"
  },
  {
    "country": "AL",
    "name": "Surroj",
    "lat": "41.99222",
    "lng": "20.34417"
  },
  {
    "country": "AL",
    "name": "Sult",
    "lat": "40.88472",
    "lng": "20.09944"
  },
  {
    "country": "AL",
    "name": "Sukë",
    "lat": "40.37528",
    "lng": "20.15472"
  },
  {
    "country": "AL",
    "name": "Suç",
    "lat": "41.57694",
    "lng": "20.05139"
  },
  {
    "country": "AL",
    "name": "Stravaj",
    "lat": "41.00528",
    "lng": "20.42306"
  },
  {
    "country": "AL",
    "name": "Steblevë",
    "lat": "41.33722",
    "lng": "20.47"
  },
  {
    "country": "AL",
    "name": "Sllovë",
    "lat": "41.80111",
    "lng": "20.40833"
  },
  {
    "country": "AL",
    "name": "Skore",
    "lat": "40.10722",
    "lng": "20.36639"
  },
  {
    "country": "AL",
    "name": "Skënderbegas",
    "lat": "40.77611",
    "lng": "20.24056"
  },
  {
    "country": "AL",
    "name": "Shushicë",
    "lat": "41.0975",
    "lng": "20.14833"
  },
  {
    "country": "AL",
    "name": "Shupenzë",
    "lat": "41.53",
    "lng": "20.42361"
  },
  {
    "country": "AL",
    "name": "Shtiqën",
    "lat": "42.04056",
    "lng": "20.43417"
  },
  {
    "country": "AL",
    "name": "Shishtavec",
    "lat": "41.98",
    "lng": "20.60583"
  },
  {
    "country": "AL",
    "name": "Shirgjan",
    "lat": "41.05194",
    "lng": "20.05333"
  },
  {
    "country": "AL",
    "name": "Shëngjin",
    "lat": "41.92611",
    "lng": "20.18833"
  },
  {
    "country": "AL",
    "name": "Shënmëri",
    "lat": "42.10417",
    "lng": "20.23833"
  },
  {
    "country": "AL",
    "name": "Selishtë",
    "lat": "41.6275",
    "lng": "20.27917"
  },
  {
    "country": "AL",
    "name": "Saraqinishtë",
    "lat": "40.10528",
    "lng": "20.22944"
  },
  {
    "country": "AL",
    "name": "Rukaj",
    "lat": "41.68361",
    "lng": "20.01917"
  },
  {
    "country": "AL",
    "name": "Rajcë",
    "lat": "41.09028",
    "lng": "20.57639"
  },
  {
    "country": "AL",
    "name": "Roshnik",
    "lat": "40.73278",
    "lng": "20.03944"
  },
  {
    "country": "AL",
    "name": "Qukës-Skënderbe",
    "lat": "41.08389",
    "lng": "20.43806"
  },
  {
    "country": "AL",
    "name": "Qestorat",
    "lat": "40.1175",
    "lng": "20.19972"
  },
  {
    "country": "AL",
    "name": "Qafëmal",
    "lat": "42.09333",
    "lng": "20.09056"
  },
  {
    "country": "AL",
    "name": "Përrenjas-Fshat",
    "lat": "41.06667",
    "lng": "20.53528"
  },
  {
    "country": "AL",
    "name": "Përrenjas",
    "lat": "41.07306",
    "lng": "20.54889"
  },
  {
    "country": "AL",
    "name": "Proptisht",
    "lat": "40.98611",
    "lng": "20.5025"
  },
  {
    "country": "AL",
    "name": "Progër",
    "lat": "40.69417",
    "lng": "20.94028"
  },
  {
    "country": "AL",
    "name": "Potom",
    "lat": "40.48833",
    "lng": "20.37333"
  },
  {
    "country": "AL",
    "name": "Poroçan",
    "lat": "40.94194",
    "lng": "20.29861"
  },
  {
    "country": "AL",
    "name": "Polis-Gostimë",
    "lat": "41.13333",
    "lng": "20.25833"
  },
  {
    "country": "AL",
    "name": "Poliçan",
    "lat": "40.61222",
    "lng": "20.09806"
  },
  {
    "country": "AL",
    "name": "Pojan",
    "lat": "40.72583",
    "lng": "20.8375"
  },
  {
    "country": "AL",
    "name": "Pogradec",
    "lat": "40.9025",
    "lng": "20.6525"
  },
  {
    "country": "AL",
    "name": "Pishaj",
    "lat": "40.88111",
    "lng": "20.18278"
  },
  {
    "country": "AL",
    "name": "Pirg",
    "lat": "40.785",
    "lng": "20.70611"
  },
  {
    "country": "AL",
    "name": "Gjinkar",
    "lat": "40.19944",
    "lng": "20.40611"
  },
  {
    "country": "AL",
    "name": "Petran",
    "lat": "40.20944",
    "lng": "20.41833"
  },
  {
    "country": "AL",
    "name": "Peshkopi",
    "lat": "41.685",
    "lng": "20.42889"
  },
  {
    "country": "AL",
    "name": "Përmet",
    "lat": "40.23361",
    "lng": "20.35167"
  },
  {
    "country": "AL",
    "name": "Ostreni i Math",
    "lat": "41.43083",
    "lng": "20.45556"
  },
  {
    "country": "AL",
    "name": "Orosh",
    "lat": "41.83333",
    "lng": "20.08333"
  },
  {
    "country": "AL",
    "name": "Orenjë",
    "lat": "41.28472",
    "lng": "20.21194"
  },
  {
    "country": "AL",
    "name": "Odrie",
    "lat": "40.13333",
    "lng": "20.16667"
  },
  {
    "country": "AL",
    "name": "Novoselë",
    "lat": "40.76139",
    "lng": "20.69833"
  },
  {
    "country": "AL",
    "name": "Picar",
    "lat": "40.16667",
    "lng": "20.04833"
  },
  {
    "country": "AL",
    "name": "Mollas",
    "lat": "40.92694",
    "lng": "20.00361"
  },
  {
    "country": "AL",
    "name": "Mollas",
    "lat": "40.42556",
    "lng": "20.67444"
  },
  {
    "country": "AL",
    "name": "Mollaj",
    "lat": "40.56028",
    "lng": "20.74028"
  },
  {
    "country": "AL",
    "name": "Miras",
    "lat": "40.50917",
    "lng": "20.92833"
  },
  {
    "country": "AL",
    "name": "Melan",
    "lat": "41.65417",
    "lng": "20.46528"
  },
  {
    "country": "AL",
    "name": "Martanesh",
    "lat": "41.4",
    "lng": "20.2"
  },
  {
    "country": "AL",
    "name": "Maqellarë",
    "lat": "41.58889",
    "lng": "20.48306"
  },
  {
    "country": "AL",
    "name": "Maliq",
    "lat": "40.70583",
    "lng": "20.69972"
  },
  {
    "country": "AL",
    "name": "Macukull",
    "lat": "41.68861",
    "lng": "20.11028"
  },
  {
    "country": "AL",
    "name": "Lunik",
    "lat": "41.28917",
    "lng": "20.32361"
  },
  {
    "country": "AL",
    "name": "Llugaj",
    "lat": "42.34139",
    "lng": "20.10861"
  },
  {
    "country": "AL",
    "name": "Lis",
    "lat": "41.6275",
    "lng": "20.08528"
  },
  {
    "country": "AL",
    "name": "Liqenas",
    "lat": "40.78667",
    "lng": "20.90222"
  },
  {
    "country": "AL",
    "name": "Librazhd",
    "lat": "41.17944",
    "lng": "20.315"
  },
  {
    "country": "AL",
    "name": "Libonik",
    "lat": "40.70444",
    "lng": "20.70861"
  },
  {
    "country": "AL",
    "name": "Libohovë",
    "lat": "40.03111",
    "lng": "20.26306"
  },
  {
    "country": "AL",
    "name": "Leskovik",
    "lat": "40.15139",
    "lng": "20.59722"
  },
  {
    "country": "AL",
    "name": "Leshnjë",
    "lat": "40.53694",
    "lng": "20.31333"
  },
  {
    "country": "AL",
    "name": "Lenias",
    "lat": "40.76667",
    "lng": "20.39139"
  },
  {
    "country": "AL",
    "name": "Lekas",
    "lat": "40.60222",
    "lng": "20.5125"
  },
  {
    "country": "AL",
    "name": "Lazarat",
    "lat": "40.04667",
    "lng": "20.1475"
  },
  {
    "country": "AL",
    "name": "Labinot-Mal",
    "lat": "41.20083",
    "lng": "20.15222"
  },
  {
    "country": "AL",
    "name": "Labinot-Fushë",
    "lat": "41.14056",
    "lng": "20.14611"
  },
  {
    "country": "AL",
    "name": "Kushovë",
    "lat": "40.78889",
    "lng": "20.18889"
  },
  {
    "country": "AL",
    "name": "Kurbnesh",
    "lat": "41.77972",
    "lng": "20.08361"
  },
  {
    "country": "AL",
    "name": "Kukur",
    "lat": "40.86778",
    "lng": "20.36361"
  },
  {
    "country": "AL",
    "name": "Kukës",
    "lat": "42.07694",
    "lng": "20.42194"
  },
  {
    "country": "AL",
    "name": "Kthella e Epërme",
    "lat": "41.81194",
    "lng": "20.05889"
  },
  {
    "country": "AL",
    "name": "Krumë",
    "lat": "42.19694",
    "lng": "20.41333"
  },
  {
    "country": "AL",
    "name": "Korçë",
    "lat": "40.61861",
    "lng": "20.78083"
  },
  {
    "country": "AL",
    "name": "Kolsh",
    "lat": "42.07806",
    "lng": "20.34194"
  },
  {
    "country": "AL",
    "name": "Kodovjat",
    "lat": "40.80556",
    "lng": "20.25111"
  },
  {
    "country": "AL",
    "name": "Klos",
    "lat": "41.50694",
    "lng": "20.08667"
  },
  {
    "country": "AL",
    "name": "Klos",
    "lat": "40.94611",
    "lng": "20.00972"
  },
  {
    "country": "AL",
    "name": "Këlcyrë",
    "lat": "40.31306",
    "lng": "20.18944"
  },
  {
    "country": "AL",
    "name": "Kastriot",
    "lat": "41.72944",
    "lng": "20.37722"
  },
  {
    "country": "AL",
    "name": "Kardhiq",
    "lat": "40.12167",
    "lng": "20.0275"
  },
  {
    "country": "AL",
    "name": "Kalis",
    "lat": "41.83889",
    "lng": "20.36667"
  },
  {
    "country": "AL",
    "name": "Iballë",
    "lat": "42.1875",
    "lng": "20.0025"
  },
  {
    "country": "AL",
    "name": "Hotolisht",
    "lat": "41.15667",
    "lng": "20.39722"
  },
  {
    "country": "AL",
    "name": "Hoçisht",
    "lat": "40.60833",
    "lng": "20.91417"
  },
  {
    "country": "AL",
    "name": "Gramsh",
    "lat": "40.86972",
    "lng": "20.18444"
  },
  {
    "country": "AL",
    "name": "Gostimë",
    "lat": "41.14556",
    "lng": "20.24"
  },
  {
    "country": "AL",
    "name": "Golaj",
    "lat": "42.2475",
    "lng": "20.38028"
  },
  {
    "country": "AL",
    "name": "Gjorica e Sipërme",
    "lat": "41.53444",
    "lng": "20.45"
  },
  {
    "country": "AL",
    "name": "Gjirokastër",
    "lat": "40.07583",
    "lng": "20.13889"
  },
  {
    "country": "AL",
    "name": "Gjinar",
    "lat": "41.0225",
    "lng": "20.18889"
  },
  {
    "country": "AL",
    "name": "Gjinaj",
    "lat": "42.11806",
    "lng": "20.43583"
  },
  {
    "country": "AL",
    "name": "Gjergjan",
    "lat": "41.04306",
    "lng": "20.02972"
  },
  {
    "country": "AL",
    "name": "Gjegjan",
    "lat": "41.93778",
    "lng": "20.01111"
  },
  {
    "country": "AL",
    "name": "Fushë-Muhurr",
    "lat": "41.67972",
    "lng": "20.33139"
  },
  {
    "country": "AL",
    "name": "Fushë-Lurë",
    "lat": "41.80611",
    "lng": "20.23194"
  },
  {
    "country": "AL",
    "name": "Fushë-Çidhnë",
    "lat": "41.76056",
    "lng": "20.34111"
  },
  {
    "country": "AL",
    "name": "Fushë-Bulqizë",
    "lat": "41.52194",
    "lng": "20.28222"
  },
  {
    "country": "AL",
    "name": "Fushë-Arrëz",
    "lat": "42.06222",
    "lng": "20.01667"
  },
  {
    "country": "AL",
    "name": "Frashër",
    "lat": "40.36889",
    "lng": "20.42444"
  },
  {
    "country": "AL",
    "name": "Fierzë",
    "lat": "42.26056",
    "lng": "20.01694"
  },
  {
    "country": "AL",
    "name": "Fajzë",
    "lat": "42.16694",
    "lng": "20.35083"
  },
  {
    "country": "AL",
    "name": "Ersekë",
    "lat": "40.33778",
    "lng": "20.67889"
  },
  {
    "country": "AL",
    "name": "Elbasan",
    "lat": "41.1125",
    "lng": "20.08222"
  },
  {
    "country": "AL",
    "name": "Drenovë",
    "lat": "40.58333",
    "lng": "20.79222"
  },
  {
    "country": "AL",
    "name": "Dishnicë",
    "lat": "40.65139",
    "lng": "20.81361"
  },
  {
    "country": "AL",
    "name": "Derjan",
    "lat": "41.67361",
    "lng": "20.05833"
  },
  {
    "country": "AL",
    "name": "Gjerbës",
    "lat": "40.62917",
    "lng": "20.25111"
  },
  {
    "country": "AL",
    "name": "Çorovodë",
    "lat": "40.50417",
    "lng": "20.22722"
  },
  {
    "country": "AL",
    "name": "Çlirim",
    "lat": "40.4175",
    "lng": "20.55028"
  },
  {
    "country": "AL",
    "name": "Cerava",
    "lat": "40.85139",
    "lng": "20.725"
  },
  {
    "country": "AL",
    "name": "Çepan",
    "lat": "40.42056",
    "lng": "20.26056"
  },
  {
    "country": "AL",
    "name": "Çarshovë",
    "lat": "40.11806",
    "lng": "20.54083"
  },
  {
    "country": "AL",
    "name": "Kokaj",
    "lat": "41.87833",
    "lng": "20.50472"
  },
  {
    "country": "AL",
    "name": "Buz",
    "lat": "40.445",
    "lng": "20.00472"
  },
  {
    "country": "AL",
    "name": "Bushtricë",
    "lat": "41.87861",
    "lng": "20.42194"
  },
  {
    "country": "AL",
    "name": "Burrel",
    "lat": "41.61028",
    "lng": "20.00889"
  },
  {
    "country": "AL",
    "name": "Bulqizë",
    "lat": "41.49167",
    "lng": "20.22194"
  },
  {
    "country": "AL",
    "name": "Bujan",
    "lat": "42.32639",
    "lng": "20.07639"
  },
  {
    "country": "AL",
    "name": "Bradashesh",
    "lat": "41.105",
    "lng": "20.0225"
  },
  {
    "country": "AL",
    "name": "Blinisht",
    "lat": "41.86139",
    "lng": "20"
  },
  {
    "country": "AL",
    "name": "Blerim",
    "lat": "42.16056",
    "lng": "20.19194"
  },
  {
    "country": "AL",
    "name": "Bilisht",
    "lat": "40.6275",
    "lng": "20.99"
  },
  {
    "country": "AL",
    "name": "Bicaj",
    "lat": "41.99472",
    "lng": "20.4125"
  },
  {
    "country": "AL",
    "name": "Dardhas",
    "lat": "40.84583",
    "lng": "20.65722"
  },
  {
    "country": "AL",
    "name": "Barmash",
    "lat": "40.27778",
    "lng": "20.61833"
  },
  {
    "country": "AL",
    "name": "Ballaban",
    "lat": "40.41667",
    "lng": "20.13444"
  },
  {
    "country": "AL",
    "name": "Arrën",
    "lat": "41.91306",
    "lng": "20.28833"
  },
  {
    "country": "AL",
    "name": "Arras",
    "lat": "41.73583",
    "lng": "20.32417"
  },
  {
    "country": "AL",
    "name": "Bytyç",
    "lat": "42.31",
    "lng": "20.20278"
  },
  {
    "country": "AL",
    "name": "Librazhd-Qendër",
    "lat": "41.19694",
    "lng": "20.33556"
  },
  {
    "country": "AL",
    "name": "Funarë",
    "lat": "41.19639",
    "lng": "20.05972"
  },
  {
    "country": "AL",
    "name": "Moglicë",
    "lat": "40.71806",
    "lng": "20.43806"
  },
  {
    "country": "AL",
    "name": "Bogovë",
    "lat": "40.57111",
    "lng": "20.15"
  },
  {
    "country": "AL",
    "name": "Piskovë",
    "lat": "40.27917",
    "lng": "20.2725"
  },
  {
    "country": "AL",
    "name": "Lukovë",
    "lat": "39.99222",
    "lng": "19.91389"
  },
  {
    "country": "AL",
    "name": "Ksamil",
    "lat": "39.76889",
    "lng": "19.99972"
  },
  {
    "country": "AL",
    "name": "Zharrëz",
    "lat": "40.70917",
    "lng": "19.64972"
  },
  {
    "country": "AL",
    "name": "Zejmen",
    "lat": "41.70778",
    "lng": "19.68917"
  },
  {
    "country": "AL",
    "name": "Zall-Herr",
    "lat": "41.38944",
    "lng": "19.8275"
  },
  {
    "country": "AL",
    "name": "Zall-Bastar",
    "lat": "41.42972",
    "lng": "19.93028"
  },
  {
    "country": "AL",
    "name": "Xhafzotaj",
    "lat": "41.34444",
    "lng": "19.5475"
  },
  {
    "country": "AL",
    "name": "Vukatanë",
    "lat": "42.02806",
    "lng": "19.54778"
  },
  {
    "country": "AL",
    "name": "Vranisht",
    "lat": "40.20972",
    "lng": "19.69083"
  },
  {
    "country": "AL",
    "name": "Vorë",
    "lat": "41.39083",
    "lng": "19.655"
  },
  {
    "country": "AL",
    "name": "Vlorë",
    "lat": "40.46667",
    "lng": "19.48972"
  },
  {
    "country": "AL",
    "name": "Velipojë",
    "lat": "41.87833",
    "lng": "19.40556"
  },
  {
    "country": "AL",
    "name": "Velabisht",
    "lat": "40.70167",
    "lng": "19.93222"
  },
  {
    "country": "AL",
    "name": "Vaqarr",
    "lat": "41.29917",
    "lng": "19.74417"
  },
  {
    "country": "AL",
    "name": "Ura Vajgurore",
    "lat": "40.76889",
    "lng": "19.87778"
  },
  {
    "country": "AL",
    "name": "Ungrej",
    "lat": "41.87528",
    "lng": "19.79472"
  },
  {
    "country": "AL",
    "name": "Ulëz",
    "lat": "41.68278",
    "lng": "19.89333"
  },
  {
    "country": "AL",
    "name": "Topojë",
    "lat": "40.76306",
    "lng": "19.43278"
  },
  {
    "country": "AL",
    "name": "Tirana",
    "lat": "41.3275",
    "lng": "19.81889"
  },
  {
    "country": "AL",
    "name": "Thumanë",
    "lat": "41.5475",
    "lng": "19.67778"
  },
  {
    "country": "AL",
    "name": "Tërbuf",
    "lat": "41.04",
    "lng": "19.61417"
  },
  {
    "country": "AL",
    "name": "Synej",
    "lat": "41.18",
    "lng": "19.5425"
  },
  {
    "country": "AL",
    "name": "Sukth",
    "lat": "41.38056",
    "lng": "19.53778"
  },
  {
    "country": "AL",
    "name": "Strum",
    "lat": "40.75111",
    "lng": "19.7375"
  },
  {
    "country": "AL",
    "name": "Sinjë",
    "lat": "40.64806",
    "lng": "19.86806"
  },
  {
    "country": "AL",
    "name": "Sinaballaj",
    "lat": "41.06889",
    "lng": "19.69944"
  },
  {
    "country": "AL",
    "name": "Shkodër",
    "lat": "42.06828",
    "lng": "19.51258"
  },
  {
    "country": "AL",
    "name": "Shijak",
    "lat": "41.34556",
    "lng": "19.56722"
  },
  {
    "country": "AL",
    "name": "Shezë",
    "lat": "41.02417",
    "lng": "19.81611"
  },
  {
    "country": "AL",
    "name": "Shënkoll",
    "lat": "41.69083",
    "lng": "19.65333"
  },
  {
    "country": "AL",
    "name": "Shëngjin",
    "lat": "41.81361",
    "lng": "19.59389"
  },
  {
    "country": "AL",
    "name": "Shëngjergj",
    "lat": "41.18333",
    "lng": "19.53333"
  },
  {
    "country": "AL",
    "name": "Shalës",
    "lat": "40.99861",
    "lng": "19.94778"
  },
  {
    "country": "AL",
    "name": "Nicaj-Shalë",
    "lat": "42.29944",
    "lng": "19.805"
  },
  {
    "country": "AL",
    "name": "Sevaster",
    "lat": "40.39639",
    "lng": "19.72972"
  },
  {
    "country": "AL",
    "name": "Selitë",
    "lat": "41.63528",
    "lng": "19.755"
  },
  {
    "country": "AL",
    "name": "Valbonë",
    "lat": "42.45139",
    "lng": "19.89167"
  },
  {
    "country": "AL",
    "name": "Selenicë",
    "lat": "40.53056",
    "lng": "19.63583"
  },
  {
    "country": "AL",
    "name": "Ruzhdie",
    "lat": "40.67083",
    "lng": "19.69833"
  },
  {
    "country": "AL",
    "name": "Rubik",
    "lat": "41.77444",
    "lng": "19.78611"
  },
  {
    "country": "AL",
    "name": "Rrogozhinë",
    "lat": "41.07639",
    "lng": "19.66528"
  },
  {
    "country": "AL",
    "name": "Rrëshen",
    "lat": "41.7675",
    "lng": "19.87556"
  },
  {
    "country": "AL",
    "name": "Rrashbull",
    "lat": "41.32278",
    "lng": "19.51028"
  },
  {
    "country": "AL",
    "name": "Rrasa e Sipërme",
    "lat": "40.96778",
    "lng": "19.82111"
  },
  {
    "country": "AL",
    "name": "Rrapë",
    "lat": "42.04444",
    "lng": "19.97056"
  },
  {
    "country": "AL",
    "name": "Roskovec",
    "lat": "40.7375",
    "lng": "19.70222"
  },
  {
    "country": "AL",
    "name": "Remas",
    "lat": "40.88639",
    "lng": "19.51139"
  },
  {
    "country": "AL",
    "name": "Qerret",
    "lat": "42.05306",
    "lng": "19.83722"
  },
  {
    "country": "AL",
    "name": "Qelëz",
    "lat": "42.08972",
    "lng": "19.895"
  },
  {
    "country": "AL",
    "name": "Pukë",
    "lat": "42.04444",
    "lng": "19.89972"
  },
  {
    "country": "AL",
    "name": "Progonat",
    "lat": "40.21333",
    "lng": "19.94472"
  },
  {
    "country": "AL",
    "name": "Prezë",
    "lat": "41.42722",
    "lng": "19.67278"
  },
  {
    "country": "AL",
    "name": "Poshnje",
    "lat": "40.78028",
    "lng": "19.84417"
  },
  {
    "country": "AL",
    "name": "Portëz",
    "lat": "40.69917",
    "lng": "19.57444"
  },
  {
    "country": "AL",
    "name": "Peza e Madhe",
    "lat": "41.2175",
    "lng": "19.69611"
  },
  {
    "country": "AL",
    "name": "Petrelë",
    "lat": "41.25306",
    "lng": "19.85306"
  },
  {
    "country": "AL",
    "name": "Përparim",
    "lat": "41.05",
    "lng": "19.79917"
  },
  {
    "country": "AL",
    "name": "Perondi",
    "lat": "40.77889",
    "lng": "19.92306"
  },
  {
    "country": "AL",
    "name": "Peqin",
    "lat": "41.04611",
    "lng": "19.75111"
  },
  {
    "country": "AL",
    "name": "Patos Fshat",
    "lat": "40.64278",
    "lng": "19.65083"
  },
  {
    "country": "AL",
    "name": "Patos",
    "lat": "40.68333",
    "lng": "19.61944"
  },
  {
    "country": "AL",
    "name": "Paskuqan",
    "lat": "41.35389",
    "lng": "19.80667"
  },
  {
    "country": "AL",
    "name": "Papër",
    "lat": "41.05167",
    "lng": "19.96083"
  },
  {
    "country": "AL",
    "name": "Pajovë",
    "lat": "41.05472",
    "lng": "19.8375"
  },
  {
    "country": "AL",
    "name": "Otllak",
    "lat": "40.74389",
    "lng": "19.93528"
  },
  {
    "country": "AL",
    "name": "Orikum",
    "lat": "40.32528",
    "lng": "19.47139"
  },
  {
    "country": "AL",
    "name": "Novoselë",
    "lat": "40.625",
    "lng": "19.46694"
  },
  {
    "country": "AL",
    "name": "Nikël",
    "lat": "41.44417",
    "lng": "19.74833"
  },
  {
    "country": "AL",
    "name": "Nicaj-Shosh",
    "lat": "42.24444",
    "lng": "19.75806"
  },
  {
    "country": "AL",
    "name": "Ngraçan",
    "lat": "40.64444",
    "lng": "19.7925"
  },
  {
    "country": "AL",
    "name": "Ndroq",
    "lat": "41.26389",
    "lng": "19.65583"
  },
  {
    "country": "AL",
    "name": "Milot",
    "lat": "41.68389",
    "lng": "19.71556"
  },
  {
    "country": "AL",
    "name": "Memaliaj",
    "lat": "40.35167",
    "lng": "19.98028"
  },
  {
    "country": "AL",
    "name": "Mbrostar-Urë",
    "lat": "40.75361",
    "lng": "19.57944"
  },
  {
    "country": "AL",
    "name": "Manzë",
    "lat": "41.42861",
    "lng": "19.59306"
  },
  {
    "country": "AL",
    "name": "Mamurras",
    "lat": "41.5775",
    "lng": "19.69222"
  },
  {
    "country": "AL",
    "name": "Maminas",
    "lat": "41.37917",
    "lng": "19.6075"
  },
  {
    "country": "AL",
    "name": "Luzi i Vogël",
    "lat": "41.1275",
    "lng": "19.57389"
  },
  {
    "country": "AL",
    "name": "Lushnjë",
    "lat": "40.94194",
    "lng": "19.705"
  },
  {
    "country": "AL",
    "name": "Luftinjë",
    "lat": "40.44278",
    "lng": "19.95444"
  },
  {
    "country": "AL",
    "name": "Libofshë",
    "lat": "40.83444",
    "lng": "19.55222"
  },
  {
    "country": "AL",
    "name": "Lezhë",
    "lat": "41.78361",
    "lng": "19.64361"
  },
  {
    "country": "AL",
    "name": "Levan",
    "lat": "40.67611",
    "lng": "19.48972"
  },
  {
    "country": "AL",
    "name": "Lekbibaj",
    "lat": "42.29472",
    "lng": "19.93167"
  },
  {
    "country": "AL",
    "name": "Lekaj",
    "lat": "41.11444",
    "lng": "19.60972"
  },
  {
    "country": "AL",
    "name": "Laç",
    "lat": "41.63556",
    "lng": "19.71306"
  },
  {
    "country": "AL",
    "name": "Kutë",
    "lat": "40.47333",
    "lng": "19.76639"
  },
  {
    "country": "AL",
    "name": "Kutalli",
    "lat": "40.78389",
    "lng": "19.78667"
  },
  {
    "country": "AL",
    "name": "Kurjan",
    "lat": "40.7175",
    "lng": "19.74556"
  },
  {
    "country": "AL",
    "name": "Kuman",
    "lat": "40.72667",
    "lng": "19.68667"
  },
  {
    "country": "AL",
    "name": "Kuçovë",
    "lat": "40.80028",
    "lng": "19.91667"
  },
  {
    "country": "AL",
    "name": "Kuç",
    "lat": "42.03972",
    "lng": "19.52528"
  },
  {
    "country": "AL",
    "name": "Kryevidh",
    "lat": "41.10056",
    "lng": "19.5275"
  },
  {
    "country": "AL",
    "name": "Krutja e Poshtme",
    "lat": "40.87194",
    "lng": "19.68083"
  },
  {
    "country": "AL",
    "name": "Krujë",
    "lat": "41.50917",
    "lng": "19.79278"
  },
  {
    "country": "AL",
    "name": "Krrabë",
    "lat": "41.21556",
    "lng": "19.97139"
  },
  {
    "country": "AL",
    "name": "Krahës",
    "lat": "40.43861",
    "lng": "19.84444"
  },
  {
    "country": "AL",
    "name": "Kozarë",
    "lat": "40.83083",
    "lng": "19.90056"
  },
  {
    "country": "AL",
    "name": "Kotë",
    "lat": "40.38944",
    "lng": "19.60222"
  },
  {
    "country": "AL",
    "name": "Koplik",
    "lat": "42.21361",
    "lng": "19.43639"
  },
  {
    "country": "AL",
    "name": "Kombësi",
    "lat": "41.58167",
    "lng": "19.98556"
  },
  {
    "country": "AL",
    "name": "Kolonjë",
    "lat": "40.82417",
    "lng": "19.60389"
  },
  {
    "country": "AL",
    "name": "Kolç",
    "lat": "41.78667",
    "lng": "19.67611"
  },
  {
    "country": "AL",
    "name": "Kavajë",
    "lat": "41.18556",
    "lng": "19.55694"
  },
  {
    "country": "AL",
    "name": "Katundi i Ri",
    "lat": "41.40306",
    "lng": "19.51806"
  },
  {
    "country": "AL",
    "name": "Kastrat",
    "lat": "42.3525",
    "lng": "19.48917"
  },
  {
    "country": "AL",
    "name": "Kashar",
    "lat": "41.34972",
    "lng": "19.71028"
  },
  {
    "country": "AL",
    "name": "Karinë",
    "lat": "41.06306",
    "lng": "19.71611"
  },
  {
    "country": "AL",
    "name": "Karbunara e Vogël",
    "lat": "40.92194",
    "lng": "19.71778"
  },
  {
    "country": "AL",
    "name": "Kamëz",
    "lat": "41.38167",
    "lng": "19.76028"
  },
  {
    "country": "AL",
    "name": "Kallmeti i Madh",
    "lat": "41.84889",
    "lng": "19.68694"
  },
  {
    "country": "AL",
    "name": "Kallmet",
    "lat": "41.41806",
    "lng": "19.82139"
  },
  {
    "country": "AL",
    "name": "Kalenjë",
    "lat": "40.59",
    "lng": "19.77833"
  },
  {
    "country": "AL",
    "name": "Kajan",
    "lat": "40.91417",
    "lng": "19.88944"
  },
  {
    "country": "AL",
    "name": "Kaçinar",
    "lat": "41.89333",
    "lng": "19.89861"
  },
  {
    "country": "AL",
    "name": "Ishëm",
    "lat": "41.54528",
    "lng": "19.6"
  },
  {
    "country": "AL",
    "name": "Hysgjokaj",
    "lat": "40.97167",
    "lng": "19.78972"
  },
  {
    "country": "AL",
    "name": "Hot",
    "lat": "42.36194",
    "lng": "19.44417"
  },
  {
    "country": "AL",
    "name": "Himarë",
    "lat": "40.10167",
    "lng": "19.74472"
  },
  {
    "country": "AL",
    "name": "Helmas",
    "lat": "41.18028",
    "lng": "19.60694"
  },
  {
    "country": "AL",
    "name": "Hekal",
    "lat": "40.56194",
    "lng": "19.73583"
  },
  {
    "country": "AL",
    "name": "Hasan",
    "lat": "41.48278",
    "lng": "19.69972"
  },
  {
    "country": "AL",
    "name": "Hajmel",
    "lat": "41.95306",
    "lng": "19.63778"
  },
  {
    "country": "AL",
    "name": "Gurra e Vogël",
    "lat": "41.53611",
    "lng": "19.99083"
  },
  {
    "country": "AL",
    "name": "Guri i Zi",
    "lat": "42.045",
    "lng": "19.57472"
  },
  {
    "country": "AL",
    "name": "Gruemirë",
    "lat": "42.15917",
    "lng": "19.51889"
  },
  {
    "country": "AL",
    "name": "Greshicë",
    "lat": "40.55194",
    "lng": "19.77833"
  },
  {
    "country": "AL",
    "name": "Grekan",
    "lat": "40.92944",
    "lng": "19.9475"
  },
  {
    "country": "AL",
    "name": "Gradishtë",
    "lat": "40.88806",
    "lng": "19.58583"
  },
  {
    "country": "AL",
    "name": "Gracen",
    "lat": "41.15194",
    "lng": "19.96361"
  },
  {
    "country": "AL",
    "name": "Grabjan",
    "lat": "40.95306",
    "lng": "19.58083"
  },
  {
    "country": "AL",
    "name": "Gosë e Madhe",
    "lat": "41.09056",
    "lng": "19.62472"
  },
  {
    "country": "AL",
    "name": "Golem",
    "lat": "40.96778",
    "lng": "19.68528"
  },
  {
    "country": "AL",
    "name": "Gjoçaj",
    "lat": "41.02556",
    "lng": "19.72389"
  },
  {
    "country": "AL",
    "name": "Gjepalaj",
    "lat": "41.33306",
    "lng": "19.57806"
  },
  {
    "country": "AL",
    "name": "Fushëkuqe",
    "lat": "41.65028",
    "lng": "19.62"
  },
  {
    "country": "AL",
    "name": "Fushë-Krujë",
    "lat": "41.47833",
    "lng": "19.71778"
  },
  {
    "country": "AL",
    "name": "Fratar",
    "lat": "40.5",
    "lng": "19.81667"
  },
  {
    "country": "AL",
    "name": "Frakulla e Madhe",
    "lat": "40.65583",
    "lng": "19.5025"
  },
  {
    "country": "AL",
    "name": "Fier-Shegan",
    "lat": "40.86722",
    "lng": "19.78528"
  },
  {
    "country": "AL",
    "name": "Fier-Çifçi",
    "lat": "40.71667",
    "lng": "19.56667"
  },
  {
    "country": "AL",
    "name": "Fier",
    "lat": "40.72389",
    "lng": "19.55611"
  },
  {
    "country": "AL",
    "name": "Farka e Madhe",
    "lat": "41.30556",
    "lng": "19.86694"
  },
  {
    "country": "AL",
    "name": "Durrës",
    "lat": "41.32355",
    "lng": "19.45469"
  },
  {
    "country": "AL",
    "name": "Drenovë",
    "lat": "40.60056",
    "lng": "19.70083"
  },
  {
    "country": "AL",
    "name": "Divjakë",
    "lat": "40.99667",
    "lng": "19.52944"
  },
  {
    "country": "AL",
    "name": "Dërmënas",
    "lat": "40.74556",
    "lng": "19.49389"
  },
  {
    "country": "AL",
    "name": "Vau i Dejës",
    "lat": "42.01",
    "lng": "19.62472"
  },
  {
    "country": "AL",
    "name": "Dajt",
    "lat": "41.39361",
    "lng": "19.91583"
  },
  {
    "country": "AL",
    "name": "Dajç",
    "lat": "41.99167",
    "lng": "19.41056"
  },
  {
    "country": "AL",
    "name": "Dajç",
    "lat": "41.91556",
    "lng": "19.60444"
  },
  {
    "country": "AL",
    "name": "Cukalat",
    "lat": "40.73028",
    "lng": "19.79056"
  },
  {
    "country": "AL",
    "name": "Cudhi Zall",
    "lat": "41.50944",
    "lng": "19.84583"
  },
  {
    "country": "AL",
    "name": "Cërrik",
    "lat": "41.03167",
    "lng": "19.97583"
  },
  {
    "country": "AL",
    "name": "Cakran",
    "lat": "40.60333",
    "lng": "19.62611"
  },
  {
    "country": "AL",
    "name": "Bushat",
    "lat": "42.11944",
    "lng": "19.89972"
  },
  {
    "country": "AL",
    "name": "Bubullimë",
    "lat": "40.81806",
    "lng": "19.64083"
  },
  {
    "country": "AL",
    "name": "Bubq",
    "lat": "41.47417",
    "lng": "19.65167"
  },
  {
    "country": "AL",
    "name": "Brataj",
    "lat": "40.26778",
    "lng": "19.66917"
  },
  {
    "country": "AL",
    "name": "Bërzhitë",
    "lat": "41.24528",
    "lng": "19.90111"
  },
  {
    "country": "AL",
    "name": "Bërxull",
    "lat": "41.38",
    "lng": "19.6875"
  },
  {
    "country": "AL",
    "name": "Bërdica e Madhe",
    "lat": "42.01528",
    "lng": "19.48167"
  },
  {
    "country": "AL",
    "name": "Berat",
    "lat": "40.70583",
    "lng": "19.95222"
  },
  {
    "country": "AL",
    "name": "Belsh",
    "lat": "40.975",
    "lng": "19.88194"
  },
  {
    "country": "AL",
    "name": "Baz",
    "lat": "41.63194",
    "lng": "19.92917"
  },
  {
    "country": "AL",
    "name": "Banaj",
    "lat": "40.82472",
    "lng": "19.83917"
  },
  {
    "country": "AL",
    "name": "Ballsh",
    "lat": "40.59889",
    "lng": "19.73472"
  },
  {
    "country": "AL",
    "name": "Ballagat",
    "lat": "40.99528",
    "lng": "19.76528"
  },
  {
    "country": "AL",
    "name": "Baldushk",
    "lat": "41.21389",
    "lng": "19.79694"
  },
  {
    "country": "AL",
    "name": "Armen",
    "lat": "40.53639",
    "lng": "19.59611"
  },
  {
    "country": "AL",
    "name": "Aranitas",
    "lat": "40.59444",
    "lng": "19.80667"
  },
  {
    "country": "AL",
    "name": "Allkaj",
    "lat": "40.8575",
    "lng": "19.75528"
  },
  {
    "country": "AL",
    "name": "Golem",
    "lat": "41.24583",
    "lng": "19.53472"
  },
  {
    "country": "AL",
    "name": "Balldreni i Ri",
    "lat": "41.81917",
    "lng": "19.64028"
  },
  {
    "country": "AL",
    "name": "Grudë-Fushë",
    "lat": "42.16222",
    "lng": "19.49667"
  },
  {
    "country": "AL",
    "name": "Fierzë",
    "lat": "40.92056",
    "lng": "19.84694"
  },
  {
    "country": "AL",
    "name": "Dushk",
    "lat": "40.72667",
    "lng": "19.75722"
  },
  {
    "country": "AL",
    "name": "Selitë",
    "lat": "40.5475",
    "lng": "19.84806"
  },
  {
    "country": "AL",
    "name": "Vllahinë",
    "lat": "40.45694",
    "lng": "19.64361"
  },
  {
    "country": "AL",
    "name": "Bajram Curri",
    "lat": "42.35734",
    "lng": "20.07679"
  },
  {
    "country": "AM",
    "name": "Zarrit’ap’",
    "lat": "39.63892",
    "lng": "45.51111"
  },
  {
    "country": "AM",
    "name": "Zangakatun",
    "lat": "39.82233",
    "lng": "45.04169"
  },
  {
    "country": "AM",
    "name": "Goravan",
    "lat": "39.90832",
    "lng": "44.73328"
  },
  {
    "country": "AM",
    "name": "Yeghegnavan",
    "lat": "39.83893",
    "lng": "44.61951"
  },
  {
    "country": "AM",
    "name": "Yeghegnadzor",
    "lat": "39.76389",
    "lng": "45.33239"
  },
  {
    "country": "AM",
    "name": "Vostan",
    "lat": "39.96515",
    "lng": "44.55937"
  },
  {
    "country": "AM",
    "name": "Vosketap’",
    "lat": "39.88114",
    "lng": "44.64917"
  },
  {
    "country": "AM",
    "name": "Vernashen",
    "lat": "39.79236",
    "lng": "45.36389"
  },
  {
    "country": "AM",
    "name": "Verishen",
    "lat": "39.53543",
    "lng": "46.32063"
  },
  {
    "country": "AM",
    "name": "Vedi",
    "lat": "39.91388",
    "lng": "44.7251"
  },
  {
    "country": "AM",
    "name": "Vayk’",
    "lat": "39.6889",
    "lng": "45.46668"
  },
  {
    "country": "AM",
    "name": "Tegh",
    "lat": "39.55826",
    "lng": "46.48054"
  },
  {
    "country": "AM",
    "name": "Surenavan",
    "lat": "39.79449",
    "lng": "44.77508"
  },
  {
    "country": "AM",
    "name": "Sisavan",
    "lat": "39.90802",
    "lng": "44.66721"
  },
  {
    "country": "AM",
    "name": "Shinuhayr",
    "lat": "39.4367",
    "lng": "46.31787"
  },
  {
    "country": "AM",
    "name": "Lusarrat",
    "lat": "39.87403",
    "lng": "44.58678"
  },
  {
    "country": "AM",
    "name": "Shahumyan",
    "lat": "39.94171",
    "lng": "44.57233"
  },
  {
    "country": "AM",
    "name": "Shatin",
    "lat": "39.83612",
    "lng": "45.30292"
  },
  {
    "country": "AM",
    "name": "Shaghat",
    "lat": "39.55698",
    "lng": "45.90727"
  },
  {
    "country": "AM",
    "name": "Rrind",
    "lat": "39.76111",
    "lng": "45.17792"
  },
  {
    "country": "AM",
    "name": "Noyakert",
    "lat": "39.83069",
    "lng": "44.66949"
  },
  {
    "country": "AM",
    "name": "Mrgavan",
    "lat": "39.97251",
    "lng": "44.53565"
  },
  {
    "country": "AM",
    "name": "Meghri",
    "lat": "38.90292",
    "lng": "46.24458"
  },
  {
    "country": "AM",
    "name": "Malishka",
    "lat": "39.74731",
    "lng": "45.4057"
  },
  {
    "country": "AM",
    "name": "Khndzoresk",
    "lat": "39.50568",
    "lng": "46.4361"
  },
  {
    "country": "AM",
    "name": "Kapan",
    "lat": "39.20755",
    "lng": "46.40576"
  },
  {
    "country": "AM",
    "name": "Jermuk",
    "lat": "39.84168",
    "lng": "45.66949"
  },
  {
    "country": "AM",
    "name": "Goris",
    "lat": "39.51111",
    "lng": "46.34168"
  },
  {
    "country": "AM",
    "name": "Gladzor",
    "lat": "39.7807",
    "lng": "45.34729"
  },
  {
    "country": "AM",
    "name": "Getap’",
    "lat": "39.76392",
    "lng": "45.30829"
  },
  {
    "country": "AM",
    "name": "Dzorastan",
    "lat": "39.27059",
    "lng": "46.3572"
  },
  {
    "country": "AM",
    "name": "Dalar",
    "lat": "39.97653",
    "lng": "44.52649"
  },
  {
    "country": "AM",
    "name": "Burastan",
    "lat": "39.99157",
    "lng": "44.49681"
  },
  {
    "country": "AM",
    "name": "Akner",
    "lat": "39.53491",
    "lng": "46.30732"
  },
  {
    "country": "AM",
    "name": "Brrnakot’",
    "lat": "39.49742",
    "lng": "45.97241"
  },
  {
    "country": "AM",
    "name": "Berk’anush",
    "lat": "39.9779",
    "lng": "44.51672"
  },
  {
    "country": "AM",
    "name": "Aygezard",
    "lat": "39.95436",
    "lng": "44.60229"
  },
  {
    "country": "AM",
    "name": "Aygepat",
    "lat": "39.95845",
    "lng": "44.59981"
  },
  {
    "country": "AM",
    "name": "Aygavan",
    "lat": "39.87327",
    "lng": "44.66984"
  },
  {
    "country": "AM",
    "name": "Avshar",
    "lat": "39.85553",
    "lng": "44.65832"
  },
  {
    "country": "AM",
    "name": "Hats’avan",
    "lat": "39.46405",
    "lng": "45.97047"
  },
  {
    "country": "AM",
    "name": "Artashat",
    "lat": "39.96144",
    "lng": "44.54447"
  },
  {
    "country": "AM",
    "name": "Yeghegis",
    "lat": "39.87231",
    "lng": "45.3501"
  },
  {
    "country": "AM",
    "name": "Armash",
    "lat": "39.76672",
    "lng": "44.8111"
  },
  {
    "country": "AM",
    "name": "Areni",
    "lat": "39.71668",
    "lng": "45.18329"
  },
  {
    "country": "AM",
    "name": "Ararat",
    "lat": "39.83069",
    "lng": "44.70569"
  },
  {
    "country": "AM",
    "name": "Angeghakot’",
    "lat": "39.56952",
    "lng": "45.94452"
  },
  {
    "country": "AM",
    "name": "Aghavnadzor",
    "lat": "39.78607",
    "lng": "45.2279"
  },
  {
    "country": "AM",
    "name": "Agarakadzor",
    "lat": "39.73608",
    "lng": "45.35553"
  },
  {
    "country": "AM",
    "name": "Agarak",
    "lat": "39.20684",
    "lng": "46.5446"
  },
  {
    "country": "AM",
    "name": "Aralez",
    "lat": "39.90008",
    "lng": "44.6557"
  },
  {
    "country": "AM",
    "name": "Horrom",
    "lat": "40.65973",
    "lng": "43.89032"
  },
  {
    "country": "AM",
    "name": "Margara",
    "lat": "40.03332",
    "lng": "44.18048"
  },
  {
    "country": "AM",
    "name": "Zovuni",
    "lat": "40.51111",
    "lng": "44.4389"
  },
  {
    "country": "AM",
    "name": "Zovaber",
    "lat": "40.56671",
    "lng": "44.79028"
  },
  {
    "country": "AM",
    "name": "Zorak",
    "lat": "40.09168",
    "lng": "44.39447"
  },
  {
    "country": "AM",
    "name": "Zarr",
    "lat": "40.25848",
    "lng": "44.73328"
  },
  {
    "country": "AM",
    "name": "Yerevan",
    "lat": "40.18111",
    "lng": "44.51361"
  },
  {
    "country": "AM",
    "name": "Yerazgavors",
    "lat": "40.69505",
    "lng": "43.74722"
  },
  {
    "country": "AM",
    "name": "Yeraskhahun",
    "lat": "40.07233",
    "lng": "44.21948"
  },
  {
    "country": "AM",
    "name": "Yeranos",
    "lat": "40.20428",
    "lng": "45.19209"
  },
  {
    "country": "AM",
    "name": "Yeghegnut",
    "lat": "40.90302",
    "lng": "44.63155"
  },
  {
    "country": "AM",
    "name": "Yeghegnut",
    "lat": "40.08893",
    "lng": "44.16669"
  },
  {
    "country": "AM",
    "name": "Ejmiatsin",
    "lat": "40.16557",
    "lng": "44.29462"
  },
  {
    "country": "AM",
    "name": "Yeghvard",
    "lat": "40.32507",
    "lng": "44.48608"
  },
  {
    "country": "AM",
    "name": "Voskevaz",
    "lat": "40.27508",
    "lng": "44.30011"
  },
  {
    "country": "AM",
    "name": "Voskevan",
    "lat": "41.12081",
    "lng": "45.06381"
  },
  {
    "country": "AM",
    "name": "Voskehask",
    "lat": "40.76426",
    "lng": "43.77474"
  },
  {
    "country": "AM",
    "name": "Verin Getashen",
    "lat": "40.13068",
    "lng": "45.25293"
  },
  {
    "country": "AM",
    "name": "Verin Dvin",
    "lat": "40.02434",
    "lng": "44.59038"
  },
  {
    "country": "AM",
    "name": "Verin Artashat",
    "lat": "39.99731",
    "lng": "44.58893"
  },
  {
    "country": "AM",
    "name": "Akht’ala",
    "lat": "41.16838",
    "lng": "44.75811"
  },
  {
    "country": "AM",
    "name": "Varser",
    "lat": "40.55548",
    "lng": "44.90832"
  },
  {
    "country": "AM",
    "name": "Vardenis",
    "lat": "40.18329",
    "lng": "45.73053"
  },
  {
    "country": "AM",
    "name": "Vardenik",
    "lat": "40.13348",
    "lng": "45.44311"
  },
  {
    "country": "AM",
    "name": "Vahan",
    "lat": "40.57549",
    "lng": "45.39769"
  },
  {
    "country": "AM",
    "name": "Vaghashen",
    "lat": "40.13611",
    "lng": "45.33069"
  },
  {
    "country": "AM",
    "name": "Vahagni",
    "lat": "40.90698",
    "lng": "44.60873"
  },
  {
    "country": "AM",
    "name": "Ushi",
    "lat": "40.34729",
    "lng": "44.37512"
  },
  {
    "country": "AM",
    "name": "Urrut",
    "lat": "41.06778",
    "lng": "44.39628"
  },
  {
    "country": "AM",
    "name": "Tsovinar",
    "lat": "40.15959",
    "lng": "45.46786"
  },
  {
    "country": "AM",
    "name": "Tsovazard",
    "lat": "40.4751",
    "lng": "45.05011"
  },
  {
    "country": "AM",
    "name": "Tsovak",
    "lat": "40.18254",
    "lng": "45.63286"
  },
  {
    "country": "AM",
    "name": "Tsovagyugh",
    "lat": "40.63348",
    "lng": "44.96112"
  },
  {
    "country": "AM",
    "name": "Tsaghkunk’",
    "lat": "40.18048",
    "lng": "44.27228"
  },
  {
    "country": "AM",
    "name": "Tsaghkahovit",
    "lat": "40.63428",
    "lng": "44.22241"
  },
  {
    "country": "AM",
    "name": "Tsaghkaber",
    "lat": "40.79849",
    "lng": "44.10144"
  },
  {
    "country": "AM",
    "name": "Tsaghkadzor",
    "lat": "40.53259",
    "lng": "44.72025"
  },
  {
    "country": "AM",
    "name": "Tsovasar",
    "lat": "40.1382",
    "lng": "45.19096"
  },
  {
    "country": "AM",
    "name": "Tashir",
    "lat": "41.12072",
    "lng": "44.28462"
  },
  {
    "country": "AM",
    "name": "Tandzut",
    "lat": "40.06952",
    "lng": "44.07788"
  },
  {
    "country": "AM",
    "name": "T’alin",
    "lat": "40.39172",
    "lng": "43.87793"
  },
  {
    "country": "AM",
    "name": "Step’anavan",
    "lat": "41.00995",
    "lng": "44.38531"
  },
  {
    "country": "AM",
    "name": "Spitak",
    "lat": "40.83221",
    "lng": "44.26731"
  },
  {
    "country": "AM",
    "name": "Spandaryan",
    "lat": "40.66105",
    "lng": "44.01551"
  },
  {
    "country": "AM",
    "name": "Alashkert",
    "lat": "40.10712",
    "lng": "44.05108"
  },
  {
    "country": "AM",
    "name": "Solak",
    "lat": "40.46252",
    "lng": "44.70709"
  },
  {
    "country": "AM",
    "name": "Sis",
    "lat": "40.05829",
    "lng": "44.38892"
  },
  {
    "country": "AM",
    "name": "Shnogh",
    "lat": "41.14693",
    "lng": "44.84043"
  },
  {
    "country": "AM",
    "name": "Shirak",
    "lat": "40.84042",
    "lng": "43.91582"
  },
  {
    "country": "AM",
    "name": "Shenavan",
    "lat": "40.48328",
    "lng": "44.38348"
  },
  {
    "country": "AM",
    "name": "Shenavan",
    "lat": "40.05548",
    "lng": "43.93048"
  },
  {
    "country": "AM",
    "name": "Sevan",
    "lat": "40.5473",
    "lng": "44.94171"
  },
  {
    "country": "AM",
    "name": "Sarukhan",
    "lat": "40.29169",
    "lng": "45.13068"
  },
  {
    "country": "AM",
    "name": "Sarigyugh",
    "lat": "41.03531",
    "lng": "45.14486"
  },
  {
    "country": "AM",
    "name": "Saratak",
    "lat": "40.6709",
    "lng": "43.87231"
  },
  {
    "country": "AM",
    "name": "Saramej",
    "lat": "40.77487",
    "lng": "44.2222"
  },
  {
    "country": "AM",
    "name": "Sarahart’",
    "lat": "40.87043",
    "lng": "44.21407"
  },
  {
    "country": "AM",
    "name": "Geghakert",
    "lat": "40.18516",
    "lng": "44.24331"
  },
  {
    "country": "AM",
    "name": "Ptghni",
    "lat": "40.25568",
    "lng": "44.58612"
  },
  {
    "country": "AM",
    "name": "Ptghunk’",
    "lat": "40.16388",
    "lng": "44.36389"
  },
  {
    "country": "AM",
    "name": "P’shatavan",
    "lat": "40.03888",
    "lng": "44.06671"
  },
  {
    "country": "AM",
    "name": "Prroshyan",
    "lat": "40.24731",
    "lng": "44.41949"
  },
  {
    "country": "AM",
    "name": "P’ok’r Mant’ash",
    "lat": "40.64026",
    "lng": "44.04666"
  },
  {
    "country": "AM",
    "name": "Zoravan",
    "lat": "40.35553",
    "lng": "44.52228"
  },
  {
    "country": "AM",
    "name": "Pemzashen",
    "lat": "40.58612",
    "lng": "43.94311"
  },
  {
    "country": "AM",
    "name": "Parravak’ar",
    "lat": "40.98248",
    "lng": "45.36696"
  },
  {
    "country": "AM",
    "name": "Oshakan",
    "lat": "40.26392",
    "lng": "44.31671"
  },
  {
    "country": "AM",
    "name": "Sardarapat",
    "lat": "40.13206",
    "lng": "44.00969"
  },
  {
    "country": "AM",
    "name": "Odzun",
    "lat": "41.05321",
    "lng": "44.61341"
  },
  {
    "country": "AM",
    "name": "Noyemberyan",
    "lat": "41.17244",
    "lng": "44.99917"
  },
  {
    "country": "AM",
    "name": "Nor Gyugh",
    "lat": "40.26672",
    "lng": "44.65832"
  },
  {
    "country": "AM",
    "name": "Nor Geghi",
    "lat": "40.32233",
    "lng": "44.58331"
  },
  {
    "country": "AM",
    "name": "Norashen",
    "lat": "41.18886",
    "lng": "44.33336"
  },
  {
    "country": "AM",
    "name": "Norashen",
    "lat": "40.0013",
    "lng": "44.59296"
  },
  {
    "country": "AM",
    "name": "Nor Armavir",
    "lat": "40.08612",
    "lng": "43.99451"
  },
  {
    "country": "AM",
    "name": "Noramarg",
    "lat": "40.02228",
    "lng": "44.42511"
  },
  {
    "country": "AM",
    "name": "Norakert",
    "lat": "40.19733",
    "lng": "44.3501"
  },
  {
    "country": "AM",
    "name": "Noratus",
    "lat": "40.37793",
    "lng": "45.18048"
  },
  {
    "country": "AM",
    "name": "Nerk’in Getashen",
    "lat": "40.14172",
    "lng": "45.27087"
  },
  {
    "country": "AM",
    "name": "Navur",
    "lat": "40.86695",
    "lng": "45.34179"
  },
  {
    "country": "AM",
    "name": "Nalbandyan",
    "lat": "40.0639",
    "lng": "43.98889"
  },
  {
    "country": "AM",
    "name": "Basen",
    "lat": "40.75767",
    "lng": "43.99274"
  },
  {
    "country": "AM",
    "name": "Hovtamej",
    "lat": "40.18329",
    "lng": "44.25848"
  },
  {
    "country": "AM",
    "name": "Mrgashen",
    "lat": "40.28607",
    "lng": "44.54449"
  },
  {
    "country": "AM",
    "name": "Mrgashat",
    "lat": "40.13068",
    "lng": "44.08069"
  },
  {
    "country": "AM",
    "name": "Mrganush",
    "lat": "40.02857",
    "lng": "44.55831"
  },
  {
    "country": "AM",
    "name": "Mosesgegh",
    "lat": "40.90534",
    "lng": "45.48838"
  },
  {
    "country": "AM",
    "name": "Mets Parni",
    "lat": "40.83472",
    "lng": "44.11108"
  },
  {
    "country": "AM",
    "name": "Mets Masrik",
    "lat": "40.21948",
    "lng": "45.76391"
  },
  {
    "country": "AM",
    "name": "Mets Mant’ash",
    "lat": "40.64376",
    "lng": "44.05653"
  },
  {
    "country": "AM",
    "name": "Metsavan",
    "lat": "41.20156",
    "lng": "44.22877"
  },
  {
    "country": "AM",
    "name": "Metsamor",
    "lat": "40.07233",
    "lng": "44.29169"
  },
  {
    "country": "AM",
    "name": "Merdzavan",
    "lat": "40.1814",
    "lng": "44.40033"
  },
  {
    "country": "AM",
    "name": "Meghrashen",
    "lat": "40.6723",
    "lng": "43.95831"
  },
  {
    "country": "AM",
    "name": "Meghradzor",
    "lat": "40.60611",
    "lng": "44.65147"
  },
  {
    "country": "AM",
    "name": "Mayakovski",
    "lat": "40.25293",
    "lng": "44.63892"
  },
  {
    "country": "AM",
    "name": "Masis",
    "lat": "40.06542",
    "lng": "44.41618"
  },
  {
    "country": "AM",
    "name": "Martuni",
    "lat": "40.13892",
    "lng": "45.30548"
  },
  {
    "country": "AM",
    "name": "Marmarashen",
    "lat": "40.05829",
    "lng": "44.47229"
  },
  {
    "country": "AM",
    "name": "Marmashen",
    "lat": "40.83486",
    "lng": "43.7779"
  },
  {
    "country": "AM",
    "name": "Margahovit",
    "lat": "40.73381",
    "lng": "44.68474"
  },
  {
    "country": "AM",
    "name": "Maralik",
    "lat": "40.57507",
    "lng": "43.87231"
  },
  {
    "country": "AM",
    "name": "Mayisyan",
    "lat": "40.84715",
    "lng": "43.83938"
  },
  {
    "country": "AM",
    "name": "Madina",
    "lat": "40.07637",
    "lng": "45.25507"
  },
  {
    "country": "AM",
    "name": "Lukashin",
    "lat": "40.18726",
    "lng": "44.0039"
  },
  {
    "country": "AM",
    "name": "Lorut",
    "lat": "40.93717",
    "lng": "44.77142"
  },
  {
    "country": "AM",
    "name": "Lichk’",
    "lat": "40.15933",
    "lng": "45.23467"
  },
  {
    "country": "AM",
    "name": "Lerrnavan",
    "lat": "40.7882",
    "lng": "44.16024"
  },
  {
    "country": "AM",
    "name": "Lerrnapat",
    "lat": "40.81538",
    "lng": "44.39344"
  },
  {
    "country": "AM",
    "name": "Lerrnants’k’",
    "lat": "40.79532",
    "lng": "44.27435"
  },
  {
    "country": "AM",
    "name": "Lerrnanist",
    "lat": "40.46676",
    "lng": "44.79249"
  },
  {
    "country": "AM",
    "name": "Lerrnakert",
    "lat": "40.5625",
    "lng": "43.9389"
  },
  {
    "country": "AM",
    "name": "Khoronk’",
    "lat": "40.13611",
    "lng": "44.24731"
  },
  {
    "country": "AM",
    "name": "Lchashen",
    "lat": "40.51947",
    "lng": "44.93048"
  },
  {
    "country": "AM",
    "name": "Lchap’",
    "lat": "40.45569",
    "lng": "45.07507"
  },
  {
    "country": "AM",
    "name": "Lanjaghbyur",
    "lat": "40.26947",
    "lng": "45.14447"
  },
  {
    "country": "AM",
    "name": "Kotayk’",
    "lat": "40.27789",
    "lng": "44.66388"
  },
  {
    "country": "AM",
    "name": "Kosh",
    "lat": "40.30011",
    "lng": "44.16107"
  },
  {
    "country": "AM",
    "name": "Vanadzor",
    "lat": "40.80456",
    "lng": "44.4939"
  },
  {
    "country": "AM",
    "name": "Hnaberd",
    "lat": "40.63721",
    "lng": "44.14058"
  },
  {
    "country": "AM",
    "name": "Khasht’arrak",
    "lat": "40.93668",
    "lng": "45.1821"
  },
  {
    "country": "AM",
    "name": "Kasakh",
    "lat": "40.53697",
    "lng": "44.41046"
  },
  {
    "country": "AM",
    "name": "Karchaghbyur",
    "lat": "40.17048",
    "lng": "45.57785"
  },
  {
    "country": "AM",
    "name": "Karbi",
    "lat": "40.33069",
    "lng": "44.37793"
  },
  {
    "country": "AM",
    "name": "Karanlukh",
    "lat": "40.10444",
    "lng": "45.28972"
  },
  {
    "country": "AM",
    "name": "Kaputan",
    "lat": "40.32507",
    "lng": "44.70007"
  },
  {
    "country": "AM",
    "name": "K’anak’erravan",
    "lat": "40.24739",
    "lng": "44.53511"
  },
  {
    "country": "AM",
    "name": "Kamo",
    "lat": "40.82572",
    "lng": "43.95071"
  },
  {
    "country": "AM",
    "name": "Gavarr",
    "lat": "40.35398",
    "lng": "45.12386"
  },
  {
    "country": "AM",
    "name": "Mayisyan",
    "lat": "40.15701",
    "lng": "44.09192"
  },
  {
    "country": "AM",
    "name": "Shahumyan",
    "lat": "40.77482",
    "lng": "44.54596"
  },
  {
    "country": "AM",
    "name": "Ijevan",
    "lat": "40.87877",
    "lng": "45.14851"
  },
  {
    "country": "AM",
    "name": "Hrazdan",
    "lat": "40.49748",
    "lng": "44.7662"
  },
  {
    "country": "AM",
    "name": "Armavir",
    "lat": "40.15446",
    "lng": "44.03815"
  },
  {
    "country": "AM",
    "name": "Hayanist",
    "lat": "40.12231",
    "lng": "44.37793"
  },
  {
    "country": "AM",
    "name": "Haghartsin",
    "lat": "40.77614",
    "lng": "44.96847"
  },
  {
    "country": "AM",
    "name": "Gyumri",
    "lat": "40.7942",
    "lng": "43.84528"
  },
  {
    "country": "AM",
    "name": "Gyulagarak",
    "lat": "40.96715",
    "lng": "44.47144"
  },
  {
    "country": "AM",
    "name": "Ghukasavan",
    "lat": "40.12793",
    "lng": "44.41669"
  },
  {
    "country": "AM",
    "name": "Geghamasar",
    "lat": "40.31091",
    "lng": "45.67924"
  },
  {
    "country": "AM",
    "name": "Gugark’",
    "lat": "40.8046",
    "lng": "44.54025"
  },
  {
    "country": "AM",
    "name": "Tsiatsan",
    "lat": "40.1861",
    "lng": "44.26947"
  },
  {
    "country": "AM",
    "name": "Goght’",
    "lat": "40.1347",
    "lng": "44.78332"
  },
  {
    "country": "AM",
    "name": "Gogaran",
    "lat": "40.89255",
    "lng": "44.19915"
  },
  {
    "country": "AM",
    "name": "Getazat",
    "lat": "40.03844",
    "lng": "44.56369"
  },
  {
    "country": "AM",
    "name": "Getashen",
    "lat": "40.04449",
    "lng": "43.94171"
  },
  {
    "country": "AM",
    "name": "Geghanist",
    "lat": "40.14587",
    "lng": "44.43048"
  },
  {
    "country": "AM",
    "name": "Geghamavan",
    "lat": "40.5625",
    "lng": "44.88892"
  },
  {
    "country": "AM",
    "name": "Garrni",
    "lat": "40.11931",
    "lng": "44.73442"
  },
  {
    "country": "AM",
    "name": "Gagarin",
    "lat": "40.54026",
    "lng": "44.86962"
  },
  {
    "country": "AM",
    "name": "Fantan",
    "lat": "40.39447",
    "lng": "44.6861"
  },
  {
    "country": "AM",
    "name": "Fioletovo",
    "lat": "40.72241",
    "lng": "44.71769"
  },
  {
    "country": "AM",
    "name": "Dzoraghbyur",
    "lat": "40.20412",
    "lng": "44.6415"
  },
  {
    "country": "AM",
    "name": "Dzoragyugh",
    "lat": "40.16957",
    "lng": "45.18337"
  },
  {
    "country": "AM",
    "name": "Dzit’hank’ov",
    "lat": "40.50848",
    "lng": "43.82092"
  },
  {
    "country": "AM",
    "name": "Jrashen",
    "lat": "40.79028",
    "lng": "44.18664"
  },
  {
    "country": "AM",
    "name": "Jrashen",
    "lat": "40.05275",
    "lng": "44.51259"
  },
  {
    "country": "AM",
    "name": "Jrahovit",
    "lat": "40.0473",
    "lng": "44.4751"
  },
  {
    "country": "AM",
    "name": "Janfida",
    "lat": "40.04449",
    "lng": "44.02789"
  },
  {
    "country": "AM",
    "name": "Dvin",
    "lat": "40.01984",
    "lng": "44.58376"
  },
  {
    "country": "AM",
    "name": "Dsegh",
    "lat": "40.9617",
    "lng": "44.65003"
  },
  {
    "country": "AM",
    "name": "Drakhtik",
    "lat": "40.56497",
    "lng": "45.2367"
  },
  {
    "country": "AM",
    "name": "Doghs",
    "lat": "40.22229",
    "lng": "44.27228"
  },
  {
    "country": "AM",
    "name": "Dilijan",
    "lat": "40.7417",
    "lng": "44.8501"
  },
  {
    "country": "AM",
    "name": "Ddmashen",
    "lat": "40.57028",
    "lng": "44.82295"
  },
  {
    "country": "AM",
    "name": "Darpas",
    "lat": "40.83674",
    "lng": "44.42494"
  },
  {
    "country": "AM",
    "name": "Dalarik",
    "lat": "40.2279",
    "lng": "43.87793"
  },
  {
    "country": "AM",
    "name": "Chochkan",
    "lat": "41.18118",
    "lng": "44.83217"
  },
  {
    "country": "AM",
    "name": "Chambarak",
    "lat": "40.59655",
    "lng": "45.35498"
  },
  {
    "country": "AM",
    "name": "Bjni",
    "lat": "40.45831",
    "lng": "44.65008"
  },
  {
    "country": "AM",
    "name": "Byureghavan",
    "lat": "40.31417",
    "lng": "44.59333"
  },
  {
    "country": "AM",
    "name": "Byurakan",
    "lat": "40.33894",
    "lng": "44.27275"
  },
  {
    "country": "AM",
    "name": "Buzhakan",
    "lat": "40.45569",
    "lng": "44.51947"
  },
  {
    "country": "AM",
    "name": "Berd",
    "lat": "40.88135",
    "lng": "45.38901"
  },
  {
    "country": "AM",
    "name": "Bazum",
    "lat": "40.86763",
    "lng": "44.43978"
  },
  {
    "country": "AM",
    "name": "Byuravan",
    "lat": "40.01604",
    "lng": "44.51889"
  },
  {
    "country": "AM",
    "name": "Bambakashat",
    "lat": "40.10828",
    "lng": "44.01947"
  },
  {
    "country": "AM",
    "name": "Balahovit",
    "lat": "40.25153",
    "lng": "44.60828"
  },
  {
    "country": "AM",
    "name": "Bagratashen",
    "lat": "41.24358",
    "lng": "44.81737"
  },
  {
    "country": "AM",
    "name": "Azatan",
    "lat": "40.71959",
    "lng": "43.82727"
  },
  {
    "country": "AM",
    "name": "Haykavan",
    "lat": "40.80312",
    "lng": "43.75173"
  },
  {
    "country": "AM",
    "name": "Aygestan",
    "lat": "40.00293",
    "lng": "44.55829"
  },
  {
    "country": "AM",
    "name": "Aygeshat",
    "lat": "40.23608",
    "lng": "44.28888"
  },
  {
    "country": "AM",
    "name": "Aygeshat",
    "lat": "40.07507",
    "lng": "44.0611"
  },
  {
    "country": "AM",
    "name": "Aknalich",
    "lat": "40.14728",
    "lng": "44.16669"
  },
  {
    "country": "AM",
    "name": "Aygehovit",
    "lat": "40.97951",
    "lng": "45.25033"
  },
  {
    "country": "AM",
    "name": "Artimet",
    "lat": "40.15008",
    "lng": "44.26672"
  },
  {
    "country": "AM",
    "name": "Astghadzor",
    "lat": "40.12231",
    "lng": "45.35553"
  },
  {
    "country": "AM",
    "name": "Ashtarak",
    "lat": "40.2991",
    "lng": "44.36204"
  },
  {
    "country": "AM",
    "name": "Ashnak",
    "lat": "40.33069",
    "lng": "43.91669"
  },
  {
    "country": "AM",
    "name": "Arzni",
    "lat": "40.2973",
    "lng": "44.59869"
  },
  {
    "country": "AM",
    "name": "Arzakan",
    "lat": "40.45007",
    "lng": "44.60828"
  },
  {
    "country": "AM",
    "name": "Arteni",
    "lat": "40.2973",
    "lng": "43.76672"
  },
  {
    "country": "AM",
    "name": "Arshaluys",
    "lat": "40.16949",
    "lng": "44.21393"
  },
  {
    "country": "AM",
    "name": "Argel",
    "lat": "40.37793",
    "lng": "44.6001"
  },
  {
    "country": "AM",
    "name": "Argavand",
    "lat": "40.15289",
    "lng": "44.4389"
  },
  {
    "country": "AM",
    "name": "Argavand",
    "lat": "40.0611",
    "lng": "44.09448"
  },
  {
    "country": "AM",
    "name": "Arevshat",
    "lat": "40.65345",
    "lng": "44.04419"
  },
  {
    "country": "AM",
    "name": "Arevshat",
    "lat": "40.03963",
    "lng": "44.54179"
  },
  {
    "country": "AM",
    "name": "Arevik",
    "lat": "40.7417",
    "lng": "43.9043"
  },
  {
    "country": "AM",
    "name": "Arevik",
    "lat": "40.1001",
    "lng": "44.09448"
  },
  {
    "country": "AM",
    "name": "Arevashogh",
    "lat": "40.86039",
    "lng": "44.27438"
  },
  {
    "country": "AM",
    "name": "Arevashat",
    "lat": "40.14447",
    "lng": "44.37512"
  },
  {
    "country": "AM",
    "name": "Archis",
    "lat": "41.16351",
    "lng": "44.87631"
  },
  {
    "country": "AM",
    "name": "Arbat’",
    "lat": "40.13892",
    "lng": "44.40289"
  },
  {
    "country": "AM",
    "name": "Arazap’",
    "lat": "40.04169",
    "lng": "44.14728"
  },
  {
    "country": "AM",
    "name": "Arrap’i",
    "lat": "40.78276",
    "lng": "43.80583"
  },
  {
    "country": "AM",
    "name": "Aramus",
    "lat": "40.25095",
    "lng": "44.66351"
  },
  {
    "country": "AM",
    "name": "Arak’s",
    "lat": "40.05548",
    "lng": "44.30292"
  },
  {
    "country": "AM",
    "name": "Aragats",
    "lat": "40.48889",
    "lng": "44.3529"
  },
  {
    "country": "AM",
    "name": "Aparan",
    "lat": "40.59323",
    "lng": "44.3589"
  },
  {
    "country": "AM",
    "name": "Apaga",
    "lat": "40.09729",
    "lng": "44.25293"
  },
  {
    "country": "AM",
    "name": "Anushavan",
    "lat": "40.65008",
    "lng": "43.98053"
  },
  {
    "country": "AM",
    "name": "Amasia",
    "lat": "40.95442",
    "lng": "43.7872"
  },
  {
    "country": "AM",
    "name": "Alaverdi",
    "lat": "41.09766",
    "lng": "44.67316"
  },
  {
    "country": "AM",
    "name": "Akunk’",
    "lat": "40.26672",
    "lng": "44.6861"
  },
  {
    "country": "AM",
    "name": "Akunk’",
    "lat": "40.15886",
    "lng": "45.72568"
  },
  {
    "country": "AM",
    "name": "Akhuryan",
    "lat": "40.78003",
    "lng": "43.90027"
  },
  {
    "country": "AM",
    "name": "Aghavnatun",
    "lat": "40.2333",
    "lng": "44.25295"
  },
  {
    "country": "AM",
    "name": "Aghavnadzor",
    "lat": "40.58195",
    "lng": "44.69581"
  },
  {
    "country": "AM",
    "name": "Agarak",
    "lat": "41.01072",
    "lng": "44.46845"
  },
  {
    "country": "AM",
    "name": "Agarakavan",
    "lat": "40.33069",
    "lng": "44.07233"
  },
  {
    "country": "AM",
    "name": "Abovyan",
    "lat": "40.27368",
    "lng": "44.63348"
  },
  {
    "country": "AM",
    "name": "Abovyan",
    "lat": "40.04851",
    "lng": "44.54742"
  },
  {
    "country": "AM",
    "name": "Vardablur",
    "lat": "40.97083",
    "lng": "44.50889"
  },
  {
    "country": "AM",
    "name": "Bardzrashen",
    "lat": "40.08533",
    "lng": "44.57957"
  },
  {
    "country": "AM",
    "name": "Nshavan",
    "lat": "40.02787",
    "lng": "44.52565"
  },
  {
    "country": "AM",
    "name": "Norabats’",
    "lat": "40.10553",
    "lng": "44.43329"
  },
  {
    "country": "AM",
    "name": "Berdavan",
    "lat": "41.20503",
    "lng": "44.99967"
  },
  {
    "country": "AM",
    "name": "Shirakamut",
    "lat": "40.86056",
    "lng": "44.15278"
  },
  {
    "country": "AM",
    "name": "Azatamut",
    "lat": "40.98204",
    "lng": "45.18551"
  },
  {
    "country": "AM",
    "name": "Getahovit",
    "lat": "40.89784",
    "lng": "45.13971"
  },
  {
    "country": "AM",
    "name": "Artsvaberd",
    "lat": "40.83947",
    "lng": "45.47033"
  },
  {
    "country": "AM",
    "name": "Nor Yerznka",
    "lat": "40.30011",
    "lng": "44.38892"
  },
  {
    "country": "AM",
    "name": "Sasunik",
    "lat": "40.25012",
    "lng": "44.34448"
  },
  {
    "country": "AM",
    "name": "Kamaris",
    "lat": "40.23539",
    "lng": "44.69459"
  },
  {
    "country": "AM",
    "name": "Gandzak",
    "lat": "40.31472",
    "lng": "45.11139"
  },
  {
    "country": "AM",
    "name": "Myasnikyan",
    "lat": "40.18048",
    "lng": "43.91949"
  },
  {
    "country": "AM",
    "name": "Lenughi",
    "lat": "40.12512",
    "lng": "43.96393"
  },
  {
    "country": "AM",
    "name": "Metsamor",
    "lat": "40.14447",
    "lng": "44.1167"
  },
  {
    "country": "AM",
    "name": "Gay",
    "lat": "40.08444",
    "lng": "44.30528"
  },
  {
    "country": "AM",
    "name": "Baghramyan",
    "lat": "40.19452",
    "lng": "44.36951"
  },
  {
    "country": "AM",
    "name": "Musalerr",
    "lat": "40.1557",
    "lng": "44.37793"
  },
  {
    "country": "AM",
    "name": "Darakert",
    "lat": "40.10553",
    "lng": "44.41388"
  },
  {
    "country": "AM",
    "name": "Dashtavan",
    "lat": "40.1001",
    "lng": "44.39172"
  },
  {
    "country": "AM",
    "name": "Nizami",
    "lat": "40.09168",
    "lng": "44.4057"
  },
  {
    "country": "AM",
    "name": "Artsvanist",
    "lat": "40.14617",
    "lng": "45.51711"
  },
  {
    "country": "AM",
    "name": "Vardadzor",
    "lat": "40.18701",
    "lng": "45.19212"
  },
  {
    "country": "AM",
    "name": "Taronik",
    "lat": "40.13367",
    "lng": "44.19957"
  },
  {
    "country": "AM",
    "name": "Aknashen",
    "lat": "40.09551",
    "lng": "44.28604"
  },
  {
    "country": "AM",
    "name": "Haykashen",
    "lat": "40.07233",
    "lng": "44.30829"
  },
  {
    "country": "AM",
    "name": "Hovtashat",
    "lat": "40.09729",
    "lng": "44.34448"
  },
  {
    "country": "AM",
    "name": "Sayat’-Nova",
    "lat": "40.07507",
    "lng": "44.40008"
  },
  {
    "country": "AM",
    "name": "Voskehat",
    "lat": "40.14172",
    "lng": "44.33069"
  },
  {
    "country": "AM",
    "name": "Griboyedov",
    "lat": "40.11307",
    "lng": "44.27169"
  },
  {
    "country": "AM",
    "name": "Gmbet’",
    "lat": "40.22369",
    "lng": "44.25409"
  },
  {
    "country": "AM",
    "name": "Aygek",
    "lat": "40.1889",
    "lng": "44.38611"
  },
  {
    "country": "AM",
    "name": "Hovtashen",
    "lat": "40.02508",
    "lng": "44.45007"
  },
  {
    "country": "AM",
    "name": "Dimitrov",
    "lat": "40.00848",
    "lng": "44.4917"
  },
  {
    "country": "AM",
    "name": "Mrgavet",
    "lat": "40.02789",
    "lng": "44.48328"
  },
  {
    "country": "AM",
    "name": "Arevabuyr",
    "lat": "40.03607",
    "lng": "44.46948"
  },
  {
    "country": "AO",
    "name": "Saurimo",
    "lat": "-9.66078",
    "lng": "20.39155"
  },
  {
    "country": "AO",
    "name": "Lucapa",
    "lat": "-8.41915",
    "lng": "20.74466"
  },
  {
    "country": "AO",
    "name": "Lumeje",
    "lat": "-11.55",
    "lng": "20.78333"
  },
  {
    "country": "AO",
    "name": "Luau",
    "lat": "-10.70727",
    "lng": "22.22466"
  },
  {
    "country": "AO",
    "name": "Léua",
    "lat": "-11.65",
    "lng": "20.45"
  },
  {
    "country": "AO",
    "name": "Cazaji",
    "lat": "-11.06715",
    "lng": "20.70148"
  },
  {
    "country": "AO",
    "name": "Uíge",
    "lat": "-7.60874",
    "lng": "15.06131"
  },
  {
    "country": "AO",
    "name": "Soio",
    "lat": "-6.1349",
    "lng": "12.36894"
  },
  {
    "country": "AO",
    "name": "N'zeto",
    "lat": "-7.23116",
    "lng": "12.8666"
  },
  {
    "country": "AO",
    "name": "N’dalatando",
    "lat": "-9.29782",
    "lng": "14.91162"
  },
  {
    "country": "AO",
    "name": "Mbanza Congo",
    "lat": "-6.26703",
    "lng": "14.2401"
  },
  {
    "country": "AO",
    "name": "Malanje",
    "lat": "-9.54015",
    "lng": "16.34096"
  },
  {
    "country": "AO",
    "name": "Luanda",
    "lat": "-8.83682",
    "lng": "13.23432"
  },
  {
    "country": "AO",
    "name": "Caxito",
    "lat": "-8.57848",
    "lng": "13.66425"
  },
  {
    "country": "AO",
    "name": "Camabatela",
    "lat": "-8.18812",
    "lng": "15.37495"
  },
  {
    "country": "AO",
    "name": "Cabinda",
    "lat": "-5.55",
    "lng": "12.2"
  },
  {
    "country": "AO",
    "name": "Uacu Cungo",
    "lat": "-11.35669",
    "lng": "15.11719"
  },
  {
    "country": "AO",
    "name": "Sumbe",
    "lat": "-11.20605",
    "lng": "13.84371"
  },
  {
    "country": "AO",
    "name": "Quibala",
    "lat": "-10.73366",
    "lng": "14.97995"
  },
  {
    "country": "AO",
    "name": "Ondjiva",
    "lat": "-17.06667",
    "lng": "15.73333"
  },
  {
    "country": "AO",
    "name": "Namibe",
    "lat": "-15.19611",
    "lng": "12.15222"
  },
  {
    "country": "AO",
    "name": "Menongue",
    "lat": "-14.6585",
    "lng": "17.69099"
  },
  {
    "country": "AO",
    "name": "Luena",
    "lat": "-11.78333",
    "lng": "19.91667"
  },
  {
    "country": "AO",
    "name": "Lubango",
    "lat": "-14.91717",
    "lng": "13.4925"
  },
  {
    "country": "AO",
    "name": "Longonjo",
    "lat": "-12.90667",
    "lng": "15.25333"
  },
  {
    "country": "AO",
    "name": "Lobito",
    "lat": "-12.3644",
    "lng": "13.53601"
  },
  {
    "country": "AO",
    "name": "Cuito",
    "lat": "-12.38333",
    "lng": "16.93333"
  },
  {
    "country": "AO",
    "name": "Huambo",
    "lat": "-12.77611",
    "lng": "15.73917"
  },
  {
    "country": "AO",
    "name": "Chissamba",
    "lat": "-12.16667",
    "lng": "17.33333"
  },
  {
    "country": "AO",
    "name": "Catumbela",
    "lat": "-12.43002",
    "lng": "13.54677"
  },
  {
    "country": "AO",
    "name": "Catabola",
    "lat": "-12.15",
    "lng": "17.28333"
  },
  {
    "country": "AO",
    "name": "Camacupa",
    "lat": "-12.01667",
    "lng": "17.48333"
  },
  {
    "country": "AO",
    "name": "Caluquembe",
    "lat": "-13.78333",
    "lng": "14.68333"
  },
  {
    "country": "AO",
    "name": "Caconda",
    "lat": "-13.73333",
    "lng": "15.06667"
  },
  {
    "country": "AO",
    "name": "Caála",
    "lat": "-12.8525",
    "lng": "15.56056"
  },
  {
    "country": "AO",
    "name": "Benguela",
    "lat": "-12.57626",
    "lng": "13.40547"
  },
  {
    "country": "AO",
    "name": "Chela",
    "lat": "-12.30261",
    "lng": "15.43358"
  },
  {
    "country": "AO",
    "name": "Chinjenje",
    "lat": "-12.93244",
    "lng": "14.99238"
  },
  {
    "country": "AQ",
    "name": "McMurdo Station",
    "lat": "-77.846",
    "lng": "166.676"
  },
  {
    "country": "AR",
    "name": "Zárate",
    "lat": "-34.09814",
    "lng": "-59.02858"
  },
  {
    "country": "AR",
    "name": "Yataity Calle",
    "lat": "-29.01913",
    "lng": "-58.90846"
  },
  {
    "country": "AR",
    "name": "Yapeyú",
    "lat": "-29.46914",
    "lng": "-56.81841"
  },
  {
    "country": "AR",
    "name": "Wanda",
    "lat": "-25.96879",
    "lng": "-54.56285"
  },
  {
    "country": "AR",
    "name": "Villa Paranacito",
    "lat": "-33.72207",
    "lng": "-58.65798"
  },
  {
    "country": "AR",
    "name": "Villa Ortúzar",
    "lat": "-34.57973",
    "lng": "-58.46829"
  },
  {
    "country": "AR",
    "name": "Villa Ocampo",
    "lat": "-28.48752",
    "lng": "-59.35515"
  },
  {
    "country": "AR",
    "name": "Villa María Grande",
    "lat": "-31.66565",
    "lng": "-59.90182"
  },
  {
    "country": "AR",
    "name": "Villa Mantero",
    "lat": "-32.39727",
    "lng": "-58.74596"
  },
  {
    "country": "AR",
    "name": "Villa Lugano",
    "lat": "-34.67907",
    "lng": "-58.47263"
  },
  {
    "country": "AR",
    "name": "Villa Hernandarias",
    "lat": "-31.23101",
    "lng": "-59.985"
  },
  {
    "country": "AR",
    "name": "Villaguay",
    "lat": "-31.8653",
    "lng": "-59.02689"
  },
  {
    "country": "AR",
    "name": "Villa Gesell",
    "lat": "-37.26394",
    "lng": "-56.97304"
  },
  {
    "country": "AR",
    "name": "Villa Escolar",
    "lat": "-26.62209",
    "lng": "-58.67134"
  },
  {
    "country": "AR",
    "name": "Villa Elisa",
    "lat": "-32.1632",
    "lng": "-58.40082"
  },
  {
    "country": "AR",
    "name": "Villa del Rosario",
    "lat": "-30.79567",
    "lng": "-57.91257"
  },
  {
    "country": "AR",
    "name": "Verónica",
    "lat": "-35.38796",
    "lng": "-57.33691"
  },
  {
    "country": "AR",
    "name": "Veinticinco de Mayo",
    "lat": "-27.37679",
    "lng": "-54.74312"
  },
  {
    "country": "AR",
    "name": "Urdinarrain",
    "lat": "-32.68573",
    "lng": "-58.89323"
  },
  {
    "country": "AR",
    "name": "Ubajay",
    "lat": "-31.79358",
    "lng": "-58.3135"
  },
  {
    "country": "AR",
    "name": "Tres Capones",
    "lat": "-28.00641",
    "lng": "-55.60471"
  },
  {
    "country": "AR",
    "name": "Tigre",
    "lat": "-34.42603",
    "lng": "-58.57962"
  },
  {
    "country": "AR",
    "name": "Tandil",
    "lat": "-37.32167",
    "lng": "-59.13316"
  },
  {
    "country": "AR",
    "name": "Tacuarendí",
    "lat": "-28.41265",
    "lng": "-59.26"
  },
  {
    "country": "AR",
    "name": "Tabossi",
    "lat": "-31.80135",
    "lng": "-59.93477"
  },
  {
    "country": "AR",
    "name": "Suipacha",
    "lat": "-34.7702",
    "lng": "-59.68783"
  },
  {
    "country": "AR",
    "name": "Sauce de Luna",
    "lat": "-31.23794",
    "lng": "-59.21872"
  },
  {
    "country": "AR",
    "name": "Sauce",
    "lat": "-30.08671",
    "lng": "-58.78777"
  },
  {
    "country": "AR",
    "name": "San Vicente",
    "lat": "-35.025",
    "lng": "-58.42276"
  },
  {
    "country": "AR",
    "name": "San Vicente",
    "lat": "-26.61667",
    "lng": "-54.13333"
  },
  {
    "country": "AR",
    "name": "Santo Tomé",
    "lat": "-28.54939",
    "lng": "-56.04077"
  },
  {
    "country": "AR",
    "name": "Santo Pipó",
    "lat": "-27.14132",
    "lng": "-55.40867"
  },
  {
    "country": "AR",
    "name": "Santa Rosa",
    "lat": "-28.26318",
    "lng": "-58.11891"
  },
  {
    "country": "AR",
    "name": "Santa María",
    "lat": "-27.90357",
    "lng": "-55.38541"
  },
  {
    "country": "AR",
    "name": "Santa Lucía",
    "lat": "-28.98746",
    "lng": "-59.10287"
  },
  {
    "country": "AR",
    "name": "Santa Elena",
    "lat": "-30.94768",
    "lng": "-59.78696"
  },
  {
    "country": "AR",
    "name": "Santa Anita",
    "lat": "-32.17476",
    "lng": "-58.78622"
  },
  {
    "country": "AR",
    "name": "Santa Ana",
    "lat": "-30.90004",
    "lng": "-57.93162"
  },
  {
    "country": "AR",
    "name": "Santa Ana",
    "lat": "-27.3674",
    "lng": "-55.58091"
  },
  {
    "country": "AR",
    "name": "San Salvador",
    "lat": "-31.62487",
    "lng": "-58.50524"
  },
  {
    "country": "AR",
    "name": "San Roque",
    "lat": "-28.57457",
    "lng": "-58.70817"
  },
  {
    "country": "AR",
    "name": "San Pedro",
    "lat": "-33.67918",
    "lng": "-59.66633"
  },
  {
    "country": "AR",
    "name": "San Pedro",
    "lat": "-26.62207",
    "lng": "-54.10842"
  },
  {
    "country": "AR",
    "name": "San Miguel del Monte",
    "lat": "-35.43962",
    "lng": "-58.80675"
  },
  {
    "country": "AR",
    "name": "San Miguel",
    "lat": "-27.99585",
    "lng": "-57.58964"
  },
  {
    "country": "AR",
    "name": "San Luis del Palmar",
    "lat": "-27.5079",
    "lng": "-58.55454"
  },
  {
    "country": "AR",
    "name": "San Lorenzo",
    "lat": "-28.13306",
    "lng": "-58.76733"
  },
  {
    "country": "AR",
    "name": "San Justo",
    "lat": "-34.6766",
    "lng": "-58.56058"
  },
  {
    "country": "AR",
    "name": "San Justo",
    "lat": "-32.44654",
    "lng": "-58.43569"
  },
  {
    "country": "AR",
    "name": "San José de Feliciano",
    "lat": "-30.38452",
    "lng": "-58.75167"
  },
  {
    "country": "AR",
    "name": "San José",
    "lat": "-27.76979",
    "lng": "-55.7826"
  },
  {
    "country": "AR",
    "name": "San Javier",
    "lat": "-30.57781",
    "lng": "-59.9317"
  },
  {
    "country": "AR",
    "name": "San Javier",
    "lat": "-27.87427",
    "lng": "-55.13509"
  },
  {
    "country": "AR",
    "name": "San Isidro",
    "lat": "-34.4721",
    "lng": "-58.52708"
  },
  {
    "country": "AR",
    "name": "San Ignacio",
    "lat": "-27.25586",
    "lng": "-55.5339"
  },
  {
    "country": "AR",
    "name": "San Gustavo",
    "lat": "-30.68961",
    "lng": "-59.3984"
  },
  {
    "country": "AR",
    "name": "San Francisco de Laishí",
    "lat": "-26.24262",
    "lng": "-58.63039"
  },
  {
    "country": "AR",
    "name": "San Cosme",
    "lat": "-27.37123",
    "lng": "-58.51214"
  },
  {
    "country": "AR",
    "name": "San Clemente del Tuyú",
    "lat": "-36.35694",
    "lng": "-56.72351"
  },
  {
    "country": "AR",
    "name": "San Cayetano",
    "lat": "-38.34653",
    "lng": "-59.60954"
  },
  {
    "country": "AR",
    "name": "San Carlos",
    "lat": "-27.74586",
    "lng": "-55.89731"
  },
  {
    "country": "AR",
    "name": "San Antonio de Areco",
    "lat": "-34.2503",
    "lng": "-59.47163"
  },
  {
    "country": "AR",
    "name": "San Andrés de Giles",
    "lat": "-34.44721",
    "lng": "-59.44451"
  },
  {
    "country": "AR",
    "name": "Saladillo",
    "lat": "-35.63708",
    "lng": "-59.77788"
  },
  {
    "country": "AR",
    "name": "Saladas",
    "lat": "-28.25384",
    "lng": "-58.62591"
  },
  {
    "country": "AR",
    "name": "Ruiz de Montoya",
    "lat": "-26.98333",
    "lng": "-55.05"
  },
  {
    "country": "AR",
    "name": "Rosario del Tala",
    "lat": "-32.30286",
    "lng": "-59.14545"
  },
  {
    "country": "AR",
    "name": "Roque Pérez",
    "lat": "-35.39794",
    "lng": "-59.33271"
  },
  {
    "country": "AR",
    "name": "Riachuelo",
    "lat": "-27.57754",
    "lng": "-58.73945"
  },
  {
    "country": "AR",
    "name": "Riacho Eh-Eh",
    "lat": "-25.36209",
    "lng": "-58.2775"
  },
  {
    "country": "AR",
    "name": "Retiro",
    "lat": "-34.58333",
    "lng": "-58.38333"
  },
  {
    "country": "AR",
    "name": "Resistencia",
    "lat": "-27.46056",
    "lng": "-58.98389"
  },
  {
    "country": "AR",
    "name": "Reconquista",
    "lat": "-29.15",
    "lng": "-59.65"
  },
  {
    "country": "AR",
    "name": "Rauch",
    "lat": "-36.7745",
    "lng": "-59.08973"
  },
  {
    "country": "AR",
    "name": "Ranchos",
    "lat": "-35.51619",
    "lng": "-58.31733"
  },
  {
    "country": "AR",
    "name": "Quilmes",
    "lat": "-34.72904",
    "lng": "-58.26374"
  },
  {
    "country": "AR",
    "name": "Puerto Yeruá",
    "lat": "-31.53713",
    "lng": "-58.01527"
  },
  {
    "country": "AR",
    "name": "Puerto Vilelas",
    "lat": "-27.51414",
    "lng": "-58.93906"
  },
  {
    "country": "AR",
    "name": "Puerto Tirol",
    "lat": "-27.37218",
    "lng": "-59.08206"
  },
  {
    "country": "AR",
    "name": "Puerto Rico",
    "lat": "-26.79598",
    "lng": "-55.02402"
  },
  {
    "country": "AR",
    "name": "Puerto Piray",
    "lat": "-26.46779",
    "lng": "-54.71476"
  },
  {
    "country": "AR",
    "name": "Puerto Libertad",
    "lat": "-25.91641",
    "lng": "-54.62089"
  },
  {
    "country": "AR",
    "name": "Puerto Leoni",
    "lat": "-26.96069",
    "lng": "-55.1657"
  },
  {
    "country": "AR",
    "name": "Puerto Iguazú",
    "lat": "-25.59912",
    "lng": "-54.57355"
  },
  {
    "country": "AR",
    "name": "Puerto Ibicuy",
    "lat": "-33.73333",
    "lng": "-59.18333"
  },
  {
    "country": "AR",
    "name": "Puerto Esperanza",
    "lat": "-26.01517",
    "lng": "-54.67306"
  },
  {
    "country": "AR",
    "name": "Puerto Eldorado",
    "lat": "-26.40843",
    "lng": "-54.69463"
  },
  {
    "country": "AR",
    "name": "Puerto Bermejo",
    "lat": "-26.93173",
    "lng": "-58.50538"
  },
  {
    "country": "AR",
    "name": "Pueblo Libertador",
    "lat": "-30.22087",
    "lng": "-59.38981"
  },
  {
    "country": "AR",
    "name": "Pronunciamiento",
    "lat": "-32.34617",
    "lng": "-58.43287"
  },
  {
    "country": "AR",
    "name": "Presidencia Roca",
    "lat": "-26.1409",
    "lng": "-59.59541"
  },
  {
    "country": "AR",
    "name": "Presidencia de la Plaza",
    "lat": "-27.00147",
    "lng": "-59.84243"
  },
  {
    "country": "AR",
    "name": "Posadas",
    "lat": "-27.36708",
    "lng": "-55.89608"
  },
  {
    "country": "AR",
    "name": "Pontevedra",
    "lat": "-34.74785",
    "lng": "-58.70072"
  },
  {
    "country": "AR",
    "name": "Pirané",
    "lat": "-25.73239",
    "lng": "-59.10879"
  },
  {
    "country": "AR",
    "name": "Pinamar",
    "lat": "-37.10795",
    "lng": "-56.8614"
  },
  {
    "country": "AR",
    "name": "Pilar",
    "lat": "-34.45866",
    "lng": "-58.9142"
  },
  {
    "country": "AR",
    "name": "Pila",
    "lat": "-36.00058",
    "lng": "-58.14391"
  },
  {
    "country": "AR",
    "name": "Piedras Blancas",
    "lat": "-31.18623",
    "lng": "-59.95957"
  },
  {
    "country": "AR",
    "name": "Picada Gobernador López",
    "lat": "-27.67069",
    "lng": "-55.24585"
  },
  {
    "country": "AR",
    "name": "Perugorría",
    "lat": "-29.34132",
    "lng": "-58.61059"
  },
  {
    "country": "AR",
    "name": "Pedro R. Fernández",
    "lat": "-28.75097",
    "lng": "-58.65583"
  },
  {
    "country": "AR",
    "name": "Paso de los Libres",
    "lat": "-29.71251",
    "lng": "-57.08771"
  },
  {
    "country": "AR",
    "name": "Paso de la Patria",
    "lat": "-27.31676",
    "lng": "-58.57197"
  },
  {
    "country": "AR",
    "name": "Panambí",
    "lat": "-27.72369",
    "lng": "-54.91515"
  },
  {
    "country": "AR",
    "name": "Pampa del Indio",
    "lat": "-26.06468",
    "lng": "-59.91898"
  },
  {
    "country": "AR",
    "name": "Pampa Almirón",
    "lat": "-26.7",
    "lng": "-59.13333"
  },
  {
    "country": "AR",
    "name": "Palo Santo",
    "lat": "-25.56332",
    "lng": "-59.33781"
  },
  {
    "country": "AR",
    "name": "Palmar Grande",
    "lat": "-27.94195",
    "lng": "-57.90057"
  },
  {
    "country": "AR",
    "name": "Olivos",
    "lat": "-34.50747",
    "lng": "-58.48703"
  },
  {
    "country": "AR",
    "name": "Oberá",
    "lat": "-27.48706",
    "lng": "-55.11994"
  },
  {
    "country": "AR",
    "name": "Nueve de Julio",
    "lat": "-28.84051",
    "lng": "-58.8265"
  },
  {
    "country": "AR",
    "name": "Nuestra Señora del Rosario de Caa Catí",
    "lat": "-27.75072",
    "lng": "-57.62073"
  },
  {
    "country": "AR",
    "name": "Nogoyá",
    "lat": "-32.39387",
    "lng": "-59.78953"
  },
  {
    "country": "AR",
    "name": "Necochea",
    "lat": "-38.5545",
    "lng": "-58.73961"
  },
  {
    "country": "AR",
    "name": "Navarro",
    "lat": "-35.00559",
    "lng": "-59.27699"
  },
  {
    "country": "AR",
    "name": "Morón",
    "lat": "-34.6509",
    "lng": "-58.61956"
  },
  {
    "country": "AR",
    "name": "Monte Caseros",
    "lat": "-30.25359",
    "lng": "-57.63626"
  },
  {
    "country": "AR",
    "name": "Montecarlo",
    "lat": "-26.5662",
    "lng": "-54.757"
  },
  {
    "country": "AR",
    "name": "Mojón Grande",
    "lat": "-27.71165",
    "lng": "-55.15631"
  },
  {
    "country": "AR",
    "name": "Mocoretá",
    "lat": "-30.61891",
    "lng": "-57.96344"
  },
  {
    "country": "AR",
    "name": "Miramar",
    "lat": "-38.27161",
    "lng": "-57.8389"
  },
  {
    "country": "AR",
    "name": "Merlo",
    "lat": "-34.66627",
    "lng": "-58.72927"
  },
  {
    "country": "AR",
    "name": "Mercedes",
    "lat": "-34.65145",
    "lng": "-59.43068"
  },
  {
    "country": "AR",
    "name": "Mercedes",
    "lat": "-29.18416",
    "lng": "-58.07519"
  },
  {
    "country": "AR",
    "name": "Mburucuyá",
    "lat": "-28.04532",
    "lng": "-58.22835"
  },
  {
    "country": "AR",
    "name": "Mártires",
    "lat": "-27.43333",
    "lng": "-55.38333"
  },
  {
    "country": "AR",
    "name": "Mariano I. Loza",
    "lat": "-29.37667",
    "lng": "-58.19436"
  },
  {
    "country": "AR",
    "name": "Margarita Belén",
    "lat": "-27.2616",
    "lng": "-58.97219"
  },
  {
    "country": "AR",
    "name": "Mar del Tuyú",
    "lat": "-36.57531",
    "lng": "-56.68883"
  },
  {
    "country": "AR",
    "name": "Mar del Plata",
    "lat": "-38.00228",
    "lng": "-57.55754"
  },
  {
    "country": "AR",
    "name": "Marcos Paz",
    "lat": "-34.78063",
    "lng": "-58.8379"
  },
  {
    "country": "AR",
    "name": "Malabrigo",
    "lat": "-29.34636",
    "lng": "-59.96957"
  },
  {
    "country": "AR",
    "name": "Makallé",
    "lat": "-27.20687",
    "lng": "-59.28696"
  },
  {
    "country": "AR",
    "name": "Maipú",
    "lat": "-36.86274",
    "lng": "-57.88094"
  },
  {
    "country": "AR",
    "name": "Magdalena",
    "lat": "-35.08065",
    "lng": "-57.51301"
  },
  {
    "country": "AR",
    "name": "Maciá",
    "lat": "-32.1722",
    "lng": "-59.39947"
  },
  {
    "country": "AR",
    "name": "Luján",
    "lat": "-34.57028",
    "lng": "-59.105"
  },
  {
    "country": "AR",
    "name": "Lucas González",
    "lat": "-32.3843",
    "lng": "-59.53013"
  },
  {
    "country": "AR",
    "name": "Los Helechos",
    "lat": "-27.5576",
    "lng": "-55.07683"
  },
  {
    "country": "AR",
    "name": "Los Conquistadores",
    "lat": "-30.5908",
    "lng": "-58.46773"
  },
  {
    "country": "AR",
    "name": "Los Charrúas",
    "lat": "-31.17548",
    "lng": "-58.18774"
  },
  {
    "country": "AR",
    "name": "Loreto",
    "lat": "-27.76834",
    "lng": "-57.27531"
  },
  {
    "country": "AR",
    "name": "Loreto",
    "lat": "-27.33635",
    "lng": "-55.52225"
  },
  {
    "country": "AR",
    "name": "Lomas de Zamora",
    "lat": "-34.76088",
    "lng": "-58.40632"
  },
  {
    "country": "AR",
    "name": "Lomas de Vallejos",
    "lat": "-27.73501",
    "lng": "-57.9185"
  },
  {
    "country": "AR",
    "name": "Lobos",
    "lat": "-35.18286",
    "lng": "-59.08975"
  },
  {
    "country": "AR",
    "name": "Lobería",
    "lat": "-38.15574",
    "lng": "-58.7913"
  },
  {
    "country": "AR",
    "name": "Libertad",
    "lat": "-30.043",
    "lng": "-57.8202"
  },
  {
    "country": "AR",
    "name": "Leandro N. Alem",
    "lat": "-27.60341",
    "lng": "-55.32491"
  },
  {
    "country": "AR",
    "name": "La Verde",
    "lat": "-27.12634",
    "lng": "-59.37352"
  },
  {
    "country": "AR",
    "name": "Las Toscas",
    "lat": "-28.3529",
    "lng": "-59.25795"
  },
  {
    "country": "AR",
    "name": "Las Garcitas",
    "lat": "-26.58333",
    "lng": "-59.8"
  },
  {
    "country": "AR",
    "name": "Las Flores",
    "lat": "-36.01403",
    "lng": "-59.09984"
  },
  {
    "country": "AR",
    "name": "Larroque",
    "lat": "-33.03595",
    "lng": "-59.00125"
  },
  {
    "country": "AR",
    "name": "La Plata",
    "lat": "-34.92145",
    "lng": "-57.95453"
  },
  {
    "country": "AR",
    "name": "La Paz",
    "lat": "-30.74485",
    "lng": "-59.64566"
  },
  {
    "country": "AR",
    "name": "Lapachito",
    "lat": "-27.15997",
    "lng": "-59.38605"
  },
  {
    "country": "AR",
    "name": "Lanús",
    "lat": "-34.70252",
    "lng": "-58.3955"
  },
  {
    "country": "AR",
    "name": "La Leonesa",
    "lat": "-27.03786",
    "lng": "-58.70347"
  },
  {
    "country": "AR",
    "name": "Laguna Naick-Neck",
    "lat": "-25.24769",
    "lng": "-58.09383"
  },
  {
    "country": "AR",
    "name": "Laguna Limpia",
    "lat": "-26.49565",
    "lng": "-59.68083"
  },
  {
    "country": "AR",
    "name": "La Escondida",
    "lat": "-27.10724",
    "lng": "-59.44784"
  },
  {
    "country": "AR",
    "name": "La Eduvigis",
    "lat": "-26.85545",
    "lng": "-59.06842"
  },
  {
    "country": "AR",
    "name": "La Cruz",
    "lat": "-29.17443",
    "lng": "-56.64326"
  },
  {
    "country": "AR",
    "name": "La Criolla",
    "lat": "-31.26904",
    "lng": "-58.10558"
  },
  {
    "country": "AR",
    "name": "Juan Pujol",
    "lat": "-30.41873",
    "lng": "-57.85612"
  },
  {
    "country": "AR",
    "name": "Jardín América",
    "lat": "-27.04346",
    "lng": "-55.22698"
  },
  {
    "country": "AR",
    "name": "Ituzaingó",
    "lat": "-34.65803",
    "lng": "-58.66317"
  },
  {
    "country": "AR",
    "name": "Ituzaingó",
    "lat": "-27.58162",
    "lng": "-56.68231"
  },
  {
    "country": "AR",
    "name": "Itatí",
    "lat": "-27.27043",
    "lng": "-58.24458"
  },
  {
    "country": "AR",
    "name": "Itá Ibaté",
    "lat": "-27.42573",
    "lng": "-57.33758"
  },
  {
    "country": "AR",
    "name": "Ibarreta",
    "lat": "-25.21438",
    "lng": "-59.85851"
  },
  {
    "country": "AR",
    "name": "Hurlingham",
    "lat": "-34.59168",
    "lng": "-58.64608"
  },
  {
    "country": "AR",
    "name": "Herrera",
    "lat": "-32.43516",
    "lng": "-58.62462"
  },
  {
    "country": "AR",
    "name": "Herradura",
    "lat": "-26.48705",
    "lng": "-58.31198"
  },
  {
    "country": "AR",
    "name": "Herlitzka",
    "lat": "-27.56516",
    "lng": "-58.25557"
  },
  {
    "country": "AR",
    "name": "Hasenkamp",
    "lat": "-31.51226",
    "lng": "-59.83545"
  },
  {
    "country": "AR",
    "name": "Guaraní",
    "lat": "-27.51667",
    "lng": "-55.16667"
  },
  {
    "country": "AR",
    "name": "Gualeguaychú",
    "lat": "-33.00937",
    "lng": "-58.51722"
  },
  {
    "country": "AR",
    "name": "Gualeguay",
    "lat": "-33.14156",
    "lng": "-59.30966"
  },
  {
    "country": "AR",
    "name": "Goya",
    "lat": "-29.14395",
    "lng": "-59.2651"
  },
  {
    "country": "AR",
    "name": "Gobernador Roca",
    "lat": "-27.18636",
    "lng": "-55.46433"
  },
  {
    "country": "AR",
    "name": "Gobernador Mansilla",
    "lat": "-32.54453",
    "lng": "-59.3548"
  },
  {
    "country": "AR",
    "name": "Gobernador Juan E. Martínez",
    "lat": "-28.91705",
    "lng": "-58.93292"
  },
  {
    "country": "AR",
    "name": "Gobernador Ingeniero Valentín Virasoro",
    "lat": "-28.05",
    "lng": "-56.03333"
  },
  {
    "country": "AR",
    "name": "General Vedia",
    "lat": "-26.93382",
    "lng": "-58.6604"
  },
  {
    "country": "AR",
    "name": "General San Martín",
    "lat": "-34.57424",
    "lng": "-58.53496"
  },
  {
    "country": "AR",
    "name": "General Rodríguez",
    "lat": "-34.60838",
    "lng": "-58.95253"
  },
  {
    "country": "AR",
    "name": "General Lavalle",
    "lat": "-36.40633",
    "lng": "-56.94329"
  },
  {
    "country": "AR",
    "name": "General Las Heras",
    "lat": "-34.92726",
    "lng": "-58.94621"
  },
  {
    "country": "AR",
    "name": "General Juan Madariaga",
    "lat": "-36.99725",
    "lng": "-57.13951"
  },
  {
    "country": "AR",
    "name": "General José de San Martín",
    "lat": "-26.53743",
    "lng": "-59.34158"
  },
  {
    "country": "AR",
    "name": "General Guido",
    "lat": "-36.64074",
    "lng": "-57.79174"
  },
  {
    "country": "AR",
    "name": "General Galarza",
    "lat": "-32.72034",
    "lng": "-59.39615"
  },
  {
    "country": "AR",
    "name": "General Conesa",
    "lat": "-36.52013",
    "lng": "-57.32537"
  },
  {
    "country": "AR",
    "name": "General Campos",
    "lat": "-31.52311",
    "lng": "-58.4049"
  },
  {
    "country": "AR",
    "name": "General Belgrano",
    "lat": "-35.76952",
    "lng": "-58.49341"
  },
  {
    "country": "AR",
    "name": "General Alvear",
    "lat": "-27.43333",
    "lng": "-55.16667"
  },
  {
    "country": "AR",
    "name": "Garupá",
    "lat": "-27.48171",
    "lng": "-55.82921"
  },
  {
    "country": "AR",
    "name": "Garuhapé",
    "lat": "-26.81768",
    "lng": "-54.95665"
  },
  {
    "country": "AR",
    "name": "Garruchos",
    "lat": "-28.18514",
    "lng": "-55.63947"
  },
  {
    "country": "AR",
    "name": "Formosa",
    "lat": "-26.17753",
    "lng": "-58.17814"
  },
  {
    "country": "AR",
    "name": "Fontana",
    "lat": "-27.41813",
    "lng": "-59.02392"
  },
  {
    "country": "AR",
    "name": "Florentino Ameghino",
    "lat": "-27.56667",
    "lng": "-55.13333"
  },
  {
    "country": "AR",
    "name": "Florencio Varela",
    "lat": "-34.82722",
    "lng": "-58.39556"
  },
  {
    "country": "AR",
    "name": "Felipe Yofré",
    "lat": "-29.10226",
    "lng": "-58.33772"
  },
  {
    "country": "AR",
    "name": "Federal",
    "lat": "-30.95465",
    "lng": "-58.78326"
  },
  {
    "country": "AR",
    "name": "Federación",
    "lat": "-31.00621",
    "lng": "-57.89962"
  },
  {
    "country": "AR",
    "name": "José María Ezeiza",
    "lat": "-34.84787",
    "lng": "-58.52869"
  },
  {
    "country": "AR",
    "name": "Esquina",
    "lat": "-30.01444",
    "lng": "-59.52719"
  },
  {
    "country": "AR",
    "name": "Espinillo",
    "lat": "-24.98132",
    "lng": "-58.5521"
  },
  {
    "country": "AR",
    "name": "Ensenada",
    "lat": "-34.86186",
    "lng": "-57.91126"
  },
  {
    "country": "AR",
    "name": "Empedrado",
    "lat": "-27.95125",
    "lng": "-58.80542"
  },
  {
    "country": "AR",
    "name": "El Soberbio",
    "lat": "-27.29847",
    "lng": "-54.19877"
  },
  {
    "country": "AR",
    "name": "Eldorado",
    "lat": "-26.40484",
    "lng": "-54.62478"
  },
  {
    "country": "AR",
    "name": "El Colorado",
    "lat": "-26.30808",
    "lng": "-59.37291"
  },
  {
    "country": "AR",
    "name": "El Alcázar",
    "lat": "-26.71459",
    "lng": "-54.81523"
  },
  {
    "country": "AR",
    "name": "Dos de Mayo",
    "lat": "-27.02277",
    "lng": "-54.68669"
  },
  {
    "country": "AR",
    "name": "Dos Arroyos",
    "lat": "-27.70784",
    "lng": "-55.23364"
  },
  {
    "country": "AR",
    "name": "Domínguez",
    "lat": "-31.9871",
    "lng": "-58.96197"
  },
  {
    "country": "AR",
    "name": "Dolores",
    "lat": "-36.31321",
    "lng": "-57.67918"
  },
  {
    "country": "AR",
    "name": "Curuzú Cuatiá",
    "lat": "-29.79171",
    "lng": "-58.0546"
  },
  {
    "country": "AR",
    "name": "Cruz de los Milagros",
    "lat": "-28.83646",
    "lng": "-59.00476"
  },
  {
    "country": "AR",
    "name": "Coté-Lai",
    "lat": "-27.5",
    "lng": "-59.6"
  },
  {
    "country": "AR",
    "name": "Corrientes",
    "lat": "-27.4806",
    "lng": "-58.8341"
  },
  {
    "country": "AR",
    "name": "Coronel Vidal",
    "lat": "-37.44604",
    "lng": "-57.72865"
  },
  {
    "country": "AR",
    "name": "Conscripto Bernardi",
    "lat": "-31.04837",
    "lng": "-59.08435"
  },
  {
    "country": "AR",
    "name": "Concordia",
    "lat": "-31.39296",
    "lng": "-58.02089"
  },
  {
    "country": "AR",
    "name": "Concepción del Uruguay",
    "lat": "-32.48249",
    "lng": "-58.23722"
  },
  {
    "country": "AR",
    "name": "Concepción de la Sierra",
    "lat": "-27.98311",
    "lng": "-55.52031"
  },
  {
    "country": "AR",
    "name": "Concepción",
    "lat": "-28.39175",
    "lng": "-57.88777"
  },
  {
    "country": "AR",
    "name": "Comandante Fontana",
    "lat": "-25.33453",
    "lng": "-59.68212"
  },
  {
    "country": "AR",
    "name": "Colonias Unidas",
    "lat": "-26.69825",
    "lng": "-59.63154"
  },
  {
    "country": "AR",
    "name": "Colonia Elisa",
    "lat": "-26.93041",
    "lng": "-59.51861"
  },
  {
    "country": "AR",
    "name": "Colonia Elía",
    "lat": "-32.66625",
    "lng": "-58.32148"
  },
  {
    "country": "AR",
    "name": "Colonia Benítez",
    "lat": "-27.33099",
    "lng": "-58.94622"
  },
  {
    "country": "AR",
    "name": "Colonia Aurora",
    "lat": "-27.47428",
    "lng": "-54.52498"
  },
  {
    "country": "AR",
    "name": "Colón",
    "lat": "-32.22337",
    "lng": "-58.14341"
  },
  {
    "country": "AR",
    "name": "Colegiales",
    "lat": "-34.57365",
    "lng": "-58.44924"
  },
  {
    "country": "AR",
    "name": "Clorinda",
    "lat": "-25.28481",
    "lng": "-57.71851"
  },
  {
    "country": "AR",
    "name": "Ciervo Petiso",
    "lat": "-26.58041",
    "lng": "-59.63094"
  },
  {
    "country": "AR",
    "name": "Chavarría",
    "lat": "-28.95489",
    "lng": "-58.57277"
  },
  {
    "country": "AR",
    "name": "Chascomús",
    "lat": "-35.57297",
    "lng": "-58.00809"
  },
  {
    "country": "AR",
    "name": "Charadai",
    "lat": "-27.63333",
    "lng": "-59.9"
  },
  {
    "country": "AR",
    "name": "Chajarí",
    "lat": "-30.75048",
    "lng": "-57.97962"
  },
  {
    "country": "AR",
    "name": "Cerro Corá",
    "lat": "-27.5131",
    "lng": "-55.60896"
  },
  {
    "country": "AR",
    "name": "Cerro Azul",
    "lat": "-27.6331",
    "lng": "-55.4962"
  },
  {
    "country": "AR",
    "name": "Ceibas",
    "lat": "-33.43333",
    "lng": "-58.75"
  },
  {
    "country": "AR",
    "name": "Castelli",
    "lat": "-36.08949",
    "lng": "-57.80393"
  },
  {
    "country": "AR",
    "name": "Caseros",
    "lat": "-34.60333",
    "lng": "-58.56409"
  },
  {
    "country": "AR",
    "name": "Caseros",
    "lat": "-32.46325",
    "lng": "-58.47872"
  },
  {
    "country": "AR",
    "name": "Carmen de Areco",
    "lat": "-34.37743",
    "lng": "-59.82395"
  },
  {
    "country": "AR",
    "name": "Caraguatay",
    "lat": "-26.60587",
    "lng": "-54.78093"
  },
  {
    "country": "AR",
    "name": "Capitán Solari",
    "lat": "-26.80215",
    "lng": "-59.56089"
  },
  {
    "country": "AR",
    "name": "Capitán Sarmiento",
    "lat": "-34.17238",
    "lng": "-59.79048"
  },
  {
    "country": "AR",
    "name": "Capioví",
    "lat": "-26.92998",
    "lng": "-55.06084"
  },
  {
    "country": "AR",
    "name": "Capilla del Señor",
    "lat": "-34.29207",
    "lng": "-59.10179"
  },
  {
    "country": "AR",
    "name": "Cañuelas",
    "lat": "-35.05184",
    "lng": "-58.76061"
  },
  {
    "country": "AR",
    "name": "Candelaria",
    "lat": "-27.4595",
    "lng": "-55.74536"
  },
  {
    "country": "AR",
    "name": "Campo Viera",
    "lat": "-27.38333",
    "lng": "-55.03333"
  },
  {
    "country": "AR",
    "name": "Campo Ramón",
    "lat": "-27.46108",
    "lng": "-55.01901"
  },
  {
    "country": "AR",
    "name": "Campo Grande",
    "lat": "-27.2077",
    "lng": "-54.97977"
  },
  {
    "country": "AR",
    "name": "Campana",
    "lat": "-34.16874",
    "lng": "-58.95914"
  },
  {
    "country": "AR",
    "name": "Buenos Aires",
    "lat": "-34.61315",
    "lng": "-58.37723"
  },
  {
    "country": "AR",
    "name": "Brandsen",
    "lat": "-35.16842",
    "lng": "-58.23427"
  },
  {
    "country": "AR",
    "name": "Bovril",
    "lat": "-31.34311",
    "lng": "-59.44512"
  },
  {
    "country": "AR",
    "name": "Bonpland",
    "lat": "-29.81708",
    "lng": "-57.42974"
  },
  {
    "country": "AR",
    "name": "Bonpland",
    "lat": "-27.48218",
    "lng": "-55.47756"
  },
  {
    "country": "AR",
    "name": "Boedo",
    "lat": "-34.63333",
    "lng": "-58.41667"
  },
  {
    "country": "AR",
    "name": "Berón de Astrada",
    "lat": "-27.55067",
    "lng": "-57.5346"
  },
  {
    "country": "AR",
    "name": "Bernardo de Irigoyen",
    "lat": "-26.2552",
    "lng": "-53.64581"
  },
  {
    "country": "AR",
    "name": "Berisso",
    "lat": "-34.8735",
    "lng": "-57.88303"
  },
  {
    "country": "AR",
    "name": "Berazategui",
    "lat": "-34.76531",
    "lng": "-58.21278"
  },
  {
    "country": "AR",
    "name": "Benito Juárez",
    "lat": "-37.67188",
    "lng": "-59.80653"
  },
  {
    "country": "AR",
    "name": "Bella Vista",
    "lat": "-28.50918",
    "lng": "-59.04009"
  },
  {
    "country": "AR",
    "name": "Belgrano",
    "lat": "-34.5627",
    "lng": "-58.45829"
  },
  {
    "country": "AR",
    "name": "Belén de Escobar",
    "lat": "-34.34833",
    "lng": "-58.79265"
  },
  {
    "country": "AR",
    "name": "Basail",
    "lat": "-27.86667",
    "lng": "-59.3"
  },
  {
    "country": "AR",
    "name": "Barranqueras",
    "lat": "-27.48132",
    "lng": "-58.93925"
  },
  {
    "country": "AR",
    "name": "Barracas",
    "lat": "-34.64966",
    "lng": "-58.38341"
  },
  {
    "country": "AR",
    "name": "Baradero",
    "lat": "-33.81105",
    "lng": "-59.50807"
  },
  {
    "country": "AR",
    "name": "Balcarce",
    "lat": "-37.84616",
    "lng": "-58.25522"
  },
  {
    "country": "AR",
    "name": "Azul",
    "lat": "-36.77698",
    "lng": "-59.85854"
  },
  {
    "country": "AR",
    "name": "Azara",
    "lat": "-28.0616",
    "lng": "-55.67797"
  },
  {
    "country": "AR",
    "name": "Ayacucho",
    "lat": "-37.15185",
    "lng": "-58.48691"
  },
  {
    "country": "AR",
    "name": "Avellaneda",
    "lat": "-29.11761",
    "lng": "-59.65834"
  },
  {
    "country": "AR",
    "name": "Arroyo del Medio",
    "lat": "-27.7",
    "lng": "-55.41667"
  },
  {
    "country": "AR",
    "name": "Aristóbulo del Valle",
    "lat": "-27.09625",
    "lng": "-54.89626"
  },
  {
    "country": "AR",
    "name": "Apóstoles",
    "lat": "-27.91421",
    "lng": "-55.75355"
  },
  {
    "country": "AR",
    "name": "Alvear",
    "lat": "-29.09683",
    "lng": "-56.55043"
  },
  {
    "country": "AR",
    "name": "Almafuerte",
    "lat": "-27.50518",
    "lng": "-55.39497"
  },
  {
    "country": "AR",
    "name": "Aldea San Antonio",
    "lat": "-32.62376",
    "lng": "-58.70333"
  },
  {
    "country": "AR",
    "name": "Alba Posse",
    "lat": "-27.56978",
    "lng": "-54.68262"
  },
  {
    "country": "AR",
    "name": "Guernica",
    "lat": "-34.91722",
    "lng": "-58.38694"
  },
  {
    "country": "AR",
    "name": "Villa Basilio Nievas",
    "lat": "-31.55",
    "lng": "-68.73333"
  },
  {
    "country": "AR",
    "name": "Zapala",
    "lat": "-38.89916",
    "lng": "-70.05442"
  },
  {
    "country": "AR",
    "name": "Yuto",
    "lat": "-23.64342",
    "lng": "-64.47194"
  },
  {
    "country": "AR",
    "name": "Yerba Buena",
    "lat": "-26.81667",
    "lng": "-65.31667"
  },
  {
    "country": "AR",
    "name": "Yacimiento Río Turbio",
    "lat": "-51.57321",
    "lng": "-72.3508"
  },
  {
    "country": "AR",
    "name": "Winifreda",
    "lat": "-36.22643",
    "lng": "-64.23388"
  },
  {
    "country": "AR",
    "name": "Wenceslao Escalante",
    "lat": "-33.17303",
    "lng": "-62.77078"
  },
  {
    "country": "AR",
    "name": "Vista Alegre",
    "lat": "-38.75",
    "lng": "-68.18333"
  },
  {
    "country": "AR",
    "name": "Vinchina",
    "lat": "-28.75964",
    "lng": "-68.20692"
  },
  {
    "country": "AR",
    "name": "Villa Valeria",
    "lat": "-34.34093",
    "lng": "-64.9203"
  },
  {
    "country": "AR",
    "name": "Villa Urquiza",
    "lat": "-31.64731",
    "lng": "-60.3748"
  },
  {
    "country": "AR",
    "name": "Villa Unión",
    "lat": "-29.41347",
    "lng": "-62.78822"
  },
  {
    "country": "AR",
    "name": "Villa Unión",
    "lat": "-29.31595",
    "lng": "-68.22658"
  },
  {
    "country": "AR",
    "name": "Villa Tulumba",
    "lat": "-30.39552",
    "lng": "-64.12241"
  },
  {
    "country": "AR",
    "name": "Villa Trinidad",
    "lat": "-30.21329",
    "lng": "-61.87597"
  },
  {
    "country": "AR",
    "name": "Villa Santa Rosa",
    "lat": "-31.74434",
    "lng": "-68.31411"
  },
  {
    "country": "AR",
    "name": "Villa Rumipal",
    "lat": "-32.1879",
    "lng": "-64.48027"
  },
  {
    "country": "AR",
    "name": "Villa Regina",
    "lat": "-39.1",
    "lng": "-67.06667"
  },
  {
    "country": "AR",
    "name": "Villa Reducción",
    "lat": "-33.20105",
    "lng": "-63.86234"
  },
  {
    "country": "AR",
    "name": "Villa Paula de Sarmiento",
    "lat": "-31.4933",
    "lng": "-68.53838"
  },
  {
    "country": "AR",
    "name": "Villa Ojo de Agua",
    "lat": "-29.50003",
    "lng": "-63.69377"
  },
  {
    "country": "AR",
    "name": "Villa Nueva",
    "lat": "-32.89722",
    "lng": "-68.78038"
  },
  {
    "country": "AR",
    "name": "Villa Nueva",
    "lat": "-32.43293",
    "lng": "-63.24763"
  },
  {
    "country": "AR",
    "name": "Villa Mugueta",
    "lat": "-33.31129",
    "lng": "-61.05515"
  },
  {
    "country": "AR",
    "name": "Villa Media Agua",
    "lat": "-31.98267",
    "lng": "-68.42394"
  },
  {
    "country": "AR",
    "name": "Villa María",
    "lat": "-32.40751",
    "lng": "-63.24016"
  },
  {
    "country": "AR",
    "name": "Villa Las Rosas",
    "lat": "-31.95021",
    "lng": "-65.05354"
  },
  {
    "country": "AR",
    "name": "Villa La Angostura",
    "lat": "-40.76173",
    "lng": "-71.64631"
  },
  {
    "country": "AR",
    "name": "Villa Krause",
    "lat": "-31.56667",
    "lng": "-68.53333"
  },
  {
    "country": "AR",
    "name": "Villa Huidobro",
    "lat": "-34.83826",
    "lng": "-64.58686"
  },
  {
    "country": "AR",
    "name": "Villa Giardino",
    "lat": "-31.03333",
    "lng": "-64.48333"
  },
  {
    "country": "AR",
    "name": "Villa General Roca",
    "lat": "-32.66535",
    "lng": "-66.45052"
  },
  {
    "country": "AR",
    "name": "Villa General Mitre",
    "lat": "-29.1431",
    "lng": "-62.65248"
  },
  {
    "country": "AR",
    "name": "Villa General Belgrano",
    "lat": "-31.97542",
    "lng": "-64.5559"
  },
  {
    "country": "AR",
    "name": "Villa Dolores",
    "lat": "-31.94585",
    "lng": "-65.18958"
  },
  {
    "country": "AR",
    "name": "Villa de Soto",
    "lat": "-30.85523",
    "lng": "-64.99947"
  },
  {
    "country": "AR",
    "name": "Villa de María",
    "lat": "-29.90195",
    "lng": "-63.72289"
  },
  {
    "country": "AR",
    "name": "Villa del Totoral",
    "lat": "-30.81667",
    "lng": "-63.71667"
  },
  {
    "country": "AR",
    "name": "Villa del Salvador",
    "lat": "-31.44155",
    "lng": "-68.39745"
  },
  {
    "country": "AR",
    "name": "Villa del Rosario",
    "lat": "-31.5566",
    "lng": "-63.53452"
  },
  {
    "country": "AR",
    "name": "Villa del Dique",
    "lat": "-32.17667",
    "lng": "-64.45543"
  },
  {
    "country": "AR",
    "name": "Villa Cura Brochero",
    "lat": "-31.70578",
    "lng": "-65.01796"
  },
  {
    "country": "AR",
    "name": "Villa Constitución",
    "lat": "-33.22778",
    "lng": "-60.3297"
  },
  {
    "country": "AR",
    "name": "Villa Concepción del Tío",
    "lat": "-31.32259",
    "lng": "-62.81354"
  },
  {
    "country": "AR",
    "name": "Chañar Ladeado",
    "lat": "-33.32524",
    "lng": "-62.03831"
  },
  {
    "country": "AR",
    "name": "Villa Castelli",
    "lat": "-29.00295",
    "lng": "-68.21277"
  },
  {
    "country": "AR",
    "name": "Villa Carlos Paz",
    "lat": "-31.42414",
    "lng": "-64.49778"
  },
  {
    "country": "AR",
    "name": "Villa Cañás",
    "lat": "-34.00565",
    "lng": "-61.60757"
  },
  {
    "country": "AR",
    "name": "Villa Bustos",
    "lat": "-29.28483",
    "lng": "-67.03308"
  },
  {
    "country": "AR",
    "name": "Villa Berthet",
    "lat": "-27.29174",
    "lng": "-60.41263"
  },
  {
    "country": "AR",
    "name": "Villa Atamisqui",
    "lat": "-28.49609",
    "lng": "-63.81609"
  },
  {
    "country": "AR",
    "name": "Villa Ascasubi",
    "lat": "-32.16351",
    "lng": "-63.89157"
  },
  {
    "country": "AR",
    "name": "Villa Ángela",
    "lat": "-27.57383",
    "lng": "-60.71526"
  },
  {
    "country": "AR",
    "name": "Villa Allende",
    "lat": "-31.29458",
    "lng": "-64.29538"
  },
  {
    "country": "AR",
    "name": "Villa Aberastain",
    "lat": "-31.65",
    "lng": "-68.58333"
  },
  {
    "country": "AR",
    "name": "Viedma",
    "lat": "-40.81345",
    "lng": "-62.99668"
  },
  {
    "country": "AR",
    "name": "Vicuña Mackenna",
    "lat": "-33.91965",
    "lng": "-64.39215"
  },
  {
    "country": "AR",
    "name": "Victorica",
    "lat": "-36.21505",
    "lng": "-65.43586"
  },
  {
    "country": "AR",
    "name": "Victoria",
    "lat": "-32.61841",
    "lng": "-60.15478"
  },
  {
    "country": "AR",
    "name": "Viamonte",
    "lat": "-33.74647",
    "lng": "-63.09764"
  },
  {
    "country": "AR",
    "name": "Viale",
    "lat": "-31.86782",
    "lng": "-60.00722"
  },
  {
    "country": "AR",
    "name": "Vera",
    "lat": "-29.4593",
    "lng": "-60.21261"
  },
  {
    "country": "AR",
    "name": "Venado Tuerto",
    "lat": "-33.74556",
    "lng": "-61.96885"
  },
  {
    "country": "AR",
    "name": "28 de Noviembre",
    "lat": "-51.5839",
    "lng": "-72.21382"
  },
  {
    "country": "AR",
    "name": "Veinticinco de Mayo",
    "lat": "-37.7741",
    "lng": "-67.71638"
  },
  {
    "country": "AR",
    "name": "Veinticinco de Mayo",
    "lat": "-35.4323",
    "lng": "-60.17271"
  },
  {
    "country": "AR",
    "name": "Vedia",
    "lat": "-34.49558",
    "lng": "-61.54138"
  },
  {
    "country": "AR",
    "name": "Valle Hermoso",
    "lat": "-31.11732",
    "lng": "-64.48084"
  },
  {
    "country": "AR",
    "name": "Valle Grande",
    "lat": "-23.47735",
    "lng": "-64.9425"
  },
  {
    "country": "AR",
    "name": "Valcheta",
    "lat": "-40.7",
    "lng": "-66.15"
  },
  {
    "country": "AR",
    "name": "Ushuaia",
    "lat": "-54.8",
    "lng": "-68.3"
  },
  {
    "country": "AR",
    "name": "Uriburu",
    "lat": "-36.50682",
    "lng": "-63.86225"
  },
  {
    "country": "AR",
    "name": "Unquillo",
    "lat": "-31.23073",
    "lng": "-64.31615"
  },
  {
    "country": "AR",
    "name": "Unión",
    "lat": "-35.15282",
    "lng": "-65.94602"
  },
  {
    "country": "AR",
    "name": "Ulapes",
    "lat": "-31.57362",
    "lng": "-66.2365"
  },
  {
    "country": "AR",
    "name": "Ucacha",
    "lat": "-33.03203",
    "lng": "-63.50666"
  },
  {
    "country": "AR",
    "name": "Tupungato",
    "lat": "-33.37146",
    "lng": "-69.14845"
  },
  {
    "country": "AR",
    "name": "Tunuyán",
    "lat": "-33.57653",
    "lng": "-69.01538"
  },
  {
    "country": "AR",
    "name": "Tumbaya",
    "lat": "-23.85626",
    "lng": "-65.45741"
  },
  {
    "country": "AR",
    "name": "Trevelin",
    "lat": "-43.0858",
    "lng": "-71.46386"
  },
  {
    "country": "AR",
    "name": "Tres Lomas",
    "lat": "-36.45722",
    "lng": "-62.86047"
  },
  {
    "country": "AR",
    "name": "Tres Isletas",
    "lat": "-26.34067",
    "lng": "-60.43207"
  },
  {
    "country": "AR",
    "name": "Tres Arroyos",
    "lat": "-38.37394",
    "lng": "-60.27978"
  },
  {
    "country": "AR",
    "name": "Tres Algarrobos",
    "lat": "-35.19471",
    "lng": "-62.77396"
  },
  {
    "country": "AR",
    "name": "Trenque Lauquen",
    "lat": "-35.97035",
    "lng": "-62.73432"
  },
  {
    "country": "AR",
    "name": "Trenel",
    "lat": "-35.69837",
    "lng": "-64.13218"
  },
  {
    "country": "AR",
    "name": "Trelew",
    "lat": "-43.24895",
    "lng": "-65.30505"
  },
  {
    "country": "AR",
    "name": "Trancas",
    "lat": "-26.21575",
    "lng": "-65.28492"
  },
  {
    "country": "AR",
    "name": "Totoras",
    "lat": "-32.5844",
    "lng": "-61.16852"
  },
  {
    "country": "AR",
    "name": "Tostado",
    "lat": "-29.23202",
    "lng": "-61.76917"
  },
  {
    "country": "AR",
    "name": "Tornquist",
    "lat": "-38.10122",
    "lng": "-62.22267"
  },
  {
    "country": "AR",
    "name": "Toledo",
    "lat": "-31.55574",
    "lng": "-64.00947"
  },
  {
    "country": "AR",
    "name": "Toay",
    "lat": "-36.67338",
    "lng": "-64.3786"
  },
  {
    "country": "AR",
    "name": "Tío Pujio",
    "lat": "-32.2879",
    "lng": "-63.35598"
  },
  {
    "country": "AR",
    "name": "Tintina",
    "lat": "-27.03333",
    "lng": "-62.71667"
  },
  {
    "country": "AR",
    "name": "Tinogasta",
    "lat": "-28.06319",
    "lng": "-67.56488"
  },
  {
    "country": "AR",
    "name": "Tilisarao",
    "lat": "-32.73292",
    "lng": "-65.29109"
  },
  {
    "country": "AR",
    "name": "Tilcara",
    "lat": "-23.57757",
    "lng": "-65.3509"
  },
  {
    "country": "AR",
    "name": "Ticino",
    "lat": "-32.6935",
    "lng": "-63.43606"
  },
  {
    "country": "AR",
    "name": "Termas de Río Hondo",
    "lat": "-27.49362",
    "lng": "-64.85972"
  },
  {
    "country": "AR",
    "name": "Telsen",
    "lat": "-42.43553",
    "lng": "-66.94078"
  },
  {
    "country": "AR",
    "name": "Telén",
    "lat": "-36.26429",
    "lng": "-65.51018"
  },
  {
    "country": "AR",
    "name": "Tecka",
    "lat": "-43.49489",
    "lng": "-70.8102"
  },
  {
    "country": "AR",
    "name": "Tartagal",
    "lat": "-22.51637",
    "lng": "-63.80131"
  },
  {
    "country": "AR",
    "name": "Tapalqué",
    "lat": "-36.35493",
    "lng": "-60.0264"
  },
  {
    "country": "AR",
    "name": "Tancacha",
    "lat": "-32.24309",
    "lng": "-63.9807"
  },
  {
    "country": "AR",
    "name": "Tamberías",
    "lat": "-31.46646",
    "lng": "-69.4255"
  },
  {
    "country": "AR",
    "name": "Tama",
    "lat": "-30.50798",
    "lng": "-66.5298"
  },
  {
    "country": "AR",
    "name": "Tafí Viejo",
    "lat": "-26.73201",
    "lng": "-65.25921"
  },
  {
    "country": "AR",
    "name": "Tafí del Valle",
    "lat": "-26.85275",
    "lng": "-65.70983"
  },
  {
    "country": "AR",
    "name": "Taco Pozo",
    "lat": "-25.61667",
    "lng": "-63.28333"
  },
  {
    "country": "AR",
    "name": "Susques",
    "lat": "-23.39864",
    "lng": "-66.36701"
  },
  {
    "country": "AR",
    "name": "Suncho Corral",
    "lat": "-27.93357",
    "lng": "-63.42938"
  },
  {
    "country": "AR",
    "name": "Sunchales",
    "lat": "-30.94404",
    "lng": "-61.56148"
  },
  {
    "country": "AR",
    "name": "Sumampa",
    "lat": "-29.3847",
    "lng": "-63.46907"
  },
  {
    "country": "AR",
    "name": "Simoca",
    "lat": "-27.26272",
    "lng": "-65.35647"
  },
  {
    "country": "AR",
    "name": "Sierra Grande",
    "lat": "-41.60603",
    "lng": "-65.35574"
  },
  {
    "country": "AR",
    "name": "Sierra Colorada",
    "lat": "-40.58487",
    "lng": "-67.75674"
  },
  {
    "country": "AR",
    "name": "Serrezuela",
    "lat": "-30.63761",
    "lng": "-65.38692"
  },
  {
    "country": "AR",
    "name": "Serrano",
    "lat": "-34.46971",
    "lng": "-63.53842"
  },
  {
    "country": "AR",
    "name": "Senillosa",
    "lat": "-39.01412",
    "lng": "-68.43281"
  },
  {
    "country": "AR",
    "name": "Selva",
    "lat": "-29.76776",
    "lng": "-62.0477"
  },
  {
    "country": "AR",
    "name": "Seguí",
    "lat": "-31.95642",
    "lng": "-60.12488"
  },
  {
    "country": "AR",
    "name": "Sebastián Elcano",
    "lat": "-30.16105",
    "lng": "-63.5936"
  },
  {
    "country": "AR",
    "name": "Saujil",
    "lat": "-28.17442",
    "lng": "-66.21177"
  },
  {
    "country": "AR",
    "name": "Saturnino M. Laspiur",
    "lat": "-31.70287",
    "lng": "-62.48202"
  },
  {
    "country": "AR",
    "name": "Sastre",
    "lat": "-31.76762",
    "lng": "-61.82887"
  },
  {
    "country": "AR",
    "name": "Sarmiento",
    "lat": "-45.58815",
    "lng": "-69.06996"
  },
  {
    "country": "AR",
    "name": "Santo Tomé",
    "lat": "-31.66274",
    "lng": "-60.7653"
  },
  {
    "country": "AR",
    "name": "Santiago Temple",
    "lat": "-31.38731",
    "lng": "-63.41821"
  },
  {
    "country": "AR",
    "name": "Santiago del Estero",
    "lat": "-27.79511",
    "lng": "-64.26149"
  },
  {
    "country": "AR",
    "name": "Santa Victoria",
    "lat": "-22.25",
    "lng": "-64.96667"
  },
  {
    "country": "AR",
    "name": "Santa Sylvina",
    "lat": "-27.83261",
    "lng": "-61.13747"
  },
  {
    "country": "AR",
    "name": "Santa Rosa de Tastil",
    "lat": "-24.45166",
    "lng": "-65.97452"
  },
  {
    "country": "AR",
    "name": "Santa Rosa de Río Primero",
    "lat": "-31.15231",
    "lng": "-63.40191"
  },
  {
    "country": "AR",
    "name": "Santa Rosa del Conlara",
    "lat": "-32.34286",
    "lng": "-65.20323"
  },
  {
    "country": "AR",
    "name": "Santa Rosa de Calamuchita",
    "lat": "-32.06905",
    "lng": "-64.53631"
  },
  {
    "country": "AR",
    "name": "Santa Rosa",
    "lat": "-36.61667",
    "lng": "-64.28333"
  },
  {
    "country": "AR",
    "name": "Santa Rosa",
    "lat": "-33.25407",
    "lng": "-68.14937"
  },
  {
    "country": "AR",
    "name": "Santa María",
    "lat": "-26.69547",
    "lng": "-66.04732"
  },
  {
    "country": "AR",
    "name": "Santa Magdalena",
    "lat": "-34.51776",
    "lng": "-63.94409"
  },
  {
    "country": "AR",
    "name": "Santa Lucía",
    "lat": "-31.53987",
    "lng": "-68.49503"
  },
  {
    "country": "AR",
    "name": "Santa Isabel",
    "lat": "-36.22724",
    "lng": "-66.9424"
  },
  {
    "country": "AR",
    "name": "Santa Fe de la Vera Cruz",
    "lat": "-31.63333",
    "lng": "-60.7"
  },
  {
    "country": "AR",
    "name": "Santa Eufemia",
    "lat": "-33.17659",
    "lng": "-63.28281"
  },
  {
    "country": "AR",
    "name": "Santa Clara",
    "lat": "-24.30921",
    "lng": "-64.66253"
  },
  {
    "country": "AR",
    "name": "Santa Catalina",
    "lat": "-21.94467",
    "lng": "-66.05219"
  },
  {
    "country": "AR",
    "name": "San Salvador de Jujuy",
    "lat": "-24.19457",
    "lng": "-65.29712"
  },
  {
    "country": "AR",
    "name": "San Ramón de la Nueva Orán",
    "lat": "-23.13705",
    "lng": "-64.32426"
  },
  {
    "country": "AR",
    "name": "San Rafael",
    "lat": "-34.61772",
    "lng": "-68.33007"
  },
  {
    "country": "AR",
    "name": "San Pedro",
    "lat": "-27.95386",
    "lng": "-65.16651"
  },
  {
    "country": "AR",
    "name": "San Pedro",
    "lat": "-24.23127",
    "lng": "-64.86614"
  },
  {
    "country": "AR",
    "name": "Sañogasta",
    "lat": "-29.0952",
    "lng": "-67.11586"
  },
  {
    "country": "AR",
    "name": "San Nicolás de los Arroyos",
    "lat": "-33.33425",
    "lng": "-60.2108"
  },
  {
    "country": "AR",
    "name": "San Miguel de Tucumán",
    "lat": "-26.82414",
    "lng": "-65.2226"
  },
  {
    "country": "AR",
    "name": "San Martín de los Andes",
    "lat": "-40.15789",
    "lng": "-71.35337"
  },
  {
    "country": "AR",
    "name": "San Martín",
    "lat": "-33.08103",
    "lng": "-68.46814"
  },
  {
    "country": "AR",
    "name": "San Martín",
    "lat": "-31.42957",
    "lng": "-68.50065"
  },
  {
    "country": "AR",
    "name": "San Luis",
    "lat": "-33.29501",
    "lng": "-66.33563"
  },
  {
    "country": "AR",
    "name": "San Lorenzo",
    "lat": "-32.74341",
    "lng": "-60.73613"
  },
  {
    "country": "AR",
    "name": "San Justo",
    "lat": "-30.78913",
    "lng": "-60.59189"
  },
  {
    "country": "AR",
    "name": "San Juan",
    "lat": "-31.5375",
    "lng": "-68.53639"
  },
  {
    "country": "AR",
    "name": "San José de la Dormida",
    "lat": "-30.3544",
    "lng": "-63.94871"
  },
  {
    "country": "AR",
    "name": "San José de Jáchal",
    "lat": "-30.24057",
    "lng": "-68.74693"
  },
  {
    "country": "AR",
    "name": "San José",
    "lat": "-28.38333",
    "lng": "-65.7"
  },
  {
    "country": "AR",
    "name": "San Jorge",
    "lat": "-31.89618",
    "lng": "-61.85984"
  },
  {
    "country": "AR",
    "name": "San Isidro",
    "lat": "-28.46265",
    "lng": "-65.72585"
  },
  {
    "country": "AR",
    "name": "San Francisco del Monte de Oro",
    "lat": "-32.59825",
    "lng": "-66.12539"
  },
  {
    "country": "AR",
    "name": "San Francisco del Chañar",
    "lat": "-29.78991",
    "lng": "-63.93861"
  },
  {
    "country": "AR",
    "name": "San Francisco",
    "lat": "-31.42797",
    "lng": "-62.08266"
  },
  {
    "country": "AR",
    "name": "San Fernando del Valle de Catamarca",
    "lat": "-28.46957",
    "lng": "-65.78524"
  },
  {
    "country": "AR",
    "name": "San Cristóbal",
    "lat": "-30.31053",
    "lng": "-61.23724"
  },
  {
    "country": "AR",
    "name": "San Carlos de Bolívar",
    "lat": "-36.25",
    "lng": "-61.1"
  },
  {
    "country": "AR",
    "name": "San Carlos Centro",
    "lat": "-31.72864",
    "lng": "-61.09192"
  },
  {
    "country": "AR",
    "name": "San Carlos",
    "lat": "-31.17761",
    "lng": "-65.10245"
  },
  {
    "country": "AR",
    "name": "San Carlos",
    "lat": "-25.88618",
    "lng": "-65.92941"
  },
  {
    "country": "AR",
    "name": "San Blas de los Sauces",
    "lat": "-28.41051",
    "lng": "-67.09341"
  },
  {
    "country": "AR",
    "name": "San Bernardo",
    "lat": "-27.28782",
    "lng": "-60.71252"
  },
  {
    "country": "AR",
    "name": "San Benito",
    "lat": "-31.78371",
    "lng": "-60.44156"
  },
  {
    "country": "AR",
    "name": "San Basilio",
    "lat": "-33.49763",
    "lng": "-64.31495"
  },
  {
    "country": "AR",
    "name": "San Antonio Oeste",
    "lat": "-40.73193",
    "lng": "-64.94769"
  },
  {
    "country": "AR",
    "name": "San Antonio de los Cobres",
    "lat": "-24.21804",
    "lng": "-66.31877"
  },
  {
    "country": "AR",
    "name": "San Antonio de Litín",
    "lat": "-32.21377",
    "lng": "-62.63237"
  },
  {
    "country": "AR",
    "name": "San Antonio",
    "lat": "-28.00927",
    "lng": "-65.71218"
  },
  {
    "country": "AR",
    "name": "San Antonio",
    "lat": "-24.36753",
    "lng": "-65.33471"
  },
  {
    "country": "AR",
    "name": "San Agustín de Valle Fértil",
    "lat": "-30.63353",
    "lng": "-67.46821"
  },
  {
    "country": "AR",
    "name": "San Agustín",
    "lat": "-31.97681",
    "lng": "-64.374"
  },
  {
    "country": "AR",
    "name": "Samuhú",
    "lat": "-27.52116",
    "lng": "-60.39167"
  },
  {
    "country": "AR",
    "name": "Sampacho",
    "lat": "-33.3839",
    "lng": "-64.72211"
  },
  {
    "country": "AR",
    "name": "Salto",
    "lat": "-34.29292",
    "lng": "-60.25455"
  },
  {
    "country": "AR",
    "name": "Salta",
    "lat": "-24.7859",
    "lng": "-65.41166"
  },
  {
    "country": "AR",
    "name": "Salsipuedes",
    "lat": "-31.13725",
    "lng": "-64.29589"
  },
  {
    "country": "AR",
    "name": "Salsacate",
    "lat": "-31.31649",
    "lng": "-65.08529"
  },
  {
    "country": "AR",
    "name": "Salliqueló",
    "lat": "-36.75216",
    "lng": "-62.96053"
  },
  {
    "country": "AR",
    "name": "Saldán",
    "lat": "-31.30262",
    "lng": "-64.307"
  },
  {
    "country": "AR",
    "name": "Sacanta",
    "lat": "-31.663",
    "lng": "-63.04505"
  },
  {
    "country": "AR",
    "name": "Rufino",
    "lat": "-34.26827",
    "lng": "-62.71262"
  },
  {
    "country": "AR",
    "name": "Rosario de Lerma",
    "lat": "-24.98206",
    "lng": "-65.57891"
  },
  {
    "country": "AR",
    "name": "Rosario de la Frontera",
    "lat": "-25.79693",
    "lng": "-64.97094"
  },
  {
    "country": "AR",
    "name": "Rosario",
    "lat": "-32.94682",
    "lng": "-60.63932"
  },
  {
    "country": "AR",
    "name": "Roldán",
    "lat": "-32.89846",
    "lng": "-60.90681"
  },
  {
    "country": "AR",
    "name": "Rojas",
    "lat": "-34.19528",
    "lng": "-60.735"
  },
  {
    "country": "AR",
    "name": "Rodeo",
    "lat": "-30.21186",
    "lng": "-69.13661"
  },
  {
    "country": "AR",
    "name": "Rivadavia",
    "lat": "-33.19051",
    "lng": "-68.46081"
  },
  {
    "country": "AR",
    "name": "Rivadavia",
    "lat": "-31.55389",
    "lng": "-68.6525"
  },
  {
    "country": "AR",
    "name": "Rivadavia",
    "lat": "-24.18832",
    "lng": "-62.89021"
  },
  {
    "country": "AR",
    "name": "Río Tercero",
    "lat": "-32.17301",
    "lng": "-64.11405"
  },
  {
    "country": "AR",
    "name": "Río Segundo",
    "lat": "-31.6526",
    "lng": "-63.9099"
  },
  {
    "country": "AR",
    "name": "Río Pico",
    "lat": "-44.17905",
    "lng": "-71.36847"
  },
  {
    "country": "AR",
    "name": "Río Mayo",
    "lat": "-45.68573",
    "lng": "-70.25797"
  },
  {
    "country": "AR",
    "name": "Río Grande",
    "lat": "-53.78769",
    "lng": "-67.70946"
  },
  {
    "country": "AR",
    "name": "Río Gallegos",
    "lat": "-51.62261",
    "lng": "-69.21813"
  },
  {
    "country": "AR",
    "name": "Río Cuarto",
    "lat": "-33.13067",
    "lng": "-64.34992"
  },
  {
    "country": "AR",
    "name": "Río Colorado",
    "lat": "-38.99397",
    "lng": "-64.09295"
  },
  {
    "country": "AR",
    "name": "Río Ceballos",
    "lat": "-31.16486",
    "lng": "-64.32241"
  },
  {
    "country": "AR",
    "name": "Rinconada",
    "lat": "-22.44083",
    "lng": "-66.16779"
  },
  {
    "country": "AR",
    "name": "Recreo",
    "lat": "-31.49076",
    "lng": "-60.73299"
  },
  {
    "country": "AR",
    "name": "Recreo",
    "lat": "-29.28184",
    "lng": "-65.06096"
  },
  {
    "country": "AR",
    "name": "Realicó",
    "lat": "-35.03658",
    "lng": "-64.2447"
  },
  {
    "country": "AR",
    "name": "Rawson",
    "lat": "-43.30016",
    "lng": "-65.10228"
  },
  {
    "country": "AR",
    "name": "Rancul",
    "lat": "-35.06862",
    "lng": "-64.68107"
  },
  {
    "country": "AR",
    "name": "Ramallo",
    "lat": "-33.48508",
    "lng": "-60.00629"
  },
  {
    "country": "AR",
    "name": "Rafaela",
    "lat": "-31.25033",
    "lng": "-61.4867"
  },
  {
    "country": "AR",
    "name": "Rada Tilly",
    "lat": "-45.92462",
    "lng": "-67.55424"
  },
  {
    "country": "AR",
    "name": "Quitilipi",
    "lat": "-26.86913",
    "lng": "-60.21683"
  },
  {
    "country": "AR",
    "name": "Quimilí",
    "lat": "-27.63333",
    "lng": "-62.41667"
  },
  {
    "country": "AR",
    "name": "Quilino",
    "lat": "-30.21397",
    "lng": "-64.50063"
  },
  {
    "country": "AR",
    "name": "Quemú Quemú",
    "lat": "-36.05463",
    "lng": "-63.56428"
  },
  {
    "country": "AR",
    "name": "Punta Alta",
    "lat": "-38.87588",
    "lng": "-62.07359"
  },
  {
    "country": "AR",
    "name": "Puerto Santa Cruz",
    "lat": "-50.0191",
    "lng": "-68.52321"
  },
  {
    "country": "AR",
    "name": "San Julián",
    "lat": "-49.30554",
    "lng": "-67.72743"
  },
  {
    "country": "AR",
    "name": "Puerto Madryn",
    "lat": "-42.7692",
    "lng": "-65.03851"
  },
  {
    "country": "AR",
    "name": "Puerto Deseado",
    "lat": "-47.75034",
    "lng": "-65.89382"
  },
  {
    "country": "AR",
    "name": "Puerta de Corral Quemado",
    "lat": "-27.23",
    "lng": "-66.93635"
  },
  {
    "country": "AR",
    "name": "Puelches",
    "lat": "-38.14562",
    "lng": "-65.91426"
  },
  {
    "country": "AR",
    "name": "Puan",
    "lat": "-37.54576",
    "lng": "-62.76723"
  },
  {
    "country": "AR",
    "name": "Presidencia Roque Sáenz Peña",
    "lat": "-26.78522",
    "lng": "-60.43876"
  },
  {
    "country": "AR",
    "name": "Pozo Hondo",
    "lat": "-27.16607",
    "lng": "-64.49"
  },
  {
    "country": "AR",
    "name": "Pozo del Tigre",
    "lat": "-24.89682",
    "lng": "-60.32359"
  },
  {
    "country": "AR",
    "name": "Pozo del Molle",
    "lat": "-32.0186",
    "lng": "-62.91984"
  },
  {
    "country": "AR",
    "name": "Porteña",
    "lat": "-31.01391",
    "lng": "-62.0665"
  },
  {
    "country": "AR",
    "name": "Pomán",
    "lat": "-28.39455",
    "lng": "-66.22052"
  },
  {
    "country": "AR",
    "name": "Pocito",
    "lat": "-31.68333",
    "lng": "-68.58333"
  },
  {
    "country": "AR",
    "name": "Plottier",
    "lat": "-38.96667",
    "lng": "-68.23333"
  },
  {
    "country": "AR",
    "name": "Plaza Huincul",
    "lat": "-38.92598",
    "lng": "-69.20863"
  },
  {
    "country": "AR",
    "name": "Piquillín",
    "lat": "-31.30158",
    "lng": "-63.75788"
  },
  {
    "country": "AR",
    "name": "Pilcaniyeu",
    "lat": "-41.11881",
    "lng": "-70.72914"
  },
  {
    "country": "AR",
    "name": "Pilar",
    "lat": "-31.6789",
    "lng": "-63.87964"
  },
  {
    "country": "AR",
    "name": "Pigüé",
    "lat": "-37.60509",
    "lng": "-62.40333"
  },
  {
    "country": "AR",
    "name": "Piedra del Águila",
    "lat": "-40.04811",
    "lng": "-70.0741"
  },
  {
    "country": "AR",
    "name": "Picún Leufú",
    "lat": "-39.52351",
    "lng": "-69.27966"
  },
  {
    "country": "AR",
    "name": "Pico Truncado",
    "lat": "-46.7949",
    "lng": "-67.95731"
  },
  {
    "country": "AR",
    "name": "Perito Moreno",
    "lat": "-46.58995",
    "lng": "-70.92975"
  },
  {
    "country": "AR",
    "name": "Pergamino",
    "lat": "-33.88995",
    "lng": "-60.57357"
  },
  {
    "country": "AR",
    "name": "Pérez",
    "lat": "-32.99835",
    "lng": "-60.76791"
  },
  {
    "country": "AR",
    "name": "Pellegrini",
    "lat": "-36.26584",
    "lng": "-63.1655"
  },
  {
    "country": "AR",
    "name": "Pehuajó",
    "lat": "-35.81077",
    "lng": "-61.8968"
  },
  {
    "country": "AR",
    "name": "Patquía",
    "lat": "-30.04681",
    "lng": "-66.88231"
  },
  {
    "country": "AR",
    "name": "Paso de Indios",
    "lat": "-43.86225",
    "lng": "-69.04603"
  },
  {
    "country": "AR",
    "name": "Pasco",
    "lat": "-32.74733",
    "lng": "-63.34232"
  },
  {
    "country": "AR",
    "name": "Pascanas",
    "lat": "-33.1255",
    "lng": "-63.04084"
  },
  {
    "country": "AR",
    "name": "Parera",
    "lat": "-35.146",
    "lng": "-64.50089"
  },
  {
    "country": "AR",
    "name": "Paraná",
    "lat": "-31.73197",
    "lng": "-60.5238"
  },
  {
    "country": "AR",
    "name": "Pampa de los Guanacos",
    "lat": "-26.23333",
    "lng": "-61.85"
  },
  {
    "country": "AR",
    "name": "Pampa del Infierno",
    "lat": "-26.50517",
    "lng": "-61.17436"
  },
  {
    "country": "AR",
    "name": "Palpalá",
    "lat": "-24.25647",
    "lng": "-65.21163"
  },
  {
    "country": "AR",
    "name": "Palma Sola",
    "lat": "-23.96336",
    "lng": "-64.29872"
  },
  {
    "country": "AR",
    "name": "Oro Verde",
    "lat": "-31.82508",
    "lng": "-60.51749"
  },
  {
    "country": "AR",
    "name": "Ordóñez",
    "lat": "-32.84057",
    "lng": "-62.86552"
  },
  {
    "country": "AR",
    "name": "Oncativo",
    "lat": "-31.91353",
    "lng": "-63.68201"
  },
  {
    "country": "AR",
    "name": "Olta",
    "lat": "-30.63117",
    "lng": "-66.263"
  },
  {
    "country": "AR",
    "name": "Oliva",
    "lat": "-32.04158",
    "lng": "-63.56978"
  },
  {
    "country": "AR",
    "name": "Olavarría",
    "lat": "-36.89272",
    "lng": "-60.32254"
  },
  {
    "country": "AR",
    "name": "Obispo Trejo",
    "lat": "-30.78128",
    "lng": "-63.41349"
  },
  {
    "country": "AR",
    "name": "Nueve de Julio",
    "lat": "-35.44437",
    "lng": "-60.88313"
  },
  {
    "country": "AR",
    "name": "Nueve de Julio",
    "lat": "-31.66914",
    "lng": "-68.39023"
  },
  {
    "country": "AR",
    "name": "Nueva Esperanza",
    "lat": "-26.19907",
    "lng": "-64.23792"
  },
  {
    "country": "AR",
    "name": "Ñorquinco",
    "lat": "-41.85072",
    "lng": "-70.90173"
  },
  {
    "country": "AR",
    "name": "Noetinger",
    "lat": "-32.36597",
    "lng": "-62.31126"
  },
  {
    "country": "AR",
    "name": "Neuquén",
    "lat": "-38.95161",
    "lng": "-68.0591"
  },
  {
    "country": "AR",
    "name": "Naschel",
    "lat": "-32.91656",
    "lng": "-65.37535"
  },
  {
    "country": "AR",
    "name": "Napenay",
    "lat": "-26.73333",
    "lng": "-60.61667"
  },
  {
    "country": "AR",
    "name": "Mutquín",
    "lat": "-28.32104",
    "lng": "-66.14253"
  },
  {
    "country": "AR",
    "name": "Morteros",
    "lat": "-30.71164",
    "lng": "-61.99862"
  },
  {
    "country": "AR",
    "name": "Morrison",
    "lat": "-32.5948",
    "lng": "-62.83455"
  },
  {
    "country": "AR",
    "name": "Monteros",
    "lat": "-27.16741",
    "lng": "-65.49832"
  },
  {
    "country": "AR",
    "name": "Monte Quemado Airport",
    "lat": "-25.80565",
    "lng": "-62.83019"
  },
  {
    "country": "AR",
    "name": "Monte Maíz",
    "lat": "-33.20462",
    "lng": "-62.60085"
  },
  {
    "country": "AR",
    "name": "Monte Hermoso",
    "lat": "-38.9825",
    "lng": "-61.29472"
  },
  {
    "country": "AR",
    "name": "Monte Cristo",
    "lat": "-31.34312",
    "lng": "-63.94437"
  },
  {
    "country": "AR",
    "name": "Monte Buey",
    "lat": "-32.91642",
    "lng": "-62.45669"
  },
  {
    "country": "AR",
    "name": "Molinos",
    "lat": "-25.4395",
    "lng": "-66.29126"
  },
  {
    "country": "AR",
    "name": "Miramar",
    "lat": "-30.91859",
    "lng": "-62.67814"
  },
  {
    "country": "AR",
    "name": "Mina Clavero",
    "lat": "-31.72101",
    "lng": "-65.00619"
  },
  {
    "country": "AR",
    "name": "Milagro",
    "lat": "-31.00326",
    "lng": "-66.00098"
  },
  {
    "country": "AR",
    "name": "Miguel Riglos",
    "lat": "-36.85398",
    "lng": "-63.68842"
  },
  {
    "country": "AR",
    "name": "Metán",
    "lat": "-25.49905",
    "lng": "-64.97388"
  },
  {
    "country": "AR",
    "name": "Merlo",
    "lat": "-32.34288",
    "lng": "-65.01396"
  },
  {
    "country": "AR",
    "name": "Mendoza",
    "lat": "-32.89084",
    "lng": "-68.82717"
  },
  {
    "country": "AR",
    "name": "Mendiolaza",
    "lat": "-31.26738",
    "lng": "-64.30087"
  },
  {
    "country": "AR",
    "name": "Melincué",
    "lat": "-33.65847",
    "lng": "-61.45459"
  },
  {
    "country": "AR",
    "name": "Médanos",
    "lat": "-38.82803",
    "lng": "-62.69355"
  },
  {
    "country": "AR",
    "name": "Mattaldi",
    "lat": "-34.48194",
    "lng": "-64.17255"
  },
  {
    "country": "AR",
    "name": "Marull",
    "lat": "-30.99471",
    "lng": "-62.82576"
  },
  {
    "country": "AR",
    "name": "Mariano Moreno",
    "lat": "-38.75029",
    "lng": "-70.02367"
  },
  {
    "country": "AR",
    "name": "Marcos Juárez",
    "lat": "-32.6978",
    "lng": "-62.10672"
  },
  {
    "country": "AR",
    "name": "Maquinchao",
    "lat": "-41.25",
    "lng": "-68.73333"
  },
  {
    "country": "AR",
    "name": "Malvinas Argentinas",
    "lat": "-31.38333",
    "lng": "-64.06667"
  },
  {
    "country": "AR",
    "name": "Malargüe",
    "lat": "-35.47545",
    "lng": "-69.58427"
  },
  {
    "country": "AR",
    "name": "Malanzán",
    "lat": "-30.80394",
    "lng": "-66.60908"
  },
  {
    "country": "AR",
    "name": "Malagueño",
    "lat": "-31.46467",
    "lng": "-64.3584"
  },
  {
    "country": "AR",
    "name": "Maipú",
    "lat": "-32.97963",
    "lng": "-68.78461"
  },
  {
    "country": "AR",
    "name": "Mainque",
    "lat": "-39.06667",
    "lng": "-67.3"
  },
  {
    "country": "AR",
    "name": "Maimará",
    "lat": "-23.62392",
    "lng": "-65.40797"
  },
  {
    "country": "AR",
    "name": "Machagai",
    "lat": "-26.92614",
    "lng": "-60.04955"
  },
  {
    "country": "AR",
    "name": "Macachín",
    "lat": "-37.13598",
    "lng": "-63.6665"
  },
  {
    "country": "AR",
    "name": "San Isidro de Lules",
    "lat": "-26.9277",
    "lng": "-65.33869"
  },
  {
    "country": "AR",
    "name": "Luján de Cuyo",
    "lat": "-33.03547",
    "lng": "-68.87782"
  },
  {
    "country": "AR",
    "name": "Luján",
    "lat": "-32.3757",
    "lng": "-65.9296"
  },
  {
    "country": "AR",
    "name": "Los Varela",
    "lat": "-27.95482",
    "lng": "-65.8655"
  },
  {
    "country": "AR",
    "name": "Los Telares",
    "lat": "-28.98479",
    "lng": "-63.44889"
  },
  {
    "country": "AR",
    "name": "Los Surgentes",
    "lat": "-32.98454",
    "lng": "-62.02191"
  },
  {
    "country": "AR",
    "name": "Los Menucos",
    "lat": "-40.84402",
    "lng": "-68.08718"
  },
  {
    "country": "AR",
    "name": "Los Juríes",
    "lat": "-28.46539",
    "lng": "-62.10862"
  },
  {
    "country": "AR",
    "name": "Los Frentones",
    "lat": "-26.4077",
    "lng": "-61.41367"
  },
  {
    "country": "AR",
    "name": "Los Cóndores",
    "lat": "-32.31983",
    "lng": "-64.27751"
  },
  {
    "country": "AR",
    "name": "Los Antiguos",
    "lat": "-46.54972",
    "lng": "-71.63086"
  },
  {
    "country": "AR",
    "name": "Los Altos",
    "lat": "-28.04845",
    "lng": "-65.49945"
  },
  {
    "country": "AR",
    "name": "Lonquimay",
    "lat": "-36.46546",
    "lng": "-63.62429"
  },
  {
    "country": "AR",
    "name": "Londres",
    "lat": "-27.71439",
    "lng": "-67.13349"
  },
  {
    "country": "AR",
    "name": "Loncopué",
    "lat": "-38.07284",
    "lng": "-70.61609"
  },
  {
    "country": "AR",
    "name": "Lincoln",
    "lat": "-34.86649",
    "lng": "-61.5302"
  },
  {
    "country": "AR",
    "name": "Limay Mahuida",
    "lat": "-37.15959",
    "lng": "-66.67595"
  },
  {
    "country": "AR",
    "name": "Libertador General San Martín",
    "lat": "-32.41074",
    "lng": "-65.67586"
  },
  {
    "country": "AR",
    "name": "Libertador General San Martín",
    "lat": "-23.80644",
    "lng": "-64.78757"
  },
  {
    "country": "AR",
    "name": "Leones",
    "lat": "-32.66174",
    "lng": "-62.29678"
  },
  {
    "country": "AR",
    "name": "Leleque",
    "lat": "-42.41225",
    "lng": "-71.06797"
  },
  {
    "country": "AR",
    "name": "La Viña",
    "lat": "-25.46642",
    "lng": "-65.5663"
  },
  {
    "country": "AR",
    "name": "La Toma",
    "lat": "-33.05258",
    "lng": "-65.62385"
  },
  {
    "country": "AR",
    "name": "La Tigra",
    "lat": "-27.10996",
    "lng": "-60.58719"
  },
  {
    "country": "AR",
    "name": "Las Varillas",
    "lat": "-31.87208",
    "lng": "-62.71946"
  },
  {
    "country": "AR",
    "name": "Las Varas",
    "lat": "-31.8026",
    "lng": "-62.61655"
  },
  {
    "country": "AR",
    "name": "Las Rosas",
    "lat": "-32.47661",
    "lng": "-61.58041"
  },
  {
    "country": "AR",
    "name": "Las Plumas",
    "lat": "-43.72058",
    "lng": "-67.28319"
  },
  {
    "country": "AR",
    "name": "Las Perdices",
    "lat": "-32.69794",
    "lng": "-63.70634"
  },
  {
    "country": "AR",
    "name": "Las Parejas",
    "lat": "-32.68478",
    "lng": "-61.51637"
  },
  {
    "country": "AR",
    "name": "Las Ovejas",
    "lat": "-36.98881",
    "lng": "-70.74991"
  },
  {
    "country": "AR",
    "name": "Las Lomitas",
    "lat": "-24.70955",
    "lng": "-60.59303"
  },
  {
    "country": "AR",
    "name": "Las Lajitas",
    "lat": "-24.68333",
    "lng": "-64.25"
  },
  {
    "country": "AR",
    "name": "Las Lajas",
    "lat": "-38.52322",
    "lng": "-70.36745"
  },
  {
    "country": "AR",
    "name": "Las Junturas",
    "lat": "-31.83125",
    "lng": "-63.45016"
  },
  {
    "country": "AR",
    "name": "Las Higueras",
    "lat": "-33.09231",
    "lng": "-64.28899"
  },
  {
    "country": "AR",
    "name": "Las Heras",
    "lat": "-46.54186",
    "lng": "-68.93593"
  },
  {
    "country": "AR",
    "name": "Las Heras",
    "lat": "-32.85273",
    "lng": "-68.82837"
  },
  {
    "country": "AR",
    "name": "Las Coloradas",
    "lat": "-39.55534",
    "lng": "-70.59491"
  },
  {
    "country": "AR",
    "name": "Las Breñas",
    "lat": "-27.08966",
    "lng": "-61.08161"
  },
  {
    "country": "AR",
    "name": "Las Acequias",
    "lat": "-33.28155",
    "lng": "-63.9761"
  },
  {
    "country": "AR",
    "name": "La Rioja",
    "lat": "-29.41105",
    "lng": "-66.85067"
  },
  {
    "country": "AR",
    "name": "La Quiaca",
    "lat": "-22.10236",
    "lng": "-65.59299"
  },
  {
    "country": "AR",
    "name": "La Puerta de San José",
    "lat": "-27.55",
    "lng": "-67.01667"
  },
  {
    "country": "AR",
    "name": "La Puerta",
    "lat": "-28.17036",
    "lng": "-65.79015"
  },
  {
    "country": "AR",
    "name": "Laprida",
    "lat": "-37.54415",
    "lng": "-60.79969"
  },
  {
    "country": "AR",
    "name": "La Poma",
    "lat": "-24.72196",
    "lng": "-66.20106"
  },
  {
    "country": "AR",
    "name": "La Playosa",
    "lat": "-32.10002",
    "lng": "-63.03088"
  },
  {
    "country": "AR",
    "name": "La Paz",
    "lat": "-33.46091",
    "lng": "-67.54956"
  },
  {
    "country": "AR",
    "name": "La Para",
    "lat": "-30.89416",
    "lng": "-63.00107"
  },
  {
    "country": "AR",
    "name": "La Merced",
    "lat": "-28.15195",
    "lng": "-65.66029"
  },
  {
    "country": "AR",
    "name": "La Mendieta",
    "lat": "-24.31187",
    "lng": "-64.96377"
  },
  {
    "country": "AR",
    "name": "La Maruja",
    "lat": "-35.6736",
    "lng": "-64.93997"
  },
  {
    "country": "AR",
    "name": "Lamarque",
    "lat": "-39.42304",
    "lng": "-65.70208"
  },
  {
    "country": "AR",
    "name": "Laguna Yema",
    "lat": "-24.25391",
    "lng": "-61.24466"
  },
  {
    "country": "AR",
    "name": "Laguna Paiva",
    "lat": "-31.30391",
    "lng": "-60.65894"
  },
  {
    "country": "AR",
    "name": "Laguna Larga",
    "lat": "-31.77652",
    "lng": "-63.80104"
  },
  {
    "country": "AR",
    "name": "La Granja",
    "lat": "-31.00919",
    "lng": "-64.26869"
  },
  {
    "country": "AR",
    "name": "Lago Puelo",
    "lat": "-42.08095",
    "lng": "-71.61405"
  },
  {
    "country": "AR",
    "name": "La Francia",
    "lat": "-31.40675",
    "lng": "-62.63396"
  },
  {
    "country": "AR",
    "name": "La Falda",
    "lat": "-31.08841",
    "lng": "-64.48987"
  },
  {
    "country": "AR",
    "name": "La Cumbre",
    "lat": "-30.98201",
    "lng": "-64.49139"
  },
  {
    "country": "AR",
    "name": "La Consulta",
    "lat": "-33.73579",
    "lng": "-69.12181"
  },
  {
    "country": "AR",
    "name": "La Cocha",
    "lat": "-27.77729",
    "lng": "-65.57035"
  },
  {
    "country": "AR",
    "name": "La Clotilde",
    "lat": "-27.13333",
    "lng": "-60.66667"
  },
  {
    "country": "AR",
    "name": "La Cesira",
    "lat": "-33.95115",
    "lng": "-62.97238"
  },
  {
    "country": "AR",
    "name": "La Carlota",
    "lat": "-33.41993",
    "lng": "-63.29769"
  },
  {
    "country": "AR",
    "name": "La Candelaria",
    "lat": "-26.12708",
    "lng": "-65.0496"
  },
  {
    "country": "AR",
    "name": "La Cañada",
    "lat": "-27.70826",
    "lng": "-63.77366"
  },
  {
    "country": "AR",
    "name": "La Calera",
    "lat": "-31.34377",
    "lng": "-64.33529"
  },
  {
    "country": "AR",
    "name": "La Caldera",
    "lat": "-24.60159",
    "lng": "-65.38098"
  },
  {
    "country": "AR",
    "name": "Laboulaye",
    "lat": "-34.12662",
    "lng": "-63.39119"
  },
  {
    "country": "AR",
    "name": "Laborde",
    "lat": "-33.15319",
    "lng": "-62.85661"
  },
  {
    "country": "AR",
    "name": "La Banda",
    "lat": "-27.73348",
    "lng": "-64.24278"
  },
  {
    "country": "AR",
    "name": "Justo Daract",
    "lat": "-33.8594",
    "lng": "-65.18277"
  },
  {
    "country": "AR",
    "name": "Justiniano Posse",
    "lat": "-32.88411",
    "lng": "-62.67788"
  },
  {
    "country": "AR",
    "name": "Junín de los Andes",
    "lat": "-39.95043",
    "lng": "-71.06936"
  },
  {
    "country": "AR",
    "name": "Junín",
    "lat": "-34.58382",
    "lng": "-60.94332"
  },
  {
    "country": "AR",
    "name": "Junín",
    "lat": "-33.14765",
    "lng": "-68.47899"
  },
  {
    "country": "AR",
    "name": "José de San Martín",
    "lat": "-44.05032",
    "lng": "-70.46967"
  },
  {
    "country": "AR",
    "name": "Joaquín V. González",
    "lat": "-25.08333",
    "lng": "-64.18333"
  },
  {
    "country": "AR",
    "name": "Jesús María",
    "lat": "-30.98153",
    "lng": "-64.09424"
  },
  {
    "country": "AR",
    "name": "James Craik",
    "lat": "-32.1612",
    "lng": "-63.46688"
  },
  {
    "country": "AR",
    "name": "Jacinto Arauz",
    "lat": "-38.08606",
    "lng": "-63.43169"
  },
  {
    "country": "AR",
    "name": "Italó",
    "lat": "-34.79237",
    "lng": "-63.78199"
  },
  {
    "country": "AR",
    "name": "Isla Verde",
    "lat": "-33.24104",
    "lng": "-62.40297"
  },
  {
    "country": "AR",
    "name": "Iruya",
    "lat": "-22.76667",
    "lng": "-65.23333"
  },
  {
    "country": "AR",
    "name": "Intendente Alvear",
    "lat": "-35.23383",
    "lng": "-63.59205"
  },
  {
    "country": "AR",
    "name": "Inriville",
    "lat": "-32.94424",
    "lng": "-62.23028"
  },
  {
    "country": "AR",
    "name": "Ingenio La Esperanza",
    "lat": "-24.22554",
    "lng": "-64.83896"
  },
  {
    "country": "AR",
    "name": "Ingeniero Luis A. Huergo",
    "lat": "-39.08333",
    "lng": "-67.23333"
  },
  {
    "country": "AR",
    "name": "Ingeniero Luiggi",
    "lat": "-35.38585",
    "lng": "-64.46519"
  },
  {
    "country": "AR",
    "name": "Ingeniero Jacobacci",
    "lat": "-41.3292",
    "lng": "-69.55015"
  },
  {
    "country": "AR",
    "name": "Ingeniero Guillermo N. Juárez",
    "lat": "-23.9",
    "lng": "-61.85"
  },
  {
    "country": "AR",
    "name": "Idiazábal",
    "lat": "-32.81411",
    "lng": "-63.03252"
  },
  {
    "country": "AR",
    "name": "Icaño",
    "lat": "-28.91934",
    "lng": "-65.32817"
  },
  {
    "country": "AR",
    "name": "Humahuaca",
    "lat": "-23.20544",
    "lng": "-65.35048"
  },
  {
    "country": "AR",
    "name": "Huinca Renancó",
    "lat": "-34.84038",
    "lng": "-64.3758"
  },
  {
    "country": "AR",
    "name": "Huillapima",
    "lat": "-28.72533",
    "lng": "-65.9787"
  },
  {
    "country": "AR",
    "name": "Huerta Grande",
    "lat": "-31.07524",
    "lng": "-64.49063"
  },
  {
    "country": "AR",
    "name": "Huanchillas",
    "lat": "-33.66653",
    "lng": "-63.63701"
  },
  {
    "country": "AR",
    "name": "Hualfín",
    "lat": "-27.22896",
    "lng": "-66.83131"
  },
  {
    "country": "AR",
    "name": "Hoyo de Epuyén",
    "lat": "-42.07189",
    "lng": "-71.50811"
  },
  {
    "country": "AR",
    "name": "Hersilia",
    "lat": "-30.00447",
    "lng": "-61.8408"
  },
  {
    "country": "AR",
    "name": "Herrera",
    "lat": "-28.48094",
    "lng": "-63.06779"
  },
  {
    "country": "AR",
    "name": "Hernando",
    "lat": "-32.42657",
    "lng": "-63.73333"
  },
  {
    "country": "AR",
    "name": "Hernández",
    "lat": "-32.3373",
    "lng": "-60.0216"
  },
  {
    "country": "AR",
    "name": "Hermoso Campo",
    "lat": "-27.60816",
    "lng": "-61.34441"
  },
  {
    "country": "AR",
    "name": "Henderson",
    "lat": "-36.3",
    "lng": "-61.71667"
  },
  {
    "country": "AR",
    "name": "Helvecia",
    "lat": "-31.09834",
    "lng": "-60.0883"
  },
  {
    "country": "AR",
    "name": "Guatraché",
    "lat": "-37.66776",
    "lng": "-63.53021"
  },
  {
    "country": "AR",
    "name": "Guatimozín",
    "lat": "-33.46149",
    "lng": "-62.43844"
  },
  {
    "country": "AR",
    "name": "Guaminí",
    "lat": "-37.03333",
    "lng": "-62.41667"
  },
  {
    "country": "AR",
    "name": "Guachipas",
    "lat": "-25.52031",
    "lng": "-65.50937"
  },
  {
    "country": "AR",
    "name": "Graneros",
    "lat": "-27.64934",
    "lng": "-65.4383"
  },
  {
    "country": "AR",
    "name": "Granadero Baigorria",
    "lat": "-32.85683",
    "lng": "-60.71754"
  },
  {
    "country": "AR",
    "name": "Godoy Cruz",
    "lat": "-32.92863",
    "lng": "-68.8351"
  },
  {
    "country": "AR",
    "name": "Gobernador Gregores",
    "lat": "-48.75057",
    "lng": "-70.24741"
  },
  {
    "country": "AR",
    "name": "Gobernador Gálvez",
    "lat": "-33.03016",
    "lng": "-60.64045"
  },
  {
    "country": "AR",
    "name": "Gobernador Costa",
    "lat": "-44.04992",
    "lng": "-70.59798"
  },
  {
    "country": "AR",
    "name": "General Villegas",
    "lat": "-35.03285",
    "lng": "-63.01252"
  },
  {
    "country": "AR",
    "name": "General Viamonte",
    "lat": "-35.00014",
    "lng": "-61.03508"
  },
  {
    "country": "AR",
    "name": "General San Martín",
    "lat": "-37.97904",
    "lng": "-63.60449"
  },
  {
    "country": "AR",
    "name": "General Roca",
    "lat": "-39.03333",
    "lng": "-67.58333"
  },
  {
    "country": "AR",
    "name": "General Roca",
    "lat": "-32.73196",
    "lng": "-61.91599"
  },
  {
    "country": "AR",
    "name": "General Ramírez",
    "lat": "-32.17601",
    "lng": "-60.20079"
  },
  {
    "country": "AR",
    "name": "General Pinto",
    "lat": "-34.76459",
    "lng": "-61.89093"
  },
  {
    "country": "AR",
    "name": "General Pinedo",
    "lat": "-27.31667",
    "lng": "-61.28333"
  },
  {
    "country": "AR",
    "name": "General Pico",
    "lat": "-35.65662",
    "lng": "-63.75682"
  },
  {
    "country": "AR",
    "name": "General Martín Miguel de Güemes",
    "lat": "-24.67034",
    "lng": "-65.04765"
  },
  {
    "country": "AR",
    "name": "General Manuel J. Campos",
    "lat": "-37.46025",
    "lng": "-63.58537"
  },
  {
    "country": "AR",
    "name": "General Levalle",
    "lat": "-34.01472",
    "lng": "-63.92413"
  },
  {
    "country": "AR",
    "name": "General Lavalle",
    "lat": "-32.72218",
    "lng": "-68.59137"
  },
  {
    "country": "AR",
    "name": "General La Madrid",
    "lat": "-37.24755",
    "lng": "-61.26273"
  },
  {
    "country": "AR",
    "name": "General Fernández Oro",
    "lat": "-38.95297",
    "lng": "-67.92489"
  },
  {
    "country": "AR",
    "name": "General Enrique Mosconi",
    "lat": "-23.21667",
    "lng": "-62.3"
  },
  {
    "country": "AR",
    "name": "General Enrique Mosconi",
    "lat": "-22.59588",
    "lng": "-63.81255"
  },
  {
    "country": "AR",
    "name": "General Enrique Godoy",
    "lat": "-39.08333",
    "lng": "-67.15"
  },
  {
    "country": "AR",
    "name": "General Conesa",
    "lat": "-40.1",
    "lng": "-64.43333"
  },
  {
    "country": "AR",
    "name": "General Cabrera",
    "lat": "-32.81313",
    "lng": "-63.87243"
  },
  {
    "country": "AR",
    "name": "General Baldissera",
    "lat": "-33.12246",
    "lng": "-62.3063"
  },
  {
    "country": "AR",
    "name": "General Arenales",
    "lat": "-34.30264",
    "lng": "-61.30522"
  },
  {
    "country": "AR",
    "name": "General Alvear",
    "lat": "-36.02078",
    "lng": "-60.0145"
  },
  {
    "country": "AR",
    "name": "General Alvear",
    "lat": "-34.97696",
    "lng": "-67.69116"
  },
  {
    "country": "AR",
    "name": "General Acha",
    "lat": "-37.37698",
    "lng": "-64.60431"
  },
  {
    "country": "AR",
    "name": "Gastre",
    "lat": "-42.27514",
    "lng": "-69.21967"
  },
  {
    "country": "AR",
    "name": "Garza",
    "lat": "-28.15321",
    "lng": "-63.53935"
  },
  {
    "country": "AR",
    "name": "Gancedo",
    "lat": "-27.49038",
    "lng": "-61.67571"
  },
  {
    "country": "AR",
    "name": "Gálvez",
    "lat": "-32.02927",
    "lng": "-61.22103"
  },
  {
    "country": "AR",
    "name": "Gaimán",
    "lat": "-43.2897",
    "lng": "-65.4929"
  },
  {
    "country": "AR",
    "name": "Funes",
    "lat": "-32.91568",
    "lng": "-60.80995"
  },
  {
    "country": "AR",
    "name": "Frías",
    "lat": "-28.63593",
    "lng": "-65.13102"
  },
  {
    "country": "AR",
    "name": "Fray Luis Beltrán",
    "lat": "-39.31667",
    "lng": "-65.76667"
  },
  {
    "country": "AR",
    "name": "Fray Luis A. Beltrán",
    "lat": "-32.79122",
    "lng": "-60.72819"
  },
  {
    "country": "AR",
    "name": "Fraile Pintado",
    "lat": "-23.94079",
    "lng": "-64.79943"
  },
  {
    "country": "AR",
    "name": "Firmat",
    "lat": "-33.45937",
    "lng": "-61.4832"
  },
  {
    "country": "AR",
    "name": "Fiambalá",
    "lat": "-27.68705",
    "lng": "-67.6149"
  },
  {
    "country": "AR",
    "name": "Fernández",
    "lat": "-27.92037",
    "lng": "-63.89349"
  },
  {
    "country": "AR",
    "name": "Famatina",
    "lat": "-28.92322",
    "lng": "-67.52253"
  },
  {
    "country": "AR",
    "name": "Famaillá",
    "lat": "-27.05413",
    "lng": "-65.40329"
  },
  {
    "country": "AR",
    "name": "Etruria",
    "lat": "-32.94008",
    "lng": "-63.2466"
  },
  {
    "country": "AR",
    "name": "Estanislao del Campo",
    "lat": "-25.05504",
    "lng": "-60.09218"
  },
  {
    "country": "AR",
    "name": "Esquel",
    "lat": "-42.91147",
    "lng": "-71.31947"
  },
  {
    "country": "AR",
    "name": "Esperanza",
    "lat": "-31.4488",
    "lng": "-60.93173"
  },
  {
    "country": "AR",
    "name": "Embarcación",
    "lat": "-23.21003",
    "lng": "-64.09965"
  },
  {
    "country": "AR",
    "name": "Embalse",
    "lat": "-32.18",
    "lng": "-64.41809"
  },
  {
    "country": "AR",
    "name": "Embajador Martini",
    "lat": "-35.38633",
    "lng": "-64.28092"
  },
  {
    "country": "AR",
    "name": "El Trébol",
    "lat": "-32.2008",
    "lng": "-61.7014"
  },
  {
    "country": "AR",
    "name": "El Tío",
    "lat": "-31.38357",
    "lng": "-62.82938"
  },
  {
    "country": "AR",
    "name": "El Simbolar",
    "lat": "-27.97167",
    "lng": "-64.89544"
  },
  {
    "country": "AR",
    "name": "El Rodeo",
    "lat": "-28.21518",
    "lng": "-65.8742"
  },
  {
    "country": "AR",
    "name": "El Quebrachal",
    "lat": "-25.28333",
    "lng": "-64.06667"
  },
  {
    "country": "AR",
    "name": "El Maitén",
    "lat": "-42.04924",
    "lng": "-71.16693"
  },
  {
    "country": "AR",
    "name": "El Huecú",
    "lat": "-37.64522",
    "lng": "-70.58006"
  },
  {
    "country": "AR",
    "name": "El Hoyo",
    "lat": "-27.02872",
    "lng": "-63.23197"
  },
  {
    "country": "AR",
    "name": "El Galpón",
    "lat": "-25.38069",
    "lng": "-64.65259"
  },
  {
    "country": "AR",
    "name": "Elena",
    "lat": "-32.57205",
    "lng": "-64.39481"
  },
  {
    "country": "AR",
    "name": "El Cuy",
    "lat": "-39.92685",
    "lng": "-68.34208"
  },
  {
    "country": "AR",
    "name": "El Carril",
    "lat": "-25.0741",
    "lng": "-65.49174"
  },
  {
    "country": "AR",
    "name": "El Carmen",
    "lat": "-24.38682",
    "lng": "-65.26177"
  },
  {
    "country": "AR",
    "name": "El Calafate",
    "lat": "-50.34075",
    "lng": "-72.27682"
  },
  {
    "country": "AR",
    "name": "El Bolsón",
    "lat": "-41.96051",
    "lng": "-71.53336"
  },
  {
    "country": "AR",
    "name": "El Arañado",
    "lat": "-31.7412",
    "lng": "-62.89322"
  },
  {
    "country": "AR",
    "name": "El Alto",
    "lat": "-28.31123",
    "lng": "-65.36397"
  },
  {
    "country": "AR",
    "name": "El Aguilar",
    "lat": "-23.22582",
    "lng": "-65.69213"
  },
  {
    "country": "AR",
    "name": "Eduardo Castex",
    "lat": "-35.91501",
    "lng": "-64.29448"
  },
  {
    "country": "AR",
    "name": "Dolavón",
    "lat": "-43.3",
    "lng": "-65.7"
  },
  {
    "country": "AR",
    "name": "Doblas",
    "lat": "-37.14967",
    "lng": "-64.01183"
  },
  {
    "country": "AR",
    "name": "Diamante",
    "lat": "-32.06641",
    "lng": "-60.63837"
  },
  {
    "country": "AR",
    "name": "Devoto",
    "lat": "-31.40431",
    "lng": "-62.30634"
  },
  {
    "country": "AR",
    "name": "Despeñaderos",
    "lat": "-31.81626",
    "lng": "-64.28989"
  },
  {
    "country": "AR",
    "name": "Del Campillo",
    "lat": "-34.37659",
    "lng": "-64.49504"
  },
  {
    "country": "AR",
    "name": "Deán Funes",
    "lat": "-30.42036",
    "lng": "-64.34984"
  },
  {
    "country": "AR",
    "name": "Darwin",
    "lat": "-39.2",
    "lng": "-65.76667"
  },
  {
    "country": "AR",
    "name": "Dalmacio Vélez Sársfield",
    "lat": "-32.61072",
    "lng": "-63.58038"
  },
  {
    "country": "AR",
    "name": "Daireaux",
    "lat": "-36.6",
    "lng": "-61.75"
  },
  {
    "country": "AR",
    "name": "Cutral-Có",
    "lat": "-38.93424",
    "lng": "-69.23052"
  },
  {
    "country": "AR",
    "name": "Cuchillo Có",
    "lat": "-38.33349",
    "lng": "-64.64331"
  },
  {
    "country": "AR",
    "name": "Cruz del Eje",
    "lat": "-30.72644",
    "lng": "-64.80387"
  },
  {
    "country": "AR",
    "name": "Cruz Alta",
    "lat": "-33.00887",
    "lng": "-61.80746"
  },
  {
    "country": "AR",
    "name": "Crespo",
    "lat": "-32.02873",
    "lng": "-60.30658"
  },
  {
    "country": "AR",
    "name": "Costa Sacate",
    "lat": "-31.6477",
    "lng": "-63.75935"
  },
  {
    "country": "AR",
    "name": "Cosquín",
    "lat": "-31.24508",
    "lng": "-64.46563"
  },
  {
    "country": "AR",
    "name": "Corzuela",
    "lat": "-26.95374",
    "lng": "-60.96928"
  },
  {
    "country": "AR",
    "name": "Corralito",
    "lat": "-32.02462",
    "lng": "-64.19216"
  },
  {
    "country": "AR",
    "name": "Corral de Bustos",
    "lat": "-33.28205",
    "lng": "-62.18463"
  },
  {
    "country": "AR",
    "name": "Coronel Suárez",
    "lat": "-37.45467",
    "lng": "-61.93343"
  },
  {
    "country": "AR",
    "name": "Coronel Pringles",
    "lat": "-37.98295",
    "lng": "-61.35615"
  },
  {
    "country": "AR",
    "name": "Coronel Moldes",
    "lat": "-33.6227",
    "lng": "-64.59711"
  },
  {
    "country": "AR",
    "name": "Coronel Du Graty",
    "lat": "-27.68038",
    "lng": "-60.91462"
  },
  {
    "country": "AR",
    "name": "Coronel Dorrego",
    "lat": "-38.71867",
    "lng": "-61.28733"
  },
  {
    "country": "AR",
    "name": "Coronel Belisle",
    "lat": "-39.18333",
    "lng": "-65.98333"
  },
  {
    "country": "AR",
    "name": "Coronel Baigorria",
    "lat": "-32.8477",
    "lng": "-64.36107"
  },
  {
    "country": "AR",
    "name": "Coronda",
    "lat": "-31.97263",
    "lng": "-60.91983"
  },
  {
    "country": "AR",
    "name": "Córdoba",
    "lat": "-31.4135",
    "lng": "-64.18105"
  },
  {
    "country": "AR",
    "name": "Contraalmirante Cordero",
    "lat": "-38.72423",
    "lng": "-68.15284"
  },
  {
    "country": "AR",
    "name": "Concepción del Bermejo",
    "lat": "-26.59926",
    "lng": "-60.94617"
  },
  {
    "country": "AR",
    "name": "Concepción",
    "lat": "-27.34127",
    "lng": "-65.59636"
  },
  {
    "country": "AR",
    "name": "Concarán",
    "lat": "-32.56009",
    "lng": "-65.2427"
  },
  {
    "country": "AR",
    "name": "Comodoro Rivadavia",
    "lat": "-45.86413",
    "lng": "-67.49656"
  },
  {
    "country": "AR",
    "name": "Comandante Luis Piedra Buena",
    "lat": "-49.98513",
    "lng": "-68.91467"
  },
  {
    "country": "AR",
    "name": "Comallo",
    "lat": "-41.02993",
    "lng": "-70.26784"
  },
  {
    "country": "AR",
    "name": "Colonia San Bartolomé",
    "lat": "-31.5278",
    "lng": "-62.72436"
  },
  {
    "country": "AR",
    "name": "Colonia La Tordilla",
    "lat": "-31.23746",
    "lng": "-63.06134"
  },
  {
    "country": "AR",
    "name": "Colonia Dora",
    "lat": "-28.6",
    "lng": "-62.95"
  },
  {
    "country": "AR",
    "name": "Colonia Barón",
    "lat": "-36.15152",
    "lng": "-63.85404"
  },
  {
    "country": "AR",
    "name": "Colón",
    "lat": "-33.89512",
    "lng": "-61.1011"
  },
  {
    "country": "AR",
    "name": "Clodomira",
    "lat": "-27.5744",
    "lng": "-64.13108"
  },
  {
    "country": "AR",
    "name": "Cipolletti",
    "lat": "-38.93392",
    "lng": "-67.99032"
  },
  {
    "country": "AR",
    "name": "Cintra",
    "lat": "-32.30673",
    "lng": "-62.65214"
  },
  {
    "country": "AR",
    "name": "Cinco Saltos",
    "lat": "-38.82225",
    "lng": "-68.06293"
  },
  {
    "country": "AR",
    "name": "Chumbicha",
    "lat": "-28.8543",
    "lng": "-66.235"
  },
  {
    "country": "AR",
    "name": "Chos Malal",
    "lat": "-37.37809",
    "lng": "-70.27085"
  },
  {
    "country": "AR",
    "name": "Chorotis",
    "lat": "-27.91578",
    "lng": "-61.39982"
  },
  {
    "country": "AR",
    "name": "Choele Choel",
    "lat": "-39.26667",
    "lng": "-65.68333"
  },
  {
    "country": "AR",
    "name": "Chivilcoy",
    "lat": "-34.89566",
    "lng": "-60.01667"
  },
  {
    "country": "AR",
    "name": "Chimpay",
    "lat": "-39.16482",
    "lng": "-66.14236"
  },
  {
    "country": "AR",
    "name": "Chimbas",
    "lat": "-31.48333",
    "lng": "-68.53333"
  },
  {
    "country": "AR",
    "name": "Chilecito",
    "lat": "-29.16195",
    "lng": "-67.4974"
  },
  {
    "country": "AR",
    "name": "Chicoana",
    "lat": "-25.10088",
    "lng": "-65.5331"
  },
  {
    "country": "AR",
    "name": "Chichinales",
    "lat": "-39.11505",
    "lng": "-66.92714"
  },
  {
    "country": "AR",
    "name": "Chepes",
    "lat": "-31.35",
    "lng": "-66.6"
  },
  {
    "country": "AR",
    "name": "Chazón",
    "lat": "-33.07872",
    "lng": "-63.27657"
  },
  {
    "country": "AR",
    "name": "Charras",
    "lat": "-33.024",
    "lng": "-64.04719"
  },
  {
    "country": "AR",
    "name": "Charata",
    "lat": "-27.21438",
    "lng": "-61.18795"
  },
  {
    "country": "AR",
    "name": "Chamical",
    "lat": "-30.36002",
    "lng": "-66.31399"
  },
  {
    "country": "AR",
    "name": "Chacabuco",
    "lat": "-34.64167",
    "lng": "-60.47389"
  },
  {
    "country": "AR",
    "name": "Cervantes",
    "lat": "-39.05",
    "lng": "-67.38333"
  },
  {
    "country": "AR",
    "name": "Cerrillos",
    "lat": "-24.89833",
    "lng": "-65.48706"
  },
  {
    "country": "AR",
    "name": "Ceres",
    "lat": "-29.881",
    "lng": "-61.94504"
  },
  {
    "country": "AR",
    "name": "Centenario",
    "lat": "-38.82955",
    "lng": "-68.1318"
  },
  {
    "country": "AR",
    "name": "Cavanagh",
    "lat": "-33.47606",
    "lng": "-62.33888"
  },
  {
    "country": "AR",
    "name": "Caucete",
    "lat": "-31.65179",
    "lng": "-68.28105"
  },
  {
    "country": "AR",
    "name": "Catriló",
    "lat": "-36.40597",
    "lng": "-63.42168"
  },
  {
    "country": "AR",
    "name": "Catriel",
    "lat": "-37.87907",
    "lng": "-67.7956"
  },
  {
    "country": "AR",
    "name": "Castro Barros",
    "lat": "-30.57952",
    "lng": "-65.72696"
  },
  {
    "country": "AR",
    "name": "Castelli",
    "lat": "-25.94679",
    "lng": "-60.61947"
  },
  {
    "country": "AR",
    "name": "Casilda",
    "lat": "-33.04417",
    "lng": "-61.16806"
  },
  {
    "country": "AR",
    "name": "Carrilobo",
    "lat": "-31.87296",
    "lng": "-63.11715"
  },
  {
    "country": "AR",
    "name": "Carnerillo",
    "lat": "-32.91371",
    "lng": "-64.02175"
  },
  {
    "country": "AR",
    "name": "Carmen de Patagones",
    "lat": "-40.79828",
    "lng": "-62.98097"
  },
  {
    "country": "AR",
    "name": "Carlos Tejedor",
    "lat": "-35.39265",
    "lng": "-62.42146"
  },
  {
    "country": "AR",
    "name": "Carlos Casares",
    "lat": "-35.62171",
    "lng": "-61.36169"
  },
  {
    "country": "AR",
    "name": "Carhué",
    "lat": "-37.17668",
    "lng": "-62.75792"
  },
  {
    "country": "AR",
    "name": "Carcarañá",
    "lat": "-32.85679",
    "lng": "-61.15331"
  },
  {
    "country": "AR",
    "name": "Capitán Bermúdez",
    "lat": "-32.82262",
    "lng": "-60.71852"
  },
  {
    "country": "AR",
    "name": "Capilla del Monte",
    "lat": "-30.86088",
    "lng": "-64.52515"
  },
  {
    "country": "AR",
    "name": "Capayán",
    "lat": "-28.76105",
    "lng": "-66.05025"
  },
  {
    "country": "AR",
    "name": "Candelaria",
    "lat": "-32.06036",
    "lng": "-65.82477"
  },
  {
    "country": "AR",
    "name": "Canals",
    "lat": "-33.56542",
    "lng": "-62.88927"
  },
  {
    "country": "AR",
    "name": "Cañada de Luque",
    "lat": "-30.73341",
    "lng": "-63.72375"
  },
  {
    "country": "AR",
    "name": "Cañada de Gómez",
    "lat": "-32.81636",
    "lng": "-61.39493"
  },
  {
    "country": "AR",
    "name": "Campo Quijano",
    "lat": "-24.90982",
    "lng": "-65.63656"
  },
  {
    "country": "AR",
    "name": "Campo Largo",
    "lat": "-26.80077",
    "lng": "-60.84215"
  },
  {
    "country": "AR",
    "name": "Campo Gallo",
    "lat": "-26.58333",
    "lng": "-62.85"
  },
  {
    "country": "AR",
    "name": "Camilo Aldao",
    "lat": "-33.12745",
    "lng": "-62.09453"
  },
  {
    "country": "AR",
    "name": "Camarones",
    "lat": "-44.79709",
    "lng": "-65.70994"
  },
  {
    "country": "AR",
    "name": "Calingasta",
    "lat": "-31.33394",
    "lng": "-69.4208"
  },
  {
    "country": "AR",
    "name": "Calilegua",
    "lat": "-23.77368",
    "lng": "-64.77002"
  },
  {
    "country": "AR",
    "name": "Caleufú",
    "lat": "-35.59559",
    "lng": "-64.55778"
  },
  {
    "country": "AR",
    "name": "Caleta Olivia",
    "lat": "-46.43929",
    "lng": "-67.52814"
  },
  {
    "country": "AR",
    "name": "Calchaquí",
    "lat": "-29.88767",
    "lng": "-60.28697"
  },
  {
    "country": "AR",
    "name": "Caimancito",
    "lat": "-23.74069",
    "lng": "-64.5937"
  },
  {
    "country": "AR",
    "name": "Cafayate",
    "lat": "-26.07286",
    "lng": "-65.97766"
  },
  {
    "country": "AR",
    "name": "Cachí",
    "lat": "-25.12033",
    "lng": "-66.16519"
  },
  {
    "country": "AR",
    "name": "Buta Ranquil",
    "lat": "-37.05222",
    "lng": "-69.87713"
  },
  {
    "country": "AR",
    "name": "Burruyacú",
    "lat": "-26.49918",
    "lng": "-64.74206"
  },
  {
    "country": "AR",
    "name": "Buena Esperanza",
    "lat": "-34.75647",
    "lng": "-65.25379"
  },
  {
    "country": "AR",
    "name": "Buchardo",
    "lat": "-34.72263",
    "lng": "-63.5092"
  },
  {
    "country": "AR",
    "name": "Brinkmann",
    "lat": "-30.86589",
    "lng": "-62.03742"
  },
  {
    "country": "AR",
    "name": "Brea Pozo",
    "lat": "-28.24382",
    "lng": "-63.95091"
  },
  {
    "country": "AR",
    "name": "Bragado",
    "lat": "-35.11912",
    "lng": "-60.48966"
  },
  {
    "country": "AR",
    "name": "Berrotarán",
    "lat": "-32.451",
    "lng": "-64.38867"
  },
  {
    "country": "AR",
    "name": "Bernasconi",
    "lat": "-37.90459",
    "lng": "-63.7424"
  },
  {
    "country": "AR",
    "name": "Bernardo Larroudé",
    "lat": "-35.02449",
    "lng": "-63.58253"
  },
  {
    "country": "AR",
    "name": "Beltrán",
    "lat": "-27.82913",
    "lng": "-64.06098"
  },
  {
    "country": "AR",
    "name": "Bell Ville",
    "lat": "-32.62591",
    "lng": "-62.68873"
  },
  {
    "country": "AR",
    "name": "Bella Vista",
    "lat": "-27.03424",
    "lng": "-65.30196"
  },
  {
    "country": "AR",
    "name": "Belén",
    "lat": "-27.65103",
    "lng": "-67.02869"
  },
  {
    "country": "AR",
    "name": "Barrancas",
    "lat": "-36.81667",
    "lng": "-69.91667"
  },
  {
    "country": "AR",
    "name": "Bandera",
    "lat": "-28.8884",
    "lng": "-62.266"
  },
  {
    "country": "AR",
    "name": "Banda del Río Salí",
    "lat": "-26.83333",
    "lng": "-65.16667"
  },
  {
    "country": "AR",
    "name": "Bañado de Ovanta",
    "lat": "-28.10564",
    "lng": "-65.31884"
  },
  {
    "country": "AR",
    "name": "Balnearia",
    "lat": "-31.0088",
    "lng": "-62.66733"
  },
  {
    "country": "AR",
    "name": "Bahía Blanca",
    "lat": "-38.71959",
    "lng": "-62.27243"
  },
  {
    "country": "AR",
    "name": "Aviá Terai",
    "lat": "-26.68532",
    "lng": "-60.7292"
  },
  {
    "country": "AR",
    "name": "Arrufó",
    "lat": "-30.23281",
    "lng": "-61.72862"
  },
  {
    "country": "AR",
    "name": "Arroyo Seco",
    "lat": "-33.15489",
    "lng": "-60.50863"
  },
  {
    "country": "AR",
    "name": "Arroyo Cabral",
    "lat": "-32.49119",
    "lng": "-63.40126"
  },
  {
    "country": "AR",
    "name": "Arroyito",
    "lat": "-31.42022",
    "lng": "-63.05002"
  },
  {
    "country": "AR",
    "name": "Arrecifes",
    "lat": "-34.0639",
    "lng": "-60.10357"
  },
  {
    "country": "AR",
    "name": "Arraga",
    "lat": "-28.04978",
    "lng": "-64.22254"
  },
  {
    "country": "AR",
    "name": "Armstrong",
    "lat": "-32.78215",
    "lng": "-61.60222"
  },
  {
    "country": "AR",
    "name": "Arias",
    "lat": "-33.64411",
    "lng": "-62.40272"
  },
  {
    "country": "AR",
    "name": "Arauco",
    "lat": "-28.5805",
    "lng": "-66.79438"
  },
  {
    "country": "AR",
    "name": "Arata",
    "lat": "-35.63895",
    "lng": "-64.35621"
  },
  {
    "country": "AR",
    "name": "Aranguren",
    "lat": "-32.24252",
    "lng": "-60.16107"
  },
  {
    "country": "AR",
    "name": "Apolinario Saravia",
    "lat": "-24.43276",
    "lng": "-63.99535"
  },
  {
    "country": "AR",
    "name": "Antofagasta de la Sierra",
    "lat": "-26.0594",
    "lng": "-67.40636"
  },
  {
    "country": "AR",
    "name": "Anguil",
    "lat": "-36.52567",
    "lng": "-64.01025"
  },
  {
    "country": "AR",
    "name": "Añelo",
    "lat": "-38.35441",
    "lng": "-68.7884"
  },
  {
    "country": "AR",
    "name": "Andalgalá",
    "lat": "-27.60012",
    "lng": "-66.31794"
  },
  {
    "country": "AR",
    "name": "Andacollo",
    "lat": "-37.17945",
    "lng": "-70.66912"
  },
  {
    "country": "AR",
    "name": "Ancasti",
    "lat": "-28.81247",
    "lng": "-65.50145"
  },
  {
    "country": "AR",
    "name": "Añatuya",
    "lat": "-28.46064",
    "lng": "-62.83472"
  },
  {
    "country": "AR",
    "name": "Aminga",
    "lat": "-28.8426",
    "lng": "-66.94546"
  },
  {
    "country": "AR",
    "name": "Florentino Ameghino",
    "lat": "-34.84405",
    "lng": "-62.46701"
  },
  {
    "country": "AR",
    "name": "Aluminé",
    "lat": "-39.23686",
    "lng": "-70.9197"
  },
  {
    "country": "AR",
    "name": "Altos de Chipión",
    "lat": "-30.9559",
    "lng": "-62.33727"
  },
  {
    "country": "AR",
    "name": "Alto Río Senguer",
    "lat": "-45.04105",
    "lng": "-70.81982"
  },
  {
    "country": "AR",
    "name": "Alta Italia",
    "lat": "-35.3335",
    "lng": "-64.11496"
  },
  {
    "country": "AR",
    "name": "Alta Gracia",
    "lat": "-31.65292",
    "lng": "-64.42826"
  },
  {
    "country": "AR",
    "name": "Alpachiri",
    "lat": "-37.37704",
    "lng": "-63.77445"
  },
  {
    "country": "AR",
    "name": "Almafuerte",
    "lat": "-32.19296",
    "lng": "-64.25559"
  },
  {
    "country": "AR",
    "name": "Allen",
    "lat": "-38.97736",
    "lng": "-67.82714"
  },
  {
    "country": "AR",
    "name": "Algarrobo del Águila",
    "lat": "-36.39968",
    "lng": "-67.14511"
  },
  {
    "country": "AR",
    "name": "Alejo Ledesma",
    "lat": "-33.60643",
    "lng": "-62.62304"
  },
  {
    "country": "AR",
    "name": "Alejandro Roca",
    "lat": "-33.35369",
    "lng": "-63.71849"
  },
  {
    "country": "AR",
    "name": "Alderetes",
    "lat": "-26.81667",
    "lng": "-65.13333"
  },
  {
    "country": "AR",
    "name": "Alberti",
    "lat": "-35.02692",
    "lng": "-60.27587"
  },
  {
    "country": "AR",
    "name": "Albardón",
    "lat": "-31.43722",
    "lng": "-68.52556"
  },
  {
    "country": "AR",
    "name": "Aimogasta",
    "lat": "-28.56091",
    "lng": "-66.80588"
  },
  {
    "country": "AR",
    "name": "Aguilares",
    "lat": "-27.4338",
    "lng": "-65.61427"
  },
  {
    "country": "AR",
    "name": "Agua de Oro",
    "lat": "-31.06661",
    "lng": "-64.30017"
  },
  {
    "country": "AR",
    "name": "Adelia María",
    "lat": "-33.63152",
    "lng": "-64.02097"
  },
  {
    "country": "AR",
    "name": "Achiras",
    "lat": "-33.17538",
    "lng": "-64.99331"
  },
  {
    "country": "AR",
    "name": "Abra Pampa",
    "lat": "-22.72049",
    "lng": "-65.69697"
  },
  {
    "country": "AR",
    "name": "Balvanera",
    "lat": "-34.61032",
    "lng": "-58.39766"
  },
  {
    "country": "AR",
    "name": "Villa Santa Rita",
    "lat": "-34.61082",
    "lng": "-58.481"
  },
  {
    "country": "AR",
    "name": "Bella Italia",
    "lat": "-31.27268",
    "lng": "-61.42396"
  },
  {
    "country": "AR",
    "name": "Cariló",
    "lat": "-37.16524",
    "lng": "-56.89133"
  },
  {
    "country": "AR",
    "name": "Villa Mercedes",
    "lat": "-33.67571",
    "lng": "-65.45783"
  },
  {
    "country": "AR",
    "name": "La Punta",
    "lat": "-33.18368",
    "lng": "-66.3127"
  },
  {
    "country": "AR",
    "name": "Villa Berna",
    "lat": "-31.90321",
    "lng": "-64.75651"
  },
  {
    "country": "AR",
    "name": "Cuesta Blanca",
    "lat": "-31.48658",
    "lng": "-64.5715"
  },
  {
    "country": "AR",
    "name": "Avellaneda",
    "lat": "-34.66018",
    "lng": "-58.36744"
  },
  {
    "country": "AR",
    "name": "San Carlos de Bariloche",
    "lat": "-41.14557",
    "lng": "-71.30822"
  },
  {
    "country": "AR",
    "name": "Santa Catalina - Dique Lujan",
    "lat": "-34.38375",
    "lng": "-58.70673"
  },
  {
    "country": "AR",
    "name": "Río Turbio",
    "lat": "-51.53587",
    "lng": "-72.33673"
  },
  {
    "country": "AR",
    "name": "Adrogué",
    "lat": "-34.80041",
    "lng": "-58.38384"
  },
  {
    "country": "AR",
    "name": "Los Laureles",
    "lat": "-29.36847",
    "lng": "-59.73634"
  },
  {
    "country": "AR",
    "name": "Gato Colorado",
    "lat": "-28.02219",
    "lng": "-61.18663"
  },
  {
    "country": "AR",
    "name": "Tolhuin",
    "lat": "-54.51083",
    "lng": "-67.1955"
  },
  {
    "country": "AR",
    "name": "Villa General Guemes",
    "lat": "-24.7553",
    "lng": "-59.4894"
  },
  {
    "country": "AR",
    "name": "Rincón de Los Sauces",
    "lat": "-37.39844",
    "lng": "-68.92874"
  },
  {
    "country": "AR",
    "name": "La Adela",
    "lat": "-38.98333",
    "lng": "-64.08333"
  },
  {
    "country": "AS",
    "name": "Aūa",
    "lat": "-14.27611",
    "lng": "-170.66389"
  },
  {
    "country": "AS",
    "name": "Vaitogi",
    "lat": "-14.35889",
    "lng": "-170.73472"
  },
  {
    "country": "AS",
    "name": "Vailoatai",
    "lat": "-14.36111",
    "lng": "-170.78222"
  },
  {
    "country": "AS",
    "name": "Taulaga",
    "lat": "-11.05528",
    "lng": "-171.08833"
  },
  {
    "country": "AS",
    "name": "Ta`ū",
    "lat": "-14.23361",
    "lng": "-169.51444"
  },
  {
    "country": "AS",
    "name": "Tāfuna",
    "lat": "-14.33583",
    "lng": "-170.72"
  },
  {
    "country": "AS",
    "name": "Faleniu",
    "lat": "-14.3325",
    "lng": "-170.74444"
  },
  {
    "country": "AS",
    "name": "Fagatogo",
    "lat": "-14.2825",
    "lng": "-170.69"
  },
  {
    "country": "AS",
    "name": "Faleāsao",
    "lat": "-14.2222",
    "lng": "-169.51278"
  },
  {
    "country": "AS",
    "name": "Leone",
    "lat": "-14.34389",
    "lng": "-170.785"
  },
  {
    "country": "AS",
    "name": "Malaeimi",
    "lat": "-14.32278",
    "lng": "-170.73389"
  },
  {
    "country": "AS",
    "name": "Mapusagafou",
    "lat": "-14.33056",
    "lng": "-170.75278"
  },
  {
    "country": "AS",
    "name": "Ofu",
    "lat": "-14.17528",
    "lng": "-169.6775"
  },
  {
    "country": "AS",
    "name": "Pago Pago",
    "lat": "-14.27806",
    "lng": "-170.7025"
  },
  {
    "country": "AT",
    "name": "Neu-Guntramsdorf",
    "lat": "48.0642",
    "lng": "16.31573"
  },
  {
    "country": "AT",
    "name": "Kleinarl",
    "lat": "47.27725",
    "lng": "13.31955"
  },
  {
    "country": "AT",
    "name": "Edelstauden",
    "lat": "46.98333",
    "lng": "15.61667"
  },
  {
    "country": "AT",
    "name": "Neuhaus am Klausenbach",
    "lat": "46.86667",
    "lng": "16.03333"
  },
  {
    "country": "AT",
    "name": "Millstatt",
    "lat": "46.80417",
    "lng": "13.58056"
  },
  {
    "country": "AT",
    "name": "Zwölfaxing",
    "lat": "48.1099",
    "lng": "16.46267"
  },
  {
    "country": "AT",
    "name": "Zwettl Stadt",
    "lat": "48.60726",
    "lng": "15.16714"
  },
  {
    "country": "AT",
    "name": "Zwettl an der Rodl",
    "lat": "48.46552",
    "lng": "14.27133"
  },
  {
    "country": "AT",
    "name": "Zwentendorf",
    "lat": "48.3453",
    "lng": "15.91026"
  },
  {
    "country": "AT",
    "name": "Zurndorf",
    "lat": "47.98314",
    "lng": "17.00315"
  },
  {
    "country": "AT",
    "name": "Zöblen",
    "lat": "47.50772",
    "lng": "10.47971"
  },
  {
    "country": "AT",
    "name": "Zöbern",
    "lat": "47.51459",
    "lng": "16.13111"
  },
  {
    "country": "AT",
    "name": "Zistersdorf",
    "lat": "48.54252",
    "lng": "16.76136"
  },
  {
    "country": "AT",
    "name": "Zirl",
    "lat": "47.2741",
    "lng": "11.23961"
  },
  {
    "country": "AT",
    "name": "Zillingtal",
    "lat": "47.81442",
    "lng": "16.40928"
  },
  {
    "country": "AT",
    "name": "Zillingdorf",
    "lat": "47.85",
    "lng": "16.33333"
  },
  {
    "country": "AT",
    "name": "Ziersdorf",
    "lat": "48.5303",
    "lng": "15.92691"
  },
  {
    "country": "AT",
    "name": "Zeutschach",
    "lat": "47.06667",
    "lng": "14.36667"
  },
  {
    "country": "AT",
    "name": "Zettling",
    "lat": "46.9522",
    "lng": "15.4342"
  },
  {
    "country": "AT",
    "name": "Zerlach",
    "lat": "46.94593",
    "lng": "15.65093"
  },
  {
    "country": "AT",
    "name": "Zeltweg",
    "lat": "47.18333",
    "lng": "14.75"
  },
  {
    "country": "AT",
    "name": "Zellerndorf",
    "lat": "48.69657",
    "lng": "15.95841"
  },
  {
    "country": "AT",
    "name": "Zellberg",
    "lat": "47.23333",
    "lng": "11.85"
  },
  {
    "country": "AT",
    "name": "Zell an der Pram",
    "lat": "48.31625",
    "lng": "13.62923"
  },
  {
    "country": "AT",
    "name": "Zell am Ziller",
    "lat": "47.23333",
    "lng": "11.88333"
  },
  {
    "country": "AT",
    "name": "Zell am See",
    "lat": "47.32556",
    "lng": "12.79444"
  },
  {
    "country": "AT",
    "name": "Zell am Pettenfirst",
    "lat": "48.08009",
    "lng": "13.59936"
  },
  {
    "country": "AT",
    "name": "Zell am Moos",
    "lat": "47.9",
    "lng": "13.31667"
  },
  {
    "country": "AT",
    "name": "Zell",
    "lat": "47.58333",
    "lng": "12.15"
  },
  {
    "country": "AT",
    "name": "Zeiselmauer",
    "lat": "48.32852",
    "lng": "16.17565"
  },
  {
    "country": "AT",
    "name": "Zeillern",
    "lat": "48.13029",
    "lng": "14.8076"
  },
  {
    "country": "AT",
    "name": "Zederhaus",
    "lat": "47.1557",
    "lng": "13.50576"
  },
  {
    "country": "AT",
    "name": "Zams",
    "lat": "47.15844",
    "lng": "10.5897"
  },
  {
    "country": "AT",
    "name": "Zagersdorf",
    "lat": "47.76471",
    "lng": "16.51382"
  },
  {
    "country": "AT",
    "name": "Ybbsitz",
    "lat": "47.94745",
    "lng": "14.8918"
  },
  {
    "country": "AT",
    "name": "Ybbs an der Donau",
    "lat": "48.16667",
    "lng": "15.08333"
  },
  {
    "country": "AT",
    "name": "Würmla",
    "lat": "48.25497",
    "lng": "15.86031"
  },
  {
    "country": "AT",
    "name": "Würflach",
    "lat": "47.77648",
    "lng": "16.05463"
  },
  {
    "country": "AT",
    "name": "Wundschuh",
    "lat": "46.92639",
    "lng": "15.45111"
  },
  {
    "country": "AT",
    "name": "Wullersdorf",
    "lat": "48.62792",
    "lng": "16.10089"
  },
  {
    "country": "AT",
    "name": "Wulkaprodersdorf",
    "lat": "47.79753",
    "lng": "16.50447"
  },
  {
    "country": "AT",
    "name": "Wörth an der Lafnitz",
    "lat": "47.21368",
    "lng": "16.08081"
  },
  {
    "country": "AT",
    "name": "Wörterberg",
    "lat": "47.21667",
    "lng": "16.1"
  },
  {
    "country": "AT",
    "name": "Wörschach",
    "lat": "47.55",
    "lng": "14.15"
  },
  {
    "country": "AT",
    "name": "Wörgl",
    "lat": "47.48906",
    "lng": "12.06174"
  },
  {
    "country": "AT",
    "name": "Wördern",
    "lat": "48.334",
    "lng": "16.21016"
  },
  {
    "country": "AT",
    "name": "Wöllersdorf",
    "lat": "47.865",
    "lng": "16.17119"
  },
  {
    "country": "AT",
    "name": "Wolkersdorf im Weinviertel",
    "lat": "48.38333",
    "lng": "16.51667"
  },
  {
    "country": "AT",
    "name": "Wolfurt",
    "lat": "47.46667",
    "lng": "9.75"
  },
  {
    "country": "AT",
    "name": "Wolfsthal",
    "lat": "48.13333",
    "lng": "17"
  },
  {
    "country": "AT",
    "name": "Wolfsgraben",
    "lat": "48.1587",
    "lng": "16.12098"
  },
  {
    "country": "AT",
    "name": "Wolfsegg am Hausruck",
    "lat": "48.10669",
    "lng": "13.67274"
  },
  {
    "country": "AT",
    "name": "Wolfsberg im Schwarzautal",
    "lat": "46.84389",
    "lng": "15.65889"
  },
  {
    "country": "AT",
    "name": "Wolfsberg",
    "lat": "46.84056",
    "lng": "14.84417"
  },
  {
    "country": "AT",
    "name": "Wolfsbach",
    "lat": "48.06667",
    "lng": "14.66667"
  },
  {
    "country": "AT",
    "name": "Wolfpassing",
    "lat": "48.07785",
    "lng": "15.06453"
  },
  {
    "country": "AT",
    "name": "Wölfnitz",
    "lat": "46.66639",
    "lng": "14.25806"
  },
  {
    "country": "AT",
    "name": "Wolfau",
    "lat": "47.25",
    "lng": "16.1"
  },
  {
    "country": "AT",
    "name": "Wippenham",
    "lat": "48.2225",
    "lng": "13.3792"
  },
  {
    "country": "AT",
    "name": "Winzendorf",
    "lat": "47.81154",
    "lng": "16.113"
  },
  {
    "country": "AT",
    "name": "Winklern bei Oberwölz",
    "lat": "47.2",
    "lng": "14.23333"
  },
  {
    "country": "AT",
    "name": "Winklern",
    "lat": "46.87361",
    "lng": "12.87472"
  },
  {
    "country": "AT",
    "name": "Winklarn",
    "lat": "48.09135",
    "lng": "14.84819"
  },
  {
    "country": "AT",
    "name": "Windischgarsten",
    "lat": "47.72223",
    "lng": "14.32755"
  },
  {
    "country": "AT",
    "name": "Windigsteig",
    "lat": "48.76667",
    "lng": "15.28333"
  },
  {
    "country": "AT",
    "name": "Windhag",
    "lat": "47.97906",
    "lng": "14.80245"
  },
  {
    "country": "AT",
    "name": "Windhaag bei Perg",
    "lat": "48.28582",
    "lng": "14.68091"
  },
  {
    "country": "AT",
    "name": "Windhaag bei Freistadt",
    "lat": "48.58774",
    "lng": "14.56186"
  },
  {
    "country": "AT",
    "name": "Winden am See",
    "lat": "47.95",
    "lng": "16.75"
  },
  {
    "country": "AT",
    "name": "Wimpassing an der Leitha",
    "lat": "47.91667",
    "lng": "16.43333"
  },
  {
    "country": "AT",
    "name": "Wimpassing",
    "lat": "48.16667",
    "lng": "13.98333"
  },
  {
    "country": "AT",
    "name": "Wimpassing im Schwarzatale",
    "lat": "47.70295",
    "lng": "16.03334"
  },
  {
    "country": "AT",
    "name": "Wilten",
    "lat": "47.25829",
    "lng": "11.38808"
  },
  {
    "country": "AT",
    "name": "Willendorf am Steinfelde",
    "lat": "47.78929",
    "lng": "16.05686"
  },
  {
    "country": "AT",
    "name": "Wilhelmsburg",
    "lat": "48.10571",
    "lng": "15.60539"
  },
  {
    "country": "AT",
    "name": "Wilfleinsdorf",
    "lat": "48.01667",
    "lng": "16.71667"
  },
  {
    "country": "AT",
    "name": "Wilfersdorf",
    "lat": "48.58333",
    "lng": "16.63333"
  },
  {
    "country": "AT",
    "name": "Wildon",
    "lat": "46.88333",
    "lng": "15.51667"
  },
  {
    "country": "AT",
    "name": "Wildermieming",
    "lat": "47.31667",
    "lng": "11.01667"
  },
  {
    "country": "AT",
    "name": "Wildalpen",
    "lat": "47.65",
    "lng": "14.98333"
  },
  {
    "country": "AT",
    "name": "Wiesmath",
    "lat": "47.61667",
    "lng": "16.28333"
  },
  {
    "country": "AT",
    "name": "Wiesing",
    "lat": "47.40486",
    "lng": "11.79708"
  },
  {
    "country": "AT",
    "name": "Wiesfleck",
    "lat": "47.38458",
    "lng": "16.14552"
  },
  {
    "country": "AT",
    "name": "Wiesen",
    "lat": "47.73776",
    "lng": "16.33798"
  },
  {
    "country": "AT",
    "name": "Wieselburg",
    "lat": "48.13333",
    "lng": "15.13333"
  },
  {
    "country": "AT",
    "name": "Wies",
    "lat": "46.72028",
    "lng": "15.27194"
  },
  {
    "country": "AT",
    "name": "Wienersdorf",
    "lat": "48.00819",
    "lng": "16.29169"
  },
  {
    "country": "AT",
    "name": "Wiener Neustadt",
    "lat": "47.80485",
    "lng": "16.23196"
  },
  {
    "country": "AT",
    "name": "Wiener Neudorf",
    "lat": "48.08278",
    "lng": "16.31384"
  },
  {
    "country": "AT",
    "name": "Vienna",
    "lat": "48.20849",
    "lng": "16.37208"
  },
  {
    "country": "AT",
    "name": "Weyregg",
    "lat": "47.90294",
    "lng": "13.57193"
  },
  {
    "country": "AT",
    "name": "Weyer",
    "lat": "47.85717",
    "lng": "14.66409"
  },
  {
    "country": "AT",
    "name": "Wetzelsdorf",
    "lat": "47.05293",
    "lng": "15.39923"
  },
  {
    "country": "AT",
    "name": "Wettmannstätten",
    "lat": "46.83056",
    "lng": "15.38722"
  },
  {
    "country": "AT",
    "name": "Westendorf",
    "lat": "47.43208",
    "lng": "12.21406"
  },
  {
    "country": "AT",
    "name": "Wernstein am Inn",
    "lat": "48.50802",
    "lng": "13.461"
  },
  {
    "country": "AT",
    "name": "Wernersdorf",
    "lat": "46.71592",
    "lng": "15.20718"
  },
  {
    "country": "AT",
    "name": "Werndorf",
    "lat": "46.92417",
    "lng": "15.49083"
  },
  {
    "country": "AT",
    "name": "Wernberg",
    "lat": "46.61667",
    "lng": "13.93333"
  },
  {
    "country": "AT",
    "name": "Werfenweng",
    "lat": "47.46204",
    "lng": "13.25582"
  },
  {
    "country": "AT",
    "name": "Werfen",
    "lat": "47.47585",
    "lng": "13.1902"
  },
  {
    "country": "AT",
    "name": "Weppersdorf",
    "lat": "47.57954",
    "lng": "16.42679"
  },
  {
    "country": "AT",
    "name": "Wenns",
    "lat": "47.16667",
    "lng": "10.73333"
  },
  {
    "country": "AT",
    "name": "Weng im Innkreis",
    "lat": "48.23508",
    "lng": "13.17801"
  },
  {
    "country": "AT",
    "name": "Wendling",
    "lat": "48.23182",
    "lng": "13.66622"
  },
  {
    "country": "AT",
    "name": "Wels",
    "lat": "48.16667",
    "lng": "14.03333"
  },
  {
    "country": "AT",
    "name": "Weiz",
    "lat": "47.21667",
    "lng": "15.61667"
  },
  {
    "country": "AT",
    "name": "Weitra",
    "lat": "48.7",
    "lng": "14.88333"
  },
  {
    "country": "AT",
    "name": "Weitersfelden",
    "lat": "48.4773",
    "lng": "14.72546"
  },
  {
    "country": "AT",
    "name": "Weitersfeld",
    "lat": "48.78097",
    "lng": "15.81345"
  },
  {
    "country": "AT",
    "name": "Weitensfeld",
    "lat": "46.84743",
    "lng": "14.19213"
  },
  {
    "country": "AT",
    "name": "Weiten",
    "lat": "48.29564",
    "lng": "15.2601"
  },
  {
    "country": "AT",
    "name": "Weistrach",
    "lat": "48.05",
    "lng": "14.58333"
  },
  {
    "country": "AT",
    "name": "Weißkirchen in Steiermark",
    "lat": "47.15",
    "lng": "14.73333"
  },
  {
    "country": "AT",
    "name": "Weisskirchen an der Traun",
    "lat": "48.16202",
    "lng": "14.12395"
  },
  {
    "country": "AT",
    "name": "Weißenkirchen in der Wachau",
    "lat": "48.3979",
    "lng": "15.46931"
  },
  {
    "country": "AT",
    "name": "Weißenbach bei Liezen",
    "lat": "47.56667",
    "lng": "14.21667"
  },
  {
    "country": "AT",
    "name": "Weissenbach an der Triesting",
    "lat": "47.98211",
    "lng": "16.03935"
  },
  {
    "country": "AT",
    "name": "Weissenbach am Lech",
    "lat": "47.44162",
    "lng": "10.64071"
  },
  {
    "country": "AT",
    "name": "Weissach",
    "lat": "47.57091",
    "lng": "12.16255"
  },
  {
    "country": "AT",
    "name": "Weinzierl bei Krems",
    "lat": "48.4",
    "lng": "15.6"
  },
  {
    "country": "AT",
    "name": "Weinzierl am Walde",
    "lat": "48.43211",
    "lng": "15.4321"
  },
  {
    "country": "AT",
    "name": "Weingraben",
    "lat": "47.51393",
    "lng": "16.36375"
  },
  {
    "country": "AT",
    "name": "Weinburg am Saßbach",
    "lat": "46.75361",
    "lng": "15.72111"
  },
  {
    "country": "AT",
    "name": "Weinburg",
    "lat": "48.11351",
    "lng": "15.53295"
  },
  {
    "country": "AT",
    "name": "Weiler",
    "lat": "47.29972",
    "lng": "9.65"
  },
  {
    "country": "AT",
    "name": "Weilbach",
    "lat": "48.27725",
    "lng": "13.37165"
  },
  {
    "country": "AT",
    "name": "Weikersdorf am Steinfelde",
    "lat": "47.80612",
    "lng": "16.14389"
  },
  {
    "country": "AT",
    "name": "Weikendorf",
    "lat": "48.34438",
    "lng": "16.76651"
  },
  {
    "country": "AT",
    "name": "Weigelsdorf",
    "lat": "47.95",
    "lng": "16.4"
  },
  {
    "country": "AT",
    "name": "Weidling",
    "lat": "48.291",
    "lng": "16.30865"
  },
  {
    "country": "AT",
    "name": "Weiden bei Rechnitz",
    "lat": "47.3",
    "lng": "16.35"
  },
  {
    "country": "AT",
    "name": "Weiden am See",
    "lat": "47.92532",
    "lng": "16.86899"
  },
  {
    "country": "AT",
    "name": "Weichselbaum",
    "lat": "46.9425",
    "lng": "16.1875"
  },
  {
    "country": "AT",
    "name": "Weibern",
    "lat": "48.18333",
    "lng": "13.7"
  },
  {
    "country": "AT",
    "name": "Weer",
    "lat": "47.30375",
    "lng": "11.64498"
  },
  {
    "country": "AT",
    "name": "Wattens",
    "lat": "47.29419",
    "lng": "11.5907"
  },
  {
    "country": "AT",
    "name": "Wattenberg",
    "lat": "47.28333",
    "lng": "11.6"
  },
  {
    "country": "AT",
    "name": "Wartmannstetten",
    "lat": "47.69359",
    "lng": "16.07506"
  },
  {
    "country": "AT",
    "name": "Warth",
    "lat": "47.65",
    "lng": "16.11667"
  },
  {
    "country": "AT",
    "name": "Warth",
    "lat": "47.25",
    "lng": "10.18333"
  },
  {
    "country": "AT",
    "name": "Wartberg ob der Aist",
    "lat": "48.34792",
    "lng": "14.50796"
  },
  {
    "country": "AT",
    "name": "Wartberg an der Krems",
    "lat": "47.98909",
    "lng": "14.11863"
  },
  {
    "country": "AT",
    "name": "Wartberg",
    "lat": "47.52717",
    "lng": "15.48095"
  },
  {
    "country": "AT",
    "name": "Wängle",
    "lat": "47.48658",
    "lng": "10.68995"
  },
  {
    "country": "AT",
    "name": "Wang",
    "lat": "48.04538",
    "lng": "15.02672"
  },
  {
    "country": "AT",
    "name": "Waltendorf",
    "lat": "47.06667",
    "lng": "15.46667"
  },
  {
    "country": "AT",
    "name": "Wals",
    "lat": "47.78333",
    "lng": "12.96667"
  },
  {
    "country": "AT",
    "name": "Walpersbach",
    "lat": "47.71667",
    "lng": "16.23333"
  },
  {
    "country": "AT",
    "name": "Wallsee",
    "lat": "48.16667",
    "lng": "14.71667"
  },
  {
    "country": "AT",
    "name": "Wallern im Burgenland",
    "lat": "47.72847",
    "lng": "16.93706"
  },
  {
    "country": "AT",
    "name": "Wallern an der Trattnach",
    "lat": "48.23296",
    "lng": "13.9462"
  },
  {
    "country": "AT",
    "name": "Waldzell",
    "lat": "48.13562",
    "lng": "13.42701"
  },
  {
    "country": "AT",
    "name": "Waldprechting",
    "lat": "47.9",
    "lng": "13.11667"
  },
  {
    "country": "AT",
    "name": "Waldneukirchen",
    "lat": "47.99854",
    "lng": "14.25879"
  },
  {
    "country": "AT",
    "name": "Waldkirchen an der Thaya",
    "lat": "48.93333",
    "lng": "15.35"
  },
  {
    "country": "AT",
    "name": "Waldkirchen am Wesen",
    "lat": "48.44059",
    "lng": "13.82174"
  },
  {
    "country": "AT",
    "name": "Walding",
    "lat": "48.35209",
    "lng": "14.1576"
  },
  {
    "country": "AT",
    "name": "Wald im Pinzgau",
    "lat": "47.25",
    "lng": "12.23333"
  },
  {
    "country": "AT",
    "name": "Waldhausen",
    "lat": "48.52183",
    "lng": "15.2625"
  },
  {
    "country": "AT",
    "name": "Waldenstein",
    "lat": "48.72845",
    "lng": "15.01419"
  },
  {
    "country": "AT",
    "name": "Waldegg",
    "lat": "47.86852",
    "lng": "16.05154"
  },
  {
    "country": "AT",
    "name": "Wald am Schoberpaß",
    "lat": "47.44936",
    "lng": "14.67567"
  },
  {
    "country": "AT",
    "name": "Walchsee",
    "lat": "47.65163",
    "lng": "12.31868"
  },
  {
    "country": "AT",
    "name": "Walchen",
    "lat": "47.28822",
    "lng": "12.68739"
  },
  {
    "country": "AT",
    "name": "Waizenkirchen",
    "lat": "48.33018",
    "lng": "13.85754"
  },
  {
    "country": "AT",
    "name": "Waiern",
    "lat": "46.73028",
    "lng": "14.08194"
  },
  {
    "country": "AT",
    "name": "Waidring",
    "lat": "47.58333",
    "lng": "12.56667"
  },
  {
    "country": "AT",
    "name": "Waidmannsfeld",
    "lat": "47.87042",
    "lng": "15.98116"
  },
  {
    "country": "AT",
    "name": "Waidhofen an der Ybbs",
    "lat": "47.96004",
    "lng": "14.77361"
  },
  {
    "country": "AT",
    "name": "Waidhofen an der Thaya",
    "lat": "48.81667",
    "lng": "15.28333"
  },
  {
    "country": "AT",
    "name": "Wagram",
    "lat": "48.23828",
    "lng": "14.22996"
  },
  {
    "country": "AT",
    "name": "Wagrain",
    "lat": "47.33528",
    "lng": "13.29889"
  },
  {
    "country": "AT",
    "name": "Wagnitz",
    "lat": "46.98333",
    "lng": "15.46667"
  },
  {
    "country": "AT",
    "name": "Wagna",
    "lat": "46.76682",
    "lng": "15.55906"
  },
  {
    "country": "AT",
    "name": "Vösendorf",
    "lat": "48.12107",
    "lng": "16.34036"
  },
  {
    "country": "AT",
    "name": "Murau",
    "lat": "47.11056",
    "lng": "14.16944"
  },
  {
    "country": "AT",
    "name": "Vorderthiersee",
    "lat": "47.58333",
    "lng": "12.1"
  },
  {
    "country": "AT",
    "name": "Vordernberg",
    "lat": "47.48809",
    "lng": "14.99436"
  },
  {
    "country": "AT",
    "name": "Vorderhornbach",
    "lat": "47.37009",
    "lng": "10.53947"
  },
  {
    "country": "AT",
    "name": "Vorchdorf",
    "lat": "48.00388",
    "lng": "13.92122"
  },
  {
    "country": "AT",
    "name": "Vorau",
    "lat": "47.40548",
    "lng": "15.88754"
  },
  {
    "country": "AT",
    "name": "Vomp",
    "lat": "47.33333",
    "lng": "11.68333"
  },
  {
    "country": "AT",
    "name": "Völs",
    "lat": "47.25",
    "lng": "11.33333"
  },
  {
    "country": "AT",
    "name": "Völkermarkt",
    "lat": "46.66222",
    "lng": "14.63444"
  },
  {
    "country": "AT",
    "name": "Völkendorf",
    "lat": "46.60806",
    "lng": "13.83153"
  },
  {
    "country": "AT",
    "name": "Voldöpp",
    "lat": "47.44469",
    "lng": "11.88343"
  },
  {
    "country": "AT",
    "name": "Volders",
    "lat": "47.28333",
    "lng": "11.56667"
  },
  {
    "country": "AT",
    "name": "Voitsberg",
    "lat": "47.04445",
    "lng": "15.15313"
  },
  {
    "country": "AT",
    "name": "Vöcklamarkt",
    "lat": "48.0025",
    "lng": "13.48383"
  },
  {
    "country": "AT",
    "name": "Vöcklabruck",
    "lat": "48.00279",
    "lng": "13.65652"
  },
  {
    "country": "AT",
    "name": "Vitis",
    "lat": "48.75964",
    "lng": "15.18259"
  },
  {
    "country": "AT",
    "name": "Virgen",
    "lat": "47.00159",
    "lng": "12.45661"
  },
  {
    "country": "AT",
    "name": "Vils",
    "lat": "47.55",
    "lng": "10.63333"
  },
  {
    "country": "AT",
    "name": "Villach",
    "lat": "46.61028",
    "lng": "13.85583"
  },
  {
    "country": "AT",
    "name": "Viktring",
    "lat": "46.59194",
    "lng": "14.26917"
  },
  {
    "country": "AT",
    "name": "Viktorsberg",
    "lat": "47.30092",
    "lng": "9.67484"
  },
  {
    "country": "AT",
    "name": "Vigaun",
    "lat": "47.66667",
    "lng": "13.13333"
  },
  {
    "country": "AT",
    "name": "Viehofen",
    "lat": "48.21667",
    "lng": "15.61667"
  },
  {
    "country": "AT",
    "name": "Viehhofen",
    "lat": "47.36667",
    "lng": "12.73333"
  },
  {
    "country": "AT",
    "name": "Viehhausen",
    "lat": "47.78333",
    "lng": "12.98333"
  },
  {
    "country": "AT",
    "name": "Viechtwang",
    "lat": "47.91531",
    "lng": "13.96345"
  },
  {
    "country": "AT",
    "name": "Velm",
    "lat": "48.03333",
    "lng": "16.43333"
  },
  {
    "country": "AT",
    "name": "Velden am Wörthersee",
    "lat": "46.61301",
    "lng": "14.0413"
  },
  {
    "country": "AT",
    "name": "Veitsch",
    "lat": "47.57815",
    "lng": "15.4945"
  },
  {
    "country": "AT",
    "name": "Utzenaich",
    "lat": "48.27622",
    "lng": "13.46091"
  },
  {
    "country": "AT",
    "name": "Uttendorf",
    "lat": "48.15887",
    "lng": "13.1218"
  },
  {
    "country": "AT",
    "name": "Uttendorf",
    "lat": "47.28333",
    "lng": "12.56667"
  },
  {
    "country": "AT",
    "name": "Utschtal",
    "lat": "47.4",
    "lng": "15.2"
  },
  {
    "country": "AT",
    "name": "Unterwart",
    "lat": "47.25",
    "lng": "16.23333"
  },
  {
    "country": "AT",
    "name": "Unterwaltersdorf",
    "lat": "47.95",
    "lng": "16.41667"
  },
  {
    "country": "AT",
    "name": "Unterwagram",
    "lat": "48.21243",
    "lng": "15.64951"
  },
  {
    "country": "AT",
    "name": "Untertauern",
    "lat": "47.3",
    "lng": "13.5"
  },
  {
    "country": "AT",
    "name": "Unterstinkenbrunn",
    "lat": "48.6677",
    "lng": "16.34607"
  },
  {
    "country": "AT",
    "name": "Untersiebenbrunn",
    "lat": "48.25",
    "lng": "16.73333"
  },
  {
    "country": "AT",
    "name": "Rohrbach an der Gölsen",
    "lat": "48.04699",
    "lng": "15.74169"
  },
  {
    "country": "AT",
    "name": "Unterpremstätten",
    "lat": "46.96472",
    "lng": "15.40417"
  },
  {
    "country": "AT",
    "name": "Unterperfuss",
    "lat": "47.26667",
    "lng": "11.25"
  },
  {
    "country": "AT",
    "name": "Unterlangkampfen",
    "lat": "47.55",
    "lng": "12.1"
  },
  {
    "country": "AT",
    "name": "Unterlamm",
    "lat": "46.97694",
    "lng": "16.06389"
  },
  {
    "country": "AT",
    "name": "Unterkohlstätten",
    "lat": "47.38333",
    "lng": "16.31667"
  },
  {
    "country": "AT",
    "name": "Grünburg",
    "lat": "47.97234",
    "lng": "14.26472"
  },
  {
    "country": "AT",
    "name": "Unterfrauenhaid",
    "lat": "47.57116",
    "lng": "16.49885"
  },
  {
    "country": "AT",
    "name": "Unterfladnitz",
    "lat": "47.18333",
    "lng": "15.66667"
  },
  {
    "country": "AT",
    "name": "Untere Fellach",
    "lat": "46.62504",
    "lng": "13.82681"
  },
  {
    "country": "AT",
    "name": "Unterbergla",
    "lat": "46.80746",
    "lng": "15.31516"
  },
  {
    "country": "AT",
    "name": "Unterauersbach",
    "lat": "46.86556",
    "lng": "15.77028"
  },
  {
    "country": "AT",
    "name": "Unken",
    "lat": "47.64966",
    "lng": "12.72946"
  },
  {
    "country": "AT",
    "name": "Ungerdorf",
    "lat": "47.08333",
    "lng": "15.66667"
  },
  {
    "country": "AT",
    "name": "Ungenach",
    "lat": "48.04756",
    "lng": "13.61472"
  },
  {
    "country": "AT",
    "name": "Umhausen",
    "lat": "47.13503",
    "lng": "10.92826"
  },
  {
    "country": "AT",
    "name": "Ulrichskirchen",
    "lat": "48.4",
    "lng": "16.48333"
  },
  {
    "country": "AT",
    "name": "Ulrichsberg",
    "lat": "48.67498",
    "lng": "13.91049"
  },
  {
    "country": "AT",
    "name": "Uderns",
    "lat": "47.31667",
    "lng": "11.86667"
  },
  {
    "country": "AT",
    "name": "Übersbach",
    "lat": "47.02318",
    "lng": "16.05517"
  },
  {
    "country": "AT",
    "name": "Übersaxen",
    "lat": "47.25284",
    "lng": "9.6708"
  },
  {
    "country": "AT",
    "name": "Übelbach",
    "lat": "47.22534",
    "lng": "15.23615"
  },
  {
    "country": "AT",
    "name": "Tweng",
    "lat": "47.18333",
    "lng": "13.6"
  },
  {
    "country": "AT",
    "name": "Türnitz",
    "lat": "47.93095",
    "lng": "15.49295"
  },
  {
    "country": "AT",
    "name": "Turnau",
    "lat": "47.55776",
    "lng": "15.33739"
  },
  {
    "country": "AT",
    "name": "Tulln",
    "lat": "48.32829",
    "lng": "16.05858"
  },
  {
    "country": "AT",
    "name": "Tulfes",
    "lat": "47.25806",
    "lng": "11.53333"
  },
  {
    "country": "AT",
    "name": "Tulbing",
    "lat": "48.29336",
    "lng": "16.12226"
  },
  {
    "country": "AT",
    "name": "Tschanigraben",
    "lat": "47.01667",
    "lng": "16.3"
  },
  {
    "country": "AT",
    "name": "Tschagguns",
    "lat": "47.08333",
    "lng": "9.9"
  },
  {
    "country": "AT",
    "name": "Trumau",
    "lat": "47.99348",
    "lng": "16.34268"
  },
  {
    "country": "AT",
    "name": "Trössing",
    "lat": "46.81667",
    "lng": "15.81667"
  },
  {
    "country": "AT",
    "name": "Trofaiach",
    "lat": "47.42524",
    "lng": "15.00681"
  },
  {
    "country": "AT",
    "name": "Tristach",
    "lat": "46.81611",
    "lng": "12.78972"
  },
  {
    "country": "AT",
    "name": "Trins",
    "lat": "47.08333",
    "lng": "11.41667"
  },
  {
    "country": "AT",
    "name": "Triebendorf",
    "lat": "47.11667",
    "lng": "14.23333"
  },
  {
    "country": "AT",
    "name": "Trieben",
    "lat": "47.48574",
    "lng": "14.48744"
  },
  {
    "country": "AT",
    "name": "Tribuswinkel",
    "lat": "48.00623",
    "lng": "16.27075"
  },
  {
    "country": "AT",
    "name": "Treibach",
    "lat": "46.86667",
    "lng": "14.46667"
  },
  {
    "country": "AT",
    "name": "Treglwang",
    "lat": "47.47458",
    "lng": "14.59083"
  },
  {
    "country": "AT",
    "name": "Trebesing",
    "lat": "46.88639",
    "lng": "13.51028"
  },
  {
    "country": "AT",
    "name": "Trautmannsdorf in Oststeiermark",
    "lat": "46.8753",
    "lng": "15.88451"
  },
  {
    "country": "AT",
    "name": "Trautmannsdorf an der Leitha",
    "lat": "48.02357",
    "lng": "16.63266"
  },
  {
    "country": "AT",
    "name": "Trausdorf an der Wulka",
    "lat": "47.8135",
    "lng": "16.5576"
  },
  {
    "country": "AT",
    "name": "Bad Traunstein",
    "lat": "48.4385",
    "lng": "15.11712"
  },
  {
    "country": "AT",
    "name": "Traunkirchen",
    "lat": "47.84462",
    "lng": "13.78939"
  },
  {
    "country": "AT",
    "name": "Traun",
    "lat": "48.22656",
    "lng": "14.23459"
  },
  {
    "country": "AT",
    "name": "Trattenbach",
    "lat": "47.6",
    "lng": "15.86667"
  },
  {
    "country": "AT",
    "name": "Traismauer",
    "lat": "48.35",
    "lng": "15.73333"
  },
  {
    "country": "AT",
    "name": "Traiskirchen",
    "lat": "48.01485",
    "lng": "16.29324"
  },
  {
    "country": "AT",
    "name": "Traisen",
    "lat": "48.03333",
    "lng": "15.6"
  },
  {
    "country": "AT",
    "name": "Trahütten",
    "lat": "46.825",
    "lng": "15.15694"
  },
  {
    "country": "AT",
    "name": "Tragwein",
    "lat": "48.33314",
    "lng": "14.62237"
  },
  {
    "country": "AT",
    "name": "Traboch",
    "lat": "47.37705",
    "lng": "14.98647"
  },
  {
    "country": "AT",
    "name": "Tobaj",
    "lat": "47.08333",
    "lng": "16.3"
  },
  {
    "country": "AT",
    "name": "Tobadill",
    "lat": "47.12513",
    "lng": "10.51404"
  },
  {
    "country": "AT",
    "name": "Timelkam",
    "lat": "48.00394",
    "lng": "13.6076"
  },
  {
    "country": "AT",
    "name": "Tieschen",
    "lat": "46.78611",
    "lng": "15.94222"
  },
  {
    "country": "AT",
    "name": "Tiefgraben",
    "lat": "47.87385",
    "lng": "13.30591"
  },
  {
    "country": "AT",
    "name": "Thüringen",
    "lat": "47.2",
    "lng": "9.76667"
  },
  {
    "country": "AT",
    "name": "Thumersbach",
    "lat": "47.32952",
    "lng": "12.81675"
  },
  {
    "country": "AT",
    "name": "Thörl",
    "lat": "47.51952",
    "lng": "15.22276"
  },
  {
    "country": "AT",
    "name": "Thomatal",
    "lat": "47.06667",
    "lng": "13.75"
  },
  {
    "country": "AT",
    "name": "Thomasberg",
    "lat": "47.56667",
    "lng": "16.13333"
  },
  {
    "country": "AT",
    "name": "Theresienfeld",
    "lat": "47.85",
    "lng": "16.23333"
  },
  {
    "country": "AT",
    "name": "Thaya",
    "lat": "48.85489",
    "lng": "15.28902"
  },
  {
    "country": "AT",
    "name": "Thaur",
    "lat": "47.29476",
    "lng": "11.47529"
  },
  {
    "country": "AT",
    "name": "Thalheim bei Wels",
    "lat": "48.15",
    "lng": "14.03333"
  },
  {
    "country": "AT",
    "name": "Thalgau",
    "lat": "47.84142",
    "lng": "13.25325"
  },
  {
    "country": "AT",
    "name": "Teufenbach",
    "lat": "47.1287",
    "lng": "14.35913"
  },
  {
    "country": "AT",
    "name": "Ternitz",
    "lat": "47.71565",
    "lng": "16.03575"
  },
  {
    "country": "AT",
    "name": "Ternberg",
    "lat": "47.94518",
    "lng": "14.3587"
  },
  {
    "country": "AT",
    "name": "Terfens",
    "lat": "47.32355",
    "lng": "11.64388"
  },
  {
    "country": "AT",
    "name": "Telfs",
    "lat": "47.30707",
    "lng": "11.06817"
  },
  {
    "country": "AT",
    "name": "Telfes im Stubai",
    "lat": "47.16667",
    "lng": "11.36667"
  },
  {
    "country": "AT",
    "name": "Teesdorf",
    "lat": "47.95",
    "lng": "16.28333"
  },
  {
    "country": "AT",
    "name": "Taxenbach",
    "lat": "47.29116",
    "lng": "12.96215"
  },
  {
    "country": "AT",
    "name": "Taxach",
    "lat": "47.7261",
    "lng": "13.07184"
  },
  {
    "country": "AT",
    "name": "Tauplitz",
    "lat": "47.56005",
    "lng": "14.01293"
  },
  {
    "country": "AT",
    "name": "Taufkirchen an der Trattnach",
    "lat": "48.24731",
    "lng": "13.74767"
  },
  {
    "country": "AT",
    "name": "Tattendorf",
    "lat": "47.95",
    "lng": "16.3"
  },
  {
    "country": "AT",
    "name": "Tarrenz",
    "lat": "47.26667",
    "lng": "10.76667"
  },
  {
    "country": "AT",
    "name": "Tannheim",
    "lat": "47.49934",
    "lng": "10.51641"
  },
  {
    "country": "AT",
    "name": "Tamsweg",
    "lat": "47.12808",
    "lng": "13.81102"
  },
  {
    "country": "AT",
    "name": "Taiskirchen im Innkreis",
    "lat": "48.26468",
    "lng": "13.57318"
  },
  {
    "country": "AT",
    "name": "Tadten",
    "lat": "47.76667",
    "lng": "16.98333"
  },
  {
    "country": "AT",
    "name": "Sulzberg",
    "lat": "47.52178",
    "lng": "9.91353"
  },
  {
    "country": "AT",
    "name": "Sulz",
    "lat": "47.28721",
    "lng": "9.65183"
  },
  {
    "country": "AT",
    "name": "Sulztal an der Weinstraße",
    "lat": "46.68333",
    "lng": "15.55"
  },
  {
    "country": "AT",
    "name": "Stummerberg",
    "lat": "47.28333",
    "lng": "11.91667"
  },
  {
    "country": "AT",
    "name": "Stumm",
    "lat": "47.29052",
    "lng": "11.88755"
  },
  {
    "country": "AT",
    "name": "Stuhlfelden",
    "lat": "47.28761",
    "lng": "12.52755"
  },
  {
    "country": "AT",
    "name": "Studenzen",
    "lat": "47.00583",
    "lng": "15.75417"
  },
  {
    "country": "AT",
    "name": "Stubenberg",
    "lat": "47.2446",
    "lng": "15.80027"
  },
  {
    "country": "AT",
    "name": "Stronsdorf",
    "lat": "48.65157",
    "lng": "16.2989"
  },
  {
    "country": "AT",
    "name": "Strobl",
    "lat": "47.71667",
    "lng": "13.48333"
  },
  {
    "country": "AT",
    "name": "Strengen",
    "lat": "47.12589",
    "lng": "10.46199"
  },
  {
    "country": "AT",
    "name": "Strengberg",
    "lat": "48.14685",
    "lng": "14.65147"
  },
  {
    "country": "AT",
    "name": "Strem",
    "lat": "47.04498",
    "lng": "16.41426"
  },
  {
    "country": "AT",
    "name": "Stratzing",
    "lat": "48.45",
    "lng": "15.6"
  },
  {
    "country": "AT",
    "name": "Strasswalchen",
    "lat": "47.97947",
    "lng": "13.25535"
  },
  {
    "country": "AT",
    "name": "Straß in Steiermark",
    "lat": "46.72722",
    "lng": "15.62444"
  },
  {
    "country": "AT",
    "name": "Strasshof an der Nordbahn",
    "lat": "48.31667",
    "lng": "16.66667"
  },
  {
    "country": "AT",
    "name": "Strassham",
    "lat": "48.28348",
    "lng": "14.14524"
  },
  {
    "country": "AT",
    "name": "Straßgang",
    "lat": "47.03333",
    "lng": "15.4"
  },
  {
    "country": "AT",
    "name": "Strassengel",
    "lat": "47.11573",
    "lng": "15.33288"
  },
  {
    "country": "AT",
    "name": "Strassen",
    "lat": "46.75389",
    "lng": "12.48417"
  },
  {
    "country": "AT",
    "name": "Straßburg-Stadt",
    "lat": "46.89444",
    "lng": "14.32861"
  },
  {
    "country": "AT",
    "name": "Strass im Zillertal",
    "lat": "47.39556",
    "lng": "11.81966"
  },
  {
    "country": "AT",
    "name": "Strass",
    "lat": "48.46667",
    "lng": "15.73333"
  },
  {
    "country": "AT",
    "name": "Strallegg",
    "lat": "47.41165",
    "lng": "15.72534"
  },
  {
    "country": "AT",
    "name": "Straden",
    "lat": "46.80917",
    "lng": "15.86806"
  },
  {
    "country": "AT",
    "name": "Stotzing",
    "lat": "47.90688",
    "lng": "16.5458"
  },
  {
    "country": "AT",
    "name": "Stössing",
    "lat": "48.12267",
    "lng": "15.81379"
  },
  {
    "country": "AT",
    "name": "Stoob",
    "lat": "47.52845",
    "lng": "16.4776"
  },
  {
    "country": "AT",
    "name": "Stollhofen",
    "lat": "48.35226",
    "lng": "15.75963"
  },
  {
    "country": "AT",
    "name": "Stockerau",
    "lat": "48.38333",
    "lng": "16.21667"
  },
  {
    "country": "AT",
    "name": "Stockenboi",
    "lat": "46.72611",
    "lng": "13.52306"
  },
  {
    "country": "AT",
    "name": "Stiwoll",
    "lat": "47.1",
    "lng": "15.21667"
  },
  {
    "country": "AT",
    "name": "Steinbrunn",
    "lat": "47.83333",
    "lng": "16.41667"
  },
  {
    "country": "AT",
    "name": "Stinatz",
    "lat": "47.20266",
    "lng": "16.13312"
  },
  {
    "country": "AT",
    "name": "Steyregg",
    "lat": "48.28513",
    "lng": "14.36995"
  },
  {
    "country": "AT",
    "name": "Steyr",
    "lat": "48.04274",
    "lng": "14.42127"
  },
  {
    "country": "AT",
    "name": "Steuerberg",
    "lat": "46.78804",
    "lng": "14.1129"
  },
  {
    "country": "AT",
    "name": "Stetten",
    "lat": "48.36667",
    "lng": "16.38333"
  },
  {
    "country": "AT",
    "name": "Stetteldorf am Wagram",
    "lat": "48.40815",
    "lng": "16.01862"
  },
  {
    "country": "AT",
    "name": "Stephanshart",
    "lat": "48.15",
    "lng": "14.81667"
  },
  {
    "country": "AT",
    "name": "Stenzengreith",
    "lat": "47.2",
    "lng": "15.51667"
  },
  {
    "country": "AT",
    "name": "Steinhaus",
    "lat": "48.11614",
    "lng": "14.0189"
  },
  {
    "country": "AT",
    "name": "Steinfeld",
    "lat": "46.75812",
    "lng": "13.24934"
  },
  {
    "country": "AT",
    "name": "Steinerkirchen an der Traun",
    "lat": "48.07911",
    "lng": "13.95796"
  },
  {
    "country": "AT",
    "name": "Steindorf am Ossiacher See",
    "lat": "46.69833",
    "lng": "14.00917"
  },
  {
    "country": "AT",
    "name": "Steinbach am Attersee",
    "lat": "47.83087",
    "lng": "13.54613"
  },
  {
    "country": "AT",
    "name": "Stein an der Donau",
    "lat": "48.40163",
    "lng": "15.58102"
  },
  {
    "country": "AT",
    "name": "Steinakirchen am Forst",
    "lat": "48.06965",
    "lng": "15.04801"
  },
  {
    "country": "AT",
    "name": "Steinach am Brenner",
    "lat": "47.08333",
    "lng": "11.46667"
  },
  {
    "country": "AT",
    "name": "Steinabrückl",
    "lat": "47.87053",
    "lng": "16.20277"
  },
  {
    "country": "AT",
    "name": "Stein",
    "lat": "46.99778",
    "lng": "16.08694"
  },
  {
    "country": "AT",
    "name": "Stegersbach",
    "lat": "47.16667",
    "lng": "16.16667"
  },
  {
    "country": "AT",
    "name": "Steeg",
    "lat": "47.24393",
    "lng": "10.29436"
  },
  {
    "country": "AT",
    "name": "Statzendorf",
    "lat": "48.30752",
    "lng": "15.64127"
  },
  {
    "country": "AT",
    "name": "Stattersdorf",
    "lat": "48.18333",
    "lng": "15.63333"
  },
  {
    "country": "AT",
    "name": "Stattegg",
    "lat": "47.13333",
    "lng": "15.41667"
  },
  {
    "country": "AT",
    "name": "Stanz bei Landeck",
    "lat": "47.14758",
    "lng": "10.5534"
  },
  {
    "country": "AT",
    "name": "Stanzach",
    "lat": "47.38333",
    "lng": "10.56667"
  },
  {
    "country": "AT",
    "name": "Stans",
    "lat": "47.36667",
    "lng": "11.71667"
  },
  {
    "country": "AT",
    "name": "Stams",
    "lat": "47.27603",
    "lng": "10.98315"
  },
  {
    "country": "AT",
    "name": "Stambach",
    "lat": "47.33333",
    "lng": "15.93333"
  },
  {
    "country": "AT",
    "name": "Stallhofen",
    "lat": "47.05",
    "lng": "15.21667"
  },
  {
    "country": "AT",
    "name": "Stallhof",
    "lat": "46.88333",
    "lng": "15.28333"
  },
  {
    "country": "AT",
    "name": "Stallehr",
    "lat": "47.13306",
    "lng": "9.85"
  },
  {
    "country": "AT",
    "name": "Stall",
    "lat": "46.89056",
    "lng": "13.03694"
  },
  {
    "country": "AT",
    "name": "Stainz bei Straden",
    "lat": "46.82444",
    "lng": "15.89222"
  },
  {
    "country": "AT",
    "name": "Stainz",
    "lat": "46.89444",
    "lng": "15.26722"
  },
  {
    "country": "AT",
    "name": "Stainach",
    "lat": "47.53343",
    "lng": "14.10872"
  },
  {
    "country": "AT",
    "name": "Stadtschlaining",
    "lat": "47.31667",
    "lng": "16.28333"
  },
  {
    "country": "AT",
    "name": "Stadl-Traun",
    "lat": "48.07963",
    "lng": "13.8614"
  },
  {
    "country": "AT",
    "name": "Stadl-Paura",
    "lat": "48.08333",
    "lng": "13.86667"
  },
  {
    "country": "AT",
    "name": "Stadl-Hausruck",
    "lat": "48.08255",
    "lng": "13.85213"
  },
  {
    "country": "AT",
    "name": "Stadl an der Mur",
    "lat": "47.08333",
    "lng": "13.96667"
  },
  {
    "country": "AT",
    "name": "Staatz",
    "lat": "48.67617",
    "lng": "16.48726"
  },
  {
    "country": "AT",
    "name": "Spratzern",
    "lat": "48.17044",
    "lng": "15.61844"
  },
  {
    "country": "AT",
    "name": "Spitz",
    "lat": "48.3656",
    "lng": "15.41416"
  },
  {
    "country": "AT",
    "name": "Spittal an der Drau",
    "lat": "46.8",
    "lng": "13.5"
  },
  {
    "country": "AT",
    "name": "Spital am Semmering",
    "lat": "47.61345",
    "lng": "15.75096"
  },
  {
    "country": "AT",
    "name": "Spital am Pyhrn",
    "lat": "47.66487",
    "lng": "14.34014"
  },
  {
    "country": "AT",
    "name": "Spillern",
    "lat": "48.38333",
    "lng": "16.25"
  },
  {
    "country": "AT",
    "name": "Spielfeld",
    "lat": "46.70556",
    "lng": "15.63722"
  },
  {
    "country": "AT",
    "name": "Spielberg bei Knittelfeld",
    "lat": "47.21667",
    "lng": "14.78333"
  },
  {
    "country": "AT",
    "name": "Spatenhof",
    "lat": "46.9625",
    "lng": "15.36111"
  },
  {
    "country": "AT",
    "name": "Spannberg",
    "lat": "48.46393",
    "lng": "16.73647"
  },
  {
    "country": "AT",
    "name": "Sooss",
    "lat": "47.98464",
    "lng": "16.21737"
  },
  {
    "country": "AT",
    "name": "Sonntagberg",
    "lat": "47.99561",
    "lng": "14.76065"
  },
  {
    "country": "AT",
    "name": "Sommerein",
    "lat": "47.98333",
    "lng": "16.65"
  },
  {
    "country": "AT",
    "name": "Sollenau",
    "lat": "47.89834",
    "lng": "16.24833"
  },
  {
    "country": "AT",
    "name": "Söll",
    "lat": "47.50378",
    "lng": "12.19221"
  },
  {
    "country": "AT",
    "name": "Sölden",
    "lat": "46.96667",
    "lng": "11"
  },
  {
    "country": "AT",
    "name": "Hall in Tirol",
    "lat": "47.28333",
    "lng": "11.51667"
  },
  {
    "country": "AT",
    "name": "Södingberg",
    "lat": "47.10703",
    "lng": "15.17169"
  },
  {
    "country": "AT",
    "name": "Söchau",
    "lat": "47.03333",
    "lng": "16.01667"
  },
  {
    "country": "AT",
    "name": "Soboth",
    "lat": "46.68139",
    "lng": "15.07833"
  },
  {
    "country": "AT",
    "name": "Sitzendorf an der Schmida",
    "lat": "48.59841",
    "lng": "15.94254"
  },
  {
    "country": "AT",
    "name": "Sittersdorf",
    "lat": "46.54444",
    "lng": "14.60583"
  },
  {
    "country": "AT",
    "name": "Sistrans",
    "lat": "47.23333",
    "lng": "11.45"
  },
  {
    "country": "AT",
    "name": "Sinabelkirchen",
    "lat": "47.102",
    "lng": "15.82795"
  },
  {
    "country": "AT",
    "name": "Simmering",
    "lat": "48.18333",
    "lng": "16.43333"
  },
  {
    "country": "AT",
    "name": "Silz",
    "lat": "47.26667",
    "lng": "10.93333"
  },
  {
    "country": "AT",
    "name": "Sillian",
    "lat": "46.75278",
    "lng": "12.42111"
  },
  {
    "country": "AT",
    "name": "Silbertal",
    "lat": "47.09368",
    "lng": "9.98314"
  },
  {
    "country": "AT",
    "name": "Sigmundsherberg",
    "lat": "48.68333",
    "lng": "15.75"
  },
  {
    "country": "AT",
    "name": "Sigless",
    "lat": "47.77533",
    "lng": "16.39503"
  },
  {
    "country": "AT",
    "name": "Siezenheim",
    "lat": "47.81529",
    "lng": "12.99039"
  },
  {
    "country": "AT",
    "name": "Sierning",
    "lat": "48.04343",
    "lng": "14.30935"
  },
  {
    "country": "AT",
    "name": "Sierndorf",
    "lat": "48.43024",
    "lng": "16.16658"
  },
  {
    "country": "AT",
    "name": "Sieghartskirchen",
    "lat": "48.25531",
    "lng": "16.01223"
  },
  {
    "country": "AT",
    "name": "Sieggraben",
    "lat": "47.65128",
    "lng": "16.37993"
  },
  {
    "country": "AT",
    "name": "Siegersdorf bei Herberstein",
    "lat": "47.2",
    "lng": "15.78333"
  },
  {
    "country": "AT",
    "name": "Siegendorf im Burgenland",
    "lat": "47.78098",
    "lng": "16.54232"
  },
  {
    "country": "AT",
    "name": "Sibratsgfäll",
    "lat": "47.42667",
    "lng": "10.03806"
  },
  {
    "country": "AT",
    "name": "Seyring",
    "lat": "48.33333",
    "lng": "16.48333"
  },
  {
    "country": "AT",
    "name": "Serfaus",
    "lat": "47.04018",
    "lng": "10.60339"
  },
  {
    "country": "AT",
    "name": "Senftenberg",
    "lat": "48.43333",
    "lng": "15.55"
  },
  {
    "country": "AT",
    "name": "Semriach",
    "lat": "47.21667",
    "lng": "15.4"
  },
  {
    "country": "AT",
    "name": "Semmering",
    "lat": "47.63347",
    "lng": "15.82993"
  },
  {
    "country": "AT",
    "name": "Selzthal",
    "lat": "47.54988",
    "lng": "14.31201"
  },
  {
    "country": "AT",
    "name": "Seitenstetten Markt",
    "lat": "48.03333",
    "lng": "14.65"
  },
  {
    "country": "AT",
    "name": "Seiersberg",
    "lat": "47",
    "lng": "15.4"
  },
  {
    "country": "AT",
    "name": "Seibersdorf",
    "lat": "47.95858",
    "lng": "16.51842"
  },
  {
    "country": "AT",
    "name": "Seggauberg",
    "lat": "46.76667",
    "lng": "15.51667"
  },
  {
    "country": "AT",
    "name": "Seewalchen",
    "lat": "47.95246",
    "lng": "13.58382"
  },
  {
    "country": "AT",
    "name": "Seewalchen",
    "lat": "47.9",
    "lng": "13.13333"
  },
  {
    "country": "AT",
    "name": "Seekirchen am Wallersee",
    "lat": "47.9",
    "lng": "13.13333"
  },
  {
    "country": "AT",
    "name": "Seeham",
    "lat": "47.96746",
    "lng": "13.07699"
  },
  {
    "country": "AT",
    "name": "Seefeld in Tirol",
    "lat": "47.33016",
    "lng": "11.18786"
  },
  {
    "country": "AT",
    "name": "Seeboden",
    "lat": "46.81909",
    "lng": "13.5143"
  },
  {
    "country": "AT",
    "name": "Seebenstein",
    "lat": "47.69936",
    "lng": "16.14484"
  },
  {
    "country": "AT",
    "name": "Seebach",
    "lat": "46.61667",
    "lng": "13.86667"
  },
  {
    "country": "AT",
    "name": "See",
    "lat": "47.08333",
    "lng": "10.46667"
  },
  {
    "country": "AT",
    "name": "Seckau",
    "lat": "47.26667",
    "lng": "14.78333"
  },
  {
    "country": "AT",
    "name": "Sebersdorf",
    "lat": "47.1865",
    "lng": "15.9936"
  },
  {
    "country": "AT",
    "name": "Schwoich",
    "lat": "47.546",
    "lng": "12.14049"
  },
  {
    "country": "AT",
    "name": "Schwertberg",
    "lat": "48.2734",
    "lng": "14.58474"
  },
  {
    "country": "AT",
    "name": "Schwendt",
    "lat": "47.63182",
    "lng": "12.39266"
  },
  {
    "country": "AT",
    "name": "Schwendau",
    "lat": "47.19753",
    "lng": "11.85897"
  },
  {
    "country": "AT",
    "name": "Schweinbach",
    "lat": "48.34033",
    "lng": "14.42247"
  },
  {
    "country": "AT",
    "name": "Schweiggers",
    "lat": "48.66667",
    "lng": "15.06667"
  },
  {
    "country": "AT",
    "name": "Schwechat",
    "lat": "48.13333",
    "lng": "16.46667"
  },
  {
    "country": "AT",
    "name": "Schwaz",
    "lat": "47.35169",
    "lng": "11.71014"
  },
  {
    "country": "AT",
    "name": "Schwarzenbach an der Pielach",
    "lat": "47.93333",
    "lng": "15.38333"
  },
  {
    "country": "AT",
    "name": "Schwarzenbach",
    "lat": "47.63547",
    "lng": "16.35109"
  },
  {
    "country": "AT",
    "name": "Schwarzenau",
    "lat": "48.74436",
    "lng": "15.25838"
  },
  {
    "country": "AT",
    "name": "Schwarzau im Schwarzautal",
    "lat": "46.87886",
    "lng": "15.66421"
  },
  {
    "country": "AT",
    "name": "Schwarzau im Gebirge",
    "lat": "47.81223",
    "lng": "15.70581"
  },
  {
    "country": "AT",
    "name": "Schwarzau am Steinfeld",
    "lat": "47.73183",
    "lng": "16.17094"
  },
  {
    "country": "AT",
    "name": "Schwarzach im Pongau",
    "lat": "47.32048",
    "lng": "13.15171"
  },
  {
    "country": "AT",
    "name": "Schwarzach",
    "lat": "47.44904",
    "lng": "9.76213"
  },
  {
    "country": "AT",
    "name": "Schwanenstadt",
    "lat": "48.05537",
    "lng": "13.77505"
  },
  {
    "country": "AT",
    "name": "Schwanberg",
    "lat": "46.75833",
    "lng": "15.20833"
  },
  {
    "country": "AT",
    "name": "Schwadorf",
    "lat": "48.06936",
    "lng": "16.57957"
  },
  {
    "country": "AT",
    "name": "Schützen am Gebirge",
    "lat": "47.85233",
    "lng": "16.62334"
  },
  {
    "country": "AT",
    "name": "Schruns",
    "lat": "47.06667",
    "lng": "9.91667"
  },
  {
    "country": "AT",
    "name": "Schrems bei Frohnleiten",
    "lat": "47.28109",
    "lng": "15.35932"
  },
  {
    "country": "AT",
    "name": "Schrems",
    "lat": "48.78333",
    "lng": "15.06667"
  },
  {
    "country": "AT",
    "name": "Schrattenthal",
    "lat": "48.7",
    "lng": "15.9"
  },
  {
    "country": "AT",
    "name": "Schrattenberg",
    "lat": "48.72359",
    "lng": "16.72201"
  },
  {
    "country": "AT",
    "name": "Schrattenbach",
    "lat": "47.77902",
    "lng": "15.9906"
  },
  {
    "country": "AT",
    "name": "Schottwien",
    "lat": "47.65683",
    "lng": "15.8725"
  },
  {
    "country": "AT",
    "name": "Schörfling",
    "lat": "47.94544",
    "lng": "13.60408"
  },
  {
    "country": "AT",
    "name": "Schoppernau",
    "lat": "47.31205",
    "lng": "10.01646"
  },
  {
    "country": "AT",
    "name": "Schönwies",
    "lat": "47.19665",
    "lng": "10.65742"
  },
  {
    "country": "AT",
    "name": "Schönering",
    "lat": "48.29838",
    "lng": "14.16103"
  },
  {
    "country": "AT",
    "name": "Schöndorf",
    "lat": "48.00167",
    "lng": "13.6588"
  },
  {
    "country": "AT",
    "name": "Schönberg im Stubaital",
    "lat": "47.18333",
    "lng": "11.41667"
  },
  {
    "country": "AT",
    "name": "Schönbach",
    "lat": "48.45",
    "lng": "15.03333"
  },
  {
    "country": "AT",
    "name": "Schönau an der Triesting",
    "lat": "47.93452",
    "lng": "16.25376"
  },
  {
    "country": "AT",
    "name": "Schöder",
    "lat": "47.18333",
    "lng": "14.1"
  },
  {
    "country": "AT",
    "name": "Schnifis",
    "lat": "47.21667",
    "lng": "9.73306"
  },
  {
    "country": "AT",
    "name": "Schnepfau",
    "lat": "47.35206",
    "lng": "9.9452"
  },
  {
    "country": "AT",
    "name": "Schmirn",
    "lat": "47.08333",
    "lng": "11.56667"
  },
  {
    "country": "AT",
    "name": "Schlüsslberg",
    "lat": "48.21861",
    "lng": "13.87161"
  },
  {
    "country": "AT",
    "name": "Schlitters",
    "lat": "47.38045",
    "lng": "11.83888"
  },
  {
    "country": "AT",
    "name": "Schlins",
    "lat": "47.2",
    "lng": "9.7"
  },
  {
    "country": "AT",
    "name": "Schlierbach",
    "lat": "47.93636",
    "lng": "14.12018"
  },
  {
    "country": "AT",
    "name": "Schleinbach",
    "lat": "48.41667",
    "lng": "16.46667"
  },
  {
    "country": "AT",
    "name": "Schleedorf",
    "lat": "47.95",
    "lng": "13.15"
  },
  {
    "country": "AT",
    "name": "Schlatt",
    "lat": "48.07177",
    "lng": "13.78904"
  },
  {
    "country": "AT",
    "name": "Schladming",
    "lat": "47.39289",
    "lng": "13.68699"
  },
  {
    "country": "AT",
    "name": "Schildorn",
    "lat": "48.14564",
    "lng": "13.46314"
  },
  {
    "country": "AT",
    "name": "Schiefling am See",
    "lat": "46.60444",
    "lng": "14.0975"
  },
  {
    "country": "AT",
    "name": "Schenkenfelden",
    "lat": "48.50273",
    "lng": "14.36188"
  },
  {
    "country": "AT",
    "name": "Scheifling",
    "lat": "47.15044",
    "lng": "14.41278"
  },
  {
    "country": "AT",
    "name": "Scheibbs",
    "lat": "48.00474",
    "lng": "15.16817"
  },
  {
    "country": "AT",
    "name": "Scheffau am Wilden Kaiser",
    "lat": "47.52943",
    "lng": "12.25139"
  },
  {
    "country": "AT",
    "name": "Scheffau am Tennengebirge",
    "lat": "47.58831",
    "lng": "13.2202"
  },
  {
    "country": "AT",
    "name": "Schattwald",
    "lat": "47.51427",
    "lng": "10.46143"
  },
  {
    "country": "AT",
    "name": "Schattendorf",
    "lat": "47.70973",
    "lng": "16.50979"
  },
  {
    "country": "AT",
    "name": "Scharnstein",
    "lat": "47.90426",
    "lng": "13.96135"
  },
  {
    "country": "AT",
    "name": "Scharnitz",
    "lat": "47.38899",
    "lng": "11.26455"
  },
  {
    "country": "AT",
    "name": "Scharndorf",
    "lat": "48.09399",
    "lng": "16.79883"
  },
  {
    "country": "AT",
    "name": "Schärding",
    "lat": "48.45294",
    "lng": "13.43722"
  },
  {
    "country": "AT",
    "name": "Schardenberg",
    "lat": "48.52058",
    "lng": "13.49791"
  },
  {
    "country": "AT",
    "name": "Schandorf",
    "lat": "47.24183",
    "lng": "16.42267"
  },
  {
    "country": "AT",
    "name": "Schalchham",
    "lat": "47.99825",
    "lng": "13.67188"
  },
  {
    "country": "AT",
    "name": "Schalchen",
    "lat": "48.11924",
    "lng": "13.15716"
  },
  {
    "country": "AT",
    "name": "Schafwiesen",
    "lat": "48.16667",
    "lng": "14.06667"
  },
  {
    "country": "AT",
    "name": "Schäffern",
    "lat": "47.47771",
    "lng": "16.10956"
  },
  {
    "country": "AT",
    "name": "Schachendorf",
    "lat": "47.26667",
    "lng": "16.43333"
  },
  {
    "country": "AT",
    "name": "Sautens",
    "lat": "47.2",
    "lng": "10.86667"
  },
  {
    "country": "AT",
    "name": "Bad Sauerbrunn",
    "lat": "47.77439",
    "lng": "16.32841"
  },
  {
    "country": "AT",
    "name": "Sattledt",
    "lat": "48.07372",
    "lng": "14.05478"
  },
  {
    "country": "AT",
    "name": "Satteins",
    "lat": "47.21667",
    "lng": "9.66667"
  },
  {
    "country": "AT",
    "name": "Sarleinsbach",
    "lat": "48.54525",
    "lng": "13.90491"
  },
  {
    "country": "AT",
    "name": "Sankt Wolfgang im Salzkammergut",
    "lat": "47.73932",
    "lng": "13.44666"
  },
  {
    "country": "AT",
    "name": "Sankt Veit in Defereggen",
    "lat": "46.92722",
    "lng": "12.42972"
  },
  {
    "country": "AT",
    "name": "Sankt Veit im Pongau",
    "lat": "47.33333",
    "lng": "13.15"
  },
  {
    "country": "AT",
    "name": "Sankt Veit an der Gölsen",
    "lat": "48.0432",
    "lng": "15.66942"
  },
  {
    "country": "AT",
    "name": "Sankt Veit an der Glan",
    "lat": "46.76806",
    "lng": "14.36028"
  },
  {
    "country": "AT",
    "name": "Sankt Veit am Vogau",
    "lat": "46.74048",
    "lng": "15.64217"
  },
  {
    "country": "AT",
    "name": "Sankt Valentin",
    "lat": "48.16667",
    "lng": "14.51667"
  },
  {
    "country": "AT",
    "name": "Sankt Ulrich bei Steyr",
    "lat": "48.02116",
    "lng": "14.43685"
  },
  {
    "country": "AT",
    "name": "Sankt Ulrich am Waasen",
    "lat": "46.93333",
    "lng": "15.53333"
  },
  {
    "country": "AT",
    "name": "Sankt Ulrich am Pillersee",
    "lat": "47.5274",
    "lng": "12.57239"
  },
  {
    "country": "AT",
    "name": "Sankt Stefan ob Stainz",
    "lat": "46.92861",
    "lng": "15.25889"
  },
  {
    "country": "AT",
    "name": "Sankt Stefan ob Leoben",
    "lat": "47.31672",
    "lng": "14.97831"
  },
  {
    "country": "AT",
    "name": "Sankt Stefan im Rosental",
    "lat": "46.90389",
    "lng": "15.71"
  },
  {
    "country": "AT",
    "name": "Sankt Stefan",
    "lat": "46.8075",
    "lng": "14.85167"
  },
  {
    "country": "AT",
    "name": "Sankt Ruprecht an der Raab",
    "lat": "47.15336",
    "lng": "15.66256"
  },
  {
    "country": "AT",
    "name": "Sankt Ruprecht",
    "lat": "46.6",
    "lng": "14.31667"
  },
  {
    "country": "AT",
    "name": "Sankt Roman",
    "lat": "48.48183",
    "lng": "13.61056"
  },
  {
    "country": "AT",
    "name": "Sankt Radegund bei Graz",
    "lat": "47.18172",
    "lng": "15.49192"
  },
  {
    "country": "AT",
    "name": "Sankt Pölten",
    "lat": "48.2",
    "lng": "15.63333"
  },
  {
    "country": "AT",
    "name": "Sankt Peter ob Judenburg",
    "lat": "47.18417",
    "lng": "14.58639"
  },
  {
    "country": "AT",
    "name": "Sankt Peter in der Au Markt",
    "lat": "48.044",
    "lng": "14.62182"
  },
  {
    "country": "AT",
    "name": "Sankt Peter im Sulmtal",
    "lat": "46.75",
    "lng": "15.25"
  },
  {
    "country": "AT",
    "name": "Sankt Peter-Freienstein",
    "lat": "47.38333",
    "lng": "15.01667"
  },
  {
    "country": "AT",
    "name": "Sankt Peter am Ottersbach",
    "lat": "46.79778",
    "lng": "15.75917"
  },
  {
    "country": "AT",
    "name": "Sankt Peter am Kammersberg",
    "lat": "47.18706",
    "lng": "14.18464"
  },
  {
    "country": "AT",
    "name": "Sankt Peter",
    "lat": "47.05",
    "lng": "15.46667"
  },
  {
    "country": "AT",
    "name": "Sankt Peter",
    "lat": "46.62978",
    "lng": "14.34016"
  },
  {
    "country": "AT",
    "name": "Sankt Peter am Hart",
    "lat": "48.25268",
    "lng": "13.09613"
  },
  {
    "country": "AT",
    "name": "Sankt Paul im Levanttal",
    "lat": "46.70056",
    "lng": "14.87556"
  },
  {
    "country": "AT",
    "name": "Sankt Pantaleon",
    "lat": "48.21058",
    "lng": "14.56804"
  },
  {
    "country": "AT",
    "name": "Sankt Oswald bei Plankenwarth",
    "lat": "47.08701",
    "lng": "15.27703"
  },
  {
    "country": "AT",
    "name": "Sankt Oswald bei Freistadt",
    "lat": "48.5",
    "lng": "14.58333"
  },
  {
    "country": "AT",
    "name": "Sankt Nikolai ob Draßling",
    "lat": "46.80889",
    "lng": "15.65083"
  },
  {
    "country": "AT",
    "name": "Sankt Nikolai im Sölktal",
    "lat": "47.31667",
    "lng": "14.05"
  },
  {
    "country": "AT",
    "name": "Sankt Nikolai im Sausal",
    "lat": "46.82111",
    "lng": "15.45194"
  },
  {
    "country": "AT",
    "name": "Sankt Michael in Obersteiermark",
    "lat": "47.33839",
    "lng": "15.01784"
  },
  {
    "country": "AT",
    "name": "Sankt Michael im Lungau",
    "lat": "47.1",
    "lng": "13.63333"
  },
  {
    "country": "AT",
    "name": "Sankt Michael im Burgenland",
    "lat": "47.12852",
    "lng": "16.27148"
  },
  {
    "country": "AT",
    "name": "Sankt Martin im Sulmtal",
    "lat": "46.75611",
    "lng": "15.29722"
  },
  {
    "country": "AT",
    "name": "Sankt Martin im Mühlkreis",
    "lat": "48.41553",
    "lng": "14.03821"
  },
  {
    "country": "AT",
    "name": "Sankt Martin im Innkreis",
    "lat": "48.29387",
    "lng": "13.43868"
  },
  {
    "country": "AT",
    "name": "Sankt Martin bei Lofer",
    "lat": "47.56667",
    "lng": "12.7"
  },
  {
    "country": "AT",
    "name": "Sankt Martin an der Raab",
    "lat": "46.9225",
    "lng": "16.13611"
  },
  {
    "country": "AT",
    "name": "Sankt Martin am Ybbsfelde",
    "lat": "48.16425",
    "lng": "15.02076"
  },
  {
    "country": "AT",
    "name": "Sankt Martin am Grimming",
    "lat": "47.48873",
    "lng": "13.98105"
  },
  {
    "country": "AT",
    "name": "Sankt Martin",
    "lat": "46.61667",
    "lng": "14.28333"
  },
  {
    "country": "AT",
    "name": "Sankt Martin",
    "lat": "46.61721",
    "lng": "13.82879"
  },
  {
    "country": "AT",
    "name": "Sankt Martin",
    "lat": "48.23091",
    "lng": "14.26781"
  },
  {
    "country": "AT",
    "name": "Sankt Martin",
    "lat": "47.44667",
    "lng": "15.2849"
  },
  {
    "country": "AT",
    "name": "Sankt Marien",
    "lat": "48.14805",
    "lng": "14.27759"
  },
  {
    "country": "AT",
    "name": "Sankt Margareten im Rosental",
    "lat": "46.54417",
    "lng": "14.42444"
  },
  {
    "country": "AT",
    "name": "Sankt Margarethen im Lungau",
    "lat": "47.07927",
    "lng": "13.69613"
  },
  {
    "country": "AT",
    "name": "Sankt Margarethen im Burgenland",
    "lat": "47.80335",
    "lng": "16.60875"
  },
  {
    "country": "AT",
    "name": "Sankt Margarethen bei Knittelfeld",
    "lat": "47.21667",
    "lng": "14.86667"
  },
  {
    "country": "AT",
    "name": "Sankt Margarethen an der Sierning",
    "lat": "48.1591",
    "lng": "15.49055"
  },
  {
    "country": "AT",
    "name": "Sankt Margarethen an der Raab",
    "lat": "47.05",
    "lng": "15.75"
  },
  {
    "country": "AT",
    "name": "Sankt Marein im Mürztal",
    "lat": "47.46667",
    "lng": "15.36667"
  },
  {
    "country": "AT",
    "name": "Sankt Marein bei Neumarkt",
    "lat": "47.06591",
    "lng": "14.42908"
  },
  {
    "country": "AT",
    "name": "Sankt Marein bei Knittelfeld",
    "lat": "47.27396",
    "lng": "14.86085"
  },
  {
    "country": "AT",
    "name": "Sankt Marein bei Graz",
    "lat": "47.01583",
    "lng": "15.68389"
  },
  {
    "country": "AT",
    "name": "Sankt Magdalen",
    "lat": "46.61667",
    "lng": "13.88333"
  },
  {
    "country": "AT",
    "name": "Sankt Lorenzen im Mürztal",
    "lat": "47.48333",
    "lng": "15.36667"
  },
  {
    "country": "AT",
    "name": "Sankt Lorenzen bei Scheifling",
    "lat": "47.14556",
    "lng": "14.40583"
  },
  {
    "country": "AT",
    "name": "Sankt Lorenzen bei Knittelfeld",
    "lat": "47.25078",
    "lng": "14.89549"
  },
  {
    "country": "AT",
    "name": "Sankt Lorenzen am Wechsel",
    "lat": "47.44153",
    "lng": "15.95498"
  },
  {
    "country": "AT",
    "name": "Sankt Lorenz",
    "lat": "47.8324",
    "lng": "13.34839"
  },
  {
    "country": "AT",
    "name": "Sankt Leonhard am Hornerwald",
    "lat": "48.6",
    "lng": "15.53333"
  },
  {
    "country": "AT",
    "name": "Sankt Leonhard am Forst",
    "lat": "48.14232",
    "lng": "15.28464"
  },
  {
    "country": "AT",
    "name": "Sankt Leonhard",
    "lat": "47.72587",
    "lng": "13.04577"
  },
  {
    "country": "AT",
    "name": "Sankt Leonhard",
    "lat": "46.62528",
    "lng": "13.85865"
  },
  {
    "country": "AT",
    "name": "Sankt Lambrecht",
    "lat": "47.06667",
    "lng": "14.3"
  },
  {
    "country": "AT",
    "name": "Sankt Kathrein am Offenegg",
    "lat": "47.3",
    "lng": "15.58333"
  },
  {
    "country": "AT",
    "name": "Sankt Kathrein am Hauenstein",
    "lat": "47.48943",
    "lng": "15.69414"
  },
  {
    "country": "AT",
    "name": "Sankt Katharein an der Laming",
    "lat": "47.47069",
    "lng": "15.16319"
  },
  {
    "country": "AT",
    "name": "Sankt Josef (Weststeiermark)",
    "lat": "46.90917",
    "lng": "15.33639"
  },
  {
    "country": "AT",
    "name": "Sankt Johann in Tirol",
    "lat": "47.5233",
    "lng": "12.4232"
  },
  {
    "country": "AT",
    "name": "Sankt Johann in der Haide",
    "lat": "47.2808",
    "lng": "16.02579"
  },
  {
    "country": "AT",
    "name": "Sankt Johann im Saggautal",
    "lat": "46.70389",
    "lng": "15.40278"
  },
  {
    "country": "AT",
    "name": "Sankt Johann im Pongau",
    "lat": "47.35",
    "lng": "13.2"
  },
  {
    "country": "AT",
    "name": "Sankt Johann bei Herberstein",
    "lat": "47.2",
    "lng": "15.8"
  },
  {
    "country": "AT",
    "name": "Sankt Johann am Tauern",
    "lat": "47.35",
    "lng": "14.46667"
  },
  {
    "country": "AT",
    "name": "Sankt Jakob im Walde",
    "lat": "47.46667",
    "lng": "15.78333"
  },
  {
    "country": "AT",
    "name": "Sankt Jakob-Breitenau",
    "lat": "47.39229",
    "lng": "15.4297"
  },
  {
    "country": "AT",
    "name": "Sankt Ilgen",
    "lat": "47.55",
    "lng": "15.16667"
  },
  {
    "country": "AT",
    "name": "Sankt Gotthard im Mühlkreis",
    "lat": "48.3802",
    "lng": "14.13185"
  },
  {
    "country": "AT",
    "name": "Sankt Gilgen",
    "lat": "47.76667",
    "lng": "13.36667"
  },
  {
    "country": "AT",
    "name": "Sankt Georgen ob Murau",
    "lat": "47.1",
    "lng": "14.1"
  },
  {
    "country": "AT",
    "name": "Sankt Georgen ob Judenburg",
    "lat": "47.20744",
    "lng": "14.49736"
  },
  {
    "country": "AT",
    "name": "Sankt Georgen im Attergau",
    "lat": "47.93595",
    "lng": "13.48306"
  },
  {
    "country": "AT",
    "name": "Sankt Georgen bei Obernberg am Inn",
    "lat": "48.29193",
    "lng": "13.3332"
  },
  {
    "country": "AT",
    "name": "Sankt Georgen an der Stiefing",
    "lat": "46.87333",
    "lng": "15.57972"
  },
  {
    "country": "AT",
    "name": "Sankt Georgen an der Leys",
    "lat": "48.03149",
    "lng": "15.22722"
  },
  {
    "country": "AT",
    "name": "Sankt Georgen an der Gusen",
    "lat": "48.27183",
    "lng": "14.44951"
  },
  {
    "country": "AT",
    "name": "Sankt Georgen am Ybbsfelde",
    "lat": "48.12892",
    "lng": "14.95364"
  },
  {
    "country": "AT",
    "name": "Sankt Georgen am Leithagebirge",
    "lat": "47.85",
    "lng": "16.55"
  },
  {
    "country": "AT",
    "name": "Sankt Georgen am Fillmannsbach",
    "lat": "48.1256",
    "lng": "13.00811"
  },
  {
    "country": "AT",
    "name": "Sankt Gallenkirch",
    "lat": "47.02102",
    "lng": "9.97335"
  },
  {
    "country": "AT",
    "name": "Sankt Gallen",
    "lat": "47.68631",
    "lng": "14.61705"
  },
  {
    "country": "AT",
    "name": "Sankt Dionysen",
    "lat": "48.22439",
    "lng": "14.25485"
  },
  {
    "country": "AT",
    "name": "Sankt Corona am Wechsel",
    "lat": "47.58333",
    "lng": "16"
  },
  {
    "country": "AT",
    "name": "Sankt Blasen",
    "lat": "47.08333",
    "lng": "14.3"
  },
  {
    "country": "AT",
    "name": "Sankt Bartholomä",
    "lat": "47.05457",
    "lng": "15.25889"
  },
  {
    "country": "AT",
    "name": "Sankt Anton im Montafon",
    "lat": "47.11667",
    "lng": "9.86667"
  },
  {
    "country": "AT",
    "name": "St Anton am Arlberg",
    "lat": "47.1275",
    "lng": "10.26372"
  },
  {
    "country": "AT",
    "name": "Sankt Anna am Aigen",
    "lat": "46.83111",
    "lng": "15.97139"
  },
  {
    "country": "AT",
    "name": "Sankt Andrä vor dem Hagenthale",
    "lat": "48.32202",
    "lng": "16.20724"
  },
  {
    "country": "AT",
    "name": "Sankt Andrä im Lungau",
    "lat": "47.15",
    "lng": "13.78333"
  },
  {
    "country": "AT",
    "name": "Sankt Andrä am Zicksee",
    "lat": "47.7841",
    "lng": "16.94195"
  },
  {
    "country": "AT",
    "name": "Sankt Andrä",
    "lat": "46.76829",
    "lng": "14.81991"
  },
  {
    "country": "AT",
    "name": "Sankt Aegyd am Neuwalde",
    "lat": "47.85383",
    "lng": "15.56969"
  },
  {
    "country": "AT",
    "name": "Sankt Aegidi",
    "lat": "48.47929",
    "lng": "13.73737"
  },
  {
    "country": "AT",
    "name": "Sammersdorf",
    "lat": "48.18091",
    "lng": "14.1667"
  },
  {
    "country": "AT",
    "name": "Salzburg",
    "lat": "47.79941",
    "lng": "13.04399"
  },
  {
    "country": "AT",
    "name": "Sallingberg",
    "lat": "48.46667",
    "lng": "15.23333"
  },
  {
    "country": "AT",
    "name": "Salla",
    "lat": "47.1",
    "lng": "14.96667"
  },
  {
    "country": "AT",
    "name": "Sachsenburg",
    "lat": "46.82917",
    "lng": "13.355"
  },
  {
    "country": "AT",
    "name": "Saalfelden am Steinernen Meer",
    "lat": "47.42681",
    "lng": "12.848"
  },
  {
    "country": "AT",
    "name": "Saalbach",
    "lat": "47.39138",
    "lng": "12.63642"
  },
  {
    "country": "AT",
    "name": "Rutzenham",
    "lat": "48.06076",
    "lng": "13.71883"
  },
  {
    "country": "AT",
    "name": "Rüstorf",
    "lat": "48.04326",
    "lng": "13.78982"
  },
  {
    "country": "AT",
    "name": "Rust",
    "lat": "47.80122",
    "lng": "16.67158"
  },
  {
    "country": "AT",
    "name": "Ruprechtshofen",
    "lat": "48.13648",
    "lng": "15.27675"
  },
  {
    "country": "AT",
    "name": "Rum",
    "lat": "47.28333",
    "lng": "11.45"
  },
  {
    "country": "AT",
    "name": "Rufling",
    "lat": "48.27839",
    "lng": "14.21674"
  },
  {
    "country": "AT",
    "name": "Rudersdorf",
    "lat": "47.05",
    "lng": "16.11667"
  },
  {
    "country": "AT",
    "name": "Ruden",
    "lat": "46.65833",
    "lng": "14.77639"
  },
  {
    "country": "AT",
    "name": "Rottenmann",
    "lat": "47.51667",
    "lng": "14.35"
  },
  {
    "country": "AT",
    "name": "Röthis",
    "lat": "47.29332",
    "lng": "9.65484"
  },
  {
    "country": "AT",
    "name": "Röthelstein",
    "lat": "47.31667",
    "lng": "15.36667"
  },
  {
    "country": "AT",
    "name": "Rotenturm an der Pinka",
    "lat": "47.25",
    "lng": "16.25"
  },
  {
    "country": "AT",
    "name": "Rosenau am Sonntagberg",
    "lat": "48.00778",
    "lng": "14.73927"
  },
  {
    "country": "AT",
    "name": "Rosegg",
    "lat": "46.58833",
    "lng": "14.01718"
  },
  {
    "country": "AT",
    "name": "Röschitz",
    "lat": "48.64312",
    "lng": "15.81774"
  },
  {
    "country": "AT",
    "name": "Roppen",
    "lat": "47.21667",
    "lng": "10.81667"
  },
  {
    "country": "AT",
    "name": "Röns",
    "lat": "47.21667",
    "lng": "9.7"
  },
  {
    "country": "AT",
    "name": "Roitham",
    "lat": "48.02432",
    "lng": "13.82166"
  },
  {
    "country": "AT",
    "name": "Rohr im Gebirge",
    "lat": "47.89471",
    "lng": "15.73603"
  },
  {
    "country": "AT",
    "name": "Rohr im Burgenland",
    "lat": "47.11667",
    "lng": "16.16667"
  },
  {
    "country": "AT",
    "name": "Röhrenbach",
    "lat": "48.65",
    "lng": "15.5"
  },
  {
    "country": "AT",
    "name": "Rohrbach in Oberösterreich",
    "lat": "48.57275",
    "lng": "13.98834"
  },
  {
    "country": "AT",
    "name": "Rohrbach bei Mattersburg",
    "lat": "47.7052",
    "lng": "16.43005"
  },
  {
    "country": "AT",
    "name": "Rohrbach an der Lafnitz",
    "lat": "47.38333",
    "lng": "16"
  },
  {
    "country": "AT",
    "name": "Rohrau",
    "lat": "48.06667",
    "lng": "16.85"
  },
  {
    "country": "AT",
    "name": "Ritzing",
    "lat": "47.61316",
    "lng": "16.49546"
  },
  {
    "country": "AT",
    "name": "Rinn",
    "lat": "47.25",
    "lng": "11.5"
  },
  {
    "country": "AT",
    "name": "Riezlern",
    "lat": "47.35778",
    "lng": "10.18759"
  },
  {
    "country": "AT",
    "name": "Rietz",
    "lat": "47.28593",
    "lng": "11.03075"
  },
  {
    "country": "AT",
    "name": "Ries",
    "lat": "47.08315",
    "lng": "15.485"
  },
  {
    "country": "AT",
    "name": "Riegersburg",
    "lat": "47",
    "lng": "15.93028"
  },
  {
    "country": "AT",
    "name": "Riefensberg",
    "lat": "47.50137",
    "lng": "9.95838"
  },
  {
    "country": "AT",
    "name": "Riedlingsdorf",
    "lat": "47.35",
    "lng": "16.13333"
  },
  {
    "country": "AT",
    "name": "Ried in der Riedmark",
    "lat": "48.27114",
    "lng": "14.52796"
  },
  {
    "country": "AT",
    "name": "Ried im Traunkreis",
    "lat": "48.02581",
    "lng": "14.07452"
  },
  {
    "country": "AT",
    "name": "Ried im Oberinntal",
    "lat": "47.05",
    "lng": "10.65"
  },
  {
    "country": "AT",
    "name": "Ried im Innkreis",
    "lat": "48.21123",
    "lng": "13.48855"
  },
  {
    "country": "AT",
    "name": "Reutte",
    "lat": "47.48333",
    "lng": "10.71667"
  },
  {
    "country": "AT",
    "name": "Reuthe",
    "lat": "47.37113",
    "lng": "9.89481"
  },
  {
    "country": "AT",
    "name": "Retznei",
    "lat": "46.73333",
    "lng": "15.56667"
  },
  {
    "country": "AT",
    "name": "Retz",
    "lat": "48.75712",
    "lng": "15.95485"
  },
  {
    "country": "AT",
    "name": "Rettenschöss",
    "lat": "47.65718",
    "lng": "12.26872"
  },
  {
    "country": "AT",
    "name": "Rettenegg",
    "lat": "47.52694",
    "lng": "15.78104"
  },
  {
    "country": "AT",
    "name": "Rennweg am Katschberg",
    "lat": "47.01667",
    "lng": "13.61667"
  },
  {
    "country": "AT",
    "name": "Reith bei Seefeld",
    "lat": "47.3",
    "lng": "11.2"
  },
  {
    "country": "AT",
    "name": "Reith bei Kitzbühel",
    "lat": "47.46667",
    "lng": "12.35"
  },
  {
    "country": "AT",
    "name": "Reith im Alpbachtal",
    "lat": "47.41694",
    "lng": "11.87785"
  },
  {
    "country": "AT",
    "name": "Reiterndorf",
    "lat": "47.70364",
    "lng": "13.62914"
  },
  {
    "country": "AT",
    "name": "Reisenberg",
    "lat": "47.99406",
    "lng": "16.52018"
  },
  {
    "country": "AT",
    "name": "Reinsberg",
    "lat": "47.98567",
    "lng": "15.07067"
  },
  {
    "country": "AT",
    "name": "Reingers",
    "lat": "48.96667",
    "lng": "15.13333"
  },
  {
    "country": "AT",
    "name": "Reifling",
    "lat": "47.13333",
    "lng": "14.66667"
  },
  {
    "country": "AT",
    "name": "Reichraming",
    "lat": "47.88333",
    "lng": "14.45"
  },
  {
    "country": "AT",
    "name": "Reichenthal",
    "lat": "48.54286",
    "lng": "14.38471"
  },
  {
    "country": "AT",
    "name": "Reichenfels",
    "lat": "47.00718",
    "lng": "14.74425"
  },
  {
    "country": "AT",
    "name": "Reichendorf",
    "lat": "47.18922",
    "lng": "15.7616"
  },
  {
    "country": "AT",
    "name": "Reichenau im Mühlkreis",
    "lat": "48.45704",
    "lng": "14.34875"
  },
  {
    "country": "AT",
    "name": "Reichenau an der Rax",
    "lat": "47.69509",
    "lng": "15.84572"
  },
  {
    "country": "AT",
    "name": "Rehberg",
    "lat": "48.43114",
    "lng": "15.58702"
  },
  {
    "country": "AT",
    "name": "Redlham",
    "lat": "48.02443",
    "lng": "13.74738"
  },
  {
    "country": "AT",
    "name": "Redleiten",
    "lat": "48.08138",
    "lng": "13.46894"
  },
  {
    "country": "AT",
    "name": "Reding",
    "lat": "46.81667",
    "lng": "14.85"
  },
  {
    "country": "AT",
    "name": "Rechnitz",
    "lat": "47.30467",
    "lng": "16.44095"
  },
  {
    "country": "AT",
    "name": "Raxendorf",
    "lat": "48.34108",
    "lng": "15.27666"
  },
  {
    "country": "AT",
    "name": "Ravelsbach",
    "lat": "48.55",
    "lng": "15.85"
  },
  {
    "country": "AT",
    "name": "Rauris",
    "lat": "47.22656",
    "lng": "12.99459"
  },
  {
    "country": "AT",
    "name": "Rauchenwarth",
    "lat": "48.0833",
    "lng": "16.52794"
  },
  {
    "country": "AT",
    "name": "Rattenberg",
    "lat": "47.43941",
    "lng": "11.89407"
  },
  {
    "country": "AT",
    "name": "Ratten",
    "lat": "47.48333",
    "lng": "15.71667"
  },
  {
    "country": "AT",
    "name": "Ratschendorf",
    "lat": "46.74222",
    "lng": "15.81583"
  },
  {
    "country": "AT",
    "name": "Ratsch an der Weinstraße",
    "lat": "46.68944",
    "lng": "15.57111"
  },
  {
    "country": "AT",
    "name": "Rastenfeld",
    "lat": "48.57348",
    "lng": "15.33176"
  },
  {
    "country": "AT",
    "name": "Rassach",
    "lat": "46.86028",
    "lng": "15.27"
  },
  {
    "country": "AT",
    "name": "Rappottenstein",
    "lat": "48.52161",
    "lng": "15.07925"
  },
  {
    "country": "AT",
    "name": "Ranten",
    "lat": "47.15949",
    "lng": "14.08349"
  },
  {
    "country": "AT",
    "name": "Ranshofen",
    "lat": "48.23308",
    "lng": "13.01571"
  },
  {
    "country": "AT",
    "name": "Rannersdorf",
    "lat": "48.12772",
    "lng": "16.46379"
  },
  {
    "country": "AT",
    "name": "Rankweil",
    "lat": "47.27108",
    "lng": "9.64308"
  },
  {
    "country": "AT",
    "name": "Raning",
    "lat": "46.85",
    "lng": "15.81667"
  },
  {
    "country": "AT",
    "name": "Ranggen",
    "lat": "47.25727",
    "lng": "11.2112"
  },
  {
    "country": "AT",
    "name": "Rangersdorf",
    "lat": "46.86001",
    "lng": "12.94923"
  },
  {
    "country": "AT",
    "name": "Randegg",
    "lat": "48.01198",
    "lng": "14.97334"
  },
  {
    "country": "AT",
    "name": "Ramsau",
    "lat": "48.00313",
    "lng": "15.80332"
  },
  {
    "country": "AT",
    "name": "Ramsau am Dachstein",
    "lat": "47.4215",
    "lng": "13.65545"
  },
  {
    "country": "AT",
    "name": "Ramsau im Zillertal",
    "lat": "47.20383",
    "lng": "11.87545"
  },
  {
    "country": "AT",
    "name": "Ramingstein",
    "lat": "47.07462",
    "lng": "13.83642"
  },
  {
    "country": "AT",
    "name": "Rainbach im Mühlkreis",
    "lat": "48.55758",
    "lng": "14.47449"
  },
  {
    "country": "AT",
    "name": "Raiding",
    "lat": "47.56581",
    "lng": "16.53056"
  },
  {
    "country": "AT",
    "name": "Ragnitz",
    "lat": "46.83667",
    "lng": "15.59278"
  },
  {
    "country": "AT",
    "name": "Raggal",
    "lat": "47.21082",
    "lng": "9.83688"
  },
  {
    "country": "AT",
    "name": "Raffelstetten",
    "lat": "48.23759",
    "lng": "14.40273"
  },
  {
    "country": "AT",
    "name": "Radstadt",
    "lat": "47.38333",
    "lng": "13.45"
  },
  {
    "country": "AT",
    "name": "Bad Radkersburg",
    "lat": "46.68806",
    "lng": "15.98806"
  },
  {
    "country": "AT",
    "name": "Radfeld",
    "lat": "47.44806",
    "lng": "11.91424"
  },
  {
    "country": "AT",
    "name": "Radenthein",
    "lat": "46.80056",
    "lng": "13.71167"
  },
  {
    "country": "AT",
    "name": "Rachau",
    "lat": "47.21667",
    "lng": "14.9"
  },
  {
    "country": "AT",
    "name": "Rabenwald",
    "lat": "47.4",
    "lng": "15.9"
  },
  {
    "country": "AT",
    "name": "Rabenstein an der Pielach",
    "lat": "48.06535",
    "lng": "15.46772"
  },
  {
    "country": "AT",
    "name": "Rabensburg",
    "lat": "48.65",
    "lng": "16.9"
  },
  {
    "country": "AT",
    "name": "Raasdorf",
    "lat": "48.24657",
    "lng": "16.56532"
  },
  {
    "country": "AT",
    "name": "Raach am Hochgebirge",
    "lat": "47.63333",
    "lng": "15.93333"
  },
  {
    "country": "AT",
    "name": "Raabs an der Thaya",
    "lat": "48.85",
    "lng": "15.5"
  },
  {
    "country": "AT",
    "name": "Raabau",
    "lat": "46.96278",
    "lng": "15.91167"
  },
  {
    "country": "AT",
    "name": "Raaba",
    "lat": "47.03333",
    "lng": "15.5"
  },
  {
    "country": "AT",
    "name": "Raab",
    "lat": "48.35243",
    "lng": "13.64691"
  },
  {
    "country": "AT",
    "name": "Pyhra",
    "lat": "48.1591",
    "lng": "15.68624"
  },
  {
    "country": "AT",
    "name": "Pusterwald",
    "lat": "47.30611",
    "lng": "14.37556"
  },
  {
    "country": "AT",
    "name": "Purkersdorf",
    "lat": "48.20769",
    "lng": "16.17539"
  },
  {
    "country": "AT",
    "name": "Purgstall",
    "lat": "48.05841",
    "lng": "15.13478"
  },
  {
    "country": "AT",
    "name": "Purbach am Neusiedler See",
    "lat": "47.91289",
    "lng": "16.69561"
  },
  {
    "country": "AT",
    "name": "Puntigam",
    "lat": "47.03333",
    "lng": "15.43333"
  },
  {
    "country": "AT",
    "name": "Pulkau",
    "lat": "48.70484",
    "lng": "15.86031"
  },
  {
    "country": "AT",
    "name": "Pühret",
    "lat": "48.03488",
    "lng": "13.72252"
  },
  {
    "country": "AT",
    "name": "Pucking",
    "lat": "48.18886",
    "lng": "14.18824"
  },
  {
    "country": "AT",
    "name": "Puchheim",
    "lat": "48",
    "lng": "13.71667"
  },
  {
    "country": "AT",
    "name": "Puchenstuben",
    "lat": "47.92819",
    "lng": "15.28748"
  },
  {
    "country": "AT",
    "name": "Puchenau",
    "lat": "48.31214",
    "lng": "14.23614"
  },
  {
    "country": "AT",
    "name": "Puchberg am Schneeberg",
    "lat": "47.78709",
    "lng": "15.91352"
  },
  {
    "country": "AT",
    "name": "Puch bei Weiz",
    "lat": "47.21667",
    "lng": "15.71667"
  },
  {
    "country": "AT",
    "name": "Puch bei Hallein",
    "lat": "47.71536",
    "lng": "13.09296"
  },
  {
    "country": "AT",
    "name": "Prutz",
    "lat": "47.08333",
    "lng": "10.66667"
  },
  {
    "country": "AT",
    "name": "Pruggern",
    "lat": "47.4237",
    "lng": "13.87625"
  },
  {
    "country": "AT",
    "name": "Proleb",
    "lat": "47.4",
    "lng": "15.13333"
  },
  {
    "country": "AT",
    "name": "Prinzersdorf",
    "lat": "48.2",
    "lng": "15.51667"
  },
  {
    "country": "AT",
    "name": "Prigglitz",
    "lat": "47.70318",
    "lng": "15.92794"
  },
  {
    "country": "AT",
    "name": "Hofamt Priel",
    "lat": "48.19581",
    "lng": "15.07746"
  },
  {
    "country": "AT",
    "name": "Pressbaum",
    "lat": "48.18333",
    "lng": "16.08333"
  },
  {
    "country": "AT",
    "name": "Prellenkirchen",
    "lat": "48.07401",
    "lng": "16.95233"
  },
  {
    "country": "AT",
    "name": "Preitenegg",
    "lat": "46.94",
    "lng": "14.92583"
  },
  {
    "country": "AT",
    "name": "Pregarten",
    "lat": "48.35488",
    "lng": "14.53217"
  },
  {
    "country": "AT",
    "name": "Preding",
    "lat": "46.85861",
    "lng": "15.40972"
  },
  {
    "country": "AT",
    "name": "Pramet",
    "lat": "48.14295",
    "lng": "13.48752"
  },
  {
    "country": "AT",
    "name": "Prambachkirchen",
    "lat": "48.31711",
    "lng": "13.90449"
  },
  {
    "country": "AT",
    "name": "Pram",
    "lat": "48.23536",
    "lng": "13.60579"
  },
  {
    "country": "AT",
    "name": "Prägraten",
    "lat": "47.01667",
    "lng": "12.38333"
  },
  {
    "country": "AT",
    "name": "Pradl",
    "lat": "47.26539",
    "lng": "11.4152"
  },
  {
    "country": "AT",
    "name": "Poysdorf",
    "lat": "48.66667",
    "lng": "16.63333"
  },
  {
    "country": "AT",
    "name": "Potzneusiedl",
    "lat": "48.04504",
    "lng": "16.9477"
  },
  {
    "country": "AT",
    "name": "Pöttsching",
    "lat": "47.80445",
    "lng": "16.37109"
  },
  {
    "country": "AT",
    "name": "Pottschach",
    "lat": "47.69856",
    "lng": "16.00725"
  },
  {
    "country": "AT",
    "name": "Pötting",
    "lat": "48.28325",
    "lng": "13.77059"
  },
  {
    "country": "AT",
    "name": "Pottenstein",
    "lat": "47.9582",
    "lng": "16.0948"
  },
  {
    "country": "AT",
    "name": "Pottendorf",
    "lat": "47.9",
    "lng": "16.38333"
  },
  {
    "country": "AT",
    "name": "Pottenbrunn",
    "lat": "48.23333",
    "lng": "15.7"
  },
  {
    "country": "AT",
    "name": "Pöttelsdorf",
    "lat": "47.75369",
    "lng": "16.43864"
  },
  {
    "country": "AT",
    "name": "Pörtschach am Wörthersee",
    "lat": "46.63639",
    "lng": "14.14639"
  },
  {
    "country": "AT",
    "name": "Poppendorf",
    "lat": "46.85611",
    "lng": "15.85639"
  },
  {
    "country": "AT",
    "name": "Pöls",
    "lat": "47.21667",
    "lng": "14.58333"
  },
  {
    "country": "AT",
    "name": "Polling in Tirol",
    "lat": "47.28333",
    "lng": "11.15"
  },
  {
    "country": "AT",
    "name": "Pöllauberg",
    "lat": "47.31667",
    "lng": "15.85"
  },
  {
    "country": "AT",
    "name": "Pöllau",
    "lat": "47.3",
    "lng": "15.83333"
  },
  {
    "country": "AT",
    "name": "Pöggstall",
    "lat": "48.31734",
    "lng": "15.20405"
  },
  {
    "country": "AT",
    "name": "Poggersdorf",
    "lat": "46.65",
    "lng": "14.45"
  },
  {
    "country": "AT",
    "name": "Podersdorf am See",
    "lat": "47.85412",
    "lng": "16.83706"
  },
  {
    "country": "AT",
    "name": "Pöchlarn",
    "lat": "48.2",
    "lng": "15.2"
  },
  {
    "country": "AT",
    "name": "Plesching",
    "lat": "48.32099",
    "lng": "14.33802"
  },
  {
    "country": "AT",
    "name": "Plankenau",
    "lat": "47.32673",
    "lng": "13.19282"
  },
  {
    "country": "AT",
    "name": "Plainfeld",
    "lat": "47.83333",
    "lng": "13.18333"
  },
  {
    "country": "AT",
    "name": "Pitzenberg",
    "lat": "48.07361",
    "lng": "13.72484"
  },
  {
    "country": "AT",
    "name": "Pitten",
    "lat": "47.71667",
    "lng": "16.18333"
  },
  {
    "country": "AT",
    "name": "Pitschgau",
    "lat": "46.7",
    "lng": "15.26667"
  },
  {
    "country": "AT",
    "name": "Pistorf",
    "lat": "46.76667",
    "lng": "15.36667"
  },
  {
    "country": "AT",
    "name": "Pischelsdorf in der Steiermark",
    "lat": "47.17417",
    "lng": "15.80572"
  },
  {
    "country": "AT",
    "name": "Pirka",
    "lat": "47",
    "lng": "15.38333"
  },
  {
    "country": "AT",
    "name": "Piringsdorf",
    "lat": "47.44826",
    "lng": "16.41516"
  },
  {
    "country": "AT",
    "name": "Pirching am Traubenberg",
    "lat": "46.95",
    "lng": "15.6"
  },
  {
    "country": "AT",
    "name": "Pinsdorf",
    "lat": "47.9298",
    "lng": "13.77068"
  },
  {
    "country": "AT",
    "name": "Pinkafeld",
    "lat": "47.36667",
    "lng": "16.11667"
  },
  {
    "country": "AT",
    "name": "Pinggau",
    "lat": "47.44232",
    "lng": "16.06713"
  },
  {
    "country": "AT",
    "name": "Pillichsdorf",
    "lat": "48.35",
    "lng": "16.53333"
  },
  {
    "country": "AT",
    "name": "Pill",
    "lat": "47.32352",
    "lng": "11.68018"
  },
  {
    "country": "AT",
    "name": "Pilgersdorf",
    "lat": "47.44106",
    "lng": "16.3492"
  },
  {
    "country": "AT",
    "name": "Piesendorf",
    "lat": "47.29077",
    "lng": "12.71839"
  },
  {
    "country": "AT",
    "name": "Pierbach",
    "lat": "48.34815",
    "lng": "14.75575"
  },
  {
    "country": "AT",
    "name": "Pichling bei Köflach",
    "lat": "47.04785",
    "lng": "15.07098"
  },
  {
    "country": "AT",
    "name": "Pichl bei Wels",
    "lat": "48.18515",
    "lng": "13.89882"
  },
  {
    "country": "AT",
    "name": "Pichl",
    "lat": "47.28333",
    "lng": "12.85"
  },
  {
    "country": "AT",
    "name": "Piberegg",
    "lat": "47.09424",
    "lng": "15.11658"
  },
  {
    "country": "AT",
    "name": "Pians",
    "lat": "47.13486",
    "lng": "10.51237"
  },
  {
    "country": "AT",
    "name": "Pfunds",
    "lat": "46.96667",
    "lng": "10.55"
  },
  {
    "country": "AT",
    "name": "Pfons",
    "lat": "47.14201",
    "lng": "11.46071"
  },
  {
    "country": "AT",
    "name": "Pflach",
    "lat": "47.51667",
    "lng": "10.71667"
  },
  {
    "country": "AT",
    "name": "Pfarrkirchen bei Bad Hall",
    "lat": "48.03046",
    "lng": "14.19914"
  },
  {
    "country": "AT",
    "name": "Pfaffstätten",
    "lat": "48.01737",
    "lng": "16.26354"
  },
  {
    "country": "AT",
    "name": "Pfaffing",
    "lat": "48.018",
    "lng": "13.47507"
  },
  {
    "country": "AT",
    "name": "Pfaffenhofen",
    "lat": "47.3",
    "lng": "11.08333"
  },
  {
    "country": "AT",
    "name": "Peuerbach",
    "lat": "48.3453",
    "lng": "13.77205"
  },
  {
    "country": "AT",
    "name": "Petzenkirchen",
    "lat": "48.14693",
    "lng": "15.15465"
  },
  {
    "country": "AT",
    "name": "Pettneu",
    "lat": "47.14595",
    "lng": "10.33655"
  },
  {
    "country": "AT",
    "name": "Pettenbach",
    "lat": "47.96016",
    "lng": "14.01692"
  },
  {
    "country": "AT",
    "name": "Petronell-Carnuntum",
    "lat": "48.11296",
    "lng": "16.86582"
  },
  {
    "country": "AT",
    "name": "Perwang am Grabensee",
    "lat": "48.00692",
    "lng": "13.083"
  },
  {
    "country": "AT",
    "name": "Pertlstein",
    "lat": "46.94056",
    "lng": "15.96167"
  },
  {
    "country": "AT",
    "name": "Persenbeug",
    "lat": "48.18733",
    "lng": "15.08809"
  },
  {
    "country": "AT",
    "name": "Pernitz",
    "lat": "47.89759",
    "lng": "15.96022"
  },
  {
    "country": "AT",
    "name": "Pernersdorf",
    "lat": "48.7",
    "lng": "16.01667"
  },
  {
    "country": "AT",
    "name": "Pernegg an der Mur",
    "lat": "47.35979",
    "lng": "15.34236"
  },
  {
    "country": "AT",
    "name": "Pernegg",
    "lat": "48.73333",
    "lng": "15.61667"
  },
  {
    "country": "AT",
    "name": "Perlsdorf",
    "lat": "46.91361",
    "lng": "15.81417"
  },
  {
    "country": "AT",
    "name": "Perg",
    "lat": "48.25",
    "lng": "14.63333"
  },
  {
    "country": "AT",
    "name": "Perchtoldsdorf",
    "lat": "48.11935",
    "lng": "16.26607"
  },
  {
    "country": "AT",
    "name": "Perchau am Sattel",
    "lat": "47.1",
    "lng": "14.45"
  },
  {
    "country": "AT",
    "name": "Penz",
    "lat": "48.03333",
    "lng": "14.48333"
  },
  {
    "country": "AT",
    "name": "Pennewang",
    "lat": "48.13333",
    "lng": "13.85"
  },
  {
    "country": "AT",
    "name": "Peggau",
    "lat": "47.2",
    "lng": "15.35"
  },
  {
    "country": "AT",
    "name": "Payerbach",
    "lat": "47.69209",
    "lng": "15.8634"
  },
  {
    "country": "AT",
    "name": "Paudorf",
    "lat": "48.35416",
    "lng": "15.61853"
  },
  {
    "country": "AT",
    "name": "Pattigham",
    "lat": "48.15521",
    "lng": "13.48443"
  },
  {
    "country": "AT",
    "name": "Patsch",
    "lat": "47.20527",
    "lng": "11.4151"
  },
  {
    "country": "AT",
    "name": "Paternion",
    "lat": "46.71417",
    "lng": "13.63611"
  },
  {
    "country": "AT",
    "name": "Passail",
    "lat": "47.28333",
    "lng": "15.51667"
  },
  {
    "country": "AT",
    "name": "Pasching",
    "lat": "48.25931",
    "lng": "14.20369"
  },
  {
    "country": "AT",
    "name": "Parschlug",
    "lat": "47.4809",
    "lng": "15.28645"
  },
  {
    "country": "AT",
    "name": "Parndorf",
    "lat": "47.99963",
    "lng": "16.86049"
  },
  {
    "country": "AT",
    "name": "Parbasdorf",
    "lat": "48.28333",
    "lng": "16.6"
  },
  {
    "country": "AT",
    "name": "Pamhagen",
    "lat": "47.70092",
    "lng": "16.90779"
  },
  {
    "country": "AT",
    "name": "Pama",
    "lat": "48.05",
    "lng": "17.03333"
  },
  {
    "country": "AT",
    "name": "Palting",
    "lat": "48.01542",
    "lng": "13.12712"
  },
  {
    "country": "AT",
    "name": "Palfau",
    "lat": "47.7",
    "lng": "14.8"
  },
  {
    "country": "AT",
    "name": "Paldau",
    "lat": "46.94222",
    "lng": "15.79583"
  },
  {
    "country": "AT",
    "name": "Pack",
    "lat": "46.97917",
    "lng": "14.98417"
  },
  {
    "country": "AT",
    "name": "Pabneukirchen",
    "lat": "48.32367",
    "lng": "14.81747"
  },
  {
    "country": "AT",
    "name": "Oeynhausen",
    "lat": "47.98533",
    "lng": "16.29187"
  },
  {
    "country": "AT",
    "name": "Oetz",
    "lat": "47.2",
    "lng": "10.9"
  },
  {
    "country": "AT",
    "name": "Otterthal",
    "lat": "47.61667",
    "lng": "15.93333"
  },
  {
    "country": "AT",
    "name": "Ottenthal",
    "lat": "48.761",
    "lng": "16.57914"
  },
  {
    "country": "AT",
    "name": "Ottensheim",
    "lat": "48.33246",
    "lng": "14.17425"
  },
  {
    "country": "AT",
    "name": "Ottenschlag im Mühlkreis",
    "lat": "48.46632",
    "lng": "14.38471"
  },
  {
    "country": "AT",
    "name": "Ottenschlag",
    "lat": "48.42393",
    "lng": "15.21924"
  },
  {
    "country": "AT",
    "name": "Ottakring",
    "lat": "48.21667",
    "lng": "16.3"
  },
  {
    "country": "AT",
    "name": "Osterwitz",
    "lat": "46.85943",
    "lng": "15.08998"
  },
  {
    "country": "AT",
    "name": "Ostermiething",
    "lat": "48.04636",
    "lng": "12.82937"
  },
  {
    "country": "AT",
    "name": "Ossiach",
    "lat": "46.67435",
    "lng": "13.98358"
  },
  {
    "country": "AT",
    "name": "Oslip",
    "lat": "47.82906",
    "lng": "16.61957"
  },
  {
    "country": "AT",
    "name": "Ort im Innkreis",
    "lat": "48.31654",
    "lng": "13.43362"
  },
  {
    "country": "AT",
    "name": "Orth an der Donau",
    "lat": "48.14524",
    "lng": "16.70089"
  },
  {
    "country": "AT",
    "name": "Ortgraben",
    "lat": "47.45",
    "lng": "16.05"
  },
  {
    "country": "AT",
    "name": "Opponitz",
    "lat": "47.87776",
    "lng": "14.82283"
  },
  {
    "country": "AT",
    "name": "Oppenberg",
    "lat": "47.48333",
    "lng": "14.26667"
  },
  {
    "country": "AT",
    "name": "Ollersdorf im Burgenland",
    "lat": "47.18333",
    "lng": "16.16667"
  },
  {
    "country": "AT",
    "name": "Olbendorf",
    "lat": "47.18333",
    "lng": "16.2"
  },
  {
    "country": "AT",
    "name": "Ohlsdorf",
    "lat": "47.96073",
    "lng": "13.79145"
  },
  {
    "country": "AT",
    "name": "Oggau",
    "lat": "47.83333",
    "lng": "16.66667"
  },
  {
    "country": "AT",
    "name": "Offenhausen",
    "lat": "48.15",
    "lng": "13.83333"
  },
  {
    "country": "AT",
    "name": "Oepping",
    "lat": "48.60284",
    "lng": "13.94586"
  },
  {
    "country": "AT",
    "name": "Oehling",
    "lat": "48.1",
    "lng": "14.8"
  },
  {
    "country": "AT",
    "name": "Oedt",
    "lat": "48.21335",
    "lng": "14.21013"
  },
  {
    "country": "AT",
    "name": "Öblarn",
    "lat": "47.45938",
    "lng": "13.99023"
  },
  {
    "country": "AT",
    "name": "Oberzeiring",
    "lat": "47.25",
    "lng": "14.48333"
  },
  {
    "country": "AT",
    "name": "Oberwölz Stadt",
    "lat": "47.20117",
    "lng": "14.28321"
  },
  {
    "country": "AT",
    "name": "Oberwölbling",
    "lat": "48.31719",
    "lng": "15.59166"
  },
  {
    "country": "AT",
    "name": "Oberweg",
    "lat": "47.15",
    "lng": "14.63333"
  },
  {
    "country": "AT",
    "name": "Oberwart",
    "lat": "47.28971",
    "lng": "16.20595"
  },
  {
    "country": "AT",
    "name": "Oberwang",
    "lat": "47.86667",
    "lng": "13.43333"
  },
  {
    "country": "AT",
    "name": "Oberwaltersdorf",
    "lat": "47.97567",
    "lng": "16.32191"
  },
  {
    "country": "AT",
    "name": "Oberwagram",
    "lat": "48.20157",
    "lng": "15.64917"
  },
  {
    "country": "AT",
    "name": "Obervogau",
    "lat": "46.745",
    "lng": "15.58472"
  },
  {
    "country": "AT",
    "name": "Obervellach",
    "lat": "46.93667",
    "lng": "13.20417"
  },
  {
    "country": "AT",
    "name": "Obertrum am See",
    "lat": "47.93722",
    "lng": "13.07722"
  },
  {
    "country": "AT",
    "name": "Obertilliach",
    "lat": "46.71056",
    "lng": "12.61444"
  },
  {
    "country": "AT",
    "name": "Oberstorcha",
    "lat": "46.96667",
    "lng": "15.8"
  },
  {
    "country": "AT",
    "name": "Obersiebenbrunn",
    "lat": "48.26537",
    "lng": "16.71076"
  },
  {
    "country": "AT",
    "name": "Obersdorf",
    "lat": "48.36667",
    "lng": "16.51667"
  },
  {
    "country": "AT",
    "name": "Oberschützen",
    "lat": "47.35138",
    "lng": "16.20732"
  },
  {
    "country": "AT",
    "name": "Oberrettenbach",
    "lat": "47.15",
    "lng": "15.8"
  },
  {
    "country": "AT",
    "name": "Oberpullendorf",
    "lat": "47.50352",
    "lng": "16.50447"
  },
  {
    "country": "AT",
    "name": "Oberpremstätten",
    "lat": "46.97444",
    "lng": "15.40444"
  },
  {
    "country": "AT",
    "name": "Pettnau",
    "lat": "47.29204",
    "lng": "11.15962"
  },
  {
    "country": "AT",
    "name": "Oberneukirchen",
    "lat": "48.46404",
    "lng": "14.22275"
  },
  {
    "country": "AT",
    "name": "Oberndorf in Tirol",
    "lat": "47.5",
    "lng": "12.38333"
  },
  {
    "country": "AT",
    "name": "Oberndorf bei Schwanenstadt",
    "lat": "48.05559",
    "lng": "13.75677"
  },
  {
    "country": "AT",
    "name": "Oberndorf bei Salzburg",
    "lat": "47.95",
    "lng": "12.93333"
  },
  {
    "country": "AT",
    "name": "Oberndorf an der Melk",
    "lat": "48.06386",
    "lng": "15.2243"
  },
  {
    "country": "AT",
    "name": "Oberndorf in der Ebene",
    "lat": "48.2704",
    "lng": "15.68985"
  },
  {
    "country": "AT",
    "name": "Obernberg am Inn",
    "lat": "48.32133",
    "lng": "13.33427"
  },
  {
    "country": "AT",
    "name": "Obermieming",
    "lat": "47.3",
    "lng": "10.98333"
  },
  {
    "country": "AT",
    "name": "Oberloisdorf",
    "lat": "47.44736",
    "lng": "16.50764"
  },
  {
    "country": "AT",
    "name": "Oberlienz",
    "lat": "46.84722",
    "lng": "12.73139"
  },
  {
    "country": "AT",
    "name": "Oberkurzheim",
    "lat": "47.23333",
    "lng": "14.58333"
  },
  {
    "country": "AT",
    "name": "Oberhofen im Inntal",
    "lat": "47.3",
    "lng": "11.08333"
  },
  {
    "country": "AT",
    "name": "Oberhofen am Irrsee",
    "lat": "47.95",
    "lng": "13.3"
  },
  {
    "country": "AT",
    "name": "Oberhausen",
    "lat": "48.1769",
    "lng": "16.58506"
  },
  {
    "country": "AT",
    "name": "Oberhart",
    "lat": "48.18333",
    "lng": "14.05"
  },
  {
    "country": "AT",
    "name": "Oberhaag",
    "lat": "46.6869",
    "lng": "15.33202"
  },
  {
    "country": "AT",
    "name": "Ober-Grafendorf",
    "lat": "48.1504",
    "lng": "15.54531"
  },
  {
    "country": "AT",
    "name": "Oberdrauburg",
    "lat": "46.74306",
    "lng": "12.97028"
  },
  {
    "country": "AT",
    "name": "Oberdorf im Burgenland",
    "lat": "47.21667",
    "lng": "16.21667"
  },
  {
    "country": "AT",
    "name": "Oberdorf am Hochegg",
    "lat": "46.97861",
    "lng": "15.72167"
  },
  {
    "country": "AT",
    "name": "Aurach",
    "lat": "47.41223",
    "lng": "12.42734"
  },
  {
    "country": "AT",
    "name": "Oberau",
    "lat": "47.44336",
    "lng": "12.04891"
  },
  {
    "country": "AT",
    "name": "Oberalm",
    "lat": "47.7",
    "lng": "13.1"
  },
  {
    "country": "AT",
    "name": "Oberaich",
    "lat": "47.4",
    "lng": "15.21667"
  },
  {
    "country": "AT",
    "name": "Obdach",
    "lat": "47.06667",
    "lng": "14.68333"
  },
  {
    "country": "AT",
    "name": "Nüziders",
    "lat": "47.16667",
    "lng": "9.8"
  },
  {
    "country": "AT",
    "name": "Nußdorf am Haunsberg",
    "lat": "47.95944",
    "lng": "13.00917"
  },
  {
    "country": "AT",
    "name": "Nöchling",
    "lat": "48.22433",
    "lng": "14.98123"
  },
  {
    "country": "AT",
    "name": "Nitscha",
    "lat": "47.11667",
    "lng": "15.75"
  },
  {
    "country": "AT",
    "name": "Nikolsdorf",
    "lat": "46.78583",
    "lng": "12.91333"
  },
  {
    "country": "AT",
    "name": "Niklasdorf",
    "lat": "47.38333",
    "lng": "15.15"
  },
  {
    "country": "AT",
    "name": "Nikitsch",
    "lat": "47.53615",
    "lng": "16.66017"
  },
  {
    "country": "AT",
    "name": "Niederwölz",
    "lat": "47.15126",
    "lng": "14.37479"
  },
  {
    "country": "AT",
    "name": "Niederthalheim",
    "lat": "48.09901",
    "lng": "13.7687"
  },
  {
    "country": "AT",
    "name": "Niederöblarn",
    "lat": "47.47667",
    "lng": "14.01937"
  },
  {
    "country": "AT",
    "name": "Niedernsill",
    "lat": "47.28333",
    "lng": "12.65"
  },
  {
    "country": "AT",
    "name": "Niederneukirchen",
    "lat": "48.16093",
    "lng": "14.33965"
  },
  {
    "country": "AT",
    "name": "Niederndorf",
    "lat": "47.65",
    "lng": "12.21667"
  },
  {
    "country": "AT",
    "name": "Niederleis",
    "lat": "48.55",
    "lng": "16.4"
  },
  {
    "country": "AT",
    "name": "Niederhollabrunn",
    "lat": "48.43333",
    "lng": "16.3"
  },
  {
    "country": "AT",
    "name": "Niederdorf",
    "lat": "46.61667",
    "lng": "14.4"
  },
  {
    "country": "AT",
    "name": "Niederbreitenbach",
    "lat": "47.53333",
    "lng": "12.08333"
  },
  {
    "country": "AT",
    "name": "Niederau",
    "lat": "47.45",
    "lng": "12.08333"
  },
  {
    "country": "AT",
    "name": "Niederalm",
    "lat": "47.72872",
    "lng": "13.06223"
  },
  {
    "country": "AT",
    "name": "Nickelsdorf",
    "lat": "47.94056",
    "lng": "17.06944"
  },
  {
    "country": "AT",
    "name": "Neuzeug",
    "lat": "48.05",
    "lng": "14.33333"
  },
  {
    "country": "AT",
    "name": "Neutillmitsch",
    "lat": "46.81667",
    "lng": "15.53333"
  },
  {
    "country": "AT",
    "name": "Neutal",
    "lat": "47.54548",
    "lng": "16.44619"
  },
  {
    "country": "AT",
    "name": "Neustift im Stubaital",
    "lat": "47.11667",
    "lng": "11.31667"
  },
  {
    "country": "AT",
    "name": "Neustift bei Güssing",
    "lat": "47.02474",
    "lng": "16.26041"
  },
  {
    "country": "AT",
    "name": "Neustift an der Lafnitz",
    "lat": "47.36667",
    "lng": "16.03333"
  },
  {
    "country": "AT",
    "name": "Neusiedl an der Zaya",
    "lat": "48.5992",
    "lng": "16.7799"
  },
  {
    "country": "AT",
    "name": "Neusiedl am See",
    "lat": "47.94901",
    "lng": "16.8417"
  },
  {
    "country": "AT",
    "name": "Neusiedl",
    "lat": "47.88769",
    "lng": "15.96313"
  },
  {
    "country": "AT",
    "name": "Neunkirchen",
    "lat": "47.72096",
    "lng": "16.08107"
  },
  {
    "country": "AT",
    "name": "Neumarkt in Steiermark",
    "lat": "47.07398",
    "lng": "14.42728"
  },
  {
    "country": "AT",
    "name": "Neumarkt im Mühlkreis",
    "lat": "48.42818",
    "lng": "14.48444"
  },
  {
    "country": "AT",
    "name": "Neumarkt im Hausruckkreis",
    "lat": "48.2728",
    "lng": "13.72836"
  },
  {
    "country": "AT",
    "name": "Neumarkt an der Ybbs",
    "lat": "48.14103",
    "lng": "15.05758"
  },
  {
    "country": "AT",
    "name": "Neumarkt am Wallersee",
    "lat": "47.95",
    "lng": "13.23333"
  },
  {
    "country": "AT",
    "name": "Neulengbach",
    "lat": "48.19745",
    "lng": "15.90219"
  },
  {
    "country": "AT",
    "name": "Neukirchen bei Lambach",
    "lat": "48.1",
    "lng": "13.81667"
  },
  {
    "country": "AT",
    "name": "Neukirchen an der Vöckla",
    "lat": "48.04053",
    "lng": "13.5376"
  },
  {
    "country": "AT",
    "name": "Neukirchen am Walde",
    "lat": "48.40584",
    "lng": "13.78158"
  },
  {
    "country": "AT",
    "name": "Neukirchen am Großvenediger",
    "lat": "47.25046",
    "lng": "12.27585"
  },
  {
    "country": "AT",
    "name": "Neukirchen",
    "lat": "47.87502",
    "lng": "13.71111"
  },
  {
    "country": "AT",
    "name": "Neuhofen an der Ybbs",
    "lat": "48.05795",
    "lng": "14.85489"
  },
  {
    "country": "AT",
    "name": "Neuhofen an der Krems",
    "lat": "48.13866",
    "lng": "14.22764"
  },
  {
    "country": "AT",
    "name": "Neuhaus",
    "lat": "46.63333",
    "lng": "14.88333"
  },
  {
    "country": "AT",
    "name": "Neufeld an der Leitha",
    "lat": "47.86558",
    "lng": "16.37856"
  },
  {
    "country": "AT",
    "name": "Neudörfl",
    "lat": "47.79655",
    "lng": "16.2977"
  },
  {
    "country": "AT",
    "name": "Neudorf bei Staatz",
    "lat": "48.72083",
    "lng": "16.49139"
  },
  {
    "country": "AT",
    "name": "Neudau",
    "lat": "47.17554",
    "lng": "16.10184"
  },
  {
    "country": "AT",
    "name": "Neuberg an der Mürz",
    "lat": "47.66423",
    "lng": "15.57226"
  },
  {
    "country": "AT",
    "name": "Nestelbach im Ilztal",
    "lat": "47.08333",
    "lng": "15.86667"
  },
  {
    "country": "AT",
    "name": "Nestelbach bei Graz",
    "lat": "47.06053",
    "lng": "15.6114"
  },
  {
    "country": "AT",
    "name": "Nesselwängle",
    "lat": "47.48333",
    "lng": "10.61667"
  },
  {
    "country": "AT",
    "name": "Nenzing",
    "lat": "47.18436",
    "lng": "9.70539"
  },
  {
    "country": "AT",
    "name": "Neidling",
    "lat": "48.24005",
    "lng": "15.55591"
  },
  {
    "country": "AT",
    "name": "Neckenmarkt",
    "lat": "47.59964",
    "lng": "16.5467"
  },
  {
    "country": "AT",
    "name": "Nauders",
    "lat": "46.88859",
    "lng": "10.50126"
  },
  {
    "country": "AT",
    "name": "Natters",
    "lat": "47.23414",
    "lng": "11.37342"
  },
  {
    "country": "AT",
    "name": "Natternbach",
    "lat": "48.3973",
    "lng": "13.74965"
  },
  {
    "country": "AT",
    "name": "Nassereith",
    "lat": "47.31667",
    "lng": "10.83333"
  },
  {
    "country": "AT",
    "name": "Namlos",
    "lat": "47.35",
    "lng": "10.66667"
  },
  {
    "country": "AT",
    "name": "Naas",
    "lat": "47.25086",
    "lng": "15.59449"
  },
  {
    "country": "AT",
    "name": "Naarn im Machlande",
    "lat": "48.22553",
    "lng": "14.60838"
  },
  {
    "country": "AT",
    "name": "Mutters",
    "lat": "47.23333",
    "lng": "11.38333"
  },
  {
    "country": "AT",
    "name": "Musau",
    "lat": "47.53195",
    "lng": "10.67339"
  },
  {
    "country": "AT",
    "name": "Mürzzuschlag",
    "lat": "47.6066",
    "lng": "15.67226"
  },
  {
    "country": "AT",
    "name": "Mürzsteg",
    "lat": "47.67556",
    "lng": "15.49145"
  },
  {
    "country": "AT",
    "name": "Mürzhofen",
    "lat": "47.48333",
    "lng": "15.38333"
  },
  {
    "country": "AT",
    "name": "Mureck",
    "lat": "46.70806",
    "lng": "15.77472"
  },
  {
    "country": "AT",
    "name": "Münzkirchen",
    "lat": "48.48333",
    "lng": "13.56667"
  },
  {
    "country": "AT",
    "name": "Münzbach",
    "lat": "48.26737",
    "lng": "14.71009"
  },
  {
    "country": "AT",
    "name": "Muntlix",
    "lat": "47.28296",
    "lng": "9.65939"
  },
  {
    "country": "AT",
    "name": "Münster",
    "lat": "47.42164",
    "lng": "11.83356"
  },
  {
    "country": "AT",
    "name": "Munderfing",
    "lat": "48.07039",
    "lng": "13.18162"
  },
  {
    "country": "AT",
    "name": "Münchendorf",
    "lat": "48.03333",
    "lng": "16.38333"
  },
  {
    "country": "AT",
    "name": "Müllendorf",
    "lat": "47.83943",
    "lng": "16.46258"
  },
  {
    "country": "AT",
    "name": "Muhr",
    "lat": "47.09893",
    "lng": "13.49756"
  },
  {
    "country": "AT",
    "name": "Mühlgraben",
    "lat": "46.88972",
    "lng": "16.04083"
  },
  {
    "country": "AT",
    "name": "Mühlen",
    "lat": "47.03071",
    "lng": "14.50848"
  },
  {
    "country": "AT",
    "name": "Mühldorf bei Feldbach",
    "lat": "46.93861",
    "lng": "15.9075"
  },
  {
    "country": "AT",
    "name": "Mühldorf",
    "lat": "48.37432",
    "lng": "15.34672"
  },
  {
    "country": "AT",
    "name": "Mühldorf",
    "lat": "47.89689",
    "lng": "13.95049"
  },
  {
    "country": "AT",
    "name": "Mühldorf",
    "lat": "46.86028",
    "lng": "13.35361"
  },
  {
    "country": "AT",
    "name": "Mühlbach am Hochkönig",
    "lat": "47.37746",
    "lng": "13.12926"
  },
  {
    "country": "AT",
    "name": "Mühlau",
    "lat": "47.28333",
    "lng": "11.4"
  },
  {
    "country": "AT",
    "name": "Muggendorf",
    "lat": "47.91059",
    "lng": "15.93533"
  },
  {
    "country": "AT",
    "name": "Muckendorf an der Donau",
    "lat": "48.33183",
    "lng": "16.1554"
  },
  {
    "country": "AT",
    "name": "Mötz",
    "lat": "47.28333",
    "lng": "10.95"
  },
  {
    "country": "AT",
    "name": "Moschendorf",
    "lat": "47.05843",
    "lng": "16.47728"
  },
  {
    "country": "AT",
    "name": "Mörtschach",
    "lat": "46.92389",
    "lng": "12.91778"
  },
  {
    "country": "AT",
    "name": "Mortantsch",
    "lat": "47.20752",
    "lng": "15.57954"
  },
  {
    "country": "AT",
    "name": "Mörbisch am See",
    "lat": "47.75",
    "lng": "16.66667"
  },
  {
    "country": "AT",
    "name": "Mooskirchen",
    "lat": "46.98167",
    "lng": "15.27889"
  },
  {
    "country": "AT",
    "name": "Moosdorf",
    "lat": "48.04492",
    "lng": "12.98902"
  },
  {
    "country": "AT",
    "name": "Moosburg",
    "lat": "46.6575",
    "lng": "14.17472"
  },
  {
    "country": "AT",
    "name": "Moosbrunn",
    "lat": "48.01667",
    "lng": "16.45"
  },
  {
    "country": "AT",
    "name": "Mönichwald",
    "lat": "47.44655",
    "lng": "15.88275"
  },
  {
    "country": "AT",
    "name": "Mönichkirchen",
    "lat": "47.51062",
    "lng": "16.03425"
  },
  {
    "country": "AT",
    "name": "Mondsee",
    "lat": "47.85648",
    "lng": "13.34908"
  },
  {
    "country": "AT",
    "name": "Mönchhof",
    "lat": "47.8802",
    "lng": "16.94126"
  },
  {
    "country": "AT",
    "name": "Molln",
    "lat": "47.88723",
    "lng": "14.25819"
  },
  {
    "country": "AT",
    "name": "Möllersdorf",
    "lat": "48.02575",
    "lng": "16.30508"
  },
  {
    "country": "AT",
    "name": "Möllbrücke",
    "lat": "46.83639",
    "lng": "13.37278"
  },
  {
    "country": "AT",
    "name": "Mölbling",
    "lat": "46.85",
    "lng": "14.43333"
  },
  {
    "country": "AT",
    "name": "Möggers",
    "lat": "47.56667",
    "lng": "9.81667"
  },
  {
    "country": "AT",
    "name": "Mogersdorf",
    "lat": "46.94917",
    "lng": "16.23222"
  },
  {
    "country": "AT",
    "name": "Modriach",
    "lat": "46.95",
    "lng": "15.05"
  },
  {
    "country": "AT",
    "name": "Mödling",
    "lat": "48.08605",
    "lng": "16.28921"
  },
  {
    "country": "AT",
    "name": "Mittertreffling",
    "lat": "48.33868",
    "lng": "14.36505"
  },
  {
    "country": "AT",
    "name": "Mittersill",
    "lat": "47.28333",
    "lng": "12.48333"
  },
  {
    "country": "AT",
    "name": "Mitterpullendorf",
    "lat": "47.49325",
    "lng": "16.52129"
  },
  {
    "country": "AT",
    "name": "Mitterndorf im Steirischen Salzkammergut",
    "lat": "47.55556",
    "lng": "13.93187"
  },
  {
    "country": "AT",
    "name": "Mitterndorf an der Fischa",
    "lat": "47.99739",
    "lng": "16.47357"
  },
  {
    "country": "AT",
    "name": "Mitterlabill",
    "lat": "46.88917",
    "lng": "15.63556"
  },
  {
    "country": "AT",
    "name": "Mitterkirchen im Machland",
    "lat": "48.18795",
    "lng": "14.69593"
  },
  {
    "country": "AT",
    "name": "Mitterhofen",
    "lat": "47.38333",
    "lng": "12.8"
  },
  {
    "country": "AT",
    "name": "Mitterdorf im Mürztal",
    "lat": "47.53333",
    "lng": "15.51667"
  },
  {
    "country": "AT",
    "name": "Mitterdorf an der Raab",
    "lat": "47.16667",
    "lng": "15.6"
  },
  {
    "country": "AT",
    "name": "Mitterberghütten",
    "lat": "47.4",
    "lng": "13.21667"
  },
  {
    "country": "AT",
    "name": "Mitterbach am Erlaufsee",
    "lat": "47.81396",
    "lng": "15.29537"
  },
  {
    "country": "AT",
    "name": "Mittelberg",
    "lat": "47.35127",
    "lng": "10.17197"
  },
  {
    "country": "AT",
    "name": "Mistelbach",
    "lat": "48.57",
    "lng": "16.57667"
  },
  {
    "country": "AT",
    "name": "Mischendorf",
    "lat": "47.19277",
    "lng": "16.31444"
  },
  {
    "country": "AT",
    "name": "Mils bei Solbad Hall",
    "lat": "47.28333",
    "lng": "11.53333"
  },
  {
    "country": "AT",
    "name": "Mils bei Imst",
    "lat": "47.20616",
    "lng": "10.67485"
  },
  {
    "country": "AT",
    "name": "Miesenbach",
    "lat": "47.84035",
    "lng": "15.98236"
  },
  {
    "country": "AT",
    "name": "Miesenbach bei Birkfeld",
    "lat": "47.36667",
    "lng": "15.76667"
  },
  {
    "country": "AT",
    "name": "Mieming",
    "lat": "47.3",
    "lng": "10.98333"
  },
  {
    "country": "AT",
    "name": "Mieders",
    "lat": "47.16667",
    "lng": "11.38333"
  },
  {
    "country": "AT",
    "name": "Michelhausen",
    "lat": "48.29085",
    "lng": "15.93893"
  },
  {
    "country": "AT",
    "name": "Micheldorf in Oberösterreich",
    "lat": "47.87764",
    "lng": "14.13357"
  },
  {
    "country": "AT",
    "name": "Micheldorf",
    "lat": "46.91667",
    "lng": "14.41667"
  },
  {
    "country": "AT",
    "name": "Michaelnbach",
    "lat": "48.28788",
    "lng": "13.83144"
  },
  {
    "country": "AT",
    "name": "Michaelerberg",
    "lat": "47.41083",
    "lng": "13.89333"
  },
  {
    "country": "AT",
    "name": "Mettersdorf am Saßbach",
    "lat": "46.80583",
    "lng": "15.71111"
  },
  {
    "country": "AT",
    "name": "Metnitz",
    "lat": "46.98056",
    "lng": "14.21667"
  },
  {
    "country": "AT",
    "name": "Merkendorf",
    "lat": "46.85722",
    "lng": "15.90389"
  },
  {
    "country": "AT",
    "name": "Mellach",
    "lat": "46.93333",
    "lng": "15.51667"
  },
  {
    "country": "AT",
    "name": "Melk",
    "lat": "48.22737",
    "lng": "15.33186"
  },
  {
    "country": "AT",
    "name": "Meiningen",
    "lat": "47.29891",
    "lng": "9.57862"
  },
  {
    "country": "AT",
    "name": "Meidling",
    "lat": "48.16667",
    "lng": "16.33333"
  },
  {
    "country": "AT",
    "name": "Mehrnbach",
    "lat": "48.20809",
    "lng": "13.43525"
  },
  {
    "country": "AT",
    "name": "Meggenhofen",
    "lat": "48.18017",
    "lng": "13.79582"
  },
  {
    "country": "AT",
    "name": "Medraz",
    "lat": "47.14256",
    "lng": "11.34287"
  },
  {
    "country": "AT",
    "name": "Mayrhofen",
    "lat": "47.16667",
    "lng": "11.86667"
  },
  {
    "country": "AT",
    "name": "Mautern in Steiermark",
    "lat": "47.4",
    "lng": "14.83333"
  },
  {
    "country": "AT",
    "name": "Mauterndorf",
    "lat": "47.13451",
    "lng": "13.67884"
  },
  {
    "country": "AT",
    "name": "Mautern",
    "lat": "48.39319",
    "lng": "15.57793"
  },
  {
    "country": "AT",
    "name": "Mauerkirchen",
    "lat": "48.19173",
    "lng": "13.13338"
  },
  {
    "country": "AT",
    "name": "Mauer bei Amstetten",
    "lat": "48.09643",
    "lng": "14.8006"
  },
  {
    "country": "AT",
    "name": "Mauerbach",
    "lat": "48.24514",
    "lng": "16.16793"
  },
  {
    "country": "AT",
    "name": "Matzendorf",
    "lat": "47.89137",
    "lng": "16.21393"
  },
  {
    "country": "AT",
    "name": "Matzen",
    "lat": "48.4",
    "lng": "16.7"
  },
  {
    "country": "AT",
    "name": "Mattsee",
    "lat": "47.96667",
    "lng": "13.1"
  },
  {
    "country": "AT",
    "name": "Mattighofen",
    "lat": "48.10732",
    "lng": "13.15081"
  },
  {
    "country": "AT",
    "name": "Mattersburg",
    "lat": "47.73333",
    "lng": "16.4"
  },
  {
    "country": "AT",
    "name": "Matrei in Osttirol",
    "lat": "47",
    "lng": "12.53333"
  },
  {
    "country": "AT",
    "name": "Matrei am Brenner",
    "lat": "47.12794",
    "lng": "11.45176"
  },
  {
    "country": "AT",
    "name": "Marz",
    "lat": "47.71667",
    "lng": "16.41667"
  },
  {
    "country": "AT",
    "name": "Martinsberg",
    "lat": "48.37549",
    "lng": "15.14997"
  },
  {
    "country": "AT",
    "name": "Markt Sankt Martin",
    "lat": "47.56205",
    "lng": "16.42508"
  },
  {
    "country": "AT",
    "name": "Sankt Florian",
    "lat": "48.20568",
    "lng": "14.37836"
  },
  {
    "country": "AT",
    "name": "Bad Pirawarth",
    "lat": "48.45194",
    "lng": "16.59833"
  },
  {
    "country": "AT",
    "name": "Markt Piesting",
    "lat": "47.87358",
    "lng": "16.1251"
  },
  {
    "country": "AT",
    "name": "Markt Neuhodis",
    "lat": "47.29565",
    "lng": "16.39564"
  },
  {
    "country": "AT",
    "name": "Markt Allhau",
    "lat": "47.28333",
    "lng": "16.08333"
  },
  {
    "country": "AT",
    "name": "Markgrafneusiedl",
    "lat": "48.26667",
    "lng": "16.63333"
  },
  {
    "country": "AT",
    "name": "Markersdorf an der Pielach",
    "lat": "48.18333",
    "lng": "15.5"
  },
  {
    "country": "AT",
    "name": "Mariazell",
    "lat": "47.77306",
    "lng": "15.31639"
  },
  {
    "country": "AT",
    "name": "Maria Wörth",
    "lat": "46.61639",
    "lng": "14.16306"
  },
  {
    "country": "AT",
    "name": "Mariatrost",
    "lat": "47.1",
    "lng": "15.5"
  },
  {
    "country": "AT",
    "name": "Mariatal",
    "lat": "47.44788",
    "lng": "11.8721"
  },
  {
    "country": "AT",
    "name": "Maria Taferl",
    "lat": "48.22702",
    "lng": "15.15954"
  },
  {
    "country": "AT",
    "name": "Mariastein",
    "lat": "47.52772",
    "lng": "12.05479"
  },
  {
    "country": "AT",
    "name": "Mariasdorf",
    "lat": "47.3658",
    "lng": "16.23136"
  },
  {
    "country": "AT",
    "name": "Maria Schmolln",
    "lat": "48.1382",
    "lng": "13.21981"
  },
  {
    "country": "AT",
    "name": "Maria Saal",
    "lat": "46.68083",
    "lng": "14.34861"
  },
  {
    "country": "AT",
    "name": "Maria Rain",
    "lat": "46.55389",
    "lng": "14.29556"
  },
  {
    "country": "AT",
    "name": "Mariapfarr",
    "lat": "47.15",
    "lng": "13.75"
  },
  {
    "country": "AT",
    "name": "Maria Neustift",
    "lat": "47.93333",
    "lng": "14.6"
  },
  {
    "country": "AT",
    "name": "Maria Lanzendorf",
    "lat": "48.09923",
    "lng": "16.41984"
  },
  {
    "country": "AT",
    "name": "Maria Lankowitz",
    "lat": "47.0622",
    "lng": "15.06525"
  },
  {
    "country": "AT",
    "name": "Maria Laach am Jauerling",
    "lat": "48.30412",
    "lng": "15.34472"
  },
  {
    "country": "AT",
    "name": "Mariahof",
    "lat": "47.1",
    "lng": "14.4"
  },
  {
    "country": "AT",
    "name": "Maria Enzersdorf",
    "lat": "48.1",
    "lng": "16.28333"
  },
  {
    "country": "AT",
    "name": "Maria Ellend",
    "lat": "48.1",
    "lng": "16.68333"
  },
  {
    "country": "AT",
    "name": "Maria-Anzbach",
    "lat": "48.19012",
    "lng": "15.93155"
  },
  {
    "country": "AT",
    "name": "Maria Alm am Steinernen Meer",
    "lat": "47.40579",
    "lng": "12.90121"
  },
  {
    "country": "AT",
    "name": "Margarethen am Moos",
    "lat": "48.03333",
    "lng": "16.6"
  },
  {
    "country": "AT",
    "name": "Marchtrenk",
    "lat": "48.19275",
    "lng": "14.11394"
  },
  {
    "country": "AT",
    "name": "Marchegg",
    "lat": "48.26217",
    "lng": "16.91045"
  },
  {
    "country": "AT",
    "name": "Marbach an der Donau",
    "lat": "48.21667",
    "lng": "15.15"
  },
  {
    "country": "AT",
    "name": "Mannswörth",
    "lat": "48.14547",
    "lng": "16.51374"
  },
  {
    "country": "AT",
    "name": "Mannsdorf an der Donau",
    "lat": "48.152",
    "lng": "16.66506"
  },
  {
    "country": "AT",
    "name": "Manning",
    "lat": "48.08851",
    "lng": "13.66682"
  },
  {
    "country": "AT",
    "name": "Mannersdorf an der Rabnitz",
    "lat": "47.42815",
    "lng": "16.52678"
  },
  {
    "country": "AT",
    "name": "Mannersdorf am Leithagebirge",
    "lat": "47.96667",
    "lng": "16.6"
  },
  {
    "country": "AT",
    "name": "Mank",
    "lat": "48.11024",
    "lng": "15.33915"
  },
  {
    "country": "AT",
    "name": "Maissau",
    "lat": "48.573",
    "lng": "15.83005"
  },
  {
    "country": "AT",
    "name": "Maishofen",
    "lat": "47.36667",
    "lng": "12.8"
  },
  {
    "country": "AT",
    "name": "Mailberg",
    "lat": "48.67379",
    "lng": "16.18132"
  },
  {
    "country": "AT",
    "name": "Maierdorf",
    "lat": "46.8925",
    "lng": "15.84972"
  },
  {
    "country": "AT",
    "name": "Mäder",
    "lat": "47.35",
    "lng": "9.61667"
  },
  {
    "country": "AT",
    "name": "Lutzmannsburg",
    "lat": "47.46373",
    "lng": "16.63665"
  },
  {
    "country": "AT",
    "name": "Lustenau",
    "lat": "47.42642",
    "lng": "9.65851"
  },
  {
    "country": "AT",
    "name": "Lunz am See",
    "lat": "47.8612",
    "lng": "15.02998"
  },
  {
    "country": "AT",
    "name": "Luftenberg an der Donau",
    "lat": "48.27462",
    "lng": "14.41303"
  },
  {
    "country": "AT",
    "name": "Ludmannsdorf",
    "lat": "46.54139",
    "lng": "14.13425"
  },
  {
    "country": "AT",
    "name": "Ludesch",
    "lat": "47.2",
    "lng": "9.78306"
  },
  {
    "country": "AT",
    "name": "Losenstein",
    "lat": "47.92428",
    "lng": "14.43672"
  },
  {
    "country": "AT",
    "name": "Lorüns",
    "lat": "47.13306",
    "lng": "9.85"
  },
  {
    "country": "AT",
    "name": "Loretto",
    "lat": "47.91559",
    "lng": "16.5179"
  },
  {
    "country": "AT",
    "name": "Loosdorf",
    "lat": "48.2",
    "lng": "15.4"
  },
  {
    "country": "AT",
    "name": "Loipersdorf bei Fürstenfeld",
    "lat": "47",
    "lng": "16.1"
  },
  {
    "country": "AT",
    "name": "Loipersbach im Burgenland",
    "lat": "47.69656",
    "lng": "16.47919"
  },
  {
    "country": "AT",
    "name": "Loich",
    "lat": "47.99578",
    "lng": "15.40163"
  },
  {
    "country": "AT",
    "name": "Lofer",
    "lat": "47.58475",
    "lng": "12.69333"
  },
  {
    "country": "AT",
    "name": "Lödersdorf",
    "lat": "46.95861",
    "lng": "15.94333"
  },
  {
    "country": "AT",
    "name": "Lochau",
    "lat": "47.53333",
    "lng": "9.75"
  },
  {
    "country": "AT",
    "name": "Litzelsdorf",
    "lat": "47.20826",
    "lng": "16.1717"
  },
  {
    "country": "AT",
    "name": "Litschau",
    "lat": "48.94409",
    "lng": "15.04483"
  },
  {
    "country": "AT",
    "name": "Linz",
    "lat": "48.30639",
    "lng": "14.28611"
  },
  {
    "country": "AT",
    "name": "Lilienfeld",
    "lat": "48.01312",
    "lng": "15.59664"
  },
  {
    "country": "AT",
    "name": "Ligist",
    "lat": "46.99389",
    "lng": "15.21083"
  },
  {
    "country": "AT",
    "name": "Liezen",
    "lat": "47.56667",
    "lng": "14.23333"
  },
  {
    "country": "AT",
    "name": "Liesingtal",
    "lat": "47.34597",
    "lng": "15.01352"
  },
  {
    "country": "AT",
    "name": "Lienz",
    "lat": "46.8289",
    "lng": "12.76903"
  },
  {
    "country": "AT",
    "name": "Lieboch",
    "lat": "46.97417",
    "lng": "15.3375"
  },
  {
    "country": "AT",
    "name": "Liebenau",
    "lat": "47.03333",
    "lng": "15.46667"
  },
  {
    "country": "AT",
    "name": "Lichtenwörth",
    "lat": "47.82756",
    "lng": "16.29873"
  },
  {
    "country": "AT",
    "name": "Lichtenegg",
    "lat": "48.15",
    "lng": "14"
  },
  {
    "country": "AT",
    "name": "Lichtenegg",
    "lat": "47.6",
    "lng": "16.2"
  },
  {
    "country": "AT",
    "name": "Leutschach",
    "lat": "46.66722",
    "lng": "15.46889"
  },
  {
    "country": "AT",
    "name": "Lermoos",
    "lat": "47.40358",
    "lng": "10.8807"
  },
  {
    "country": "AT",
    "name": "Leopoldsdorf im Marchfelde",
    "lat": "48.22261",
    "lng": "16.68858"
  },
  {
    "country": "AT",
    "name": "Leopoldsdorf",
    "lat": "48.11557",
    "lng": "16.39126"
  },
  {
    "country": "AT",
    "name": "Leonstein",
    "lat": "47.89666",
    "lng": "14.23124"
  },
  {
    "country": "AT",
    "name": "Leonding",
    "lat": "48.27965",
    "lng": "14.2533"
  },
  {
    "country": "AT",
    "name": "Leogang",
    "lat": "47.43906",
    "lng": "12.76109"
  },
  {
    "country": "AT",
    "name": "Leobersdorf",
    "lat": "47.92796",
    "lng": "16.21651"
  },
  {
    "country": "AT",
    "name": "Leobendorf",
    "lat": "48.38333",
    "lng": "16.31667"
  },
  {
    "country": "AT",
    "name": "Leoben",
    "lat": "47.3765",
    "lng": "15.09144"
  },
  {
    "country": "AT",
    "name": "Lenzing",
    "lat": "47.97326",
    "lng": "13.60846"
  },
  {
    "country": "AT",
    "name": "Lengfelden",
    "lat": "47.85",
    "lng": "13.05"
  },
  {
    "country": "AT",
    "name": "Lengenfeld",
    "lat": "48.47187",
    "lng": "15.5987"
  },
  {
    "country": "AT",
    "name": "Lendorf",
    "lat": "46.83528",
    "lng": "13.43028"
  },
  {
    "country": "AT",
    "name": "Lend",
    "lat": "47.29856",
    "lng": "13.05176"
  },
  {
    "country": "AT",
    "name": "Lembach im Mühlkreis",
    "lat": "48.49517",
    "lng": "13.89513"
  },
  {
    "country": "AT",
    "name": "Leitzersdorf",
    "lat": "48.41918",
    "lng": "16.24513"
  },
  {
    "country": "AT",
    "name": "Leitring",
    "lat": "46.76667",
    "lng": "15.56667"
  },
  {
    "country": "AT",
    "name": "Leithaprodersdorf",
    "lat": "47.93348",
    "lng": "16.47915"
  },
  {
    "country": "AT",
    "name": "Leitersdorf im Raabtal",
    "lat": "46.94182",
    "lng": "15.93365"
  },
  {
    "country": "AT",
    "name": "Leitendorf",
    "lat": "47.36667",
    "lng": "15.08333"
  },
  {
    "country": "AT",
    "name": "Leisach",
    "lat": "46.8125",
    "lng": "12.74861"
  },
  {
    "country": "AT",
    "name": "Leibnitz",
    "lat": "46.78161",
    "lng": "15.53836"
  },
  {
    "country": "AT",
    "name": "Leiben",
    "lat": "48.24628",
    "lng": "15.2746"
  },
  {
    "country": "AT",
    "name": "Ledenitzen",
    "lat": "46.56639",
    "lng": "13.96139"
  },
  {
    "country": "AT",
    "name": "Lechaschau",
    "lat": "47.48804",
    "lng": "10.70652"
  },
  {
    "country": "AT",
    "name": "Lech",
    "lat": "47.20797",
    "lng": "10.14184"
  },
  {
    "country": "AT",
    "name": "Laxenburg",
    "lat": "48.06833",
    "lng": "16.35607"
  },
  {
    "country": "AT",
    "name": "Tullnerbach-Lawies",
    "lat": "48.18912",
    "lng": "16.09117"
  },
  {
    "country": "AT",
    "name": "Lavant",
    "lat": "46.79889",
    "lng": "12.83806"
  },
  {
    "country": "AT",
    "name": "Lavamünd",
    "lat": "46.64019",
    "lng": "14.94733"
  },
  {
    "country": "AT",
    "name": "Lauterach",
    "lat": "47.47572",
    "lng": "9.72941"
  },
  {
    "country": "AT",
    "name": "Laussa",
    "lat": "47.95",
    "lng": "14.45"
  },
  {
    "country": "AT",
    "name": "Launsdorf",
    "lat": "46.77056",
    "lng": "14.45194"
  },
  {
    "country": "AT",
    "name": "Lassnitzhöhe",
    "lat": "47.06667",
    "lng": "15.58333"
  },
  {
    "country": "AT",
    "name": "Lassing",
    "lat": "47.53374",
    "lng": "14.25808"
  },
  {
    "country": "AT",
    "name": "Lassee",
    "lat": "48.22479",
    "lng": "16.8223"
  },
  {
    "country": "AT",
    "name": "Lanzenkirchen",
    "lat": "47.73621",
    "lng": "16.21985"
  },
  {
    "country": "AT",
    "name": "Lans",
    "lat": "47.23833",
    "lng": "11.43139"
  },
  {
    "country": "AT",
    "name": "Lannach",
    "lat": "46.94611",
    "lng": "15.33722"
  },
  {
    "country": "AT",
    "name": "Langschlag",
    "lat": "48.57448",
    "lng": "14.88459"
  },
  {
    "country": "AT",
    "name": "Langenzersdorf",
    "lat": "48.30432",
    "lng": "16.36143"
  },
  {
    "country": "AT",
    "name": "Langenwang",
    "lat": "47.56667",
    "lng": "15.61667"
  },
  {
    "country": "AT",
    "name": "Langenstein",
    "lat": "48.252",
    "lng": "14.47655"
  },
  {
    "country": "AT",
    "name": "Langenrohr",
    "lat": "48.30489",
    "lng": "16.01034"
  },
  {
    "country": "AT",
    "name": "Langenlois",
    "lat": "48.46667",
    "lng": "15.66667"
  },
  {
    "country": "AT",
    "name": "Langen",
    "lat": "47.51667",
    "lng": "9.81667"
  },
  {
    "country": "AT",
    "name": "Langegg bei Graz",
    "lat": "47.05",
    "lng": "15.63333"
  },
  {
    "country": "AT",
    "name": "Langau",
    "lat": "48.83207",
    "lng": "15.7156"
  },
  {
    "country": "AT",
    "name": "Lang",
    "lat": "46.83765",
    "lng": "15.50471"
  },
  {
    "country": "AT",
    "name": "Landskron",
    "lat": "46.61667",
    "lng": "13.88333"
  },
  {
    "country": "AT",
    "name": "Landl",
    "lat": "47.65666",
    "lng": "14.73189"
  },
  {
    "country": "AT",
    "name": "Landegg",
    "lat": "47.9",
    "lng": "16.4"
  },
  {
    "country": "AT",
    "name": "Landeck",
    "lat": "47.13988",
    "lng": "10.56593"
  },
  {
    "country": "AT",
    "name": "Lamprechtshausen",
    "lat": "47.99098",
    "lng": "12.95481"
  },
  {
    "country": "AT",
    "name": "Lambach",
    "lat": "48.09276",
    "lng": "13.87453"
  },
  {
    "country": "AT",
    "name": "Lafnitz",
    "lat": "47.36792",
    "lng": "16.01103"
  },
  {
    "country": "AT",
    "name": "Ladis",
    "lat": "47.07459",
    "lng": "10.64949"
  },
  {
    "country": "AT",
    "name": "Ladendorf",
    "lat": "48.53333",
    "lng": "16.48333"
  },
  {
    "country": "AT",
    "name": "Lackendorf",
    "lat": "47.58996",
    "lng": "16.50404"
  },
  {
    "country": "AT",
    "name": "Lackenbach",
    "lat": "47.59042",
    "lng": "16.46533"
  },
  {
    "country": "AT",
    "name": "Labuch",
    "lat": "47.06667",
    "lng": "15.66667"
  },
  {
    "country": "AT",
    "name": "Laakirchen",
    "lat": "47.98188",
    "lng": "13.82166"
  },
  {
    "country": "AT",
    "name": "Laab im Walde",
    "lat": "48.15486",
    "lng": "16.17359"
  },
  {
    "country": "AT",
    "name": "Laa an der Thaya",
    "lat": "48.71667",
    "lng": "16.38333"
  },
  {
    "country": "AT",
    "name": "Kundl",
    "lat": "47.46667",
    "lng": "11.98333"
  },
  {
    "country": "AT",
    "name": "Kumberg",
    "lat": "47.16422",
    "lng": "15.53261"
  },
  {
    "country": "AT",
    "name": "Kulm am Zirbitz",
    "lat": "47.05814",
    "lng": "14.48702"
  },
  {
    "country": "AT",
    "name": "Kukmirn",
    "lat": "47.07544",
    "lng": "16.21033"
  },
  {
    "country": "AT",
    "name": "Kühnsdorf",
    "lat": "46.62194",
    "lng": "14.63639"
  },
  {
    "country": "AT",
    "name": "Kufstein",
    "lat": "47.58333",
    "lng": "12.16667"
  },
  {
    "country": "AT",
    "name": "Kuchl",
    "lat": "47.62647",
    "lng": "13.1448"
  },
  {
    "country": "AT",
    "name": "Krusdorf",
    "lat": "46.83944",
    "lng": "15.86083"
  },
  {
    "country": "AT",
    "name": "Krumpendorf",
    "lat": "46.63333",
    "lng": "14.21667"
  },
  {
    "country": "AT",
    "name": "Krumnussbaum",
    "lat": "48.20877",
    "lng": "15.16212"
  },
  {
    "country": "AT",
    "name": "Krumegg",
    "lat": "47.02111",
    "lng": "15.63139"
  },
  {
    "country": "AT",
    "name": "Krumbach Markt",
    "lat": "47.51667",
    "lng": "16.18333"
  },
  {
    "country": "AT",
    "name": "Krumbach",
    "lat": "47.48306",
    "lng": "9.93583"
  },
  {
    "country": "AT",
    "name": "Krumau am Kamp",
    "lat": "48.58879",
    "lng": "15.44914"
  },
  {
    "country": "AT",
    "name": "Krottendorf bei Ligist",
    "lat": "47.01667",
    "lng": "15.21667"
  },
  {
    "country": "AT",
    "name": "Krottendorf",
    "lat": "47.2",
    "lng": "15.63333"
  },
  {
    "country": "AT",
    "name": "Kronstorf",
    "lat": "48.14324",
    "lng": "14.46307"
  },
  {
    "country": "AT",
    "name": "Kritzendorf",
    "lat": "48.32932",
    "lng": "16.30011"
  },
  {
    "country": "AT",
    "name": "Krispl",
    "lat": "47.71667",
    "lng": "13.18333"
  },
  {
    "country": "AT",
    "name": "Krieglach",
    "lat": "47.54728",
    "lng": "15.56248"
  },
  {
    "country": "AT",
    "name": "Bad Kreuzen",
    "lat": "48.26737",
    "lng": "14.80648"
  },
  {
    "country": "AT",
    "name": "Krensdorf",
    "lat": "47.78552",
    "lng": "16.41495"
  },
  {
    "country": "AT",
    "name": "Kremsmünster",
    "lat": "48.0529",
    "lng": "14.12919"
  },
  {
    "country": "AT",
    "name": "Kremsdorf",
    "lat": "48.20031",
    "lng": "14.26249"
  },
  {
    "country": "AT",
    "name": "Krems an der Donau",
    "lat": "48.40921",
    "lng": "15.61415"
  },
  {
    "country": "AT",
    "name": "Kraubath an der Mur",
    "lat": "47.3",
    "lng": "14.93333"
  },
  {
    "country": "AT",
    "name": "Kramsach",
    "lat": "47.44312",
    "lng": "11.87545"
  },
  {
    "country": "AT",
    "name": "Krakauschatten",
    "lat": "47.18333",
    "lng": "13.96667"
  },
  {
    "country": "AT",
    "name": "Krakauhintermühlen",
    "lat": "47.18333",
    "lng": "13.98333"
  },
  {
    "country": "AT",
    "name": "Krakaudorf",
    "lat": "47.18131",
    "lng": "14.02061"
  },
  {
    "country": "AT",
    "name": "Köttmannsdorf",
    "lat": "46.56139",
    "lng": "14.23389"
  },
  {
    "country": "AT",
    "name": "Kottingbrunn",
    "lat": "47.95096",
    "lng": "16.22715"
  },
  {
    "country": "AT",
    "name": "Kötschach",
    "lat": "46.68167",
    "lng": "13.00694"
  },
  {
    "country": "AT",
    "name": "Köstendorf",
    "lat": "47.95",
    "lng": "13.2"
  },
  {
    "country": "AT",
    "name": "Kössen",
    "lat": "47.6699",
    "lng": "12.40545"
  },
  {
    "country": "AT",
    "name": "Korneuburg",
    "lat": "48.35",
    "lng": "16.33333"
  },
  {
    "country": "AT",
    "name": "Koppl",
    "lat": "47.80808",
    "lng": "13.15561"
  },
  {
    "country": "AT",
    "name": "Kopfing im Innkreis",
    "lat": "48.43991",
    "lng": "13.65841"
  },
  {
    "country": "AT",
    "name": "Königswiesen",
    "lat": "48.40453",
    "lng": "14.83824"
  },
  {
    "country": "AT",
    "name": "Königstetten",
    "lat": "48.30198",
    "lng": "16.14492"
  },
  {
    "country": "AT",
    "name": "Königsdorf",
    "lat": "47",
    "lng": "16.16667"
  },
  {
    "country": "AT",
    "name": "Kolsassberg",
    "lat": "47.2815",
    "lng": "11.65289"
  },
  {
    "country": "AT",
    "name": "Kohlschwarz",
    "lat": "47.11667",
    "lng": "15.11667"
  },
  {
    "country": "AT",
    "name": "Kohlberg",
    "lat": "46.9",
    "lng": "15.78333"
  },
  {
    "country": "AT",
    "name": "Kohfidisch",
    "lat": "47.17472",
    "lng": "16.35701"
  },
  {
    "country": "AT",
    "name": "Köflach",
    "lat": "47.06667",
    "lng": "15.08333"
  },
  {
    "country": "AT",
    "name": "Koblach",
    "lat": "47.33306",
    "lng": "9.6"
  },
  {
    "country": "AT",
    "name": "Kobersdorf",
    "lat": "47.59572",
    "lng": "16.39173"
  },
  {
    "country": "AT",
    "name": "Kobenz",
    "lat": "47.25",
    "lng": "14.85"
  },
  {
    "country": "AT",
    "name": "Knittelfeld",
    "lat": "47.21667",
    "lng": "14.81667"
  },
  {
    "country": "AT",
    "name": "Klosterneuburg",
    "lat": "48.30521",
    "lng": "16.32522"
  },
  {
    "country": "AT",
    "name": "Klösterle",
    "lat": "47.13333",
    "lng": "10.08333"
  },
  {
    "country": "AT",
    "name": "Kloster",
    "lat": "46.88333",
    "lng": "15.08333"
  },
  {
    "country": "AT",
    "name": "Klöch",
    "lat": "46.76472",
    "lng": "15.96556"
  },
  {
    "country": "AT",
    "name": "Klingenbach",
    "lat": "47.75202",
    "lng": "16.54069"
  },
  {
    "country": "AT",
    "name": "Kleinzell",
    "lat": "47.97993",
    "lng": "15.7362"
  },
  {
    "country": "AT",
    "name": "Kleinsölk",
    "lat": "47.39444",
    "lng": "13.93944"
  },
  {
    "country": "AT",
    "name": "Kleinsöding",
    "lat": "47",
    "lng": "15.28333"
  },
  {
    "country": "AT",
    "name": "Klein Sankt Paul",
    "lat": "46.83611",
    "lng": "14.54139"
  },
  {
    "country": "AT",
    "name": "Klein-Pöchlarn",
    "lat": "48.21667",
    "lng": "15.21667"
  },
  {
    "country": "AT",
    "name": "Kleinmürbisch",
    "lat": "47.03299",
    "lng": "16.32448"
  },
  {
    "country": "AT",
    "name": "Kleinlobming",
    "lat": "47.14954",
    "lng": "14.84875"
  },
  {
    "country": "AT",
    "name": "Kleinhöflein im Burgenland",
    "lat": "47.84151",
    "lng": "16.50413"
  },
  {
    "country": "AT",
    "name": "Klausen-Leopoldsdorf",
    "lat": "48.08771",
    "lng": "16.01686"
  },
  {
    "country": "AT",
    "name": "Klaus",
    "lat": "47.30913",
    "lng": "9.64678"
  },
  {
    "country": "AT",
    "name": "Klagenfurt am Wörthersee",
    "lat": "46.62472",
    "lng": "14.30528"
  },
  {
    "country": "AT",
    "name": "Klaffer am Hochficht",
    "lat": "48.69544",
    "lng": "13.88131"
  },
  {
    "country": "AT",
    "name": "Kitzeck im Sausal",
    "lat": "46.78072",
    "lng": "15.45384"
  },
  {
    "country": "AT",
    "name": "Kitzbühel",
    "lat": "47.44637",
    "lng": "12.39215"
  },
  {
    "country": "AT",
    "name": "Kittsee",
    "lat": "48.0925",
    "lng": "17.06389"
  },
  {
    "country": "AT",
    "name": "Kirnberg an der Mank",
    "lat": "48.07246",
    "lng": "15.32232"
  },
  {
    "country": "AT",
    "name": "Kirchstetten",
    "lat": "48.18333",
    "lng": "15.81667"
  },
  {
    "country": "AT",
    "name": "Kirchschlag in der Buckligen Welt",
    "lat": "47.5",
    "lng": "16.28333"
  },
  {
    "country": "AT",
    "name": "Kirchschlag bei Linz",
    "lat": "48.41149",
    "lng": "14.27656"
  },
  {
    "country": "AT",
    "name": "Kirchschlag",
    "lat": "48.39345",
    "lng": "15.22285"
  },
  {
    "country": "AT",
    "name": "Kirchdorf in Tirol",
    "lat": "47.55626",
    "lng": "12.44511"
  },
  {
    "country": "AT",
    "name": "Kirchdorf an der Krems",
    "lat": "47.90558",
    "lng": "14.12228"
  },
  {
    "country": "AT",
    "name": "Kirchberg ob der Donau",
    "lat": "48.4444",
    "lng": "13.93805"
  },
  {
    "country": "AT",
    "name": "Kirchberg in Tirol",
    "lat": "47.44539",
    "lng": "12.31602"
  },
  {
    "country": "AT",
    "name": "Kirchberg an der Raab",
    "lat": "46.98583",
    "lng": "15.76694"
  },
  {
    "country": "AT",
    "name": "Kirchberg an der Pielach",
    "lat": "48.0269",
    "lng": "15.42875"
  },
  {
    "country": "AT",
    "name": "Kirchberg am Wechsel",
    "lat": "47.60738",
    "lng": "15.99103"
  },
  {
    "country": "AT",
    "name": "Kirchberg am Walde",
    "lat": "48.72477",
    "lng": "15.08826"
  },
  {
    "country": "AT",
    "name": "Kirchberg am Wagram",
    "lat": "48.43182",
    "lng": "15.89692"
  },
  {
    "country": "AT",
    "name": "Kirchbach in Steiermark",
    "lat": "46.93167",
    "lng": "15.66194"
  },
  {
    "country": "AT",
    "name": "Kirchbach",
    "lat": "46.6416",
    "lng": "13.18454"
  },
  {
    "country": "AT",
    "name": "Kindberg",
    "lat": "47.5",
    "lng": "15.45"
  },
  {
    "country": "AT",
    "name": "Kilb",
    "lat": "48.10101",
    "lng": "15.4085"
  },
  {
    "country": "AT",
    "name": "Kierling",
    "lat": "48.30997",
    "lng": "16.27616"
  },
  {
    "country": "AT",
    "name": "Keutschach am See",
    "lat": "46.59306",
    "lng": "14.18889"
  },
  {
    "country": "AT",
    "name": "Kennelbach",
    "lat": "47.48306",
    "lng": "9.76667"
  },
  {
    "country": "AT",
    "name": "Kemeten",
    "lat": "47.24859",
    "lng": "16.15213"
  },
  {
    "country": "AT",
    "name": "Kematen in Tirol",
    "lat": "47.25",
    "lng": "11.26667"
  },
  {
    "country": "AT",
    "name": "Kematen an der Krems",
    "lat": "48.1115",
    "lng": "14.19391"
  },
  {
    "country": "AT",
    "name": "Kematen an der Ybbs",
    "lat": "48.02541",
    "lng": "14.76468"
  },
  {
    "country": "AT",
    "name": "Kautzen",
    "lat": "48.93",
    "lng": "15.23932"
  },
  {
    "country": "AT",
    "name": "Kauns",
    "lat": "47.07822",
    "lng": "10.69219"
  },
  {
    "country": "AT",
    "name": "Kaumberg",
    "lat": "48.02415",
    "lng": "15.89842"
  },
  {
    "country": "AT",
    "name": "Katzelsdorf",
    "lat": "48.28456",
    "lng": "16.10836"
  },
  {
    "country": "AT",
    "name": "Katzelsdorf",
    "lat": "47.78055",
    "lng": "16.26985"
  },
  {
    "country": "AT",
    "name": "Katsdorf",
    "lat": "48.31791",
    "lng": "14.47432"
  },
  {
    "country": "AT",
    "name": "Kasten bei Böheimkirchen",
    "lat": "48.1532",
    "lng": "15.77946"
  },
  {
    "country": "AT",
    "name": "Kartitsch",
    "lat": "46.72889",
    "lng": "12.50083"
  },
  {
    "country": "AT",
    "name": "Karrösten",
    "lat": "47.2254",
    "lng": "10.76561"
  },
  {
    "country": "AT",
    "name": "Karres",
    "lat": "47.21667",
    "lng": "10.78333"
  },
  {
    "country": "AT",
    "name": "Karlstetten",
    "lat": "48.2592",
    "lng": "15.56544"
  },
  {
    "country": "AT",
    "name": "Kaprun",
    "lat": "47.27239",
    "lng": "12.75985"
  },
  {
    "country": "AT",
    "name": "Kappl",
    "lat": "47.06667",
    "lng": "10.38333"
  },
  {
    "country": "AT",
    "name": "Kappel am Krappfeld",
    "lat": "46.83861",
    "lng": "14.48639"
  },
  {
    "country": "AT",
    "name": "Kapfing",
    "lat": "47.33333",
    "lng": "11.85"
  },
  {
    "country": "AT",
    "name": "Kapfenstein",
    "lat": "46.88611",
    "lng": "15.97167"
  },
  {
    "country": "AT",
    "name": "Kapfenberg",
    "lat": "47.44458",
    "lng": "15.29331"
  },
  {
    "country": "AT",
    "name": "Kapelln",
    "lat": "48.25817",
    "lng": "15.75731"
  },
  {
    "country": "AT",
    "name": "Kapellen",
    "lat": "47.64784",
    "lng": "15.62863"
  },
  {
    "country": "AT",
    "name": "Kammern im Liesingtal",
    "lat": "47.39245",
    "lng": "14.90407"
  },
  {
    "country": "AT",
    "name": "Kalwang",
    "lat": "47.42678",
    "lng": "14.75442"
  },
  {
    "country": "AT",
    "name": "Kaltenleutgeben",
    "lat": "48.11646",
    "lng": "16.19956"
  },
  {
    "country": "AT",
    "name": "Kaltenbach",
    "lat": "47.70618",
    "lng": "13.60914"
  },
  {
    "country": "AT",
    "name": "Kaltenbach",
    "lat": "47.28333",
    "lng": "11.86667"
  },
  {
    "country": "AT",
    "name": "Kalsdorf bei Graz",
    "lat": "46.96528",
    "lng": "15.48028"
  },
  {
    "country": "AT",
    "name": "Kaisersdorf",
    "lat": "47.53741",
    "lng": "16.39198"
  },
  {
    "country": "AT",
    "name": "Kaindorf an der Sulm",
    "lat": "46.79248",
    "lng": "15.53879"
  },
  {
    "country": "AT",
    "name": "Kaindorf",
    "lat": "47.22537",
    "lng": "15.91125"
  },
  {
    "country": "AT",
    "name": "Kainbach",
    "lat": "47.08333",
    "lng": "15.51667"
  },
  {
    "country": "AT",
    "name": "Kainach bei Voitsberg",
    "lat": "47.13637",
    "lng": "15.0953"
  },
  {
    "country": "AT",
    "name": "Kaibing",
    "lat": "47.2",
    "lng": "15.83333"
  },
  {
    "country": "AT",
    "name": "Jungholz",
    "lat": "47.57409",
    "lng": "10.44723"
  },
  {
    "country": "AT",
    "name": "Judendorf",
    "lat": "47.4",
    "lng": "15.1"
  },
  {
    "country": "AT",
    "name": "Warmbad-Judendorf",
    "lat": "46.60126",
    "lng": "13.82241"
  },
  {
    "country": "AT",
    "name": "Judendorf",
    "lat": "47.11667",
    "lng": "15.35"
  },
  {
    "country": "AT",
    "name": "Judenburg",
    "lat": "47.16667",
    "lng": "14.66667"
  },
  {
    "country": "AT",
    "name": "Jois",
    "lat": "47.96165",
    "lng": "16.79604"
  },
  {
    "country": "AT",
    "name": "Johnsbach",
    "lat": "47.53333",
    "lng": "14.58333"
  },
  {
    "country": "AT",
    "name": "Jochberg",
    "lat": "47.3792",
    "lng": "12.41807"
  },
  {
    "country": "AT",
    "name": "Jerzens",
    "lat": "47.1512",
    "lng": "10.74686"
  },
  {
    "country": "AT",
    "name": "Jennersdorf",
    "lat": "46.93848",
    "lng": "16.14158"
  },
  {
    "country": "AT",
    "name": "Jenbach",
    "lat": "47.39173",
    "lng": "11.77245"
  },
  {
    "country": "AT",
    "name": "Jedenspeigen",
    "lat": "48.49807",
    "lng": "16.87225"
  },
  {
    "country": "AT",
    "name": "Japons",
    "lat": "48.7925",
    "lng": "15.56831"
  },
  {
    "country": "AT",
    "name": "Jaidhof",
    "lat": "48.53333",
    "lng": "15.48333"
  },
  {
    "country": "AT",
    "name": "Jagerberg",
    "lat": "46.85361",
    "lng": "15.73806"
  },
  {
    "country": "AT",
    "name": "Jabing",
    "lat": "47.2388",
    "lng": "16.27659"
  },
  {
    "country": "AT",
    "name": "Ysper",
    "lat": "48.28865",
    "lng": "15.06131"
  },
  {
    "country": "AT",
    "name": "Ischgl",
    "lat": "47.01257",
    "lng": "10.29179"
  },
  {
    "country": "AT",
    "name": "Irschen",
    "lat": "46.75694",
    "lng": "13.02528"
  },
  {
    "country": "AT",
    "name": "Irrsdorf",
    "lat": "47.96667",
    "lng": "13.28333"
  },
  {
    "country": "AT",
    "name": "Irdning",
    "lat": "47.50529",
    "lng": "14.10155"
  },
  {
    "country": "AT",
    "name": "Inzing",
    "lat": "47.2737",
    "lng": "11.19751"
  },
  {
    "country": "AT",
    "name": "Inzersdorf im Kremstal",
    "lat": "47.92808",
    "lng": "14.08104"
  },
  {
    "country": "AT",
    "name": "Inzenhof",
    "lat": "47.01667",
    "lng": "16.31667"
  },
  {
    "country": "AT",
    "name": "Innsbruck",
    "lat": "47.26266",
    "lng": "11.39454"
  },
  {
    "country": "AT",
    "name": "Weerberg",
    "lat": "47.29841",
    "lng": "11.66592"
  },
  {
    "country": "AT",
    "name": "Innervillgraten",
    "lat": "46.81194",
    "lng": "12.37472"
  },
  {
    "country": "AT",
    "name": "Innerschwand",
    "lat": "47.83333",
    "lng": "13.4"
  },
  {
    "country": "AT",
    "name": "Innere Stadt",
    "lat": "48.20906",
    "lng": "16.37135"
  },
  {
    "country": "AT",
    "name": "Innerbraz",
    "lat": "47.15",
    "lng": "9.91667"
  },
  {
    "country": "AT",
    "name": "Imsterberg",
    "lat": "47.20517",
    "lng": "10.69605"
  },
  {
    "country": "AT",
    "name": "Imst",
    "lat": "47.24504",
    "lng": "10.73974"
  },
  {
    "country": "AT",
    "name": "Ilz",
    "lat": "47.08649",
    "lng": "15.92676"
  },
  {
    "country": "AT",
    "name": "Illmitz",
    "lat": "47.76148",
    "lng": "16.80024"
  },
  {
    "country": "AT",
    "name": "Hüttschlag",
    "lat": "47.17635",
    "lng": "13.23239"
  },
  {
    "country": "AT",
    "name": "Hüttenberg",
    "lat": "46.94139",
    "lng": "14.55"
  },
  {
    "country": "AT",
    "name": "Hutten",
    "lat": "48.17856",
    "lng": "15.98579"
  },
  {
    "country": "AT",
    "name": "Hüttau",
    "lat": "47.4161",
    "lng": "13.30775"
  },
  {
    "country": "AT",
    "name": "Hürm",
    "lat": "48.15601",
    "lng": "15.41262"
  },
  {
    "country": "AT",
    "name": "Hundsheim",
    "lat": "48.11749",
    "lng": "16.93581"
  },
  {
    "country": "AT",
    "name": "Hötting",
    "lat": "47.26815",
    "lng": "11.36868"
  },
  {
    "country": "AT",
    "name": "Hörtendorf",
    "lat": "46.63333",
    "lng": "14.4"
  },
  {
    "country": "AT",
    "name": "Hörsching",
    "lat": "48.22627",
    "lng": "14.17786"
  },
  {
    "country": "AT",
    "name": "Hornstein",
    "lat": "47.88049",
    "lng": "16.44447"
  },
  {
    "country": "AT",
    "name": "Horn",
    "lat": "48.66274",
    "lng": "15.65663"
  },
  {
    "country": "AT",
    "name": "Horitschon",
    "lat": "47.58729",
    "lng": "16.54696"
  },
  {
    "country": "AT",
    "name": "Hörbranz",
    "lat": "47.55",
    "lng": "9.75"
  },
  {
    "country": "AT",
    "name": "Hopfgarten im Brixental",
    "lat": "47.4498",
    "lng": "12.15659"
  },
  {
    "country": "AT",
    "name": "Hopfgarten in Defereggen",
    "lat": "46.91917",
    "lng": "12.53639"
  },
  {
    "country": "AT",
    "name": "Hönigsberg",
    "lat": "47.58038",
    "lng": "15.64808"
  },
  {
    "country": "AT",
    "name": "Holzhausen",
    "lat": "48.22296",
    "lng": "14.09683"
  },
  {
    "country": "AT",
    "name": "Hollersbach im Pinzgau",
    "lat": "47.27658",
    "lng": "12.42326"
  },
  {
    "country": "AT",
    "name": "Hollenthon",
    "lat": "47.58938",
    "lng": "16.26131"
  },
  {
    "country": "AT",
    "name": "Hollenstein an der Ybbs",
    "lat": "47.80305",
    "lng": "14.77312"
  },
  {
    "country": "AT",
    "name": "Hollenegg",
    "lat": "46.79147",
    "lng": "15.21345"
  },
  {
    "country": "AT",
    "name": "Hollabrunn",
    "lat": "48.55",
    "lng": "16.08333"
  },
  {
    "country": "AT",
    "name": "Hohenweiler",
    "lat": "47.58333",
    "lng": "9.78333"
  },
  {
    "country": "AT",
    "name": "Hohenthurn",
    "lat": "46.55774",
    "lng": "13.66038"
  },
  {
    "country": "AT",
    "name": "Hohentauern",
    "lat": "47.43333",
    "lng": "14.48333"
  },
  {
    "country": "AT",
    "name": "Hohenruppersdorf",
    "lat": "48.46439",
    "lng": "16.65244"
  },
  {
    "country": "AT",
    "name": "Hohenems",
    "lat": "47.36667",
    "lng": "9.68306"
  },
  {
    "country": "AT",
    "name": "Hoheneich",
    "lat": "48.77195",
    "lng": "15.02857"
  },
  {
    "country": "AT",
    "name": "Hohenberg",
    "lat": "47.90679",
    "lng": "15.61998"
  },
  {
    "country": "AT",
    "name": "Hohenau an der Raab",
    "lat": "47.3",
    "lng": "15.55"
  },
  {
    "country": "AT",
    "name": "Hohenau",
    "lat": "48.6042",
    "lng": "16.9047"
  },
  {
    "country": "AT",
    "name": "Hofstetten",
    "lat": "48.09711",
    "lng": "15.51149"
  },
  {
    "country": "AT",
    "name": "Hofstätten an der Raab",
    "lat": "47.06667",
    "lng": "15.73333"
  },
  {
    "country": "AT",
    "name": "Höflein",
    "lat": "48.06667",
    "lng": "16.78333"
  },
  {
    "country": "AT",
    "name": "Hofkirchen im Traunkreis",
    "lat": "48.14312",
    "lng": "14.37776"
  },
  {
    "country": "AT",
    "name": "Höfen",
    "lat": "47.46667",
    "lng": "10.68333"
  },
  {
    "country": "AT",
    "name": "Hof bei Straden",
    "lat": "46.8",
    "lng": "15.93333"
  },
  {
    "country": "AT",
    "name": "Hof bei Salzburg",
    "lat": "47.81929",
    "lng": "13.21488"
  },
  {
    "country": "AT",
    "name": "Hof am Leithaberge",
    "lat": "47.95",
    "lng": "16.58333"
  },
  {
    "country": "AT",
    "name": "Hof",
    "lat": "47.86667",
    "lng": "13.31667"
  },
  {
    "country": "AT",
    "name": "Hof",
    "lat": "47.35",
    "lng": "13.31667"
  },
  {
    "country": "AT",
    "name": "Hochwolkersdorf",
    "lat": "47.66127",
    "lng": "16.28072"
  },
  {
    "country": "AT",
    "name": "Hochtregist",
    "lat": "47.1",
    "lng": "15.13333"
  },
  {
    "country": "AT",
    "name": "Höchst",
    "lat": "47.45934",
    "lng": "9.6405"
  },
  {
    "country": "AT",
    "name": "Hochfilzen",
    "lat": "47.46667",
    "lng": "12.61667"
  },
  {
    "country": "AT",
    "name": "Hochburg-Ach",
    "lat": "48.13001",
    "lng": "12.87735"
  },
  {
    "country": "AT",
    "name": "Hitzendorf",
    "lat": "47.03333",
    "lng": "15.3"
  },
  {
    "country": "AT",
    "name": "Hirtenberg",
    "lat": "47.93095",
    "lng": "16.17908"
  },
  {
    "country": "AT",
    "name": "Hirschegg",
    "lat": "47.34813",
    "lng": "10.17137"
  },
  {
    "country": "AT",
    "name": "Hirschbach",
    "lat": "48.74329",
    "lng": "15.12521"
  },
  {
    "country": "AT",
    "name": "Hirnsdorf",
    "lat": "47.19167",
    "lng": "15.82868"
  },
  {
    "country": "AT",
    "name": "Hirm",
    "lat": "47.78652",
    "lng": "16.4546"
  },
  {
    "country": "AT",
    "name": "Hippach",
    "lat": "47.20435",
    "lng": "11.86523"
  },
  {
    "country": "AT",
    "name": "Hintersee",
    "lat": "47.7",
    "lng": "13.28333"
  },
  {
    "country": "AT",
    "name": "Hinterbrühl",
    "lat": "48.08611",
    "lng": "16.24809"
  },
  {
    "country": "AT",
    "name": "Himmelreich",
    "lat": "47.8",
    "lng": "12.98333"
  },
  {
    "country": "AT",
    "name": "Himmelberg",
    "lat": "46.75667",
    "lng": "14.03056"
  },
  {
    "country": "AT",
    "name": "Himberg",
    "lat": "48.08333",
    "lng": "16.43333"
  },
  {
    "country": "AT",
    "name": "Hietzing",
    "lat": "48.18623",
    "lng": "16.2965"
  },
  {
    "country": "AT",
    "name": "Hieflau",
    "lat": "47.60639",
    "lng": "14.74503"
  },
  {
    "country": "AT",
    "name": "Heugraben",
    "lat": "47.11783",
    "lng": "16.19041"
  },
  {
    "country": "AT",
    "name": "Hetzendorf",
    "lat": "47.18333",
    "lng": "14.68333"
  },
  {
    "country": "AT",
    "name": "Herzogsdorf",
    "lat": "48.43011",
    "lng": "14.1128"
  },
  {
    "country": "AT",
    "name": "Herzogenburg",
    "lat": "48.28137",
    "lng": "15.69431"
  },
  {
    "country": "AT",
    "name": "Herrnbaumgarten",
    "lat": "48.69606",
    "lng": "16.68283"
  },
  {
    "country": "AT",
    "name": "Hernstein",
    "lat": "47.89465",
    "lng": "16.10561"
  },
  {
    "country": "AT",
    "name": "Hernals",
    "lat": "48.23333",
    "lng": "16.26667"
  },
  {
    "country": "AT",
    "name": "Hermagor",
    "lat": "46.62722",
    "lng": "13.36722"
  },
  {
    "country": "AT",
    "name": "Hennersdorf",
    "lat": "48.11173",
    "lng": "16.36311"
  },
  {
    "country": "AT",
    "name": "Henndorf am Wallersee",
    "lat": "47.9",
    "lng": "13.18333"
  },
  {
    "country": "AT",
    "name": "Hengsberg",
    "lat": "46.86667",
    "lng": "15.43333"
  },
  {
    "country": "AT",
    "name": "Hellmonsödt",
    "lat": "48.43333",
    "lng": "14.3"
  },
  {
    "country": "AT",
    "name": "Heiterwang",
    "lat": "47.45",
    "lng": "10.75"
  },
  {
    "country": "AT",
    "name": "Heiligenkreuz im Lafnitztal",
    "lat": "46.98917",
    "lng": "16.26083"
  },
  {
    "country": "AT",
    "name": "Heiligenkreuz am Waasen",
    "lat": "46.95583",
    "lng": "15.58806"
  },
  {
    "country": "AT",
    "name": "Heiligenkreuz",
    "lat": "48.05559",
    "lng": "16.12493"
  },
  {
    "country": "AT",
    "name": "Heiligeneich",
    "lat": "48.29964",
    "lng": "15.89413"
  },
  {
    "country": "AT",
    "name": "Heiligenbrunn",
    "lat": "47.02705",
    "lng": "16.41688"
  },
  {
    "country": "AT",
    "name": "Heiligenblut",
    "lat": "47.03979",
    "lng": "12.84345"
  },
  {
    "country": "AT",
    "name": "Heidenreichstein",
    "lat": "48.86667",
    "lng": "15.11667"
  },
  {
    "country": "AT",
    "name": "Hausmening",
    "lat": "48.07074",
    "lng": "14.81438"
  },
  {
    "country": "AT",
    "name": "Hausmannstätten",
    "lat": "46.99111",
    "lng": "15.51139"
  },
  {
    "country": "AT",
    "name": "Hausleiten",
    "lat": "48.38333",
    "lng": "16.1"
  },
  {
    "country": "AT",
    "name": "Hauskirchen",
    "lat": "48.6",
    "lng": "16.76667"
  },
  {
    "country": "AT",
    "name": "Hausbrunn",
    "lat": "48.62602",
    "lng": "16.82844"
  },
  {
    "country": "AT",
    "name": "Haus",
    "lat": "47.40997",
    "lng": "13.76724"
  },
  {
    "country": "AT",
    "name": "Haunoldstein",
    "lat": "48.2",
    "lng": "15.45"
  },
  {
    "country": "AT",
    "name": "Haugsdorf",
    "lat": "48.70762",
    "lng": "16.07656"
  },
  {
    "country": "AT",
    "name": "Haugschlag",
    "lat": "48.98333",
    "lng": "15.05"
  },
  {
    "country": "AT",
    "name": "Hatzendorf",
    "lat": "46.97686",
    "lng": "16.00107"
  },
  {
    "country": "AT",
    "name": "Hatting",
    "lat": "47.2787",
    "lng": "11.16838"
  },
  {
    "country": "AT",
    "name": "Haslach an der Mühl",
    "lat": "48.5757",
    "lng": "14.03984"
  },
  {
    "country": "AT",
    "name": "Häselgehr",
    "lat": "47.31667",
    "lng": "10.5"
  },
  {
    "country": "AT",
    "name": "Haselbach",
    "lat": "48.25308",
    "lng": "13.05614"
  },
  {
    "country": "AT",
    "name": "Hartmannsdorf",
    "lat": "47.05461",
    "lng": "15.83941"
  },
  {
    "country": "AT",
    "name": "Hartl",
    "lat": "47.18333",
    "lng": "15.91667"
  },
  {
    "country": "AT",
    "name": "Hartkirchen",
    "lat": "48.36349",
    "lng": "14.00422"
  },
  {
    "country": "AT",
    "name": "Hart im Zillertal",
    "lat": "47.35106",
    "lng": "11.86476"
  },
  {
    "country": "AT",
    "name": "Hartheim",
    "lat": "48.28079",
    "lng": "14.11426"
  },
  {
    "country": "AT",
    "name": "Hartberg",
    "lat": "47.28333",
    "lng": "15.96667"
  },
  {
    "country": "AT",
    "name": "Hart",
    "lat": "48.26526",
    "lng": "14.25691"
  },
  {
    "country": "AT",
    "name": "Harmannsdorf",
    "lat": "48.39724",
    "lng": "16.3722"
  },
  {
    "country": "AT",
    "name": "Harland",
    "lat": "48.16162",
    "lng": "15.63835"
  },
  {
    "country": "AT",
    "name": "Haringsee",
    "lat": "48.1927",
    "lng": "16.78741"
  },
  {
    "country": "AT",
    "name": "Bad Häring",
    "lat": "47.51071",
    "lng": "12.11912"
  },
  {
    "country": "AT",
    "name": "Hardegg",
    "lat": "48.85",
    "lng": "15.85"
  },
  {
    "country": "AT",
    "name": "Hard",
    "lat": "47.48306",
    "lng": "9.68306"
  },
  {
    "country": "AT",
    "name": "Hannersdorf",
    "lat": "47.22895",
    "lng": "16.3825"
  },
  {
    "country": "AT",
    "name": "Handenberg",
    "lat": "48.13356",
    "lng": "13.00751"
  },
  {
    "country": "AT",
    "name": "Hallwang",
    "lat": "47.85",
    "lng": "13.08333"
  },
  {
    "country": "AT",
    "name": "Hallein",
    "lat": "47.68333",
    "lng": "13.1"
  },
  {
    "country": "AT",
    "name": "Halbturn",
    "lat": "47.87019",
    "lng": "16.97542"
  },
  {
    "country": "AT",
    "name": "Halbenrain",
    "lat": "46.72194",
    "lng": "15.94667"
  },
  {
    "country": "AT",
    "name": "Hainzenberg",
    "lat": "47.21788",
    "lng": "11.90034"
  },
  {
    "country": "AT",
    "name": "Hainsdorf im Schwarzautal",
    "lat": "46.83583",
    "lng": "15.64139"
  },
  {
    "country": "AT",
    "name": "Hainfeld",
    "lat": "48.0339",
    "lng": "15.77414"
  },
  {
    "country": "AT",
    "name": "Hainersdorf",
    "lat": "47.11506",
    "lng": "15.94374"
  },
  {
    "country": "AT",
    "name": "Hainburg an der Donau",
    "lat": "48.14627",
    "lng": "16.94504"
  },
  {
    "country": "AT",
    "name": "Haiming",
    "lat": "47.25",
    "lng": "10.88333"
  },
  {
    "country": "AT",
    "name": "Haidershofen",
    "lat": "48.07579",
    "lng": "14.46131"
  },
  {
    "country": "AT",
    "name": "Haiden",
    "lat": "47.7179",
    "lng": "13.56906"
  },
  {
    "country": "AT",
    "name": "Haid",
    "lat": "48.20477",
    "lng": "14.25107"
  },
  {
    "country": "AT",
    "name": "Haibach im Mühlkreis",
    "lat": "48.44429",
    "lng": "14.34411"
  },
  {
    "country": "AT",
    "name": "Hagenbrunn",
    "lat": "48.33333",
    "lng": "16.4"
  },
  {
    "country": "AT",
    "name": "Hagenberg im Mühlkreis",
    "lat": "48.36788",
    "lng": "14.51689"
  },
  {
    "country": "AT",
    "name": "Hafnerbach",
    "lat": "48.21667",
    "lng": "15.48333"
  },
  {
    "country": "AT",
    "name": "Hafendorf",
    "lat": "47.45653",
    "lng": "15.31837"
  },
  {
    "country": "AT",
    "name": "Hadres",
    "lat": "48.70965",
    "lng": "16.13038"
  },
  {
    "country": "AT",
    "name": "Hadersdorf am Kamp",
    "lat": "48.45",
    "lng": "15.71667"
  },
  {
    "country": "AT",
    "name": "Hackerberg",
    "lat": "47.2",
    "lng": "16.11667"
  },
  {
    "country": "AT",
    "name": "Habach",
    "lat": "47.81753",
    "lng": "13.16252"
  },
  {
    "country": "AT",
    "name": "Haag am Hausruck",
    "lat": "48.18423",
    "lng": "13.64373"
  },
  {
    "country": "AT",
    "name": "Haag",
    "lat": "48.27063",
    "lng": "14.26875"
  },
  {
    "country": "AT",
    "name": "Haag",
    "lat": "48.19027",
    "lng": "15.90135"
  },
  {
    "country": "AT",
    "name": "Haag",
    "lat": "48.11362",
    "lng": "14.56753"
  },
  {
    "country": "AT",
    "name": "Güttenbach",
    "lat": "47.1571",
    "lng": "16.2923"
  },
  {
    "country": "AT",
    "name": "Guttaring",
    "lat": "46.88536",
    "lng": "14.51071"
  },
  {
    "country": "AT",
    "name": "Gutenstein",
    "lat": "47.876",
    "lng": "15.88881"
  },
  {
    "country": "AT",
    "name": "Gutenbrunn",
    "lat": "48.3652",
    "lng": "15.11899"
  },
  {
    "country": "AT",
    "name": "Gutau",
    "lat": "48.41724",
    "lng": "14.61285"
  },
  {
    "country": "AT",
    "name": "Güssing",
    "lat": "47.05936",
    "lng": "16.32431"
  },
  {
    "country": "AT",
    "name": "Gurk",
    "lat": "46.87389",
    "lng": "14.29167"
  },
  {
    "country": "AT",
    "name": "Guntramsdorf",
    "lat": "48.04687",
    "lng": "16.31384"
  },
  {
    "country": "AT",
    "name": "Guntersdorf",
    "lat": "48.65",
    "lng": "16.05"
  },
  {
    "country": "AT",
    "name": "Gunskirchen",
    "lat": "48.13333",
    "lng": "13.95"
  },
  {
    "country": "AT",
    "name": "Günselsdorf",
    "lat": "47.94395",
    "lng": "16.26062"
  },
  {
    "country": "AT",
    "name": "Gundersdorf",
    "lat": "46.95",
    "lng": "15.23333"
  },
  {
    "country": "AT",
    "name": "Gumpoldskirchen",
    "lat": "48.04538",
    "lng": "16.2771"
  },
  {
    "country": "AT",
    "name": "Gugging",
    "lat": "48.31385",
    "lng": "16.24852"
  },
  {
    "country": "AT",
    "name": "Gschwandt",
    "lat": "47.93515",
    "lng": "13.84569"
  },
  {
    "country": "AT",
    "name": "Grünbach am Schneeberg",
    "lat": "47.79747",
    "lng": "15.98785"
  },
  {
    "country": "AT",
    "name": "Grünau im Almtal",
    "lat": "47.85493",
    "lng": "13.95573"
  },
  {
    "country": "AT",
    "name": "Großweikersdorf",
    "lat": "48.47123",
    "lng": "15.98251"
  },
  {
    "country": "AT",
    "name": "Grosssulz",
    "lat": "46.94556",
    "lng": "15.49028"
  },
  {
    "country": "AT",
    "name": "Großsölk",
    "lat": "47.41667",
    "lng": "13.96667"
  },
  {
    "country": "AT",
    "name": "Groß-Siegharts",
    "lat": "48.7918",
    "lng": "15.40429"
  },
  {
    "country": "AT",
    "name": "Groß-Schweinbarth",
    "lat": "48.41472",
    "lng": "16.63194"
  },
  {
    "country": "AT",
    "name": "Groß Sankt Florian",
    "lat": "46.82444",
    "lng": "15.31861"
  },
  {
    "country": "AT",
    "name": "Großrußbach",
    "lat": "48.47412",
    "lng": "16.41649"
  },
  {
    "country": "AT",
    "name": "Großriedenthal",
    "lat": "48.48333",
    "lng": "15.86667"
  },
  {
    "country": "AT",
    "name": "Grossraming",
    "lat": "47.88333",
    "lng": "14.55"
  },
  {
    "country": "AT",
    "name": "Grosspetersdorf",
    "lat": "47.23895",
    "lng": "16.31783"
  },
  {
    "country": "AT",
    "name": "Großmugl",
    "lat": "48.49917",
    "lng": "16.23056"
  },
  {
    "country": "AT",
    "name": "Großlobming",
    "lat": "47.18333",
    "lng": "14.8"
  },
  {
    "country": "AT",
    "name": "Großkrut",
    "lat": "48.64389",
    "lng": "16.72361"
  },
  {
    "country": "AT",
    "name": "Großklein",
    "lat": "46.73611",
    "lng": "15.44444"
  },
  {
    "country": "AT",
    "name": "Grosshöflein",
    "lat": "47.83586",
    "lng": "16.48035"
  },
  {
    "country": "AT",
    "name": "Großhofen",
    "lat": "48.25834",
    "lng": "16.6194"
  },
  {
    "country": "AT",
    "name": "Heimschuh",
    "lat": "46.76",
    "lng": "15.49306"
  },
  {
    "country": "AT",
    "name": "Großharras",
    "lat": "48.66389",
    "lng": "16.24556"
  },
  {
    "country": "AT",
    "name": "Grossgmain",
    "lat": "47.71667",
    "lng": "12.91667"
  },
  {
    "country": "AT",
    "name": "Groß-Gerungs",
    "lat": "48.57422",
    "lng": "14.95789"
  },
  {
    "country": "AT",
    "name": "Groß-Enzersdorf",
    "lat": "48.20278",
    "lng": "16.55083"
  },
  {
    "country": "AT",
    "name": "Groß-Engersdorf",
    "lat": "48.35873",
    "lng": "16.5661"
  },
  {
    "country": "AT",
    "name": "Großebersdorf",
    "lat": "48.36405",
    "lng": "16.47076"
  },
  {
    "country": "AT",
    "name": "Großdorf",
    "lat": "47.43361",
    "lng": "9.91528"
  },
  {
    "country": "AT",
    "name": "Grossarl",
    "lat": "47.23333",
    "lng": "13.2"
  },
  {
    "country": "AT",
    "name": "Grödig",
    "lat": "47.73833",
    "lng": "13.0373"
  },
  {
    "country": "AT",
    "name": "Gröbming",
    "lat": "47.44272",
    "lng": "13.90122"
  },
  {
    "country": "AT",
    "name": "Grins",
    "lat": "47.14034",
    "lng": "10.51409"
  },
  {
    "country": "AT",
    "name": "Grimmenstein",
    "lat": "47.61635",
    "lng": "16.12724"
  },
  {
    "country": "AT",
    "name": "Griffen",
    "lat": "46.70444",
    "lng": "14.73278"
  },
  {
    "country": "AT",
    "name": "Grieskirchen",
    "lat": "48.23333",
    "lng": "13.83333"
  },
  {
    "country": "AT",
    "name": "Gries im Sellrain",
    "lat": "47.19554",
    "lng": "11.15619"
  },
  {
    "country": "AT",
    "name": "Gries am Brenner",
    "lat": "47.03849",
    "lng": "11.48131"
  },
  {
    "country": "AT",
    "name": "Gresten",
    "lat": "47.98521",
    "lng": "15.02552"
  },
  {
    "country": "AT",
    "name": "Gressenberg",
    "lat": "46.8",
    "lng": "15.11667"
  },
  {
    "country": "AT",
    "name": "Greisdorf",
    "lat": "46.92647",
    "lng": "15.21906"
  },
  {
    "country": "AT",
    "name": "Greinsfurth",
    "lat": "48.10846",
    "lng": "14.8439"
  },
  {
    "country": "AT",
    "name": "Grein",
    "lat": "48.22862",
    "lng": "14.85884"
  },
  {
    "country": "AT",
    "name": "Greifenburg",
    "lat": "46.75027",
    "lng": "13.17982"
  },
  {
    "country": "AT",
    "name": "Graz",
    "lat": "47.06667",
    "lng": "15.45"
  },
  {
    "country": "AT",
    "name": "Gratwein",
    "lat": "47.11667",
    "lng": "15.31667"
  },
  {
    "country": "AT",
    "name": "Gratkorn",
    "lat": "47.13333",
    "lng": "15.35"
  },
  {
    "country": "AT",
    "name": "Grän",
    "lat": "47.5",
    "lng": "10.55"
  },
  {
    "country": "AT",
    "name": "Grambach",
    "lat": "47.01473",
    "lng": "15.50407"
  },
  {
    "country": "AT",
    "name": "Gramatneusiedl",
    "lat": "48.0304",
    "lng": "16.48936"
  },
  {
    "country": "AT",
    "name": "Gramastetten",
    "lat": "48.38028",
    "lng": "14.19185"
  },
  {
    "country": "AT",
    "name": "Gramais",
    "lat": "47.26667",
    "lng": "10.53333"
  },
  {
    "country": "AT",
    "name": "Grafenwörth",
    "lat": "48.4079",
    "lng": "15.77826"
  },
  {
    "country": "AT",
    "name": "Grafenstein",
    "lat": "46.61393",
    "lng": "14.46719"
  },
  {
    "country": "AT",
    "name": "Grafenschlag",
    "lat": "48.5",
    "lng": "15.16667"
  },
  {
    "country": "AT",
    "name": "Grafenschachen",
    "lat": "47.36667",
    "lng": "16.06667"
  },
  {
    "country": "AT",
    "name": "Grafenegg",
    "lat": "48.4304",
    "lng": "15.74907"
  },
  {
    "country": "AT",
    "name": "Grafendorf bei Hartberg",
    "lat": "47.34028",
    "lng": "15.9906"
  },
  {
    "country": "AT",
    "name": "Grabersdorf",
    "lat": "46.84306",
    "lng": "15.82472"
  },
  {
    "country": "AT",
    "name": "Götzis",
    "lat": "47.33306",
    "lng": "9.63306"
  },
  {
    "country": "AT",
    "name": "Götzens",
    "lat": "47.23606",
    "lng": "11.31154"
  },
  {
    "country": "AT",
    "name": "Götzendorf an der Leitha",
    "lat": "48.01667",
    "lng": "16.58333"
  },
  {
    "country": "AT",
    "name": "Göttelsberg",
    "lat": "47.21667",
    "lng": "15.6"
  },
  {
    "country": "AT",
    "name": "Göstling an der Ybbs",
    "lat": "47.80664",
    "lng": "14.93797"
  },
  {
    "country": "AT",
    "name": "Gösting",
    "lat": "47.09788",
    "lng": "15.39777"
  },
  {
    "country": "AT",
    "name": "Gössendorf",
    "lat": "46.99826",
    "lng": "15.48556"
  },
  {
    "country": "AT",
    "name": "Gossendorf",
    "lat": "46.91076",
    "lng": "15.93043"
  },
  {
    "country": "AT",
    "name": "Gössenberg",
    "lat": "47.41667",
    "lng": "13.81667"
  },
  {
    "country": "AT",
    "name": "Göss",
    "lat": "47.35871",
    "lng": "15.10015"
  },
  {
    "country": "AT",
    "name": "Gosdorf",
    "lat": "46.72778",
    "lng": "15.7925"
  },
  {
    "country": "AT",
    "name": "Gosau",
    "lat": "47.58417",
    "lng": "13.53447"
  },
  {
    "country": "AT",
    "name": "Göpfritz an der Wild",
    "lat": "48.72497",
    "lng": "15.40236"
  },
  {
    "country": "AT",
    "name": "Gols",
    "lat": "47.89689",
    "lng": "16.91113"
  },
  {
    "country": "AT",
    "name": "Golling an der Salzach",
    "lat": "47.6",
    "lng": "13.16667"
  },
  {
    "country": "AT",
    "name": "Göllersdorf",
    "lat": "48.49357",
    "lng": "16.11943"
  },
  {
    "country": "AT",
    "name": "Goldwörth",
    "lat": "48.32664",
    "lng": "14.10112"
  },
  {
    "country": "AT",
    "name": "Goldegg",
    "lat": "47.31875",
    "lng": "13.09922"
  },
  {
    "country": "AT",
    "name": "Going",
    "lat": "47.51332",
    "lng": "12.33164"
  },
  {
    "country": "AT",
    "name": "Göfis",
    "lat": "47.23356",
    "lng": "9.63458"
  },
  {
    "country": "AT",
    "name": "Gniebing",
    "lat": "46.96252",
    "lng": "15.85645"
  },
  {
    "country": "AT",
    "name": "Gnesau",
    "lat": "46.77544",
    "lng": "13.96251"
  },
  {
    "country": "AT",
    "name": "Gneixendorf",
    "lat": "48.43751",
    "lng": "15.6181"
  },
  {
    "country": "AT",
    "name": "Gnas",
    "lat": "46.87306",
    "lng": "15.82528"
  },
  {
    "country": "AT",
    "name": "Gnadendorf",
    "lat": "48.61667",
    "lng": "16.4"
  },
  {
    "country": "AT",
    "name": "Gmunden",
    "lat": "47.91839",
    "lng": "13.79933"
  },
  {
    "country": "AT",
    "name": "Gmünd",
    "lat": "48.7683",
    "lng": "14.9808"
  },
  {
    "country": "AT",
    "name": "Gmünd",
    "lat": "46.90722",
    "lng": "13.52944"
  },
  {
    "country": "AT",
    "name": "Glojach",
    "lat": "46.86667",
    "lng": "15.66667"
  },
  {
    "country": "AT",
    "name": "Gloggnitz",
    "lat": "47.67487",
    "lng": "15.93893"
  },
  {
    "country": "AT",
    "name": "Glödnitz",
    "lat": "46.87398",
    "lng": "14.11915"
  },
  {
    "country": "AT",
    "name": "Globasnitz",
    "lat": "46.55694",
    "lng": "14.70278"
  },
  {
    "country": "AT",
    "name": "Glinzendorf",
    "lat": "48.24605",
    "lng": "16.6406"
  },
  {
    "country": "AT",
    "name": "Gleisdorf",
    "lat": "47.10559",
    "lng": "15.71011"
  },
  {
    "country": "AT",
    "name": "Gleinstätten",
    "lat": "46.75361",
    "lng": "15.36972"
  },
  {
    "country": "AT",
    "name": "Glasenbach",
    "lat": "47.76667",
    "lng": "13.08333"
  },
  {
    "country": "AT",
    "name": "Glanegg",
    "lat": "47.75",
    "lng": "13"
  },
  {
    "country": "AT",
    "name": "Glanegg",
    "lat": "46.72259",
    "lng": "14.19893"
  },
  {
    "country": "AT",
    "name": "Gießhübl",
    "lat": "48.0978",
    "lng": "16.23479"
  },
  {
    "country": "AT",
    "name": "Gföhl",
    "lat": "48.51667",
    "lng": "15.48333"
  },
  {
    "country": "AT",
    "name": "Gersdorf an der Feistritz",
    "lat": "47.16667",
    "lng": "15.85"
  },
  {
    "country": "AT",
    "name": "Gerolding",
    "lat": "48.25",
    "lng": "15.41667"
  },
  {
    "country": "AT",
    "name": "Gerersdorf",
    "lat": "48.20088",
    "lng": "15.55613"
  },
  {
    "country": "AT",
    "name": "Gerasdorf bei Wien",
    "lat": "48.29447",
    "lng": "16.46765"
  },
  {
    "country": "AT",
    "name": "Geras",
    "lat": "48.79725",
    "lng": "15.67268"
  },
  {
    "country": "AT",
    "name": "Georgenberg",
    "lat": "47.63333",
    "lng": "13.15"
  },
  {
    "country": "AT",
    "name": "Geistthal",
    "lat": "47.16667",
    "lng": "15.16667"
  },
  {
    "country": "AT",
    "name": "Gedersdorf",
    "lat": "48.43319",
    "lng": "15.68865"
  },
  {
    "country": "AT",
    "name": "Geboltskirchen",
    "lat": "48.15338",
    "lng": "13.6336"
  },
  {
    "country": "AT",
    "name": "Gaweinstal",
    "lat": "48.48003",
    "lng": "16.5879"
  },
  {
    "country": "AT",
    "name": "Gaubitsch",
    "lat": "48.65",
    "lng": "16.38333"
  },
  {
    "country": "AT",
    "name": "Gattendorf",
    "lat": "48.01667",
    "lng": "16.98333"
  },
  {
    "country": "AT",
    "name": "Gastern",
    "lat": "48.89446",
    "lng": "15.22027"
  },
  {
    "country": "AT",
    "name": "Gaspoltshofen",
    "lat": "48.14324",
    "lng": "13.73643"
  },
  {
    "country": "AT",
    "name": "Gasen",
    "lat": "47.38333",
    "lng": "15.56667"
  },
  {
    "country": "AT",
    "name": "Gaschurn",
    "lat": "46.98584",
    "lng": "10.02702"
  },
  {
    "country": "AT",
    "name": "Garsten",
    "lat": "48.0224",
    "lng": "14.40747"
  },
  {
    "country": "AT",
    "name": "Gars am Kamp",
    "lat": "48.58899",
    "lng": "15.65363"
  },
  {
    "country": "AT",
    "name": "Garanas",
    "lat": "46.76667",
    "lng": "15.11667"
  },
  {
    "country": "AT",
    "name": "Ganz",
    "lat": "47.6",
    "lng": "15.68333"
  },
  {
    "country": "AT",
    "name": "Gänserndorf",
    "lat": "48.33925",
    "lng": "16.72016"
  },
  {
    "country": "AT",
    "name": "Bad Gams",
    "lat": "46.87111",
    "lng": "15.22472"
  },
  {
    "country": "AT",
    "name": "Gams bei Hieflau",
    "lat": "47.66667",
    "lng": "14.78333"
  },
  {
    "country": "AT",
    "name": "Gampern",
    "lat": "47.98877",
    "lng": "13.5543"
  },
  {
    "country": "AT",
    "name": "Gamlitz",
    "lat": "46.72028",
    "lng": "15.55333"
  },
  {
    "country": "AT",
    "name": "Gaming",
    "lat": "47.929",
    "lng": "15.08818"
  },
  {
    "country": "AT",
    "name": "Galtür",
    "lat": "46.96667",
    "lng": "10.18333"
  },
  {
    "country": "AT",
    "name": "Gallzein",
    "lat": "47.36807",
    "lng": "11.77159"
  },
  {
    "country": "AT",
    "name": "Gallspach",
    "lat": "48.20992",
    "lng": "13.80981"
  },
  {
    "country": "AT",
    "name": "Gallneukirchen",
    "lat": "48.35363",
    "lng": "14.41604"
  },
  {
    "country": "AT",
    "name": "Gallmannsegg",
    "lat": "47.18333",
    "lng": "15.06667"
  },
  {
    "country": "AT",
    "name": "Gallizien",
    "lat": "46.55",
    "lng": "14.51667"
  },
  {
    "country": "AT",
    "name": "Gaißau",
    "lat": "47.46667",
    "lng": "9.6"
  },
  {
    "country": "AT",
    "name": "Gainfarn",
    "lat": "47.9628",
    "lng": "16.19368"
  },
  {
    "country": "AT",
    "name": "Gailitz",
    "lat": "46.56083",
    "lng": "13.70444"
  },
  {
    "country": "AT",
    "name": "Gaflenz",
    "lat": "47.89511",
    "lng": "14.72477"
  },
  {
    "country": "AT",
    "name": "Gablitz",
    "lat": "48.22856",
    "lng": "16.15437"
  },
  {
    "country": "AT",
    "name": "Gabersdorf",
    "lat": "46.77722",
    "lng": "15.58417"
  },
  {
    "country": "AT",
    "name": "Gaal",
    "lat": "47.27268",
    "lng": "14.67003"
  },
  {
    "country": "AT",
    "name": "Gaaden",
    "lat": "48.05364",
    "lng": "16.20003"
  },
  {
    "country": "AT",
    "name": "Fußach",
    "lat": "47.47933",
    "lng": "9.66278"
  },
  {
    "country": "AT",
    "name": "Fuschl am See",
    "lat": "47.8",
    "lng": "13.3"
  },
  {
    "country": "AT",
    "name": "Furth an der Triesting",
    "lat": "47.97326",
    "lng": "15.97326"
  },
  {
    "country": "AT",
    "name": "Furth bei Göttweig",
    "lat": "48.37385",
    "lng": "15.61408"
  },
  {
    "country": "AT",
    "name": "Fürstenfeld",
    "lat": "47.05",
    "lng": "16.08333"
  },
  {
    "country": "AT",
    "name": "Fürnitz",
    "lat": "46.56188",
    "lng": "13.81732"
  },
  {
    "country": "AT",
    "name": "Fulpmes",
    "lat": "47.15202",
    "lng": "11.34922"
  },
  {
    "country": "AT",
    "name": "Fügenberg",
    "lat": "47.3521",
    "lng": "11.84173"
  },
  {
    "country": "AT",
    "name": "Fügen",
    "lat": "47.347",
    "lng": "11.84939"
  },
  {
    "country": "AT",
    "name": "Frohsdorf",
    "lat": "47.73333",
    "lng": "16.25"
  },
  {
    "country": "AT",
    "name": "Frohnleiten",
    "lat": "47.26667",
    "lng": "15.31667"
  },
  {
    "country": "AT",
    "name": "Fritzens",
    "lat": "47.30535",
    "lng": "11.5895"
  },
  {
    "country": "AT",
    "name": "Friesach",
    "lat": "46.95528",
    "lng": "14.40583"
  },
  {
    "country": "AT",
    "name": "Friedberg",
    "lat": "47.43333",
    "lng": "16.05"
  },
  {
    "country": "AT",
    "name": "Fresach",
    "lat": "46.71556",
    "lng": "13.69083"
  },
  {
    "country": "AT",
    "name": "Freistadt",
    "lat": "48.51103",
    "lng": "14.50453"
  },
  {
    "country": "AT",
    "name": "Freindorf",
    "lat": "48.2257",
    "lng": "14.2951"
  },
  {
    "country": "AT",
    "name": "Freiland bei Deutschlandsberg",
    "lat": "46.83333",
    "lng": "15.13333"
  },
  {
    "country": "AT",
    "name": "Freidorf an der Laßnitz",
    "lat": "46.81667",
    "lng": "15.25"
  },
  {
    "country": "AT",
    "name": "Fraxern",
    "lat": "47.31498",
    "lng": "9.67391"
  },
  {
    "country": "AT",
    "name": "Frauenkirchen",
    "lat": "47.83678",
    "lng": "16.92581"
  },
  {
    "country": "AT",
    "name": "Frauenberg",
    "lat": "47.42855",
    "lng": "15.34206"
  },
  {
    "country": "AT",
    "name": "Frannach",
    "lat": "46.91306",
    "lng": "15.63361"
  },
  {
    "country": "AT",
    "name": "Frankenmarkt",
    "lat": "47.98333",
    "lng": "13.41667"
  },
  {
    "country": "AT",
    "name": "Frankenfels",
    "lat": "47.98234",
    "lng": "15.32593"
  },
  {
    "country": "AT",
    "name": "Frankenburg",
    "lat": "48.06844",
    "lng": "13.49065"
  },
  {
    "country": "AT",
    "name": "Forstau",
    "lat": "47.37842",
    "lng": "13.55558"
  },
  {
    "country": "AT",
    "name": "Fornach",
    "lat": "48.02277",
    "lng": "13.42941"
  },
  {
    "country": "AT",
    "name": "Forchtenstein",
    "lat": "47.71161",
    "lng": "16.34525"
  },
  {
    "country": "AT",
    "name": "Forchach",
    "lat": "47.41667",
    "lng": "10.58333"
  },
  {
    "country": "AT",
    "name": "Fohnsdorf",
    "lat": "47.2",
    "lng": "14.68333"
  },
  {
    "country": "AT",
    "name": "Floridsdorf",
    "lat": "48.25",
    "lng": "16.4"
  },
  {
    "country": "AT",
    "name": "Floing",
    "lat": "47.26356",
    "lng": "15.7465"
  },
  {
    "country": "AT",
    "name": "Flirsch",
    "lat": "47.15",
    "lng": "10.4"
  },
  {
    "country": "AT",
    "name": "Fliess",
    "lat": "47.11667",
    "lng": "10.61667"
  },
  {
    "country": "AT",
    "name": "Flaurling",
    "lat": "47.29143",
    "lng": "11.12319"
  },
  {
    "country": "AT",
    "name": "Flattach",
    "lat": "46.93861",
    "lng": "13.13444"
  },
  {
    "country": "AT",
    "name": "Flatschach",
    "lat": "47.21667",
    "lng": "14.75"
  },
  {
    "country": "AT",
    "name": "Fladnitz im Raabtal",
    "lat": "46.99167",
    "lng": "15.78528"
  },
  {
    "country": "AT",
    "name": "Flachau",
    "lat": "47.34406",
    "lng": "13.39148"
  },
  {
    "country": "AT",
    "name": "Fiss",
    "lat": "47.05714",
    "lng": "10.61747"
  },
  {
    "country": "AT",
    "name": "Fisching",
    "lat": "48.22301",
    "lng": "14.42771"
  },
  {
    "country": "AT",
    "name": "Fischbach",
    "lat": "47.44234",
    "lng": "15.64972"
  },
  {
    "country": "AT",
    "name": "Fischamend-Markt",
    "lat": "48.11667",
    "lng": "16.6"
  },
  {
    "country": "AT",
    "name": "Finkenstein",
    "lat": "46.56155",
    "lng": "13.87086"
  },
  {
    "country": "AT",
    "name": "Finkenberg",
    "lat": "47.15279",
    "lng": "11.82212"
  },
  {
    "country": "AT",
    "name": "Filzmoos",
    "lat": "47.43333",
    "lng": "13.51667"
  },
  {
    "country": "AT",
    "name": "Fiecht",
    "lat": "47.35",
    "lng": "11.7"
  },
  {
    "country": "AT",
    "name": "Fieberbrunn",
    "lat": "47.47626",
    "lng": "12.54347"
  },
  {
    "country": "AT",
    "name": "Ferschnitz",
    "lat": "48.09419",
    "lng": "14.98454"
  },
  {
    "country": "AT",
    "name": "Fernitz",
    "lat": "46.97389",
    "lng": "15.50111"
  },
  {
    "country": "AT",
    "name": "Ferndorf",
    "lat": "46.73651",
    "lng": "13.62661"
  },
  {
    "country": "AT",
    "name": "Ferlach",
    "lat": "46.52694",
    "lng": "14.30194"
  },
  {
    "country": "AT",
    "name": "Fendels",
    "lat": "47.0539",
    "lng": "10.67777"
  },
  {
    "country": "AT",
    "name": "Fels am Wagram",
    "lat": "48.43333",
    "lng": "15.81667"
  },
  {
    "country": "AT",
    "name": "Felixdorf",
    "lat": "47.88159",
    "lng": "16.24208"
  },
  {
    "country": "AT",
    "name": "Feldkirchen in Kärnten",
    "lat": "46.72368",
    "lng": "14.0958"
  },
  {
    "country": "AT",
    "name": "Feldkirchen bei Graz",
    "lat": "47.01667",
    "lng": "15.45"
  },
  {
    "country": "AT",
    "name": "Feldkirchen an der Donau",
    "lat": "48.34524",
    "lng": "14.05134"
  },
  {
    "country": "AT",
    "name": "Feldkirch",
    "lat": "47.23306",
    "lng": "9.6"
  },
  {
    "country": "AT",
    "name": "Feldbach",
    "lat": "46.95306",
    "lng": "15.88833"
  },
  {
    "country": "AT",
    "name": "Feld am See",
    "lat": "46.77639",
    "lng": "13.74778"
  },
  {
    "country": "AT",
    "name": "Feistritz ob Bleiburg",
    "lat": "46.55",
    "lng": "14.76667"
  },
  {
    "country": "AT",
    "name": "Feistritz im Rosental",
    "lat": "46.51667",
    "lng": "14.16667"
  },
  {
    "country": "AT",
    "name": "Feistritz bei Knittelfeld",
    "lat": "47.26802",
    "lng": "14.89334"
  },
  {
    "country": "AT",
    "name": "Feistritz an der Gail",
    "lat": "46.5775",
    "lng": "13.60667"
  },
  {
    "country": "AT",
    "name": "Feistritz an der Drau",
    "lat": "46.70157",
    "lng": "13.66479"
  },
  {
    "country": "AT",
    "name": "Feistritz am Wechsel",
    "lat": "47.6",
    "lng": "16.05"
  },
  {
    "country": "AT",
    "name": "Fehring",
    "lat": "46.94",
    "lng": "16.00806"
  },
  {
    "country": "AT",
    "name": "Farrach",
    "lat": "47.18333",
    "lng": "14.73333"
  },
  {
    "country": "AT",
    "name": "Fallbach",
    "lat": "48.65",
    "lng": "16.41667"
  },
  {
    "country": "AT",
    "name": "Falkenstein",
    "lat": "48.71667",
    "lng": "16.58333"
  },
  {
    "country": "AT",
    "name": "St. Ruprecht-Falkendorf",
    "lat": "47.1011",
    "lng": "14.01752"
  },
  {
    "country": "AT",
    "name": "Falkenburg",
    "lat": "47.5",
    "lng": "14.08333"
  },
  {
    "country": "AT",
    "name": "Faistenau",
    "lat": "47.77767",
    "lng": "13.23393"
  },
  {
    "country": "AT",
    "name": "Faak am See",
    "lat": "46.56806",
    "lng": "13.90972"
  },
  {
    "country": "AT",
    "name": "Euratsfeld",
    "lat": "48.08181",
    "lng": "14.93154"
  },
  {
    "country": "AT",
    "name": "Eugendorf",
    "lat": "47.86765",
    "lng": "13.12609"
  },
  {
    "country": "AT",
    "name": "Eschenau",
    "lat": "48.04825",
    "lng": "15.56694"
  },
  {
    "country": "AT",
    "name": "Erpfendorf",
    "lat": "47.58333",
    "lng": "12.46667"
  },
  {
    "country": "AT",
    "name": "Erpersdorf",
    "lat": "48.3421",
    "lng": "15.91747"
  },
  {
    "country": "AT",
    "name": "Ernsthofen",
    "lat": "48.12915",
    "lng": "14.48058"
  },
  {
    "country": "AT",
    "name": "Ernstbrunn",
    "lat": "48.53333",
    "lng": "16.35"
  },
  {
    "country": "AT",
    "name": "Erlauf",
    "lat": "48.18333",
    "lng": "15.18333"
  },
  {
    "country": "AT",
    "name": "Bad Erlach",
    "lat": "47.72722",
    "lng": "16.21444"
  },
  {
    "country": "AT",
    "name": "Erl",
    "lat": "47.68333",
    "lng": "12.18333"
  },
  {
    "country": "AT",
    "name": "Enzersfeld",
    "lat": "48.36338",
    "lng": "16.42387"
  },
  {
    "country": "AT",
    "name": "Enzersdorf an der Fischa",
    "lat": "48.08502",
    "lng": "16.60832"
  },
  {
    "country": "AT",
    "name": "Enzenreith",
    "lat": "47.66839",
    "lng": "15.95249"
  },
  {
    "country": "AT",
    "name": "Ennsdorf",
    "lat": "48.21181",
    "lng": "14.5029"
  },
  {
    "country": "AT",
    "name": "Enns",
    "lat": "48.21346",
    "lng": "14.47612"
  },
  {
    "country": "AT",
    "name": "Engerwitzdorf",
    "lat": "48.34507",
    "lng": "14.44204"
  },
  {
    "country": "AT",
    "name": "Engelhartstetten",
    "lat": "48.1816",
    "lng": "16.88367"
  },
  {
    "country": "AT",
    "name": "Endach",
    "lat": "47.56796",
    "lng": "12.15603"
  },
  {
    "country": "AT",
    "name": "Empersdorf",
    "lat": "46.99892",
    "lng": "15.59959"
  },
  {
    "country": "AT",
    "name": "Emmersdorf an der Donau",
    "lat": "48.2414",
    "lng": "15.33721"
  },
  {
    "country": "AT",
    "name": "Eltendorf",
    "lat": "47.0087",
    "lng": "16.20239"
  },
  {
    "country": "AT",
    "name": "Elsbethen",
    "lat": "47.76464",
    "lng": "13.08104"
  },
  {
    "country": "AT",
    "name": "Elmen",
    "lat": "47.34039",
    "lng": "10.54318"
  },
  {
    "country": "AT",
    "name": "Ellmau",
    "lat": "47.51378",
    "lng": "12.29937"
  },
  {
    "country": "AT",
    "name": "Elixhausen",
    "lat": "47.86667",
    "lng": "13.06667"
  },
  {
    "country": "AT",
    "name": "Elbigenalp",
    "lat": "47.29041",
    "lng": "10.43607"
  },
  {
    "country": "AT",
    "name": "Eisgarn",
    "lat": "48.91675",
    "lng": "15.1032"
  },
  {
    "country": "AT",
    "name": "Eisenstadt",
    "lat": "47.84565",
    "lng": "16.52327"
  },
  {
    "country": "AT",
    "name": "Eisenerz",
    "lat": "47.53333",
    "lng": "14.88333"
  },
  {
    "country": "AT",
    "name": "Eisbach",
    "lat": "47.11667",
    "lng": "15.26667"
  },
  {
    "country": "AT",
    "name": "Eidenberg",
    "lat": "48.39439",
    "lng": "14.23313"
  },
  {
    "country": "AT",
    "name": "Eichgraben",
    "lat": "48.17204",
    "lng": "15.98391"
  },
  {
    "country": "AT",
    "name": "Eichfeld",
    "lat": "46.72528",
    "lng": "15.76806"
  },
  {
    "country": "AT",
    "name": "Eichenberg",
    "lat": "47.53333",
    "lng": "9.78333"
  },
  {
    "country": "AT",
    "name": "Eichberg",
    "lat": "47.38188",
    "lng": "15.97356"
  },
  {
    "country": "AT",
    "name": "Eibiswald",
    "lat": "46.68667",
    "lng": "15.24722"
  },
  {
    "country": "AT",
    "name": "Ehrenhausen",
    "lat": "46.72417",
    "lng": "15.58667"
  },
  {
    "country": "AT",
    "name": "Ehenbichl",
    "lat": "47.46667",
    "lng": "10.7"
  },
  {
    "country": "AT",
    "name": "Eggersdorf bei Graz",
    "lat": "47.12338",
    "lng": "15.60084"
  },
  {
    "country": "AT",
    "name": "Eggern",
    "lat": "48.90829",
    "lng": "15.14877"
  },
  {
    "country": "AT",
    "name": "Eggenburg",
    "lat": "48.63892",
    "lng": "15.81903"
  },
  {
    "country": "AT",
    "name": "Eggenberg",
    "lat": "47.07",
    "lng": "15.39871"
  },
  {
    "country": "AT",
    "name": "Egg",
    "lat": "47.43154",
    "lng": "9.89762"
  },
  {
    "country": "AT",
    "name": "Eferding",
    "lat": "48.30866",
    "lng": "14.02233"
  },
  {
    "country": "AT",
    "name": "Edt bei Lambach",
    "lat": "48.11667",
    "lng": "13.88333"
  },
  {
    "country": "AT",
    "name": "Edlitz",
    "lat": "47.59797",
    "lng": "16.14052"
  },
  {
    "country": "AT",
    "name": "Edelstal",
    "lat": "48.1",
    "lng": "16.98333"
  },
  {
    "country": "AT",
    "name": "Edelsgrub",
    "lat": "47.03333",
    "lng": "15.6"
  },
  {
    "country": "AT",
    "name": "Edelschrott",
    "lat": "47.02156",
    "lng": "15.05266"
  },
  {
    "country": "AT",
    "name": "Edelsbach bei Feldbach",
    "lat": "46.98944",
    "lng": "15.83694"
  },
  {
    "country": "AT",
    "name": "Eckartsau",
    "lat": "48.14507",
    "lng": "16.79737"
  },
  {
    "country": "AT",
    "name": "Echsenbach",
    "lat": "48.71667",
    "lng": "15.21667"
  },
  {
    "country": "AT",
    "name": "Ebreichsdorf",
    "lat": "47.95579",
    "lng": "16.40705"
  },
  {
    "country": "AT",
    "name": "Eberstein",
    "lat": "46.80806",
    "lng": "14.56"
  },
  {
    "country": "AT",
    "name": "Eberstalzell",
    "lat": "48.04392",
    "lng": "13.98319"
  },
  {
    "country": "AT",
    "name": "Ebersdorf",
    "lat": "47.19852",
    "lng": "15.96219"
  },
  {
    "country": "AT",
    "name": "Eberschwang",
    "lat": "48.15504",
    "lng": "13.56194"
  },
  {
    "country": "AT",
    "name": "Eberndorf",
    "lat": "46.59139",
    "lng": "14.64361"
  },
  {
    "country": "AT",
    "name": "Ebergassing",
    "lat": "48.04567",
    "lng": "16.51709"
  },
  {
    "country": "AT",
    "name": "Eberau",
    "lat": "47.10764",
    "lng": "16.46044"
  },
  {
    "country": "AT",
    "name": "Ebenthal",
    "lat": "48.43333",
    "lng": "16.78333"
  },
  {
    "country": "AT",
    "name": "Ebenthal",
    "lat": "46.60806",
    "lng": "14.36417"
  },
  {
    "country": "AT",
    "name": "Ebensee",
    "lat": "47.80716",
    "lng": "13.779"
  },
  {
    "country": "AT",
    "name": "Eben im Pongau",
    "lat": "47.4",
    "lng": "13.4"
  },
  {
    "country": "AT",
    "name": "Ebenfurth",
    "lat": "47.87738",
    "lng": "16.36731"
  },
  {
    "country": "AT",
    "name": "Ebenau",
    "lat": "47.79073",
    "lng": "13.17527"
  },
  {
    "country": "AT",
    "name": "Eben am Achensee",
    "lat": "47.4138",
    "lng": "11.76138"
  },
  {
    "country": "AT",
    "name": "Ebbs",
    "lat": "47.63333",
    "lng": "12.21667"
  },
  {
    "country": "AT",
    "name": "Dürnstein in der Steiermark",
    "lat": "46.98833",
    "lng": "14.39167"
  },
  {
    "country": "AT",
    "name": "Dürnstein",
    "lat": "48.39582",
    "lng": "15.51973"
  },
  {
    "country": "AT",
    "name": "Dürnkrut",
    "lat": "48.47315",
    "lng": "16.85062"
  },
  {
    "country": "AT",
    "name": "Düns",
    "lat": "47.22353",
    "lng": "9.71663"
  },
  {
    "country": "AT",
    "name": "Droß",
    "lat": "48.46393",
    "lng": "15.57561"
  },
  {
    "country": "AT",
    "name": "Drösing",
    "lat": "48.539",
    "lng": "16.90264"
  },
  {
    "country": "AT",
    "name": "Drassburg",
    "lat": "47.74645",
    "lng": "16.48679"
  },
  {
    "country": "AT",
    "name": "Drasenhofen",
    "lat": "48.75",
    "lng": "16.65"
  },
  {
    "country": "AT",
    "name": "Dornbirn",
    "lat": "47.41427",
    "lng": "9.74195"
  },
  {
    "country": "AT",
    "name": "Dorfstetten",
    "lat": "48.32573",
    "lng": "14.98218"
  },
  {
    "country": "AT",
    "name": "Dorfgastein",
    "lat": "47.24172",
    "lng": "13.10223"
  },
  {
    "country": "AT",
    "name": "Dorfbeuern",
    "lat": "48.01667",
    "lng": "13.01667"
  },
  {
    "country": "AT",
    "name": "Doren",
    "lat": "47.49278",
    "lng": "9.87972"
  },
  {
    "country": "AT",
    "name": "Doppl",
    "lat": "48.24811",
    "lng": "14.25416"
  },
  {
    "country": "AT",
    "name": "Donnerskirchen",
    "lat": "47.89425",
    "lng": "16.64635"
  },
  {
    "country": "AT",
    "name": "Donnersbach",
    "lat": "47.46139",
    "lng": "14.12972"
  },
  {
    "country": "AT",
    "name": "Donawitz",
    "lat": "47.36667",
    "lng": "15.06667"
  },
  {
    "country": "AT",
    "name": "Dölsach",
    "lat": "46.82833",
    "lng": "12.84528"
  },
  {
    "country": "AT",
    "name": "Döbriach",
    "lat": "46.78049",
    "lng": "13.65738"
  },
  {
    "country": "AT",
    "name": "Dobersberg",
    "lat": "48.9151",
    "lng": "15.32188"
  },
  {
    "country": "AT",
    "name": "Diex",
    "lat": "46.75",
    "lng": "14.6"
  },
  {
    "country": "AT",
    "name": "Dietersdorf am Gnasbach",
    "lat": "46.80917",
    "lng": "15.81167"
  },
  {
    "country": "AT",
    "name": "Dietersdorf",
    "lat": "47.2",
    "lng": "14.66667"
  },
  {
    "country": "AT",
    "name": "Dietachdorf",
    "lat": "48.08364",
    "lng": "14.42874"
  },
  {
    "country": "AT",
    "name": "Dietach",
    "lat": "48.09018",
    "lng": "14.41647"
  },
  {
    "country": "AT",
    "name": "Dienten am Hochkönig",
    "lat": "47.38324",
    "lng": "13.00369"
  },
  {
    "country": "AT",
    "name": "Dienersdorf",
    "lat": "47.23979",
    "lng": "15.90142"
  },
  {
    "country": "AT",
    "name": "Diemlach",
    "lat": "47.4361",
    "lng": "15.2746"
  },
  {
    "country": "AT",
    "name": "Deutsch-Wagram",
    "lat": "48.29972",
    "lng": "16.56667"
  },
  {
    "country": "AT",
    "name": "Deutschlandsberg",
    "lat": "46.81528",
    "lng": "15.22222"
  },
  {
    "country": "AT",
    "name": "Deutschkreutz",
    "lat": "47.6",
    "lng": "16.63333"
  },
  {
    "country": "AT",
    "name": "Deutsch Kaltenbrunn",
    "lat": "47.09455",
    "lng": "16.13145"
  },
  {
    "country": "AT",
    "name": "Deutsch Jahrndorf",
    "lat": "48.01667",
    "lng": "17.1"
  },
  {
    "country": "AT",
    "name": "Deutsch Griffen",
    "lat": "46.85606",
    "lng": "14.07501"
  },
  {
    "country": "AT",
    "name": "Deutsch Goritz",
    "lat": "46.75083",
    "lng": "15.82944"
  },
  {
    "country": "AT",
    "name": "Deutschfeistritz",
    "lat": "47.19852",
    "lng": "15.33623"
  },
  {
    "country": "AT",
    "name": "Deuchendorf",
    "lat": "47.46593",
    "lng": "15.32172"
  },
  {
    "country": "AT",
    "name": "Desselbrunn",
    "lat": "48.02145",
    "lng": "13.77027"
  },
  {
    "country": "AT",
    "name": "Dellach im Drautal",
    "lat": "46.7375",
    "lng": "13.07833"
  },
  {
    "country": "AT",
    "name": "Dellach",
    "lat": "46.66175",
    "lng": "13.07965"
  },
  {
    "country": "AT",
    "name": "Dechantskirchen",
    "lat": "47.41667",
    "lng": "16.01667"
  },
  {
    "country": "AT",
    "name": "Debant",
    "lat": "46.83333",
    "lng": "12.81667"
  },
  {
    "country": "AT",
    "name": "Dalaas",
    "lat": "47.12446",
    "lng": "9.99104"
  },
  {
    "country": "AT",
    "name": "Bürs",
    "lat": "47.14972",
    "lng": "9.8"
  },
  {
    "country": "AT",
    "name": "Bürmoos",
    "lat": "47.98343",
    "lng": "12.91786"
  },
  {
    "country": "AT",
    "name": "Burgfried",
    "lat": "48.5199",
    "lng": "14.2957"
  },
  {
    "country": "AT",
    "name": "Burgfried",
    "lat": "47.68004",
    "lng": "13.11175"
  },
  {
    "country": "AT",
    "name": "Burgau",
    "lat": "47.14268",
    "lng": "16.09643"
  },
  {
    "country": "AT",
    "name": "Buchkirchen",
    "lat": "48.22427",
    "lng": "14.02242"
  },
  {
    "country": "AT",
    "name": "Buch bei Jenbach",
    "lat": "47.37447",
    "lng": "11.754"
  },
  {
    "country": "AT",
    "name": "Buchbach",
    "lat": "47.69648",
    "lng": "15.98425"
  },
  {
    "country": "AT",
    "name": "Brunn an der Wild",
    "lat": "48.69425",
    "lng": "15.52008"
  },
  {
    "country": "AT",
    "name": "Brunn an der Schneebergbahn",
    "lat": "47.82376",
    "lng": "16.15934"
  },
  {
    "country": "AT",
    "name": "Brunn am Gebirge",
    "lat": "48.10697",
    "lng": "16.28466"
  },
  {
    "country": "AT",
    "name": "Brunn",
    "lat": "46.72944",
    "lng": "15.3"
  },
  {
    "country": "AT",
    "name": "Bruckneudorf",
    "lat": "48.01667",
    "lng": "16.78333"
  },
  {
    "country": "AT",
    "name": "Brückl",
    "lat": "46.75167",
    "lng": "14.53667"
  },
  {
    "country": "AT",
    "name": "Bruck an der Mur",
    "lat": "47.41667",
    "lng": "15.28333"
  },
  {
    "country": "AT",
    "name": "Bruck an der Leitha",
    "lat": "48.01667",
    "lng": "16.76667"
  },
  {
    "country": "AT",
    "name": "Bruck an der Großglocknerstraße",
    "lat": "47.28494",
    "lng": "12.8231"
  },
  {
    "country": "AT",
    "name": "Bruck am Ziller",
    "lat": "47.38998",
    "lng": "11.85124"
  },
  {
    "country": "AT",
    "name": "Bromberg",
    "lat": "47.66539",
    "lng": "16.2099"
  },
  {
    "country": "AT",
    "name": "Brixlegg",
    "lat": "47.42942",
    "lng": "11.87794"
  },
  {
    "country": "AT",
    "name": "Brixen im Thale",
    "lat": "47.45",
    "lng": "12.25"
  },
  {
    "country": "AT",
    "name": "Bretstein",
    "lat": "47.33333",
    "lng": "14.41667"
  },
  {
    "country": "AT",
    "name": "Breitenwang",
    "lat": "47.48713",
    "lng": "10.7342"
  },
  {
    "country": "AT",
    "name": "Breitenfurt bei Wien",
    "lat": "48.13333",
    "lng": "16.15"
  },
  {
    "country": "AT",
    "name": "Breitenfeld an der Rittschein",
    "lat": "47.03333",
    "lng": "15.95"
  },
  {
    "country": "AT",
    "name": "Breitenfeld am Tannenriegel",
    "lat": "46.85",
    "lng": "15.63333"
  },
  {
    "country": "AT",
    "name": "Breitenbrunn",
    "lat": "47.94452",
    "lng": "16.73149"
  },
  {
    "country": "AT",
    "name": "Breitenbach am Inn",
    "lat": "47.47829",
    "lng": "11.97372"
  },
  {
    "country": "AT",
    "name": "Breitenau",
    "lat": "47.73355",
    "lng": "16.14338"
  },
  {
    "country": "AT",
    "name": "Bregenz",
    "lat": "47.50311",
    "lng": "9.7471"
  },
  {
    "country": "AT",
    "name": "Braunau am Inn",
    "lat": "48.25628",
    "lng": "13.04343"
  },
  {
    "country": "AT",
    "name": "Brandenberg",
    "lat": "47.49053",
    "lng": "11.89459"
  },
  {
    "country": "AT",
    "name": "Bramberg am Wildkogel",
    "lat": "47.26979",
    "lng": "12.3385"
  },
  {
    "country": "AT",
    "name": "Böheimkirchen",
    "lat": "48.19779",
    "lng": "15.76178"
  },
  {
    "country": "AT",
    "name": "Bodensdorf",
    "lat": "46.69111",
    "lng": "13.97111"
  },
  {
    "country": "AT",
    "name": "Bocksdorf",
    "lat": "47.14256",
    "lng": "16.17784"
  },
  {
    "country": "AT",
    "name": "Bockfließ",
    "lat": "48.36",
    "lng": "16.60389"
  },
  {
    "country": "AT",
    "name": "Bad Blumau",
    "lat": "47.11667",
    "lng": "16.05"
  },
  {
    "country": "AT",
    "name": "Bludesch",
    "lat": "47.2",
    "lng": "9.73306"
  },
  {
    "country": "AT",
    "name": "Bludenz",
    "lat": "47.15476",
    "lng": "9.82255"
  },
  {
    "country": "AT",
    "name": "Blons",
    "lat": "47.22327",
    "lng": "9.83414"
  },
  {
    "country": "AT",
    "name": "Blindenmarkt",
    "lat": "48.12749",
    "lng": "14.98647"
  },
  {
    "country": "AT",
    "name": "Bleiburg/Pliberk",
    "lat": "46.59",
    "lng": "14.79889"
  },
  {
    "country": "AT",
    "name": "Blaindorf",
    "lat": "47.17498",
    "lng": "15.86795"
  },
  {
    "country": "AT",
    "name": "Bizau",
    "lat": "47.36906",
    "lng": "9.92839"
  },
  {
    "country": "AT",
    "name": "Bischofstetten",
    "lat": "48.12222",
    "lng": "15.46909"
  },
  {
    "country": "AT",
    "name": "Bischofshofen",
    "lat": "47.41667",
    "lng": "13.21667"
  },
  {
    "country": "AT",
    "name": "Bisamberg",
    "lat": "48.33333",
    "lng": "16.35"
  },
  {
    "country": "AT",
    "name": "Birkfeld",
    "lat": "47.35",
    "lng": "15.68333"
  },
  {
    "country": "AT",
    "name": "Birgitz",
    "lat": "47.23536",
    "lng": "11.29922"
  },
  {
    "country": "AT",
    "name": "Bildstein",
    "lat": "47.45",
    "lng": "9.76667"
  },
  {
    "country": "AT",
    "name": "Bierbaum am Auersbach",
    "lat": "46.82949",
    "lng": "15.79237"
  },
  {
    "country": "AT",
    "name": "Biedermannsdorf",
    "lat": "48.08393",
    "lng": "16.34542"
  },
  {
    "country": "AT",
    "name": "Bichlbach",
    "lat": "47.42033",
    "lng": "10.79042"
  },
  {
    "country": "AT",
    "name": "Biberwier",
    "lat": "47.38333",
    "lng": "10.9"
  },
  {
    "country": "AT",
    "name": "Biberbach",
    "lat": "48.03006",
    "lng": "14.70795"
  },
  {
    "country": "AT",
    "name": "Bezau",
    "lat": "47.38478",
    "lng": "9.90139"
  },
  {
    "country": "AT",
    "name": "Berwang",
    "lat": "47.40807",
    "lng": "10.74735"
  },
  {
    "country": "AT",
    "name": "Bernstein",
    "lat": "47.4",
    "lng": "16.25"
  },
  {
    "country": "AT",
    "name": "Bernhardsthal",
    "lat": "48.69158",
    "lng": "16.86951"
  },
  {
    "country": "AT",
    "name": "Berndorf bei Salzburg",
    "lat": "47.99532",
    "lng": "13.06146"
  },
  {
    "country": "AT",
    "name": "Berndorf",
    "lat": "47.94567",
    "lng": "16.10973"
  },
  {
    "country": "AT",
    "name": "Berndorf",
    "lat": "47.41667",
    "lng": "15.26667"
  },
  {
    "country": "AT",
    "name": "Bergheim",
    "lat": "47.83333",
    "lng": "13.03333"
  },
  {
    "country": "AT",
    "name": "Bergham",
    "lat": "48.28182",
    "lng": "14.23141"
  },
  {
    "country": "AT",
    "name": "Berg",
    "lat": "48.10147",
    "lng": "17.03842"
  },
  {
    "country": "AT",
    "name": "Behamberg",
    "lat": "48.01667",
    "lng": "14.48333"
  },
  {
    "country": "AT",
    "name": "Baumkirchen",
    "lat": "47.3",
    "lng": "11.56667"
  },
  {
    "country": "AT",
    "name": "Baumgarten bei Gnas",
    "lat": "46.91667",
    "lng": "15.76667"
  },
  {
    "country": "AT",
    "name": "Batschuns",
    "lat": "47.28306",
    "lng": "9.65"
  },
  {
    "country": "AT",
    "name": "Barwies",
    "lat": "47.3",
    "lng": "10.96667"
  },
  {
    "country": "AT",
    "name": "Bartholomäberg",
    "lat": "47.08333",
    "lng": "9.9"
  },
  {
    "country": "AT",
    "name": "Bärnkopf",
    "lat": "48.39046",
    "lng": "15.00479"
  },
  {
    "country": "AT",
    "name": "Baldramsdorf",
    "lat": "46.80111",
    "lng": "13.45333"
  },
  {
    "country": "AT",
    "name": "Bairisch Kölldorf",
    "lat": "46.86667",
    "lng": "15.93333"
  },
  {
    "country": "AT",
    "name": "Wimsbach",
    "lat": "48.06667",
    "lng": "13.9"
  },
  {
    "country": "AT",
    "name": "Bad Vöslau",
    "lat": "47.96533",
    "lng": "16.21359"
  },
  {
    "country": "AT",
    "name": "Bad Tatzmannsdorf",
    "lat": "47.33126",
    "lng": "16.23067"
  },
  {
    "country": "AT",
    "name": "Bad Schönau",
    "lat": "47.49473",
    "lng": "16.2341"
  },
  {
    "country": "AT",
    "name": "Bad Schallerbach",
    "lat": "48.22999",
    "lng": "13.91925"
  },
  {
    "country": "AT",
    "name": "Bad Sankt Leonhard im Lavanttal",
    "lat": "46.96278",
    "lng": "14.79167"
  },
  {
    "country": "AT",
    "name": "Bad Ischl",
    "lat": "47.71109",
    "lng": "13.61893"
  },
  {
    "country": "AT",
    "name": "Bad Hofgastein",
    "lat": "47.17274",
    "lng": "13.09871"
  },
  {
    "country": "AT",
    "name": "Bad Hall",
    "lat": "48.03832",
    "lng": "14.20773"
  },
  {
    "country": "AT",
    "name": "Bad Goisern",
    "lat": "47.64252",
    "lng": "13.61609"
  },
  {
    "country": "AT",
    "name": "Bad Gleichenberg",
    "lat": "46.87556",
    "lng": "15.90861"
  },
  {
    "country": "AT",
    "name": "Bad Gastein",
    "lat": "47.11547",
    "lng": "13.13467"
  },
  {
    "country": "AT",
    "name": "Bad Fischau",
    "lat": "47.83137",
    "lng": "16.16707"
  },
  {
    "country": "AT",
    "name": "Badersdorf",
    "lat": "47.2",
    "lng": "16.36667"
  },
  {
    "country": "AT",
    "name": "Baden",
    "lat": "48.00543",
    "lng": "16.23264"
  },
  {
    "country": "AT",
    "name": "Bad Deutsch-Altenburg",
    "lat": "48.13425",
    "lng": "16.90624"
  },
  {
    "country": "AT",
    "name": "Bad Aussee",
    "lat": "47.60998",
    "lng": "13.78243"
  },
  {
    "country": "AT",
    "name": "Bachmanning",
    "lat": "48.13104",
    "lng": "13.79436"
  },
  {
    "country": "AT",
    "name": "Axams",
    "lat": "47.23111",
    "lng": "11.27892"
  },
  {
    "country": "AT",
    "name": "Außervillgraten",
    "lat": "46.7875",
    "lng": "12.43139"
  },
  {
    "country": "AT",
    "name": "Ausserbraz",
    "lat": "47.14875",
    "lng": "9.90066"
  },
  {
    "country": "AT",
    "name": "Aurolzmünster",
    "lat": "48.24834",
    "lng": "13.45533"
  },
  {
    "country": "AT",
    "name": "Aurach am Hongar",
    "lat": "47.95182",
    "lng": "13.67291"
  },
  {
    "country": "AT",
    "name": "Auersthal",
    "lat": "48.37373",
    "lng": "16.63596"
  },
  {
    "country": "AT",
    "name": "Auersbach",
    "lat": "47.01667",
    "lng": "15.86667"
  },
  {
    "country": "AT",
    "name": "Audorf",
    "lat": "48.2181",
    "lng": "14.27931"
  },
  {
    "country": "AT",
    "name": "Au an der Traun",
    "lat": "48.1802",
    "lng": "14.11248"
  },
  {
    "country": "AT",
    "name": "Au am Leithaberge",
    "lat": "47.92296",
    "lng": "16.55794"
  },
  {
    "country": "AT",
    "name": "Au",
    "lat": "47.7",
    "lng": "13.06667"
  },
  {
    "country": "AT",
    "name": "Au",
    "lat": "47.32176",
    "lng": "9.98067"
  },
  {
    "country": "AT",
    "name": "Atzesberg",
    "lat": "48.53959",
    "lng": "13.86936"
  },
  {
    "country": "AT",
    "name": "Atzenbrugg",
    "lat": "48.29119",
    "lng": "15.90614"
  },
  {
    "country": "AT",
    "name": "Atzbach",
    "lat": "48.08364",
    "lng": "13.70347"
  },
  {
    "country": "AT",
    "name": "Attnang",
    "lat": "48.01667",
    "lng": "13.71667"
  },
  {
    "country": "AT",
    "name": "Attersee",
    "lat": "47.91646",
    "lng": "13.53953"
  },
  {
    "country": "AT",
    "name": "Attendorf",
    "lat": "47.00426",
    "lng": "15.33897"
  },
  {
    "country": "AT",
    "name": "Asten",
    "lat": "48.21941",
    "lng": "14.41784"
  },
  {
    "country": "AT",
    "name": "Asperhofen",
    "lat": "48.24583",
    "lng": "15.92606"
  },
  {
    "country": "AT",
    "name": "Asparn an der Zaya",
    "lat": "48.58333",
    "lng": "16.5"
  },
  {
    "country": "AT",
    "name": "Aspang Markt",
    "lat": "47.55",
    "lng": "16.08333"
  },
  {
    "country": "AT",
    "name": "Aschbach Markt",
    "lat": "48.07234",
    "lng": "14.75395"
  },
  {
    "country": "AT",
    "name": "Aschau",
    "lat": "47.26667",
    "lng": "11.9"
  },
  {
    "country": "AT",
    "name": "Aschach an der Steyr",
    "lat": "48.01312",
    "lng": "14.33544"
  },
  {
    "country": "AT",
    "name": "Aschach an der Donau",
    "lat": "48.36458",
    "lng": "14.02044"
  },
  {
    "country": "AT",
    "name": "Arzl im Pitztal",
    "lat": "47.20712",
    "lng": "10.76261"
  },
  {
    "country": "AT",
    "name": "Arzl",
    "lat": "47.28333",
    "lng": "11.43333"
  },
  {
    "country": "AT",
    "name": "Arzberg",
    "lat": "47.25",
    "lng": "15.51667"
  },
  {
    "country": "AT",
    "name": "Arriach",
    "lat": "46.72921",
    "lng": "13.85046"
  },
  {
    "country": "AT",
    "name": "Arnreit",
    "lat": "48.52513",
    "lng": "13.99487"
  },
  {
    "country": "AT",
    "name": "Arnoldstein",
    "lat": "46.54611",
    "lng": "13.71"
  },
  {
    "country": "AT",
    "name": "Arnfels",
    "lat": "46.67639",
    "lng": "15.40306"
  },
  {
    "country": "AT",
    "name": "Ardning",
    "lat": "47.5912",
    "lng": "14.36372"
  },
  {
    "country": "AT",
    "name": "Ardagger Stift",
    "lat": "48.15",
    "lng": "14.83333"
  },
  {
    "country": "AT",
    "name": "Arbesbach",
    "lat": "48.49337",
    "lng": "14.95308"
  },
  {
    "country": "AT",
    "name": "Apfelberg",
    "lat": "47.2",
    "lng": "14.83333"
  },
  {
    "country": "AT",
    "name": "Apetlon",
    "lat": "47.74394",
    "lng": "16.8302"
  },
  {
    "country": "AT",
    "name": "Anthering",
    "lat": "47.88333",
    "lng": "13.01667"
  },
  {
    "country": "AT",
    "name": "Antau",
    "lat": "47.77377",
    "lng": "16.47984"
  },
  {
    "country": "AT",
    "name": "Ansfelden",
    "lat": "48.20969",
    "lng": "14.29004"
  },
  {
    "country": "AT",
    "name": "Anras",
    "lat": "46.77389",
    "lng": "12.56083"
  },
  {
    "country": "AT",
    "name": "Annabichl",
    "lat": "46.65",
    "lng": "14.31667"
  },
  {
    "country": "AT",
    "name": "Annaberg",
    "lat": "47.87134",
    "lng": "15.37648"
  },
  {
    "country": "AT",
    "name": "Anif",
    "lat": "47.75",
    "lng": "13.06667"
  },
  {
    "country": "AT",
    "name": "Angern an der March",
    "lat": "48.37778",
    "lng": "16.82806"
  },
  {
    "country": "AT",
    "name": "Anger",
    "lat": "47.27422",
    "lng": "15.69139"
  },
  {
    "country": "AT",
    "name": "Angath",
    "lat": "47.50758",
    "lng": "12.06513"
  },
  {
    "country": "AT",
    "name": "Andorf",
    "lat": "48.3713",
    "lng": "13.57412"
  },
  {
    "country": "AT",
    "name": "Andlersdorf",
    "lat": "48.18333",
    "lng": "16.66667"
  },
  {
    "country": "AT",
    "name": "Andelsbuch",
    "lat": "47.41167",
    "lng": "9.89326"
  },
  {
    "country": "AT",
    "name": "Andau",
    "lat": "47.77441",
    "lng": "17.03293"
  },
  {
    "country": "AT",
    "name": "Amstetten",
    "lat": "48.1229",
    "lng": "14.87206"
  },
  {
    "country": "AT",
    "name": "Amras",
    "lat": "47.25",
    "lng": "11.41667"
  },
  {
    "country": "AT",
    "name": "Ampflwang",
    "lat": "48.08333",
    "lng": "13.56667"
  },
  {
    "country": "AT",
    "name": "Ampass",
    "lat": "47.26251",
    "lng": "11.46226"
  },
  {
    "country": "AT",
    "name": "Amlach",
    "lat": "46.81639",
    "lng": "12.76361"
  },
  {
    "country": "AT",
    "name": "Altmünster",
    "lat": "47.90219",
    "lng": "13.76415"
  },
  {
    "country": "AT",
    "name": "Altmelon",
    "lat": "48.46222",
    "lng": "14.96552"
  },
  {
    "country": "AT",
    "name": "Altlichtenwarth",
    "lat": "48.64442",
    "lng": "16.79664"
  },
  {
    "country": "AT",
    "name": "Altlichtenberg",
    "lat": "48.36001",
    "lng": "14.25845"
  },
  {
    "country": "AT",
    "name": "Altlengbach",
    "lat": "48.15355",
    "lng": "15.92606"
  },
  {
    "country": "AT",
    "name": "Althofen",
    "lat": "46.87298",
    "lng": "14.47449"
  },
  {
    "country": "AT",
    "name": "Altheim",
    "lat": "48.25154",
    "lng": "13.23406"
  },
  {
    "country": "AT",
    "name": "Altenmarkt im Pongau",
    "lat": "47.38333",
    "lng": "13.41667"
  },
  {
    "country": "AT",
    "name": "Altenmarkt bei Sankt Gallen",
    "lat": "47.72327",
    "lng": "14.64838"
  },
  {
    "country": "AT",
    "name": "Altenmarkt bei Fürstenfeld",
    "lat": "47.06638",
    "lng": "16.04785"
  },
  {
    "country": "AT",
    "name": "Altenmarkt an der Triesting",
    "lat": "48.01553",
    "lng": "15.99661"
  },
  {
    "country": "AT",
    "name": "Altenfelden",
    "lat": "48.48555",
    "lng": "13.9698"
  },
  {
    "country": "AT",
    "name": "Altendorf",
    "lat": "47.65",
    "lng": "16.01667"
  },
  {
    "country": "AT",
    "name": "Altenburg",
    "lat": "48.64765",
    "lng": "15.59295"
  },
  {
    "country": "AT",
    "name": "Altenberg bei Linz",
    "lat": "48.37284",
    "lng": "14.35029"
  },
  {
    "country": "AT",
    "name": "Altaussee",
    "lat": "47.63844",
    "lng": "13.76278"
  },
  {
    "country": "AT",
    "name": "Altach",
    "lat": "47.35",
    "lng": "9.65"
  },
  {
    "country": "AT",
    "name": "Allhartsberg",
    "lat": "48.02633",
    "lng": "14.79009"
  },
  {
    "country": "AT",
    "name": "Allhaming",
    "lat": "48.15246",
    "lng": "14.17022"
  },
  {
    "country": "AT",
    "name": "Allerheiligen im Mürztal",
    "lat": "47.46667",
    "lng": "15.4"
  },
  {
    "country": "AT",
    "name": "Allerheiligen im Mühlkreis",
    "lat": "48.30215",
    "lng": "14.65061"
  },
  {
    "country": "AT",
    "name": "Allerheiligen bei Wildon",
    "lat": "46.91417",
    "lng": "15.55444"
  },
  {
    "country": "AT",
    "name": "Allentsteig",
    "lat": "48.69725",
    "lng": "15.32756"
  },
  {
    "country": "AT",
    "name": "Alland",
    "lat": "48.05829",
    "lng": "16.07901"
  },
  {
    "country": "AT",
    "name": "Alkoven",
    "lat": "48.28753",
    "lng": "14.10748"
  },
  {
    "country": "AT",
    "name": "Aldrans",
    "lat": "47.25",
    "lng": "11.45"
  },
  {
    "country": "AT",
    "name": "Albersdorf",
    "lat": "47.12166",
    "lng": "15.69826"
  },
  {
    "country": "AT",
    "name": "Alberndorf in der Riedmark",
    "lat": "48.40607",
    "lng": "14.41441"
  },
  {
    "country": "AT",
    "name": "Aistersheim",
    "lat": "48.1868",
    "lng": "13.74175"
  },
  {
    "country": "AT",
    "name": "Ainet",
    "lat": "46.86603",
    "lng": "12.68968"
  },
  {
    "country": "AT",
    "name": "Aigen im Mühlkreis",
    "lat": "48.64578",
    "lng": "13.97109"
  },
  {
    "country": "AT",
    "name": "Aigen im Ennstal",
    "lat": "47.51667",
    "lng": "14.13333"
  },
  {
    "country": "AT",
    "name": "Bad Kleinkirchheim",
    "lat": "46.81556",
    "lng": "13.78056"
  },
  {
    "country": "AT",
    "name": "Aichkirchen",
    "lat": "48.10944",
    "lng": "13.79158"
  },
  {
    "country": "AT",
    "name": "Aich",
    "lat": "47.4228",
    "lng": "13.82145"
  },
  {
    "country": "AT",
    "name": "Aibl",
    "lat": "46.68145",
    "lng": "15.22619"
  },
  {
    "country": "AT",
    "name": "Ahorn",
    "lat": "48.52382",
    "lng": "14.17408"
  },
  {
    "country": "AT",
    "name": "Aggsbach",
    "lat": "48.29404",
    "lng": "15.40382"
  },
  {
    "country": "AT",
    "name": "Aflenz Kurort",
    "lat": "47.54211",
    "lng": "15.23898"
  },
  {
    "country": "AT",
    "name": "Adnet",
    "lat": "47.69746",
    "lng": "13.13115"
  },
  {
    "country": "AT",
    "name": "Admont",
    "lat": "47.57537",
    "lng": "14.46075"
  },
  {
    "country": "AT",
    "name": "Adlwang",
    "lat": "47.99245",
    "lng": "14.21742"
  },
  {
    "country": "AT",
    "name": "Aderklaa",
    "lat": "48.28333",
    "lng": "16.53333"
  },
  {
    "country": "AT",
    "name": "Achenkirch",
    "lat": "47.52659",
    "lng": "11.70559"
  },
  {
    "country": "AT",
    "name": "Achau",
    "lat": "48.08026",
    "lng": "16.38611"
  },
  {
    "country": "AT",
    "name": "Abwinden",
    "lat": "48.25903",
    "lng": "14.42625"
  },
  {
    "country": "AT",
    "name": "Abtissendorf",
    "lat": "46.99583",
    "lng": "15.45639"
  },
  {
    "country": "AT",
    "name": "Abtenau",
    "lat": "47.56373",
    "lng": "13.34599"
  },
  {
    "country": "AT",
    "name": "Absam",
    "lat": "47.29572",
    "lng": "11.50593"
  },
  {
    "country": "AT",
    "name": "Abfaltersbach",
    "lat": "46.75715",
    "lng": "12.52828"
  },
  {
    "country": "AT",
    "name": "Schlaiten",
    "lat": "46.87944",
    "lng": "12.65417"
  },
  {
    "country": "AT",
    "name": "Thurn",
    "lat": "46.85056",
    "lng": "12.76861"
  },
  {
    "country": "AT",
    "name": "Untertilliach",
    "lat": "46.70417",
    "lng": "12.70861"
  },
  {
    "country": "AT",
    "name": "Finkenstein am Faaker See",
    "lat": "46.57904",
    "lng": "13.93496"
  },
  {
    "country": "AT",
    "name": "Sankt Jakob in Defereggen",
    "lat": "46.91972",
    "lng": "12.33139"
  },
  {
    "country": "AT",
    "name": "Attnang-Puchheim",
    "lat": "48.00833",
    "lng": "13.71667"
  },
  {
    "country": "AT",
    "name": "Obernberg am Brenner",
    "lat": "47.01667",
    "lng": "11.41667"
  },
  {
    "country": "AT",
    "name": "Mühlbachl",
    "lat": "47.13333",
    "lng": "11.45"
  },
  {
    "country": "AT",
    "name": "Ötztal-Bahnhof",
    "lat": "47.23333",
    "lng": "10.85"
  },
  {
    "country": "AT",
    "name": "Leutasch",
    "lat": "47.3689",
    "lng": "11.14404"
  },
  {
    "country": "AT",
    "name": "Maurach",
    "lat": "47.42124",
    "lng": "11.75305"
  },
  {
    "country": "AT",
    "name": "Gschnitz",
    "lat": "47.04469",
    "lng": "11.35089"
  },
  {
    "country": "AT",
    "name": "Navis",
    "lat": "47.11667",
    "lng": "11.53333"
  },
  {
    "country": "AT",
    "name": "Ellbögen",
    "lat": "47.16667",
    "lng": "11.45"
  },
  {
    "country": "AT",
    "name": "Sellrain",
    "lat": "47.21667",
    "lng": "11.21667"
  },
  {
    "country": "AT",
    "name": "Oberperfuss",
    "lat": "47.24451",
    "lng": "11.24755"
  },
  {
    "country": "AT",
    "name": "Igls",
    "lat": "47.23127",
    "lng": "11.41018"
  },
  {
    "country": "AT",
    "name": "Obsteig",
    "lat": "47.3",
    "lng": "10.93333"
  },
  {
    "country": "AT",
    "name": "Kolsass",
    "lat": "47.3",
    "lng": "11.63333"
  },
  {
    "country": "AT",
    "name": "Gnadenwald",
    "lat": "47.31667",
    "lng": "11.56667"
  },
  {
    "country": "AT",
    "name": "Ehrwald",
    "lat": "47.4",
    "lng": "10.91667"
  },
  {
    "country": "AT",
    "name": "Neue Heimat",
    "lat": "48.24565",
    "lng": "13.04172"
  },
  {
    "country": "AT",
    "name": "Gaumberg",
    "lat": "48.28085",
    "lng": "14.26935"
  },
  {
    "country": "AT",
    "name": "Berg",
    "lat": "48.29278",
    "lng": "14.24778"
  },
  {
    "country": "AT",
    "name": "Lanzendorf",
    "lat": "48.11056",
    "lng": "16.445"
  },
  {
    "country": "AT",
    "name": "Walserfeld",
    "lat": "47.79222",
    "lng": "12.98"
  },
  {
    "country": "AT",
    "name": "Lehen",
    "lat": "47.87083",
    "lng": "13.01722"
  },
  {
    "country": "AT",
    "name": "Ansfelden",
    "lat": "47.965",
    "lng": "13.04944"
  },
  {
    "country": "AT",
    "name": "Heinfels",
    "lat": "46.75",
    "lng": "12.45"
  },
  {
    "country": "AT",
    "name": "Kals am Großglockner",
    "lat": "47.00227",
    "lng": "12.64552"
  },
  {
    "country": "AT",
    "name": "Gerlosberg",
    "lat": "47.21667",
    "lng": "11.93333"
  },
  {
    "country": "AT",
    "name": "Gerlos",
    "lat": "47.22464",
    "lng": "12.03012"
  },
  {
    "country": "AT",
    "name": "Krimml",
    "lat": "47.21799",
    "lng": "12.17487"
  },
  {
    "country": "AT",
    "name": "Rohrberg",
    "lat": "47.23333",
    "lng": "11.91667"
  },
  {
    "country": "AT",
    "name": "Ried im Zillertal",
    "lat": "47.3",
    "lng": "11.86667"
  },
  {
    "country": "AT",
    "name": "Hinterglemm",
    "lat": "47.37685",
    "lng": "12.59583"
  },
  {
    "country": "AT",
    "name": "Alpbach",
    "lat": "47.39878",
    "lng": "11.94373"
  },
  {
    "country": "AT",
    "name": "Itter",
    "lat": "47.46667",
    "lng": "12.13333"
  },
  {
    "country": "AT",
    "name": "Brand",
    "lat": "47.10083",
    "lng": "9.73722"
  },
  {
    "country": "AT",
    "name": "Rain",
    "lat": "46.60528",
    "lng": "14.38611"
  },
  {
    "country": "AT",
    "name": "Kleinedling",
    "lat": "46.81417",
    "lng": "14.82778"
  },
  {
    "country": "AT",
    "name": "Liebenfels",
    "lat": "46.73778",
    "lng": "14.28667"
  },
  {
    "country": "AT",
    "name": "Frauenstein",
    "lat": "46.81417",
    "lng": "14.29417"
  },
  {
    "country": "AT",
    "name": "Eppenstein",
    "lat": "47.12833",
    "lng": "14.7375"
  },
  {
    "country": "AT",
    "name": "Hochleithen",
    "lat": "48.45317",
    "lng": "16.5309"
  },
  {
    "country": "AT",
    "name": "Höf",
    "lat": "47.13401",
    "lng": "15.49092"
  },
  {
    "country": "AT",
    "name": "Niederschöckl",
    "lat": "47.15",
    "lng": "15.5"
  },
  {
    "country": "AT",
    "name": "Sankt Oswald ob Eibiswald",
    "lat": "46.70833",
    "lng": "15.14667"
  },
  {
    "country": "AT",
    "name": "Wildschönau",
    "lat": "47.40619",
    "lng": "12.03784"
  },
  {
    "country": "AT",
    "name": "Langkampfen",
    "lat": "47.54878",
    "lng": "12.10127"
  },
  {
    "country": "AT",
    "name": "Hart bei Graz",
    "lat": "47.04311",
    "lng": "15.51527"
  },
  {
    "country": "AT",
    "name": "Berg im Drautal",
    "lat": "46.74915",
    "lng": "13.13536"
  },
  {
    "country": "AT",
    "name": "Lockenhaus",
    "lat": "47.40753",
    "lng": "16.41623"
  },
  {
    "country": "AT",
    "name": "St. Georgen am Längsee",
    "lat": "46.78061",
    "lng": "14.43033"
  },
  {
    "country": "AT",
    "name": "St. Martin of Tennengebirge",
    "lat": "47.465",
    "lng": "13.37761"
  },
  {
    "country": "AT",
    "name": "Afiesl",
    "lat": "48.58229",
    "lng": "14.12777"
  },
  {
    "country": "AT",
    "name": "Großkirchheim",
    "lat": "46.9727",
    "lng": "12.89589"
  },
  {
    "country": "AT",
    "name": "Damüls",
    "lat": "47.28034",
    "lng": "9.89164"
  },
  {
    "country": "AT",
    "name": "Bad Waltersdorf",
    "lat": "47.1696",
    "lng": "16.0087"
  },
  {
    "country": "AT",
    "name": "Bad Zell",
    "lat": "48.34906",
    "lng": "14.66945"
  },
  {
    "country": "AT",
    "name": "Auen",
    "lat": "46.59963",
    "lng": "13.84389"
  },
  {
    "country": "AT",
    "name": "Bad Leonfelden",
    "lat": "48.52047",
    "lng": "14.29459"
  },
  {
    "country": "AT",
    "name": "Pfarrwerfen",
    "lat": "47.45729",
    "lng": "13.20531"
  },
  {
    "country": "AT",
    "name": "Thal",
    "lat": "47.07644",
    "lng": "15.36052"
  },
  {
    "country": "AT",
    "name": "Bürserberg",
    "lat": "47.14644",
    "lng": "9.77736"
  },
  {
    "country": "AT",
    "name": "Holzgau",
    "lat": "47.26045",
    "lng": "10.34419"
  },
  {
    "country": "AT",
    "name": "Schröcken",
    "lat": "47.25755",
    "lng": "10.09197"
  },
  {
    "country": "AT",
    "name": "Nebelberg",
    "lat": "48.62854",
    "lng": "13.84629"
  },
  {
    "country": "AT",
    "name": "Ottnang am Hausruck",
    "lat": "48.09568",
    "lng": "13.65841"
  },
  {
    "country": "AT",
    "name": "Prottes",
    "lat": "48.3868",
    "lng": "16.7389"
  },
  {
    "country": "AT",
    "name": "Favoriten",
    "lat": "48.16116",
    "lng": "16.38233"
  },
  {
    "country": "AT",
    "name": "Sonnberg im Mühlkreis",
    "lat": "48.4608",
    "lng": "14.31167"
  },
  {
    "country": "AT",
    "name": "Unternberg",
    "lat": "47.11269",
    "lng": "13.74261"
  },
  {
    "country": "AT",
    "name": "Alberschwende",
    "lat": "47.45025",
    "lng": "9.83152"
  },
  {
    "country": "AT",
    "name": "Mellau",
    "lat": "47.35034",
    "lng": "9.88149"
  },
  {
    "country": "AT",
    "name": "Frastanz",
    "lat": "47.21735",
    "lng": "9.62995"
  },
  {
    "country": "AT",
    "name": "Kirchbichl",
    "lat": "47.51743",
    "lng": "12.09629"
  },
  {
    "country": "AT",
    "name": "Baierdorf-Umgebung",
    "lat": "47.28511",
    "lng": "15.71045"
  },
  {
    "country": "AT",
    "name": "Sonntag",
    "lat": "47.23857",
    "lng": "9.89765"
  },
  {
    "country": "AT",
    "name": "Bärnbach",
    "lat": "47.07141",
    "lng": "15.12792"
  },
  {
    "country": "AT",
    "name": "Längenfeld",
    "lat": "47.07398",
    "lng": "10.96951"
  },
  {
    "country": "AT",
    "name": "Haus im Ennstal",
    "lat": "47.41058",
    "lng": "13.76759"
  },
  {
    "country": "AT",
    "name": "Hall bei Admont",
    "lat": "47.587",
    "lng": "14.46372"
  },
  {
    "country": "AT",
    "name": "Vandans",
    "lat": "47.09569",
    "lng": "9.86525"
  },
  {
    "country": "AT",
    "name": "Ertl",
    "lat": "47.97704",
    "lng": "14.63134"
  },
  {
    "country": "AT",
    "name": "Schwarzenberg",
    "lat": "47.41415",
    "lng": "9.85154"
  },
  {
    "country": "AT",
    "name": "Hittisau",
    "lat": "47.45781",
    "lng": "9.95962"
  },
  {
    "country": "AT",
    "name": "Micheldorf in Kärnten",
    "lat": "46.91465",
    "lng": "14.42733"
  },
  {
    "country": "AT",
    "name": "Schärding Vorstadt",
    "lat": "48.45195",
    "lng": "13.43946"
  },
  {
    "country": "AT",
    "name": "Neuberg im Burgenland",
    "lat": "47.16894",
    "lng": "16.26054"
  },
  {
    "country": "AT",
    "name": "Schönkirchen-Reyersdorf",
    "lat": "48.35477",
    "lng": "16.69115"
  },
  {
    "country": "AT",
    "name": "Klein-Neusiedl",
    "lat": "48.09379",
    "lng": "16.60661"
  },
  {
    "country": "AT",
    "name": "Eggendorf",
    "lat": "47.85809",
    "lng": "16.32182"
  },
  {
    "country": "AT",
    "name": "Seitenberg",
    "lat": "46.74801",
    "lng": "14.08825"
  },
  {
    "country": "AT",
    "name": "Dünserberg",
    "lat": "47.22752",
    "lng": "9.72372"
  },
  {
    "country": "AT",
    "name": "Aschau im Zillertal",
    "lat": "47.26613",
    "lng": "11.89536"
  },
  {
    "country": "AT",
    "name": "Assling",
    "lat": "46.78663",
    "lng": "12.63951"
  },
  {
    "country": "AT",
    "name": "Thiersee",
    "lat": "47.59424",
    "lng": "12.11758"
  },
  {
    "country": "AT",
    "name": "Mitterndorf",
    "lat": "47.57728",
    "lng": "12.16968"
  },
  {
    "country": "AT",
    "name": "Grinzens",
    "lat": "47.22927",
    "lng": "11.25318"
  },
  {
    "country": "AT",
    "name": "Mauer",
    "lat": "46.74104",
    "lng": "14.22937"
  },
  {
    "country": "AT",
    "name": "Mautbrücken",
    "lat": "46.72037",
    "lng": "14.19399"
  },
  {
    "country": "AT",
    "name": "Fresen",
    "lat": "46.70516",
    "lng": "14.04513"
  },
  {
    "country": "AT",
    "name": "Draschen",
    "lat": "46.76909",
    "lng": "14.06758"
  },
  {
    "country": "AT",
    "name": "Hinterberg",
    "lat": "47.36066",
    "lng": "15.06951"
  },
  {
    "country": "AT",
    "name": "Tillmitsch Links der Laßnitz",
    "lat": "46.80955",
    "lng": "15.52394"
  },
  {
    "country": "AT",
    "name": "Kirchenviertel",
    "lat": "47.13124",
    "lng": "15.34764"
  },
  {
    "country": "AT",
    "name": "Taugl",
    "lat": "47.64747",
    "lng": "13.20282"
  },
  {
    "country": "AT",
    "name": "Anger",
    "lat": "47.15593",
    "lng": "13.10592"
  },
  {
    "country": "AT",
    "name": "Sticklberg",
    "lat": "47.53036",
    "lng": "15.77911"
  },
  {
    "country": "AT",
    "name": "Klaffenegg",
    "lat": "47.51813",
    "lng": "15.76006"
  },
  {
    "country": "AT",
    "name": "Wagrain",
    "lat": "48.00503",
    "lng": "13.67163"
  },
  {
    "country": "AT",
    "name": "Weißenkirchen im Attergau",
    "lat": "47.94964",
    "lng": "13.41843"
  },
  {
    "country": "AT",
    "name": "Nöstlbach",
    "lat": "48.1666",
    "lng": "14.24609"
  },
  {
    "country": "AT",
    "name": "Klausner",
    "lat": "47.5756",
    "lng": "14.35029"
  },
  {
    "country": "AT",
    "name": "Puchlkirchen am Trattberg",
    "lat": "48.04478",
    "lng": "13.57198"
  },
  {
    "country": "AT",
    "name": "Wagnergraben",
    "lat": "48.02036",
    "lng": "13.02395"
  },
  {
    "country": "AT",
    "name": "Illitsch",
    "lat": "46.53855",
    "lng": "13.86681"
  },
  {
    "country": "AT",
    "name": "Diesseits",
    "lat": "48.29216",
    "lng": "13.43546"
  },
  {
    "country": "AT",
    "name": "Wasserburg",
    "lat": "48.27425",
    "lng": "14.56152"
  },
  {
    "country": "AT",
    "name": "Loitzenberg",
    "lat": "48.27291",
    "lng": "14.55259"
  },
  {
    "country": "AT",
    "name": "Unterjosefstal",
    "lat": "48.29216",
    "lng": "14.57525"
  },
  {
    "country": "AT",
    "name": "Doppl",
    "lat": "48.28245",
    "lng": "14.56851"
  },
  {
    "country": "AT",
    "name": "Wolfern",
    "lat": "48.08278",
    "lng": "14.37201"
  },
  {
    "country": "AT",
    "name": "Eggendorf",
    "lat": "48.1313",
    "lng": "15.6196"
  },
  {
    "country": "AT",
    "name": "Hart",
    "lat": "48.1532",
    "lng": "15.61569"
  },
  {
    "country": "AT",
    "name": "Ratzersdorf an der Traisen",
    "lat": "48.22639",
    "lng": "15.66629"
  },
  {
    "country": "AT",
    "name": "Regau",
    "lat": "47.99078",
    "lng": "13.68811"
  },
  {
    "country": "AT",
    "name": "Bernardin",
    "lat": "48.16042",
    "lng": "14.00834"
  },
  {
    "country": "AT",
    "name": "Brandln",
    "lat": "48.1451",
    "lng": "13.99504"
  },
  {
    "country": "AT",
    "name": "Dickerldorf",
    "lat": "48.17676",
    "lng": "14.05705"
  },
  {
    "country": "AT",
    "name": "Laahen",
    "lat": "48.17192",
    "lng": "14.00637"
  },
  {
    "country": "AT",
    "name": "Oberhaid",
    "lat": "48.17593",
    "lng": "14.01495"
  },
  {
    "country": "AT",
    "name": "Gralla",
    "lat": "46.81404",
    "lng": "15.5551"
  },
  {
    "country": "AT",
    "name": "Wispl",
    "lat": "48.16488",
    "lng": "13.99753"
  },
  {
    "country": "AT",
    "name": "Haidl",
    "lat": "48.17267",
    "lng": "14.05297"
  },
  {
    "country": "AT",
    "name": "Tiefenbach",
    "lat": "47.5354",
    "lng": "16.21346"
  },
  {
    "country": "AT",
    "name": "Gries",
    "lat": "46.8316",
    "lng": "14.85103"
  },
  {
    "country": "AT",
    "name": "Priel",
    "lat": "46.82758",
    "lng": "14.8333"
  },
  {
    "country": "AT",
    "name": "Kreuzstetten",
    "lat": "48.48046",
    "lng": "16.47323"
  },
  {
    "country": "AT",
    "name": "Langholzfeld",
    "lat": "48.24297",
    "lng": "14.24772"
  },
  {
    "country": "AT",
    "name": "Neufurth",
    "lat": "48.07894",
    "lng": "14.8118"
  },
  {
    "country": "AT",
    "name": "Villacher Vorstadt",
    "lat": "46.62368",
    "lng": "14.28892"
  },
  {
    "country": "AT",
    "name": "Völkermarkter Vorstadt",
    "lat": "46.62418",
    "lng": "14.32081"
  },
  {
    "country": "AT",
    "name": "St. Veiter Vorstadt",
    "lat": "46.6317",
    "lng": "14.30579"
  },
  {
    "country": "AT",
    "name": "Lerchenfeld",
    "lat": "48.41234",
    "lng": "15.63183"
  },
  {
    "country": "AT",
    "name": "Reinbach",
    "lat": "47.34673",
    "lng": "13.19072"
  },
  {
    "country": "AT",
    "name": "Niederstraß",
    "lat": "48.01398",
    "lng": "13.72956"
  },
  {
    "country": "AT",
    "name": "Langenlebarn-Oberaigen",
    "lat": "48.33023",
    "lng": "16.11059"
  },
  {
    "country": "AT",
    "name": "Lind",
    "lat": "46.62244",
    "lng": "13.84715"
  },
  {
    "country": "AT",
    "name": "Zell-Arzberg",
    "lat": "47.95191",
    "lng": "14.79322"
  },
  {
    "country": "AT",
    "name": "Zell-Markt",
    "lat": "47.95878",
    "lng": "14.78318"
  },
  {
    "country": "AT",
    "name": "Esch",
    "lat": "47.8403",
    "lng": "13.09223"
  },
  {
    "country": "AT",
    "name": "Innere Stadt",
    "lat": "47.0665",
    "lng": "15.44051"
  },
  {
    "country": "AT",
    "name": "Villach-Innere Stadt",
    "lat": "46.61275",
    "lng": "13.84638"
  },
  {
    "country": "AT",
    "name": "Schachen bei Vorau",
    "lat": "47.3801",
    "lng": "15.85816"
  },
  {
    "country": "AT",
    "name": "Obergäu",
    "lat": "47.58955",
    "lng": "13.17621"
  },
  {
    "country": "AT",
    "name": "Eching",
    "lat": "47.97263",
    "lng": "12.88786"
  },
  {
    "country": "AT",
    "name": "Untereisenfeld",
    "lat": "48.168",
    "lng": "14.041"
  },
  {
    "country": "AT",
    "name": "Hochpoint",
    "lat": "48.16139",
    "lng": "14.03838"
  },
  {
    "country": "AT",
    "name": "Dörfl",
    "lat": "48.01245",
    "lng": "13.65472"
  },
  {
    "country": "AT",
    "name": "Dürnau",
    "lat": "47.9971",
    "lng": "13.64459"
  },
  {
    "country": "AT",
    "name": "Neualm",
    "lat": "47.69336",
    "lng": "13.08758"
  },
  {
    "country": "AT",
    "name": "Neu-Feffernitz",
    "lat": "46.68772",
    "lng": "13.67914"
  },
  {
    "country": "AT",
    "name": "Braunau Neustadt",
    "lat": "48.24606",
    "lng": "13.03583"
  },
  {
    "country": "AT",
    "name": "Schleben",
    "lat": "46.62039",
    "lng": "13.93301"
  },
  {
    "country": "AT",
    "name": "Wudmath",
    "lat": "46.59634",
    "lng": "13.98067"
  },
  {
    "country": "AT",
    "name": "Bergern",
    "lat": "48.16752",
    "lng": "14.11153"
  },
  {
    "country": "AT",
    "name": "Höfling",
    "lat": "48.05444",
    "lng": "15.03672"
  },
  {
    "country": "AT",
    "name": "Vasoldsberg",
    "lat": "47.01634",
    "lng": "15.55835"
  },
  {
    "country": "AT",
    "name": "St. Agathen und Perau",
    "lat": "46.60627",
    "lng": "13.85615"
  },
  {
    "country": "AT",
    "name": "Laab",
    "lat": "48.2611",
    "lng": "13.05418"
  },
  {
    "country": "AT",
    "name": "Absdorf",
    "lat": "48.40021",
    "lng": "15.97874"
  },
  {
    "country": "AT",
    "name": "Rohrendorf bei Krems",
    "lat": "48.41935",
    "lng": "15.65772"
  },
  {
    "country": "AT",
    "name": "Tux",
    "lat": "47.15559",
    "lng": "11.72872"
  },
  {
    "country": "AT",
    "name": "Bergland",
    "lat": "48.15595",
    "lng": "15.18553"
  },
  {
    "country": "AT",
    "name": "Rosental an der Kainach",
    "lat": "47.05192",
    "lng": "15.122"
  },
  {
    "country": "AT",
    "name": "Ufer",
    "lat": "48.24842",
    "lng": "14.49977"
  },
  {
    "country": "AT",
    "name": "Lingenau",
    "lat": "47.45033",
    "lng": "9.92166"
  },
  {
    "country": "AT",
    "name": "Tillmitsch",
    "lat": "46.81195",
    "lng": "15.51679"
  },
  {
    "country": "AT",
    "name": "Donaustadt",
    "lat": "48.2333",
    "lng": "16.46002"
  },
  {
    "country": "AT",
    "name": "Jakomini",
    "lat": "47.05441",
    "lng": "15.44984"
  },
  {
    "country": "AT",
    "name": "Lend",
    "lat": "47.08256",
    "lng": "15.41589"
  },
  {
    "country": "AT",
    "name": "Geidorf",
    "lat": "47.08393",
    "lng": "15.444"
  },
  {
    "country": "AT",
    "name": "Sankt Leonhard",
    "lat": "47.06924",
    "lng": "15.45784"
  },
  {
    "country": "AT",
    "name": "Andritz",
    "lat": "47.11387",
    "lng": "15.42348"
  },
  {
    "country": "AT",
    "name": "Gries",
    "lat": "47.06236",
    "lng": "15.42421"
  },
  {
    "country": "AT",
    "name": "Viktringer Vorstadt",
    "lat": "46.61773",
    "lng": "14.30931"
  },
  {
    "country": "AT",
    "name": "Angerberg",
    "lat": "47.50563",
    "lng": "12.03119"
  },
  {
    "country": "AT",
    "name": "Rohr im Kremstal",
    "lat": "48.06864",
    "lng": "14.19306"
  },
  {
    "country": "AT",
    "name": "Langenegg",
    "lat": "47.46922",
    "lng": "9.89744"
  },
  {
    "country": "AT",
    "name": "Vogau",
    "lat": "46.73187",
    "lng": "15.60837"
  },
  {
    "country": "AT",
    "name": "Reitberg",
    "lat": "47.85269",
    "lng": "13.1573"
  },
  {
    "country": "AT",
    "name": "Föderlach I",
    "lat": "46.59998",
    "lng": "13.96128"
  },
  {
    "country": "AT",
    "name": "Vals",
    "lat": "47.04507",
    "lng": "11.53281"
  },
  {
    "country": "AT",
    "name": "Hinterleiten",
    "lat": "48.16513",
    "lng": "15.96654"
  },
  {
    "country": "AT",
    "name": "Neubau",
    "lat": "48.21901",
    "lng": "14.19301"
  },
  {
    "country": "AT",
    "name": "Steinfeld",
    "lat": "47.71254",
    "lng": "13.6326"
  },
  {
    "country": "AU",
    "name": "York",
    "lat": "-31.88809",
    "lng": "116.7678"
  },
  {
    "country": "AU",
    "name": "Yanchep",
    "lat": "-31.54678",
    "lng": "115.63171"
  },
  {
    "country": "AU",
    "name": "Yallingup",
    "lat": "-33.64592",
    "lng": "115.03514"
  },
  {
    "country": "AU",
    "name": "Wundowie",
    "lat": "-31.76163",
    "lng": "116.3799"
  },
  {
    "country": "AU",
    "name": "Wooroloo",
    "lat": "-31.8038",
    "lng": "116.31311"
  },
  {
    "country": "AU",
    "name": "Woodville",
    "lat": "-34.88333",
    "lng": "138.55"
  },
  {
    "country": "AU",
    "name": "Woodside",
    "lat": "-34.95433",
    "lng": "138.87901"
  },
  {
    "country": "AU",
    "name": "Wongan Hills",
    "lat": "-30.89294",
    "lng": "116.71925"
  },
  {
    "country": "AU",
    "name": "Williamstown",
    "lat": "-34.6721",
    "lng": "138.89108"
  },
  {
    "country": "AU",
    "name": "Willaston",
    "lat": "-34.58333",
    "lng": "138.75"
  },
  {
    "country": "AU",
    "name": "Whyalla",
    "lat": "-33.03268",
    "lng": "137.56483"
  },
  {
    "country": "AU",
    "name": "Wembley",
    "lat": "-31.93333",
    "lng": "115.8"
  },
  {
    "country": "AU",
    "name": "Wellard",
    "lat": "-32.26667",
    "lng": "115.83333"
  },
  {
    "country": "AU",
    "name": "Wayville",
    "lat": "-34.95",
    "lng": "138.58333"
  },
  {
    "country": "AU",
    "name": "Waroona",
    "lat": "-32.84323",
    "lng": "115.92201"
  },
  {
    "country": "AU",
    "name": "Wanneroo",
    "lat": "-31.75",
    "lng": "115.8"
  },
  {
    "country": "AU",
    "name": "Wallaroo",
    "lat": "-33.93881",
    "lng": "137.63365"
  },
  {
    "country": "AU",
    "name": "Waikerie",
    "lat": "-34.18178",
    "lng": "139.98552"
  },
  {
    "country": "AU",
    "name": "Wagin",
    "lat": "-33.30894",
    "lng": "117.34328"
  },
  {
    "country": "AU",
    "name": "Waggrakine",
    "lat": "-28.71883",
    "lng": "114.63924"
  },
  {
    "country": "AU",
    "name": "Virginia",
    "lat": "-34.6663",
    "lng": "138.56027"
  },
  {
    "country": "AU",
    "name": "Victor Harbor",
    "lat": "-35.55042",
    "lng": "138.62154"
  },
  {
    "country": "AU",
    "name": "Vasse",
    "lat": "-33.66667",
    "lng": "115.25"
  },
  {
    "country": "AU",
    "name": "Upper Sturt",
    "lat": "-35.01667",
    "lng": "138.68333"
  },
  {
    "country": "AU",
    "name": "Unley",
    "lat": "-34.95",
    "lng": "138.6"
  },
  {
    "country": "AU",
    "name": "Two Wells",
    "lat": "-34.59327",
    "lng": "138.51367"
  },
  {
    "country": "AU",
    "name": "Tumby Bay",
    "lat": "-34.3773",
    "lng": "136.10065"
  },
  {
    "country": "AU",
    "name": "Trigg",
    "lat": "-31.86939",
    "lng": "115.7571"
  },
  {
    "country": "AU",
    "name": "Toodyay",
    "lat": "-31.54977",
    "lng": "116.46743"
  },
  {
    "country": "AU",
    "name": "Thebarton",
    "lat": "-34.91667",
    "lng": "138.56667"
  },
  {
    "country": "AU",
    "name": "Tennant Creek",
    "lat": "-19.6497",
    "lng": "134.19147"
  },
  {
    "country": "AU",
    "name": "Tanunda",
    "lat": "-34.52336",
    "lng": "138.95982"
  },
  {
    "country": "AU",
    "name": "Tailem Bend",
    "lat": "-35.25226",
    "lng": "139.45546"
  },
  {
    "country": "AU",
    "name": "Swan View",
    "lat": "-31.88333",
    "lng": "116.05"
  },
  {
    "country": "AU",
    "name": "Swanbourne",
    "lat": "-31.96878",
    "lng": "115.7673"
  },
  {
    "country": "AU",
    "name": "Subiaco",
    "lat": "-31.9485",
    "lng": "115.8268"
  },
  {
    "country": "AU",
    "name": "Sturt",
    "lat": "-35.01667",
    "lng": "138.55"
  },
  {
    "country": "AU",
    "name": "Streaky Bay",
    "lat": "-32.79554",
    "lng": "134.20928"
  },
  {
    "country": "AU",
    "name": "Strathalbyn",
    "lat": "-35.25979",
    "lng": "138.89247"
  },
  {
    "country": "AU",
    "name": "Stoneville",
    "lat": "-30.86667",
    "lng": "121.76667"
  },
  {
    "country": "AU",
    "name": "Stirling",
    "lat": "-35.01518",
    "lng": "138.73637"
  },
  {
    "country": "AU",
    "name": "Spearwood",
    "lat": "-32.10534",
    "lng": "115.77797"
  },
  {
    "country": "AU",
    "name": "South Perth",
    "lat": "-31.98333",
    "lng": "115.86667"
  },
  {
    "country": "AU",
    "name": "Solomontown",
    "lat": "-33.1853",
    "lng": "138.02364"
  },
  {
    "country": "AU",
    "name": "Smithfield",
    "lat": "-34.68333",
    "lng": "138.68333"
  },
  {
    "country": "AU",
    "name": "Serpentine",
    "lat": "-32.36051",
    "lng": "115.97723"
  },
  {
    "country": "AU",
    "name": "Seaton",
    "lat": "-34.9",
    "lng": "138.51667"
  },
  {
    "country": "AU",
    "name": "Seaford",
    "lat": "-35.1898",
    "lng": "138.47589"
  },
  {
    "country": "AU",
    "name": "Scarborough",
    "lat": "-31.89578",
    "lng": "115.76431"
  },
  {
    "country": "AU",
    "name": "Salisbury",
    "lat": "-34.76667",
    "lng": "138.63333"
  },
  {
    "country": "AU",
    "name": "Safety Bay",
    "lat": "-32.30463",
    "lng": "115.74213"
  },
  {
    "country": "AU",
    "name": "Roxby Downs",
    "lat": "-30.56305",
    "lng": "136.89546"
  },
  {
    "country": "AU",
    "name": "Roseworthy",
    "lat": "-34.53397",
    "lng": "138.75023"
  },
  {
    "country": "AU",
    "name": "Roebourne",
    "lat": "-20.77229",
    "lng": "117.14648"
  },
  {
    "country": "AU",
    "name": "Rockingham",
    "lat": "-32.27682",
    "lng": "115.72978"
  },
  {
    "country": "AU",
    "name": "Maida Vale",
    "lat": "-31.95187",
    "lng": "116.02764"
  },
  {
    "country": "AU",
    "name": "Reynella",
    "lat": "-35.09372",
    "lng": "138.53082"
  },
  {
    "country": "AU",
    "name": "Ravensthorpe",
    "lat": "-33.58303",
    "lng": "120.04688"
  },
  {
    "country": "AU",
    "name": "Quorn",
    "lat": "-32.34676",
    "lng": "138.04176"
  },
  {
    "country": "AU",
    "name": "Quindalup",
    "lat": "-33.6356",
    "lng": "115.14899"
  },
  {
    "country": "AU",
    "name": "Prospect",
    "lat": "-34.88241",
    "lng": "138.5933"
  },
  {
    "country": "AU",
    "name": "Port Willunga",
    "lat": "-35.27792",
    "lng": "138.4523"
  },
  {
    "country": "AU",
    "name": "Port Victoria",
    "lat": "-34.49602",
    "lng": "137.4827"
  },
  {
    "country": "AU",
    "name": "Port Pirie",
    "lat": "-33.19176",
    "lng": "138.01746"
  },
  {
    "country": "AU",
    "name": "Port Noarlunga",
    "lat": "-35.14802",
    "lng": "138.47099"
  },
  {
    "country": "AU",
    "name": "Port Lincoln",
    "lat": "-34.72625",
    "lng": "135.87442"
  },
  {
    "country": "AU",
    "name": "Port Hedland",
    "lat": "-20.31215",
    "lng": "118.61059"
  },
  {
    "country": "AU",
    "name": "Port Elliot",
    "lat": "-35.53017",
    "lng": "138.67922"
  },
  {
    "country": "AU",
    "name": "Port Augusta West",
    "lat": "-32.48611",
    "lng": "137.75833"
  },
  {
    "country": "AU",
    "name": "Port Augusta",
    "lat": "-32.49597",
    "lng": "137.77281"
  },
  {
    "country": "AU",
    "name": "Port Adelaide",
    "lat": "-34.85",
    "lng": "138.46667"
  },
  {
    "country": "AU",
    "name": "Plympton",
    "lat": "-34.95",
    "lng": "138.55"
  },
  {
    "country": "AU",
    "name": "Pinjarra",
    "lat": "-32.6298",
    "lng": "115.87351"
  },
  {
    "country": "AU",
    "name": "Peterborough",
    "lat": "-32.97205",
    "lng": "138.84073"
  },
  {
    "country": "AU",
    "name": "Perth",
    "lat": "-31.95224",
    "lng": "115.8614"
  },
  {
    "country": "AU",
    "name": "Pemberton",
    "lat": "-34.44311",
    "lng": "116.03689"
  },
  {
    "country": "AU",
    "name": "Pearce",
    "lat": "-31.66667",
    "lng": "116.01667"
  },
  {
    "country": "AU",
    "name": "Parkerville",
    "lat": "-31.87472",
    "lng": "116.138"
  },
  {
    "country": "AU",
    "name": "Parap",
    "lat": "-12.43054",
    "lng": "130.84142"
  },
  {
    "country": "AU",
    "name": "One Tree Hill",
    "lat": "-34.7",
    "lng": "138.76667"
  },
  {
    "country": "AU",
    "name": "Oakbank",
    "lat": "-34.9834",
    "lng": "138.84528"
  },
  {
    "country": "AU",
    "name": "Nuriootpa",
    "lat": "-34.46825",
    "lng": "138.99767"
  },
  {
    "country": "AU",
    "name": "North Fremantle",
    "lat": "-32.03333",
    "lng": "115.75"
  },
  {
    "country": "AU",
    "name": "North Beach",
    "lat": "-31.86298",
    "lng": "115.75624"
  },
  {
    "country": "AU",
    "name": "Northampton",
    "lat": "-28.34994",
    "lng": "114.63821"
  },
  {
    "country": "AU",
    "name": "Northam",
    "lat": "-31.64932",
    "lng": "116.67423"
  },
  {
    "country": "AU",
    "name": "Normanville",
    "lat": "-35.44623",
    "lng": "138.3213"
  },
  {
    "country": "AU",
    "name": "Noarlunga",
    "lat": "-35.18209",
    "lng": "138.50138"
  },
  {
    "country": "AU",
    "name": "Nhulunbuy",
    "lat": "-12.18165",
    "lng": "136.77841"
  },
  {
    "country": "AU",
    "name": "Newman",
    "lat": "-23.35644",
    "lng": "119.73553"
  },
  {
    "country": "AU",
    "name": "Nedlands",
    "lat": "-31.98184",
    "lng": "115.8073"
  },
  {
    "country": "AU",
    "name": "Narrogin",
    "lat": "-32.93282",
    "lng": "117.17763"
  },
  {
    "country": "AU",
    "name": "Nairne",
    "lat": "-35.0345",
    "lng": "138.91154"
  },
  {
    "country": "AU",
    "name": "Murray Bridge",
    "lat": "-35.11986",
    "lng": "139.27345"
  },
  {
    "country": "AU",
    "name": "Mundijong",
    "lat": "-32.29217",
    "lng": "115.98564"
  },
  {
    "country": "AU",
    "name": "Mundaring",
    "lat": "-31.9021",
    "lng": "116.16757"
  },
  {
    "country": "AU",
    "name": "Mount Isa",
    "lat": "-20.72523",
    "lng": "139.49727"
  },
  {
    "country": "AU",
    "name": "Mount Helena",
    "lat": "-31.87606",
    "lng": "116.21025"
  },
  {
    "country": "AU",
    "name": "Mount Compass",
    "lat": "-35.34685",
    "lng": "138.62032"
  },
  {
    "country": "AU",
    "name": "Mount Barker",
    "lat": "-35.06667",
    "lng": "138.86667"
  },
  {
    "country": "AU",
    "name": "Mount Barker",
    "lat": "-34.63084",
    "lng": "117.66606"
  },
  {
    "country": "AU",
    "name": "Mosman Park",
    "lat": "-32.00538",
    "lng": "115.7638"
  },
  {
    "country": "AU",
    "name": "Morphett Vale",
    "lat": "-35.13333",
    "lng": "138.51667"
  },
  {
    "country": "AU",
    "name": "Moora",
    "lat": "-30.64003",
    "lng": "116.00365"
  },
  {
    "country": "AU",
    "name": "Modbury",
    "lat": "-34.83333",
    "lng": "138.68333"
  },
  {
    "country": "AU",
    "name": "Moana",
    "lat": "-35.19394",
    "lng": "138.47614"
  },
  {
    "country": "AU",
    "name": "Mitcham",
    "lat": "-34.97892",
    "lng": "138.62184"
  },
  {
    "country": "AU",
    "name": "Midland",
    "lat": "-31.9",
    "lng": "116"
  },
  {
    "country": "AU",
    "name": "Middle Swan",
    "lat": "-31.85",
    "lng": "116.01667"
  },
  {
    "country": "AU",
    "name": "Merredin",
    "lat": "-31.48094",
    "lng": "118.27448"
  },
  {
    "country": "AU",
    "name": "Meningie",
    "lat": "-35.68637",
    "lng": "139.34007"
  },
  {
    "country": "AU",
    "name": "Melville",
    "lat": "-28.18333",
    "lng": "116.73333"
  },
  {
    "country": "AU",
    "name": "Medina",
    "lat": "-32.23333",
    "lng": "115.78333"
  },
  {
    "country": "AU",
    "name": "Meadows",
    "lat": "-35.18021",
    "lng": "138.7625"
  },
  {
    "country": "AU",
    "name": "McMinns Lagoon",
    "lat": "-12.55397",
    "lng": "131.11165"
  },
  {
    "country": "AU",
    "name": "McLaren Vale",
    "lat": "-35.21895",
    "lng": "138.54326"
  },
  {
    "country": "AU",
    "name": "Maylands",
    "lat": "-31.93097",
    "lng": "115.89486"
  },
  {
    "country": "AU",
    "name": "Marion",
    "lat": "-35.00423",
    "lng": "138.55313"
  },
  {
    "country": "AU",
    "name": "Marino",
    "lat": "-35.04468",
    "lng": "138.51236"
  },
  {
    "country": "AU",
    "name": "Margaret River",
    "lat": "-33.95504",
    "lng": "115.07599"
  },
  {
    "country": "AU",
    "name": "Mannum",
    "lat": "-34.91529",
    "lng": "139.30325"
  },
  {
    "country": "AU",
    "name": "Manning",
    "lat": "-32.01594",
    "lng": "115.86714"
  },
  {
    "country": "AU",
    "name": "Manjimup",
    "lat": "-34.24122",
    "lng": "116.14564"
  },
  {
    "country": "AU",
    "name": "Mandurah",
    "lat": "-32.5269",
    "lng": "115.7217"
  },
  {
    "country": "AU",
    "name": "Mallala",
    "lat": "-34.4374",
    "lng": "138.50987"
  },
  {
    "country": "AU",
    "name": "Maitland",
    "lat": "-34.37386",
    "lng": "137.67333"
  },
  {
    "country": "AU",
    "name": "Maddington",
    "lat": "-32.05",
    "lng": "115.98333"
  },
  {
    "country": "AU",
    "name": "Macclesfield",
    "lat": "-35.17182",
    "lng": "138.83589"
  },
  {
    "country": "AU",
    "name": "Lyndoch",
    "lat": "-34.60124",
    "lng": "138.89094"
  },
  {
    "country": "AU",
    "name": "Lower Chittering",
    "lat": "-31.58333",
    "lng": "116.11667"
  },
  {
    "country": "AU",
    "name": "Lobethal",
    "lat": "-34.90455",
    "lng": "138.87477"
  },
  {
    "country": "AU",
    "name": "Little Hampton",
    "lat": "-35.05",
    "lng": "138.85"
  },
  {
    "country": "AU",
    "name": "Lewiston",
    "lat": "-34.60449",
    "lng": "138.59125"
  },
  {
    "country": "AU",
    "name": "Langhorne Creek",
    "lat": "-35.29596",
    "lng": "139.03591"
  },
  {
    "country": "AU",
    "name": "Kwinana",
    "lat": "-32.23013",
    "lng": "115.78128"
  },
  {
    "country": "AU",
    "name": "Kununurra",
    "lat": "-15.77825",
    "lng": "128.74208"
  },
  {
    "country": "AU",
    "name": "Kojonup",
    "lat": "-33.8305",
    "lng": "117.15946"
  },
  {
    "country": "AU",
    "name": "Kingscote",
    "lat": "-35.6559",
    "lng": "137.6393"
  },
  {
    "country": "AU",
    "name": "Kenwick",
    "lat": "-32.03333",
    "lng": "115.96667"
  },
  {
    "country": "AU",
    "name": "Kendenup",
    "lat": "-34.48213",
    "lng": "117.62533"
  },
  {
    "country": "AU",
    "name": "Kelmscott",
    "lat": "-32.12434",
    "lng": "116.0259"
  },
  {
    "country": "AU",
    "name": "Katherine",
    "lat": "-14.46517",
    "lng": "132.26347"
  },
  {
    "country": "AU",
    "name": "Katanning",
    "lat": "-33.68787",
    "lng": "117.5584"
  },
  {
    "country": "AU",
    "name": "Kapunda",
    "lat": "-34.33871",
    "lng": "138.91644"
  },
  {
    "country": "AU",
    "name": "Kalgoorlie",
    "lat": "-30.74614",
    "lng": "121.4742"
  },
  {
    "country": "AU",
    "name": "Kalbarri",
    "lat": "-27.7105",
    "lng": "114.16505"
  },
  {
    "country": "AU",
    "name": "Kadina",
    "lat": "-33.96495",
    "lng": "137.71634"
  },
  {
    "country": "AU",
    "name": "Jamestown",
    "lat": "-33.20531",
    "lng": "138.60503"
  },
  {
    "country": "AU",
    "name": "Ingle Farm",
    "lat": "-34.83333",
    "lng": "138.63333"
  },
  {
    "country": "AU",
    "name": "Hope Valley",
    "lat": "-34.83333",
    "lng": "138.7"
  },
  {
    "country": "AU",
    "name": "Honiton",
    "lat": "-35.11667",
    "lng": "137.65"
  },
  {
    "country": "AU",
    "name": "Hindmarsh Island",
    "lat": "-35.51014",
    "lng": "138.86762"
  },
  {
    "country": "AU",
    "name": "Heathfield",
    "lat": "-35.01667",
    "lng": "138.71667"
  },
  {
    "country": "AU",
    "name": "Harvey",
    "lat": "-33.07863",
    "lng": "115.91512"
  },
  {
    "country": "AU",
    "name": "Happy Valley",
    "lat": "-35.08333",
    "lng": "138.53333"
  },
  {
    "country": "AU",
    "name": "Halls Creek",
    "lat": "-18.22485",
    "lng": "127.66647"
  },
  {
    "country": "AU",
    "name": "Hahndorf",
    "lat": "-35.02863",
    "lng": "138.80779"
  },
  {
    "country": "AU",
    "name": "Hackham",
    "lat": "-35.15",
    "lng": "138.51667"
  },
  {
    "country": "AU",
    "name": "Gumeracha",
    "lat": "-34.82388",
    "lng": "138.88467"
  },
  {
    "country": "AU",
    "name": "Guildford",
    "lat": "-31.9",
    "lng": "115.96667"
  },
  {
    "country": "AU",
    "name": "Greenmount",
    "lat": "-31.90072",
    "lng": "116.0495"
  },
  {
    "country": "AU",
    "name": "Grasmere",
    "lat": "-35.01806",
    "lng": "117.75556"
  },
  {
    "country": "AU",
    "name": "Grange",
    "lat": "-34.90223",
    "lng": "138.49022"
  },
  {
    "country": "AU",
    "name": "Gosnells",
    "lat": "-32.081",
    "lng": "116.0054"
  },
  {
    "country": "AU",
    "name": "Gooseberry Hill",
    "lat": "-31.95444",
    "lng": "116.0492"
  },
  {
    "country": "AU",
    "name": "Goolwa",
    "lat": "-35.50159",
    "lng": "138.78191"
  },
  {
    "country": "AU",
    "name": "Golden Grove",
    "lat": "-34.78333",
    "lng": "138.73333"
  },
  {
    "country": "AU",
    "name": "Glenelg",
    "lat": "-34.98079",
    "lng": "138.515"
  },
  {
    "country": "AU",
    "name": "Gilles Plains",
    "lat": "-34.85",
    "lng": "138.65"
  },
  {
    "country": "AU",
    "name": "Geraldton",
    "lat": "-28.77897",
    "lng": "114.61459"
  },
  {
    "country": "AU",
    "name": "Gawler",
    "lat": "-34.60251",
    "lng": "138.74902"
  },
  {
    "country": "AU",
    "name": "Fremantle",
    "lat": "-32.05632",
    "lng": "115.74557"
  },
  {
    "country": "AU",
    "name": "Freeling",
    "lat": "-34.45407",
    "lng": "138.80868"
  },
  {
    "country": "AU",
    "name": "Findon",
    "lat": "-34.9",
    "lng": "138.53333"
  },
  {
    "country": "AU",
    "name": "Esperance",
    "lat": "-33.85919",
    "lng": "121.89164"
  },
  {
    "country": "AU",
    "name": "Encounter Bay",
    "lat": "-35.57419",
    "lng": "138.60055"
  },
  {
    "country": "AU",
    "name": "Elizabeth",
    "lat": "-34.71944",
    "lng": "138.67707"
  },
  {
    "country": "AU",
    "name": "Donnybrook",
    "lat": "-33.5713",
    "lng": "115.82446"
  },
  {
    "country": "AU",
    "name": "Dongara",
    "lat": "-29.25818",
    "lng": "114.93276"
  },
  {
    "country": "AU",
    "name": "Chidlow",
    "lat": "-31.86094",
    "lng": "116.27243"
  },
  {
    "country": "AU",
    "name": "Derby",
    "lat": "-17.30295",
    "lng": "123.62864"
  },
  {
    "country": "AU",
    "name": "Denmark",
    "lat": "-34.96067",
    "lng": "117.35321"
  },
  {
    "country": "AU",
    "name": "Port Denison",
    "lat": "-29.27367",
    "lng": "114.92068"
  },
  {
    "country": "AU",
    "name": "Darwin",
    "lat": "-12.46113",
    "lng": "130.84185"
  },
  {
    "country": "AU",
    "name": "Darlington",
    "lat": "-35.03333",
    "lng": "138.56667"
  },
  {
    "country": "AU",
    "name": "Darlington",
    "lat": "-31.91906",
    "lng": "116.0812"
  },
  {
    "country": "AU",
    "name": "Dampier",
    "lat": "-20.66275",
    "lng": "116.71256"
  },
  {
    "country": "AU",
    "name": "Cunderdin",
    "lat": "-31.65398",
    "lng": "117.23374"
  },
  {
    "country": "AU",
    "name": "Cummins",
    "lat": "-34.26396",
    "lng": "135.726"
  },
  {
    "country": "AU",
    "name": "Crystal Brook",
    "lat": "-33.35256",
    "lng": "138.20955"
  },
  {
    "country": "AU",
    "name": "Craigburn Farm",
    "lat": "-35.05",
    "lng": "138.61667"
  },
  {
    "country": "AU",
    "name": "Crafers",
    "lat": "-35",
    "lng": "138.7"
  },
  {
    "country": "AU",
    "name": "Cottesloe",
    "lat": "-32",
    "lng": "115.76667"
  },
  {
    "country": "AU",
    "name": "Coromandel Valley",
    "lat": "-35.05",
    "lng": "138.61667"
  },
  {
    "country": "AU",
    "name": "Coogee",
    "lat": "-32.11934",
    "lng": "115.7665"
  },
  {
    "country": "AU",
    "name": "Coober Pedy",
    "lat": "-29.01415",
    "lng": "134.75495"
  },
  {
    "country": "AU",
    "name": "Collie",
    "lat": "-33.36206",
    "lng": "116.15617"
  },
  {
    "country": "AU",
    "name": "Cleve",
    "lat": "-33.7",
    "lng": "136.5"
  },
  {
    "country": "AU",
    "name": "Clare",
    "lat": "-33.83325",
    "lng": "138.61064"
  },
  {
    "country": "AU",
    "name": "Cheltenham",
    "lat": "-34.86667",
    "lng": "138.51667"
  },
  {
    "country": "AU",
    "name": "Ceduna",
    "lat": "-32.1266",
    "lng": "133.67271"
  },
  {
    "country": "AU",
    "name": "Caversham",
    "lat": "-31.88333",
    "lng": "115.96667"
  },
  {
    "country": "AU",
    "name": "Carnarvon",
    "lat": "-24.88258",
    "lng": "113.65713"
  },
  {
    "country": "AU",
    "name": "Capel",
    "lat": "-33.55808",
    "lng": "115.56278"
  },
  {
    "country": "AU",
    "name": "Cannington",
    "lat": "-32.01667",
    "lng": "115.95"
  },
  {
    "country": "AU",
    "name": "Campbelltown",
    "lat": "-34.88333",
    "lng": "138.66667"
  },
  {
    "country": "AU",
    "name": "Callington",
    "lat": "-35.11977",
    "lng": "139.0414"
  },
  {
    "country": "AU",
    "name": "Byford",
    "lat": "-32.22099",
    "lng": "116.009"
  },
  {
    "country": "AU",
    "name": "Busselton",
    "lat": "-33.65249",
    "lng": "115.3455"
  },
  {
    "country": "AU",
    "name": "Bunbury",
    "lat": "-33.32711",
    "lng": "115.64137"
  },
  {
    "country": "AU",
    "name": "Bullsbrook",
    "lat": "-31.66905",
    "lng": "115.9999"
  },
  {
    "country": "AU",
    "name": "Broome",
    "lat": "-17.95538",
    "lng": "122.23922"
  },
  {
    "country": "AU",
    "name": "Brighton",
    "lat": "-35.0182",
    "lng": "138.52351"
  },
  {
    "country": "AU",
    "name": "Bridgewater",
    "lat": "-35",
    "lng": "138.75"
  },
  {
    "country": "AU",
    "name": "Bridgetown",
    "lat": "-33.96242",
    "lng": "116.13598"
  },
  {
    "country": "AU",
    "name": "Boyup Brook",
    "lat": "-33.83425",
    "lng": "116.38776"
  },
  {
    "country": "AU",
    "name": "Boyanup",
    "lat": "-33.48295",
    "lng": "115.72838"
  },
  {
    "country": "AU",
    "name": "Boulder",
    "lat": "-30.78204",
    "lng": "121.4912"
  },
  {
    "country": "AU",
    "name": "Blackwood",
    "lat": "-35.02139",
    "lng": "138.61429"
  },
  {
    "country": "AU",
    "name": "Birkenhead",
    "lat": "-34.83685",
    "lng": "138.49788"
  },
  {
    "country": "AU",
    "name": "Birdwood",
    "lat": "-34.81826",
    "lng": "138.96478"
  },
  {
    "country": "AU",
    "name": "Beverley",
    "lat": "-32.10839",
    "lng": "116.92736"
  },
  {
    "country": "AU",
    "name": "Bentley",
    "lat": "-32",
    "lng": "115.91667"
  },
  {
    "country": "AU",
    "name": "Bellevue",
    "lat": "-31.9",
    "lng": "116.01667"
  },
  {
    "country": "AU",
    "name": "Belair",
    "lat": "-34.99766",
    "lng": "138.62077"
  },
  {
    "country": "AU",
    "name": "Bedford Park",
    "lat": "-35.03333",
    "lng": "138.56667"
  },
  {
    "country": "AU",
    "name": "Bedfordale",
    "lat": "-32.17406",
    "lng": "116.0504"
  },
  {
    "country": "AU",
    "name": "Beaumont",
    "lat": "-34.94899",
    "lng": "138.66188"
  },
  {
    "country": "AU",
    "name": "Bassendean",
    "lat": "-31.90906",
    "lng": "115.9437"
  },
  {
    "country": "AU",
    "name": "Balhannah",
    "lat": "-34.99094",
    "lng": "138.82565"
  },
  {
    "country": "AU",
    "name": "Balaklava",
    "lat": "-34.14542",
    "lng": "138.41148"
  },
  {
    "country": "AU",
    "name": "Australind",
    "lat": "-33.2792",
    "lng": "115.71504"
  },
  {
    "country": "AU",
    "name": "Augusta",
    "lat": "-34.31566",
    "lng": "115.15922"
  },
  {
    "country": "AU",
    "name": "Armadale",
    "lat": "-32.14607",
    "lng": "116.0093"
  },
  {
    "country": "AU",
    "name": "Ardrossan",
    "lat": "-34.42217",
    "lng": "137.91907"
  },
  {
    "country": "AU",
    "name": "Applecross",
    "lat": "-32.01667",
    "lng": "115.83333"
  },
  {
    "country": "AU",
    "name": "Angle Vale",
    "lat": "-34.64098",
    "lng": "138.6461"
  },
  {
    "country": "AU",
    "name": "Angaston",
    "lat": "-34.50129",
    "lng": "139.04625"
  },
  {
    "country": "AU",
    "name": "Alice Springs",
    "lat": "-23.69748",
    "lng": "133.88362"
  },
  {
    "country": "AU",
    "name": "Aldinga",
    "lat": "-35.28333",
    "lng": "138.48333"
  },
  {
    "country": "AU",
    "name": "Aldgate",
    "lat": "-35.01667",
    "lng": "138.73333"
  },
  {
    "country": "AU",
    "name": "Albany",
    "lat": "-35.02692",
    "lng": "117.88369"
  },
  {
    "country": "AU",
    "name": "Adelaide",
    "lat": "-34.92866",
    "lng": "138.59863"
  },
  {
    "country": "AU",
    "name": "Dunsborough",
    "lat": "-33.61512",
    "lng": "115.10561"
  },
  {
    "country": "AU",
    "name": "Eaton",
    "lat": "-33.31664",
    "lng": "115.70503"
  },
  {
    "country": "AU",
    "name": "Seacliff",
    "lat": "-35.03474",
    "lng": "138.52288"
  },
  {
    "country": "AU",
    "name": "Clapham",
    "lat": "-34.98989",
    "lng": "138.60158"
  },
  {
    "country": "AU",
    "name": "Two Rocks",
    "lat": "-31.49985",
    "lng": "115.58737"
  },
  {
    "country": "AU",
    "name": "Quinns Rocks",
    "lat": "-31.67379",
    "lng": "115.70372"
  },
  {
    "country": "AU",
    "name": "East Fremantle",
    "lat": "-32.03823",
    "lng": "115.7676"
  },
  {
    "country": "AU",
    "name": "Peppermint Grove",
    "lat": "-31.99878",
    "lng": "115.7682"
  },
  {
    "country": "AU",
    "name": "Claremont",
    "lat": "-31.97961",
    "lng": "115.7823"
  },
  {
    "country": "AU",
    "name": "Bicton",
    "lat": "-32.02778",
    "lng": "115.78333"
  },
  {
    "country": "AU",
    "name": "Attadale",
    "lat": "-32.02489",
    "lng": "115.802"
  },
  {
    "country": "AU",
    "name": "Shenton Park",
    "lat": "-31.95833",
    "lng": "115.79722"
  },
  {
    "country": "AU",
    "name": "Dalkeith",
    "lat": "-31.99517",
    "lng": "115.7998"
  },
  {
    "country": "AU",
    "name": "Jurien Bay",
    "lat": "-30.30591",
    "lng": "115.03825"
  },
  {
    "country": "AU",
    "name": "Warnbro",
    "lat": "-32.34017",
    "lng": "115.7473"
  },
  {
    "country": "AU",
    "name": "Mullaloo",
    "lat": "-31.77896",
    "lng": "115.73676"
  },
  {
    "country": "AU",
    "name": "Alyangula",
    "lat": "-13.85413",
    "lng": "136.42129"
  },
  {
    "country": "AU",
    "name": "Stuart Park",
    "lat": "-12.4486",
    "lng": "130.84249"
  },
  {
    "country": "AU",
    "name": "Larrakeyah",
    "lat": "-12.45527",
    "lng": "130.83172"
  },
  {
    "country": "AU",
    "name": "Leanyer",
    "lat": "-12.36667",
    "lng": "130.9"
  },
  {
    "country": "AU",
    "name": "Ludmilla",
    "lat": "-12.42032",
    "lng": "130.85506"
  },
  {
    "country": "AU",
    "name": "Fannie Bay",
    "lat": "-12.42275",
    "lng": "130.83627"
  },
  {
    "country": "AU",
    "name": "Nightcliff",
    "lat": "-12.38299",
    "lng": "130.8517"
  },
  {
    "country": "AU",
    "name": "Glen Iris",
    "lat": "-33.33713",
    "lng": "115.6743"
  },
  {
    "country": "AU",
    "name": "Lower King",
    "lat": "-34.95778",
    "lng": "117.93833"
  },
  {
    "country": "AU",
    "name": "Young",
    "lat": "-34.3135",
    "lng": "148.30107"
  },
  {
    "country": "AU",
    "name": "Yeppoon",
    "lat": "-23.12683",
    "lng": "150.74406"
  },
  {
    "country": "AU",
    "name": "Yatala",
    "lat": "-27.71667",
    "lng": "153.21667"
  },
  {
    "country": "AU",
    "name": "Yass",
    "lat": "-34.84036",
    "lng": "148.90987"
  },
  {
    "country": "AU",
    "name": "Yarrawonga",
    "lat": "-36.01923",
    "lng": "145.99973"
  },
  {
    "country": "AU",
    "name": "Yarraville",
    "lat": "-37.81667",
    "lng": "144.9"
  },
  {
    "country": "AU",
    "name": "Yarraman",
    "lat": "-26.84167",
    "lng": "151.98138"
  },
  {
    "country": "AU",
    "name": "Yarra Junction",
    "lat": "-37.78192",
    "lng": "145.6143"
  },
  {
    "country": "AU",
    "name": "Yarra Glen",
    "lat": "-37.65794",
    "lng": "145.37416"
  },
  {
    "country": "AU",
    "name": "Yandina",
    "lat": "-26.56165",
    "lng": "152.95595"
  },
  {
    "country": "AU",
    "name": "Wynyard",
    "lat": "-40.9897",
    "lng": "145.72617"
  },
  {
    "country": "AU",
    "name": "Wynnum",
    "lat": "-27.44527",
    "lng": "153.15813"
  },
  {
    "country": "AU",
    "name": "Worrolong",
    "lat": "-37.80619",
    "lng": "140.84803"
  },
  {
    "country": "AU",
    "name": "Woree",
    "lat": "-16.95",
    "lng": "145.75"
  },
  {
    "country": "AU",
    "name": "Woori Yallock",
    "lat": "-37.78062",
    "lng": "145.53819"
  },
  {
    "country": "AU",
    "name": "Woorim",
    "lat": "-27.06931",
    "lng": "153.20427"
  },
  {
    "country": "AU",
    "name": "Woombye",
    "lat": "-26.66054",
    "lng": "152.96947"
  },
  {
    "country": "AU",
    "name": "Woolgoolga",
    "lat": "-30.11058",
    "lng": "153.20067"
  },
  {
    "country": "AU",
    "name": "Woodridge",
    "lat": "-27.63333",
    "lng": "153.1"
  },
  {
    "country": "AU",
    "name": "Woodford",
    "lat": "-26.95291",
    "lng": "152.77747"
  },
  {
    "country": "AU",
    "name": "Wondai",
    "lat": "-26.3177",
    "lng": "151.87242"
  },
  {
    "country": "AU",
    "name": "Wodonga",
    "lat": "-36.12179",
    "lng": "146.88809"
  },
  {
    "country": "AU",
    "name": "Windsor",
    "lat": "-37.85344",
    "lng": "144.99241"
  },
  {
    "country": "AU",
    "name": "Windaroo",
    "lat": "-27.73333",
    "lng": "153.2"
  },
  {
    "country": "AU",
    "name": "Williamstown",
    "lat": "-37.86349",
    "lng": "144.899"
  },
  {
    "country": "AU",
    "name": "Whittlesea",
    "lat": "-37.51152",
    "lng": "145.11836"
  },
  {
    "country": "AU",
    "name": "Wheelers Hill",
    "lat": "-37.9",
    "lng": "145.18333"
  },
  {
    "country": "AU",
    "name": "West Wyalong",
    "lat": "-33.92373",
    "lng": "147.20473"
  },
  {
    "country": "AU",
    "name": "Westmead",
    "lat": "-33.80383",
    "lng": "150.98768"
  },
  {
    "country": "AU",
    "name": "Westcourt",
    "lat": "-26.8",
    "lng": "150.15"
  },
  {
    "country": "AU",
    "name": "Westbury",
    "lat": "-41.52914",
    "lng": "146.83914"
  },
  {
    "country": "AU",
    "name": "Westbrook",
    "lat": "-27.61667",
    "lng": "151.86667"
  },
  {
    "country": "AU",
    "name": "Werribee",
    "lat": "-37.9",
    "lng": "144.66667"
  },
  {
    "country": "AU",
    "name": "Wellington Point",
    "lat": "-27.48333",
    "lng": "153.25"
  },
  {
    "country": "AU",
    "name": "Wellington",
    "lat": "-32.55588",
    "lng": "148.94508"
  },
  {
    "country": "AU",
    "name": "Weipa",
    "lat": "-12.62346",
    "lng": "141.87883"
  },
  {
    "country": "AU",
    "name": "Wattleglen",
    "lat": "-37.66667",
    "lng": "145.18333"
  },
  {
    "country": "AU",
    "name": "Watsonia",
    "lat": "-37.71667",
    "lng": "145.08333"
  },
  {
    "country": "AU",
    "name": "Warwick",
    "lat": "-28.21901",
    "lng": "152.03438"
  },
  {
    "country": "AU",
    "name": "Warrnambool",
    "lat": "-38.38176",
    "lng": "142.48799"
  },
  {
    "country": "AU",
    "name": "Warrane",
    "lat": "-42.85546",
    "lng": "147.38297"
  },
  {
    "country": "AU",
    "name": "Warrandyte",
    "lat": "-37.75",
    "lng": "145.23333"
  },
  {
    "country": "AU",
    "name": "Warragul",
    "lat": "-38.15912",
    "lng": "145.93118"
  },
  {
    "country": "AU",
    "name": "Wantirna South",
    "lat": "-37.88333",
    "lng": "145.21667"
  },
  {
    "country": "AU",
    "name": "Wantirna",
    "lat": "-37.85",
    "lng": "145.21667"
  },
  {
    "country": "AU",
    "name": "Wangaratta",
    "lat": "-36.35846",
    "lng": "146.32056"
  },
  {
    "country": "AU",
    "name": "Walkerston",
    "lat": "-21.16097",
    "lng": "149.05814"
  },
  {
    "country": "AU",
    "name": "Wahroonga",
    "lat": "-33.71816",
    "lng": "151.11561"
  },
  {
    "country": "AU",
    "name": "Wagga Wagga",
    "lat": "-35.12577",
    "lng": "147.35375"
  },
  {
    "country": "AU",
    "name": "Wacol",
    "lat": "-27.58333",
    "lng": "152.93333"
  },
  {
    "country": "AU",
    "name": "Victoria Point",
    "lat": "-27.58329",
    "lng": "153.31172"
  },
  {
    "country": "AU",
    "name": "Vermont",
    "lat": "-37.83616",
    "lng": "145.19428"
  },
  {
    "country": "AU",
    "name": "Urraween",
    "lat": "-25.29522",
    "lng": "152.82206"
  },
  {
    "country": "AU",
    "name": "Urangan",
    "lat": "-25.29214",
    "lng": "152.90535"
  },
  {
    "country": "AU",
    "name": "Upwey",
    "lat": "-37.9",
    "lng": "145.33333"
  },
  {
    "country": "AU",
    "name": "Upper Coomera",
    "lat": "-27.9",
    "lng": "153.3"
  },
  {
    "country": "AU",
    "name": "Ulverstone",
    "lat": "-41.16026",
    "lng": "146.18242"
  },
  {
    "country": "AU",
    "name": "Ulladulla",
    "lat": "-35.35906",
    "lng": "150.47247"
  },
  {
    "country": "AU",
    "name": "Tyabb",
    "lat": "-38.25",
    "lng": "145.18333"
  },
  {
    "country": "AU",
    "name": "Tumut",
    "lat": "-35.30642",
    "lng": "148.21818"
  },
  {
    "country": "AU",
    "name": "Tumbi Vmbi",
    "lat": "-33.36667",
    "lng": "151.45"
  },
  {
    "country": "AU",
    "name": "Tullamarine",
    "lat": "-37.70128",
    "lng": "144.881"
  },
  {
    "country": "AU",
    "name": "Tugun",
    "lat": "-28.15",
    "lng": "153.5"
  },
  {
    "country": "AU",
    "name": "Truganina",
    "lat": "-37.81667",
    "lng": "144.75"
  },
  {
    "country": "AU",
    "name": "Trinity Beach",
    "lat": "-16.78876",
    "lng": "145.69682"
  },
  {
    "country": "AU",
    "name": "Tremont",
    "lat": "-37.9",
    "lng": "145.33333"
  },
  {
    "country": "AU",
    "name": "Traralgon",
    "lat": "-38.19528",
    "lng": "146.5415"
  },
  {
    "country": "AU",
    "name": "Townsville",
    "lat": "-19.26639",
    "lng": "146.80569"
  },
  {
    "country": "AU",
    "name": "Torquay",
    "lat": "-25.28496",
    "lng": "152.87886"
  },
  {
    "country": "AU",
    "name": "Toowoomba",
    "lat": "-27.56056",
    "lng": "151.95386"
  },
  {
    "country": "AU",
    "name": "Toorak",
    "lat": "-37.84165",
    "lng": "145.01438"
  },
  {
    "country": "AU",
    "name": "Tooradin",
    "lat": "-38.21475",
    "lng": "145.38325"
  },
  {
    "country": "AU",
    "name": "Toongabbie",
    "lat": "-33.78333",
    "lng": "150.95"
  },
  {
    "country": "AU",
    "name": "Toolooa",
    "lat": "-23.88505",
    "lng": "151.26783"
  },
  {
    "country": "AU",
    "name": "Tolga",
    "lat": "-17.23333",
    "lng": "145.48333"
  },
  {
    "country": "AU",
    "name": "Tin Can Bay",
    "lat": "-25.91914",
    "lng": "153.0032"
  },
  {
    "country": "AU",
    "name": "Thornbury",
    "lat": "-37.75",
    "lng": "145"
  },
  {
    "country": "AU",
    "name": "Thomastown",
    "lat": "-37.68333",
    "lng": "145.01667"
  },
  {
    "country": "AU",
    "name": "The Entrance",
    "lat": "-33.33876",
    "lng": "151.4978"
  },
  {
    "country": "AU",
    "name": "The Basin",
    "lat": "-37.85",
    "lng": "145.31667"
  },
  {
    "country": "AU",
    "name": "Thagoona",
    "lat": "-27.63333",
    "lng": "152.63333"
  },
  {
    "country": "AU",
    "name": "Thabeban",
    "lat": "-24.9",
    "lng": "152.35"
  },
  {
    "country": "AU",
    "name": "Tewantin",
    "lat": "-26.39104",
    "lng": "153.03432"
  },
  {
    "country": "AU",
    "name": "Templestowe Lower",
    "lat": "-37.76667",
    "lng": "145.11667"
  },
  {
    "country": "AU",
    "name": "Tarragindi",
    "lat": "-27.53333",
    "lng": "153.03333"
  },
  {
    "country": "AU",
    "name": "Taroona",
    "lat": "-42.9452",
    "lng": "147.3484"
  },
  {
    "country": "AU",
    "name": "Taroom",
    "lat": "-25.63925",
    "lng": "149.7998"
  },
  {
    "country": "AU",
    "name": "Tarneit",
    "lat": "-37.86667",
    "lng": "144.66667"
  },
  {
    "country": "AU",
    "name": "Taree",
    "lat": "-31.91099",
    "lng": "152.45387"
  },
  {
    "country": "AU",
    "name": "Tamworth",
    "lat": "-31.09048",
    "lng": "150.92905"
  },
  {
    "country": "AU",
    "name": "Tallebudgera",
    "lat": "-28.15",
    "lng": "153.43333"
  },
  {
    "country": "AU",
    "name": "Sydney",
    "lat": "-33.86785",
    "lng": "151.20732"
  },
  {
    "country": "AU",
    "name": "Sydenham",
    "lat": "-37.7",
    "lng": "144.76667"
  },
  {
    "country": "AU",
    "name": "Swan Hill",
    "lat": "-35.33781",
    "lng": "143.5544"
  },
  {
    "country": "AU",
    "name": "Surrey Hills",
    "lat": "-37.81667",
    "lng": "145.1"
  },
  {
    "country": "AU",
    "name": "Surfers Paradise",
    "lat": "-28.00274",
    "lng": "153.42999"
  },
  {
    "country": "AU",
    "name": "Sunnybank",
    "lat": "-27.58333",
    "lng": "153.05"
  },
  {
    "country": "AU",
    "name": "Sunbury",
    "lat": "-37.57742",
    "lng": "144.72607"
  },
  {
    "country": "AU",
    "name": "Strathpine",
    "lat": "-27.30414",
    "lng": "152.98977"
  },
  {
    "country": "AU",
    "name": "Strathfield",
    "lat": "-33.88096",
    "lng": "151.07986"
  },
  {
    "country": "AU",
    "name": "Port Stephens",
    "lat": "-32.71314",
    "lng": "152.06623"
  },
  {
    "country": "AU",
    "name": "Stawell",
    "lat": "-37.05632",
    "lng": "142.78088"
  },
  {
    "country": "AU",
    "name": "Stanthorpe",
    "lat": "-28.65425",
    "lng": "151.93388"
  },
  {
    "country": "AU",
    "name": "Springvale South",
    "lat": "-37.96667",
    "lng": "145.15"
  },
  {
    "country": "AU",
    "name": "Springvale",
    "lat": "-37.94853",
    "lng": "145.15274"
  },
  {
    "country": "AU",
    "name": "Spring Hill",
    "lat": "-27.46141",
    "lng": "153.02311"
  },
  {
    "country": "AU",
    "name": "Spotswood",
    "lat": "-37.82975",
    "lng": "144.88516"
  },
  {
    "country": "AU",
    "name": "Werribee South",
    "lat": "-37.9475",
    "lng": "144.71667"
  },
  {
    "country": "AU",
    "name": "Southport",
    "lat": "-27.96724",
    "lng": "153.39796"
  },
  {
    "country": "AU",
    "name": "South Melbourne",
    "lat": "-37.83333",
    "lng": "144.96667"
  },
  {
    "country": "AU",
    "name": "South Grafton",
    "lat": "-29.7076",
    "lng": "152.92627"
  },
  {
    "country": "AU",
    "name": "Sorrento",
    "lat": "-38.33958",
    "lng": "144.74126"
  },
  {
    "country": "AU",
    "name": "Sorell",
    "lat": "-42.78161",
    "lng": "147.56267"
  },
  {
    "country": "AU",
    "name": "Somerville",
    "lat": "-38.21667",
    "lng": "145.16667"
  },
  {
    "country": "AU",
    "name": "Somers",
    "lat": "-38.4",
    "lng": "145.16667"
  },
  {
    "country": "AU",
    "name": "Smithton",
    "lat": "-40.84587",
    "lng": "145.12498"
  },
  {
    "country": "AU",
    "name": "Slacks Creek",
    "lat": "-27.65",
    "lng": "153.15"
  },
  {
    "country": "AU",
    "name": "Singleton",
    "lat": "-32.56742",
    "lng": "151.16603"
  },
  {
    "country": "AU",
    "name": "Shorncliffe",
    "lat": "-27.32759",
    "lng": "153.08161"
  },
  {
    "country": "AU",
    "name": "Shepparton",
    "lat": "-36.38047",
    "lng": "145.39867"
  },
  {
    "country": "AU",
    "name": "Shellharbour Village",
    "lat": "-34.58333",
    "lng": "150.86667"
  },
  {
    "country": "AU",
    "name": "Sheffield",
    "lat": "-41.39947",
    "lng": "146.33897"
  },
  {
    "country": "AU",
    "name": "Sharon",
    "lat": "-24.87593",
    "lng": "152.26994"
  },
  {
    "country": "AU",
    "name": "Selby",
    "lat": "-37.91667",
    "lng": "145.38333"
  },
  {
    "country": "AU",
    "name": "Sebastopol",
    "lat": "-37.58532",
    "lng": "143.83953"
  },
  {
    "country": "AU",
    "name": "Seaford",
    "lat": "-38.1",
    "lng": "145.13333"
  },
  {
    "country": "AU",
    "name": "Scottsdale",
    "lat": "-41.1578",
    "lng": "147.51727"
  },
  {
    "country": "AU",
    "name": "Scoresby",
    "lat": "-37.9",
    "lng": "145.23333"
  },
  {
    "country": "AU",
    "name": "Scarness",
    "lat": "-25.28405",
    "lng": "152.856"
  },
  {
    "country": "AU",
    "name": "Sawtell",
    "lat": "-30.36459",
    "lng": "153.10141"
  },
  {
    "country": "AU",
    "name": "Sarina",
    "lat": "-21.4191",
    "lng": "149.21677"
  },
  {
    "country": "AU",
    "name": "Sandgate",
    "lat": "-27.32198",
    "lng": "153.06951"
  },
  {
    "country": "AU",
    "name": "Sandford",
    "lat": "-42.93333",
    "lng": "147.5"
  },
  {
    "country": "AU",
    "name": "Sale",
    "lat": "-38.11095",
    "lng": "147.06802"
  },
  {
    "country": "AU",
    "name": "Saint Kilda",
    "lat": "-37.8676",
    "lng": "144.98099"
  },
  {
    "country": "AU",
    "name": "St Helens",
    "lat": "-41.32028",
    "lng": "148.23889"
  },
  {
    "country": "AU",
    "name": "Saint Helena",
    "lat": "-37.7",
    "lng": "145.13333"
  },
  {
    "country": "AU",
    "name": "Saint Andrews",
    "lat": "-37.60151",
    "lng": "145.27235"
  },
  {
    "country": "AU",
    "name": "Saint Albans",
    "lat": "-37.73333",
    "lng": "144.8"
  },
  {
    "country": "AU",
    "name": "Rye",
    "lat": "-38.36667",
    "lng": "144.81667"
  },
  {
    "country": "AU",
    "name": "Rutherford",
    "lat": "-32.71667",
    "lng": "151.53333"
  },
  {
    "country": "AU",
    "name": "Rowville",
    "lat": "-37.93333",
    "lng": "145.23333"
  },
  {
    "country": "AU",
    "name": "Rosebud",
    "lat": "-38.35542",
    "lng": "144.9068"
  },
  {
    "country": "AU",
    "name": "Rosebery",
    "lat": "-41.77941",
    "lng": "145.53825"
  },
  {
    "country": "AU",
    "name": "Rosanna",
    "lat": "-37.75",
    "lng": "145.06667"
  },
  {
    "country": "AU",
    "name": "Roma",
    "lat": "-26.56741",
    "lng": "148.78751"
  },
  {
    "country": "AU",
    "name": "Rokeby",
    "lat": "-42.89875",
    "lng": "147.44917"
  },
  {
    "country": "AU",
    "name": "Rocklea",
    "lat": "-27.53917",
    "lng": "153.00402"
  },
  {
    "country": "AU",
    "name": "Rockhampton",
    "lat": "-23.38032",
    "lng": "150.50595"
  },
  {
    "country": "AU",
    "name": "Rockbank",
    "lat": "-37.73353",
    "lng": "144.67003"
  },
  {
    "country": "AU",
    "name": "Riverview",
    "lat": "-27.6",
    "lng": "152.85"
  },
  {
    "country": "AU",
    "name": "Riverstone",
    "lat": "-33.68333",
    "lng": "150.86667"
  },
  {
    "country": "AU",
    "name": "Ripponlea",
    "lat": "-37.88333",
    "lng": "145"
  },
  {
    "country": "AU",
    "name": "Ringwood East",
    "lat": "-37.81667",
    "lng": "145.25"
  },
  {
    "country": "AU",
    "name": "Richmond",
    "lat": "-37.81819",
    "lng": "145.00176"
  },
  {
    "country": "AU",
    "name": "Richmond",
    "lat": "-33.59956",
    "lng": "150.75142"
  },
  {
    "country": "AU",
    "name": "Rhodes",
    "lat": "-33.82663",
    "lng": "151.0881"
  },
  {
    "country": "AU",
    "name": "Revesby",
    "lat": "-33.95",
    "lng": "151.01667"
  },
  {
    "country": "AU",
    "name": "Reservoir",
    "lat": "-37.71667",
    "lng": "145"
  },
  {
    "country": "AU",
    "name": "Research",
    "lat": "-37.7",
    "lng": "145.18333"
  },
  {
    "country": "AU",
    "name": "Renmark West",
    "lat": "-34.16531",
    "lng": "140.7097"
  },
  {
    "country": "AU",
    "name": "Renmark",
    "lat": "-34.17702",
    "lng": "140.74697"
  },
  {
    "country": "AU",
    "name": "Regents Park",
    "lat": "-33.88333",
    "lng": "151.01667"
  },
  {
    "country": "AU",
    "name": "Redlynch",
    "lat": "-16.88333",
    "lng": "145.7"
  },
  {
    "country": "AU",
    "name": "Redland Bay",
    "lat": "-27.6113",
    "lng": "153.30022"
  },
  {
    "country": "AU",
    "name": "Red Hill",
    "lat": "-20.31667",
    "lng": "148.5"
  },
  {
    "country": "AU",
    "name": "Redhead",
    "lat": "-33.01178",
    "lng": "151.71142"
  },
  {
    "country": "AU",
    "name": "Redfern",
    "lat": "-33.89279",
    "lng": "151.20415"
  },
  {
    "country": "AU",
    "name": "Redbank",
    "lat": "-27.6",
    "lng": "152.86667"
  },
  {
    "country": "AU",
    "name": "Raworth",
    "lat": "-32.73333",
    "lng": "151.61667"
  },
  {
    "country": "AU",
    "name": "Ravenshoe",
    "lat": "-17.60901",
    "lng": "145.48413"
  },
  {
    "country": "AU",
    "name": "Rathmines",
    "lat": "-33.03773",
    "lng": "151.58443"
  },
  {
    "country": "AU",
    "name": "Quirindi",
    "lat": "-31.50763",
    "lng": "150.67902"
  },
  {
    "country": "AU",
    "name": "Queenstown",
    "lat": "-42.0805",
    "lng": "145.55646"
  },
  {
    "country": "AU",
    "name": "Queenscliff",
    "lat": "-38.26789",
    "lng": "144.66193"
  },
  {
    "country": "AU",
    "name": "Queanbeyan",
    "lat": "-35.35493",
    "lng": "149.232"
  },
  {
    "country": "AU",
    "name": "Quakers Hill",
    "lat": "-33.73333",
    "lng": "150.88333"
  },
  {
    "country": "AU",
    "name": "Pymble",
    "lat": "-33.74386",
    "lng": "151.14188"
  },
  {
    "country": "AU",
    "name": "Proserpine",
    "lat": "-20.4011",
    "lng": "148.5802"
  },
  {
    "country": "AU",
    "name": "Preston",
    "lat": "-37.75",
    "lng": "145.01667"
  },
  {
    "country": "AU",
    "name": "Port Sorell",
    "lat": "-41.16652",
    "lng": "146.55283"
  },
  {
    "country": "AU",
    "name": "Port Melbourne",
    "lat": "-37.83961",
    "lng": "144.94228"
  },
  {
    "country": "AU",
    "name": "Port Macquarie",
    "lat": "-31.43084",
    "lng": "152.90894"
  },
  {
    "country": "AU",
    "name": "Portland",
    "lat": "-38.3462",
    "lng": "141.60257"
  },
  {
    "country": "AU",
    "name": "Portland",
    "lat": "-33.35709",
    "lng": "149.98148"
  },
  {
    "country": "AU",
    "name": "Port Kembla",
    "lat": "-34.4818",
    "lng": "150.9012"
  },
  {
    "country": "AU",
    "name": "Port Fairy",
    "lat": "-38.38535",
    "lng": "142.2371"
  },
  {
    "country": "AU",
    "name": "Port Douglas",
    "lat": "-16.48383",
    "lng": "145.46725"
  },
  {
    "country": "AU",
    "name": "Point Cook",
    "lat": "-37.91482",
    "lng": "144.75088"
  },
  {
    "country": "AU",
    "name": "Point Clare",
    "lat": "-33.44378",
    "lng": "151.32732"
  },
  {
    "country": "AU",
    "name": "Plenty",
    "lat": "-37.66667",
    "lng": "145.11667"
  },
  {
    "country": "AU",
    "name": "Pitt Town",
    "lat": "-33.58718",
    "lng": "150.85857"
  },
  {
    "country": "AU",
    "name": "Picton",
    "lat": "-34.16995",
    "lng": "150.61168"
  },
  {
    "country": "AU",
    "name": "Phillip",
    "lat": "-31.13333",
    "lng": "150.85"
  },
  {
    "country": "AU",
    "name": "Perthville",
    "lat": "-33.48741",
    "lng": "149.54642"
  },
  {
    "country": "AU",
    "name": "Perth",
    "lat": "-41.57231",
    "lng": "147.17096"
  },
  {
    "country": "AU",
    "name": "Penshurst",
    "lat": "-33.96667",
    "lng": "151.08333"
  },
  {
    "country": "AU",
    "name": "Penrith",
    "lat": "-33.75",
    "lng": "150.7"
  },
  {
    "country": "AU",
    "name": "Penola",
    "lat": "-37.3752",
    "lng": "140.83678"
  },
  {
    "country": "AU",
    "name": "Pennant Hills",
    "lat": "-33.73783",
    "lng": "151.07216"
  },
  {
    "country": "AU",
    "name": "Penguin",
    "lat": "-41.12258",
    "lng": "146.07318"
  },
  {
    "country": "AU",
    "name": "Peak Hill",
    "lat": "-32.72387",
    "lng": "148.19052"
  },
  {
    "country": "AU",
    "name": "Pascoe Vale",
    "lat": "-37.73333",
    "lng": "144.93333"
  },
  {
    "country": "AU",
    "name": "Parkville",
    "lat": "-37.78333",
    "lng": "144.95"
  },
  {
    "country": "AU",
    "name": "Parkes",
    "lat": "-33.1372",
    "lng": "148.1759"
  },
  {
    "country": "AU",
    "name": "Parkdale",
    "lat": "-37.98333",
    "lng": "145.06667"
  },
  {
    "country": "AU",
    "name": "Palm Beach",
    "lat": "-33.59664",
    "lng": "151.32384"
  },
  {
    "country": "AU",
    "name": "Palm Beach",
    "lat": "-28.11694",
    "lng": "153.46584"
  },
  {
    "country": "AU",
    "name": "Pakenham Upper",
    "lat": "-38.01667",
    "lng": "145.51667"
  },
  {
    "country": "AU",
    "name": "Pakenham South",
    "lat": "-38.13333",
    "lng": "145.51667"
  },
  {
    "country": "AU",
    "name": "Ouyen",
    "lat": "-35.07087",
    "lng": "142.32034"
  },
  {
    "country": "AU",
    "name": "Ormond",
    "lat": "-37.9",
    "lng": "145.03333"
  },
  {
    "country": "AU",
    "name": "Orange",
    "lat": "-33.28397",
    "lng": "149.10018"
  },
  {
    "country": "AU",
    "name": "One Mile",
    "lat": "-27.62902",
    "lng": "152.73768"
  },
  {
    "country": "AU",
    "name": "Olinda",
    "lat": "-37.85",
    "lng": "145.36667"
  },
  {
    "country": "AU",
    "name": "Old Beach",
    "lat": "-42.77758",
    "lng": "147.26659"
  },
  {
    "country": "AU",
    "name": "Old Bar",
    "lat": "-31.9694",
    "lng": "152.58807"
  },
  {
    "country": "AU",
    "name": "Officer",
    "lat": "-38.05916",
    "lng": "145.40947"
  },
  {
    "country": "AU",
    "name": "Oberon",
    "lat": "-33.70398",
    "lng": "149.85915"
  },
  {
    "country": "AU",
    "name": "Oatley",
    "lat": "-33.98004",
    "lng": "151.07201"
  },
  {
    "country": "AU",
    "name": "Oakey",
    "lat": "-27.43305",
    "lng": "151.72063"
  },
  {
    "country": "AU",
    "name": "Oakdale",
    "lat": "-34.0793",
    "lng": "150.5132"
  },
  {
    "country": "AU",
    "name": "Nyngan",
    "lat": "-31.56375",
    "lng": "147.19373"
  },
  {
    "country": "AU",
    "name": "Nunawading",
    "lat": "-37.82043",
    "lng": "145.17308"
  },
  {
    "country": "AU",
    "name": "Nowra",
    "lat": "-34.88422",
    "lng": "150.60036"
  },
  {
    "country": "AU",
    "name": "Notting Hill",
    "lat": "-37.905",
    "lng": "145.1427"
  },
  {
    "country": "AU",
    "name": "North Wonthaggi",
    "lat": "-38.6",
    "lng": "145.6"
  },
  {
    "country": "AU",
    "name": "North Turramurra",
    "lat": "-33.71313",
    "lng": "151.14638"
  },
  {
    "country": "AU",
    "name": "North Sydney",
    "lat": "-33.839",
    "lng": "151.2072"
  },
  {
    "country": "AU",
    "name": "North Melbourne",
    "lat": "-37.79798",
    "lng": "144.94512"
  },
  {
    "country": "AU",
    "name": "Northmead",
    "lat": "-33.78333",
    "lng": "150.98333"
  },
  {
    "country": "AU",
    "name": "North Haven",
    "lat": "-31.6368",
    "lng": "152.81357"
  },
  {
    "country": "AU",
    "name": "North Fitzroy",
    "lat": "-37.78862",
    "lng": "144.97885"
  },
  {
    "country": "AU",
    "name": "Northcote",
    "lat": "-37.76667",
    "lng": "145"
  },
  {
    "country": "AU",
    "name": "Normanhurst",
    "lat": "-33.73333",
    "lng": "151.1"
  },
  {
    "country": "AU",
    "name": "Noosaville",
    "lat": "-26.4",
    "lng": "153.06667"
  },
  {
    "country": "AU",
    "name": "Noosa Heads",
    "lat": "-26.39433",
    "lng": "153.0901"
  },
  {
    "country": "AU",
    "name": "Noble Park",
    "lat": "-37.96667",
    "lng": "145.16667"
  },
  {
    "country": "AU",
    "name": "Nimbin",
    "lat": "-28.59545",
    "lng": "153.22336"
  },
  {
    "country": "AU",
    "name": "Newtown",
    "lat": "-33.89835",
    "lng": "151.17754"
  },
  {
    "country": "AU",
    "name": "Newstead",
    "lat": "-41.43333",
    "lng": "147.16667"
  },
  {
    "country": "AU",
    "name": "Newport",
    "lat": "-37.84427",
    "lng": "144.88483"
  },
  {
    "country": "AU",
    "name": "Newport",
    "lat": "-33.65639",
    "lng": "151.31401"
  },
  {
    "country": "AU",
    "name": "New Norfolk",
    "lat": "-42.78261",
    "lng": "147.0587"
  },
  {
    "country": "AU",
    "name": "Newnham",
    "lat": "-41.39714",
    "lng": "147.13127"
  },
  {
    "country": "AU",
    "name": "Newington",
    "lat": "-37.55846",
    "lng": "143.82485"
  },
  {
    "country": "AU",
    "name": "Newcastle",
    "lat": "-32.92715",
    "lng": "151.77647"
  },
  {
    "country": "AU",
    "name": "Nerang",
    "lat": "-27.98941",
    "lng": "153.33633"
  },
  {
    "country": "AU",
    "name": "Nelson Bay",
    "lat": "-32.72043",
    "lng": "152.14398"
  },
  {
    "country": "AU",
    "name": "Narromine",
    "lat": "-32.23121",
    "lng": "148.24052"
  },
  {
    "country": "AU",
    "name": "Narre Warren North",
    "lat": "-37.98333",
    "lng": "145.31667"
  },
  {
    "country": "AU",
    "name": "Narre Warren",
    "lat": "-38.03333",
    "lng": "145.3"
  },
  {
    "country": "AU",
    "name": "Narrandera",
    "lat": "-34.74752",
    "lng": "146.55096"
  },
  {
    "country": "AU",
    "name": "Narrabri",
    "lat": "-30.32488",
    "lng": "149.78266"
  },
  {
    "country": "AU",
    "name": "Narrabeen",
    "lat": "-33.71277",
    "lng": "151.29736"
  },
  {
    "country": "AU",
    "name": "Narooma",
    "lat": "-36.21783",
    "lng": "150.13247"
  },
  {
    "country": "AU",
    "name": "Narellan",
    "lat": "-34.03333",
    "lng": "150.73333"
  },
  {
    "country": "AU",
    "name": "Narara",
    "lat": "-33.4",
    "lng": "151.35"
  },
  {
    "country": "AU",
    "name": "Narangba",
    "lat": "-27.20338",
    "lng": "152.95923"
  },
  {
    "country": "AU",
    "name": "Naracoorte",
    "lat": "-36.95785",
    "lng": "140.7383"
  },
  {
    "country": "AU",
    "name": "Nana Glen",
    "lat": "-30.13333",
    "lng": "153.01667"
  },
  {
    "country": "AU",
    "name": "Nambucca Heads",
    "lat": "-30.64318",
    "lng": "153.00884"
  },
  {
    "country": "AU",
    "name": "Nambucca",
    "lat": "-30.63333",
    "lng": "152.98333"
  },
  {
    "country": "AU",
    "name": "Nambour",
    "lat": "-26.62613",
    "lng": "152.95941"
  },
  {
    "country": "AU",
    "name": "Nabiac",
    "lat": "-32.09837",
    "lng": "152.37627"
  },
  {
    "country": "AU",
    "name": "Muswellbrook",
    "lat": "-32.26118",
    "lng": "150.89009"
  },
  {
    "country": "AU",
    "name": "Murwillumbah",
    "lat": "-28.32732",
    "lng": "153.39339"
  },
  {
    "country": "AU",
    "name": "Murrumbeena",
    "lat": "-37.9",
    "lng": "145.06667"
  },
  {
    "country": "AU",
    "name": "Murrumbateman",
    "lat": "-34.97199",
    "lng": "149.02985"
  },
  {
    "country": "AU",
    "name": "Mundulla",
    "lat": "-36.36667",
    "lng": "140.68333"
  },
  {
    "country": "AU",
    "name": "Mulwala",
    "lat": "-35.98536",
    "lng": "146.00534"
  },
  {
    "country": "AU",
    "name": "Mulgrave",
    "lat": "-37.91667",
    "lng": "145.2"
  },
  {
    "country": "AU",
    "name": "Mulgoa",
    "lat": "-33.838",
    "lng": "150.64963"
  },
  {
    "country": "AU",
    "name": "Mudgee",
    "lat": "-32.59426",
    "lng": "149.5871"
  },
  {
    "country": "AU",
    "name": "Mount Waverley",
    "lat": "-37.87709",
    "lng": "145.12939"
  },
  {
    "country": "AU",
    "name": "Mount Pleasant",
    "lat": "-37.58333",
    "lng": "143.86667"
  },
  {
    "country": "AU",
    "name": "Mount Martha",
    "lat": "-38.26667",
    "lng": "145.01667"
  },
  {
    "country": "AU",
    "name": "Mount Gambier",
    "lat": "-37.8318",
    "lng": "140.77919"
  },
  {
    "country": "AU",
    "name": "Mount Evelyn",
    "lat": "-37.78333",
    "lng": "145.38333"
  },
  {
    "country": "AU",
    "name": "Mount Eliza",
    "lat": "-38.18333",
    "lng": "145.08333"
  },
  {
    "country": "AU",
    "name": "Mount Druitt",
    "lat": "-33.76667",
    "lng": "150.81667"
  },
  {
    "country": "AU",
    "name": "Mount Dandenong",
    "lat": "-37.83333",
    "lng": "145.36667"
  },
  {
    "country": "AU",
    "name": "Mount Colah",
    "lat": "-33.68333",
    "lng": "151.11667"
  },
  {
    "country": "AU",
    "name": "Mount Clear",
    "lat": "-37.6",
    "lng": "143.88333"
  },
  {
    "country": "AU",
    "name": "Mount Beauty",
    "lat": "-36.73628",
    "lng": "147.17531"
  },
  {
    "country": "AU",
    "name": "Moss Vale",
    "lat": "-34.55374",
    "lng": "150.37115"
  },
  {
    "country": "AU",
    "name": "Mosman",
    "lat": "-33.83902",
    "lng": "151.23956"
  },
  {
    "country": "AU",
    "name": "Morwell",
    "lat": "-38.23476",
    "lng": "146.39499"
  },
  {
    "country": "AU",
    "name": "Moruya",
    "lat": "-35.9125",
    "lng": "150.08144"
  },
  {
    "country": "AU",
    "name": "Mortdale",
    "lat": "-33.96667",
    "lng": "151.08333"
  },
  {
    "country": "AU",
    "name": "Mornington",
    "lat": "-38.21792",
    "lng": "145.03876"
  },
  {
    "country": "AU",
    "name": "Moree",
    "lat": "-29.46278",
    "lng": "149.84157"
  },
  {
    "country": "AU",
    "name": "Mordialloc",
    "lat": "-38",
    "lng": "145.08333"
  },
  {
    "country": "AU",
    "name": "Morayfield",
    "lat": "-27.10876",
    "lng": "152.94907"
  },
  {
    "country": "AU",
    "name": "Moorooduc",
    "lat": "-38.21667",
    "lng": "145.11667"
  },
  {
    "country": "AU",
    "name": "Moorabbin",
    "lat": "-37.93667",
    "lng": "145.03417"
  },
  {
    "country": "AU",
    "name": "Moonee Ponds",
    "lat": "-37.76667",
    "lng": "144.91667"
  },
  {
    "country": "AU",
    "name": "Moonee Beach",
    "lat": "-30.20575",
    "lng": "153.15293"
  },
  {
    "country": "AU",
    "name": "Moonah",
    "lat": "-42.84617",
    "lng": "147.30228"
  },
  {
    "country": "AU",
    "name": "Mooloolaba",
    "lat": "-26.68164",
    "lng": "153.11925"
  },
  {
    "country": "AU",
    "name": "Montrose",
    "lat": "-37.81667",
    "lng": "145.35"
  },
  {
    "country": "AU",
    "name": "Montmorency",
    "lat": "-37.71667",
    "lng": "145.11667"
  },
  {
    "country": "AU",
    "name": "Mont Albert",
    "lat": "-37.81667",
    "lng": "145.1"
  },
  {
    "country": "AU",
    "name": "Monbulk",
    "lat": "-37.88333",
    "lng": "145.4"
  },
  {
    "country": "AU",
    "name": "Monash",
    "lat": "-34.2384",
    "lng": "140.56131"
  },
  {
    "country": "AU",
    "name": "Molong",
    "lat": "-33.09233",
    "lng": "148.87002"
  },
  {
    "country": "AU",
    "name": "Moggill",
    "lat": "-27.58333",
    "lng": "152.86667"
  },
  {
    "country": "AU",
    "name": "Moe",
    "lat": "-38.17828",
    "lng": "146.26099"
  },
  {
    "country": "AU",
    "name": "Moama",
    "lat": "-36.10413",
    "lng": "144.7608"
  },
  {
    "country": "AU",
    "name": "Mittagong",
    "lat": "-34.45002",
    "lng": "150.44572"
  },
  {
    "country": "AU",
    "name": "Mitcham",
    "lat": "-37.81667",
    "lng": "145.2"
  },
  {
    "country": "AU",
    "name": "Miranda",
    "lat": "-34.03857",
    "lng": "151.10005"
  },
  {
    "country": "AU",
    "name": "Milton",
    "lat": "-35.31644",
    "lng": "150.4361"
  },
  {
    "country": "AU",
    "name": "Millthorpe",
    "lat": "-33.44601",
    "lng": "149.18539"
  },
  {
    "country": "AU",
    "name": "Mill Park",
    "lat": "-37.66667",
    "lng": "145.06667"
  },
  {
    "country": "AU",
    "name": "Millicent",
    "lat": "-37.59389",
    "lng": "140.34947"
  },
  {
    "country": "AU",
    "name": "Millgrove",
    "lat": "-37.75527",
    "lng": "145.65347"
  },
  {
    "country": "AU",
    "name": "Mildura",
    "lat": "-34.18551",
    "lng": "142.16251"
  },
  {
    "country": "AU",
    "name": "Merrylands",
    "lat": "-33.83333",
    "lng": "150.98333"
  },
  {
    "country": "AU",
    "name": "Merriwa",
    "lat": "-32.13922",
    "lng": "150.35562"
  },
  {
    "country": "AU",
    "name": "Merimbula",
    "lat": "-36.88901",
    "lng": "149.90961"
  },
  {
    "country": "AU",
    "name": "Merricks",
    "lat": "-38.38333",
    "lng": "145.08333"
  },
  {
    "country": "AU",
    "name": "Mernda",
    "lat": "-37.60075",
    "lng": "145.09555"
  },
  {
    "country": "AU",
    "name": "Mentone",
    "lat": "-37.98333",
    "lng": "145.06667"
  },
  {
    "country": "AU",
    "name": "Menai",
    "lat": "-34.01667",
    "lng": "151.01667"
  },
  {
    "country": "AU",
    "name": "Melton South",
    "lat": "-37.70773",
    "lng": "144.57493"
  },
  {
    "country": "AU",
    "name": "Melton",
    "lat": "-37.68339",
    "lng": "144.58543"
  },
  {
    "country": "AU",
    "name": "Melbourne",
    "lat": "-37.814",
    "lng": "144.96332"
  },
  {
    "country": "AU",
    "name": "Medowie",
    "lat": "-32.7415",
    "lng": "151.8676"
  },
  {
    "country": "AU",
    "name": "McKinnon",
    "lat": "-37.91667",
    "lng": "145.05"
  },
  {
    "country": "AU",
    "name": "Matraville",
    "lat": "-33.95",
    "lng": "151.23333"
  },
  {
    "country": "AU",
    "name": "Mascot",
    "lat": "-33.92598",
    "lng": "151.19347"
  },
  {
    "country": "AU",
    "name": "Maryborough",
    "lat": "-37.04562",
    "lng": "143.73923"
  },
  {
    "country": "AU",
    "name": "Maryborough",
    "lat": "-25.54073",
    "lng": "152.70493"
  },
  {
    "country": "AU",
    "name": "Marrickville",
    "lat": "-33.90318",
    "lng": "151.15176"
  },
  {
    "country": "AU",
    "name": "Maroubra",
    "lat": "-33.95",
    "lng": "151.23333"
  },
  {
    "country": "AU",
    "name": "Maribyrnong",
    "lat": "-37.78333",
    "lng": "144.88333"
  },
  {
    "country": "AU",
    "name": "Margate",
    "lat": "-43.02814",
    "lng": "147.26256"
  },
  {
    "country": "AU",
    "name": "Margate",
    "lat": "-27.24761",
    "lng": "153.09809"
  },
  {
    "country": "AU",
    "name": "Mareeba",
    "lat": "-16.99096",
    "lng": "145.42306"
  },
  {
    "country": "AU",
    "name": "Mansfield",
    "lat": "-37.052",
    "lng": "146.08846"
  },
  {
    "country": "AU",
    "name": "Manly",
    "lat": "-33.79798",
    "lng": "151.28826"
  },
  {
    "country": "AU",
    "name": "Manilla",
    "lat": "-30.74748",
    "lng": "150.71974"
  },
  {
    "country": "AU",
    "name": "Maleny",
    "lat": "-26.76001",
    "lng": "152.84926"
  },
  {
    "country": "AU",
    "name": "Malabar",
    "lat": "-33.96216",
    "lng": "151.24796"
  },
  {
    "country": "AU",
    "name": "Maitland",
    "lat": "-32.73308",
    "lng": "151.5574"
  },
  {
    "country": "AU",
    "name": "Macleod",
    "lat": "-37.73333",
    "lng": "145.06667"
  },
  {
    "country": "AU",
    "name": "Maclean",
    "lat": "-29.4581",
    "lng": "153.19753"
  },
  {
    "country": "AU",
    "name": "Macksville",
    "lat": "-30.7078",
    "lng": "152.92029"
  },
  {
    "country": "AU",
    "name": "Mackay",
    "lat": "-21.15345",
    "lng": "149.16554"
  },
  {
    "country": "AU",
    "name": "Macclesfield",
    "lat": "-37.88333",
    "lng": "145.48333"
  },
  {
    "country": "AU",
    "name": "Lysterfield",
    "lat": "-37.93333",
    "lng": "145.3"
  },
  {
    "country": "AU",
    "name": "Luddenham",
    "lat": "-33.8785",
    "lng": "150.68863"
  },
  {
    "country": "AU",
    "name": "Loxton",
    "lat": "-34.4502",
    "lng": "140.56908"
  },
  {
    "country": "AU",
    "name": "Lower Plenty",
    "lat": "-37.73333",
    "lng": "145.11667"
  },
  {
    "country": "AU",
    "name": "Loveday",
    "lat": "-34.28333",
    "lng": "140.43333"
  },
  {
    "country": "AU",
    "name": "Lorn",
    "lat": "-32.73333",
    "lng": "151.56667"
  },
  {
    "country": "AU",
    "name": "Long Jetty",
    "lat": "-33.35795",
    "lng": "151.48135"
  },
  {
    "country": "AU",
    "name": "Longford",
    "lat": "-41.60512",
    "lng": "147.11887"
  },
  {
    "country": "AU",
    "name": "Liverpool",
    "lat": "-33.91938",
    "lng": "150.92588"
  },
  {
    "country": "AU",
    "name": "Little River",
    "lat": "-37.96667",
    "lng": "144.5"
  },
  {
    "country": "AU",
    "name": "Lithgow",
    "lat": "-33.4845",
    "lng": "150.14903"
  },
  {
    "country": "AU",
    "name": "Lismore",
    "lat": "-28.81354",
    "lng": "153.2773"
  },
  {
    "country": "AU",
    "name": "Lisarow",
    "lat": "-33.38333",
    "lng": "151.36667"
  },
  {
    "country": "AU",
    "name": "Lindisfarne",
    "lat": "-42.84837",
    "lng": "147.36192"
  },
  {
    "country": "AU",
    "name": "Lindfield",
    "lat": "-33.78333",
    "lng": "151.16667"
  },
  {
    "country": "AU",
    "name": "Lilydale",
    "lat": "-37.75",
    "lng": "145.35"
  },
  {
    "country": "AU",
    "name": "Lightning Ridge",
    "lat": "-29.42743",
    "lng": "147.97865"
  },
  {
    "country": "AU",
    "name": "Lidcombe",
    "lat": "-33.86436",
    "lng": "151.0397"
  },
  {
    "country": "AU",
    "name": "Leura",
    "lat": "-33.71667",
    "lng": "150.33333"
  },
  {
    "country": "AU",
    "name": "Leumeah",
    "lat": "-34.05",
    "lng": "150.83333"
  },
  {
    "country": "AU",
    "name": "Leopold",
    "lat": "-38.19001",
    "lng": "144.46825"
  },
  {
    "country": "AU",
    "name": "Leichhardt",
    "lat": "-33.88341",
    "lng": "151.15625"
  },
  {
    "country": "AU",
    "name": "Leeton",
    "lat": "-34.55105",
    "lng": "146.40483"
  },
  {
    "country": "AU",
    "name": "Lawson",
    "lat": "-33.72064",
    "lng": "150.42975"
  },
  {
    "country": "AU",
    "name": "Lavington",
    "lat": "-36.03976",
    "lng": "146.93958"
  },
  {
    "country": "AU",
    "name": "Camden Haven",
    "lat": "-31.64484",
    "lng": "152.79462"
  },
  {
    "country": "AU",
    "name": "Launceston",
    "lat": "-41.43876",
    "lng": "147.13467"
  },
  {
    "country": "AU",
    "name": "Lauderdale",
    "lat": "-42.91364",
    "lng": "147.48747"
  },
  {
    "country": "AU",
    "name": "Latrobe",
    "lat": "-41.24641",
    "lng": "146.42458"
  },
  {
    "country": "AU",
    "name": "Larnook",
    "lat": "-28.65162",
    "lng": "153.11077"
  },
  {
    "country": "AU",
    "name": "Largs",
    "lat": "-32.7",
    "lng": "151.6"
  },
  {
    "country": "AU",
    "name": "Lara",
    "lat": "-38.02388",
    "lng": "144.40617"
  },
  {
    "country": "AU",
    "name": "Langwarrin",
    "lat": "-38.16667",
    "lng": "145.16667"
  },
  {
    "country": "AU",
    "name": "Lane Cove",
    "lat": "-33.8157",
    "lng": "151.16679"
  },
  {
    "country": "AU",
    "name": "Lalor",
    "lat": "-37.66667",
    "lng": "145.01667"
  },
  {
    "country": "AU",
    "name": "Lakes Entrance",
    "lat": "-37.86679",
    "lng": "148.00159"
  },
  {
    "country": "AU",
    "name": "Lakemba",
    "lat": "-33.91972",
    "lng": "151.07592"
  },
  {
    "country": "AU",
    "name": "Lake Illawarra",
    "lat": "-34.54658",
    "lng": "150.85645"
  },
  {
    "country": "AU",
    "name": "Lake Cargelligo",
    "lat": "-33.29884",
    "lng": "146.37296"
  },
  {
    "country": "AU",
    "name": "Lake Albert",
    "lat": "-35.16667",
    "lng": "147.38333"
  },
  {
    "country": "AU",
    "name": "Kyogle",
    "lat": "-28.62075",
    "lng": "153.00482"
  },
  {
    "country": "AU",
    "name": "Kyabram",
    "lat": "-36.31335",
    "lng": "145.05035"
  },
  {
    "country": "AU",
    "name": "Kurri Kurri",
    "lat": "-32.81933",
    "lng": "151.47908"
  },
  {
    "country": "AU",
    "name": "Kurnell",
    "lat": "-34.01088",
    "lng": "151.20512"
  },
  {
    "country": "AU",
    "name": "Kuranda",
    "lat": "-16.81978",
    "lng": "145.63818"
  },
  {
    "country": "AU",
    "name": "Kotara",
    "lat": "-32.95",
    "lng": "151.68333"
  },
  {
    "country": "AU",
    "name": "Koo-Wee-Rup",
    "lat": "-38.19941",
    "lng": "145.49081"
  },
  {
    "country": "AU",
    "name": "Kootingal",
    "lat": "-31.05857",
    "lng": "151.0535"
  },
  {
    "country": "AU",
    "name": "Kogarah",
    "lat": "-33.98333",
    "lng": "151.11667"
  },
  {
    "country": "AU",
    "name": "Kirribilli",
    "lat": "-33.84867",
    "lng": "151.2162"
  },
  {
    "country": "AU",
    "name": "Kingston Beach",
    "lat": "-42.98021",
    "lng": "147.31941"
  },
  {
    "country": "AU",
    "name": "Kingston",
    "lat": "-42.97638",
    "lng": "147.30351"
  },
  {
    "country": "AU",
    "name": "Kingston",
    "lat": "-34.23333",
    "lng": "140.35"
  },
  {
    "country": "AU",
    "name": "Kingscliff",
    "lat": "-28.25983",
    "lng": "153.57816"
  },
  {
    "country": "AU",
    "name": "Kinglake West",
    "lat": "-37.46667",
    "lng": "145.23333"
  },
  {
    "country": "AU",
    "name": "Kingaroy",
    "lat": "-26.53994",
    "lng": "151.8373"
  },
  {
    "country": "AU",
    "name": "Kilsyth",
    "lat": "-37.8",
    "lng": "145.31667"
  },
  {
    "country": "AU",
    "name": "Kiama",
    "lat": "-34.66828",
    "lng": "150.85219"
  },
  {
    "country": "AU",
    "name": "Keysborough",
    "lat": "-37.99116",
    "lng": "145.17385"
  },
  {
    "country": "AU",
    "name": "Kew",
    "lat": "-37.80639",
    "lng": "145.03086"
  },
  {
    "country": "AU",
    "name": "Kettering",
    "lat": "-43.12623",
    "lng": "147.24641"
  },
  {
    "country": "AU",
    "name": "Kenthurst",
    "lat": "-33.65527",
    "lng": "151.00503"
  },
  {
    "country": "AU",
    "name": "Kensington",
    "lat": "-33.92019",
    "lng": "151.22241"
  },
  {
    "country": "AU",
    "name": "Kensington",
    "lat": "-37.78333",
    "lng": "144.93333"
  },
  {
    "country": "AU",
    "name": "Kennington",
    "lat": "-36.78333",
    "lng": "144.3"
  },
  {
    "country": "AU",
    "name": "Kendall",
    "lat": "-31.63295",
    "lng": "152.70393"
  },
  {
    "country": "AU",
    "name": "Kempsey",
    "lat": "-31.07898",
    "lng": "152.83093"
  },
  {
    "country": "AU",
    "name": "Kelso",
    "lat": "-33.41667",
    "lng": "149.6"
  },
  {
    "country": "AU",
    "name": "Keith",
    "lat": "-36.0991",
    "lng": "140.35315"
  },
  {
    "country": "AU",
    "name": "Keiraville",
    "lat": "-34.41667",
    "lng": "150.86667"
  },
  {
    "country": "AU",
    "name": "Keilor",
    "lat": "-37.71667",
    "lng": "144.83333"
  },
  {
    "country": "AU",
    "name": "Katoomba",
    "lat": "-33.71977",
    "lng": "150.30739"
  },
  {
    "country": "AU",
    "name": "Kanwal",
    "lat": "-33.253",
    "lng": "151.4911"
  },
  {
    "country": "AU",
    "name": "Kangaroo Valley",
    "lat": "-34.73806",
    "lng": "150.53657"
  },
  {
    "country": "AU",
    "name": "Kangaroo Flat",
    "lat": "-36.8",
    "lng": "144.25"
  },
  {
    "country": "AU",
    "name": "Kandos",
    "lat": "-32.85772",
    "lng": "149.96832"
  },
  {
    "country": "AU",
    "name": "Kalorama",
    "lat": "-37.81667",
    "lng": "145.36667"
  },
  {
    "country": "AU",
    "name": "Kallista",
    "lat": "-37.88333",
    "lng": "145.36667"
  },
  {
    "country": "AU",
    "name": "Kahibah",
    "lat": "-32.96667",
    "lng": "151.71667"
  },
  {
    "country": "AU",
    "name": "Junee",
    "lat": "-34.86819",
    "lng": "147.58273"
  },
  {
    "country": "AU",
    "name": "Jindera",
    "lat": "-35.95474",
    "lng": "146.88852"
  },
  {
    "country": "AU",
    "name": "Jindabyne",
    "lat": "-36.41745",
    "lng": "148.62254"
  },
  {
    "country": "AU",
    "name": "Jilliby",
    "lat": "-33.22605",
    "lng": "151.41684"
  },
  {
    "country": "AU",
    "name": "Jannali",
    "lat": "-34.01643",
    "lng": "151.06065"
  },
  {
    "country": "AU",
    "name": "Jamberoo",
    "lat": "-34.64745",
    "lng": "150.77464"
  },
  {
    "country": "AU",
    "name": "Ivanhoe East",
    "lat": "-37.7832",
    "lng": "145.05249"
  },
  {
    "country": "AU",
    "name": "Inverell",
    "lat": "-29.77403",
    "lng": "151.11166"
  },
  {
    "country": "AU",
    "name": "Innisfail",
    "lat": "-17.52209",
    "lng": "146.03102"
  },
  {
    "country": "AU",
    "name": "Ingleburn",
    "lat": "-34",
    "lng": "150.86667"
  },
  {
    "country": "AU",
    "name": "Ingham",
    "lat": "-18.64552",
    "lng": "146.16248"
  },
  {
    "country": "AU",
    "name": "Hurstville Grove",
    "lat": "-33.97993",
    "lng": "151.09029"
  },
  {
    "country": "AU",
    "name": "Hurstbridge",
    "lat": "-37.64157",
    "lng": "145.19408"
  },
  {
    "country": "AU",
    "name": "Huonville",
    "lat": "-43.03124",
    "lng": "147.04813"
  },
  {
    "country": "AU",
    "name": "Hughesdale",
    "lat": "-37.9",
    "lng": "145.08333"
  },
  {
    "country": "AU",
    "name": "Hughenden",
    "lat": "-20.84399",
    "lng": "144.20035"
  },
  {
    "country": "AU",
    "name": "Howlong",
    "lat": "-35.98197",
    "lng": "146.63248"
  },
  {
    "country": "AU",
    "name": "Horsham",
    "lat": "-36.71131",
    "lng": "142.19981"
  },
  {
    "country": "AU",
    "name": "Hornsby",
    "lat": "-33.70244",
    "lng": "151.09931"
  },
  {
    "country": "AU",
    "name": "Home Hill",
    "lat": "-19.65921",
    "lng": "147.41232"
  },
  {
    "country": "AU",
    "name": "Homebush",
    "lat": "-33.86667",
    "lng": "151.08333"
  },
  {
    "country": "AU",
    "name": "Holsworthy",
    "lat": "-33.98333",
    "lng": "150.96667"
  },
  {
    "country": "AU",
    "name": "Holgate",
    "lat": "-33.4",
    "lng": "151.41667"
  },
  {
    "country": "AU",
    "name": "Holbrook",
    "lat": "-35.721",
    "lng": "147.31605"
  },
  {
    "country": "AU",
    "name": "Hobart",
    "lat": "-42.87936",
    "lng": "147.32941"
  },
  {
    "country": "AU",
    "name": "Hillston",
    "lat": "-33.48266",
    "lng": "145.53525"
  },
  {
    "country": "AU",
    "name": "Highett",
    "lat": "-37.95",
    "lng": "145.05"
  },
  {
    "country": "AU",
    "name": "Henty",
    "lat": "-35.52094",
    "lng": "147.03426"
  },
  {
    "country": "AU",
    "name": "Helensburgh",
    "lat": "-34.17836",
    "lng": "150.99522"
  },
  {
    "country": "AU",
    "name": "Heidelberg West",
    "lat": "-37.75",
    "lng": "145.03333"
  },
  {
    "country": "AU",
    "name": "Heidelberg",
    "lat": "-37.75",
    "lng": "145.06667"
  },
  {
    "country": "AU",
    "name": "Heddon Greta",
    "lat": "-32.80204",
    "lng": "151.51327"
  },
  {
    "country": "AU",
    "name": "Heathmont",
    "lat": "-37.83333",
    "lng": "145.25"
  },
  {
    "country": "AU",
    "name": "Heatherton",
    "lat": "-37.96667",
    "lng": "145.1"
  },
  {
    "country": "AU",
    "name": "Heathcote",
    "lat": "-34.0841",
    "lng": "151.01305"
  },
  {
    "country": "AU",
    "name": "Healesville",
    "lat": "-37.65395",
    "lng": "145.51718"
  },
  {
    "country": "AU",
    "name": "Hazelbrook",
    "lat": "-33.72446",
    "lng": "150.45839"
  },
  {
    "country": "AU",
    "name": "Haymarket",
    "lat": "-33.87868",
    "lng": "151.20526"
  },
  {
    "country": "AU",
    "name": "Hay",
    "lat": "-34.50903",
    "lng": "144.84306"
  },
  {
    "country": "AU",
    "name": "Hawthorn South",
    "lat": "-37.8329",
    "lng": "145.0367"
  },
  {
    "country": "AU",
    "name": "Hawthorn",
    "lat": "-37.81992",
    "lng": "145.0358"
  },
  {
    "country": "AU",
    "name": "Hawks Nest",
    "lat": "-32.66755",
    "lng": "152.17831"
  },
  {
    "country": "AU",
    "name": "Hastings",
    "lat": "-38.3",
    "lng": "145.18333"
  },
  {
    "country": "AU",
    "name": "Harrington",
    "lat": "-31.88306",
    "lng": "152.65924"
  },
  {
    "country": "AU",
    "name": "Hampton Park",
    "lat": "-38.03333",
    "lng": "145.25"
  },
  {
    "country": "AU",
    "name": "Hampton",
    "lat": "-37.95",
    "lng": "145"
  },
  {
    "country": "AU",
    "name": "Hamilton",
    "lat": "-37.74425",
    "lng": "142.02202"
  },
  {
    "country": "AU",
    "name": "Hallam",
    "lat": "-38.01667",
    "lng": "145.26667"
  },
  {
    "country": "AU",
    "name": "Haberfield",
    "lat": "-33.88296",
    "lng": "151.14389"
  },
  {
    "country": "AU",
    "name": "Gympie",
    "lat": "-26.18979",
    "lng": "152.66499"
  },
  {
    "country": "AU",
    "name": "Guyra",
    "lat": "-30.2168",
    "lng": "151.66785"
  },
  {
    "country": "AU",
    "name": "Gunnedah",
    "lat": "-30.98065",
    "lng": "150.25838"
  },
  {
    "country": "AU",
    "name": "Gundaroo",
    "lat": "-35.03333",
    "lng": "149.25"
  },
  {
    "country": "AU",
    "name": "Gundagai",
    "lat": "-35.06352",
    "lng": "148.10365"
  },
  {
    "country": "AU",
    "name": "Gulgong",
    "lat": "-32.36253",
    "lng": "149.53201"
  },
  {
    "country": "AU",
    "name": "Grovedale",
    "lat": "-38.2",
    "lng": "144.35"
  },
  {
    "country": "AU",
    "name": "Griffith",
    "lat": "-34.28853",
    "lng": "146.05093"
  },
  {
    "country": "AU",
    "name": "Greta",
    "lat": "-32.67783",
    "lng": "151.38924"
  },
  {
    "country": "AU",
    "name": "Grenfell",
    "lat": "-33.89549",
    "lng": "148.16438"
  },
  {
    "country": "AU",
    "name": "Greenwell Point",
    "lat": "-34.90751",
    "lng": "150.73113"
  },
  {
    "country": "AU",
    "name": "Greenvale",
    "lat": "-37.63333",
    "lng": "144.86667"
  },
  {
    "country": "AU",
    "name": "Greensborough",
    "lat": "-37.70462",
    "lng": "145.10302"
  },
  {
    "country": "AU",
    "name": "Granville",
    "lat": "-33.83333",
    "lng": "151.01667"
  },
  {
    "country": "AU",
    "name": "Granton",
    "lat": "-42.75149",
    "lng": "147.22795"
  },
  {
    "country": "AU",
    "name": "Grafton",
    "lat": "-29.68104",
    "lng": "152.93394"
  },
  {
    "country": "AU",
    "name": "Goulburn",
    "lat": "-34.75155",
    "lng": "149.72086"
  },
  {
    "country": "AU",
    "name": "Gosford",
    "lat": "-33.4244",
    "lng": "151.34399"
  },
  {
    "country": "AU",
    "name": "Gorokan",
    "lat": "-33.25764",
    "lng": "151.5097"
  },
  {
    "country": "AU",
    "name": "Gordon",
    "lat": "-33.75535",
    "lng": "151.15115"
  },
  {
    "country": "AU",
    "name": "Goonellabah",
    "lat": "-28.81667",
    "lng": "153.31667"
  },
  {
    "country": "AU",
    "name": "Goondiwindi",
    "lat": "-28.54709",
    "lng": "150.30546"
  },
  {
    "country": "AU",
    "name": "Goodna",
    "lat": "-27.61046",
    "lng": "152.89896"
  },
  {
    "country": "AU",
    "name": "Gol Gol",
    "lat": "-34.17388",
    "lng": "142.22187"
  },
  {
    "country": "AU",
    "name": "Gold Coast",
    "lat": "-28.00029",
    "lng": "153.43088"
  },
  {
    "country": "AU",
    "name": "Gloucester",
    "lat": "-32.0077",
    "lng": "151.9633"
  },
  {
    "country": "AU",
    "name": "Glenroy",
    "lat": "-37.7",
    "lng": "144.93333"
  },
  {
    "country": "AU",
    "name": "Glenorie",
    "lat": "-33.60177",
    "lng": "151.00886"
  },
  {
    "country": "AU",
    "name": "Glenorchy",
    "lat": "-42.83343",
    "lng": "147.27593"
  },
  {
    "country": "AU",
    "name": "Glen Innes",
    "lat": "-29.73485",
    "lng": "151.7385"
  },
  {
    "country": "AU",
    "name": "Glen Huntly",
    "lat": "-37.88333",
    "lng": "145.05"
  },
  {
    "country": "AU",
    "name": "Glenhaven",
    "lat": "-33.7",
    "lng": "151"
  },
  {
    "country": "AU",
    "name": "Glenfield",
    "lat": "-33.96667",
    "lng": "150.9"
  },
  {
    "country": "AU",
    "name": "Glenferrie",
    "lat": "-37.83333",
    "lng": "145.05"
  },
  {
    "country": "AU",
    "name": "Glenbrook",
    "lat": "-33.76667",
    "lng": "150.61667"
  },
  {
    "country": "AU",
    "name": "Gladstone",
    "lat": "-23.84852",
    "lng": "151.25775"
  },
  {
    "country": "AU",
    "name": "Gilgandra",
    "lat": "-31.71173",
    "lng": "148.66252"
  },
  {
    "country": "AU",
    "name": "Gilgai",
    "lat": "-29.8527",
    "lng": "151.11806"
  },
  {
    "country": "AU",
    "name": "Gerringong",
    "lat": "-34.74702",
    "lng": "150.82809"
  },
  {
    "country": "AU",
    "name": "George Town",
    "lat": "-41.10559",
    "lng": "146.82606"
  },
  {
    "country": "AU",
    "name": "Gembrook",
    "lat": "-37.95321",
    "lng": "145.55536"
  },
  {
    "country": "AU",
    "name": "Geeveston",
    "lat": "-43.16337",
    "lng": "146.92549"
  },
  {
    "country": "AU",
    "name": "Geelong West",
    "lat": "-38.13888",
    "lng": "144.34842"
  },
  {
    "country": "AU",
    "name": "Geelong",
    "lat": "-38.14711",
    "lng": "144.36069"
  },
  {
    "country": "AU",
    "name": "Gayndah",
    "lat": "-25.62522",
    "lng": "151.61144"
  },
  {
    "country": "AU",
    "name": "Gatton",
    "lat": "-27.55873",
    "lng": "152.27618"
  },
  {
    "country": "AU",
    "name": "Garfield",
    "lat": "-38.08985",
    "lng": "145.67502"
  },
  {
    "country": "AU",
    "name": "Galston",
    "lat": "-33.65297",
    "lng": "151.04713"
  },
  {
    "country": "AU",
    "name": "Frederickton",
    "lat": "-31.03749",
    "lng": "152.8753"
  },
  {
    "country": "AU",
    "name": "Frankston East",
    "lat": "-38.13333",
    "lng": "145.13333"
  },
  {
    "country": "AU",
    "name": "Frankston",
    "lat": "-38.14458",
    "lng": "145.12291"
  },
  {
    "country": "AU",
    "name": "Franklin",
    "lat": "-43.08884",
    "lng": "147.00906"
  },
  {
    "country": "AU",
    "name": "Forster",
    "lat": "-32.18136",
    "lng": "152.51715"
  },
  {
    "country": "AU",
    "name": "Forest Hill",
    "lat": "-35.1481",
    "lng": "147.46707"
  },
  {
    "country": "AU",
    "name": "Forest Hill",
    "lat": "-37.83333",
    "lng": "145.18333"
  },
  {
    "country": "AU",
    "name": "Forbes",
    "lat": "-33.38436",
    "lng": "148.0076"
  },
  {
    "country": "AU",
    "name": "Footscray",
    "lat": "-37.8",
    "lng": "144.9"
  },
  {
    "country": "AU",
    "name": "Fitzroy",
    "lat": "-37.79839",
    "lng": "144.97833"
  },
  {
    "country": "AU",
    "name": "Finley",
    "lat": "-35.65498",
    "lng": "145.57106"
  },
  {
    "country": "AU",
    "name": "Ferny Creek",
    "lat": "-37.88333",
    "lng": "145.33333"
  },
  {
    "country": "AU",
    "name": "Federal",
    "lat": "-28.6485",
    "lng": "153.4512"
  },
  {
    "country": "AU",
    "name": "Fawkner",
    "lat": "-37.71667",
    "lng": "144.96667"
  },
  {
    "country": "AU",
    "name": "Falls Creek",
    "lat": "-34.96667",
    "lng": "150.6"
  },
  {
    "country": "AU",
    "name": "Fairfield",
    "lat": "-33.86667",
    "lng": "150.95"
  },
  {
    "country": "AU",
    "name": "Evans Head",
    "lat": "-29.11777",
    "lng": "153.43072"
  },
  {
    "country": "AU",
    "name": "Evandale",
    "lat": "-41.56858",
    "lng": "147.25271"
  },
  {
    "country": "AU",
    "name": "Eulomogo",
    "lat": "-32.26667",
    "lng": "148.68333"
  },
  {
    "country": "AU",
    "name": "Ettalong Beach",
    "lat": "-33.51058",
    "lng": "151.33044"
  },
  {
    "country": "AU",
    "name": "Ettalong",
    "lat": "-33.51301",
    "lng": "151.3383"
  },
  {
    "country": "AU",
    "name": "Essendon",
    "lat": "-37.76667",
    "lng": "144.91667"
  },
  {
    "country": "AU",
    "name": "Erina",
    "lat": "-33.43218",
    "lng": "151.38972"
  },
  {
    "country": "AU",
    "name": "Epsom",
    "lat": "-36.71667",
    "lng": "144.31667"
  },
  {
    "country": "AU",
    "name": "Epping",
    "lat": "-37.65",
    "lng": "145.03333"
  },
  {
    "country": "AU",
    "name": "Epping",
    "lat": "-33.77271",
    "lng": "151.08184"
  },
  {
    "country": "AU",
    "name": "Enmore",
    "lat": "-30.73333",
    "lng": "151.8"
  },
  {
    "country": "AU",
    "name": "Engadine",
    "lat": "-34.06564",
    "lng": "151.01266"
  },
  {
    "country": "AU",
    "name": "Empire Bay",
    "lat": "-33.49385",
    "lng": "151.3629"
  },
  {
    "country": "AU",
    "name": "Emerald",
    "lat": "-37.93167",
    "lng": "145.44093"
  },
  {
    "country": "AU",
    "name": "Emerald",
    "lat": "-23.52296",
    "lng": "148.15784"
  },
  {
    "country": "AU",
    "name": "Eltham North",
    "lat": "-37.7",
    "lng": "145.15"
  },
  {
    "country": "AU",
    "name": "Eltham",
    "lat": "-37.73333",
    "lng": "145.15"
  },
  {
    "country": "AU",
    "name": "Elderslie",
    "lat": "-34.05",
    "lng": "150.7"
  },
  {
    "country": "AU",
    "name": "Eight Mile Plains",
    "lat": "-27.58333",
    "lng": "153.1"
  },
  {
    "country": "AU",
    "name": "Eglinton",
    "lat": "-33.37731",
    "lng": "149.54654"
  },
  {
    "country": "AU",
    "name": "Edithvale",
    "lat": "-38.03724",
    "lng": "145.10974"
  },
  {
    "country": "AU",
    "name": "Edgecliff",
    "lat": "-33.88333",
    "lng": "151.25"
  },
  {
    "country": "AU",
    "name": "Eden",
    "lat": "-37.06675",
    "lng": "149.90029"
  },
  {
    "country": "AU",
    "name": "Echuca",
    "lat": "-36.14057",
    "lng": "144.75185"
  },
  {
    "country": "AU",
    "name": "Eastwood",
    "lat": "-33.79176",
    "lng": "151.08057"
  },
  {
    "country": "AU",
    "name": "East Maitland",
    "lat": "-32.75",
    "lng": "151.58333"
  },
  {
    "country": "AU",
    "name": "East Hills",
    "lat": "-33.96667",
    "lng": "150.98333"
  },
  {
    "country": "AU",
    "name": "East Gosford",
    "lat": "-33.43874",
    "lng": "151.35338"
  },
  {
    "country": "AU",
    "name": "East Ballina",
    "lat": "-28.85709",
    "lng": "153.58736"
  },
  {
    "country": "AU",
    "name": "Earlwood",
    "lat": "-33.95",
    "lng": "151.1"
  },
  {
    "country": "AU",
    "name": "Dungog",
    "lat": "-32.40431",
    "lng": "151.75192"
  },
  {
    "country": "AU",
    "name": "Dunedoo",
    "lat": "-32.01634",
    "lng": "149.3871"
  },
  {
    "country": "AU",
    "name": "Dubbo",
    "lat": "-32.24295",
    "lng": "148.60484"
  },
  {
    "country": "AU",
    "name": "Dromana",
    "lat": "-38.33375",
    "lng": "144.96458"
  },
  {
    "country": "AU",
    "name": "Douglas Park",
    "lat": "-34.18496",
    "lng": "150.71449"
  },
  {
    "country": "AU",
    "name": "Dorrigo",
    "lat": "-30.34112",
    "lng": "152.71394"
  },
  {
    "country": "AU",
    "name": "Doreen",
    "lat": "-37.6",
    "lng": "145.15"
  },
  {
    "country": "AU",
    "name": "Dora Creek",
    "lat": "-33.08139",
    "lng": "151.49677"
  },
  {
    "country": "AU",
    "name": "Doonside",
    "lat": "-33.76667",
    "lng": "150.86667"
  },
  {
    "country": "AU",
    "name": "Donvale",
    "lat": "-37.7891",
    "lng": "145.17488"
  },
  {
    "country": "AU",
    "name": "Doncaster East",
    "lat": "-37.78761",
    "lng": "145.14888"
  },
  {
    "country": "AU",
    "name": "Doncaster",
    "lat": "-37.78828",
    "lng": "145.12373"
  },
  {
    "country": "AU",
    "name": "Dingley Village",
    "lat": "-37.9827",
    "lng": "145.1342"
  },
  {
    "country": "AU",
    "name": "Diggers Rest",
    "lat": "-37.62597",
    "lng": "144.71881"
  },
  {
    "country": "AU",
    "name": "Diamond Creek",
    "lat": "-37.66667",
    "lng": "145.15"
  },
  {
    "country": "AU",
    "name": "Devonport",
    "lat": "-41.17695",
    "lng": "146.35152"
  },
  {
    "country": "AU",
    "name": "Derrimut",
    "lat": "-37.79238",
    "lng": "144.76994"
  },
  {
    "country": "AU",
    "name": "Denman",
    "lat": "-32.38788",
    "lng": "150.68935"
  },
  {
    "country": "AU",
    "name": "Deniliquin",
    "lat": "-35.53245",
    "lng": "144.95364"
  },
  {
    "country": "AU",
    "name": "Deloraine",
    "lat": "-41.52477",
    "lng": "146.65701"
  },
  {
    "country": "AU",
    "name": "Deer Park",
    "lat": "-37.76667",
    "lng": "144.78333"
  },
  {
    "country": "AU",
    "name": "Deception Bay",
    "lat": "-27.19354",
    "lng": "153.02631"
  },
  {
    "country": "AU",
    "name": "Deagon",
    "lat": "-27.33333",
    "lng": "153.06667"
  },
  {
    "country": "AU",
    "name": "Davistown",
    "lat": "-33.48559",
    "lng": "151.36151"
  },
  {
    "country": "AU",
    "name": "Davidson",
    "lat": "-33.74297",
    "lng": "151.2008"
  },
  {
    "country": "AU",
    "name": "Darlington Point",
    "lat": "-34.56942",
    "lng": "145.9987"
  },
  {
    "country": "AU",
    "name": "Darlinghurst",
    "lat": "-33.87939",
    "lng": "151.21925"
  },
  {
    "country": "AU",
    "name": "Dareton",
    "lat": "-34.09468",
    "lng": "142.03966"
  },
  {
    "country": "AU",
    "name": "Lower Plenty",
    "lat": "-37.75",
    "lng": "145.11667"
  },
  {
    "country": "AU",
    "name": "Dapto",
    "lat": "-34.5",
    "lng": "150.78333"
  },
  {
    "country": "AU",
    "name": "Dandenong",
    "lat": "-37.98333",
    "lng": "145.2"
  },
  {
    "country": "AU",
    "name": "Dalby",
    "lat": "-27.18169",
    "lng": "151.26205"
  },
  {
    "country": "AU",
    "name": "D’Aguilar",
    "lat": "-26.98333",
    "lng": "152.8"
  },
  {
    "country": "AU",
    "name": "Daceyville",
    "lat": "-33.93333",
    "lng": "151.23333"
  },
  {
    "country": "AU",
    "name": "Cygnet",
    "lat": "-43.15333",
    "lng": "147.07253"
  },
  {
    "country": "AU",
    "name": "Currie",
    "lat": "-39.92976",
    "lng": "143.85385"
  },
  {
    "country": "AU",
    "name": "Cundletown",
    "lat": "-31.8941",
    "lng": "152.52141"
  },
  {
    "country": "AU",
    "name": "Culcairn",
    "lat": "-35.66669",
    "lng": "147.03845"
  },
  {
    "country": "AU",
    "name": "Croydon North",
    "lat": "-37.78333",
    "lng": "145.3"
  },
  {
    "country": "AU",
    "name": "Croydon",
    "lat": "-37.8",
    "lng": "145.28333"
  },
  {
    "country": "AU",
    "name": "Croydon",
    "lat": "-33.88333",
    "lng": "151.11667"
  },
  {
    "country": "AU",
    "name": "Crookwell",
    "lat": "-34.45925",
    "lng": "149.47137"
  },
  {
    "country": "AU",
    "name": "Cronulla",
    "lat": "-34.06251",
    "lng": "151.14961"
  },
  {
    "country": "AU",
    "name": "Cringila",
    "lat": "-34.46667",
    "lng": "150.88333"
  },
  {
    "country": "AU",
    "name": "Crib Point",
    "lat": "-38.35",
    "lng": "145.2"
  },
  {
    "country": "AU",
    "name": "Crescent Head",
    "lat": "-31.1887",
    "lng": "152.97301"
  },
  {
    "country": "AU",
    "name": "Cremorne",
    "lat": "-37.83333",
    "lng": "145"
  },
  {
    "country": "AU",
    "name": "Cranbourne",
    "lat": "-38.11342",
    "lng": "145.28326"
  },
  {
    "country": "AU",
    "name": "Craigieburn",
    "lat": "-37.6",
    "lng": "144.95"
  },
  {
    "country": "AU",
    "name": "Cowra",
    "lat": "-33.83554",
    "lng": "148.69663"
  },
  {
    "country": "AU",
    "name": "Cowes",
    "lat": "-38.45231",
    "lng": "145.23865"
  },
  {
    "country": "AU",
    "name": "Coutts Crossing",
    "lat": "-29.82619",
    "lng": "152.89156"
  },
  {
    "country": "AU",
    "name": "Corrimal",
    "lat": "-34.37864",
    "lng": "150.90356"
  },
  {
    "country": "AU",
    "name": "Corowa",
    "lat": "-35.99704",
    "lng": "146.38552"
  },
  {
    "country": "AU",
    "name": "Coraki",
    "lat": "-28.9926",
    "lng": "153.28374"
  },
  {
    "country": "AU",
    "name": "Cootamundra",
    "lat": "-34.64095",
    "lng": "148.02838"
  },
  {
    "country": "AU",
    "name": "Coorparoo",
    "lat": "-27.49325",
    "lng": "153.05826"
  },
  {
    "country": "AU",
    "name": "Cooranbong",
    "lat": "-33.07622",
    "lng": "151.45409"
  },
  {
    "country": "AU",
    "name": "Coonamble",
    "lat": "-30.95389",
    "lng": "148.38881"
  },
  {
    "country": "AU",
    "name": "Coonabarabran",
    "lat": "-31.27734",
    "lng": "149.27904"
  },
  {
    "country": "AU",
    "name": "Cooma",
    "lat": "-36.23517",
    "lng": "149.12408"
  },
  {
    "country": "AU",
    "name": "Coolum Beach",
    "lat": "-26.5283",
    "lng": "153.08809"
  },
  {
    "country": "AU",
    "name": "Coolamon",
    "lat": "-34.81641",
    "lng": "147.19577"
  },
  {
    "country": "AU",
    "name": "Cooktown",
    "lat": "-15.43912",
    "lng": "145.136"
  },
  {
    "country": "AU",
    "name": "Coogee",
    "lat": "-33.9205",
    "lng": "151.25522"
  },
  {
    "country": "AU",
    "name": "Coniston",
    "lat": "-34.45",
    "lng": "150.88333"
  },
  {
    "country": "AU",
    "name": "Condobolin",
    "lat": "-33.08877",
    "lng": "147.15139"
  },
  {
    "country": "AU",
    "name": "Concord",
    "lat": "-33.84722",
    "lng": "151.10381"
  },
  {
    "country": "AU",
    "name": "Como",
    "lat": "-33.99941",
    "lng": "151.06389"
  },
  {
    "country": "AU",
    "name": "Colo Vale",
    "lat": "-34.40095",
    "lng": "150.48573"
  },
  {
    "country": "AU",
    "name": "Collingwood",
    "lat": "-37.80253",
    "lng": "144.98872"
  },
  {
    "country": "AU",
    "name": "Colac",
    "lat": "-38.339",
    "lng": "143.58489"
  },
  {
    "country": "AU",
    "name": "Coffs Harbour",
    "lat": "-30.29626",
    "lng": "153.11351"
  },
  {
    "country": "AU",
    "name": "Cockatoo",
    "lat": "-37.93677",
    "lng": "145.49376"
  },
  {
    "country": "AU",
    "name": "Coburg",
    "lat": "-37.75",
    "lng": "144.96667"
  },
  {
    "country": "AU",
    "name": "Cobbitty",
    "lat": "-34.01592",
    "lng": "150.67854"
  },
  {
    "country": "AU",
    "name": "Cobar",
    "lat": "-31.49666",
    "lng": "145.83439"
  },
  {
    "country": "AU",
    "name": "Cloncurry",
    "lat": "-20.70718",
    "lng": "140.51303"
  },
  {
    "country": "AU",
    "name": "Clifton Springs",
    "lat": "-38.1567",
    "lng": "144.5551"
  },
  {
    "country": "AU",
    "name": "Clifton Hill",
    "lat": "-37.79798",
    "lng": "144.99533"
  },
  {
    "country": "AU",
    "name": "Cleveland",
    "lat": "-27.52677",
    "lng": "153.26516"
  },
  {
    "country": "AU",
    "name": "Clayton South",
    "lat": "-37.93333",
    "lng": "145.11667"
  },
  {
    "country": "AU",
    "name": "Clayton",
    "lat": "-37.91667",
    "lng": "145.11667"
  },
  {
    "country": "AU",
    "name": "Clarinda",
    "lat": "-37.93333",
    "lng": "145.11667"
  },
  {
    "country": "AU",
    "name": "Clarence Town",
    "lat": "-32.58395",
    "lng": "151.77757"
  },
  {
    "country": "AU",
    "name": "Claremont",
    "lat": "-42.78333",
    "lng": "147.25"
  },
  {
    "country": "AU",
    "name": "Wollongong",
    "lat": "-34.424",
    "lng": "150.89345"
  },
  {
    "country": "AU",
    "name": "Churchill",
    "lat": "-27.64233",
    "lng": "152.75022"
  },
  {
    "country": "AU",
    "name": "Chipping Norton",
    "lat": "-33.9",
    "lng": "150.95"
  },
  {
    "country": "AU",
    "name": "Chippendale",
    "lat": "-33.88673",
    "lng": "151.19745"
  },
  {
    "country": "AU",
    "name": "Chinderah",
    "lat": "-28.23333",
    "lng": "153.55"
  },
  {
    "country": "AU",
    "name": "Chinchilla",
    "lat": "-26.73787",
    "lng": "150.6297"
  },
  {
    "country": "AU",
    "name": "Childers",
    "lat": "-25.23708",
    "lng": "152.27876"
  },
  {
    "country": "AU",
    "name": "Chelsea Heights",
    "lat": "-38.03333",
    "lng": "145.13333"
  },
  {
    "country": "AU",
    "name": "Chelsea",
    "lat": "-38.05",
    "lng": "145.11667"
  },
  {
    "country": "AU",
    "name": "Chatswood",
    "lat": "-33.8",
    "lng": "151.18333"
  },
  {
    "country": "AU",
    "name": "Charters Towers",
    "lat": "-20.07671",
    "lng": "146.26353"
  },
  {
    "country": "AU",
    "name": "Charlestown",
    "lat": "-32.95",
    "lng": "151.66667"
  },
  {
    "country": "AU",
    "name": "Cessnock",
    "lat": "-32.83211",
    "lng": "151.35623"
  },
  {
    "country": "AU",
    "name": "Caulfield North",
    "lat": "-37.8739",
    "lng": "145.02485"
  },
  {
    "country": "AU",
    "name": "Caulfield East",
    "lat": "-37.88333",
    "lng": "145.05"
  },
  {
    "country": "AU",
    "name": "Caulfield",
    "lat": "-37.88251",
    "lng": "145.02288"
  },
  {
    "country": "AU",
    "name": "Castlemaine",
    "lat": "-37.06709",
    "lng": "144.21684"
  },
  {
    "country": "AU",
    "name": "Castle Hill",
    "lat": "-33.73333",
    "lng": "151"
  },
  {
    "country": "AU",
    "name": "Castlecrag",
    "lat": "-33.79987",
    "lng": "151.2231"
  },
  {
    "country": "AU",
    "name": "Casino",
    "lat": "-28.85819",
    "lng": "153.04748"
  },
  {
    "country": "AU",
    "name": "Carrum Downs",
    "lat": "-38.09968",
    "lng": "145.17248"
  },
  {
    "country": "AU",
    "name": "Carrum",
    "lat": "-38.08333",
    "lng": "145.13333"
  },
  {
    "country": "AU",
    "name": "Carnegie",
    "lat": "-37.88333",
    "lng": "145.06667"
  },
  {
    "country": "AU",
    "name": "Carlton North",
    "lat": "-37.78818",
    "lng": "144.97014"
  },
  {
    "country": "AU",
    "name": "Carlton",
    "lat": "-37.8",
    "lng": "144.96667"
  },
  {
    "country": "AU",
    "name": "Carlingford",
    "lat": "-33.78269",
    "lng": "151.04888"
  },
  {
    "country": "AU",
    "name": "Caringbah",
    "lat": "-34.04726",
    "lng": "151.12051"
  },
  {
    "country": "AU",
    "name": "Cardiff",
    "lat": "-32.95",
    "lng": "151.66667"
  },
  {
    "country": "AU",
    "name": "Canowindra",
    "lat": "-33.56247",
    "lng": "148.66434"
  },
  {
    "country": "AU",
    "name": "Canberra",
    "lat": "-35.28346",
    "lng": "149.12807"
  },
  {
    "country": "AU",
    "name": "Canadian",
    "lat": "-37.57606",
    "lng": "143.87742"
  },
  {
    "country": "AU",
    "name": "Camperdown",
    "lat": "-33.88965",
    "lng": "151.17642"
  },
  {
    "country": "AU",
    "name": "Campbelltown",
    "lat": "-34.06667",
    "lng": "150.81667"
  },
  {
    "country": "AU",
    "name": "Campbellfield",
    "lat": "-37.68333",
    "lng": "144.95"
  },
  {
    "country": "AU",
    "name": "Cambridge",
    "lat": "-42.83333",
    "lng": "147.45"
  },
  {
    "country": "AU",
    "name": "Camberwell",
    "lat": "-37.84205",
    "lng": "145.0694"
  },
  {
    "country": "AU",
    "name": "Caloundra",
    "lat": "-26.80346",
    "lng": "153.12195"
  },
  {
    "country": "AU",
    "name": "Cairns",
    "lat": "-16.92366",
    "lng": "145.76613"
  },
  {
    "country": "AU",
    "name": "Caboolture",
    "lat": "-27.08465",
    "lng": "152.9511"
  },
  {
    "country": "AU",
    "name": "Byron Bay",
    "lat": "-28.64989",
    "lng": "153.61246"
  },
  {
    "country": "AU",
    "name": "Buxton",
    "lat": "-34.26017",
    "lng": "150.53288"
  },
  {
    "country": "AU",
    "name": "Burwood East",
    "lat": "-37.85",
    "lng": "145.15"
  },
  {
    "country": "AU",
    "name": "Burwood",
    "lat": "-33.88333",
    "lng": "151.1"
  },
  {
    "country": "AU",
    "name": "Burringbar",
    "lat": "-28.4358",
    "lng": "153.47324"
  },
  {
    "country": "AU",
    "name": "Burpengary",
    "lat": "-27.15746",
    "lng": "152.95758"
  },
  {
    "country": "AU",
    "name": "Burnie",
    "lat": "-41.05584",
    "lng": "145.90375"
  },
  {
    "country": "AU",
    "name": "Bunyip",
    "lat": "-38.09789",
    "lng": "145.71606"
  },
  {
    "country": "AU",
    "name": "Bungendore",
    "lat": "-35.25382",
    "lng": "149.44007"
  },
  {
    "country": "AU",
    "name": "Bundanoon",
    "lat": "-34.65658",
    "lng": "150.29623"
  },
  {
    "country": "AU",
    "name": "Bundamba",
    "lat": "-27.60947",
    "lng": "152.81133"
  },
  {
    "country": "AU",
    "name": "Bundaberg",
    "lat": "-24.86621",
    "lng": "152.3479"
  },
  {
    "country": "AU",
    "name": "Bulli",
    "lat": "-34.33834",
    "lng": "150.91347"
  },
  {
    "country": "AU",
    "name": "Bulleen",
    "lat": "-37.76667",
    "lng": "145.08333"
  },
  {
    "country": "AU",
    "name": "Bulahdelah",
    "lat": "-32.40698",
    "lng": "152.21185"
  },
  {
    "country": "AU",
    "name": "Budgewoi",
    "lat": "-33.2339",
    "lng": "151.55412"
  },
  {
    "country": "AU",
    "name": "Buderim",
    "lat": "-26.68443",
    "lng": "153.05705"
  },
  {
    "country": "AU",
    "name": "Brunswick West",
    "lat": "-37.76461",
    "lng": "144.94383"
  },
  {
    "country": "AU",
    "name": "Brunswick Heads",
    "lat": "-28.54003",
    "lng": "153.54573"
  },
  {
    "country": "AU",
    "name": "Brunswick East",
    "lat": "-37.77255",
    "lng": "144.97241"
  },
  {
    "country": "AU",
    "name": "Brunswick",
    "lat": "-37.76667",
    "lng": "144.96667"
  },
  {
    "country": "AU",
    "name": "Brown Hill",
    "lat": "-37.55",
    "lng": "143.9"
  },
  {
    "country": "AU",
    "name": "Broulee",
    "lat": "-35.85469",
    "lng": "150.17392"
  },
  {
    "country": "AU",
    "name": "Broken Hill",
    "lat": "-31.9652",
    "lng": "141.4512"
  },
  {
    "country": "AU",
    "name": "Broadmeadows",
    "lat": "-37.68015",
    "lng": "144.91877"
  },
  {
    "country": "AU",
    "name": "Brisbane",
    "lat": "-27.46794",
    "lng": "153.02809"
  },
  {
    "country": "AU",
    "name": "Bringelly",
    "lat": "-33.93333",
    "lng": "150.73333"
  },
  {
    "country": "AU",
    "name": "Brighton",
    "lat": "-37.90561",
    "lng": "145.00279"
  },
  {
    "country": "AU",
    "name": "Brighton",
    "lat": "-27.29582",
    "lng": "153.05721"
  },
  {
    "country": "AU",
    "name": "Bridport",
    "lat": "-41.00046",
    "lng": "147.39175"
  },
  {
    "country": "AU",
    "name": "Bridgewater",
    "lat": "-42.73719",
    "lng": "147.22784"
  },
  {
    "country": "AU",
    "name": "Briar Hill",
    "lat": "-37.71667",
    "lng": "145.11667"
  },
  {
    "country": "AU",
    "name": "Brewarrina",
    "lat": "-29.96067",
    "lng": "146.85986"
  },
  {
    "country": "AU",
    "name": "Branxton",
    "lat": "-32.65547",
    "lng": "151.35113"
  },
  {
    "country": "AU",
    "name": "Braidwood",
    "lat": "-35.44148",
    "lng": "149.7998"
  },
  {
    "country": "AU",
    "name": "Box Hill",
    "lat": "-37.81887",
    "lng": "145.12545"
  },
  {
    "country": "AU",
    "name": "Bowraville",
    "lat": "-30.64997",
    "lng": "152.85146"
  },
  {
    "country": "AU",
    "name": "Bowral",
    "lat": "-34.4775",
    "lng": "150.4204"
  },
  {
    "country": "AU",
    "name": "Bowenfels",
    "lat": "-33.51667",
    "lng": "150.11667"
  },
  {
    "country": "AU",
    "name": "Bowen",
    "lat": "-20.01367",
    "lng": "148.24754"
  },
  {
    "country": "AU",
    "name": "Bourke",
    "lat": "-30.09011",
    "lng": "145.93646"
  },
  {
    "country": "AU",
    "name": "Botany",
    "lat": "-33.94599",
    "lng": "151.19591"
  },
  {
    "country": "AU",
    "name": "Boronia",
    "lat": "-37.86667",
    "lng": "145.28333"
  },
  {
    "country": "AU",
    "name": "Bordertown",
    "lat": "-36.30768",
    "lng": "140.77167"
  },
  {
    "country": "AU",
    "name": "Boorowa",
    "lat": "-34.43661",
    "lng": "148.71634"
  },
  {
    "country": "AU",
    "name": "Booker Bay",
    "lat": "-33.51667",
    "lng": "151.35"
  },
  {
    "country": "AU",
    "name": "Bonville",
    "lat": "-30.38284",
    "lng": "153.05959"
  },
  {
    "country": "AU",
    "name": "Bongaree",
    "lat": "-27.08367",
    "lng": "153.15942"
  },
  {
    "country": "AU",
    "name": "Bombala",
    "lat": "-36.91212",
    "lng": "149.23669"
  },
  {
    "country": "AU",
    "name": "Bomaderry",
    "lat": "-34.84967",
    "lng": "150.61093"
  },
  {
    "country": "AU",
    "name": "Bolwarra",
    "lat": "-32.71667",
    "lng": "151.56667"
  },
  {
    "country": "AU",
    "name": "Boggabri",
    "lat": "-30.70953",
    "lng": "150.04121"
  },
  {
    "country": "AU",
    "name": "Boggabilla",
    "lat": "-28.60477",
    "lng": "150.35934"
  },
  {
    "country": "AU",
    "name": "Boambee",
    "lat": "-30.33981",
    "lng": "153.06783"
  },
  {
    "country": "AU",
    "name": "Blayney",
    "lat": "-33.53233",
    "lng": "149.25367"
  },
  {
    "country": "AU",
    "name": "Blaxland",
    "lat": "-33.75",
    "lng": "150.6"
  },
  {
    "country": "AU",
    "name": "Blair Athol",
    "lat": "-30.65",
    "lng": "150.2"
  },
  {
    "country": "AU",
    "name": "Blackwater",
    "lat": "-23.58351",
    "lng": "148.87912"
  },
  {
    "country": "AU",
    "name": "Blackwall",
    "lat": "-33.5019",
    "lng": "151.32365"
  },
  {
    "country": "AU",
    "name": "Blacktown",
    "lat": "-33.76667",
    "lng": "150.91667"
  },
  {
    "country": "AU",
    "name": "Blackmans Bay",
    "lat": "-43.00311",
    "lng": "147.31694"
  },
  {
    "country": "AU",
    "name": "Black Hill",
    "lat": "-37.55",
    "lng": "143.86667"
  },
  {
    "country": "AU",
    "name": "Blackheath",
    "lat": "-33.63567",
    "lng": "150.28318"
  },
  {
    "country": "AU",
    "name": "Bingara",
    "lat": "-29.86931",
    "lng": "150.57204"
  },
  {
    "country": "AU",
    "name": "Biloela",
    "lat": "-24.39589",
    "lng": "150.51504"
  },
  {
    "country": "AU",
    "name": "Bilambil",
    "lat": "-28.2266",
    "lng": "153.4676"
  },
  {
    "country": "AU",
    "name": "Bexley",
    "lat": "-33.95",
    "lng": "151.11667"
  },
  {
    "country": "AU",
    "name": "Berwick",
    "lat": "-38.03333",
    "lng": "145.35"
  },
  {
    "country": "AU",
    "name": "Berry",
    "lat": "-34.77507",
    "lng": "150.69436"
  },
  {
    "country": "AU",
    "name": "Berrigan",
    "lat": "-35.65879",
    "lng": "145.81145"
  },
  {
    "country": "AU",
    "name": "Berriedale",
    "lat": "-42.81667",
    "lng": "147.25"
  },
  {
    "country": "AU",
    "name": "Berridale",
    "lat": "-36.36673",
    "lng": "148.82772"
  },
  {
    "country": "AU",
    "name": "Berri",
    "lat": "-34.28107",
    "lng": "140.59958"
  },
  {
    "country": "AU",
    "name": "Berowra",
    "lat": "-33.62078",
    "lng": "151.15091"
  },
  {
    "country": "AU",
    "name": "Bermagui",
    "lat": "-36.419",
    "lng": "150.06355"
  },
  {
    "country": "AU",
    "name": "Berkeley Vale",
    "lat": "-33.35",
    "lng": "151.43333"
  },
  {
    "country": "AU",
    "name": "Berkeley",
    "lat": "-34.48333",
    "lng": "150.85"
  },
  {
    "country": "AU",
    "name": "Beresfield",
    "lat": "-32.8",
    "lng": "151.65"
  },
  {
    "country": "AU",
    "name": "Bentleigh",
    "lat": "-37.91806",
    "lng": "145.03544"
  },
  {
    "country": "AU",
    "name": "Bensville",
    "lat": "-33.49757",
    "lng": "151.38084"
  },
  {
    "country": "AU",
    "name": "Bendigo",
    "lat": "-36.75818",
    "lng": "144.28024"
  },
  {
    "country": "AU",
    "name": "Benalla",
    "lat": "-36.55113",
    "lng": "145.98425"
  },
  {
    "country": "AU",
    "name": "Belmont",
    "lat": "-33.0274",
    "lng": "151.6601"
  },
  {
    "country": "AU",
    "name": "Belmont",
    "lat": "-27.5",
    "lng": "153.11667"
  },
  {
    "country": "AU",
    "name": "Bellingen",
    "lat": "-30.45294",
    "lng": "152.89911"
  },
  {
    "country": "AU",
    "name": "Bellerive",
    "lat": "-42.87551",
    "lng": "147.3703"
  },
  {
    "country": "AU",
    "name": "Belgrave South",
    "lat": "-37.93333",
    "lng": "145.33333"
  },
  {
    "country": "AU",
    "name": "Belgrave Heights",
    "lat": "-37.91667",
    "lng": "145.35"
  },
  {
    "country": "AU",
    "name": "Belgrave",
    "lat": "-37.9",
    "lng": "145.35"
  },
  {
    "country": "AU",
    "name": "Belconnen",
    "lat": "-35.21667",
    "lng": "149.08333"
  },
  {
    "country": "AU",
    "name": "Bega",
    "lat": "-36.67392",
    "lng": "149.84178"
  },
  {
    "country": "AU",
    "name": "Beenleigh",
    "lat": "-27.71137",
    "lng": "153.2029"
  },
  {
    "country": "AU",
    "name": "Beauty Point",
    "lat": "-41.16216",
    "lng": "146.82146"
  },
  {
    "country": "AU",
    "name": "Beaumaris",
    "lat": "-37.98534",
    "lng": "145.03361"
  },
  {
    "country": "AU",
    "name": "Beaconsfield Upper",
    "lat": "-37.99415",
    "lng": "145.4142"
  },
  {
    "country": "AU",
    "name": "Beaconsfield",
    "lat": "-41.20227",
    "lng": "146.81723"
  },
  {
    "country": "AU",
    "name": "Bay View",
    "lat": "-33.65982",
    "lng": "151.29878"
  },
  {
    "country": "AU",
    "name": "Bayswater",
    "lat": "-37.85",
    "lng": "145.26667"
  },
  {
    "country": "AU",
    "name": "Baxter",
    "lat": "-38.2",
    "lng": "145.15"
  },
  {
    "country": "AU",
    "name": "Baulkham Hills",
    "lat": "-33.75881",
    "lng": "150.99292"
  },
  {
    "country": "AU",
    "name": "Bathurst",
    "lat": "-33.41665",
    "lng": "149.5806"
  },
  {
    "country": "AU",
    "name": "Batemans Bay",
    "lat": "-35.70658",
    "lng": "150.17541"
  },
  {
    "country": "AU",
    "name": "Barmera",
    "lat": "-34.25562",
    "lng": "140.46147"
  },
  {
    "country": "AU",
    "name": "Banora Point",
    "lat": "-28.21298",
    "lng": "153.53634"
  },
  {
    "country": "AU",
    "name": "Bankstown",
    "lat": "-33.91667",
    "lng": "151.03333"
  },
  {
    "country": "AU",
    "name": "Balwyn",
    "lat": "-37.81667",
    "lng": "145.06667"
  },
  {
    "country": "AU",
    "name": "Balnarring",
    "lat": "-38.36667",
    "lng": "145.13333"
  },
  {
    "country": "AU",
    "name": "Balmain",
    "lat": "-33.85481",
    "lng": "151.1833"
  },
  {
    "country": "AU",
    "name": "Ballina",
    "lat": "-28.86414",
    "lng": "153.56541"
  },
  {
    "country": "AU",
    "name": "Ballarat East",
    "lat": "-37.56667",
    "lng": "143.86667"
  },
  {
    "country": "AU",
    "name": "Ballarat",
    "lat": "-37.56622",
    "lng": "143.84957"
  },
  {
    "country": "AU",
    "name": "Balgowlah",
    "lat": "-33.79494",
    "lng": "151.2572"
  },
  {
    "country": "AU",
    "name": "Balaclava",
    "lat": "-37.86667",
    "lng": "145"
  },
  {
    "country": "AU",
    "name": "Bairnsdale",
    "lat": "-37.82289",
    "lng": "147.61041"
  },
  {
    "country": "AU",
    "name": "Badger Creek",
    "lat": "-37.7",
    "lng": "145.51667"
  },
  {
    "country": "AU",
    "name": "Bacchus Marsh",
    "lat": "-37.67268",
    "lng": "144.43829"
  },
  {
    "country": "AU",
    "name": "Ayr",
    "lat": "-19.57393",
    "lng": "147.40666"
  },
  {
    "country": "AU",
    "name": "Avoca Beach",
    "lat": "-33.46818",
    "lng": "151.4339"
  },
  {
    "country": "AU",
    "name": "Austins Ferry",
    "lat": "-42.76667",
    "lng": "147.25"
  },
  {
    "country": "AU",
    "name": "Auburn",
    "lat": "-33.85",
    "lng": "151.03333"
  },
  {
    "country": "AU",
    "name": "Atherton",
    "lat": "-17.26864",
    "lng": "145.47522"
  },
  {
    "country": "AU",
    "name": "Asquith",
    "lat": "-33.68333",
    "lng": "151.1"
  },
  {
    "country": "AU",
    "name": "Aspendale",
    "lat": "-38.02913",
    "lng": "145.10266"
  },
  {
    "country": "AU",
    "name": "Ashfield",
    "lat": "-33.88834",
    "lng": "151.12274"
  },
  {
    "country": "AU",
    "name": "Ashburton",
    "lat": "-37.86667",
    "lng": "145.08333"
  },
  {
    "country": "AU",
    "name": "Ascot Vale",
    "lat": "-37.78333",
    "lng": "144.91667"
  },
  {
    "country": "AU",
    "name": "Artarmon",
    "lat": "-33.81667",
    "lng": "151.18333"
  },
  {
    "country": "AU",
    "name": "Armidale",
    "lat": "-30.50123",
    "lng": "151.66553"
  },
  {
    "country": "AU",
    "name": "Arcadia",
    "lat": "-33.61667",
    "lng": "151.03333"
  },
  {
    "country": "AU",
    "name": "Ararat",
    "lat": "-37.28542",
    "lng": "142.92728"
  },
  {
    "country": "AU",
    "name": "Apollo Bay",
    "lat": "-38.7594",
    "lng": "143.67219"
  },
  {
    "country": "AU",
    "name": "Anna Bay",
    "lat": "-32.78135",
    "lng": "152.08586"
  },
  {
    "country": "AU",
    "name": "Anglesea",
    "lat": "-38.4073",
    "lng": "144.18587"
  },
  {
    "country": "AU",
    "name": "Altona",
    "lat": "-37.86964",
    "lng": "144.83036"
  },
  {
    "country": "AU",
    "name": "Alphington",
    "lat": "-37.78333",
    "lng": "145.03333"
  },
  {
    "country": "AU",
    "name": "Allansford",
    "lat": "-38.38639",
    "lng": "142.59431"
  },
  {
    "country": "AU",
    "name": "Alexandria",
    "lat": "-33.91667",
    "lng": "151.2"
  },
  {
    "country": "AU",
    "name": "Alexandra",
    "lat": "-37.19132",
    "lng": "145.7112"
  },
  {
    "country": "AU",
    "name": "Albury",
    "lat": "-36.07482",
    "lng": "146.92401"
  },
  {
    "country": "AU",
    "name": "Albion",
    "lat": "-37.76667",
    "lng": "144.83333"
  },
  {
    "country": "AU",
    "name": "Albert Park",
    "lat": "-37.83333",
    "lng": "145"
  },
  {
    "country": "AU",
    "name": "Abbotsford",
    "lat": "-37.8",
    "lng": "145"
  },
  {
    "country": "AU",
    "name": "Holmesville",
    "lat": "-32.9",
    "lng": "151.59167"
  },
  {
    "country": "AU",
    "name": "Lambton",
    "lat": "-32.91667",
    "lng": "151.7"
  },
  {
    "country": "AU",
    "name": "New Lambton",
    "lat": "-32.95",
    "lng": "151.68333"
  },
  {
    "country": "AU",
    "name": "Raymond Terrace",
    "lat": "-32.75",
    "lng": "151.75"
  },
  {
    "country": "AU",
    "name": "Mayfield",
    "lat": "-41.3876",
    "lng": "147.13052"
  },
  {
    "country": "AU",
    "name": "Invermay",
    "lat": "-41.39167",
    "lng": "147.13056"
  },
  {
    "country": "AU",
    "name": "Gymea",
    "lat": "-34.03637",
    "lng": "151.08528"
  },
  {
    "country": "AU",
    "name": "Kirrawee",
    "lat": "-34.03831",
    "lng": "151.06903"
  },
  {
    "country": "AU",
    "name": "Loftus",
    "lat": "-34.04467",
    "lng": "151.04646"
  },
  {
    "country": "AU",
    "name": "Dolans Bay",
    "lat": "-34.06653",
    "lng": "151.12806"
  },
  {
    "country": "AU",
    "name": "Bundeena",
    "lat": "-34.08384",
    "lng": "151.15016"
  },
  {
    "country": "AU",
    "name": "Gymea Bay",
    "lat": "-34.05209",
    "lng": "151.08795"
  },
  {
    "country": "AU",
    "name": "Kareela",
    "lat": "-34.01336",
    "lng": "151.08345"
  },
  {
    "country": "AU",
    "name": "Bonnet Bay",
    "lat": "-34.01023",
    "lng": "151.05253"
  },
  {
    "country": "AU",
    "name": "Oyster Bay",
    "lat": "-34.00407",
    "lng": "151.07588"
  },
  {
    "country": "AU",
    "name": "Grays Point",
    "lat": "-34.05873",
    "lng": "151.08604"
  },
  {
    "country": "AU",
    "name": "Brighton-Le-Sands",
    "lat": "-33.96009",
    "lng": "151.1511"
  },
  {
    "country": "AU",
    "name": "Monterey",
    "lat": "-33.9725",
    "lng": "151.1481"
  },
  {
    "country": "AU",
    "name": "Ramsgate",
    "lat": "-33.9822",
    "lng": "151.14"
  },
  {
    "country": "AU",
    "name": "Blakehurst",
    "lat": "-33.99152",
    "lng": "151.10876"
  },
  {
    "country": "AU",
    "name": "Connells Point",
    "lat": "-33.98827",
    "lng": "151.09094"
  },
  {
    "country": "AU",
    "name": "Lugarno",
    "lat": "-33.98267",
    "lng": "151.04184"
  },
  {
    "country": "AU",
    "name": "Peakhurst",
    "lat": "-33.96288",
    "lng": "151.05161"
  },
  {
    "country": "AU",
    "name": "Padstow",
    "lat": "-33.95687",
    "lng": "151.03191"
  },
  {
    "country": "AU",
    "name": "Goodwood",
    "lat": "-42.82822",
    "lng": "147.29301"
  },
  {
    "country": "AU",
    "name": "Lutana",
    "lat": "-42.83475",
    "lng": "147.31152"
  },
  {
    "country": "AU",
    "name": "New Town",
    "lat": "-42.85758",
    "lng": "147.30869"
  },
  {
    "country": "AU",
    "name": "Lake Heights",
    "lat": "-34.48667",
    "lng": "150.875"
  },
  {
    "country": "AU",
    "name": "Sandy Bay",
    "lat": "-42.89449",
    "lng": "147.32439"
  },
  {
    "country": "AU",
    "name": "Fairy Meadow",
    "lat": "-34.39303",
    "lng": "150.89275"
  },
  {
    "country": "AU",
    "name": "Mount Ousley",
    "lat": "-34.40213",
    "lng": "150.88786"
  },
  {
    "country": "AU",
    "name": "Mount Keira",
    "lat": "-34.41889",
    "lng": "150.85417"
  },
  {
    "country": "AU",
    "name": "Gwynneville",
    "lat": "-34.41667",
    "lng": "150.8875"
  },
  {
    "country": "AU",
    "name": "Mangerton",
    "lat": "-34.43667",
    "lng": "150.87167"
  },
  {
    "country": "AU",
    "name": "Mount Saint Thomas",
    "lat": "-34.44333",
    "lng": "150.87222"
  },
  {
    "country": "AU",
    "name": "Palm Cove",
    "lat": "-16.75",
    "lng": "145.66667"
  },
  {
    "country": "AU",
    "name": "Yorkeys Knob",
    "lat": "-16.80278",
    "lng": "145.72083"
  },
  {
    "country": "AU",
    "name": "South Brisbane",
    "lat": "-27.48034",
    "lng": "153.02049"
  },
  {
    "country": "AU",
    "name": "Scarborough",
    "lat": "-27.20118",
    "lng": "153.10939"
  },
  {
    "country": "AU",
    "name": "Bonbeach",
    "lat": "-38.06528",
    "lng": "145.12278"
  },
  {
    "country": "AU",
    "name": "McCrae",
    "lat": "-38.34972",
    "lng": "144.92806"
  },
  {
    "country": "AU",
    "name": "Laverton",
    "lat": "-37.86201",
    "lng": "144.76979"
  },
  {
    "country": "AU",
    "name": "North Brighton",
    "lat": "-37.90694",
    "lng": "145.00528"
  },
  {
    "country": "AU",
    "name": "Cheltenham",
    "lat": "-37.96944",
    "lng": "145.04806"
  },
  {
    "country": "AU",
    "name": "Bellevue Hill",
    "lat": "-33.87899",
    "lng": "151.25101"
  },
  {
    "country": "AU",
    "name": "Paddington",
    "lat": "-33.88419",
    "lng": "151.23151"
  },
  {
    "country": "AU",
    "name": "Lilyfield",
    "lat": "-33.87499",
    "lng": "151.1653"
  },
  {
    "country": "AU",
    "name": "Drummoyne",
    "lat": "-33.85237",
    "lng": "151.15491"
  },
  {
    "country": "AU",
    "name": "Greenwich",
    "lat": "-33.83954",
    "lng": "151.183"
  },
  {
    "country": "AU",
    "name": "Hunters Hill",
    "lat": "-33.83432",
    "lng": "151.1459"
  },
  {
    "country": "AU",
    "name": "Longueville",
    "lat": "-33.83285",
    "lng": "151.16531"
  },
  {
    "country": "AU",
    "name": "Crows Nest",
    "lat": "-33.82494",
    "lng": "151.20398"
  },
  {
    "country": "AU",
    "name": "Cammeray",
    "lat": "-33.82132",
    "lng": "151.21609"
  },
  {
    "country": "AU",
    "name": "Clontarf",
    "lat": "-33.80554",
    "lng": "151.25367"
  },
  {
    "country": "AU",
    "name": "Cremorne",
    "lat": "-33.82679",
    "lng": "151.22633"
  },
  {
    "country": "AU",
    "name": "Neutral Bay",
    "lat": "-33.83784",
    "lng": "151.2175"
  },
  {
    "country": "AU",
    "name": "Point Piper",
    "lat": "-33.86667",
    "lng": "151.25"
  },
  {
    "country": "AU",
    "name": "Darling Point",
    "lat": "-33.87064",
    "lng": "151.23895"
  },
  {
    "country": "AU",
    "name": "Dover Heights",
    "lat": "-33.87083",
    "lng": "151.27917"
  },
  {
    "country": "AU",
    "name": "Randwick",
    "lat": "-33.91439",
    "lng": "151.24895"
  },
  {
    "country": "AU",
    "name": "Clovelly",
    "lat": "-33.91214",
    "lng": "151.25882"
  },
  {
    "country": "AU",
    "name": "Bronte",
    "lat": "-33.90198",
    "lng": "151.26556"
  },
  {
    "country": "AU",
    "name": "Bondi",
    "lat": "-33.89429",
    "lng": "151.26444"
  },
  {
    "country": "AU",
    "name": "Gladesville",
    "lat": "-33.83333",
    "lng": "151.13333"
  },
  {
    "country": "AU",
    "name": "Forestville",
    "lat": "-33.76667",
    "lng": "151.20833"
  },
  {
    "country": "AU",
    "name": "Brookvale",
    "lat": "-33.76108",
    "lng": "151.27446"
  },
  {
    "country": "AU",
    "name": "Curl Curl",
    "lat": "-33.76886",
    "lng": "151.28888"
  },
  {
    "country": "AU",
    "name": "Dee Why",
    "lat": "-33.75",
    "lng": "151.3"
  },
  {
    "country": "AU",
    "name": "Umina",
    "lat": "-33.52314",
    "lng": "151.31325"
  },
  {
    "country": "AU",
    "name": "Blairgowrie",
    "lat": "-38.36131",
    "lng": "144.77955"
  },
  {
    "country": "AU",
    "name": "Flinders",
    "lat": "-34.58333",
    "lng": "150.85516"
  },
  {
    "country": "AU",
    "name": "Airport West",
    "lat": "-37.7247",
    "lng": "144.88126"
  },
  {
    "country": "AU",
    "name": "Niddrie",
    "lat": "-37.7375",
    "lng": "144.89212"
  },
  {
    "country": "AU",
    "name": "Gladstone Park",
    "lat": "-37.68742",
    "lng": "144.88675"
  },
  {
    "country": "AU",
    "name": "Palmerston",
    "lat": "-12.48602",
    "lng": "130.9833"
  },
  {
    "country": "AU",
    "name": "Tom Price",
    "lat": "-22.6939",
    "lng": "117.7931"
  },
  {
    "country": "AU",
    "name": "Hervey Bay",
    "lat": "-25.28762",
    "lng": "152.76936"
  },
  {
    "country": "AU",
    "name": "Moranbah",
    "lat": "-22.00163",
    "lng": "148.04661"
  },
  {
    "country": "AU",
    "name": "Heyfield",
    "lat": "-37.9813",
    "lng": "146.78559"
  },
  {
    "country": "AU",
    "name": "Kaleen",
    "lat": "-35.21814",
    "lng": "149.10516"
  },
  {
    "country": "AU",
    "name": "Karratha",
    "lat": "-20.73765",
    "lng": "116.84629"
  },
  {
    "country": "AU",
    "name": "Enfield",
    "lat": "-34.8526",
    "lng": "138.60255"
  },
  {
    "country": "AU",
    "name": "Hillarys",
    "lat": "-31.80698",
    "lng": "115.74045"
  },
  {
    "country": "AU",
    "name": "Kingsford",
    "lat": "-33.92399",
    "lng": "151.22749"
  },
  {
    "country": "AU",
    "name": "Klemzig",
    "lat": "-34.87928",
    "lng": "138.63562"
  },
  {
    "country": "AU",
    "name": "Maidstone",
    "lat": "-37.78035",
    "lng": "144.87353"
  },
  {
    "country": "AU",
    "name": "Osborne Park",
    "lat": "-31.90066",
    "lng": "115.81083"
  },
  {
    "country": "AU",
    "name": "Seven Mile Beach",
    "lat": "-42.85863",
    "lng": "147.50532"
  },
  {
    "country": "AU",
    "name": "Woollahra",
    "lat": "-33.8878",
    "lng": "151.23681"
  },
  {
    "country": "AU",
    "name": "Corlette",
    "lat": "-32.72014",
    "lng": "152.10846"
  },
  {
    "country": "AU",
    "name": "Burswood",
    "lat": "-31.95872",
    "lng": "115.90396"
  },
  {
    "country": "AU",
    "name": "Howrah",
    "lat": "-42.88728",
    "lng": "147.40554"
  },
  {
    "country": "AU",
    "name": "Springfield Lakes",
    "lat": "-27.66757",
    "lng": "152.92488"
  },
  {
    "country": "AU",
    "name": "Attwood",
    "lat": "-37.66955",
    "lng": "144.88675"
  },
  {
    "country": "AU",
    "name": "North Narrabeen",
    "lat": "-33.70935",
    "lng": "151.29607"
  },
  {
    "country": "AU",
    "name": "Joondalup",
    "lat": "-31.74445",
    "lng": "115.76835"
  },
  {
    "country": "AU",
    "name": "Como",
    "lat": "-31.99119",
    "lng": "115.86336"
  },
  {
    "country": "AU",
    "name": "Arncliffe",
    "lat": "-33.93627",
    "lng": "151.14819"
  },
  {
    "country": "AU",
    "name": "East Lismore",
    "lat": "-28.82591",
    "lng": "153.2888"
  },
  {
    "country": "AU",
    "name": "Mindarie",
    "lat": "-31.68932",
    "lng": "115.70698"
  },
  {
    "country": "AU",
    "name": "Clarkson",
    "lat": "-31.68282",
    "lng": "115.7247"
  },
  {
    "country": "AU",
    "name": "Kinross",
    "lat": "-31.71868",
    "lng": "115.73839"
  },
  {
    "country": "AU",
    "name": "Currambine",
    "lat": "-31.73306",
    "lng": "115.74766"
  },
  {
    "country": "AU",
    "name": "Iluka",
    "lat": "-31.73554",
    "lng": "115.73058"
  },
  {
    "country": "AU",
    "name": "Heathridge",
    "lat": "-31.76244",
    "lng": "115.75895"
  },
  {
    "country": "AU",
    "name": "Paradise Point",
    "lat": "-27.88663",
    "lng": "153.3933"
  },
  {
    "country": "AU",
    "name": "Girraween",
    "lat": "-33.799",
    "lng": "150.943"
  },
  {
    "country": "AU",
    "name": "Freshwater",
    "lat": "-33.77867",
    "lng": "151.28569"
  },
  {
    "country": "AU",
    "name": "Tieri",
    "lat": "-23.03829",
    "lng": "148.34463"
  },
  {
    "country": "AU",
    "name": "Kingsbury",
    "lat": "-37.71406",
    "lng": "145.03509"
  },
  {
    "country": "AU",
    "name": "Taringa",
    "lat": "-27.49061",
    "lng": "152.97861"
  },
  {
    "country": "AU",
    "name": "Inala",
    "lat": "-27.59715",
    "lng": "152.97432"
  },
  {
    "country": "AU",
    "name": "Mount Lawley",
    "lat": "-31.93439",
    "lng": "115.8716"
  },
  {
    "country": "AU",
    "name": "Main Beach",
    "lat": "-27.97879",
    "lng": "153.4266"
  },
  {
    "country": "AU",
    "name": "Paradise",
    "lat": "-34.87361",
    "lng": "138.66896"
  },
  {
    "country": "AU",
    "name": "Blair Athol",
    "lat": "-34.85889",
    "lng": "138.59656"
  },
  {
    "country": "AU",
    "name": "Athelstone",
    "lat": "-34.87019",
    "lng": "138.6999"
  },
  {
    "country": "AU",
    "name": "Wooloowin",
    "lat": "-27.42244",
    "lng": "153.04204"
  },
  {
    "country": "AU",
    "name": "Zillmere",
    "lat": "-27.35591",
    "lng": "153.04453"
  },
  {
    "country": "AU",
    "name": "Taigum",
    "lat": "-27.34265",
    "lng": "153.04444"
  },
  {
    "country": "AU",
    "name": "Bracken Ridge",
    "lat": "-27.3171",
    "lng": "153.03097"
  },
  {
    "country": "AU",
    "name": "Mango Hill",
    "lat": "-27.24349",
    "lng": "153.02384"
  },
  {
    "country": "AU",
    "name": "Woolloongabba",
    "lat": "-27.48855",
    "lng": "153.03655"
  },
  {
    "country": "AU",
    "name": "Milton",
    "lat": "-27.47039",
    "lng": "153.00312"
  },
  {
    "country": "AU",
    "name": "Fortitude Valley",
    "lat": "-27.45706",
    "lng": "153.03178"
  },
  {
    "country": "AU",
    "name": "Windsor",
    "lat": "-27.43631",
    "lng": "153.02882"
  },
  {
    "country": "AU",
    "name": "Twin Waters",
    "lat": "-26.61",
    "lng": "153"
  },
  {
    "country": "AU",
    "name": "Bridegman Downs",
    "lat": "-27.35538",
    "lng": "152.99432"
  },
  {
    "country": "AU",
    "name": "Canada Bay",
    "lat": "-33.85",
    "lng": "151.15"
  },
  {
    "country": "AU",
    "name": "Canterbury",
    "lat": "-33.91192",
    "lng": "151.11862"
  },
  {
    "country": "AU",
    "name": "Forresters Beach",
    "lat": "-33.407",
    "lng": "151.476"
  },
  {
    "country": "AU",
    "name": "Tamborine Mountain",
    "lat": "-27.96954",
    "lng": "153.19937"
  },
  {
    "country": "AU",
    "name": "East Melbourne",
    "lat": "-37.81667",
    "lng": "144.9879"
  },
  {
    "country": "AU",
    "name": "Rainbow Beach",
    "lat": "-25.90432",
    "lng": "153.09174"
  },
  {
    "country": "AU",
    "name": "North Shore",
    "lat": "-31.40237",
    "lng": "152.90185"
  },
  {
    "country": "AU",
    "name": "North Ryde",
    "lat": "-33.79677",
    "lng": "151.12436"
  },
  {
    "country": "AU",
    "name": "Stirling",
    "lat": "-31.88343",
    "lng": "115.8099"
  },
  {
    "country": "AU",
    "name": "Caroline Springs",
    "lat": "-37.74124",
    "lng": "144.73631"
  },
  {
    "country": "AU",
    "name": "Hoppers Crossing",
    "lat": "-37.88264",
    "lng": "144.7003"
  },
  {
    "country": "AU",
    "name": "West Melbourne",
    "lat": "-37.81014",
    "lng": "144.95"
  },
  {
    "country": "AU",
    "name": "Rouse Hill",
    "lat": "-33.68207",
    "lng": "150.9154"
  },
  {
    "country": "AU",
    "name": "Logan City",
    "lat": "-27.63917",
    "lng": "153.10944"
  },
  {
    "country": "AU",
    "name": "Carindale",
    "lat": "-27.50578",
    "lng": "153.10236"
  },
  {
    "country": "AU",
    "name": "Parramatta",
    "lat": "-33.8178",
    "lng": "151.00348"
  },
  {
    "country": "AU",
    "name": "Macquarie",
    "lat": "-35.25126",
    "lng": "149.06363"
  },
  {
    "country": "AU",
    "name": "Ferntree Gully",
    "lat": "-37.88461",
    "lng": "145.29539"
  },
  {
    "country": "AU",
    "name": "Fullarton",
    "lat": "-34.951",
    "lng": "138.629"
  },
  {
    "country": "AU",
    "name": "Macarthur",
    "lat": "-35.40885",
    "lng": "149.12696"
  },
  {
    "country": "AU",
    "name": "Phillip Island",
    "lat": "-38.48349",
    "lng": "145.23102"
  },
  {
    "country": "AU",
    "name": "Springwood",
    "lat": "-27.61183",
    "lng": "153.12899"
  },
  {
    "country": "AU",
    "name": "Adelaide Hills",
    "lat": "-34.91119",
    "lng": "138.70735"
  },
  {
    "country": "AU",
    "name": "Erskine",
    "lat": "-32.55717",
    "lng": "115.70657"
  },
  {
    "country": "AU",
    "name": "Canning Vale",
    "lat": "-32.05799",
    "lng": "115.91814"
  },
  {
    "country": "AU",
    "name": "Varsity Lakes",
    "lat": "-28.0894",
    "lng": "153.4122"
  },
  {
    "country": "AU",
    "name": "Roselands",
    "lat": "-33.93317",
    "lng": "151.0732"
  },
  {
    "country": "AU",
    "name": "Oxenford",
    "lat": "-27.89033",
    "lng": "153.31309"
  },
  {
    "country": "AU",
    "name": "Toormina",
    "lat": "-30.35384",
    "lng": "153.08843"
  },
  {
    "country": "AU",
    "name": "Glenmore Park",
    "lat": "-33.79068",
    "lng": "150.6693"
  },
  {
    "country": "AU",
    "name": "Southbank",
    "lat": "-37.8228",
    "lng": "144.96434"
  },
  {
    "country": "AU",
    "name": "Magnetic Island",
    "lat": "-19.15514",
    "lng": "146.8485"
  },
  {
    "country": "AU",
    "name": "St Kilda East",
    "lat": "-37.86594",
    "lng": "145.00018"
  },
  {
    "country": "AU",
    "name": "Docklands",
    "lat": "-37.8149",
    "lng": "144.95052"
  },
  {
    "country": "AU",
    "name": "Shoalwater",
    "lat": "-32.29088",
    "lng": "115.71101"
  },
  {
    "country": "AU",
    "name": "Melton West",
    "lat": "-37.67852",
    "lng": "144.56883"
  },
  {
    "country": "AU",
    "name": "Brookfield",
    "lat": "-37.7008",
    "lng": "144.56025"
  },
  {
    "country": "AU",
    "name": "Kurunjang",
    "lat": "-37.67587",
    "lng": "144.5969"
  },
  {
    "country": "AU",
    "name": "Ashwood",
    "lat": "-37.86659",
    "lng": "145.10553"
  },
  {
    "country": "AU",
    "name": "Glen Iris",
    "lat": "-37.85995",
    "lng": "145.05489"
  },
  {
    "country": "AU",
    "name": "Elsternwick",
    "lat": "-37.88441",
    "lng": "145.00434"
  },
  {
    "country": "AU",
    "name": "Elwood",
    "lat": "-37.88214",
    "lng": "144.98215"
  },
  {
    "country": "AU",
    "name": "Burwood",
    "lat": "-37.84978",
    "lng": "145.11901"
  },
  {
    "country": "AU",
    "name": "Box Hill South",
    "lat": "-37.83236",
    "lng": "145.12098"
  },
  {
    "country": "AU",
    "name": "Blackburn",
    "lat": "-37.81901",
    "lng": "145.15326"
  },
  {
    "country": "AU",
    "name": "Canterbury",
    "lat": "-37.8247",
    "lng": "145.08476"
  },
  {
    "country": "AU",
    "name": "Hawthorn East",
    "lat": "-37.82484",
    "lng": "145.0464"
  },
  {
    "country": "AU",
    "name": "Kew East",
    "lat": "-37.79758",
    "lng": "145.05378"
  },
  {
    "country": "AU",
    "name": "Balwyn North",
    "lat": "-37.79086",
    "lng": "145.09386"
  },
  {
    "country": "AU",
    "name": "Mont Albert North",
    "lat": "-37.80043",
    "lng": "145.10828"
  },
  {
    "country": "AU",
    "name": "Box Hill North",
    "lat": "-37.80266",
    "lng": "145.12656"
  },
  {
    "country": "AU",
    "name": "Blackburn North",
    "lat": "-37.80931",
    "lng": "145.1518"
  },
  {
    "country": "AU",
    "name": "Blackburn South",
    "lat": "-37.83975",
    "lng": "145.15549"
  },
  {
    "country": "AU",
    "name": "Chadstone",
    "lat": "-37.88766",
    "lng": "145.09519"
  },
  {
    "country": "AU",
    "name": "Malvern East",
    "lat": "-37.87397",
    "lng": "145.04253"
  },
  {
    "country": "AU",
    "name": "Oakleigh South",
    "lat": "-37.92416",
    "lng": "145.09146"
  },
  {
    "country": "AU",
    "name": "Caulfield South",
    "lat": "-37.89562",
    "lng": "145.02597"
  },
  {
    "country": "AU",
    "name": "Brighton East",
    "lat": "-37.90232",
    "lng": "145.01734"
  },
  {
    "country": "AU",
    "name": "Hampton East",
    "lat": "-37.93695",
    "lng": "145.02863"
  },
  {
    "country": "AU",
    "name": "Black Rock",
    "lat": "-37.97357",
    "lng": "145.01636"
  },
  {
    "country": "AU",
    "name": "Aspendale Gardens",
    "lat": "-38.02277",
    "lng": "145.11798"
  },
  {
    "country": "AU",
    "name": "Booval",
    "lat": "-27.61328",
    "lng": "152.78944"
  },
  {
    "country": "AU",
    "name": "North Booval",
    "lat": "-27.60392",
    "lng": "152.79485"
  },
  {
    "country": "AU",
    "name": "North Ipswich",
    "lat": "-27.60286",
    "lng": "152.76146"
  },
  {
    "country": "AU",
    "name": "Brassall",
    "lat": "-27.59753",
    "lng": "152.74755"
  },
  {
    "country": "AU",
    "name": "Silkstone",
    "lat": "-27.62126",
    "lng": "152.78768"
  },
  {
    "country": "AU",
    "name": "Eastern Heights",
    "lat": "-27.62849",
    "lng": "152.77828"
  },
  {
    "country": "AU",
    "name": "Raceview",
    "lat": "-27.63472",
    "lng": "152.77519"
  },
  {
    "country": "AU",
    "name": "Flinders View",
    "lat": "-27.65046",
    "lng": "152.77451"
  },
  {
    "country": "AU",
    "name": "Deebing Heights",
    "lat": "-27.66719",
    "lng": "152.74867"
  },
  {
    "country": "AU",
    "name": "Yamanto",
    "lat": "-27.66027",
    "lng": "152.73863"
  },
  {
    "country": "AU",
    "name": "Redbank Plains",
    "lat": "-27.64613",
    "lng": "152.85965"
  },
  {
    "country": "AU",
    "name": "Collingwood Park",
    "lat": "-27.61282",
    "lng": "152.86008"
  },
  {
    "country": "AU",
    "name": "Clontarf",
    "lat": "-27.25341",
    "lng": "153.07835"
  },
  {
    "country": "AU",
    "name": "Woody Point",
    "lat": "-27.25608",
    "lng": "153.10427"
  },
  {
    "country": "AU",
    "name": "Ballarat Central",
    "lat": "-37.56206",
    "lng": "143.85082"
  },
  {
    "country": "AU",
    "name": "Golden Point",
    "lat": "-37.57493",
    "lng": "143.8687"
  },
  {
    "country": "AU",
    "name": "Delacombe",
    "lat": "-37.58911",
    "lng": "143.81472"
  },
  {
    "country": "AU",
    "name": "St Albans",
    "lat": "-37.74496",
    "lng": "144.80049"
  },
  {
    "country": "AU",
    "name": "St Leonards",
    "lat": "-33.82344",
    "lng": "151.19836"
  },
  {
    "country": "AU",
    "name": "St Kilda West",
    "lat": "-37.85988",
    "lng": "144.97108"
  },
  {
    "country": "AU",
    "name": "Eleebana",
    "lat": "-32.9896",
    "lng": "151.63642"
  },
  {
    "country": "AU",
    "name": "Summer Hill",
    "lat": "-33.89146",
    "lng": "151.13825"
  },
  {
    "country": "AU",
    "name": "Bohle Plains",
    "lat": "-19.31365",
    "lng": "146.69186"
  },
  {
    "country": "AU",
    "name": "Jacobs Well",
    "lat": "-27.77992",
    "lng": "153.36153"
  },
  {
    "country": "AU",
    "name": "Launching Place",
    "lat": "-37.78058",
    "lng": "145.56834"
  },
  {
    "country": "AU",
    "name": "Saint Andrews Beach",
    "lat": "-38.4141",
    "lng": "144.82436"
  },
  {
    "country": "AU",
    "name": "West Perth",
    "lat": "-31.94896",
    "lng": "115.84199"
  },
  {
    "country": "AU",
    "name": "Altona North",
    "lat": "-37.83487",
    "lng": "144.84735"
  },
  {
    "country": "AU",
    "name": "Balcatta",
    "lat": "-31.87501",
    "lng": "115.82839"
  },
  {
    "country": "AU",
    "name": "Belmont",
    "lat": "-31.9435",
    "lng": "115.9255"
  },
  {
    "country": "AU",
    "name": "Bateau Bay",
    "lat": "-33.38334",
    "lng": "151.46671"
  },
  {
    "country": "AU",
    "name": "Macmasters Beach",
    "lat": "-33.49663",
    "lng": "151.42215"
  },
  {
    "country": "AU",
    "name": "Paraburdoo",
    "lat": "-23.20417",
    "lng": "117.66973"
  },
  {
    "country": "AU",
    "name": "Pottsville Beach",
    "lat": "-28.38853",
    "lng": "153.56564"
  },
  {
    "country": "AU",
    "name": "Thursday Island",
    "lat": "-10.58257",
    "lng": "142.21949"
  },
  {
    "country": "AU",
    "name": "East Perth",
    "lat": "-31.95872",
    "lng": "115.87109"
  },
  {
    "country": "AU",
    "name": "Leederville",
    "lat": "-31.93628",
    "lng": "115.8419"
  },
  {
    "country": "AU",
    "name": "Doveton",
    "lat": "-37.99346",
    "lng": "145.23891"
  },
  {
    "country": "AU",
    "name": "Endeavour Hills",
    "lat": "-37.97695",
    "lng": "145.25866"
  },
  {
    "country": "AU",
    "name": "Tighes Hill",
    "lat": "-32.90732",
    "lng": "151.7509"
  },
  {
    "country": "AU",
    "name": "Bossley Park",
    "lat": "-33.86184",
    "lng": "150.8841"
  },
  {
    "country": "AU",
    "name": "White Gum Valley",
    "lat": "-32.06031",
    "lng": "115.77058"
  },
  {
    "country": "AU",
    "name": "Kellyville",
    "lat": "-33.71028",
    "lng": "150.95095"
  },
  {
    "country": "AU",
    "name": "Tapping",
    "lat": "-31.71947",
    "lng": "115.79559"
  },
  {
    "country": "AU",
    "name": "Casuarina",
    "lat": "-28.30042",
    "lng": "153.57064"
  },
  {
    "country": "AU",
    "name": "Taylors Lakes",
    "lat": "-37.69863",
    "lng": "144.78631"
  },
  {
    "country": "AU",
    "name": "Cherrybrook",
    "lat": "-33.72197",
    "lng": "151.04607"
  },
  {
    "country": "AU",
    "name": "Woodvale",
    "lat": "-31.78928",
    "lng": "115.79676"
  },
  {
    "country": "AU",
    "name": "Bellfield",
    "lat": "-37.75309",
    "lng": "145.03848"
  },
  {
    "country": "AU",
    "name": "Roxburgh Park",
    "lat": "-37.62581",
    "lng": "144.92555"
  },
  {
    "country": "AU",
    "name": "Eumemmerring",
    "lat": "-37.9978",
    "lng": "145.24821"
  },
  {
    "country": "AU",
    "name": "Prestons",
    "lat": "-33.94185",
    "lng": "150.8717"
  },
  {
    "country": "AU",
    "name": "Warriewood",
    "lat": "-33.68857",
    "lng": "151.29534"
  },
  {
    "country": "AU",
    "name": "Beeliar",
    "lat": "-32.13339",
    "lng": "115.80637"
  },
  {
    "country": "AU",
    "name": "Lynbrook",
    "lat": "-38.05588",
    "lng": "145.25615"
  },
  {
    "country": "AU",
    "name": "Botanic Ridge",
    "lat": "-38.13922",
    "lng": "145.26841"
  },
  {
    "country": "AU",
    "name": "Orelia",
    "lat": "-32.2333",
    "lng": "115.82227"
  },
  {
    "country": "AU",
    "name": "Waterways",
    "lat": "-38.01478",
    "lng": "145.1305"
  },
  {
    "country": "AU",
    "name": "Wyndham Vale",
    "lat": "-37.89138",
    "lng": "144.62368"
  },
  {
    "country": "AU",
    "name": "Ballajura",
    "lat": "-31.84062",
    "lng": "115.89549"
  },
  {
    "country": "AU",
    "name": "Ardross",
    "lat": "-32.02696",
    "lng": "115.83548"
  },
  {
    "country": "AU",
    "name": "Long Gully",
    "lat": "-36.74305",
    "lng": "144.25788"
  },
  {
    "country": "AU",
    "name": "Willetton",
    "lat": "-32.05251",
    "lng": "115.88782"
  },
  {
    "country": "AU",
    "name": "Travancore",
    "lat": "-37.78076",
    "lng": "144.93545"
  },
  {
    "country": "AU",
    "name": "Carramar",
    "lat": "-31.69023",
    "lng": "115.77159"
  },
  {
    "country": "AU",
    "name": "Seaholme",
    "lat": "-37.864",
    "lng": "144.84504"
  },
  {
    "country": "AU",
    "name": "South Kingsville",
    "lat": "-37.83018",
    "lng": "144.8709"
  },
  {
    "country": "AU",
    "name": "Safety Beach",
    "lat": "-38.31535",
    "lng": "145.00027"
  },
  {
    "country": "AU",
    "name": "Blind Bight",
    "lat": "-38.21427",
    "lng": "145.3377"
  },
  {
    "country": "AU",
    "name": "Alexander Heights",
    "lat": "-31.82758",
    "lng": "115.86501"
  },
  {
    "country": "AU",
    "name": "Singleton",
    "lat": "-32.44403",
    "lng": "115.75725"
  },
  {
    "country": "AU",
    "name": "Ridgewood",
    "lat": "-31.6615",
    "lng": "115.72261"
  },
  {
    "country": "AU",
    "name": "Delahey",
    "lat": "-37.7198",
    "lng": "144.77732"
  },
  {
    "country": "AU",
    "name": "Wilson",
    "lat": "-32.02058",
    "lng": "115.91181"
  },
  {
    "country": "AU",
    "name": "Butler",
    "lat": "-31.64298",
    "lng": "115.70431"
  },
  {
    "country": "AU",
    "name": "Darch",
    "lat": "-31.81255",
    "lng": "115.8458"
  },
  {
    "country": "AU",
    "name": "Queens Park",
    "lat": "-32.00314",
    "lng": "115.94621"
  },
  {
    "country": "AU",
    "name": "Innaloo",
    "lat": "-31.89272",
    "lng": "115.79508"
  },
  {
    "country": "AU",
    "name": "Cannon Hill",
    "lat": "-27.47237",
    "lng": "153.09475"
  },
  {
    "country": "AU",
    "name": "Booragoon",
    "lat": "-32.03945",
    "lng": "115.83369"
  },
  {
    "country": "AU",
    "name": "Rossmoyne",
    "lat": "-32.03965",
    "lng": "115.86781"
  },
  {
    "country": "AU",
    "name": "Seville Grove",
    "lat": "-32.13645",
    "lng": "115.98905"
  },
  {
    "country": "AU",
    "name": "Murrumba Downs",
    "lat": "-27.26733",
    "lng": "153.01053"
  },
  {
    "country": "AU",
    "name": "Cabramatta",
    "lat": "-33.89743",
    "lng": "150.93446"
  },
  {
    "country": "AU",
    "name": "Campsie",
    "lat": "-33.9125",
    "lng": "151.10279"
  },
  {
    "country": "AU",
    "name": "Casula",
    "lat": "-33.95222",
    "lng": "150.89949"
  },
  {
    "country": "AU",
    "name": "Knoxfield",
    "lat": "-37.88978",
    "lng": "145.24962"
  },
  {
    "country": "AU",
    "name": "Chambers Flat",
    "lat": "-27.74811",
    "lng": "153.07764"
  },
  {
    "country": "AU",
    "name": "Brookdale",
    "lat": "-32.16696",
    "lng": "116.00193"
  },
  {
    "country": "AU",
    "name": "Little Mountain",
    "lat": "-26.78436",
    "lng": "153.09218"
  },
  {
    "country": "AU",
    "name": "Glendenning",
    "lat": "-33.7483",
    "lng": "150.85411"
  },
  {
    "country": "AU",
    "name": "Greystanes",
    "lat": "-33.82346",
    "lng": "150.94607"
  },
  {
    "country": "AU",
    "name": "Sinagra",
    "lat": "-31.74261",
    "lng": "115.80633"
  },
  {
    "country": "AU",
    "name": "Langford",
    "lat": "-32.04092",
    "lng": "115.94157"
  },
  {
    "country": "AU",
    "name": "Padbury",
    "lat": "-31.80645",
    "lng": "115.7688"
  },
  {
    "country": "AU",
    "name": "East Victoria Park",
    "lat": "-31.98894",
    "lng": "115.90388"
  },
  {
    "country": "AU",
    "name": "Milperra",
    "lat": "-33.93934",
    "lng": "150.98148"
  },
  {
    "country": "AU",
    "name": "Soldiers Hill",
    "lat": "-37.54962",
    "lng": "143.85872"
  },
  {
    "country": "AU",
    "name": "Tecoma",
    "lat": "-37.90303",
    "lng": "145.34468"
  },
  {
    "country": "AU",
    "name": "Palmyra",
    "lat": "-32.04502",
    "lng": "115.78589"
  },
  {
    "country": "AU",
    "name": "Stratton",
    "lat": "-31.86828",
    "lng": "116.04066"
  },
  {
    "country": "AU",
    "name": "Tootgarook",
    "lat": "-38.3777",
    "lng": "144.85015"
  },
  {
    "country": "AU",
    "name": "Yagoona",
    "lat": "-33.9049",
    "lng": "151.01996"
  },
  {
    "country": "AU",
    "name": "Bell Park",
    "lat": "-38.10793",
    "lng": "144.33839"
  },
  {
    "country": "AU",
    "name": "Bell Post Hill",
    "lat": "-38.09564",
    "lng": "144.31968"
  },
  {
    "country": "AU",
    "name": "Quarry Hill",
    "lat": "-36.77646",
    "lng": "144.28024"
  },
  {
    "country": "AU",
    "name": "Park Orchards",
    "lat": "-37.77688",
    "lng": "145.21463"
  },
  {
    "country": "AU",
    "name": "Golden Square",
    "lat": "-36.77265",
    "lng": "144.25271"
  },
  {
    "country": "AU",
    "name": "Annerley",
    "lat": "-27.51228",
    "lng": "153.03248"
  },
  {
    "country": "AU",
    "name": "Highton",
    "lat": "-38.17058",
    "lng": "144.3114"
  },
  {
    "country": "AU",
    "name": "Kealba",
    "lat": "-37.7371",
    "lng": "144.8283"
  },
  {
    "country": "AU",
    "name": "Jacana",
    "lat": "-37.68778",
    "lng": "144.91111"
  },
  {
    "country": "AU",
    "name": "Dulwich Hill",
    "lat": "-33.9041",
    "lng": "151.13945"
  },
  {
    "country": "AU",
    "name": "Viewbank",
    "lat": "-37.73991",
    "lng": "145.09323"
  },
  {
    "country": "AU",
    "name": "Highvale",
    "lat": "-27.37227",
    "lng": "152.80195"
  },
  {
    "country": "AU",
    "name": "Chirnside Park",
    "lat": "-37.7386",
    "lng": "145.31431"
  },
  {
    "country": "AU",
    "name": "Coolaroo",
    "lat": "-37.65675",
    "lng": "144.9346"
  },
  {
    "country": "AU",
    "name": "Junction Village",
    "lat": "-38.13636",
    "lng": "145.29684"
  },
  {
    "country": "AU",
    "name": "Meadow Heights",
    "lat": "-37.65117",
    "lng": "144.91855"
  },
  {
    "country": "AU",
    "name": "Middle Park",
    "lat": "-37.85116",
    "lng": "144.96201"
  },
  {
    "country": "AU",
    "name": "Westminster",
    "lat": "-31.86744",
    "lng": "115.83919"
  },
  {
    "country": "AU",
    "name": "Paralowie",
    "lat": "-34.75705",
    "lng": "138.60819"
  },
  {
    "country": "AU",
    "name": "Bertram",
    "lat": "-32.24369",
    "lng": "115.84572"
  },
  {
    "country": "AU",
    "name": "Bibra Lake",
    "lat": "-32.09764",
    "lng": "115.81921"
  },
  {
    "country": "AU",
    "name": "Dianella",
    "lat": "-31.88822",
    "lng": "115.87186"
  },
  {
    "country": "AU",
    "name": "Duncraig",
    "lat": "-31.83291",
    "lng": "115.7759"
  },
  {
    "country": "AU",
    "name": "Hammond Park",
    "lat": "-32.16853",
    "lng": "115.8504"
  },
  {
    "country": "AU",
    "name": "Hillman",
    "lat": "-32.28327",
    "lng": "115.76364"
  },
  {
    "country": "AU",
    "name": "Yallambie",
    "lat": "-37.72515",
    "lng": "145.09352"
  },
  {
    "country": "AU",
    "name": "Kardinya",
    "lat": "-32.06561",
    "lng": "115.81483"
  },
  {
    "country": "AU",
    "name": "Karrinyup",
    "lat": "-31.87233",
    "lng": "115.77684"
  },
  {
    "country": "AU",
    "name": "Kewdale",
    "lat": "-31.97886",
    "lng": "115.95159"
  },
  {
    "country": "AU",
    "name": "Millars Well",
    "lat": "-20.74168",
    "lng": "116.81731"
  },
  {
    "country": "AU",
    "name": "Ocean Reef",
    "lat": "-31.75871",
    "lng": "115.73601"
  },
  {
    "country": "AU",
    "name": "Samson",
    "lat": "-32.06996",
    "lng": "115.7977"
  },
  {
    "country": "AU",
    "name": "Port Kennedy",
    "lat": "-32.37342",
    "lng": "115.7515"
  },
  {
    "country": "AU",
    "name": "Secret Harbour",
    "lat": "-32.40589",
    "lng": "115.75852"
  },
  {
    "country": "AU",
    "name": "Success",
    "lat": "-32.14281",
    "lng": "115.84999"
  },
  {
    "country": "AU",
    "name": "Tuart Hill",
    "lat": "-31.89808",
    "lng": "115.83495"
  },
  {
    "country": "AU",
    "name": "Thornlie",
    "lat": "-32.06003",
    "lng": "115.955"
  },
  {
    "country": "AU",
    "name": "Winthrop",
    "lat": "-32.05216",
    "lng": "115.82972"
  },
  {
    "country": "AU",
    "name": "Yangebup",
    "lat": "-32.12065",
    "lng": "115.81623"
  },
  {
    "country": "AU",
    "name": "Yokine",
    "lat": "-31.90113",
    "lng": "115.85319"
  },
  {
    "country": "AU",
    "name": "Punchbowl",
    "lat": "-33.92893",
    "lng": "151.05111"
  },
  {
    "country": "AU",
    "name": "Parafield Gardens",
    "lat": "-34.78254",
    "lng": "138.61077"
  },
  {
    "country": "AU",
    "name": "Brooklyn",
    "lat": "-37.81609",
    "lng": "144.8415"
  },
  {
    "country": "AU",
    "name": "Hillside",
    "lat": "-37.69047",
    "lng": "144.74172"
  },
  {
    "country": "AU",
    "name": "Redcliffe",
    "lat": "-31.93845",
    "lng": "115.94645"
  },
  {
    "country": "AU",
    "name": "Wavell Heights",
    "lat": "-27.39385",
    "lng": "153.04698"
  },
  {
    "country": "AU",
    "name": "Bayswater",
    "lat": "-31.91686",
    "lng": "115.91776"
  },
  {
    "country": "AU",
    "name": "The Vines",
    "lat": "-31.75492",
    "lng": "116.00238"
  },
  {
    "country": "AU",
    "name": "Springvale",
    "lat": "-35.16687",
    "lng": "147.33058"
  },
  {
    "country": "AU",
    "name": "St Clair",
    "lat": "-33.79728",
    "lng": "150.7847"
  },
  {
    "country": "AU",
    "name": "Grange",
    "lat": "-27.42251",
    "lng": "153.01527"
  },
  {
    "country": "AU",
    "name": "Kirwan",
    "lat": "-19.30323",
    "lng": "146.72531"
  },
  {
    "country": "AU",
    "name": "Beldon",
    "lat": "-31.77466",
    "lng": "115.7627"
  },
  {
    "country": "AU",
    "name": "St James",
    "lat": "-32.00004",
    "lng": "115.9098"
  },
  {
    "country": "AU",
    "name": "Braybrook",
    "lat": "-37.78671",
    "lng": "144.85484"
  },
  {
    "country": "AU",
    "name": "Cairnlea",
    "lat": "-37.75931",
    "lng": "144.78781"
  },
  {
    "country": "AU",
    "name": "Bundoora",
    "lat": "-37.69825",
    "lng": "145.05967"
  },
  {
    "country": "AU",
    "name": "Patterson Lakes",
    "lat": "-38.06934",
    "lng": "145.14327"
  },
  {
    "country": "AU",
    "name": "Southern River",
    "lat": "-32.10658",
    "lng": "115.95896"
  },
  {
    "country": "AU",
    "name": "Skye",
    "lat": "-38.10505",
    "lng": "145.2163"
  },
  {
    "country": "AU",
    "name": "City of Cockburn",
    "lat": "-32.10261",
    "lng": "115.84422"
  },
  {
    "country": "AU",
    "name": "Beaumont Hills",
    "lat": "-33.69993",
    "lng": "150.9411"
  },
  {
    "country": "AU",
    "name": "North Adelaide",
    "lat": "-34.90733",
    "lng": "138.59141"
  },
  {
    "country": "AU",
    "name": "Victoria Park",
    "lat": "-31.97619",
    "lng": "115.90525"
  },
  {
    "country": "AU",
    "name": "Milsons Point",
    "lat": "-33.846",
    "lng": "151.21192"
  },
  {
    "country": "AU",
    "name": "Forrest",
    "lat": "-35.31499",
    "lng": "149.12859"
  },
  {
    "country": "AU",
    "name": "Cranbourne South",
    "lat": "-38.13502",
    "lng": "145.23958"
  },
  {
    "country": "AU",
    "name": "Bondi Junction",
    "lat": "-33.89275",
    "lng": "151.24723"
  },
  {
    "country": "AU",
    "name": "Bald Hills",
    "lat": "-27.32112",
    "lng": "153.00857"
  },
  {
    "country": "AU",
    "name": "East Geelong",
    "lat": "-38.15568",
    "lng": "144.37202"
  },
  {
    "country": "AU",
    "name": "Beecroft",
    "lat": "-33.74954",
    "lng": "151.0648"
  },
  {
    "country": "AU",
    "name": "Williams Landing",
    "lat": "-37.8619",
    "lng": "144.74371"
  },
  {
    "country": "AU",
    "name": "Nickol",
    "lat": "-20.74558",
    "lng": "116.7954"
  },
  {
    "country": "AU",
    "name": "Lane Cove North",
    "lat": "-33.80543",
    "lng": "151.16638"
  },
  {
    "country": "AU",
    "name": "Carrolls Creek",
    "lat": "-28.82272",
    "lng": "152.10305"
  },
  {
    "country": "AU",
    "name": "Ascot",
    "lat": "-27.43154",
    "lng": "153.058"
  },
  {
    "country": "AU",
    "name": "Robertson",
    "lat": "-27.56583",
    "lng": "153.05738"
  },
  {
    "country": "AU",
    "name": "Nathan",
    "lat": "-27.55888",
    "lng": "153.0623"
  },
  {
    "country": "AU",
    "name": "Chermside West",
    "lat": "-27.38383",
    "lng": "153.01586"
  },
  {
    "country": "AU",
    "name": "Everton Park",
    "lat": "-27.40732",
    "lng": "152.9884"
  },
  {
    "country": "AU",
    "name": "Gordon Park",
    "lat": "-27.41899",
    "lng": "153.02547"
  },
  {
    "country": "AU",
    "name": "Stafford",
    "lat": "-27.41044",
    "lng": "153.01105"
  },
  {
    "country": "AU",
    "name": "Stafford Heights",
    "lat": "-27.39354",
    "lng": "153.0105"
  },
  {
    "country": "AU",
    "name": "Wilston",
    "lat": "-27.43218",
    "lng": "153.01904"
  },
  {
    "country": "AU",
    "name": "Burbank",
    "lat": "-27.55584",
    "lng": "153.14701"
  },
  {
    "country": "AU",
    "name": "Coopers Plains",
    "lat": "-27.56463",
    "lng": "153.04067"
  },
  {
    "country": "AU",
    "name": "Forest Lake",
    "lat": "-27.62563",
    "lng": "152.96883"
  },
  {
    "country": "AU",
    "name": "Greenslopes",
    "lat": "-27.50815",
    "lng": "153.04951"
  },
  {
    "country": "AU",
    "name": "Mackenzie",
    "lat": "-27.54351",
    "lng": "153.12057"
  },
  {
    "country": "AU",
    "name": "Mansfield",
    "lat": "-27.53929",
    "lng": "153.09895"
  },
  {
    "country": "AU",
    "name": "Mount Gravatt East",
    "lat": "-27.5405",
    "lng": "153.08221"
  },
  {
    "country": "AU",
    "name": "Richlands",
    "lat": "-27.59616",
    "lng": "152.95321"
  },
  {
    "country": "AU",
    "name": "Seventeen Mile Rocks",
    "lat": "-27.5507",
    "lng": "152.95896"
  },
  {
    "country": "AU",
    "name": "Sunnybank Hills",
    "lat": "-27.61025",
    "lng": "153.05388"
  },
  {
    "country": "AU",
    "name": "Upper Mount Gravatt",
    "lat": "-27.56128",
    "lng": "153.08453"
  },
  {
    "country": "AU",
    "name": "Yeerongpilly",
    "lat": "-27.5215",
    "lng": "153.01234"
  },
  {
    "country": "AU",
    "name": "Yeronga",
    "lat": "-27.51571",
    "lng": "153.01642"
  },
  {
    "country": "AU",
    "name": "Balmoral",
    "lat": "-27.45341",
    "lng": "153.0668"
  },
  {
    "country": "AU",
    "name": "Camp Hill",
    "lat": "-27.49354",
    "lng": "153.07629"
  },
  {
    "country": "AU",
    "name": "Chandler",
    "lat": "-27.51398",
    "lng": "153.14907"
  },
  {
    "country": "AU",
    "name": "Manly West",
    "lat": "-27.47382",
    "lng": "153.16641"
  },
  {
    "country": "AU",
    "name": "Morningside",
    "lat": "-27.46165",
    "lng": "153.07511"
  },
  {
    "country": "AU",
    "name": "Seven Hills",
    "lat": "-27.48341",
    "lng": "153.07474"
  },
  {
    "country": "AU",
    "name": "Wynnum West",
    "lat": "-27.45824",
    "lng": "153.15319"
  },
  {
    "country": "AU",
    "name": "Kenmore Hills",
    "lat": "-27.5042",
    "lng": "152.93183"
  },
  {
    "country": "AU",
    "name": "Pullenvale",
    "lat": "-27.52283",
    "lng": "152.88651"
  },
  {
    "country": "AU",
    "name": "Riverhills",
    "lat": "-27.55928",
    "lng": "152.91106"
  },
  {
    "country": "AU",
    "name": "East Ipswich",
    "lat": "-27.60637",
    "lng": "152.77232"
  },
  {
    "country": "AU",
    "name": "Sadliers Crossing",
    "lat": "-27.61251",
    "lng": "152.74577"
  },
  {
    "country": "AU",
    "name": "Springfield",
    "lat": "-27.65365",
    "lng": "152.91716"
  },
  {
    "country": "AU",
    "name": "Tivoli",
    "lat": "-27.59278",
    "lng": "152.76798"
  },
  {
    "country": "AU",
    "name": "Cedar Vale",
    "lat": "-27.88923",
    "lng": "153.02891"
  },
  {
    "country": "AU",
    "name": "Logan Reserve",
    "lat": "-27.72414",
    "lng": "153.09002"
  },
  {
    "country": "AU",
    "name": "North Maclean",
    "lat": "-27.76759",
    "lng": "153.01646"
  },
  {
    "country": "AU",
    "name": "Park Ridge South",
    "lat": "-27.72707",
    "lng": "153.0332"
  },
  {
    "country": "AU",
    "name": "Rochedale South",
    "lat": "-27.59521",
    "lng": "153.12332"
  },
  {
    "country": "AU",
    "name": "Waterford West",
    "lat": "-27.69056",
    "lng": "153.13319"
  },
  {
    "country": "AU",
    "name": "Caboolture South",
    "lat": "-27.09389",
    "lng": "152.94874"
  },
  {
    "country": "AU",
    "name": "Ferny Hills",
    "lat": "-27.39594",
    "lng": "152.93737"
  },
  {
    "country": "AU",
    "name": "Samford Valley",
    "lat": "-27.3727",
    "lng": "152.86699"
  },
  {
    "country": "AU",
    "name": "Flemington",
    "lat": "-37.78825",
    "lng": "144.93001"
  },
  {
    "country": "AU",
    "name": "Fairfield",
    "lat": "-37.77977",
    "lng": "145.01764"
  },
  {
    "country": "AU",
    "name": "Heidelberg Heights",
    "lat": "-37.74313",
    "lng": "145.05695"
  },
  {
    "country": "AU",
    "name": "Watsonia North",
    "lat": "-37.69981",
    "lng": "145.08468"
  },
  {
    "country": "AU",
    "name": "Westmeadows",
    "lat": "-37.67604",
    "lng": "144.88701"
  },
  {
    "country": "AU",
    "name": "Essendon North",
    "lat": "-37.74225",
    "lng": "144.90546"
  },
  {
    "country": "AU",
    "name": "Essendon West",
    "lat": "-37.75758",
    "lng": "144.87903"
  },
  {
    "country": "AU",
    "name": "Keilor East",
    "lat": "-37.73261",
    "lng": "144.86504"
  },
  {
    "country": "AU",
    "name": "Coburg North",
    "lat": "-37.72867",
    "lng": "144.96134"
  },
  {
    "country": "AU",
    "name": "Gowanbrae",
    "lat": "-37.70823",
    "lng": "144.89079"
  },
  {
    "country": "AU",
    "name": "Hadfield",
    "lat": "-37.70728",
    "lng": "144.9416"
  },
  {
    "country": "AU",
    "name": "Oak Park",
    "lat": "-37.71842",
    "lng": "144.91945"
  },
  {
    "country": "AU",
    "name": "Pascoe Vale South",
    "lat": "-37.73973",
    "lng": "144.94615"
  },
  {
    "country": "AU",
    "name": "North Warrandyte",
    "lat": "-37.72924",
    "lng": "145.21574"
  },
  {
    "country": "AU",
    "name": "Bayswater North",
    "lat": "-37.82612",
    "lng": "145.29831"
  },
  {
    "country": "AU",
    "name": "Croydon Hills",
    "lat": "-37.77651",
    "lng": "145.26355"
  },
  {
    "country": "AU",
    "name": "Croydon South",
    "lat": "-37.81232",
    "lng": "145.2681"
  },
  {
    "country": "AU",
    "name": "Kilsyth South",
    "lat": "-37.82033",
    "lng": "145.31599"
  },
  {
    "country": "AU",
    "name": "Warranwood",
    "lat": "-37.77555",
    "lng": "145.24728"
  },
  {
    "country": "AU",
    "name": "Vermont South",
    "lat": "-37.85747",
    "lng": "145.1827"
  },
  {
    "country": "AU",
    "name": "Officer South",
    "lat": "-38.0863",
    "lng": "145.40208"
  },
  {
    "country": "AU",
    "name": "Cranbourne East",
    "lat": "-38.11531",
    "lng": "145.29814"
  },
  {
    "country": "AU",
    "name": "Cranbourne North",
    "lat": "-38.08292",
    "lng": "145.27805"
  },
  {
    "country": "AU",
    "name": "Cranbourne West",
    "lat": "-38.0965",
    "lng": "145.26707"
  },
  {
    "country": "AU",
    "name": "Narre Warren South",
    "lat": "-38.04369",
    "lng": "145.2923"
  },
  {
    "country": "AU",
    "name": "Dandenong North",
    "lat": "-37.96649",
    "lng": "145.2081"
  },
  {
    "country": "AU",
    "name": "Noble Park North",
    "lat": "-37.94978",
    "lng": "145.19257"
  },
  {
    "country": "AU",
    "name": "Frankston North",
    "lat": "-38.12352",
    "lng": "145.14836"
  },
  {
    "country": "AU",
    "name": "Frankston South",
    "lat": "-38.16604",
    "lng": "145.13643"
  },
  {
    "country": "AU",
    "name": "Sandhurst",
    "lat": "-38.081",
    "lng": "145.20767"
  },
  {
    "country": "AU",
    "name": "Langwarrin South",
    "lat": "-38.19868",
    "lng": "145.18068"
  },
  {
    "country": "AU",
    "name": "Rosebud West",
    "lat": "-38.36444",
    "lng": "144.87748"
  },
  {
    "country": "AU",
    "name": "Keilor Downs",
    "lat": "-37.72337",
    "lng": "144.80839"
  },
  {
    "country": "AU",
    "name": "Keilor Lodge",
    "lat": "-37.69997",
    "lng": "144.80332"
  },
  {
    "country": "AU",
    "name": "Keilor Park",
    "lat": "-37.72025",
    "lng": "144.85422"
  },
  {
    "country": "AU",
    "name": "Sunshine North",
    "lat": "-37.76987",
    "lng": "144.82787"
  },
  {
    "country": "AU",
    "name": "Sunshine West",
    "lat": "-37.79117",
    "lng": "144.81637"
  },
  {
    "country": "AU",
    "name": "Altona Meadows",
    "lat": "-37.88413",
    "lng": "144.78367"
  },
  {
    "country": "AU",
    "name": "Williamstown North",
    "lat": "-37.85515",
    "lng": "144.88259"
  },
  {
    "country": "AU",
    "name": "Kingsville",
    "lat": "-37.80819",
    "lng": "144.87911"
  },
  {
    "country": "AU",
    "name": "Seddon",
    "lat": "-37.80607",
    "lng": "144.8907"
  },
  {
    "country": "AU",
    "name": "West Footscray",
    "lat": "-37.79746",
    "lng": "144.87727"
  },
  {
    "country": "AU",
    "name": "Burnside Heights",
    "lat": "-37.72691",
    "lng": "144.75225"
  },
  {
    "country": "AU",
    "name": "Taylors Hill",
    "lat": "-37.70988",
    "lng": "144.75483"
  },
  {
    "country": "AU",
    "name": "Allambie Heights",
    "lat": "-33.76655",
    "lng": "151.24981"
  },
  {
    "country": "AU",
    "name": "Balmain East",
    "lat": "-33.8571",
    "lng": "151.19282"
  },
  {
    "country": "AU",
    "name": "Banksia",
    "lat": "-33.94601",
    "lng": "151.14304"
  },
  {
    "country": "AU",
    "name": "Bardwell Valley",
    "lat": "-33.93344",
    "lng": "151.13668"
  },
  {
    "country": "AU",
    "name": "Belfield",
    "lat": "-33.90354",
    "lng": "151.08467"
  },
  {
    "country": "AU",
    "name": "Berala",
    "lat": "-33.87197",
    "lng": "151.03386"
  },
  {
    "country": "AU",
    "name": "Berowra Heights",
    "lat": "-33.61211",
    "lng": "151.13754"
  },
  {
    "country": "AU",
    "name": "Beverly Park",
    "lat": "-33.97707",
    "lng": "151.13437"
  },
  {
    "country": "AU",
    "name": "Bexley North",
    "lat": "-33.93848",
    "lng": "151.11385"
  },
  {
    "country": "AU",
    "name": "Bilgola Beach",
    "lat": "-33.64487",
    "lng": "151.32427"
  },
  {
    "country": "AU",
    "name": "Blackett",
    "lat": "-33.73792",
    "lng": "150.81812"
  },
  {
    "country": "AU",
    "name": "Bondi Beach",
    "lat": "-33.89079",
    "lng": "151.27852"
  },
  {
    "country": "AU",
    "name": "Cabramatta West",
    "lat": "-33.89669",
    "lng": "150.91056"
  },
  {
    "country": "AU",
    "name": "Cambridge Park",
    "lat": "-33.74784",
    "lng": "150.72208"
  },
  {
    "country": "AU",
    "name": "Camden South",
    "lat": "-34.08312",
    "lng": "150.69491"
  },
  {
    "country": "AU",
    "name": "Caringbah South",
    "lat": "-34.05662",
    "lng": "151.12149"
  },
  {
    "country": "AU",
    "name": "Castle Cove",
    "lat": "-33.78655",
    "lng": "151.20925"
  },
  {
    "country": "AU",
    "name": "Chatswood West",
    "lat": "-33.79402",
    "lng": "151.16492"
  },
  {
    "country": "AU",
    "name": "Church Point",
    "lat": "-33.6451",
    "lng": "151.28367"
  },
  {
    "country": "AU",
    "name": "Carramar",
    "lat": "-33.88382",
    "lng": "150.96153"
  },
  {
    "country": "AU",
    "name": "Cecil Park",
    "lat": "-33.87433",
    "lng": "150.84177"
  },
  {
    "country": "AU",
    "name": "Clemton Park",
    "lat": "-33.93476",
    "lng": "151.09046"
  },
  {
    "country": "AU",
    "name": "Concord West",
    "lat": "-33.84809",
    "lng": "151.08609"
  },
  {
    "country": "AU",
    "name": "Constitution Hill",
    "lat": "-33.79259",
    "lng": "150.97627"
  },
  {
    "country": "AU",
    "name": "Cremorne Point",
    "lat": "-33.84008",
    "lng": "151.22698"
  },
  {
    "country": "AU",
    "name": "Darlington",
    "lat": "-33.89103",
    "lng": "151.19548"
  },
  {
    "country": "AU",
    "name": "Denham Court",
    "lat": "-33.98307",
    "lng": "150.84606"
  },
  {
    "country": "AU",
    "name": "Denistone",
    "lat": "-33.79835",
    "lng": "151.09051"
  },
  {
    "country": "AU",
    "name": "Dolls Point",
    "lat": "-33.99498",
    "lng": "151.14552"
  },
  {
    "country": "AU",
    "name": "Dundas Valley",
    "lat": "-33.78826",
    "lng": "151.05261"
  },
  {
    "country": "AU",
    "name": "East Lindfield",
    "lat": "-33.76664",
    "lng": "151.18685"
  },
  {
    "country": "AU",
    "name": "East Ryde",
    "lat": "-33.81031",
    "lng": "151.13153"
  },
  {
    "country": "AU",
    "name": "Emu Heights",
    "lat": "-33.73453",
    "lng": "150.64874"
  },
  {
    "country": "AU",
    "name": "Ermington",
    "lat": "-33.81483",
    "lng": "151.05467"
  },
  {
    "country": "AU",
    "name": "Fairfield East",
    "lat": "-33.86938",
    "lng": "150.97129"
  },
  {
    "country": "AU",
    "name": "Fairfield Heights",
    "lat": "-33.86445",
    "lng": "150.93884"
  },
  {
    "country": "AU",
    "name": "Fairlight",
    "lat": "-33.79575",
    "lng": "151.27346"
  },
  {
    "country": "AU",
    "name": "Glen Alpine",
    "lat": "-34.086",
    "lng": "150.78512"
  },
  {
    "country": "AU",
    "name": "Guildford West",
    "lat": "-33.85242",
    "lng": "150.97395"
  },
  {
    "country": "AU",
    "name": "Harris Park",
    "lat": "-33.82285",
    "lng": "151.00781"
  },
  {
    "country": "AU",
    "name": "Hassall Grove",
    "lat": "-33.73349",
    "lng": "150.83542"
  },
  {
    "country": "AU",
    "name": "Hornsby Heights",
    "lat": "-33.6713",
    "lng": "151.09428"
  },
  {
    "country": "AU",
    "name": "Horsley Park",
    "lat": "-33.84322",
    "lng": "150.84889"
  },
  {
    "country": "AU",
    "name": "Hurstville",
    "lat": "-33.9677",
    "lng": "151.10149"
  },
  {
    "country": "AU",
    "name": "Ingleside",
    "lat": "-33.68462",
    "lng": "151.26354"
  },
  {
    "country": "AU",
    "name": "Killara",
    "lat": "-33.76604",
    "lng": "151.16213"
  },
  {
    "country": "AU",
    "name": "Killarney Heights",
    "lat": "-33.77451",
    "lng": "151.22028"
  },
  {
    "country": "AU",
    "name": "Kingswood Park",
    "lat": "-33.76651",
    "lng": "150.7144"
  },
  {
    "country": "AU",
    "name": "Kogarah Bay",
    "lat": "-33.97951",
    "lng": "151.12119"
  },
  {
    "country": "AU",
    "name": "Kurraba Point",
    "lat": "-33.84235",
    "lng": "151.22256"
  },
  {
    "country": "AU",
    "name": "Koomooloo",
    "lat": "-33.5547",
    "lng": "139.46805"
  },
  {
    "country": "AU",
    "name": "Lane Cove West",
    "lat": "-33.81613",
    "lng": "151.15145"
  },
  {
    "country": "AU",
    "name": "Lewisham",
    "lat": "-33.89719",
    "lng": "151.14883"
  },
  {
    "country": "AU",
    "name": "Macquarie Park",
    "lat": "-33.775",
    "lng": "151.11248"
  },
  {
    "country": "AU",
    "name": "Marsfield",
    "lat": "-33.77784",
    "lng": "151.10574"
  },
  {
    "country": "AU",
    "name": "Miller",
    "lat": "-33.92089",
    "lng": "150.88469"
  },
  {
    "country": "AU",
    "name": "Narellan Vale",
    "lat": "-34.04974",
    "lng": "150.74392"
  },
  {
    "country": "AU",
    "name": "Narraweena",
    "lat": "-33.75519",
    "lng": "151.27659"
  },
  {
    "country": "AU",
    "name": "North Bondi",
    "lat": "-33.88787",
    "lng": "151.28075"
  },
  {
    "country": "AU",
    "name": "North Curl Curl",
    "lat": "-33.76434",
    "lng": "151.29727"
  },
  {
    "country": "AU",
    "name": "North Epping",
    "lat": "-33.75944",
    "lng": "151.09248"
  },
  {
    "country": "AU",
    "name": "North Manly",
    "lat": "-33.77561",
    "lng": "151.26921"
  },
  {
    "country": "AU",
    "name": "North Wahroonga",
    "lat": "-33.70531",
    "lng": "151.12278"
  },
  {
    "country": "AU",
    "name": "Ramsgate Beach",
    "lat": "-33.98523",
    "lng": "151.14634"
  },
  {
    "country": "AU",
    "name": "Roseville Chase",
    "lat": "-33.77852",
    "lng": "151.19677"
  },
  {
    "country": "AU",
    "name": "Scheyville",
    "lat": "-33.6045",
    "lng": "150.88314"
  },
  {
    "country": "AU",
    "name": "South Coogee",
    "lat": "-33.93106",
    "lng": "151.25599"
  },
  {
    "country": "AU",
    "name": "South Turramurra",
    "lat": "-33.74941",
    "lng": "151.11257"
  },
  {
    "country": "AU",
    "name": "South Windsor",
    "lat": "-33.61808",
    "lng": "150.80443"
  },
  {
    "country": "AU",
    "name": "Stanhope Gardens",
    "lat": "-33.72206",
    "lng": "150.92597"
  },
  {
    "country": "AU",
    "name": "Strathfield South",
    "lat": "-33.89252",
    "lng": "151.08334"
  },
  {
    "country": "AU",
    "name": "Telopea",
    "lat": "-33.79279",
    "lng": "151.03858"
  },
  {
    "country": "AU",
    "name": "Wareemba",
    "lat": "-33.85819",
    "lng": "151.13085"
  },
  {
    "country": "AU",
    "name": "Werrington County",
    "lat": "-33.7465",
    "lng": "150.73929"
  },
  {
    "country": "AU",
    "name": "Werrington Downs",
    "lat": "-33.74206",
    "lng": "150.72779"
  },
  {
    "country": "AU",
    "name": "West Pennant",
    "lat": "-33.7457",
    "lng": "151.04764"
  },
  {
    "country": "AU",
    "name": "West Ryde",
    "lat": "-33.80543",
    "lng": "151.07386"
  },
  {
    "country": "AU",
    "name": "Wollstonecraft",
    "lat": "-33.8328",
    "lng": "151.18981"
  },
  {
    "country": "AU",
    "name": "Woronora Heights",
    "lat": "-34.03562",
    "lng": "151.02734"
  },
  {
    "country": "AU",
    "name": "Virginia",
    "lat": "-12.51895",
    "lng": "131.02844"
  },
  {
    "country": "AU",
    "name": "Glenunga",
    "lat": "-34.95013",
    "lng": "138.63841"
  },
  {
    "country": "AU",
    "name": "Hazelwood Park",
    "lat": "-34.93947",
    "lng": "138.65879"
  },
  {
    "country": "AU",
    "name": "Kensington Gardens",
    "lat": "-34.92582",
    "lng": "138.66145"
  },
  {
    "country": "AU",
    "name": "Leabrook",
    "lat": "-34.92976",
    "lng": "138.65862"
  },
  {
    "country": "AU",
    "name": "Linden Park",
    "lat": "-34.94728",
    "lng": "138.65287"
  },
  {
    "country": "AU",
    "name": "Mount Osmond",
    "lat": "-34.9629",
    "lng": "138.65664"
  },
  {
    "country": "AU",
    "name": "Tusmore",
    "lat": "-34.93894",
    "lng": "138.65059"
  },
  {
    "country": "AU",
    "name": "Wattle Park",
    "lat": "-34.92516",
    "lng": "138.67501"
  },
  {
    "country": "AU",
    "name": "Hectorville",
    "lat": "-34.89157",
    "lng": "138.65892"
  },
  {
    "country": "AU",
    "name": "Albert Park",
    "lat": "-34.87201",
    "lng": "138.51966"
  },
  {
    "country": "AU",
    "name": "Allenby Gardens",
    "lat": "-34.89766",
    "lng": "138.55425"
  },
  {
    "country": "AU",
    "name": "Henley Beach",
    "lat": "-34.92029",
    "lng": "138.49442"
  },
  {
    "country": "AU",
    "name": "Royal Park",
    "lat": "-34.87415",
    "lng": "138.51189"
  },
  {
    "country": "AU",
    "name": "West Lakes Shore",
    "lat": "-34.8601",
    "lng": "138.48966"
  },
  {
    "country": "AU",
    "name": "Woodville North",
    "lat": "-34.872",
    "lng": "138.54309"
  },
  {
    "country": "AU",
    "name": "Woodville West",
    "lat": "-34.8864",
    "lng": "138.53095"
  },
  {
    "country": "AU",
    "name": "Glenelg East",
    "lat": "-34.9764",
    "lng": "138.52962"
  },
  {
    "country": "AU",
    "name": "North Brighton",
    "lat": "-35.00279",
    "lng": "138.52211"
  },
  {
    "country": "AU",
    "name": "Seacliff Park",
    "lat": "-35.02983",
    "lng": "138.53129"
  },
  {
    "country": "AU",
    "name": "Clovelly Park",
    "lat": "-34.99951",
    "lng": "138.57081"
  },
  {
    "country": "AU",
    "name": "Plympton Park",
    "lat": "-34.98071",
    "lng": "138.54918"
  },
  {
    "country": "AU",
    "name": "South Plympton",
    "lat": "-34.97682",
    "lng": "138.55588"
  },
  {
    "country": "AU",
    "name": "Trott Park",
    "lat": "-35.07576",
    "lng": "138.54189"
  },
  {
    "country": "AU",
    "name": "Clarence Gardens",
    "lat": "-34.97539",
    "lng": "138.57983"
  },
  {
    "country": "AU",
    "name": "Hawthorn",
    "lat": "-34.97384",
    "lng": "138.60738"
  },
  {
    "country": "AU",
    "name": "Marden",
    "lat": "-34.89569",
    "lng": "138.6378"
  },
  {
    "country": "AU",
    "name": "Payneham",
    "lat": "-34.89724",
    "lng": "138.64064"
  },
  {
    "country": "AU",
    "name": "Royston Park",
    "lat": "-34.90045",
    "lng": "138.63605"
  },
  {
    "country": "AU",
    "name": "Trinity Gardens",
    "lat": "-34.91438",
    "lng": "138.64141"
  },
  {
    "country": "AU",
    "name": "Noarlunga Downs",
    "lat": "-35.1504",
    "lng": "138.50395"
  },
  {
    "country": "AU",
    "name": "Alberton",
    "lat": "-34.85925",
    "lng": "138.52138"
  },
  {
    "country": "AU",
    "name": "Forestville",
    "lat": "-34.94946",
    "lng": "138.57845"
  },
  {
    "country": "AU",
    "name": "Millswood",
    "lat": "-34.95505",
    "lng": "138.58888"
  },
  {
    "country": "AU",
    "name": "Unley Park",
    "lat": "-34.96388",
    "lng": "138.60776"
  },
  {
    "country": "AU",
    "name": "Acton",
    "lat": "-35.27767",
    "lng": "149.11829"
  },
  {
    "country": "AU",
    "name": "Alfred Cove",
    "lat": "-32.03316",
    "lng": "115.81259"
  },
  {
    "country": "AU",
    "name": "Bedford",
    "lat": "-31.91132",
    "lng": "115.8892"
  },
  {
    "country": "AU",
    "name": "City Beach",
    "lat": "-31.9344",
    "lng": "115.76174"
  },
  {
    "country": "AU",
    "name": "Coolbinia",
    "lat": "-31.9147",
    "lng": "115.84894"
  },
  {
    "country": "AU",
    "name": "Crawley",
    "lat": "-31.98418",
    "lng": "115.81603"
  },
  {
    "country": "AU",
    "name": "Daglish",
    "lat": "-31.94828",
    "lng": "115.81899"
  },
  {
    "country": "AU",
    "name": "East Cannington",
    "lat": "-32.0098",
    "lng": "115.95503"
  },
  {
    "country": "AU",
    "name": "Eden Hill",
    "lat": "-31.88908",
    "lng": "115.94675"
  },
  {
    "country": "AU",
    "name": "Embleton",
    "lat": "-31.90355",
    "lng": "115.90902"
  },
  {
    "country": "AU",
    "name": "Ferndale",
    "lat": "-32.03494",
    "lng": "115.92233"
  },
  {
    "country": "AU",
    "name": "Harrisdale",
    "lat": "-32.11084",
    "lng": "115.93563"
  },
  {
    "country": "AU",
    "name": "Henley Brook",
    "lat": "-31.81393",
    "lng": "115.98807"
  },
  {
    "country": "AU",
    "name": "Hilton",
    "lat": "-32.06208",
    "lng": "115.78049"
  },
  {
    "country": "AU",
    "name": "Jindalee",
    "lat": "-31.64938",
    "lng": "115.69496"
  },
  {
    "country": "AU",
    "name": "Joondanna",
    "lat": "-31.90767",
    "lng": "115.84233"
  },
  {
    "country": "AU",
    "name": "Kallaroo",
    "lat": "-31.79098",
    "lng": "115.75298"
  },
  {
    "country": "AU",
    "name": "Mount Pleasant",
    "lat": "-32.03974",
    "lng": "115.84993"
  },
  {
    "country": "AU",
    "name": "Myaree",
    "lat": "-32.04",
    "lng": "115.81761"
  },
  {
    "country": "AU",
    "name": "Oakford",
    "lat": "-32.20094",
    "lng": "115.93391"
  },
  {
    "country": "AU",
    "name": "Parmelia",
    "lat": "-32.25784",
    "lng": "115.82208"
  },
  {
    "country": "AU",
    "name": "Rivervale",
    "lat": "-31.95546",
    "lng": "115.91306"
  },
  {
    "country": "AU",
    "name": "South Fremantle",
    "lat": "-32.06907",
    "lng": "115.75453"
  },
  {
    "country": "AU",
    "name": "South Guildford",
    "lat": "-31.9122",
    "lng": "115.96825"
  },
  {
    "country": "AU",
    "name": "South Lake",
    "lat": "-32.11125",
    "lng": "115.83873"
  },
  {
    "country": "AU",
    "name": "Watermans Bay",
    "lat": "-31.84915",
    "lng": "115.7559"
  },
  {
    "country": "AU",
    "name": "Wembley Downs",
    "lat": "-31.91169",
    "lng": "115.77358"
  },
  {
    "country": "AU",
    "name": "West Leederville",
    "lat": "-31.94141",
    "lng": "115.83117"
  },
  {
    "country": "AU",
    "name": "Woodbridge",
    "lat": "-31.88695",
    "lng": "115.99196"
  },
  {
    "country": "AU",
    "name": "Acton Park",
    "lat": "-42.87932",
    "lng": "147.48459"
  },
  {
    "country": "AU",
    "name": "West Moonah",
    "lat": "-42.84996",
    "lng": "147.28181"
  },
  {
    "country": "AU",
    "name": "Dynnyrne",
    "lat": "-42.90541",
    "lng": "147.31576"
  },
  {
    "country": "AU",
    "name": "Burleigh Waters",
    "lat": "-28.09975",
    "lng": "153.42463"
  },
  {
    "country": "AU",
    "name": "Clear Island Waters",
    "lat": "-28.05308",
    "lng": "153.39815"
  },
  {
    "country": "AU",
    "name": "Lower Beechmont",
    "lat": "-28.04751",
    "lng": "153.24572"
  },
  {
    "country": "AU",
    "name": "Mount Nathan",
    "lat": "-27.9643",
    "lng": "153.27198"
  },
  {
    "country": "AU",
    "name": "Ormeau Hills",
    "lat": "-27.79653",
    "lng": "153.2567"
  },
  {
    "country": "AU",
    "name": "Tallebudgera Valley",
    "lat": "-28.1927",
    "lng": "153.35489"
  },
  {
    "country": "AU",
    "name": "Lakelands",
    "lat": "-32.47754",
    "lng": "115.75573"
  },
  {
    "country": "AU",
    "name": "South Yunderup",
    "lat": "-32.5851",
    "lng": "115.78015"
  },
  {
    "country": "AU",
    "name": "Arcadia vale",
    "lat": "-33.06052",
    "lng": "151.58408"
  },
  {
    "country": "AU",
    "name": "Buff Point",
    "lat": "-33.22285",
    "lng": "151.53125"
  },
  {
    "country": "AU",
    "name": "Charmhaven",
    "lat": "-33.22671",
    "lng": "151.50284"
  },
  {
    "country": "AU",
    "name": "Chittaway Bay",
    "lat": "-33.32769",
    "lng": "151.42971"
  },
  {
    "country": "AU",
    "name": "Kingfisher Shores",
    "lat": "-33.16834",
    "lng": "151.55305"
  },
  {
    "country": "AU",
    "name": "Little Jilliby",
    "lat": "-33.24066",
    "lng": "151.37006"
  },
  {
    "country": "AU",
    "name": "Noraville",
    "lat": "-33.26785",
    "lng": "151.55352"
  },
  {
    "country": "AU",
    "name": "Tuggerawong",
    "lat": "-33.2804",
    "lng": "151.48044"
  },
  {
    "country": "AU",
    "name": "Bar Beach",
    "lat": "-32.94128",
    "lng": "151.76544"
  },
  {
    "country": "AU",
    "name": "Broadmeadow",
    "lat": "-32.92371",
    "lng": "151.72849"
  },
  {
    "country": "AU",
    "name": "Carrington",
    "lat": "-32.91501",
    "lng": "151.76436"
  },
  {
    "country": "AU",
    "name": "Cooks Hill",
    "lat": "-32.93244",
    "lng": "151.77114"
  },
  {
    "country": "AU",
    "name": "Elermore Vale",
    "lat": "-32.91621",
    "lng": "151.67665"
  },
  {
    "country": "AU",
    "name": "Hamilton",
    "lat": "-32.92207",
    "lng": "151.74711"
  },
  {
    "country": "AU",
    "name": "The Junction",
    "lat": "-32.93822",
    "lng": "151.75909"
  },
  {
    "country": "AU",
    "name": "Mayfield",
    "lat": "-32.89793",
    "lng": "151.73613"
  },
  {
    "country": "AU",
    "name": "Mayfield West",
    "lat": "-32.89195",
    "lng": "151.72711"
  },
  {
    "country": "AU",
    "name": "Merewether Heights",
    "lat": "-32.94733",
    "lng": "151.73565"
  },
  {
    "country": "AU",
    "name": "New Lambton Heights",
    "lat": "-32.92466",
    "lng": "151.69364"
  },
  {
    "country": "AU",
    "name": "North Lambton",
    "lat": "-32.90605",
    "lng": "151.70574"
  },
  {
    "country": "AU",
    "name": "Rankin Park",
    "lat": "-32.92516",
    "lng": "151.68016"
  },
  {
    "country": "AU",
    "name": "Waratah",
    "lat": "-32.90667",
    "lng": "151.72647"
  },
  {
    "country": "AU",
    "name": "Belmont North",
    "lat": "-33.02081",
    "lng": "151.66849"
  },
  {
    "country": "AU",
    "name": "Belmont South",
    "lat": "-33.04934",
    "lng": "151.65695"
  },
  {
    "country": "AU",
    "name": "Bolton Point",
    "lat": "-33.00177",
    "lng": "151.61013"
  },
  {
    "country": "AU",
    "name": "Cardiff Heights",
    "lat": "-32.93626",
    "lng": "151.67227"
  },
  {
    "country": "AU",
    "name": "Cardiff South",
    "lat": "-32.9547",
    "lng": "151.66446"
  },
  {
    "country": "AU",
    "name": "Coal Point",
    "lat": "-33.04225",
    "lng": "151.61159"
  },
  {
    "country": "AU",
    "name": "Fennell Bay",
    "lat": "-32.9922",
    "lng": "151.60008"
  },
  {
    "country": "AU",
    "name": "Floraville",
    "lat": "-33.01116",
    "lng": "151.6648"
  },
  {
    "country": "AU",
    "name": "Garden Suburb",
    "lat": "-32.94368",
    "lng": "151.68085"
  },
  {
    "country": "AU",
    "name": "Gateshead",
    "lat": "-32.98208",
    "lng": "151.69188"
  },
  {
    "country": "AU",
    "name": "Glendale",
    "lat": "-32.93194",
    "lng": "151.64103"
  },
  {
    "country": "AU",
    "name": "Highfields",
    "lat": "-32.95331",
    "lng": "151.71231"
  },
  {
    "country": "AU",
    "name": "Jewells",
    "lat": "-33.01386",
    "lng": "151.68308"
  },
  {
    "country": "AU",
    "name": "Tingira Heights",
    "lat": "-32.99725",
    "lng": "151.67021"
  },
  {
    "country": "AU",
    "name": "Windale",
    "lat": "-32.99277",
    "lng": "151.68167"
  },
  {
    "country": "AU",
    "name": "Toronto",
    "lat": "-33.01357",
    "lng": "151.59373"
  },
  {
    "country": "AU",
    "name": "Bolwarra Heights",
    "lat": "-32.701",
    "lng": "151.58541"
  },
  {
    "country": "AU",
    "name": "West Rockhampton",
    "lat": "-23.37941",
    "lng": "150.48175"
  },
  {
    "country": "AU",
    "name": "Black Mountain",
    "lat": "-26.39886",
    "lng": "152.87561"
  },
  {
    "country": "AU",
    "name": "Caloundra West",
    "lat": "-26.80634",
    "lng": "153.10894"
  },
  {
    "country": "AU",
    "name": "Dicky Beach",
    "lat": "-26.78364",
    "lng": "153.13766"
  },
  {
    "country": "AU",
    "name": "Peregian Springs",
    "lat": "-26.48801",
    "lng": "153.07577"
  },
  {
    "country": "AU",
    "name": "Albion Park Rail",
    "lat": "-34.56634",
    "lng": "150.79177"
  },
  {
    "country": "AU",
    "name": "Barrack Heights",
    "lat": "-34.56464",
    "lng": "150.85692"
  },
  {
    "country": "AU",
    "name": "Calderwood",
    "lat": "-34.5505",
    "lng": "150.71131"
  },
  {
    "country": "AU",
    "name": "Cordeaux Heights",
    "lat": "-34.44043",
    "lng": "150.83748"
  },
  {
    "country": "AU",
    "name": "Croom",
    "lat": "-34.59432",
    "lng": "150.84126"
  },
  {
    "country": "AU",
    "name": "East Corrimal",
    "lat": "-34.37606",
    "lng": "150.91078"
  },
  {
    "country": "AU",
    "name": "Koonawarra",
    "lat": "-34.50212",
    "lng": "150.80855"
  },
  {
    "country": "AU",
    "name": "West Wollongong",
    "lat": "-34.4248",
    "lng": "150.86417"
  },
  {
    "country": "AU",
    "name": "Lake Wendouree",
    "lat": "-37.54993",
    "lng": "143.8473"
  },
  {
    "country": "AU",
    "name": "White Hills",
    "lat": "-36.72875",
    "lng": "144.30525"
  },
  {
    "country": "AU",
    "name": "Nulsen",
    "lat": "-33.85696",
    "lng": "121.87499"
  },
  {
    "country": "AU",
    "name": "Breakwater",
    "lat": "-38.17987",
    "lng": "144.36765"
  },
  {
    "country": "AU",
    "name": "Hamlyn Heights",
    "lat": "-38.12108",
    "lng": "144.32799"
  },
  {
    "country": "AU",
    "name": "Wandana Heights",
    "lat": "-38.17577",
    "lng": "144.30387"
  },
  {
    "country": "AU",
    "name": "Monkland",
    "lat": "-26.21191",
    "lng": "152.68245"
  },
  {
    "country": "AU",
    "name": "East Launceston",
    "lat": "-41.43843",
    "lng": "147.15101"
  },
  {
    "country": "AU",
    "name": "Summerhill",
    "lat": "-41.46747",
    "lng": "147.12796"
  },
  {
    "country": "AU",
    "name": "West Launceston",
    "lat": "-41.45092",
    "lng": "147.13114"
  },
  {
    "country": "AU",
    "name": "Bilambil Heights",
    "lat": "-28.2161",
    "lng": "153.48415"
  },
  {
    "country": "AU",
    "name": "Tweed Heads West",
    "lat": "-28.18736",
    "lng": "153.52278"
  },
  {
    "country": "AU",
    "name": "Rangeville",
    "lat": "-27.58318",
    "lng": "151.97997"
  },
  {
    "country": "AU",
    "name": "Darling Heights",
    "lat": "-27.59659",
    "lng": "151.93045"
  },
  {
    "country": "AU",
    "name": "East Toowoomba",
    "lat": "-27.57086",
    "lng": "151.97422"
  },
  {
    "country": "AU",
    "name": "Top Camp",
    "lat": "-27.63584",
    "lng": "151.9392"
  },
  {
    "country": "AU",
    "name": "Wilsonton Heights",
    "lat": "-27.53227",
    "lng": "151.92444"
  },
  {
    "country": "AU",
    "name": "East Tamworth",
    "lat": "-31.08548",
    "lng": "150.93721"
  },
  {
    "country": "AU",
    "name": "South Tamworth",
    "lat": "-31.11",
    "lng": "150.92254"
  },
  {
    "country": "AU",
    "name": "Tinbeerwah",
    "lat": "-26.40443",
    "lng": "152.98256"
  },
  {
    "country": "AU",
    "name": "Cooroibah",
    "lat": "-26.36316",
    "lng": "152.98599"
  },
  {
    "country": "AU",
    "name": "East Albury",
    "lat": "-36.08144",
    "lng": "146.92991"
  },
  {
    "country": "AU",
    "name": "North Albury",
    "lat": "-36.05745",
    "lng": "146.92995"
  },
  {
    "country": "AU",
    "name": "South Albury",
    "lat": "-36.08654",
    "lng": "146.90905"
  },
  {
    "country": "AU",
    "name": "West Albury",
    "lat": "-36.07979",
    "lng": "146.89227"
  },
  {
    "country": "AU",
    "name": "Sunshine Coast",
    "lat": "-26.65682",
    "lng": "153.07955"
  },
  {
    "country": "AU",
    "name": "Marangaroo",
    "lat": "-31.82711",
    "lng": "115.83843"
  },
  {
    "country": "AU",
    "name": "Kalamunda",
    "lat": "-31.97372",
    "lng": "116.05845"
  },
  {
    "country": "AW",
    "name": "Oranjestad",
    "lat": "12.52398",
    "lng": "-70.02703"
  },
  {
    "country": "AX",
    "name": "Vårdö",
    "lat": "60.25",
    "lng": "20.38333"
  },
  {
    "country": "AX",
    "name": "Sund",
    "lat": "60.25",
    "lng": "20.11667"
  },
  {
    "country": "AX",
    "name": "Sottunga",
    "lat": "60.13023",
    "lng": "20.66683"
  },
  {
    "country": "AX",
    "name": "Saltvik",
    "lat": "60.28333",
    "lng": "20.05"
  },
  {
    "country": "AX",
    "name": "Lumparland",
    "lat": "60.11695",
    "lng": "20.25819"
  },
  {
    "country": "AX",
    "name": "Lemland",
    "lat": "60.07178",
    "lng": "20.08472"
  },
  {
    "country": "AX",
    "name": "Kumlinge",
    "lat": "60.26013",
    "lng": "20.77892"
  },
  {
    "country": "AX",
    "name": "Kökar",
    "lat": "59.92051",
    "lng": "20.90883"
  },
  {
    "country": "AX",
    "name": "Föglö",
    "lat": "60.01667",
    "lng": "20.41667"
  },
  {
    "country": "AX",
    "name": "Brändö",
    "lat": "60.41165",
    "lng": "21.04534"
  },
  {
    "country": "AX",
    "name": "Mariehamn",
    "lat": "60.09726",
    "lng": "19.93481"
  },
  {
    "country": "AX",
    "name": "Jomala",
    "lat": "60.14902",
    "lng": "19.951"
  },
  {
    "country": "AX",
    "name": "Hammarland",
    "lat": "60.21667",
    "lng": "19.75"
  },
  {
    "country": "AX",
    "name": "Geta",
    "lat": "60.37453",
    "lng": "19.84455"
  },
  {
    "country": "AX",
    "name": "Finström",
    "lat": "60.26667",
    "lng": "19.93333"
  },
  {
    "country": "AX",
    "name": "Eckerö",
    "lat": "60.21249",
    "lng": "19.61442"
  },
  {
    "country": "AZ",
    "name": "Sharur City",
    "lat": "39.55298",
    "lng": "44.97993"
  },
  {
    "country": "AZ",
    "name": "Prishibinskoye",
    "lat": "39.11998",
    "lng": "48.59383"
  },
  {
    "country": "AZ",
    "name": "Zangilan",
    "lat": "39.0884",
    "lng": "46.6513"
  },
  {
    "country": "AZ",
    "name": "Yaycı",
    "lat": "38.94052",
    "lng": "45.73244"
  },
  {
    "country": "AZ",
    "name": "Yardımlı",
    "lat": "38.90771",
    "lng": "48.24052"
  },
  {
    "country": "AZ",
    "name": "Novyy Karanlug",
    "lat": "39.79546",
    "lng": "47.10989"
  },
  {
    "country": "AZ",
    "name": "Xankandi",
    "lat": "39.8177",
    "lng": "46.7528"
  },
  {
    "country": "AZ",
    "name": "Əhmədbəyli",
    "lat": "39.88074",
    "lng": "48.39158"
  },
  {
    "country": "AZ",
    "name": "Shushi",
    "lat": "39.76006",
    "lng": "46.74989"
  },
  {
    "country": "AZ",
    "name": "Salyan",
    "lat": "39.59621",
    "lng": "48.98479"
  },
  {
    "country": "AZ",
    "name": "Şahbuz",
    "lat": "39.40722",
    "lng": "45.57389"
  },
  {
    "country": "AZ",
    "name": "Sedarak",
    "lat": "39.71427",
    "lng": "44.88455"
  },
  {
    "country": "AZ",
    "name": "Sumbatan-diza",
    "lat": "38.94804",
    "lng": "45.82572"
  },
  {
    "country": "AZ",
    "name": "Saatlı",
    "lat": "39.93214",
    "lng": "48.36892"
  },
  {
    "country": "AZ",
    "name": "Qubadlı",
    "lat": "39.34441",
    "lng": "46.58183"
  },
  {
    "country": "AZ",
    "name": "Qaraçala",
    "lat": "39.81614",
    "lng": "48.93792"
  },
  {
    "country": "AZ",
    "name": "Orjonikidze",
    "lat": "39.63571",
    "lng": "47.71199"
  },
  {
    "country": "AZ",
    "name": "Ordubad",
    "lat": "38.90961",
    "lng": "46.02274"
  },
  {
    "country": "AZ",
    "name": "Neftçala",
    "lat": "39.3768",
    "lng": "49.247"
  },
  {
    "country": "AZ",
    "name": "Nakhchivan",
    "lat": "39.20889",
    "lng": "45.41222"
  },
  {
    "country": "AZ",
    "name": "Mincivan",
    "lat": "39.03058",
    "lng": "46.7214"
  },
  {
    "country": "AZ",
    "name": "Masally",
    "lat": "39.03532",
    "lng": "48.6654"
  },
  {
    "country": "AZ",
    "name": "Lerik",
    "lat": "38.77388",
    "lng": "48.41497"
  },
  {
    "country": "AZ",
    "name": "Lankaran",
    "lat": "38.75428",
    "lng": "48.85062"
  },
  {
    "country": "AZ",
    "name": "Laçın",
    "lat": "39.59881",
    "lng": "46.55045"
  },
  {
    "country": "AZ",
    "name": "Qıvraq",
    "lat": "39.39939",
    "lng": "45.11513"
  },
  {
    "country": "AZ",
    "name": "Qırmızı Bazar",
    "lat": "39.67833",
    "lng": "46.94884"
  },
  {
    "country": "AZ",
    "name": "Kizhaba",
    "lat": "38.53461",
    "lng": "48.80546"
  },
  {
    "country": "AZ",
    "name": "Xocalı",
    "lat": "39.91297",
    "lng": "46.79028"
  },
  {
    "country": "AZ",
    "name": "Xıllı",
    "lat": "39.43012",
    "lng": "49.10166"
  },
  {
    "country": "AZ",
    "name": "Imishli",
    "lat": "39.87095",
    "lng": "48.05995"
  },
  {
    "country": "AZ",
    "name": "Horadiz",
    "lat": "39.44877",
    "lng": "47.33531"
  },
  {
    "country": "AZ",
    "name": "Haftoni",
    "lat": "38.76325",
    "lng": "48.76223"
  },
  {
    "country": "AZ",
    "name": "Hadrut",
    "lat": "39.52002",
    "lng": "47.0318"
  },
  {
    "country": "AZ",
    "name": "Fizuli",
    "lat": "39.60094",
    "lng": "47.14529"
  },
  {
    "country": "AZ",
    "name": "Jebrail",
    "lat": "39.39917",
    "lng": "47.02835"
  },
  {
    "country": "AZ",
    "name": "Dünyamalılar",
    "lat": "39.77278",
    "lng": "47.75889"
  },
  {
    "country": "AZ",
    "name": "Deste",
    "lat": "38.88375",
    "lng": "45.90963"
  },
  {
    "country": "AZ",
    "name": "Culfa",
    "lat": "38.95397",
    "lng": "45.62961"
  },
  {
    "country": "AZ",
    "name": "Jalilabad",
    "lat": "39.20963",
    "lng": "48.49186"
  },
  {
    "country": "AZ",
    "name": "Cahri",
    "lat": "39.34837",
    "lng": "45.41557"
  },
  {
    "country": "AZ",
    "name": "Boradigah",
    "lat": "38.93013",
    "lng": "48.7092"
  },
  {
    "country": "AZ",
    "name": "Pushkino",
    "lat": "39.45833",
    "lng": "48.545"
  },
  {
    "country": "AZ",
    "name": "Beylagan",
    "lat": "39.77556",
    "lng": "47.61861"
  },
  {
    "country": "AZ",
    "name": "Severo-Vostotchnyi Bank",
    "lat": "39.41117",
    "lng": "49.24792"
  },
  {
    "country": "AZ",
    "name": "Tazakend",
    "lat": "39.15459",
    "lng": "45.44282"
  },
  {
    "country": "AZ",
    "name": "Astara",
    "lat": "38.45598",
    "lng": "48.87498"
  },
  {
    "country": "AZ",
    "name": "Askyaran",
    "lat": "39.93667",
    "lng": "46.83278"
  },
  {
    "country": "AZ",
    "name": "Şirvan",
    "lat": "39.93778",
    "lng": "48.929"
  },
  {
    "country": "AZ",
    "name": "Ağdam",
    "lat": "39.99096",
    "lng": "46.92736"
  },
  {
    "country": "AZ",
    "name": "Sovetabad",
    "lat": "39.33667",
    "lng": "49.21414"
  },
  {
    "country": "AZ",
    "name": "Avşar",
    "lat": "39.97389",
    "lng": "47.42389"
  },
  {
    "country": "AZ",
    "name": "Birinci Aşıqlı",
    "lat": "39.81917",
    "lng": "47.67944"
  },
  {
    "country": "AZ",
    "name": "Yuxarı Aran",
    "lat": "39.73361",
    "lng": "47.655"
  },
  {
    "country": "AZ",
    "name": "Çalxanqala",
    "lat": "39.44167",
    "lng": "45.28333"
  },
  {
    "country": "AZ",
    "name": "Oğlanqala",
    "lat": "39.58694",
    "lng": "45.04611"
  },
  {
    "country": "AZ",
    "name": "Zyrya",
    "lat": "40.36613",
    "lng": "50.29198"
  },
  {
    "country": "AZ",
    "name": "Zardob",
    "lat": "40.21991",
    "lng": "47.70997"
  },
  {
    "country": "AZ",
    "name": "Zaqatala",
    "lat": "41.6316",
    "lng": "46.64479"
  },
  {
    "country": "AZ",
    "name": "Zabrat",
    "lat": "40.47746",
    "lng": "49.94174"
  },
  {
    "country": "AZ",
    "name": "Yevlakh",
    "lat": "40.61832",
    "lng": "47.15014"
  },
  {
    "country": "AZ",
    "name": "Yanıqlı",
    "lat": "40.8432",
    "lng": "45.6803"
  },
  {
    "country": "AZ",
    "name": "Xudat",
    "lat": "41.63052",
    "lng": "48.68161"
  },
  {
    "country": "AZ",
    "name": "Yelenendorf",
    "lat": "40.58584",
    "lng": "46.3189"
  },
  {
    "country": "AZ",
    "name": "Xaçmaz",
    "lat": "41.46426",
    "lng": "48.80565"
  },
  {
    "country": "AZ",
    "name": "Verkhniy Dashkesan",
    "lat": "40.49357",
    "lng": "46.07175"
  },
  {
    "country": "AZ",
    "name": "Vank",
    "lat": "40.05275",
    "lng": "46.54419"
  },
  {
    "country": "AZ",
    "name": "Ujar",
    "lat": "40.51902",
    "lng": "47.65423"
  },
  {
    "country": "AZ",
    "name": "Türkan",
    "lat": "40.3646",
    "lng": "50.22075"
  },
  {
    "country": "AZ",
    "name": "Tovuz",
    "lat": "40.99249",
    "lng": "45.62838"
  },
  {
    "country": "AZ",
    "name": "Terter",
    "lat": "40.34201",
    "lng": "46.93161"
  },
  {
    "country": "AZ",
    "name": "Sumqayıt",
    "lat": "40.58972",
    "lng": "49.66861"
  },
  {
    "country": "AZ",
    "name": "Kyzyl-Burun",
    "lat": "41.07811",
    "lng": "49.11564"
  },
  {
    "country": "AZ",
    "name": "Şuraabad",
    "lat": "40.81943",
    "lng": "49.46787"
  },
  {
    "country": "AZ",
    "name": "Qaraçuxur",
    "lat": "40.39667",
    "lng": "49.97361"
  },
  {
    "country": "AZ",
    "name": "Saray",
    "lat": "40.53299",
    "lng": "49.71681"
  },
  {
    "country": "AZ",
    "name": "Samur",
    "lat": "41.63671",
    "lng": "48.43028"
  },
  {
    "country": "AZ",
    "name": "Shamkhor",
    "lat": "40.82975",
    "lng": "46.0178"
  },
  {
    "country": "AZ",
    "name": "Shamakhi",
    "lat": "40.63141",
    "lng": "48.64137"
  },
  {
    "country": "AZ",
    "name": "Saloğlu",
    "lat": "41.27524",
    "lng": "45.35293"
  },
  {
    "country": "AZ",
    "name": "Sheki",
    "lat": "41.19194",
    "lng": "47.17056"
  },
  {
    "country": "AZ",
    "name": "Samux",
    "lat": "40.76485",
    "lng": "46.40868"
  },
  {
    "country": "AZ",
    "name": "Sabunçu",
    "lat": "40.4425",
    "lng": "49.94806"
  },
  {
    "country": "AZ",
    "name": "Sabirabad",
    "lat": "40.00869",
    "lng": "48.47701"
  },
  {
    "country": "AZ",
    "name": "Qusar",
    "lat": "41.4275",
    "lng": "48.4302"
  },
  {
    "country": "AZ",
    "name": "Quba",
    "lat": "41.36108",
    "lng": "48.51341"
  },
  {
    "country": "AZ",
    "name": "Qobustan",
    "lat": "40.08238",
    "lng": "49.41205"
  },
  {
    "country": "AZ",
    "name": "Hacıqabul",
    "lat": "40.03874",
    "lng": "48.94286"
  },
  {
    "country": "AZ",
    "name": "Qazax",
    "lat": "41.09246",
    "lng": "45.36561"
  },
  {
    "country": "AZ",
    "name": "Qax",
    "lat": "41.41826",
    "lng": "46.92043"
  },
  {
    "country": "AZ",
    "name": "Qasım İsmayılov",
    "lat": "40.81156",
    "lng": "46.26112"
  },
  {
    "country": "AZ",
    "name": "Qutqashen",
    "lat": "40.98247",
    "lng": "47.84909"
  },
  {
    "country": "AZ",
    "name": "Puta",
    "lat": "40.29667",
    "lng": "49.66028"
  },
  {
    "country": "AZ",
    "name": "Oğuz",
    "lat": "41.07128",
    "lng": "47.46528"
  },
  {
    "country": "AZ",
    "name": "Novosaratovka",
    "lat": "40.59811",
    "lng": "45.60079"
  },
  {
    "country": "AZ",
    "name": "Hacı Zeynalabdin",
    "lat": "40.62333",
    "lng": "49.55861"
  },
  {
    "country": "AZ",
    "name": "Nardaran",
    "lat": "40.55611",
    "lng": "50.00556"
  },
  {
    "country": "AZ",
    "name": "Naftalan",
    "lat": "40.50821",
    "lng": "46.8203"
  },
  {
    "country": "AZ",
    "name": "Mingelchaur",
    "lat": "40.76395",
    "lng": "47.05953"
  },
  {
    "country": "AZ",
    "name": "Maştağa",
    "lat": "40.52983",
    "lng": "50.00616"
  },
  {
    "country": "AZ",
    "name": "Mardakan",
    "lat": "40.49182",
    "lng": "50.14292"
  },
  {
    "country": "AZ",
    "name": "Qobustan",
    "lat": "40.5336",
    "lng": "48.92819"
  },
  {
    "country": "AZ",
    "name": "Mamrux",
    "lat": "41.54243",
    "lng": "46.767"
  },
  {
    "country": "AZ",
    "name": "Lökbatan",
    "lat": "40.3256",
    "lng": "49.73376"
  },
  {
    "country": "AZ",
    "name": "Qızılhacılı",
    "lat": "40.57362",
    "lng": "46.849"
  },
  {
    "country": "AZ",
    "name": "Kyurdarmir",
    "lat": "40.34532",
    "lng": "48.15085"
  },
  {
    "country": "AZ",
    "name": "Qobu",
    "lat": "40.40472",
    "lng": "49.71306"
  },
  {
    "country": "AZ",
    "name": "Kilyazi",
    "lat": "40.87098",
    "lng": "49.34233"
  },
  {
    "country": "AZ",
    "name": "Khyzy",
    "lat": "40.90576",
    "lng": "49.08127"
  },
  {
    "country": "AZ",
    "name": "Khirdalan",
    "lat": "40.44808",
    "lng": "49.75502"
  },
  {
    "country": "AZ",
    "name": "Khodzhi-Gasan",
    "lat": "40.41293",
    "lng": "49.76904"
  },
  {
    "country": "AZ",
    "name": "Korgöz",
    "lat": "40.30446",
    "lng": "49.6236"
  },
  {
    "country": "AZ",
    "name": "Qarayeri",
    "lat": "40.78718",
    "lng": "46.31714"
  },
  {
    "country": "AZ",
    "name": "Qaramanlı",
    "lat": "40.48135",
    "lng": "46.99339"
  },
  {
    "country": "AZ",
    "name": "Qaraxanlı",
    "lat": "41.04358",
    "lng": "45.65527"
  },
  {
    "country": "AZ",
    "name": "Qandax",
    "lat": "41.47546",
    "lng": "46.54128"
  },
  {
    "country": "AZ",
    "name": "Vurğun",
    "lat": "41.09524",
    "lng": "45.47111"
  },
  {
    "country": "AZ",
    "name": "Kerbakhiar",
    "lat": "40.10984",
    "lng": "46.04446"
  },
  {
    "country": "AZ",
    "name": "Qala",
    "lat": "40.44256",
    "lng": "50.16759"
  },
  {
    "country": "AZ",
    "name": "Qax İngiloy",
    "lat": "41.42412",
    "lng": "46.93859"
  },
  {
    "country": "AZ",
    "name": "Qaxbaş",
    "lat": "41.43254",
    "lng": "46.9646"
  },
  {
    "country": "AZ",
    "name": "İsmayıllı",
    "lat": "40.78485",
    "lng": "48.15141"
  },
  {
    "country": "AZ",
    "name": "Yeni Suraxanı",
    "lat": "40.43026",
    "lng": "50.03598"
  },
  {
    "country": "AZ",
    "name": "Gyuzdek",
    "lat": "40.37444",
    "lng": "49.68194"
  },
  {
    "country": "AZ",
    "name": "Geoktschai",
    "lat": "40.65055",
    "lng": "47.74219"
  },
  {
    "country": "AZ",
    "name": "Hövsan",
    "lat": "40.37444",
    "lng": "50.08528"
  },
  {
    "country": "AZ",
    "name": "Goranboy",
    "lat": "40.61028",
    "lng": "46.78972"
  },
  {
    "country": "AZ",
    "name": "Ganja",
    "lat": "40.68278",
    "lng": "46.36056"
  },
  {
    "country": "AZ",
    "name": "Kyadabek",
    "lat": "40.57055",
    "lng": "45.81229"
  },
  {
    "country": "AZ",
    "name": "Faldarlı",
    "lat": "41.46868",
    "lng": "46.51579"
  },
  {
    "country": "AZ",
    "name": "Corat",
    "lat": "40.57176",
    "lng": "49.70509"
  },
  {
    "country": "AZ",
    "name": "Ceyranbatan",
    "lat": "40.54194",
    "lng": "49.66073"
  },
  {
    "country": "AZ",
    "name": "Dzagam",
    "lat": "40.9033",
    "lng": "45.88564"
  },
  {
    "country": "AZ",
    "name": "Dondar Quşçu",
    "lat": "40.9539",
    "lng": "45.61942"
  },
  {
    "country": "AZ",
    "name": "Digah",
    "lat": "40.49257",
    "lng": "49.87477"
  },
  {
    "country": "AZ",
    "name": "Divichibazar",
    "lat": "41.20117",
    "lng": "48.98712"
  },
  {
    "country": "AZ",
    "name": "Yukhary-Dashkesan",
    "lat": "40.52393",
    "lng": "46.08186"
  },
  {
    "country": "AZ",
    "name": "Dolyar",
    "lat": "40.86278",
    "lng": "46.03493"
  },
  {
    "country": "AZ",
    "name": "Çobansığnaq",
    "lat": "40.75244",
    "lng": "45.70645"
  },
  {
    "country": "AZ",
    "name": "Çinarlı",
    "lat": "41.46965",
    "lng": "46.91582"
  },
  {
    "country": "AZ",
    "name": "Çatax",
    "lat": "40.72622",
    "lng": "45.55919"
  },
  {
    "country": "AZ",
    "name": "Buzovna",
    "lat": "40.51903",
    "lng": "50.11438"
  },
  {
    "country": "AZ",
    "name": "Binagadi",
    "lat": "40.46602",
    "lng": "49.82783"
  },
  {
    "country": "AZ",
    "name": "Biny Selo",
    "lat": "40.45076",
    "lng": "50.08686"
  },
  {
    "country": "AZ",
    "name": "Bilajer",
    "lat": "40.56441",
    "lng": "50.04002"
  },
  {
    "country": "AZ",
    "name": "Basqal",
    "lat": "40.7552",
    "lng": "48.39104"
  },
  {
    "country": "AZ",
    "name": "Baş Göynük",
    "lat": "41.32582",
    "lng": "47.11357"
  },
  {
    "country": "AZ",
    "name": "Barda",
    "lat": "40.37577",
    "lng": "47.12619"
  },
  {
    "country": "AZ",
    "name": "Belokany",
    "lat": "41.72626",
    "lng": "46.40478"
  },
  {
    "country": "AZ",
    "name": "Balakhani",
    "lat": "40.46344",
    "lng": "49.91893"
  },
  {
    "country": "AZ",
    "name": "Bilajari",
    "lat": "40.4444",
    "lng": "49.80566"
  },
  {
    "country": "AZ",
    "name": "Baku",
    "lat": "40.37767",
    "lng": "49.89201"
  },
  {
    "country": "AZ",
    "name": "Arıqıran",
    "lat": "40.53971",
    "lng": "45.61414"
  },
  {
    "country": "AZ",
    "name": "Arıqdam",
    "lat": "40.59313",
    "lng": "45.799"
  },
  {
    "country": "AZ",
    "name": "Pirallahı",
    "lat": "40.47013",
    "lng": "50.32476"
  },
  {
    "country": "AZ",
    "name": "Amirdzhan",
    "lat": "40.42639",
    "lng": "49.98361"
  },
  {
    "country": "AZ",
    "name": "Altıağac",
    "lat": "40.85927",
    "lng": "48.93477"
  },
  {
    "country": "AZ",
    "name": "Aliabad",
    "lat": "41.4829",
    "lng": "46.63483"
  },
  {
    "country": "AZ",
    "name": "Aghsu",
    "lat": "40.57028",
    "lng": "48.40087"
  },
  {
    "country": "AZ",
    "name": "Aghstafa",
    "lat": "41.11889",
    "lng": "45.45389"
  },
  {
    "country": "AZ",
    "name": "Ağdaş",
    "lat": "40.64699",
    "lng": "47.4738"
  },
  {
    "country": "AZ",
    "name": "Martakert",
    "lat": "40.21127",
    "lng": "46.82135"
  },
  {
    "country": "AZ",
    "name": "Agdzhabedy",
    "lat": "40.05015",
    "lng": "47.45937"
  },
  {
    "country": "AZ",
    "name": "Böyük Qaramurad",
    "lat": "40.57626",
    "lng": "45.63727"
  },
  {
    "country": "AZ",
    "name": "Mughan",
    "lat": "40.09902",
    "lng": "48.81886"
  },
  {
    "country": "AZ",
    "name": "Qabaqçöl",
    "lat": "41.75259",
    "lng": "46.27052"
  },
  {
    "country": "AZ",
    "name": "Bakıxanov",
    "lat": "40.41894",
    "lng": "49.96693"
  },
  {
    "country": "AZ",
    "name": "Qırmızı Samux",
    "lat": "40.93972",
    "lng": "46.37889"
  },
  {
    "country": "AZ",
    "name": "Hacıhüseynli",
    "lat": "41.45639",
    "lng": "48.64889"
  },
  {
    "country": "AZ",
    "name": "Aran",
    "lat": "40.62528",
    "lng": "46.97556"
  },
  {
    "country": "AZ",
    "name": "Samuxlu",
    "lat": "40.50833",
    "lng": "47.16917"
  },
  {
    "country": "AZ",
    "name": "Ramana",
    "lat": "40.44222",
    "lng": "49.98056"
  },
  {
    "country": "AZ",
    "name": "Badamdar",
    "lat": "40.34024",
    "lng": "49.8045"
  },
  {
    "country": "AZ",
    "name": "Heydarabad",
    "lat": "39.72286",
    "lng": "44.84846"
  },
  {
    "country": "BA",
    "name": "Zvornik",
    "lat": "44.38605",
    "lng": "19.10247"
  },
  {
    "country": "BA",
    "name": "Živinice",
    "lat": "44.54765",
    "lng": "17.37357"
  },
  {
    "country": "BA",
    "name": "Živinice",
    "lat": "44.44929",
    "lng": "18.64978"
  },
  {
    "country": "BA",
    "name": "Žepče",
    "lat": "44.42667",
    "lng": "18.03778"
  },
  {
    "country": "BA",
    "name": "Zenica",
    "lat": "44.20169",
    "lng": "17.90397"
  },
  {
    "country": "BA",
    "name": "Željezno Polje",
    "lat": "44.39875",
    "lng": "17.94103"
  },
  {
    "country": "BA",
    "name": "Zborište",
    "lat": "45.14593",
    "lng": "16.01728"
  },
  {
    "country": "BA",
    "name": "Zavidovići",
    "lat": "44.44583",
    "lng": "18.14972"
  },
  {
    "country": "BA",
    "name": "Zabrišće",
    "lat": "43.79224",
    "lng": "16.94224"
  },
  {
    "country": "BA",
    "name": "Vukovije Donje",
    "lat": "44.46209",
    "lng": "18.74941"
  },
  {
    "country": "BA",
    "name": "Vrnograč",
    "lat": "45.16369",
    "lng": "15.95444"
  },
  {
    "country": "BA",
    "name": "Vozuća",
    "lat": "44.35878",
    "lng": "18.35397"
  },
  {
    "country": "BA",
    "name": "Voljevac",
    "lat": "43.87873",
    "lng": "17.65861"
  },
  {
    "country": "BA",
    "name": "Vogošća",
    "lat": "43.90225",
    "lng": "18.34438"
  },
  {
    "country": "BA",
    "name": "Vlasenica",
    "lat": "44.18183",
    "lng": "18.94096"
  },
  {
    "country": "BA",
    "name": "Vitina",
    "lat": "43.2375",
    "lng": "17.48389"
  },
  {
    "country": "BA",
    "name": "Vitez",
    "lat": "44.15424",
    "lng": "17.79009"
  },
  {
    "country": "BA",
    "name": "Visoko",
    "lat": "43.98889",
    "lng": "18.17806"
  },
  {
    "country": "BA",
    "name": "Višegrad",
    "lat": "43.7826",
    "lng": "19.29256"
  },
  {
    "country": "BA",
    "name": "Vidoši",
    "lat": "43.77139",
    "lng": "17.02833"
  },
  {
    "country": "BA",
    "name": "Velika Obarska",
    "lat": "44.80461",
    "lng": "19.16183"
  },
  {
    "country": "BA",
    "name": "Velika Kladuša",
    "lat": "45.18497",
    "lng": "15.80579"
  },
  {
    "country": "BA",
    "name": "Velagići",
    "lat": "44.55618",
    "lng": "16.73349"
  },
  {
    "country": "BA",
    "name": "Varoška Rijeka",
    "lat": "45.08936",
    "lng": "16.01906"
  },
  {
    "country": "BA",
    "name": "Vareš",
    "lat": "44.16444",
    "lng": "18.32833"
  },
  {
    "country": "BA",
    "name": "Ustikolina",
    "lat": "43.58338",
    "lng": "18.79106"
  },
  {
    "country": "BA",
    "name": "Ugljevik",
    "lat": "44.66361",
    "lng": "19.02028"
  },
  {
    "country": "BA",
    "name": "Tuzla",
    "lat": "44.53842",
    "lng": "18.66709"
  },
  {
    "country": "BA",
    "name": "Turbe",
    "lat": "44.24352",
    "lng": "17.57499"
  },
  {
    "country": "BA",
    "name": "Tržačka Raštela",
    "lat": "44.97597",
    "lng": "15.78489"
  },
  {
    "country": "BA",
    "name": "Trnovo",
    "lat": "43.6658",
    "lng": "18.44593"
  },
  {
    "country": "BA",
    "name": "Trn",
    "lat": "44.85829",
    "lng": "17.23583"
  },
  {
    "country": "BA",
    "name": "Trebinje",
    "lat": "42.71197",
    "lng": "18.34362"
  },
  {
    "country": "BA",
    "name": "Travnik",
    "lat": "44.22637",
    "lng": "17.66583"
  },
  {
    "country": "BA",
    "name": "Tojšići",
    "lat": "44.50133",
    "lng": "18.78523"
  },
  {
    "country": "BA",
    "name": "Teslić",
    "lat": "44.60639",
    "lng": "17.85972"
  },
  {
    "country": "BA",
    "name": "Tešanj",
    "lat": "44.61191",
    "lng": "17.98552"
  },
  {
    "country": "BA",
    "name": "Tasovčići",
    "lat": "43.11333",
    "lng": "17.72"
  },
  {
    "country": "BA",
    "name": "Svodna",
    "lat": "45.0377",
    "lng": "16.54019"
  },
  {
    "country": "BA",
    "name": "Šumatac",
    "lat": "45.09743",
    "lng": "15.85818"
  },
  {
    "country": "BA",
    "name": "Šturlić",
    "lat": "45.06389",
    "lng": "15.77806"
  },
  {
    "country": "BA",
    "name": "Stupari",
    "lat": "44.31382",
    "lng": "18.68416"
  },
  {
    "country": "BA",
    "name": "Stolac",
    "lat": "43.084",
    "lng": "17.95995"
  },
  {
    "country": "BA",
    "name": "Stjepan-Polje",
    "lat": "44.71634",
    "lng": "18.25783"
  },
  {
    "country": "BA",
    "name": "Stijena",
    "lat": "44.9363",
    "lng": "16.02224"
  },
  {
    "country": "BA",
    "name": "Srebrenik",
    "lat": "44.70819",
    "lng": "18.48834"
  },
  {
    "country": "BA",
    "name": "Srebrenica",
    "lat": "44.10748",
    "lng": "19.29669"
  },
  {
    "country": "BA",
    "name": "Srbac",
    "lat": "45.0973",
    "lng": "17.52331"
  },
  {
    "country": "BA",
    "name": "Solina",
    "lat": "44.56226",
    "lng": "18.69322"
  },
  {
    "country": "BA",
    "name": "Sokolac",
    "lat": "43.93817",
    "lng": "18.80079"
  },
  {
    "country": "BA",
    "name": "Sladna",
    "lat": "44.72897",
    "lng": "18.42575"
  },
  {
    "country": "BA",
    "name": "Kneževo",
    "lat": "44.49071",
    "lng": "17.38161"
  },
  {
    "country": "BA",
    "name": "Šipovo",
    "lat": "44.28237",
    "lng": "17.08597"
  },
  {
    "country": "BA",
    "name": "Šerići",
    "lat": "44.46674",
    "lng": "18.5637"
  },
  {
    "country": "BA",
    "name": "Šekovići",
    "lat": "44.29896",
    "lng": "18.85532"
  },
  {
    "country": "BA",
    "name": "Sarajevo",
    "lat": "43.84864",
    "lng": "18.35644"
  },
  {
    "country": "BA",
    "name": "Sapna",
    "lat": "44.5038",
    "lng": "18.99818"
  },
  {
    "country": "BA",
    "name": "Sanski Most",
    "lat": "44.7667",
    "lng": "16.667"
  },
  {
    "country": "BA",
    "name": "Sanica",
    "lat": "44.61354",
    "lng": "16.64062"
  },
  {
    "country": "BA",
    "name": "Rumboci",
    "lat": "43.83154",
    "lng": "17.50273"
  },
  {
    "country": "BA",
    "name": "Rudo",
    "lat": "43.61781",
    "lng": "19.36719"
  },
  {
    "country": "BA",
    "name": "Rogatica",
    "lat": "43.79894",
    "lng": "19.00363"
  },
  {
    "country": "BA",
    "name": "Rodoč",
    "lat": "43.31453",
    "lng": "17.8029"
  },
  {
    "country": "BA",
    "name": "Ravno",
    "lat": "42.88741",
    "lng": "17.96555"
  },
  {
    "country": "BA",
    "name": "Radišići",
    "lat": "43.22302",
    "lng": "17.54056"
  },
  {
    "country": "BA",
    "name": "Puračić",
    "lat": "44.54562",
    "lng": "18.47865"
  },
  {
    "country": "BA",
    "name": "Novi Travnik",
    "lat": "44.17133",
    "lng": "17.65816"
  },
  {
    "country": "BA",
    "name": "Prozor",
    "lat": "43.82222",
    "lng": "17.60917"
  },
  {
    "country": "BA",
    "name": "Prnjavor",
    "lat": "44.87021",
    "lng": "17.66256"
  },
  {
    "country": "BA",
    "name": "Prijedor",
    "lat": "44.97991",
    "lng": "16.71401"
  },
  {
    "country": "BA",
    "name": "Priboj",
    "lat": "44.60233",
    "lng": "18.93165"
  },
  {
    "country": "BA",
    "name": "Pribinić",
    "lat": "44.6101",
    "lng": "17.68981"
  },
  {
    "country": "BA",
    "name": "Prača",
    "lat": "43.76367",
    "lng": "18.76512"
  },
  {
    "country": "BA",
    "name": "Potoci",
    "lat": "44.39261",
    "lng": "16.62001"
  },
  {
    "country": "BA",
    "name": "Potoci",
    "lat": "43.40953",
    "lng": "17.87855"
  },
  {
    "country": "BA",
    "name": "Posušje",
    "lat": "43.47281",
    "lng": "17.32621"
  },
  {
    "country": "BA",
    "name": "Popovi",
    "lat": "44.76547",
    "lng": "19.28667"
  },
  {
    "country": "BA",
    "name": "Polje-Bijela",
    "lat": "43.63299",
    "lng": "17.97216"
  },
  {
    "country": "BA",
    "name": "Podzvizd",
    "lat": "45.17417",
    "lng": "15.87361"
  },
  {
    "country": "BA",
    "name": "Podhum",
    "lat": "43.72295",
    "lng": "16.99887"
  },
  {
    "country": "BA",
    "name": "Petkovci",
    "lat": "44.46849",
    "lng": "19.07466"
  },
  {
    "country": "BA",
    "name": "Pelagićevo",
    "lat": "44.90105",
    "lng": "18.59185"
  },
  {
    "country": "BA",
    "name": "Pećigrad",
    "lat": "45.05444",
    "lng": "15.89694"
  },
  {
    "country": "BA",
    "name": "Peći",
    "lat": "44.63139",
    "lng": "16.7825"
  },
  {
    "country": "BA",
    "name": "Pazarić",
    "lat": "43.78882",
    "lng": "18.16049"
  },
  {
    "country": "BA",
    "name": "Pale",
    "lat": "43.81664",
    "lng": "18.56949"
  },
  {
    "country": "BA",
    "name": "Otoka",
    "lat": "44.96",
    "lng": "16.17917"
  },
  {
    "country": "BA",
    "name": "Ostrožac",
    "lat": "44.90866",
    "lng": "15.94045"
  },
  {
    "country": "BA",
    "name": "Oštra Luka",
    "lat": "44.99724",
    "lng": "18.58464"
  },
  {
    "country": "BA",
    "name": "Oštra Luka",
    "lat": "44.86027",
    "lng": "16.66069"
  },
  {
    "country": "BA",
    "name": "Osmaci",
    "lat": "44.40159",
    "lng": "18.91638"
  },
  {
    "country": "BA",
    "name": "Orguz",
    "lat": "43.77414",
    "lng": "16.86329"
  },
  {
    "country": "BA",
    "name": "Orašje",
    "lat": "45.03366",
    "lng": "18.69334"
  },
  {
    "country": "BA",
    "name": "Orašac",
    "lat": "44.63039",
    "lng": "16.07443"
  },
  {
    "country": "BA",
    "name": "Orahovica Donja",
    "lat": "44.65345",
    "lng": "18.36951"
  },
  {
    "country": "BA",
    "name": "Omarska",
    "lat": "44.8917",
    "lng": "16.89814"
  },
  {
    "country": "BA",
    "name": "Omanjska",
    "lat": "44.69831",
    "lng": "17.95757"
  },
  {
    "country": "BA",
    "name": "Olovo",
    "lat": "44.1277",
    "lng": "18.58065"
  },
  {
    "country": "BA",
    "name": "Odžak",
    "lat": "45.02461",
    "lng": "18.32107"
  },
  {
    "country": "BA",
    "name": "Obudovac",
    "lat": "44.95215",
    "lng": "18.59869"
  },
  {
    "country": "BA",
    "name": "Novo Selo",
    "lat": "44.08007",
    "lng": "17.15556"
  },
  {
    "country": "BA",
    "name": "Novi Šeher",
    "lat": "44.51031",
    "lng": "18.02624"
  },
  {
    "country": "BA",
    "name": "Nevesinje",
    "lat": "43.25861",
    "lng": "18.11333"
  },
  {
    "country": "BA",
    "name": "Neum",
    "lat": "42.92333",
    "lng": "17.61556"
  },
  {
    "country": "BA",
    "name": "Mrkonjić Grad",
    "lat": "44.41729",
    "lng": "17.08288"
  },
  {
    "country": "BA",
    "name": "Mramor",
    "lat": "44.59234",
    "lng": "18.56458"
  },
  {
    "country": "BA",
    "name": "Mostar",
    "lat": "43.34333",
    "lng": "17.80806"
  },
  {
    "country": "BA",
    "name": "Mionica",
    "lat": "44.86646",
    "lng": "18.46603"
  },
  {
    "country": "BA",
    "name": "Milići",
    "lat": "44.17016",
    "lng": "19.09195"
  },
  {
    "country": "BA",
    "name": "Matuzići",
    "lat": "44.68776",
    "lng": "18.04885"
  },
  {
    "country": "BA",
    "name": "Maslovare",
    "lat": "44.56594",
    "lng": "17.53216"
  },
  {
    "country": "BA",
    "name": "Marićka",
    "lat": "44.86801",
    "lng": "16.8551"
  },
  {
    "country": "BA",
    "name": "Mala Kladuša",
    "lat": "45.13443",
    "lng": "15.85217"
  },
  {
    "country": "BA",
    "name": "Mahala",
    "lat": "44.01194",
    "lng": "18.25528"
  },
  {
    "country": "BA",
    "name": "Maglajani",
    "lat": "44.94975",
    "lng": "17.35014"
  },
  {
    "country": "BA",
    "name": "Maglaj",
    "lat": "44.54771",
    "lng": "18.10003"
  },
  {
    "country": "BA",
    "name": "Lukavica",
    "lat": "44.76452",
    "lng": "18.16887"
  },
  {
    "country": "BA",
    "name": "Lukavica",
    "lat": "43.82693",
    "lng": "18.38318"
  },
  {
    "country": "BA",
    "name": "Lukavac",
    "lat": "44.54245",
    "lng": "18.52618"
  },
  {
    "country": "BA",
    "name": "Lopare",
    "lat": "44.63498",
    "lng": "18.8434"
  },
  {
    "country": "BA",
    "name": "Lokvine",
    "lat": "44.20466",
    "lng": "17.85665"
  },
  {
    "country": "BA",
    "name": "Ljubuški",
    "lat": "43.19694",
    "lng": "17.545"
  },
  {
    "country": "BA",
    "name": "Ljubinje",
    "lat": "42.9512",
    "lng": "18.08702"
  },
  {
    "country": "BA",
    "name": "Livno",
    "lat": "43.82695",
    "lng": "17.00746"
  },
  {
    "country": "BA",
    "name": "Široki Brijeg",
    "lat": "43.3829",
    "lng": "17.59416"
  },
  {
    "country": "BA",
    "name": "Laktaši",
    "lat": "44.90857",
    "lng": "17.30135"
  },
  {
    "country": "BA",
    "name": "Kupres",
    "lat": "43.99273",
    "lng": "17.27639"
  },
  {
    "country": "BA",
    "name": "Krupa na Vrbasu",
    "lat": "44.61875",
    "lng": "17.14351"
  },
  {
    "country": "BA",
    "name": "Teočak",
    "lat": "44.60321",
    "lng": "18.97967"
  },
  {
    "country": "BA",
    "name": "Kreševo",
    "lat": "43.86556",
    "lng": "18.04333"
  },
  {
    "country": "BA",
    "name": "Kotor Varoš",
    "lat": "44.61831",
    "lng": "17.37204"
  },
  {
    "country": "BA",
    "name": "Kopači",
    "lat": "43.67833",
    "lng": "19.02845"
  },
  {
    "country": "BA",
    "name": "Kočerin",
    "lat": "43.39005",
    "lng": "17.48552"
  },
  {
    "country": "BA",
    "name": "Kobilja Glava",
    "lat": "43.88188",
    "lng": "18.38864"
  },
  {
    "country": "BA",
    "name": "Klokotnica",
    "lat": "44.7329",
    "lng": "18.18884"
  },
  {
    "country": "BA",
    "name": "Ključ",
    "lat": "44.53251",
    "lng": "16.77682"
  },
  {
    "country": "BA",
    "name": "Kladanj",
    "lat": "44.22669",
    "lng": "18.69274"
  },
  {
    "country": "BA",
    "name": "Kiseljak",
    "lat": "44.48904",
    "lng": "18.56982"
  },
  {
    "country": "BA",
    "name": "Kiseljak",
    "lat": "43.94295",
    "lng": "18.08132"
  },
  {
    "country": "BA",
    "name": "Karadaglije",
    "lat": "44.57065",
    "lng": "18.01775"
  },
  {
    "country": "BA",
    "name": "Kalinovik",
    "lat": "43.50464",
    "lng": "18.44649"
  },
  {
    "country": "BA",
    "name": "Kalesija",
    "lat": "44.43765",
    "lng": "18.90713"
  },
  {
    "country": "BA",
    "name": "Kalenderovci Donji",
    "lat": "44.94673",
    "lng": "17.83785"
  },
  {
    "country": "BA",
    "name": "Kakanj",
    "lat": "44.13311",
    "lng": "18.12292"
  },
  {
    "country": "BA",
    "name": "Jezerski",
    "lat": "44.98172",
    "lng": "16.09447"
  },
  {
    "country": "BA",
    "name": "Jezero",
    "lat": "44.34954",
    "lng": "17.1688"
  },
  {
    "country": "BA",
    "name": "Janja",
    "lat": "44.66554",
    "lng": "19.24691"
  },
  {
    "country": "BA",
    "name": "Jajce",
    "lat": "44.34203",
    "lng": "17.27059"
  },
  {
    "country": "BA",
    "name": "Izačić",
    "lat": "44.87485",
    "lng": "15.78256"
  },
  {
    "country": "BA",
    "name": "Ilijaš",
    "lat": "43.95128",
    "lng": "18.27128"
  },
  {
    "country": "BA",
    "name": "Ilidža",
    "lat": "43.82939",
    "lng": "18.30003"
  },
  {
    "country": "BA",
    "name": "Hreša",
    "lat": "43.878",
    "lng": "18.49699"
  },
  {
    "country": "BA",
    "name": "Han Pijesak",
    "lat": "44.08161",
    "lng": "18.95258"
  },
  {
    "country": "BA",
    "name": "Hadžići",
    "lat": "43.82222",
    "lng": "18.20667"
  },
  {
    "country": "BA",
    "name": "Grude",
    "lat": "43.37208",
    "lng": "17.41449"
  },
  {
    "country": "BA",
    "name": "Gromiljak",
    "lat": "43.96668",
    "lng": "18.05504"
  },
  {
    "country": "BA",
    "name": "Gradačac",
    "lat": "44.87851",
    "lng": "18.42764"
  },
  {
    "country": "BA",
    "name": "Gračanica",
    "lat": "44.70307",
    "lng": "18.3101"
  },
  {
    "country": "BA",
    "name": "Gračanica",
    "lat": "43.73333",
    "lng": "18.28333"
  },
  {
    "country": "BA",
    "name": "Gostovići",
    "lat": "44.41124",
    "lng": "18.17029"
  },
  {
    "country": "BA",
    "name": "Gornji Vakuf",
    "lat": "43.93806",
    "lng": "17.58833"
  },
  {
    "country": "BA",
    "name": "Gornji Ribnik",
    "lat": "44.41752",
    "lng": "16.8169"
  },
  {
    "country": "BA",
    "name": "Gornje Živinice",
    "lat": "44.42921",
    "lng": "18.61667"
  },
  {
    "country": "BA",
    "name": "Gornje Moštre",
    "lat": "44.01911",
    "lng": "18.15477"
  },
  {
    "country": "BA",
    "name": "Gornja Tuzla",
    "lat": "44.55659",
    "lng": "18.76159"
  },
  {
    "country": "BA",
    "name": "Gornja Koprivna",
    "lat": "45.01091",
    "lng": "15.95487"
  },
  {
    "country": "BA",
    "name": "Gorica",
    "lat": "43.41833",
    "lng": "17.285"
  },
  {
    "country": "BA",
    "name": "Goražde",
    "lat": "43.66795",
    "lng": "18.97564"
  },
  {
    "country": "BA",
    "name": "Gnojnica",
    "lat": "44.62058",
    "lng": "18.44684"
  },
  {
    "country": "BA",
    "name": "Glamoč",
    "lat": "44.04583",
    "lng": "16.84861"
  },
  {
    "country": "BA",
    "name": "Gacko",
    "lat": "43.16722",
    "lng": "18.53528"
  },
  {
    "country": "BA",
    "name": "Fojnica",
    "lat": "43.95952",
    "lng": "17.90288"
  },
  {
    "country": "BA",
    "name": "Foča",
    "lat": "43.50646",
    "lng": "18.77854"
  },
  {
    "country": "BA",
    "name": "Tomislavgrad",
    "lat": "43.71849",
    "lng": "17.22515"
  },
  {
    "country": "BA",
    "name": "Dubravica",
    "lat": "44.44131",
    "lng": "18.11883"
  },
  {
    "country": "BA",
    "name": "Dubrave Gornje",
    "lat": "44.47229",
    "lng": "18.72685"
  },
  {
    "country": "BA",
    "name": "Dubrave Donje",
    "lat": "44.4806",
    "lng": "18.69709"
  },
  {
    "country": "BA",
    "name": "Drvar",
    "lat": "44.37389",
    "lng": "16.38083"
  },
  {
    "country": "BA",
    "name": "Drinovci",
    "lat": "43.35454",
    "lng": "17.32536"
  },
  {
    "country": "BA",
    "name": "Drinić",
    "lat": "44.50671",
    "lng": "16.46699"
  },
  {
    "country": "BA",
    "name": "Donji Žabar",
    "lat": "44.94317",
    "lng": "18.64673"
  },
  {
    "country": "BA",
    "name": "Donji Vakuf",
    "lat": "44.14361",
    "lng": "17.4"
  },
  {
    "country": "BA",
    "name": "Donji Dubovik",
    "lat": "44.89021",
    "lng": "16.3251"
  },
  {
    "country": "BA",
    "name": "Donja Međiđa",
    "lat": "44.80235",
    "lng": "18.40477"
  },
  {
    "country": "BA",
    "name": "Donja Mahala",
    "lat": "45.04327",
    "lng": "18.66996"
  },
  {
    "country": "BA",
    "name": "Donja Dubica",
    "lat": "45.07559",
    "lng": "18.41023"
  },
  {
    "country": "BA",
    "name": "Domaljevac",
    "lat": "45.0611",
    "lng": "18.58612"
  },
  {
    "country": "BA",
    "name": "Dobrljin",
    "lat": "45.15106",
    "lng": "16.47869"
  },
  {
    "country": "BA",
    "name": "Dobrinje",
    "lat": "44.05008",
    "lng": "18.11958"
  },
  {
    "country": "BA",
    "name": "Doboj",
    "lat": "44.73179",
    "lng": "18.08698"
  },
  {
    "country": "BA",
    "name": "Divičani",
    "lat": "44.36682",
    "lng": "17.32678"
  },
  {
    "country": "BA",
    "name": "Derventa",
    "lat": "44.97839",
    "lng": "17.90779"
  },
  {
    "country": "BA",
    "name": "Čitluk",
    "lat": "43.22861",
    "lng": "17.70083"
  },
  {
    "country": "BA",
    "name": "Cim",
    "lat": "43.35401",
    "lng": "17.78045"
  },
  {
    "country": "BA",
    "name": "Čelinac",
    "lat": "44.73998",
    "lng": "17.31881"
  },
  {
    "country": "BA",
    "name": "Čelić",
    "lat": "44.72524",
    "lng": "18.81474"
  },
  {
    "country": "BA",
    "name": "Čečava",
    "lat": "44.67961",
    "lng": "17.7578"
  },
  {
    "country": "BA",
    "name": "Cazin",
    "lat": "44.96694",
    "lng": "15.94306"
  },
  {
    "country": "BA",
    "name": "Čapljina",
    "lat": "43.12139",
    "lng": "17.68444"
  },
  {
    "country": "BA",
    "name": "Čajniče",
    "lat": "43.55712",
    "lng": "19.07186"
  },
  {
    "country": "BA",
    "name": "Bužim",
    "lat": "45.05361",
    "lng": "16.03254"
  },
  {
    "country": "BA",
    "name": "Busovača",
    "lat": "44.09769",
    "lng": "17.8783"
  },
  {
    "country": "BA",
    "name": "Bugojno",
    "lat": "44.05722",
    "lng": "17.45083"
  },
  {
    "country": "BA",
    "name": "Bronzani Majdan",
    "lat": "44.79237",
    "lng": "16.94039"
  },
  {
    "country": "BA",
    "name": "Brka",
    "lat": "44.82837",
    "lng": "18.7242"
  },
  {
    "country": "BA",
    "name": "Breza",
    "lat": "44.01862",
    "lng": "18.26063"
  },
  {
    "country": "BA",
    "name": "Brčko",
    "lat": "44.86995",
    "lng": "18.81012"
  },
  {
    "country": "BA",
    "name": "Bratunac",
    "lat": "44.18455",
    "lng": "19.33085"
  },
  {
    "country": "BA",
    "name": "Petrovo",
    "lat": "44.62804",
    "lng": "18.35323"
  },
  {
    "country": "BA",
    "name": "Bosansko Grahovo",
    "lat": "44.17944",
    "lng": "16.36389"
  },
  {
    "country": "BA",
    "name": "Šamac",
    "lat": "45.05987",
    "lng": "18.46756"
  },
  {
    "country": "BA",
    "name": "Bosanski Petrovac",
    "lat": "44.55537",
    "lng": "16.36897"
  },
  {
    "country": "BA",
    "name": "Novi Grad",
    "lat": "45.04643",
    "lng": "16.37782"
  },
  {
    "country": "BA",
    "name": "Brod",
    "lat": "45.13747",
    "lng": "17.98722"
  },
  {
    "country": "BA",
    "name": "Bosanska Krupa",
    "lat": "44.8825",
    "lng": "16.15139"
  },
  {
    "country": "BA",
    "name": "Kostajnica",
    "lat": "45.21956",
    "lng": "16.53929"
  },
  {
    "country": "BA",
    "name": "Gradiška",
    "lat": "45.14484",
    "lng": "17.25453"
  },
  {
    "country": "BA",
    "name": "Kozarska Dubica",
    "lat": "45.17667",
    "lng": "16.80944"
  },
  {
    "country": "BA",
    "name": "Blatnica",
    "lat": "44.48677",
    "lng": "17.82278"
  },
  {
    "country": "BA",
    "name": "Blagaj",
    "lat": "43.25892",
    "lng": "17.88815"
  },
  {
    "country": "BA",
    "name": "Bileća",
    "lat": "42.87645",
    "lng": "18.42967"
  },
  {
    "country": "BA",
    "name": "Bila",
    "lat": "43.78265",
    "lng": "16.92676"
  },
  {
    "country": "BA",
    "name": "Bijeljina",
    "lat": "44.75874",
    "lng": "19.21437"
  },
  {
    "country": "BA",
    "name": "Bihać",
    "lat": "44.81694",
    "lng": "15.87083"
  },
  {
    "country": "BA",
    "name": "Berkovići",
    "lat": "43.09472",
    "lng": "18.17028"
  },
  {
    "country": "BA",
    "name": "Banovići",
    "lat": "44.40596",
    "lng": "18.52648"
  },
  {
    "country": "BA",
    "name": "Banja Luka",
    "lat": "44.77842",
    "lng": "17.19386"
  },
  {
    "country": "BA",
    "name": "Balatun",
    "lat": "44.86332",
    "lng": "19.33931"
  },
  {
    "country": "BA",
    "name": "Koran",
    "lat": "43.81038",
    "lng": "18.56999"
  },
  {
    "country": "BA",
    "name": "Jelah",
    "lat": "44.654",
    "lng": "17.95897"
  },
  {
    "country": "BA",
    "name": "Stanari",
    "lat": "44.74475",
    "lng": "17.82714"
  },
  {
    "country": "BA",
    "name": "Dobratići",
    "lat": "44.37792",
    "lng": "17.41426"
  },
  {
    "country": "BA",
    "name": "Podbrdo",
    "lat": "44.44189",
    "lng": "17.01495"
  },
  {
    "country": "BA",
    "name": "Malešići",
    "lat": "44.73824",
    "lng": "18.27335"
  },
  {
    "country": "BA",
    "name": "Svojat",
    "lat": "44.39548",
    "lng": "18.73849"
  },
  {
    "country": "BA",
    "name": "Dvorovi",
    "lat": "44.80753",
    "lng": "19.25999"
  },
  {
    "country": "BA",
    "name": "Knežica",
    "lat": "45.10548",
    "lng": "16.67668"
  },
  {
    "country": "BA",
    "name": "Pjanići",
    "lat": "44.98568",
    "lng": "15.82304"
  },
  {
    "country": "BA",
    "name": "Polje",
    "lat": "43.88014",
    "lng": "18.07452"
  },
  {
    "country": "BA",
    "name": "Ilići",
    "lat": "43.34765",
    "lng": "17.76848"
  },
  {
    "country": "BA",
    "name": "Careva Ćuprija",
    "lat": "44.2663",
    "lng": "18.42961"
  },
  {
    "country": "BA",
    "name": "Starcevica",
    "lat": "44.75708",
    "lng": "17.21178"
  },
  {
    "country": "BA",
    "name": "Čelinac",
    "lat": "44.72453",
    "lng": "17.32431"
  },
  {
    "country": "BA",
    "name": "Hiseti",
    "lat": "44.76111",
    "lng": "17.17944"
  },
  {
    "country": "BA",
    "name": "Piskavica",
    "lat": "44.86717",
    "lng": "16.97464"
  },
  {
    "country": "BA",
    "name": "Lamovita",
    "lat": "44.92018",
    "lng": "16.89933"
  },
  {
    "country": "BA",
    "name": "Tešanjka",
    "lat": "44.67228",
    "lng": "18.01109"
  },
  {
    "country": "BA",
    "name": "Kovači",
    "lat": "44.44874",
    "lng": "18.20521"
  },
  {
    "country": "BA",
    "name": "Liješnica",
    "lat": "44.49497",
    "lng": "18.07644"
  },
  {
    "country": "BA",
    "name": "Ćoralići",
    "lat": "45.00694",
    "lng": "15.87194"
  },
  {
    "country": "BA",
    "name": "Crnići",
    "lat": "43.13156",
    "lng": "17.86452"
  },
  {
    "country": "BA",
    "name": "Barice",
    "lat": "44.54065",
    "lng": "18.48069"
  },
  {
    "country": "BA",
    "name": "Hotonj",
    "lat": "43.89341",
    "lng": "18.37751"
  },
  {
    "country": "BA",
    "name": "Skokovi",
    "lat": "45.03139",
    "lng": "15.91444"
  },
  {
    "country": "BA",
    "name": "Drežnica",
    "lat": "43.52891",
    "lng": "17.2812"
  },
  {
    "country": "BA",
    "name": "Kačuni",
    "lat": "44.06433",
    "lng": "17.93894"
  },
  {
    "country": "BA",
    "name": "Pajić Polje",
    "lat": "43.97583",
    "lng": "17.5275"
  },
  {
    "country": "BA",
    "name": "Gornja Breza",
    "lat": "44.03758",
    "lng": "18.24564"
  },
  {
    "country": "BA",
    "name": "Todorovo",
    "lat": "45.08833",
    "lng": "15.93083"
  },
  {
    "country": "BA",
    "name": "Konjic",
    "lat": "43.65126",
    "lng": "17.96082"
  },
  {
    "country": "BA",
    "name": "Jablanica",
    "lat": "43.66028",
    "lng": "17.76167"
  },
  {
    "country": "BA",
    "name": "Bijela",
    "lat": "43.60871",
    "lng": "17.95078"
  },
  {
    "country": "BA",
    "name": "Mejdan - Obilićevo",
    "lat": "44.76324",
    "lng": "17.19012"
  },
  {
    "country": "BB",
    "name": "Welchman Hall",
    "lat": "13.18676",
    "lng": "-59.57663"
  },
  {
    "country": "BB",
    "name": "Crane",
    "lat": "13.10487",
    "lng": "-59.44861"
  },
  {
    "country": "BB",
    "name": "Speightstown",
    "lat": "13.25072",
    "lng": "-59.64396"
  },
  {
    "country": "BB",
    "name": "Oistins",
    "lat": "13.07067",
    "lng": "-59.54637"
  },
  {
    "country": "BB",
    "name": "Holetown",
    "lat": "13.18672",
    "lng": "-59.63808"
  },
  {
    "country": "BB",
    "name": "Greenland",
    "lat": "13.25808",
    "lng": "-59.57763"
  },
  {
    "country": "BB",
    "name": "Four Cross Roads",
    "lat": "13.17018",
    "lng": "-59.52186"
  },
  {
    "country": "BB",
    "name": "Checker Hall",
    "lat": "13.28445",
    "lng": "-59.64223"
  },
  {
    "country": "BB",
    "name": "Bridgetown",
    "lat": "13.10732",
    "lng": "-59.62021"
  },
  {
    "country": "BB",
    "name": "Bathsheba",
    "lat": "13.21133",
    "lng": "-59.52596"
  },
  {
    "country": "BD",
    "name": "Thākurgaon",
    "lat": "26.03097",
    "lng": "88.46989"
  },
  {
    "country": "BD",
    "name": "Teknāf",
    "lat": "20.85829",
    "lng": "92.29773"
  },
  {
    "country": "BD",
    "name": "Tungi",
    "lat": "23.89154",
    "lng": "90.40232"
  },
  {
    "country": "BD",
    "name": "Sylhet",
    "lat": "24.89904",
    "lng": "91.87198"
  },
  {
    "country": "BD",
    "name": "Dohār",
    "lat": "23.59311",
    "lng": "90.14251"
  },
  {
    "country": "BD",
    "name": "Jamālpur",
    "lat": "24.91965",
    "lng": "89.94812"
  },
  {
    "country": "BD",
    "name": "Shibganj",
    "lat": "25.00146",
    "lng": "89.32266"
  },
  {
    "country": "BD",
    "name": "Shibganj",
    "lat": "24.68501",
    "lng": "88.15638"
  },
  {
    "country": "BD",
    "name": "Sātkhira",
    "lat": "22.70817",
    "lng": "89.07185"
  },
  {
    "country": "BD",
    "name": "Sirajganj",
    "lat": "24.45771",
    "lng": "89.70802"
  },
  {
    "country": "BD",
    "name": "Netrakona",
    "lat": "24.88352",
    "lng": "90.72898"
  },
  {
    "country": "BD",
    "name": "Narsingdi",
    "lat": "23.92298",
    "lng": "90.71768"
  },
  {
    "country": "BD",
    "name": "Sandwīp",
    "lat": "22.51409",
    "lng": "91.45491"
  },
  {
    "country": "BD",
    "name": "Shāhzādpur",
    "lat": "24.17687",
    "lng": "89.5988"
  },
  {
    "country": "BD",
    "name": "Rāmganj",
    "lat": "23.1006",
    "lng": "90.84989"
  },
  {
    "country": "BD",
    "name": "Rājshāhi",
    "lat": "24.374",
    "lng": "88.60114"
  },
  {
    "country": "BD",
    "name": "Purbadhala",
    "lat": "24.94077",
    "lng": "90.60025"
  },
  {
    "country": "BD",
    "name": "Pirojpur",
    "lat": "22.57965",
    "lng": "89.97521"
  },
  {
    "country": "BD",
    "name": "Panchagarh",
    "lat": "26.33338",
    "lng": "88.55777"
  },
  {
    "country": "BD",
    "name": "Patiya",
    "lat": "22.29543",
    "lng": "91.979"
  },
  {
    "country": "BD",
    "name": "Parbatipur",
    "lat": "25.66369",
    "lng": "88.93093"
  },
  {
    "country": "BD",
    "name": "Nārāyanganj",
    "lat": "23.61352",
    "lng": "90.50298"
  },
  {
    "country": "BD",
    "name": "Nālchiti",
    "lat": "22.63696",
    "lng": "90.27195"
  },
  {
    "country": "BD",
    "name": "Nāgarpur",
    "lat": "24.05783",
    "lng": "89.87696"
  },
  {
    "country": "BD",
    "name": "Nageswari",
    "lat": "25.96817",
    "lng": "89.69153"
  },
  {
    "country": "BD",
    "name": "Mymensingh",
    "lat": "24.75636",
    "lng": "90.40646"
  },
  {
    "country": "BD",
    "name": "Muktāgācha",
    "lat": "24.76484",
    "lng": "90.25698"
  },
  {
    "country": "BD",
    "name": "Mirzāpur",
    "lat": "24.10287",
    "lng": "90.09841"
  },
  {
    "country": "BD",
    "name": "Maulavi Bāzār",
    "lat": "24.48888",
    "lng": "91.77075"
  },
  {
    "country": "BD",
    "name": "Morrelgonj",
    "lat": "22.45566",
    "lng": "89.85584"
  },
  {
    "country": "BD",
    "name": "Mehendiganj",
    "lat": "22.82257",
    "lng": "90.52859"
  },
  {
    "country": "BD",
    "name": "Mathba",
    "lat": "22.28616",
    "lng": "89.95883"
  },
  {
    "country": "BD",
    "name": "Lalmonirhat",
    "lat": "25.91719",
    "lng": "89.44595"
  },
  {
    "country": "BD",
    "name": "Lākshām",
    "lat": "23.24018",
    "lng": "91.12143"
  },
  {
    "country": "BD",
    "name": "Comilla",
    "lat": "23.46186",
    "lng": "91.18503"
  },
  {
    "country": "BD",
    "name": "Rangpur",
    "lat": "25.74664",
    "lng": "89.25166"
  },
  {
    "country": "BD",
    "name": "Kushtia",
    "lat": "23.9028",
    "lng": "89.11943"
  },
  {
    "country": "BD",
    "name": "Kālīganj",
    "lat": "23.40964",
    "lng": "89.13801"
  },
  {
    "country": "BD",
    "name": "Jhingergācha",
    "lat": "23.11134",
    "lng": "89.09061"
  },
  {
    "country": "BD",
    "name": "Joypur Hāt",
    "lat": "25.10147",
    "lng": "89.02734"
  },
  {
    "country": "BD",
    "name": "Ishurdi",
    "lat": "24.12858",
    "lng": "89.06573"
  },
  {
    "country": "BD",
    "name": "Habiganj",
    "lat": "24.38044",
    "lng": "91.41299"
  },
  {
    "country": "BD",
    "name": "Gaurnadi",
    "lat": "22.97372",
    "lng": "90.22376"
  },
  {
    "country": "BD",
    "name": "Gafargaon",
    "lat": "24.432",
    "lng": "90.5585"
  },
  {
    "country": "BD",
    "name": "Feni",
    "lat": "23.0144",
    "lng": "91.3966"
  },
  {
    "country": "BD",
    "name": "Rāipur",
    "lat": "23.0391",
    "lng": "90.76808"
  },
  {
    "country": "BD",
    "name": "Sarankhola",
    "lat": "22.31006",
    "lng": "89.79113"
  },
  {
    "country": "BD",
    "name": "Dhaka",
    "lat": "23.7104",
    "lng": "90.40744"
  },
  {
    "country": "BD",
    "name": "Chilmāri",
    "lat": "25.55613",
    "lng": "89.67097"
  },
  {
    "country": "BD",
    "name": "Chhāgalnāiya",
    "lat": "23.02475",
    "lng": "91.51091"
  },
  {
    "country": "BD",
    "name": "Lālmohan",
    "lat": "22.33774",
    "lng": "90.73708"
  },
  {
    "country": "BD",
    "name": "Khagrachhari",
    "lat": "23.10787",
    "lng": "91.97007"
  },
  {
    "country": "BD",
    "name": "Chhātak",
    "lat": "25.03852",
    "lng": "91.66958"
  },
  {
    "country": "BD",
    "name": "Bhātpāra Abhaynagar",
    "lat": "23.01472",
    "lng": "89.43936"
  },
  {
    "country": "BD",
    "name": "Bherāmāra",
    "lat": "24.02452",
    "lng": "88.99234"
  },
  {
    "country": "BD",
    "name": "Bhairab Bāzār",
    "lat": "24.0524",
    "lng": "90.9764"
  },
  {
    "country": "BD",
    "name": "Bāndarban",
    "lat": "22.19534",
    "lng": "92.21946"
  },
  {
    "country": "BD",
    "name": "Kālia",
    "lat": "23.043",
    "lng": "89.63094"
  },
  {
    "country": "BD",
    "name": "Baniachang",
    "lat": "24.51863",
    "lng": "91.35787"
  },
  {
    "country": "BD",
    "name": "Bājitpur",
    "lat": "24.21623",
    "lng": "90.95002"
  },
  {
    "country": "BD",
    "name": "Bagerhat",
    "lat": "22.65657",
    "lng": "89.79123"
  },
  {
    "country": "BD",
    "name": "Badarganj",
    "lat": "25.67419",
    "lng": "89.05377"
  },
  {
    "country": "BD",
    "name": "Narail",
    "lat": "23.15509",
    "lng": "89.49515"
  },
  {
    "country": "BD",
    "name": "Tungipāra",
    "lat": "22.89983",
    "lng": "89.90326"
  },
  {
    "country": "BD",
    "name": "Sonārgaon",
    "lat": "23.65",
    "lng": "90.61667"
  },
  {
    "country": "BD",
    "name": "Sarishābāri",
    "lat": "24.75127",
    "lng": "89.83126"
  },
  {
    "country": "BD",
    "name": "Sakhipur",
    "lat": "24.31988",
    "lng": "90.16943"
  },
  {
    "country": "BD",
    "name": "Raojān",
    "lat": "22.53511",
    "lng": "91.91919"
  },
  {
    "country": "BD",
    "name": "Phultala",
    "lat": "22.71673",
    "lng": "89.51194"
  },
  {
    "country": "BD",
    "name": "Pālang",
    "lat": "23.21824",
    "lng": "90.35076"
  },
  {
    "country": "BD",
    "name": "Pār Naogaon",
    "lat": "24.80418",
    "lng": "88.94875"
  },
  {
    "country": "BD",
    "name": "Nabīnagar",
    "lat": "23.88791",
    "lng": "90.96792"
  },
  {
    "country": "BD",
    "name": "Ramnagar",
    "lat": "23.7772",
    "lng": "90.17604"
  },
  {
    "country": "BD",
    "name": "Lakshmīpur",
    "lat": "22.9443",
    "lng": "90.83005"
  },
  {
    "country": "BD",
    "name": "Kesabpur",
    "lat": "22.90725",
    "lng": "89.21954"
  },
  {
    "country": "BD",
    "name": "Jahedpur",
    "lat": "24.83333",
    "lng": "91.65"
  },
  {
    "country": "BD",
    "name": "Hājīganj",
    "lat": "23.25191",
    "lng": "90.85508"
  },
  {
    "country": "BD",
    "name": "Farīdpur",
    "lat": "23.60612",
    "lng": "89.84064"
  },
  {
    "country": "BD",
    "name": "Dinājpur",
    "lat": "25.62745",
    "lng": "88.63779"
  },
  {
    "country": "BD",
    "name": "Uttar Char Fasson",
    "lat": "22.22647",
    "lng": "90.71275"
  },
  {
    "country": "BD",
    "name": "Chittagong",
    "lat": "22.3384",
    "lng": "91.83168"
  },
  {
    "country": "BD",
    "name": "Char Bhadrāsan",
    "lat": "23.30916",
    "lng": "90.22698"
  },
  {
    "country": "BD",
    "name": "Bera",
    "lat": "24.07821",
    "lng": "89.63262"
  },
  {
    "country": "BD",
    "name": "Burhānuddin",
    "lat": "22.49518",
    "lng": "90.72391"
  },
  {
    "country": "BD",
    "name": "Sātkania",
    "lat": "22.07639",
    "lng": "92.04955"
  },
  {
    "country": "BD",
    "name": "Cox’s Bāzār",
    "lat": "21.43973",
    "lng": "92.00955"
  },
  {
    "country": "BD",
    "name": "Khulna",
    "lat": "22.80979",
    "lng": "89.56439"
  },
  {
    "country": "BD",
    "name": "Bhola",
    "lat": "22.68759",
    "lng": "90.64403"
  },
  {
    "country": "BD",
    "name": "Barisāl",
    "lat": "22.70497",
    "lng": "90.37013"
  },
  {
    "country": "BD",
    "name": "Jessore",
    "lat": "23.16971",
    "lng": "89.21371"
  },
  {
    "country": "BD",
    "name": "Pābna",
    "lat": "24.00644",
    "lng": "89.2372"
  },
  {
    "country": "BD",
    "name": "Tāngāil",
    "lat": "24.24984",
    "lng": "89.91655"
  },
  {
    "country": "BD",
    "name": "Bogra",
    "lat": "24.85098",
    "lng": "89.37108"
  },
  {
    "country": "BD",
    "name": "Pīrgaaj",
    "lat": "25.85587",
    "lng": "88.35943"
  },
  {
    "country": "BD",
    "name": "Nawābganj",
    "lat": "24.59025",
    "lng": "88.27444"
  },
  {
    "country": "BD",
    "name": "Mādārīpur",
    "lat": "23.17097",
    "lng": "90.20935"
  },
  {
    "country": "BD",
    "name": "Sherpur",
    "lat": "25.01881",
    "lng": "90.01751"
  },
  {
    "country": "BD",
    "name": "Kishorganj",
    "lat": "24.43944",
    "lng": "90.78291"
  },
  {
    "country": "BD",
    "name": "Manikchari",
    "lat": "22.83957",
    "lng": "91.84128"
  },
  {
    "country": "BD",
    "name": "Bhāndāria",
    "lat": "22.48898",
    "lng": "90.06273"
  },
  {
    "country": "BD",
    "name": "Bibir Hat",
    "lat": "22.68347",
    "lng": "91.79058"
  },
  {
    "country": "BD",
    "name": "Saidpur",
    "lat": "25.77769",
    "lng": "88.89169"
  },
  {
    "country": "BD",
    "name": "Puthia",
    "lat": "24.36537",
    "lng": "88.83431"
  },
  {
    "country": "BD",
    "name": "Natore",
    "lat": "24.41112",
    "lng": "88.98673"
  },
  {
    "country": "BD",
    "name": "Nowlamary",
    "lat": "23.67346",
    "lng": "88.98885"
  },
  {
    "country": "BD",
    "name": "Magura",
    "lat": "23.48702",
    "lng": "89.41592"
  },
  {
    "country": "BD",
    "name": "Azimpur",
    "lat": "23.7298",
    "lng": "90.3854"
  },
  {
    "country": "BD",
    "name": "Gaibandha",
    "lat": "25.3293",
    "lng": "89.5438"
  },
  {
    "country": "BD",
    "name": "Mahasthangarh",
    "lat": "24.96111",
    "lng": "89.34278"
  },
  {
    "country": "BD",
    "name": "Paltan",
    "lat": "23.73625",
    "lng": "90.41426"
  },
  {
    "country": "BD",
    "name": "Parvez Ali Hossain",
    "lat": "23.78758",
    "lng": "90.16487"
  },
  {
    "country": "BD",
    "name": "Khanbaniara",
    "lat": "23.78225",
    "lng": "90.18382"
  },
  {
    "country": "BD",
    "name": "Char Golora",
    "lat": "23.82037",
    "lng": "90.12175"
  },
  {
    "country": "BD",
    "name": "Parvez Ali Family",
    "lat": "23.81741",
    "lng": "90.11921"
  },
  {
    "country": "BD",
    "name": "Joymontop",
    "lat": "23.78789",
    "lng": "90.16472"
  },
  {
    "country": "BD",
    "name": "Sayani",
    "lat": "23.79119",
    "lng": "90.16972"
  },
  {
    "country": "BE",
    "name": "Zwijndrecht",
    "lat": "51.21979",
    "lng": "4.32664"
  },
  {
    "country": "BE",
    "name": "Zwevegem",
    "lat": "50.81268",
    "lng": "3.33848"
  },
  {
    "country": "BE",
    "name": "Zutendaal",
    "lat": "50.93306",
    "lng": "5.5753"
  },
  {
    "country": "BE",
    "name": "Zulte",
    "lat": "50.91954",
    "lng": "3.44859"
  },
  {
    "country": "BE",
    "name": "Zuienkerke",
    "lat": "51.26511",
    "lng": "3.15506"
  },
  {
    "country": "BE",
    "name": "Zoutleeuw",
    "lat": "50.83316",
    "lng": "5.10376"
  },
  {
    "country": "BE",
    "name": "Zottegem",
    "lat": "50.86955",
    "lng": "3.81052"
  },
  {
    "country": "BE",
    "name": "Zonnebeke",
    "lat": "50.8726",
    "lng": "2.98725"
  },
  {
    "country": "BE",
    "name": "Zonhoven",
    "lat": "50.99064",
    "lng": "5.36819"
  },
  {
    "country": "BE",
    "name": "Zomergem",
    "lat": "51.11994",
    "lng": "3.56496"
  },
  {
    "country": "BE",
    "name": "Zoersel",
    "lat": "51.26825",
    "lng": "4.71296"
  },
  {
    "country": "BE",
    "name": "Zingem",
    "lat": "50.90409",
    "lng": "3.65305"
  },
  {
    "country": "BE",
    "name": "Zemst",
    "lat": "50.98318",
    "lng": "4.46079"
  },
  {
    "country": "BE",
    "name": "Zelzate",
    "lat": "51.18963",
    "lng": "3.80777"
  },
  {
    "country": "BE",
    "name": "Zele",
    "lat": "51.06566",
    "lng": "4.0403"
  },
  {
    "country": "BE",
    "name": "Zeebrugge",
    "lat": "51.32901",
    "lng": "3.18188"
  },
  {
    "country": "BE",
    "name": "Zedelgem",
    "lat": "51.14236",
    "lng": "3.1368"
  },
  {
    "country": "BE",
    "name": "Zaventem",
    "lat": "50.88365",
    "lng": "4.47298"
  },
  {
    "country": "BE",
    "name": "Zandhoven",
    "lat": "51.21488",
    "lng": "4.66164"
  },
  {
    "country": "BE",
    "name": "Yvoir",
    "lat": "50.3279",
    "lng": "4.88059"
  },
  {
    "country": "BE",
    "name": "Wuustwezel",
    "lat": "51.39214",
    "lng": "4.59546"
  },
  {
    "country": "BE",
    "name": "Wommelgem",
    "lat": "51.20452",
    "lng": "4.5225"
  },
  {
    "country": "BE",
    "name": "Wingene",
    "lat": "51.05782",
    "lng": "3.27359"
  },
  {
    "country": "BE",
    "name": "Willebroek",
    "lat": "51.06041",
    "lng": "4.36019"
  },
  {
    "country": "BE",
    "name": "Wijnegem",
    "lat": "51.22787",
    "lng": "4.51895"
  },
  {
    "country": "BE",
    "name": "Wielsbeke",
    "lat": "50.9",
    "lng": "3.36667"
  },
  {
    "country": "BE",
    "name": "Wichelen",
    "lat": "51.00526",
    "lng": "3.97683"
  },
  {
    "country": "BE",
    "name": "Wezembeek-Oppem",
    "lat": "50.8395",
    "lng": "4.49427"
  },
  {
    "country": "BE",
    "name": "Wevelgem",
    "lat": "50.8",
    "lng": "3.16667"
  },
  {
    "country": "BE",
    "name": "Wetteren",
    "lat": "51.00526",
    "lng": "3.88341"
  },
  {
    "country": "BE",
    "name": "Westerlo",
    "lat": "51.09049",
    "lng": "4.91544"
  },
  {
    "country": "BE",
    "name": "Wervik",
    "lat": "50.78069",
    "lng": "3.03854"
  },
  {
    "country": "BE",
    "name": "Wenduine",
    "lat": "51.2983",
    "lng": "3.08213"
  },
  {
    "country": "BE",
    "name": "Wemmel",
    "lat": "50.90812",
    "lng": "4.30613"
  },
  {
    "country": "BE",
    "name": "Wellin",
    "lat": "50.08133",
    "lng": "5.11413"
  },
  {
    "country": "BE",
    "name": "Wellen",
    "lat": "50.84096",
    "lng": "5.33867"
  },
  {
    "country": "BE",
    "name": "Welkenraedt",
    "lat": "50.6605",
    "lng": "5.97034"
  },
  {
    "country": "BE",
    "name": "Wavre",
    "lat": "50.71717",
    "lng": "4.60138"
  },
  {
    "country": "BE",
    "name": "Waterloo",
    "lat": "50.71469",
    "lng": "4.3991"
  },
  {
    "country": "BE",
    "name": "Wasseiges",
    "lat": "50.62186",
    "lng": "5.00528"
  },
  {
    "country": "BE",
    "name": "Waremme",
    "lat": "50.6976",
    "lng": "5.25524"
  },
  {
    "country": "BE",
    "name": "Waregem",
    "lat": "50.88898",
    "lng": "3.42756"
  },
  {
    "country": "BE",
    "name": "Wanze",
    "lat": "50.53907",
    "lng": "5.20846"
  },
  {
    "country": "BE",
    "name": "Walhain-Saint-Paul",
    "lat": "50.62627",
    "lng": "4.69837"
  },
  {
    "country": "BE",
    "name": "Walcourt",
    "lat": "50.25401",
    "lng": "4.43796"
  },
  {
    "country": "BE",
    "name": "Waimes",
    "lat": "50.41488",
    "lng": "6.11207"
  },
  {
    "country": "BE",
    "name": "Wachtebeke",
    "lat": "51.16852",
    "lng": "3.87183"
  },
  {
    "country": "BE",
    "name": "Waasmunster",
    "lat": "51.10572",
    "lng": "4.08573"
  },
  {
    "country": "BE",
    "name": "Waarschoot",
    "lat": "51.1525",
    "lng": "3.605"
  },
  {
    "country": "BE",
    "name": "Vosselaar",
    "lat": "51.30856",
    "lng": "4.8896"
  },
  {
    "country": "BE",
    "name": "Vorselaar",
    "lat": "51.20243",
    "lng": "4.77259"
  },
  {
    "country": "BE",
    "name": "Visé",
    "lat": "50.7376",
    "lng": "5.69907"
  },
  {
    "country": "BE",
    "name": "Virton",
    "lat": "49.56824",
    "lng": "5.53259"
  },
  {
    "country": "BE",
    "name": "Vilvoorde",
    "lat": "50.92814",
    "lng": "4.42938"
  },
  {
    "country": "BE",
    "name": "Villers-le-Bouillet",
    "lat": "50.57708",
    "lng": "5.25945"
  },
  {
    "country": "BE",
    "name": "Villers-la-Ville",
    "lat": "50.56667",
    "lng": "4.51667"
  },
  {
    "country": "BE",
    "name": "Vielsalm",
    "lat": "50.28407",
    "lng": "5.91502"
  },
  {
    "country": "BE",
    "name": "Veurne",
    "lat": "51.07316",
    "lng": "2.66803"
  },
  {
    "country": "BE",
    "name": "Verviers",
    "lat": "50.58907",
    "lng": "5.86241"
  },
  {
    "country": "BE",
    "name": "Verlaine",
    "lat": "50.60743",
    "lng": "5.3174"
  },
  {
    "country": "BE",
    "name": "Vaux-sur-Sûre",
    "lat": "49.911",
    "lng": "5.57848"
  },
  {
    "country": "BE",
    "name": "Turnhout",
    "lat": "51.32254",
    "lng": "4.94471"
  },
  {
    "country": "BE",
    "name": "Tubize",
    "lat": "50.69059",
    "lng": "4.2009"
  },
  {
    "country": "BE",
    "name": "Trooz",
    "lat": "50.57026",
    "lng": "5.69521"
  },
  {
    "country": "BE",
    "name": "Trois-Ponts",
    "lat": "50.37128",
    "lng": "5.87146"
  },
  {
    "country": "BE",
    "name": "Tremelo",
    "lat": "50.99231",
    "lng": "4.70807"
  },
  {
    "country": "BE",
    "name": "Tournai",
    "lat": "50.60715",
    "lng": "3.38932"
  },
  {
    "country": "BE",
    "name": "Torhout",
    "lat": "51.0656",
    "lng": "3.10085"
  },
  {
    "country": "BE",
    "name": "Tongeren",
    "lat": "50.78054",
    "lng": "5.46484"
  },
  {
    "country": "BE",
    "name": "Tintigny",
    "lat": "49.68326",
    "lng": "5.51349"
  },
  {
    "country": "BE",
    "name": "Tinlot",
    "lat": "50.47493",
    "lng": "5.37755"
  },
  {
    "country": "BE",
    "name": "Tienen",
    "lat": "50.80745",
    "lng": "4.9378"
  },
  {
    "country": "BE",
    "name": "Tielt",
    "lat": "50.99931",
    "lng": "3.32707"
  },
  {
    "country": "BE",
    "name": "Thuin",
    "lat": "50.33933",
    "lng": "4.28604"
  },
  {
    "country": "BE",
    "name": "Theux",
    "lat": "50.53323",
    "lng": "5.81245"
  },
  {
    "country": "BE",
    "name": "Tessenderlo",
    "lat": "51.06513",
    "lng": "5.08856"
  },
  {
    "country": "BE",
    "name": "Tervuren",
    "lat": "50.82372",
    "lng": "4.51418"
  },
  {
    "country": "BE",
    "name": "Ternat",
    "lat": "50.86654",
    "lng": "4.16682"
  },
  {
    "country": "BE",
    "name": "Tenneville",
    "lat": "50.09501",
    "lng": "5.52895"
  },
  {
    "country": "BE",
    "name": "Temse",
    "lat": "51.12794",
    "lng": "4.21372"
  },
  {
    "country": "BE",
    "name": "Tellin",
    "lat": "50.08038",
    "lng": "5.21638"
  },
  {
    "country": "BE",
    "name": "Stoumont",
    "lat": "50.40667",
    "lng": "5.80838"
  },
  {
    "country": "BE",
    "name": "Stekene",
    "lat": "51.2099",
    "lng": "4.03651"
  },
  {
    "country": "BE",
    "name": "Steenokkerzeel",
    "lat": "50.91851",
    "lng": "4.50989"
  },
  {
    "country": "BE",
    "name": "Stavelot",
    "lat": "50.395",
    "lng": "5.93124"
  },
  {
    "country": "BE",
    "name": "Staden",
    "lat": "50.97456",
    "lng": "3.01469"
  },
  {
    "country": "BE",
    "name": "Stabroek",
    "lat": "51.33189",
    "lng": "4.37127"
  },
  {
    "country": "BE",
    "name": "Sprimont",
    "lat": "50.50922",
    "lng": "5.6595"
  },
  {
    "country": "BE",
    "name": "Spa",
    "lat": "50.48375",
    "lng": "5.86674"
  },
  {
    "country": "BE",
    "name": "Soumagne",
    "lat": "50.61385",
    "lng": "5.74679"
  },
  {
    "country": "BE",
    "name": "Somme-Leuze",
    "lat": "50.33699",
    "lng": "5.36705"
  },
  {
    "country": "BE",
    "name": "Sombreffe",
    "lat": "50.52865",
    "lng": "4.60087"
  },
  {
    "country": "BE",
    "name": "Soignies",
    "lat": "50.57904",
    "lng": "4.07129"
  },
  {
    "country": "BE",
    "name": "Sint-Truiden",
    "lat": "50.81679",
    "lng": "5.18647"
  },
  {
    "country": "BE",
    "name": "Sint-Pieters-Leeuw",
    "lat": "50.77926",
    "lng": "4.24355"
  },
  {
    "country": "BE",
    "name": "Sint-Niklaas",
    "lat": "51.16509",
    "lng": "4.1437"
  },
  {
    "country": "BE",
    "name": "Sint-Martens-Lennik",
    "lat": "50.81158",
    "lng": "4.16965"
  },
  {
    "country": "BE",
    "name": "Sint-Martens-Latem",
    "lat": "51.01459",
    "lng": "3.63779"
  },
  {
    "country": "BE",
    "name": "Sint-Maria-Lierde",
    "lat": "50.82172",
    "lng": "3.84814"
  },
  {
    "country": "BE",
    "name": "Sint-Lievens-Houtem",
    "lat": "50.9197",
    "lng": "3.86225"
  },
  {
    "country": "BE",
    "name": "Sint-Laureins",
    "lat": "51.24202",
    "lng": "3.52441"
  },
  {
    "country": "BE",
    "name": "Sint-Kruis",
    "lat": "51.21399",
    "lng": "3.24949"
  },
  {
    "country": "BE",
    "name": "Sint-Katelijne-Waver",
    "lat": "51.06691",
    "lng": "4.53469"
  },
  {
    "country": "BE",
    "name": "Sint-Gillis-Waas",
    "lat": "51.21914",
    "lng": "4.12374"
  },
  {
    "country": "BE",
    "name": "Sint-Genesius-Rode",
    "lat": "50.74645",
    "lng": "4.35754"
  },
  {
    "country": "BE",
    "name": "Sint-Amands",
    "lat": "51.05645",
    "lng": "4.20957"
  },
  {
    "country": "BE",
    "name": "Silly",
    "lat": "50.64877",
    "lng": "3.92363"
  },
  {
    "country": "BE",
    "name": "Seraing",
    "lat": "50.58362",
    "lng": "5.50115"
  },
  {
    "country": "BE",
    "name": "Seneffe",
    "lat": "50.53135",
    "lng": "4.26301"
  },
  {
    "country": "BE",
    "name": "Schoten",
    "lat": "51.25251",
    "lng": "4.50268"
  },
  {
    "country": "BE",
    "name": "Schilde",
    "lat": "51.24107",
    "lng": "4.58336"
  },
  {
    "country": "BE",
    "name": "Schelle",
    "lat": "51.12615",
    "lng": "4.34114"
  },
  {
    "country": "BE",
    "name": "Saint-Yvon",
    "lat": "50.74335",
    "lng": "2.90992"
  },
  {
    "country": "BE",
    "name": "Saint-Vith",
    "lat": "50.28146",
    "lng": "6.12724"
  },
  {
    "country": "BE",
    "name": "Saint-Nicolas",
    "lat": "50.62837",
    "lng": "5.53243"
  },
  {
    "country": "BE",
    "name": "Saint-Léger",
    "lat": "49.61196",
    "lng": "5.65688"
  },
  {
    "country": "BE",
    "name": "Saint-Hubert",
    "lat": "50.02668",
    "lng": "5.37401"
  },
  {
    "country": "BE",
    "name": "Saint-Ghislain",
    "lat": "50.44816",
    "lng": "3.81886"
  },
  {
    "country": "BE",
    "name": "Sainte-Ode",
    "lat": "50.01723",
    "lng": "5.51926"
  },
  {
    "country": "BE",
    "name": "Rumst",
    "lat": "51.08153",
    "lng": "4.42217"
  },
  {
    "country": "BE",
    "name": "Rumes",
    "lat": "50.5545",
    "lng": "3.30535"
  },
  {
    "country": "BE",
    "name": "Ruiselede",
    "lat": "51.04039",
    "lng": "3.39416"
  },
  {
    "country": "BE",
    "name": "Rouvroy",
    "lat": "49.53771",
    "lng": "5.49031"
  },
  {
    "country": "BE",
    "name": "Rotselaar",
    "lat": "50.95302",
    "lng": "4.71665"
  },
  {
    "country": "BE",
    "name": "Ronse",
    "lat": "50.74574",
    "lng": "3.6005"
  },
  {
    "country": "BE",
    "name": "Mons-lez-Liège",
    "lat": "50.61667",
    "lng": "5.46667"
  },
  {
    "country": "BE",
    "name": "Roeulx",
    "lat": "50.50365",
    "lng": "4.11163"
  },
  {
    "country": "BE",
    "name": "Roeselare",
    "lat": "50.94653",
    "lng": "3.12269"
  },
  {
    "country": "BE",
    "name": "Rochefort",
    "lat": "50.1631",
    "lng": "5.2216"
  },
  {
    "country": "BE",
    "name": "Rixensart",
    "lat": "50.71229",
    "lng": "4.52529"
  },
  {
    "country": "BE",
    "name": "Rijkevorsel",
    "lat": "51.34795",
    "lng": "4.76053"
  },
  {
    "country": "BE",
    "name": "Riemst",
    "lat": "50.80995",
    "lng": "5.60131"
  },
  {
    "country": "BE",
    "name": "Retie",
    "lat": "51.26652",
    "lng": "5.08242"
  },
  {
    "country": "BE",
    "name": "Rendeux",
    "lat": "50.23423",
    "lng": "5.50414"
  },
  {
    "country": "BE",
    "name": "Remicourt",
    "lat": "50.68069",
    "lng": "5.32785"
  },
  {
    "country": "BE",
    "name": "Rebecq-Rognon",
    "lat": "50.65147",
    "lng": "4.10683"
  },
  {
    "country": "BE",
    "name": "Ravels",
    "lat": "51.37274",
    "lng": "4.9921"
  },
  {
    "country": "BE",
    "name": "Ranst",
    "lat": "51.18983",
    "lng": "4.56533"
  },
  {
    "country": "BE",
    "name": "Ramillies",
    "lat": "50.63395",
    "lng": "4.90119"
  },
  {
    "country": "BE",
    "name": "Raeren",
    "lat": "50.6672",
    "lng": "6.11535"
  },
  {
    "country": "BE",
    "name": "Quiévrain",
    "lat": "50.40737",
    "lng": "3.68351"
  },
  {
    "country": "BE",
    "name": "Quévy-le-Petit",
    "lat": "50.36879",
    "lng": "3.93602"
  },
  {
    "country": "BE",
    "name": "Quaregnon",
    "lat": "50.44067",
    "lng": "3.8653"
  },
  {
    "country": "BE",
    "name": "Puurs",
    "lat": "51.07409",
    "lng": "4.28844"
  },
  {
    "country": "BE",
    "name": "Putte",
    "lat": "51.05337",
    "lng": "4.63263"
  },
  {
    "country": "BE",
    "name": "Profondeville",
    "lat": "50.37581",
    "lng": "4.86506"
  },
  {
    "country": "BE",
    "name": "Poperinge",
    "lat": "50.85386",
    "lng": "2.72659"
  },
  {
    "country": "BE",
    "name": "Pont-à-Celles",
    "lat": "50.50518",
    "lng": "4.36887"
  },
  {
    "country": "BE",
    "name": "Plombières",
    "lat": "50.73656",
    "lng": "5.95922"
  },
  {
    "country": "BE",
    "name": "Pittem",
    "lat": "50.99279",
    "lng": "3.26317"
  },
  {
    "country": "BE",
    "name": "Philippeville",
    "lat": "50.19612",
    "lng": "4.54374"
  },
  {
    "country": "BE",
    "name": "Perwez",
    "lat": "50.62426",
    "lng": "4.81354"
  },
  {
    "country": "BE",
    "name": "Péruwelz",
    "lat": "50.50819",
    "lng": "3.59373"
  },
  {
    "country": "BE",
    "name": "Perre",
    "lat": "50.88914",
    "lng": "3.86098"
  },
  {
    "country": "BE",
    "name": "Pepinster",
    "lat": "50.57375",
    "lng": "5.8049"
  },
  {
    "country": "BE",
    "name": "Pepingen",
    "lat": "50.75922",
    "lng": "4.15983"
  },
  {
    "country": "BE",
    "name": "Peer",
    "lat": "51.1303",
    "lng": "5.45952"
  },
  {
    "country": "BE",
    "name": "Pecq",
    "lat": "50.68619",
    "lng": "3.33789"
  },
  {
    "country": "BE",
    "name": "Paliseul",
    "lat": "49.90395",
    "lng": "5.13537"
  },
  {
    "country": "BE",
    "name": "Overpelt",
    "lat": "51.21038",
    "lng": "5.41557"
  },
  {
    "country": "BE",
    "name": "Overijse",
    "lat": "50.77436",
    "lng": "4.53461"
  },
  {
    "country": "BE",
    "name": "Oupeye",
    "lat": "50.71184",
    "lng": "5.6468"
  },
  {
    "country": "BE",
    "name": "Ouffet",
    "lat": "50.4387",
    "lng": "5.4657"
  },
  {
    "country": "BE",
    "name": "Oud-Turnhout",
    "lat": "51.31978",
    "lng": "4.9841"
  },
  {
    "country": "BE",
    "name": "Oud-Heverlee",
    "lat": "50.83522",
    "lng": "4.66421"
  },
  {
    "country": "BE",
    "name": "Oudenburg",
    "lat": "51.18489",
    "lng": "3.00035"
  },
  {
    "country": "BE",
    "name": "Oudenaarde",
    "lat": "50.85168",
    "lng": "3.60891"
  },
  {
    "country": "BE",
    "name": "Ottignies",
    "lat": "50.66535",
    "lng": "4.56679"
  },
  {
    "country": "BE",
    "name": "Oreye",
    "lat": "50.71749",
    "lng": "5.3488"
  },
  {
    "country": "BE",
    "name": "Opwijk",
    "lat": "50.96724",
    "lng": "4.18442"
  },
  {
    "country": "BE",
    "name": "Opglabbeek",
    "lat": "51.04258",
    "lng": "5.58346"
  },
  {
    "country": "BE",
    "name": "Oostrozebeke",
    "lat": "50.92093",
    "lng": "3.33799"
  },
  {
    "country": "BE",
    "name": "Oostmalle",
    "lat": "51.3",
    "lng": "4.73333"
  },
  {
    "country": "BE",
    "name": "Oostkamp",
    "lat": "51.15432",
    "lng": "3.23128"
  },
  {
    "country": "BE",
    "name": "Oosterzele",
    "lat": "50.95261",
    "lng": "3.79826"
  },
  {
    "country": "BE",
    "name": "Ostend",
    "lat": "51.21551",
    "lng": "2.927"
  },
  {
    "country": "BE",
    "name": "Oostduinkerke",
    "lat": "51.11565",
    "lng": "2.68217"
  },
  {
    "country": "BE",
    "name": "Onhaye",
    "lat": "50.24148",
    "lng": "4.84069"
  },
  {
    "country": "BE",
    "name": "Olne",
    "lat": "50.58994",
    "lng": "5.74662"
  },
  {
    "country": "BE",
    "name": "Olen",
    "lat": "51.14391",
    "lng": "4.8598"
  },
  {
    "country": "BE",
    "name": "Ohey",
    "lat": "50.4357",
    "lng": "5.12375"
  },
  {
    "country": "BE",
    "name": "Noville-les-Bois",
    "lat": "50.55702",
    "lng": "4.98466"
  },
  {
    "country": "BE",
    "name": "Nivelles",
    "lat": "50.59833",
    "lng": "4.32848"
  },
  {
    "country": "BE",
    "name": "Ninove",
    "lat": "50.82776",
    "lng": "4.02657"
  },
  {
    "country": "BE",
    "name": "Nijlen",
    "lat": "51.16096",
    "lng": "4.67008"
  },
  {
    "country": "BE",
    "name": "Nieuwpoort",
    "lat": "51.13008",
    "lng": "2.75135"
  },
  {
    "country": "BE",
    "name": "Nieuwerkerken",
    "lat": "50.8638",
    "lng": "5.19467"
  },
  {
    "country": "BE",
    "name": "Niel",
    "lat": "51.11096",
    "lng": "4.33428"
  },
  {
    "country": "BE",
    "name": "Nevele",
    "lat": "51.03531",
    "lng": "3.54574"
  },
  {
    "country": "BE",
    "name": "Neufchâteau",
    "lat": "49.84074",
    "lng": "5.43535"
  },
  {
    "country": "BE",
    "name": "Neerpelt",
    "lat": "51.22807",
    "lng": "5.4427"
  },
  {
    "country": "BE",
    "name": "Nazareth",
    "lat": "50.95686",
    "lng": "3.59425"
  },
  {
    "country": "BE",
    "name": "Nassogne",
    "lat": "50.12849",
    "lng": "5.34274"
  },
  {
    "country": "BE",
    "name": "Nandrin",
    "lat": "50.50675",
    "lng": "5.41905"
  },
  {
    "country": "BE",
    "name": "Namur",
    "lat": "50.4669",
    "lng": "4.86746"
  },
  {
    "country": "BE",
    "name": "Musson",
    "lat": "49.55835",
    "lng": "5.70525"
  },
  {
    "country": "BE",
    "name": "Mouscron",
    "lat": "50.74497",
    "lng": "3.20639"
  },
  {
    "country": "BE",
    "name": "Mortsel",
    "lat": "51.16697",
    "lng": "4.45127"
  },
  {
    "country": "BE",
    "name": "Morlanwelz-Mariemont",
    "lat": "50.45502",
    "lng": "4.24519"
  },
  {
    "country": "BE",
    "name": "Moorslede",
    "lat": "50.8919",
    "lng": "3.06117"
  },
  {
    "country": "BE",
    "name": "Mont-Saint-Guibert",
    "lat": "50.63427",
    "lng": "4.61061"
  },
  {
    "country": "BE",
    "name": "Mons",
    "lat": "50.45413",
    "lng": "3.95229"
  },
  {
    "country": "BE",
    "name": "Momignies",
    "lat": "50.0271",
    "lng": "4.16519"
  },
  {
    "country": "BE",
    "name": "Mol",
    "lat": "51.19188",
    "lng": "5.11662"
  },
  {
    "country": "BE",
    "name": "Moerbeke",
    "lat": "51.17409",
    "lng": "3.93001"
  },
  {
    "country": "BE",
    "name": "Modave",
    "lat": "50.44614",
    "lng": "5.29532"
  },
  {
    "country": "BE",
    "name": "Middelkerke",
    "lat": "51.18532",
    "lng": "2.82077"
  },
  {
    "country": "BE",
    "name": "Meulebeke",
    "lat": "50.95136",
    "lng": "3.28804"
  },
  {
    "country": "BE",
    "name": "Mettet",
    "lat": "50.32119",
    "lng": "4.66232"
  },
  {
    "country": "BE",
    "name": "Messancy",
    "lat": "49.59201",
    "lng": "5.81879"
  },
  {
    "country": "BE",
    "name": "Merksplas",
    "lat": "51.35851",
    "lng": "4.86513"
  },
  {
    "country": "BE",
    "name": "Merelbeke",
    "lat": "50.99447",
    "lng": "3.74621"
  },
  {
    "country": "BE",
    "name": "Merchtem",
    "lat": "50.95129",
    "lng": "4.23197"
  },
  {
    "country": "BE",
    "name": "Merbes-le-Château",
    "lat": "50.32449",
    "lng": "4.16489"
  },
  {
    "country": "BE",
    "name": "Menen",
    "lat": "50.79722",
    "lng": "3.12245"
  },
  {
    "country": "BE",
    "name": "Melle",
    "lat": "51.00232",
    "lng": "3.80526"
  },
  {
    "country": "BE",
    "name": "Meix-devant-Virton",
    "lat": "49.60581",
    "lng": "5.48045"
  },
  {
    "country": "BE",
    "name": "Meise",
    "lat": "50.93934",
    "lng": "4.32655"
  },
  {
    "country": "BE",
    "name": "Meerhout",
    "lat": "51.1321",
    "lng": "5.07842"
  },
  {
    "country": "BE",
    "name": "Mechelen",
    "lat": "51.02574",
    "lng": "4.47762"
  },
  {
    "country": "BE",
    "name": "Martelange",
    "lat": "49.83195",
    "lng": "5.73655"
  },
  {
    "country": "BE",
    "name": "Marchin",
    "lat": "50.46707",
    "lng": "5.2428"
  },
  {
    "country": "BE",
    "name": "Marche-en-Famenne",
    "lat": "50.22678",
    "lng": "5.34416"
  },
  {
    "country": "BE",
    "name": "Manhay",
    "lat": "50.29219",
    "lng": "5.67562"
  },
  {
    "country": "BE",
    "name": "Manage",
    "lat": "50.50312",
    "lng": "4.23589"
  },
  {
    "country": "BE",
    "name": "Malmédy",
    "lat": "50.42686",
    "lng": "6.02794"
  },
  {
    "country": "BE",
    "name": "Maldegem",
    "lat": "51.20737",
    "lng": "3.44511"
  },
  {
    "country": "BE",
    "name": "Machelen",
    "lat": "50.91061",
    "lng": "4.44174"
  },
  {
    "country": "BE",
    "name": "Maasmechelen",
    "lat": "50.96545",
    "lng": "5.69452"
  },
  {
    "country": "BE",
    "name": "Maaseik",
    "lat": "51.09802",
    "lng": "5.78379"
  },
  {
    "country": "BE",
    "name": "Lummen",
    "lat": "50.98772",
    "lng": "5.19121"
  },
  {
    "country": "BE",
    "name": "Lubbeek",
    "lat": "50.88278",
    "lng": "4.83896"
  },
  {
    "country": "BE",
    "name": "Lovendegem",
    "lat": "51.10168",
    "lng": "3.61298"
  },
  {
    "country": "BE",
    "name": "Louvain-la-Neuve",
    "lat": "50.66829",
    "lng": "4.61443"
  },
  {
    "country": "BE",
    "name": "Lontzen",
    "lat": "50.68126",
    "lng": "6.00712"
  },
  {
    "country": "BE",
    "name": "Londerzeel",
    "lat": "51.00468",
    "lng": "4.30304"
  },
  {
    "country": "BE",
    "name": "Lommel",
    "lat": "51.23074",
    "lng": "5.31349"
  },
  {
    "country": "BE",
    "name": "Lokeren",
    "lat": "51.10364",
    "lng": "3.99339"
  },
  {
    "country": "BE",
    "name": "Lochristi",
    "lat": "51.09644",
    "lng": "3.83194"
  },
  {
    "country": "BE",
    "name": "Lobbes",
    "lat": "50.35258",
    "lng": "4.26716"
  },
  {
    "country": "BE",
    "name": "Lint",
    "lat": "51.12707",
    "lng": "4.49669"
  },
  {
    "country": "BE",
    "name": "Linkebeek",
    "lat": "50.76781",
    "lng": "4.33688"
  },
  {
    "country": "BE",
    "name": "Lincent",
    "lat": "50.71222",
    "lng": "5.03654"
  },
  {
    "country": "BE",
    "name": "Limbourg",
    "lat": "50.61222",
    "lng": "5.9412"
  },
  {
    "country": "BE",
    "name": "Lille",
    "lat": "51.24197",
    "lng": "4.82313"
  },
  {
    "country": "BE",
    "name": "Lier",
    "lat": "51.13128",
    "lng": "4.57041"
  },
  {
    "country": "BE",
    "name": "Lierneux",
    "lat": "50.28477",
    "lng": "5.79236"
  },
  {
    "country": "BE",
    "name": "Liège",
    "lat": "50.63373",
    "lng": "5.56749"
  },
  {
    "country": "BE",
    "name": "Liedekerke",
    "lat": "50.86892",
    "lng": "4.08743"
  },
  {
    "country": "BE",
    "name": "Lichtervelde",
    "lat": "51.03333",
    "lng": "3.15"
  },
  {
    "country": "BE",
    "name": "Libin",
    "lat": "49.98107",
    "lng": "5.25612"
  },
  {
    "country": "BE",
    "name": "Leuven",
    "lat": "50.87959",
    "lng": "4.70093"
  },
  {
    "country": "BE",
    "name": "Lessines",
    "lat": "50.71104",
    "lng": "3.83579"
  },
  {
    "country": "BE",
    "name": "Leopoldsburg",
    "lat": "51.11667",
    "lng": "5.25"
  },
  {
    "country": "BE",
    "name": "Lens",
    "lat": "50.55696",
    "lng": "3.89946"
  },
  {
    "country": "BE",
    "name": "Lendelede",
    "lat": "50.88626",
    "lng": "3.23747"
  },
  {
    "country": "BE",
    "name": "Léglise",
    "lat": "49.79985",
    "lng": "5.53652"
  },
  {
    "country": "BE",
    "name": "Ledegem",
    "lat": "50.85785",
    "lng": "3.12409"
  },
  {
    "country": "BE",
    "name": "Ledeberg",
    "lat": "51.03859",
    "lng": "3.74458"
  },
  {
    "country": "BE",
    "name": "Ledeberg",
    "lat": "50.84356",
    "lng": "4.09112"
  },
  {
    "country": "BE",
    "name": "Lede",
    "lat": "50.96626",
    "lng": "3.98594"
  },
  {
    "country": "BE",
    "name": "Lebbeke",
    "lat": "51.00464",
    "lng": "4.13457"
  },
  {
    "country": "BE",
    "name": "La Roche-en-Ardenne",
    "lat": "50.18361",
    "lng": "5.57547"
  },
  {
    "country": "BE",
    "name": "Landen",
    "lat": "50.75267",
    "lng": "5.082"
  },
  {
    "country": "BE",
    "name": "Lanaken",
    "lat": "50.89318",
    "lng": "5.6468"
  },
  {
    "country": "BE",
    "name": "La Louvière",
    "lat": "50.48657",
    "lng": "4.18785"
  },
  {
    "country": "BE",
    "name": "La Hulpe",
    "lat": "50.73091",
    "lng": "4.48577"
  },
  {
    "country": "BE",
    "name": "La Calamine",
    "lat": "50.71809",
    "lng": "6.01107"
  },
  {
    "country": "BE",
    "name": "La Bruyère",
    "lat": "50.39478",
    "lng": "4.61444"
  },
  {
    "country": "BE",
    "name": "Laarne",
    "lat": "51.03078",
    "lng": "3.85077"
  },
  {
    "country": "BE",
    "name": "Kuurne",
    "lat": "50.85143",
    "lng": "3.2824"
  },
  {
    "country": "BE",
    "name": "Kruishoutem",
    "lat": "50.90168",
    "lng": "3.52588"
  },
  {
    "country": "BE",
    "name": "Kruibeke",
    "lat": "51.17048",
    "lng": "4.31444"
  },
  {
    "country": "BE",
    "name": "Kraainem",
    "lat": "50.86155",
    "lng": "4.46946"
  },
  {
    "country": "BE",
    "name": "Kortrijk",
    "lat": "50.82803",
    "lng": "3.26487"
  },
  {
    "country": "BE",
    "name": "Kortessem",
    "lat": "50.8589",
    "lng": "5.38974"
  },
  {
    "country": "BE",
    "name": "Kortenberg",
    "lat": "50.88982",
    "lng": "4.54353"
  },
  {
    "country": "BE",
    "name": "Kortenaken",
    "lat": "50.90862",
    "lng": "5.05968"
  },
  {
    "country": "BE",
    "name": "Kortemark",
    "lat": "51.02951",
    "lng": "3.04112"
  },
  {
    "country": "BE",
    "name": "Kontich",
    "lat": "51.13213",
    "lng": "4.44706"
  },
  {
    "country": "BE",
    "name": "Koksijde",
    "lat": "51.11642",
    "lng": "2.63772"
  },
  {
    "country": "BE",
    "name": "Koekelare",
    "lat": "51.09047",
    "lng": "2.9783"
  },
  {
    "country": "BE",
    "name": "Knokke-Heist",
    "lat": "51.35",
    "lng": "3.26667"
  },
  {
    "country": "BE",
    "name": "Knesselare",
    "lat": "51.13932",
    "lng": "3.41282"
  },
  {
    "country": "BE",
    "name": "Kinrooi",
    "lat": "51.14543",
    "lng": "5.74207"
  },
  {
    "country": "BE",
    "name": "Keerbergen",
    "lat": "51.00295",
    "lng": "4.63434"
  },
  {
    "country": "BE",
    "name": "Kasterlee",
    "lat": "51.24118",
    "lng": "4.96651"
  },
  {
    "country": "BE",
    "name": "Kaprijke",
    "lat": "51.2172",
    "lng": "3.61519"
  },
  {
    "country": "BE",
    "name": "Kapelle-op-den-Bos",
    "lat": "51.0097",
    "lng": "4.36303"
  },
  {
    "country": "BE",
    "name": "Kapellen",
    "lat": "51.31377",
    "lng": "4.43539"
  },
  {
    "country": "BE",
    "name": "Kampenhout",
    "lat": "50.9421",
    "lng": "4.55103"
  },
  {
    "country": "BE",
    "name": "Kalmthout",
    "lat": "51.38442",
    "lng": "4.47556"
  },
  {
    "country": "BE",
    "name": "Jurbise",
    "lat": "50.531",
    "lng": "3.90942"
  },
  {
    "country": "BE",
    "name": "Juprelle",
    "lat": "50.7076",
    "lng": "5.53127"
  },
  {
    "country": "BE",
    "name": "Jodoigne",
    "lat": "50.72357",
    "lng": "4.86914"
  },
  {
    "country": "BE",
    "name": "Jalhay",
    "lat": "50.55876",
    "lng": "5.96764"
  },
  {
    "country": "BE",
    "name": "Jabbeke",
    "lat": "51.18185",
    "lng": "3.08935"
  },
  {
    "country": "BE",
    "name": "Izegem",
    "lat": "50.91396",
    "lng": "3.21378"
  },
  {
    "country": "BE",
    "name": "Ittre",
    "lat": "50.64396",
    "lng": "4.26476"
  },
  {
    "country": "BE",
    "name": "Ingelmunster",
    "lat": "50.92081",
    "lng": "3.25571"
  },
  {
    "country": "BE",
    "name": "Incourt",
    "lat": "50.69151",
    "lng": "4.79816"
  },
  {
    "country": "BE",
    "name": "Ieper",
    "lat": "50.85114",
    "lng": "2.88569"
  },
  {
    "country": "BE",
    "name": "Ichtegem",
    "lat": "51.09572",
    "lng": "3.01549"
  },
  {
    "country": "BE",
    "name": "Huy",
    "lat": "50.51894",
    "lng": "5.23284"
  },
  {
    "country": "BE",
    "name": "Hulshout",
    "lat": "51.07451",
    "lng": "4.79081"
  },
  {
    "country": "BE",
    "name": "Huldenberg",
    "lat": "50.78939",
    "lng": "4.5831"
  },
  {
    "country": "BE",
    "name": "Hove",
    "lat": "51.15446",
    "lng": "4.4707"
  },
  {
    "country": "BE",
    "name": "Houyet",
    "lat": "50.18619",
    "lng": "5.00762"
  },
  {
    "country": "BE",
    "name": "Houthulst",
    "lat": "50.97824",
    "lng": "2.9505"
  },
  {
    "country": "BE",
    "name": "Houthalen",
    "lat": "51.03427",
    "lng": "5.37429"
  },
  {
    "country": "BE",
    "name": "Houffalize",
    "lat": "50.13235",
    "lng": "5.78962"
  },
  {
    "country": "BE",
    "name": "Hotton",
    "lat": "50.26742",
    "lng": "5.44609"
  },
  {
    "country": "BE",
    "name": "Hoogstraten",
    "lat": "51.40029",
    "lng": "4.76034"
  },
  {
    "country": "BE",
    "name": "Hooglede",
    "lat": "50.98333",
    "lng": "3.08333"
  },
  {
    "country": "BE",
    "name": "Holsbeek",
    "lat": "50.92097",
    "lng": "4.75747"
  },
  {
    "country": "BE",
    "name": "Hoeselt",
    "lat": "50.84714",
    "lng": "5.48767"
  },
  {
    "country": "BE",
    "name": "Hoeilaart",
    "lat": "50.7673",
    "lng": "4.46835"
  },
  {
    "country": "BE",
    "name": "Hoegaarden",
    "lat": "50.7756",
    "lng": "4.88952"
  },
  {
    "country": "BE",
    "name": "Hoboken",
    "lat": "51.17611",
    "lng": "4.34844"
  },
  {
    "country": "BE",
    "name": "Heusden",
    "lat": "51.03664",
    "lng": "5.28013"
  },
  {
    "country": "BE",
    "name": "Herzele",
    "lat": "50.88681",
    "lng": "3.89014"
  },
  {
    "country": "BE",
    "name": "Herve",
    "lat": "50.64083",
    "lng": "5.79353"
  },
  {
    "country": "BE",
    "name": "Herstal",
    "lat": "50.66415",
    "lng": "5.62346"
  },
  {
    "country": "BE",
    "name": "Herselt",
    "lat": "51.05159",
    "lng": "4.88231"
  },
  {
    "country": "BE",
    "name": "Héron",
    "lat": "50.54731",
    "lng": "5.09774"
  },
  {
    "country": "BE",
    "name": "Herne",
    "lat": "50.72423",
    "lng": "4.03481"
  },
  {
    "country": "BE",
    "name": "Herk-de-Stad",
    "lat": "50.94013",
    "lng": "5.16636"
  },
  {
    "country": "BE",
    "name": "Herenthout",
    "lat": "51.1401",
    "lng": "4.75572"
  },
  {
    "country": "BE",
    "name": "Herentals",
    "lat": "51.17655",
    "lng": "4.83248"
  },
  {
    "country": "BE",
    "name": "Herent",
    "lat": "50.90861",
    "lng": "4.67056"
  },
  {
    "country": "BE",
    "name": "Herbeumont",
    "lat": "49.78086",
    "lng": "5.2358"
  },
  {
    "country": "BE",
    "name": "Hensies",
    "lat": "50.43263",
    "lng": "3.68411"
  },
  {
    "country": "BE",
    "name": "Hemiksem",
    "lat": "51.14484",
    "lng": "4.33874"
  },
  {
    "country": "BE",
    "name": "Helchteren",
    "lat": "51.05591",
    "lng": "5.38244"
  },
  {
    "country": "BE",
    "name": "Heist-op-den-Berg",
    "lat": "51.07537",
    "lng": "4.72827"
  },
  {
    "country": "BE",
    "name": "Heers",
    "lat": "50.75383",
    "lng": "5.3021"
  },
  {
    "country": "BE",
    "name": "Havelange",
    "lat": "50.38931",
    "lng": "5.23816"
  },
  {
    "country": "BE",
    "name": "Hastière-Lavaux",
    "lat": "50.21849",
    "lng": "4.82446"
  },
  {
    "country": "BE",
    "name": "Hasselt",
    "lat": "50.93106",
    "lng": "5.33781"
  },
  {
    "country": "BE",
    "name": "Harelbeke",
    "lat": "50.85343",
    "lng": "3.30935"
  },
  {
    "country": "BE",
    "name": "Hannut",
    "lat": "50.67142",
    "lng": "5.07898"
  },
  {
    "country": "BE",
    "name": "Hamois",
    "lat": "50.3402",
    "lng": "5.15619"
  },
  {
    "country": "BE",
    "name": "Hamoir",
    "lat": "50.42675",
    "lng": "5.53304"
  },
  {
    "country": "BE",
    "name": "Hamme",
    "lat": "51.09822",
    "lng": "4.13705"
  },
  {
    "country": "BE",
    "name": "Halle",
    "lat": "50.73385",
    "lng": "4.23454"
  },
  {
    "country": "BE",
    "name": "Halen",
    "lat": "50.94837",
    "lng": "5.11096"
  },
  {
    "country": "BE",
    "name": "Habay-la-Vieille",
    "lat": "49.72329",
    "lng": "5.61999"
  },
  {
    "country": "BE",
    "name": "Haaltert",
    "lat": "50.90634",
    "lng": "4.00093"
  },
  {
    "country": "BE",
    "name": "Haacht",
    "lat": "50.97737",
    "lng": "4.63777"
  },
  {
    "country": "BE",
    "name": "Grobbendonk",
    "lat": "51.19043",
    "lng": "4.73562"
  },
  {
    "country": "BE",
    "name": "Grimbergen",
    "lat": "50.93409",
    "lng": "4.37213"
  },
  {
    "country": "BE",
    "name": "Grez-Doiceau",
    "lat": "50.73901",
    "lng": "4.69829"
  },
  {
    "country": "BE",
    "name": "Gouvy",
    "lat": "50.186",
    "lng": "5.93917"
  },
  {
    "country": "BE",
    "name": "Gooik",
    "lat": "50.79443",
    "lng": "4.11378"
  },
  {
    "country": "BE",
    "name": "Glabbeek",
    "lat": "50.87267",
    "lng": "4.95615"
  },
  {
    "country": "BE",
    "name": "Gistel",
    "lat": "51.15612",
    "lng": "2.96387"
  },
  {
    "country": "BE",
    "name": "Gingelom",
    "lat": "50.74792",
    "lng": "5.13422"
  },
  {
    "country": "BE",
    "name": "Gesves",
    "lat": "50.40146",
    "lng": "5.07457"
  },
  {
    "country": "BE",
    "name": "Gerpinnes",
    "lat": "50.33789",
    "lng": "4.52731"
  },
  {
    "country": "BE",
    "name": "Geraardsbergen",
    "lat": "50.77343",
    "lng": "3.88223"
  },
  {
    "country": "BE",
    "name": "Gent",
    "lat": "51.05",
    "lng": "3.71667"
  },
  {
    "country": "BE",
    "name": "Genk",
    "lat": "50.965",
    "lng": "5.50082"
  },
  {
    "country": "BE",
    "name": "Genappe",
    "lat": "50.61173",
    "lng": "4.45152"
  },
  {
    "country": "BE",
    "name": "Gembloux",
    "lat": "50.56149",
    "lng": "4.69889"
  },
  {
    "country": "BE",
    "name": "Geetbets",
    "lat": "50.89431",
    "lng": "5.11199"
  },
  {
    "country": "BE",
    "name": "Geer",
    "lat": "50.6699",
    "lng": "5.17364"
  },
  {
    "country": "BE",
    "name": "Geel",
    "lat": "51.16557",
    "lng": "4.98917"
  },
  {
    "country": "BE",
    "name": "Gedinne",
    "lat": "49.98037",
    "lng": "4.93674"
  },
  {
    "country": "BE",
    "name": "Gavere",
    "lat": "50.92917",
    "lng": "3.66184"
  },
  {
    "country": "BE",
    "name": "Galmaarden",
    "lat": "50.75389",
    "lng": "3.97121"
  },
  {
    "country": "BE",
    "name": "Froidchapelle",
    "lat": "50.15106",
    "lng": "4.32742"
  },
  {
    "country": "BE",
    "name": "Frasnes-lez-Buissenal",
    "lat": "50.66783",
    "lng": "3.62047"
  },
  {
    "country": "BE",
    "name": "Frameries",
    "lat": "50.40578",
    "lng": "3.89603"
  },
  {
    "country": "BE",
    "name": "Sint-Pieters-Voeren",
    "lat": "50.73863",
    "lng": "5.82224"
  },
  {
    "country": "BE",
    "name": "Fosses-la-Ville",
    "lat": "50.39517",
    "lng": "4.69623"
  },
  {
    "country": "BE",
    "name": "Forville",
    "lat": "50.57424",
    "lng": "4.99861"
  },
  {
    "country": "BE",
    "name": "Florenville",
    "lat": "49.69983",
    "lng": "5.3074"
  },
  {
    "country": "BE",
    "name": "Florennes",
    "lat": "50.25127",
    "lng": "4.60636"
  },
  {
    "country": "BE",
    "name": "Floreffe",
    "lat": "50.43452",
    "lng": "4.7596"
  },
  {
    "country": "BE",
    "name": "Flobecq",
    "lat": "50.73733",
    "lng": "3.73876"
  },
  {
    "country": "BE",
    "name": "Fleurus",
    "lat": "50.48351",
    "lng": "4.55006"
  },
  {
    "country": "BE",
    "name": "Fléron",
    "lat": "50.61516",
    "lng": "5.68062"
  },
  {
    "country": "BE",
    "name": "Flémalle-Haute",
    "lat": "50.59994",
    "lng": "5.44471"
  },
  {
    "country": "BE",
    "name": "Fexhe-le-Haut-Clocher",
    "lat": "50.6654",
    "lng": "5.39978"
  },
  {
    "country": "BE",
    "name": "Ferrières",
    "lat": "50.40157",
    "lng": "5.61092"
  },
  {
    "country": "BE",
    "name": "Fauvillers",
    "lat": "49.85116",
    "lng": "5.66405"
  },
  {
    "country": "BE",
    "name": "Farciennes",
    "lat": "50.43006",
    "lng": "4.54152"
  },
  {
    "country": "BE",
    "name": "Faimes",
    "lat": "50.66252",
    "lng": "5.26005"
  },
  {
    "country": "BE",
    "name": "Evergem",
    "lat": "51.10529",
    "lng": "3.704"
  },
  {
    "country": "BE",
    "name": "Eupen",
    "lat": "50.6279",
    "lng": "6.03647"
  },
  {
    "country": "BE",
    "name": "Étalle",
    "lat": "49.67385",
    "lng": "5.60019"
  },
  {
    "country": "BE",
    "name": "Estinnes-au-Val",
    "lat": "50.41016",
    "lng": "4.10477"
  },
  {
    "country": "BE",
    "name": "Estaimpuis",
    "lat": "50.70485",
    "lng": "3.26785"
  },
  {
    "country": "BE",
    "name": "Essen",
    "lat": "51.46791",
    "lng": "4.46901"
  },
  {
    "country": "BE",
    "name": "Esneux",
    "lat": "50.53596",
    "lng": "5.56775"
  },
  {
    "country": "BE",
    "name": "Erquelinnes",
    "lat": "50.30688",
    "lng": "4.11129"
  },
  {
    "country": "BE",
    "name": "Érezée",
    "lat": "50.29292",
    "lng": "5.55815"
  },
  {
    "country": "BE",
    "name": "Engis",
    "lat": "50.58156",
    "lng": "5.39916"
  },
  {
    "country": "BE",
    "name": "Enghien",
    "lat": "50.68373",
    "lng": "4.03284"
  },
  {
    "country": "BE",
    "name": "Ellezelles",
    "lat": "50.73512",
    "lng": "3.67985"
  },
  {
    "country": "BE",
    "name": "Éghezée",
    "lat": "50.59076",
    "lng": "4.91175"
  },
  {
    "country": "BE",
    "name": "Eeklo",
    "lat": "51.18703",
    "lng": "3.55654"
  },
  {
    "country": "BE",
    "name": "Edegem",
    "lat": "51.15662",
    "lng": "4.44504"
  },
  {
    "country": "BE",
    "name": "Écaussinnes-d’Enghien",
    "lat": "50.56822",
    "lng": "4.1658"
  },
  {
    "country": "BE",
    "name": "Durbuy",
    "lat": "50.35291",
    "lng": "5.45631"
  },
  {
    "country": "BE",
    "name": "Duffel",
    "lat": "51.09554",
    "lng": "4.50903"
  },
  {
    "country": "BE",
    "name": "Drogenbos",
    "lat": "50.78733",
    "lng": "4.31471"
  },
  {
    "country": "BE",
    "name": "Dour",
    "lat": "50.39583",
    "lng": "3.77792"
  },
  {
    "country": "BE",
    "name": "Donceel",
    "lat": "50.64827",
    "lng": "5.32"
  },
  {
    "country": "BE",
    "name": "Doische",
    "lat": "50.13356",
    "lng": "4.73545"
  },
  {
    "country": "BE",
    "name": "Dison",
    "lat": "50.61004",
    "lng": "5.8534"
  },
  {
    "country": "BE",
    "name": "Dinant",
    "lat": "50.25807",
    "lng": "4.91166"
  },
  {
    "country": "BE",
    "name": "Dilbeek",
    "lat": "50.84799",
    "lng": "4.25972"
  },
  {
    "country": "BE",
    "name": "Diksmuide",
    "lat": "51.03248",
    "lng": "2.86384"
  },
  {
    "country": "BE",
    "name": "Diest",
    "lat": "50.98923",
    "lng": "5.05062"
  },
  {
    "country": "BE",
    "name": "Diepenbeek",
    "lat": "50.90769",
    "lng": "5.41875"
  },
  {
    "country": "BE",
    "name": "Diegem",
    "lat": "50.89727",
    "lng": "4.43354"
  },
  {
    "country": "BE",
    "name": "Deurne",
    "lat": "51.22134",
    "lng": "4.46595"
  },
  {
    "country": "BE",
    "name": "Destelbergen",
    "lat": "51.05952",
    "lng": "3.79899"
  },
  {
    "country": "BE",
    "name": "Dessel",
    "lat": "51.23855",
    "lng": "5.11448"
  },
  {
    "country": "BE",
    "name": "De Pinte",
    "lat": "50.99339",
    "lng": "3.64747"
  },
  {
    "country": "BE",
    "name": "De Panne",
    "lat": "51.09793",
    "lng": "2.59368"
  },
  {
    "country": "BE",
    "name": "Dentergem",
    "lat": "50.96429",
    "lng": "3.41617"
  },
  {
    "country": "BE",
    "name": "Dendermonde",
    "lat": "51.02869",
    "lng": "4.10106"
  },
  {
    "country": "BE",
    "name": "Denderleeuw",
    "lat": "50.88506",
    "lng": "4.07601"
  },
  {
    "country": "BE",
    "name": "Deinze",
    "lat": "50.98175",
    "lng": "3.53096"
  },
  {
    "country": "BE",
    "name": "De Haan",
    "lat": "51.27261",
    "lng": "3.03446"
  },
  {
    "country": "BE",
    "name": "Deerlijk",
    "lat": "50.85337",
    "lng": "3.35416"
  },
  {
    "country": "BE",
    "name": "Daverdisse",
    "lat": "50.02161",
    "lng": "5.11811"
  },
  {
    "country": "BE",
    "name": "Damme",
    "lat": "51.25147",
    "lng": "3.28144"
  },
  {
    "country": "BE",
    "name": "Dalhem",
    "lat": "50.71315",
    "lng": "5.72774"
  },
  {
    "country": "BE",
    "name": "Crisnée",
    "lat": "50.71703",
    "lng": "5.39802"
  },
  {
    "country": "BE",
    "name": "Couvin",
    "lat": "50.05284",
    "lng": "4.49495"
  },
  {
    "country": "BE",
    "name": "Court-Saint-Étienne",
    "lat": "50.63378",
    "lng": "4.56851"
  },
  {
    "country": "BE",
    "name": "Courcelles",
    "lat": "50.46379",
    "lng": "4.3747"
  },
  {
    "country": "BE",
    "name": "Comblain-au-Pont",
    "lat": "50.47488",
    "lng": "5.57711"
  },
  {
    "country": "BE",
    "name": "Colfontaine",
    "lat": "50.4141",
    "lng": "3.85569"
  },
  {
    "country": "BE",
    "name": "Clavier",
    "lat": "50.40069",
    "lng": "5.35154"
  },
  {
    "country": "BE",
    "name": "Ciney",
    "lat": "50.29449",
    "lng": "5.10015"
  },
  {
    "country": "BE",
    "name": "Chiny",
    "lat": "49.73833",
    "lng": "5.34104"
  },
  {
    "country": "BE",
    "name": "Chimay",
    "lat": "50.04856",
    "lng": "4.31712"
  },
  {
    "country": "BE",
    "name": "Chièvres",
    "lat": "50.58787",
    "lng": "3.80711"
  },
  {
    "country": "BE",
    "name": "Chaumont-Gistoux",
    "lat": "50.67753",
    "lng": "4.7212"
  },
  {
    "country": "BE",
    "name": "Chaudfontaine",
    "lat": "50.5828",
    "lng": "5.6341"
  },
  {
    "country": "BE",
    "name": "Châtelet",
    "lat": "50.40338",
    "lng": "4.52826"
  },
  {
    "country": "BE",
    "name": "Chastre-Villeroux-Blanmont",
    "lat": "50.60857",
    "lng": "4.64198"
  },
  {
    "country": "BE",
    "name": "Chasse Royale",
    "lat": "50.42842",
    "lng": "3.95001"
  },
  {
    "country": "BE",
    "name": "Charleroi",
    "lat": "50.41136",
    "lng": "4.44448"
  },
  {
    "country": "BE",
    "name": "Chapelle-lez-Herlaimont",
    "lat": "50.4713",
    "lng": "4.28227"
  },
  {
    "country": "BE",
    "name": "Cerfontaine",
    "lat": "50.17047",
    "lng": "4.41028"
  },
  {
    "country": "BE",
    "name": "Celles",
    "lat": "50.71229",
    "lng": "3.45733"
  },
  {
    "country": "BE",
    "name": "Butgenbach",
    "lat": "50.42689",
    "lng": "6.20504"
  },
  {
    "country": "BE",
    "name": "Burdinne",
    "lat": "50.58454",
    "lng": "5.07663"
  },
  {
    "country": "BE",
    "name": "Bullange",
    "lat": "50.40731",
    "lng": "6.25749"
  },
  {
    "country": "BE",
    "name": "Buggenhout",
    "lat": "51.0159",
    "lng": "4.20173"
  },
  {
    "country": "BE",
    "name": "Brussels",
    "lat": "50.85045",
    "lng": "4.34878"
  },
  {
    "country": "BE",
    "name": "Brunehault",
    "lat": "50.50524",
    "lng": "4.43209"
  },
  {
    "country": "BE",
    "name": "Brugge",
    "lat": "51.20892",
    "lng": "3.22424"
  },
  {
    "country": "BE",
    "name": "Brugelette",
    "lat": "50.59577",
    "lng": "3.85363"
  },
  {
    "country": "BE",
    "name": "Bree",
    "lat": "51.14152",
    "lng": "5.5969"
  },
  {
    "country": "BE",
    "name": "Bredene",
    "lat": "51.23489",
    "lng": "2.97559"
  },
  {
    "country": "BE",
    "name": "Brecht",
    "lat": "51.35024",
    "lng": "4.63829"
  },
  {
    "country": "BE",
    "name": "Brasschaat",
    "lat": "51.2912",
    "lng": "4.49182"
  },
  {
    "country": "BE",
    "name": "Braives",
    "lat": "50.61745",
    "lng": "5.13302"
  },
  {
    "country": "BE",
    "name": "Braine-le-Comte",
    "lat": "50.60979",
    "lng": "4.14658"
  },
  {
    "country": "BE",
    "name": "Braine-le-Château",
    "lat": "50.6799",
    "lng": "4.27385"
  },
  {
    "country": "BE",
    "name": "Braine-l'Alleud",
    "lat": "50.68363",
    "lng": "4.36784"
  },
  {
    "country": "BE",
    "name": "Boutersem",
    "lat": "50.83511",
    "lng": "4.8345"
  },
  {
    "country": "BE",
    "name": "Boussu",
    "lat": "50.43417",
    "lng": "3.7944"
  },
  {
    "country": "BE",
    "name": "Bouillon",
    "lat": "49.79324",
    "lng": "5.06703"
  },
  {
    "country": "BE",
    "name": "Borsbeek",
    "lat": "51.19661",
    "lng": "4.48543"
  },
  {
    "country": "BE",
    "name": "Bornem",
    "lat": "51.09716",
    "lng": "4.24364"
  },
  {
    "country": "BE",
    "name": "Borgloon",
    "lat": "50.80505",
    "lng": "5.34366"
  },
  {
    "country": "BE",
    "name": "Boortmeerbeek",
    "lat": "50.97929",
    "lng": "4.57443"
  },
  {
    "country": "BE",
    "name": "Boom",
    "lat": "51.09242",
    "lng": "4.3717"
  },
  {
    "country": "BE",
    "name": "Bonheiden",
    "lat": "51.02261",
    "lng": "4.54714"
  },
  {
    "country": "BE",
    "name": "Boechout",
    "lat": "51.15959",
    "lng": "4.49195"
  },
  {
    "country": "BE",
    "name": "Bocholt",
    "lat": "51.17337",
    "lng": "5.57994"
  },
  {
    "country": "BE",
    "name": "Blégny",
    "lat": "50.67255",
    "lng": "5.72508"
  },
  {
    "country": "BE",
    "name": "Blankenberge",
    "lat": "51.31306",
    "lng": "3.13227"
  },
  {
    "country": "BE",
    "name": "Binche",
    "lat": "50.41155",
    "lng": "4.16469"
  },
  {
    "country": "BE",
    "name": "Bilzen",
    "lat": "50.87325",
    "lng": "5.5184"
  },
  {
    "country": "BE",
    "name": "Bièvre",
    "lat": "49.94085",
    "lng": "5.01591"
  },
  {
    "country": "BE",
    "name": "Bierbeek",
    "lat": "50.82876",
    "lng": "4.75949"
  },
  {
    "country": "BE",
    "name": "Beyne-Heusay",
    "lat": "50.62251",
    "lng": "5.66508"
  },
  {
    "country": "BE",
    "name": "Beveren",
    "lat": "51.21187",
    "lng": "4.25633"
  },
  {
    "country": "BE",
    "name": "Bever",
    "lat": "50.91667",
    "lng": "4.31667"
  },
  {
    "country": "BE",
    "name": "Bertrix",
    "lat": "49.85596",
    "lng": "5.25539"
  },
  {
    "country": "BE",
    "name": "Bertogne",
    "lat": "50.08364",
    "lng": "5.66689"
  },
  {
    "country": "BE",
    "name": "Bertem",
    "lat": "50.86403",
    "lng": "4.62918"
  },
  {
    "country": "BE",
    "name": "Bernissart",
    "lat": "50.4746",
    "lng": "3.64961"
  },
  {
    "country": "BE",
    "name": "Berloz",
    "lat": "50.69829",
    "lng": "5.21236"
  },
  {
    "country": "BE",
    "name": "Berlare",
    "lat": "51.03333",
    "lng": "4"
  },
  {
    "country": "BE",
    "name": "Berlaar",
    "lat": "51.1176",
    "lng": "4.65835"
  },
  {
    "country": "BE",
    "name": "Beringen",
    "lat": "51.04954",
    "lng": "5.22606"
  },
  {
    "country": "BE",
    "name": "Beloeil",
    "lat": "50.55047",
    "lng": "3.73484"
  },
  {
    "country": "BE",
    "name": "Bekkevoort",
    "lat": "50.94074",
    "lng": "4.969"
  },
  {
    "country": "BE",
    "name": "Begijnendijk",
    "lat": "51.01942",
    "lng": "4.78377"
  },
  {
    "country": "BE",
    "name": "Beersel",
    "lat": "50.76589",
    "lng": "4.3002"
  },
  {
    "country": "BE",
    "name": "Beerse",
    "lat": "51.31927",
    "lng": "4.85304"
  },
  {
    "country": "BE",
    "name": "Beernem",
    "lat": "51.13981",
    "lng": "3.33896"
  },
  {
    "country": "BE",
    "name": "Beauvechain",
    "lat": "50.78195",
    "lng": "4.7718"
  },
  {
    "country": "BE",
    "name": "Beauraing",
    "lat": "50.11042",
    "lng": "4.95554"
  },
  {
    "country": "BE",
    "name": "Beaumont",
    "lat": "50.23699",
    "lng": "4.23926"
  },
  {
    "country": "BE",
    "name": "Bastogne",
    "lat": "50.00347",
    "lng": "5.71844"
  },
  {
    "country": "BE",
    "name": "Bassenge",
    "lat": "50.75883",
    "lng": "5.60989"
  },
  {
    "country": "BE",
    "name": "Basse Lasne",
    "lat": "50.69503",
    "lng": "4.49218"
  },
  {
    "country": "BE",
    "name": "Balen",
    "lat": "51.16837",
    "lng": "5.17027"
  },
  {
    "country": "BE",
    "name": "Baelen",
    "lat": "50.63131",
    "lng": "5.97433"
  },
  {
    "country": "BE",
    "name": "Baarle-Hertog",
    "lat": "51.40504",
    "lng": "4.89226"
  },
  {
    "country": "BE",
    "name": "Aywaille",
    "lat": "50.47411",
    "lng": "5.67684"
  },
  {
    "country": "BE",
    "name": "Awans",
    "lat": "50.66774",
    "lng": "5.46329"
  },
  {
    "country": "BE",
    "name": "Avelgem",
    "lat": "50.77618",
    "lng": "3.44502"
  },
  {
    "country": "BE",
    "name": "Aubel",
    "lat": "50.70189",
    "lng": "5.85812"
  },
  {
    "country": "BE",
    "name": "Aubange",
    "lat": "49.56652",
    "lng": "5.80492"
  },
  {
    "country": "BE",
    "name": "Attert",
    "lat": "49.75035",
    "lng": "5.78634"
  },
  {
    "country": "BE",
    "name": "Ath",
    "lat": "50.62937",
    "lng": "3.77801"
  },
  {
    "country": "BE",
    "name": "Assesse",
    "lat": "50.36934",
    "lng": "5.02204"
  },
  {
    "country": "BE",
    "name": "Assenede",
    "lat": "51.22598",
    "lng": "3.75085"
  },
  {
    "country": "BE",
    "name": "Asse",
    "lat": "50.91011",
    "lng": "4.19836"
  },
  {
    "country": "BE",
    "name": "As",
    "lat": "51.00755",
    "lng": "5.58453"
  },
  {
    "country": "BE",
    "name": "Arlon",
    "lat": "49.68333",
    "lng": "5.81667"
  },
  {
    "country": "BE",
    "name": "Arendonk",
    "lat": "51.32267",
    "lng": "5.08289"
  },
  {
    "country": "BE",
    "name": "Ardooie",
    "lat": "50.9757",
    "lng": "3.19736"
  },
  {
    "country": "BE",
    "name": "Anzegem",
    "lat": "50.837",
    "lng": "3.47786"
  },
  {
    "country": "BE",
    "name": "Antwerpen",
    "lat": "51.21989",
    "lng": "4.40346"
  },
  {
    "country": "BE",
    "name": "Antoing",
    "lat": "50.56765",
    "lng": "3.4492"
  },
  {
    "country": "BE",
    "name": "Anthisnes",
    "lat": "50.48323",
    "lng": "5.519"
  },
  {
    "country": "BE",
    "name": "Ans",
    "lat": "50.6623",
    "lng": "5.52029"
  },
  {
    "country": "BE",
    "name": "Anhée",
    "lat": "50.31039",
    "lng": "4.87827"
  },
  {
    "country": "BE",
    "name": "Anderlues",
    "lat": "50.40704",
    "lng": "4.27136"
  },
  {
    "country": "BE",
    "name": "Andenne",
    "lat": "50.48941",
    "lng": "5.09513"
  },
  {
    "country": "BE",
    "name": "Amblève",
    "lat": "50.35357",
    "lng": "6.17002"
  },
  {
    "country": "BE",
    "name": "Amay",
    "lat": "50.54829",
    "lng": "5.30974"
  },
  {
    "country": "BE",
    "name": "Alveringem",
    "lat": "51.01238",
    "lng": "2.71117"
  },
  {
    "country": "BE",
    "name": "Alken",
    "lat": "50.87553",
    "lng": "5.30558"
  },
  {
    "country": "BE",
    "name": "Aiseau",
    "lat": "50.41158",
    "lng": "4.58671"
  },
  {
    "country": "BE",
    "name": "Aartselaar",
    "lat": "51.13412",
    "lng": "4.38678"
  },
  {
    "country": "BE",
    "name": "Aarschot",
    "lat": "50.98715",
    "lng": "4.83695"
  },
  {
    "country": "BE",
    "name": "Aalter",
    "lat": "51.09017",
    "lng": "3.44693"
  },
  {
    "country": "BE",
    "name": "Aalst",
    "lat": "50.93604",
    "lng": "4.0355"
  },
  {
    "country": "BE",
    "name": "Sint-Joris",
    "lat": "50.87117",
    "lng": "5.272"
  },
  {
    "country": "BE",
    "name": "Terkoest",
    "lat": "50.89832",
    "lng": "5.27623"
  },
  {
    "country": "BF",
    "name": "Zorgo",
    "lat": "12.24922",
    "lng": "-0.61527"
  },
  {
    "country": "BF",
    "name": "Zitenga",
    "lat": "12.74846",
    "lng": "-1.30989"
  },
  {
    "country": "BF",
    "name": "Ziniaré",
    "lat": "12.58186",
    "lng": "-1.2971"
  },
  {
    "country": "BF",
    "name": "Yako",
    "lat": "12.9591",
    "lng": "-2.26075"
  },
  {
    "country": "BF",
    "name": "Tougan",
    "lat": "13.0725",
    "lng": "-3.0694"
  },
  {
    "country": "BF",
    "name": "Toma",
    "lat": "12.75844",
    "lng": "-2.89879"
  },
  {
    "country": "BF",
    "name": "Toéghin",
    "lat": "12.8159",
    "lng": "-1.72763"
  },
  {
    "country": "BF",
    "name": "Titao",
    "lat": "13.76667",
    "lng": "-2.06667"
  },
  {
    "country": "BF",
    "name": "Tenkodogo",
    "lat": "11.78",
    "lng": "-0.36972"
  },
  {
    "country": "BF",
    "name": "Tanghin-Dassouri",
    "lat": "12.27256",
    "lng": "-1.71704"
  },
  {
    "country": "BF",
    "name": "Sourgoubila",
    "lat": "12.41462",
    "lng": "-1.80644"
  },
  {
    "country": "BF",
    "name": "Salanso",
    "lat": "12.17423",
    "lng": "-4.08477"
  },
  {
    "country": "BF",
    "name": "Sindou",
    "lat": "10.66667",
    "lng": "-5.16667"
  },
  {
    "country": "BF",
    "name": "Siglé",
    "lat": "12.55618",
    "lng": "-1.88775"
  },
  {
    "country": "BF",
    "name": "Sebba",
    "lat": "13.43641",
    "lng": "0.53044"
  },
  {
    "country": "BF",
    "name": "Sapouy",
    "lat": "11.55444",
    "lng": "-1.77361"
  },
  {
    "country": "BF",
    "name": "Saponé",
    "lat": "12.05356",
    "lng": "-1.60491"
  },
  {
    "country": "BF",
    "name": "Saaba",
    "lat": "12.37136",
    "lng": "-1.41468"
  },
  {
    "country": "BF",
    "name": "Réo",
    "lat": "12.31963",
    "lng": "-2.47094"
  },
  {
    "country": "BF",
    "name": "Pô",
    "lat": "11.16972",
    "lng": "-1.145"
  },
  {
    "country": "BF",
    "name": "Pitmoaga",
    "lat": "12.24564",
    "lng": "-1.88148"
  },
  {
    "country": "BF",
    "name": "Pama",
    "lat": "11.24972",
    "lng": "0.7075"
  },
  {
    "country": "BF",
    "name": "Pabré",
    "lat": "12.52147",
    "lng": "-1.58631"
  },
  {
    "country": "BF",
    "name": "Oursi",
    "lat": "14.67553",
    "lng": "-0.46033"
  },
  {
    "country": "BF",
    "name": "Ourgou-Manéga",
    "lat": "12.77994",
    "lng": "-1.5077"
  },
  {
    "country": "BF",
    "name": "Ouargaye",
    "lat": "11.50202",
    "lng": "0.05886"
  },
  {
    "country": "BF",
    "name": "Ouahigouya",
    "lat": "13.58278",
    "lng": "-2.42158"
  },
  {
    "country": "BF",
    "name": "Ouagadougou",
    "lat": "12.36566",
    "lng": "-1.53388"
  },
  {
    "country": "BF",
    "name": "Niou",
    "lat": "12.76975",
    "lng": "-1.93376"
  },
  {
    "country": "BF",
    "name": "Nouna",
    "lat": "12.72939",
    "lng": "-3.86305"
  },
  {
    "country": "BF",
    "name": "Manga",
    "lat": "11.66361",
    "lng": "-1.07306"
  },
  {
    "country": "BF",
    "name": "Mané",
    "lat": "12.98836",
    "lng": "-1.34434"
  },
  {
    "country": "BF",
    "name": "Loumbila",
    "lat": "12.51863",
    "lng": "-1.3734"
  },
  {
    "country": "BF",
    "name": "Léo",
    "lat": "11.10033",
    "lng": "-2.10654"
  },
  {
    "country": "BF",
    "name": "Laye",
    "lat": "12.53118",
    "lng": "-1.77684"
  },
  {
    "country": "BF",
    "name": "Koupéla",
    "lat": "12.17864",
    "lng": "-0.35103"
  },
  {
    "country": "BF",
    "name": "Koudougou",
    "lat": "12.25263",
    "lng": "-2.36272"
  },
  {
    "country": "BF",
    "name": "Korsimoro",
    "lat": "12.82506",
    "lng": "-1.06737"
  },
  {
    "country": "BF",
    "name": "Kongoussi",
    "lat": "13.32583",
    "lng": "-1.53472"
  },
  {
    "country": "BF",
    "name": "Komsilga",
    "lat": "12.18653",
    "lng": "-1.63379"
  },
  {
    "country": "BF",
    "name": "Komki-Ipala",
    "lat": "12.18279",
    "lng": "-1.79131"
  },
  {
    "country": "BF",
    "name": "Kombissiri",
    "lat": "12.06095",
    "lng": "-1.33355"
  },
  {
    "country": "BF",
    "name": "Kokologo",
    "lat": "12.19392",
    "lng": "-1.87687"
  },
  {
    "country": "BF",
    "name": "Kayao",
    "lat": "12.01295",
    "lng": "-1.8419"
  },
  {
    "country": "BF",
    "name": "Kaya",
    "lat": "13.09167",
    "lng": "-1.08444"
  },
  {
    "country": "BF",
    "name": "Houndé",
    "lat": "11.5",
    "lng": "-3.51667"
  },
  {
    "country": "BF",
    "name": "Gourcy",
    "lat": "13.20776",
    "lng": "-2.35893"
  },
  {
    "country": "BF",
    "name": "Goulouré",
    "lat": "12.23484",
    "lng": "-1.93394"
  },
  {
    "country": "BF",
    "name": "Gorom-Gorom",
    "lat": "14.4429",
    "lng": "-0.23468"
  },
  {
    "country": "BF",
    "name": "Gayéri",
    "lat": "12.64824",
    "lng": "0.49314"
  },
  {
    "country": "BF",
    "name": "Garango",
    "lat": "11.8",
    "lng": "-0.55056"
  },
  {
    "country": "BF",
    "name": "Fada N'gourma",
    "lat": "12.06157",
    "lng": "0.35843"
  },
  {
    "country": "BF",
    "name": "Dori",
    "lat": "14.0354",
    "lng": "-0.0345"
  },
  {
    "country": "BF",
    "name": "Djibo",
    "lat": "14.0994",
    "lng": "-1.62554"
  },
  {
    "country": "BF",
    "name": "Diébougou",
    "lat": "10.96209",
    "lng": "-3.24967"
  },
  {
    "country": "BF",
    "name": "Diapaga",
    "lat": "12.07305",
    "lng": "1.78838"
  },
  {
    "country": "BF",
    "name": "Déou",
    "lat": "14.60084",
    "lng": "-0.71901"
  },
  {
    "country": "BF",
    "name": "Dédougou",
    "lat": "12.46338",
    "lng": "-3.46075"
  },
  {
    "country": "BF",
    "name": "Dapélogo",
    "lat": "12.67274",
    "lng": "-1.53907"
  },
  {
    "country": "BF",
    "name": "Dano",
    "lat": "11.1464",
    "lng": "-3.05784"
  },
  {
    "country": "BF",
    "name": "Boussouma",
    "lat": "12.91069",
    "lng": "-1.0819"
  },
  {
    "country": "BF",
    "name": "Boussé",
    "lat": "12.66121",
    "lng": "-1.89515"
  },
  {
    "country": "BF",
    "name": "Boulsa",
    "lat": "12.66664",
    "lng": "-0.57469"
  },
  {
    "country": "BF",
    "name": "Boromo",
    "lat": "11.74542",
    "lng": "-2.93006"
  },
  {
    "country": "BF",
    "name": "Bogandé",
    "lat": "12.9704",
    "lng": "-0.14953"
  },
  {
    "country": "BF",
    "name": "Bobo-Dioulasso",
    "lat": "11.17715",
    "lng": "-4.2979"
  },
  {
    "country": "BF",
    "name": "Bingo",
    "lat": "12.30092",
    "lng": "-1.8348"
  },
  {
    "country": "BF",
    "name": "Bilanga",
    "lat": "12.54652",
    "lng": "-0.02438"
  },
  {
    "country": "BF",
    "name": "Batié",
    "lat": "9.88333",
    "lng": "-2.91667"
  },
  {
    "country": "BF",
    "name": "Barani",
    "lat": "13.1691",
    "lng": "-3.8899"
  },
  {
    "country": "BF",
    "name": "Banfora",
    "lat": "10.63333",
    "lng": "-4.76667"
  },
  {
    "country": "BF",
    "name": "Absouya",
    "lat": "12.6406",
    "lng": "-1.05426"
  },
  {
    "country": "BF",
    "name": "Gaoua",
    "lat": "10.29917",
    "lng": "-3.25083"
  },
  {
    "country": "BF",
    "name": "Orodara",
    "lat": "10.94917",
    "lng": "-4.93417"
  },
  {
    "country": "BF",
    "name": "Tin-Akoff",
    "lat": "14.96549",
    "lng": "-0.16335"
  },
  {
    "country": "BF",
    "name": "Mani",
    "lat": "13.25833",
    "lng": "-0.21306"
  },
  {
    "country": "BG",
    "name": "Beloslav",
    "lat": "43.1896",
    "lng": "27.70429"
  },
  {
    "country": "BG",
    "name": "Zlatograd",
    "lat": "41.3795",
    "lng": "25.09605"
  },
  {
    "country": "BG",
    "name": "Zlatitsa",
    "lat": "42.71667",
    "lng": "24.13333"
  },
  {
    "country": "BG",
    "name": "Zlataritsa",
    "lat": "43.05",
    "lng": "25.9"
  },
  {
    "country": "BG",
    "name": "Zemen",
    "lat": "42.47889",
    "lng": "22.74917"
  },
  {
    "country": "BG",
    "name": "Zelenikovo",
    "lat": "42.4",
    "lng": "25.08333"
  },
  {
    "country": "BG",
    "name": "Zavet",
    "lat": "43.76036",
    "lng": "26.68063"
  },
  {
    "country": "BG",
    "name": "Yambol",
    "lat": "42.48333",
    "lng": "26.5"
  },
  {
    "country": "BG",
    "name": "Yakoruda",
    "lat": "42.02528",
    "lng": "23.68417"
  },
  {
    "country": "BG",
    "name": "Yakimovo",
    "lat": "43.63472",
    "lng": "23.3535"
  },
  {
    "country": "BG",
    "name": "Yablanitsa",
    "lat": "43.03139",
    "lng": "24.11278"
  },
  {
    "country": "BG",
    "name": "Varshets",
    "lat": "43.19528",
    "lng": "23.28611"
  },
  {
    "country": "BG",
    "name": "Varbitsa",
    "lat": "43",
    "lng": "26.63333"
  },
  {
    "country": "BG",
    "name": "Valchidol",
    "lat": "43.4",
    "lng": "27.55"
  },
  {
    "country": "BG",
    "name": "Valchedram",
    "lat": "43.69281",
    "lng": "23.44518"
  },
  {
    "country": "BG",
    "name": "Vratsa",
    "lat": "43.21",
    "lng": "23.5625"
  },
  {
    "country": "BG",
    "name": "Sveti Vlas",
    "lat": "42.7136",
    "lng": "27.75867"
  },
  {
    "country": "BG",
    "name": "Vidin",
    "lat": "43.99",
    "lng": "22.8725"
  },
  {
    "country": "BG",
    "name": "Vetrino",
    "lat": "43.31667",
    "lng": "27.43333"
  },
  {
    "country": "BG",
    "name": "Vetovo",
    "lat": "43.7",
    "lng": "26.26667"
  },
  {
    "country": "BG",
    "name": "Venets",
    "lat": "43.55",
    "lng": "26.93333"
  },
  {
    "country": "BG",
    "name": "Velingrad",
    "lat": "42.02754",
    "lng": "23.99155"
  },
  {
    "country": "BG",
    "name": "Veliko Tŭrnovo",
    "lat": "43.08124",
    "lng": "25.62904"
  },
  {
    "country": "BG",
    "name": "Varna",
    "lat": "43.21667",
    "lng": "27.91667"
  },
  {
    "country": "BG",
    "name": "Ugarchin",
    "lat": "43.1",
    "lng": "24.41667"
  },
  {
    "country": "BG",
    "name": "Tvarditsa",
    "lat": "42.7",
    "lng": "25.9"
  },
  {
    "country": "BG",
    "name": "Tutrakan",
    "lat": "44.05",
    "lng": "26.61667"
  },
  {
    "country": "BG",
    "name": "Targovishte",
    "lat": "43.2512",
    "lng": "26.57215"
  },
  {
    "country": "BG",
    "name": "Tsenovo",
    "lat": "43.53588",
    "lng": "25.65764"
  },
  {
    "country": "BG",
    "name": "Tryavna",
    "lat": "42.86667",
    "lng": "25.5"
  },
  {
    "country": "BG",
    "name": "Tran",
    "lat": "42.83528",
    "lng": "22.65167"
  },
  {
    "country": "BG",
    "name": "Troyan",
    "lat": "42.89427",
    "lng": "24.71589"
  },
  {
    "country": "BG",
    "name": "Topolovo",
    "lat": "41.9",
    "lng": "25"
  },
  {
    "country": "BG",
    "name": "Topolovgrad",
    "lat": "42.08333",
    "lng": "26.33333"
  },
  {
    "country": "BG",
    "name": "Dobrich",
    "lat": "43.56667",
    "lng": "27.83333"
  },
  {
    "country": "BG",
    "name": "Tochilari",
    "lat": "43.85",
    "lng": "26.46667"
  },
  {
    "country": "BG",
    "name": "Teteven",
    "lat": "42.91667",
    "lng": "24.26667"
  },
  {
    "country": "BG",
    "name": "Tervel",
    "lat": "43.74789",
    "lng": "27.40911"
  },
  {
    "country": "BG",
    "name": "Batanovtsi",
    "lat": "42.59692",
    "lng": "22.95634"
  },
  {
    "country": "BG",
    "name": "Svoge",
    "lat": "42.96667",
    "lng": "23.35"
  },
  {
    "country": "BG",
    "name": "Svishtov",
    "lat": "43.61959",
    "lng": "25.35044"
  },
  {
    "country": "BG",
    "name": "Svilengrad",
    "lat": "41.76667",
    "lng": "26.2"
  },
  {
    "country": "BG",
    "name": "Suvorovo",
    "lat": "43.33058",
    "lng": "27.59908"
  },
  {
    "country": "BG",
    "name": "Sarnitsa",
    "lat": "41.73835",
    "lng": "24.02435"
  },
  {
    "country": "BG",
    "name": "Sungurlare",
    "lat": "42.76667",
    "lng": "26.78333"
  },
  {
    "country": "BG",
    "name": "Suhindol",
    "lat": "43.19167",
    "lng": "25.18111"
  },
  {
    "country": "BG",
    "name": "Saedinenie",
    "lat": "42.26667",
    "lng": "24.55"
  },
  {
    "country": "BG",
    "name": "Strumyani",
    "lat": "41.63333",
    "lng": "23.2"
  },
  {
    "country": "BG",
    "name": "Strelcha",
    "lat": "42.5",
    "lng": "24.31667"
  },
  {
    "country": "BG",
    "name": "Strazhitsa",
    "lat": "43.23333",
    "lng": "25.96667"
  },
  {
    "country": "BG",
    "name": "Straldzha",
    "lat": "42.6",
    "lng": "26.68333"
  },
  {
    "country": "BG",
    "name": "Stara Zagora",
    "lat": "42.43278",
    "lng": "25.64194"
  },
  {
    "country": "BG",
    "name": "Stara Kresna",
    "lat": "41.8",
    "lng": "23.18333"
  },
  {
    "country": "BG",
    "name": "Dupnitsa",
    "lat": "42.26667",
    "lng": "23.11667"
  },
  {
    "country": "BG",
    "name": "Stamboliyski",
    "lat": "42.13333",
    "lng": "24.53333"
  },
  {
    "country": "BG",
    "name": "Spasovo",
    "lat": "43.70168",
    "lng": "28.30399"
  },
  {
    "country": "BG",
    "name": "Sozopol",
    "lat": "42.41801",
    "lng": "27.6956"
  },
  {
    "country": "BG",
    "name": "Sofia",
    "lat": "42.69751",
    "lng": "23.32415"
  },
  {
    "country": "BG",
    "name": "Smyadovo",
    "lat": "43.06667",
    "lng": "27.01667"
  },
  {
    "country": "BG",
    "name": "Smolyan",
    "lat": "41.57439",
    "lng": "24.71204"
  },
  {
    "country": "BG",
    "name": "Slivo Pole",
    "lat": "43.94248",
    "lng": "26.20464"
  },
  {
    "country": "BG",
    "name": "Slivnitsa",
    "lat": "42.85182",
    "lng": "23.03792"
  },
  {
    "country": "BG",
    "name": "Sliven",
    "lat": "42.68583",
    "lng": "26.32917"
  },
  {
    "country": "BG",
    "name": "Slavyanovo",
    "lat": "43.46667",
    "lng": "24.86667"
  },
  {
    "country": "BG",
    "name": "Sitovo",
    "lat": "44.0273",
    "lng": "27.01982"
  },
  {
    "country": "BG",
    "name": "Simitli",
    "lat": "41.88333",
    "lng": "23.11667"
  },
  {
    "country": "BG",
    "name": "Simeonovgrad",
    "lat": "42.03333",
    "lng": "25.83333"
  },
  {
    "country": "BG",
    "name": "Silistra",
    "lat": "44.11667",
    "lng": "27.26667"
  },
  {
    "country": "BG",
    "name": "Shumen",
    "lat": "43.27064",
    "lng": "26.92286"
  },
  {
    "country": "BG",
    "name": "Shipka",
    "lat": "42.71667",
    "lng": "25.33333"
  },
  {
    "country": "BG",
    "name": "Shabla",
    "lat": "43.53983",
    "lng": "28.53429"
  },
  {
    "country": "BG",
    "name": "Sevlievo",
    "lat": "43.02583",
    "lng": "25.11361"
  },
  {
    "country": "BG",
    "name": "Septemvri",
    "lat": "42.21138",
    "lng": "24.12946"
  },
  {
    "country": "BG",
    "name": "Senovo",
    "lat": "43.65",
    "lng": "26.36667"
  },
  {
    "country": "BG",
    "name": "Satovcha",
    "lat": "41.61667",
    "lng": "23.98333"
  },
  {
    "country": "BG",
    "name": "Sarafovo",
    "lat": "42.56079",
    "lng": "27.52195"
  },
  {
    "country": "BG",
    "name": "Sapareva Banya",
    "lat": "42.28333",
    "lng": "23.26667"
  },
  {
    "country": "BG",
    "name": "Sandanski",
    "lat": "41.56667",
    "lng": "23.28333"
  },
  {
    "country": "BG",
    "name": "Samuil",
    "lat": "43.51667",
    "lng": "26.75"
  },
  {
    "country": "BG",
    "name": "Samokov",
    "lat": "42.337",
    "lng": "23.5528"
  },
  {
    "country": "BG",
    "name": "Sadovo",
    "lat": "42.13178",
    "lng": "24.93999"
  },
  {
    "country": "BG",
    "name": "Ruzhintsi",
    "lat": "43.62179",
    "lng": "22.83286"
  },
  {
    "country": "BG",
    "name": "Ruse",
    "lat": "43.85639",
    "lng": "25.97083"
  },
  {
    "country": "BG",
    "name": "Ruen",
    "lat": "42.8",
    "lng": "27.28333"
  },
  {
    "country": "BG",
    "name": "Rudozem",
    "lat": "41.48751",
    "lng": "24.84945"
  },
  {
    "country": "BG",
    "name": "Roman",
    "lat": "43.15",
    "lng": "23.91667"
  },
  {
    "country": "BG",
    "name": "Rila",
    "lat": "42.13333",
    "lng": "23.13333"
  },
  {
    "country": "BG",
    "name": "Razlog",
    "lat": "41.8863",
    "lng": "23.46714"
  },
  {
    "country": "BG",
    "name": "Razgrad",
    "lat": "43.53333",
    "lng": "26.51667"
  },
  {
    "country": "BG",
    "name": "Ravda",
    "lat": "42.64185",
    "lng": "27.67713"
  },
  {
    "country": "BG",
    "name": "Rakovski",
    "lat": "42.27408",
    "lng": "24.94083"
  },
  {
    "country": "BG",
    "name": "Rakitovo",
    "lat": "41.99012",
    "lng": "24.0873"
  },
  {
    "country": "BG",
    "name": "Radomir",
    "lat": "42.54565",
    "lng": "22.96553"
  },
  {
    "country": "BG",
    "name": "Radnevo",
    "lat": "42.3",
    "lng": "25.93333"
  },
  {
    "country": "BG",
    "name": "Parvomaytsi",
    "lat": "43.15",
    "lng": "25.65"
  },
  {
    "country": "BG",
    "name": "Parvomay",
    "lat": "42.1",
    "lng": "25.21667"
  },
  {
    "country": "BG",
    "name": "Provadia",
    "lat": "43.18333",
    "lng": "27.43333"
  },
  {
    "country": "BG",
    "name": "Primorsko",
    "lat": "42.26791",
    "lng": "27.75611"
  },
  {
    "country": "BG",
    "name": "Veliki Preslav",
    "lat": "43.16667",
    "lng": "26.81667"
  },
  {
    "country": "BG",
    "name": "Pravets",
    "lat": "42.88333",
    "lng": "23.91667"
  },
  {
    "country": "BG",
    "name": "Pordim",
    "lat": "43.38333",
    "lng": "24.85"
  },
  {
    "country": "BG",
    "name": "Popovo",
    "lat": "43.35",
    "lng": "26.23333"
  },
  {
    "country": "BG",
    "name": "Pomorie",
    "lat": "42.56326",
    "lng": "27.62986"
  },
  {
    "country": "BG",
    "name": "Polski Trambesh",
    "lat": "43.37233",
    "lng": "25.63525"
  },
  {
    "country": "BG",
    "name": "Plovdiv",
    "lat": "42.15",
    "lng": "24.75"
  },
  {
    "country": "BG",
    "name": "Pliska",
    "lat": "43.36667",
    "lng": "27.11667"
  },
  {
    "country": "BG",
    "name": "Pleven",
    "lat": "43.41667",
    "lng": "24.61667"
  },
  {
    "country": "BG",
    "name": "Pirdop",
    "lat": "42.7",
    "lng": "24.18333"
  },
  {
    "country": "BG",
    "name": "Petrich",
    "lat": "41.39846",
    "lng": "23.20702"
  },
  {
    "country": "BG",
    "name": "Peshtera",
    "lat": "42.03372",
    "lng": "24.29995"
  },
  {
    "country": "BG",
    "name": "Perushtitsa",
    "lat": "42.05",
    "lng": "24.55"
  },
  {
    "country": "BG",
    "name": "Pernik",
    "lat": "42.6",
    "lng": "23.03333"
  },
  {
    "country": "BG",
    "name": "Iskar",
    "lat": "43.45",
    "lng": "24.26667"
  },
  {
    "country": "BG",
    "name": "Pazardzhik",
    "lat": "42.2",
    "lng": "24.33333"
  },
  {
    "country": "BG",
    "name": "Pavlikeni",
    "lat": "43.24278",
    "lng": "25.32194"
  },
  {
    "country": "BG",
    "name": "Pavel Banya",
    "lat": "42.6",
    "lng": "25.2"
  },
  {
    "country": "BG",
    "name": "Panagyurishte",
    "lat": "42.49518",
    "lng": "24.19021"
  },
  {
    "country": "BG",
    "name": "Oryahovo",
    "lat": "43.73504",
    "lng": "23.95792"
  },
  {
    "country": "BG",
    "name": "Opaka",
    "lat": "43.45",
    "lng": "26.16667"
  },
  {
    "country": "BG",
    "name": "Omurtag",
    "lat": "43.1",
    "lng": "26.41667"
  },
  {
    "country": "BG",
    "name": "Obzor",
    "lat": "42.81998",
    "lng": "27.88007"
  },
  {
    "country": "BG",
    "name": "Novo Selo",
    "lat": "44.15861",
    "lng": "22.78667"
  },
  {
    "country": "BG",
    "name": "Novi Pazar",
    "lat": "43.35",
    "lng": "27.2"
  },
  {
    "country": "BG",
    "name": "Nova Zagora",
    "lat": "42.48333",
    "lng": "26.01667"
  },
  {
    "country": "BG",
    "name": "Nikopol",
    "lat": "43.70255",
    "lng": "24.89645"
  },
  {
    "country": "BG",
    "name": "Nikolaevo",
    "lat": "42.63333",
    "lng": "25.8"
  },
  {
    "country": "BG",
    "name": "Nevestino",
    "lat": "42.25551",
    "lng": "22.85175"
  },
  {
    "country": "BG",
    "name": "Nesebar",
    "lat": "42.65921",
    "lng": "27.73602"
  },
  {
    "country": "BG",
    "name": "Nedelino",
    "lat": "41.45602",
    "lng": "25.08008"
  },
  {
    "country": "BG",
    "name": "Maglizh",
    "lat": "42.6",
    "lng": "25.55"
  },
  {
    "country": "BG",
    "name": "Mizia",
    "lat": "43.68623",
    "lng": "23.85371"
  },
  {
    "country": "BG",
    "name": "Mirkovo",
    "lat": "42.7",
    "lng": "23.98333"
  },
  {
    "country": "BG",
    "name": "Mineralni Bani",
    "lat": "41.91667",
    "lng": "25.35"
  },
  {
    "country": "BG",
    "name": "Montana",
    "lat": "43.4125",
    "lng": "23.225"
  },
  {
    "country": "BG",
    "name": "Tsarevo",
    "lat": "42.16955",
    "lng": "27.84541"
  },
  {
    "country": "BG",
    "name": "Mezdra",
    "lat": "43.15",
    "lng": "23.7"
  },
  {
    "country": "BG",
    "name": "Medovene",
    "lat": "43.76667",
    "lng": "26.51667"
  },
  {
    "country": "BG",
    "name": "Medkovets",
    "lat": "43.62403",
    "lng": "23.16876"
  },
  {
    "country": "BG",
    "name": "Malko Tarnovo",
    "lat": "41.97958",
    "lng": "27.52477"
  },
  {
    "country": "BG",
    "name": "Makresh",
    "lat": "43.76794",
    "lng": "22.66406"
  },
  {
    "country": "BG",
    "name": "Madzharovo",
    "lat": "41.63461",
    "lng": "25.86439"
  },
  {
    "country": "BG",
    "name": "Madan",
    "lat": "41.49869",
    "lng": "24.93973"
  },
  {
    "country": "BG",
    "name": "Lyubimets",
    "lat": "41.83333",
    "lng": "26.08333"
  },
  {
    "country": "BG",
    "name": "Lyaskovets",
    "lat": "43.11111",
    "lng": "25.72833"
  },
  {
    "country": "BG",
    "name": "Lukovit",
    "lat": "43.2",
    "lng": "24.16667"
  },
  {
    "country": "BG",
    "name": "Laki",
    "lat": "41.85",
    "lng": "24.81667"
  },
  {
    "country": "BG",
    "name": "Loznitsa",
    "lat": "43.36667",
    "lng": "26.6"
  },
  {
    "country": "BG",
    "name": "Lovech",
    "lat": "43.13333",
    "lng": "24.71667"
  },
  {
    "country": "BG",
    "name": "Lom",
    "lat": "43.81389",
    "lng": "23.23611"
  },
  {
    "country": "BG",
    "name": "Levski",
    "lat": "43.36667",
    "lng": "25.13333"
  },
  {
    "country": "BG",
    "name": "Letnitsa",
    "lat": "43.31167",
    "lng": "25.07333"
  },
  {
    "country": "BG",
    "name": "Lesichovo",
    "lat": "42.35626",
    "lng": "24.1119"
  },
  {
    "country": "BG",
    "name": "Lakatnik",
    "lat": "43.05",
    "lng": "23.4"
  },
  {
    "country": "BG",
    "name": "Kyustendil",
    "lat": "42.28389",
    "lng": "22.69111"
  },
  {
    "country": "BG",
    "name": "Kardzhali",
    "lat": "41.65",
    "lng": "25.36667"
  },
  {
    "country": "BG",
    "name": "Kula",
    "lat": "43.88833",
    "lng": "22.52139"
  },
  {
    "country": "BG",
    "name": "Kubrat",
    "lat": "43.79658",
    "lng": "26.50063"
  },
  {
    "country": "BG",
    "name": "Krushari",
    "lat": "43.81675",
    "lng": "27.75552"
  },
  {
    "country": "BG",
    "name": "Krumovgrad",
    "lat": "41.47127",
    "lng": "25.65485"
  },
  {
    "country": "BG",
    "name": "Krivodol",
    "lat": "43.37444",
    "lng": "23.48444"
  },
  {
    "country": "BG",
    "name": "Krichim",
    "lat": "42.05",
    "lng": "24.46667"
  },
  {
    "country": "BG",
    "name": "Kresna",
    "lat": "41.73333",
    "lng": "23.15"
  },
  {
    "country": "BG",
    "name": "Kozloduy",
    "lat": "43.77864",
    "lng": "23.72058"
  },
  {
    "country": "BG",
    "name": "Koynare",
    "lat": "43.35",
    "lng": "24.13333"
  },
  {
    "country": "BG",
    "name": "Kotel",
    "lat": "42.88333",
    "lng": "26.45"
  },
  {
    "country": "BG",
    "name": "Kostinbrod",
    "lat": "42.81667",
    "lng": "23.21667"
  },
  {
    "country": "BG",
    "name": "Koprivshtitsa",
    "lat": "42.63333",
    "lng": "24.35"
  },
  {
    "country": "BG",
    "name": "Kocherinovo",
    "lat": "42.08439",
    "lng": "23.0571"
  },
  {
    "country": "BG",
    "name": "Knezha",
    "lat": "43.5",
    "lng": "24.08333"
  },
  {
    "country": "BG",
    "name": "Klisura",
    "lat": "42.7",
    "lng": "24.45"
  },
  {
    "country": "BG",
    "name": "Kiten",
    "lat": "43.08333",
    "lng": "27.31667"
  },
  {
    "country": "BG",
    "name": "Kiten",
    "lat": "42.23424",
    "lng": "27.7749"
  },
  {
    "country": "BG",
    "name": "Kirkovo",
    "lat": "41.32715",
    "lng": "25.36379"
  },
  {
    "country": "BG",
    "name": "Kilifarevo",
    "lat": "42.98333",
    "lng": "25.63333"
  },
  {
    "country": "BG",
    "name": "Tsar Kaloyan",
    "lat": "43.61667",
    "lng": "26.25"
  },
  {
    "country": "BG",
    "name": "Hisarya",
    "lat": "42.5",
    "lng": "24.7"
  },
  {
    "country": "BG",
    "name": "Hayredin",
    "lat": "43.60193",
    "lng": "23.66135"
  },
  {
    "country": "BG",
    "name": "Haskovo",
    "lat": "41.93415",
    "lng": "25.55557"
  },
  {
    "country": "BG",
    "name": "Harmanli",
    "lat": "41.93333",
    "lng": "25.9"
  },
  {
    "country": "BG",
    "name": "Hadzhidimovo",
    "lat": "41.52222",
    "lng": "23.86861"
  },
  {
    "country": "BG",
    "name": "Kermen",
    "lat": "42.5",
    "lng": "26.25"
  },
  {
    "country": "BG",
    "name": "Kazanlak",
    "lat": "42.61667",
    "lng": "25.4"
  },
  {
    "country": "BG",
    "name": "Kaynardzha",
    "lat": "43.99278",
    "lng": "27.50713"
  },
  {
    "country": "BG",
    "name": "Kavarna",
    "lat": "43.43601",
    "lng": "28.33953"
  },
  {
    "country": "BG",
    "name": "Kaspichan",
    "lat": "43.31667",
    "lng": "27.16667"
  },
  {
    "country": "BG",
    "name": "Karnobat",
    "lat": "42.65",
    "lng": "26.98333"
  },
  {
    "country": "BG",
    "name": "Karlovo",
    "lat": "42.63333",
    "lng": "24.8"
  },
  {
    "country": "BG",
    "name": "Kaolinovo",
    "lat": "43.61667",
    "lng": "27.11667"
  },
  {
    "country": "BG",
    "name": "Kameno",
    "lat": "42.57084",
    "lng": "27.29875"
  },
  {
    "country": "BG",
    "name": "Kaloyanovo",
    "lat": "42.35",
    "lng": "24.73333"
  },
  {
    "country": "BG",
    "name": "Kalofer",
    "lat": "42.61667",
    "lng": "24.98333"
  },
  {
    "country": "BG",
    "name": "Ivaylovgrad",
    "lat": "41.52672",
    "lng": "26.1249"
  },
  {
    "country": "BG",
    "name": "Ivanovo",
    "lat": "43.68568",
    "lng": "25.95565"
  },
  {
    "country": "BG",
    "name": "Isperih",
    "lat": "43.71667",
    "lng": "26.83333"
  },
  {
    "country": "BG",
    "name": "Iskar",
    "lat": "43.6708",
    "lng": "24.45233"
  },
  {
    "country": "BG",
    "name": "Ihtiman",
    "lat": "42.43333",
    "lng": "23.81667"
  },
  {
    "country": "BG",
    "name": "Garmen",
    "lat": "41.6",
    "lng": "23.81667"
  },
  {
    "country": "BG",
    "name": "Gurkovo",
    "lat": "42.66667",
    "lng": "25.8"
  },
  {
    "country": "BG",
    "name": "Gulyantsi",
    "lat": "43.64109",
    "lng": "24.69368"
  },
  {
    "country": "BG",
    "name": "Gŭlŭbovo",
    "lat": "42.13333",
    "lng": "25.85"
  },
  {
    "country": "BG",
    "name": "Sredets",
    "lat": "42.34747",
    "lng": "27.17898"
  },
  {
    "country": "BG",
    "name": "Gramada",
    "lat": "43.83738",
    "lng": "22.65279"
  },
  {
    "country": "BG",
    "name": "Gyovren",
    "lat": "41.66326",
    "lng": "24.37557"
  },
  {
    "country": "BG",
    "name": "Gotse Delchev",
    "lat": "41.56667",
    "lng": "23.73333"
  },
  {
    "country": "BG",
    "name": "Gorna Oryahovitsa",
    "lat": "43.12778",
    "lng": "25.70167"
  },
  {
    "country": "BG",
    "name": "Gorna Malina",
    "lat": "42.68333",
    "lng": "23.7"
  },
  {
    "country": "BG",
    "name": "Gorichevo",
    "lat": "43.85",
    "lng": "26.45"
  },
  {
    "country": "BG",
    "name": "Godech",
    "lat": "43.01682",
    "lng": "23.04852"
  },
  {
    "country": "BG",
    "name": "Glavinitsa",
    "lat": "43.91667",
    "lng": "26.83333"
  },
  {
    "country": "BG",
    "name": "Dolni Chiflik",
    "lat": "42.99296",
    "lng": "27.71596"
  },
  {
    "country": "BG",
    "name": "General Toshevo",
    "lat": "43.70123",
    "lng": "28.03787"
  },
  {
    "country": "BG",
    "name": "Gara Hitrino",
    "lat": "43.43333",
    "lng": "26.91667"
  },
  {
    "country": "BG",
    "name": "Gabrovo",
    "lat": "42.87472",
    "lng": "25.33417"
  },
  {
    "country": "BG",
    "name": "Gabrovo",
    "lat": "41.8",
    "lng": "25.26667"
  },
  {
    "country": "BG",
    "name": "Etropole",
    "lat": "42.83333",
    "lng": "24"
  },
  {
    "country": "BG",
    "name": "Elkhovo",
    "lat": "42.38333",
    "lng": "25.43333"
  },
  {
    "country": "BG",
    "name": "Elhovo",
    "lat": "42.16667",
    "lng": "26.56667"
  },
  {
    "country": "BG",
    "name": "Elin Pelin",
    "lat": "42.66667",
    "lng": "23.6"
  },
  {
    "country": "BG",
    "name": "Elena",
    "lat": "42.93333",
    "lng": "25.88333"
  },
  {
    "country": "BG",
    "name": "Dzhebel",
    "lat": "41.49566",
    "lng": "25.30363"
  },
  {
    "country": "BG",
    "name": "Dve Mogili",
    "lat": "43.59258",
    "lng": "25.87486"
  },
  {
    "country": "BG",
    "name": "Dunavtsi",
    "lat": "43.92111",
    "lng": "22.82111"
  },
  {
    "country": "BG",
    "name": "Dulovo",
    "lat": "43.81667",
    "lng": "27.15"
  },
  {
    "country": "BG",
    "name": "Dalgopol",
    "lat": "43.05",
    "lng": "27.35"
  },
  {
    "country": "BG",
    "name": "Dryanovo",
    "lat": "42.97897",
    "lng": "25.4785"
  },
  {
    "country": "BG",
    "name": "Drenovets",
    "lat": "43.69134",
    "lng": "22.97365"
  },
  {
    "country": "BG",
    "name": "Dragoman",
    "lat": "42.92191",
    "lng": "22.93109"
  },
  {
    "country": "BG",
    "name": "Dospat",
    "lat": "41.64462",
    "lng": "24.15857"
  },
  {
    "country": "BG",
    "name": "Dolni Dabnik",
    "lat": "43.4",
    "lng": "24.43333"
  },
  {
    "country": "BG",
    "name": "Dolna Mitropolia",
    "lat": "43.46667",
    "lng": "24.53333"
  },
  {
    "country": "BG",
    "name": "Dolna Banya",
    "lat": "42.3",
    "lng": "23.76667"
  },
  {
    "country": "BG",
    "name": "Dimovo",
    "lat": "43.74167",
    "lng": "22.72694"
  },
  {
    "country": "BG",
    "name": "Dimitrovgrad",
    "lat": "42.05",
    "lng": "25.6"
  },
  {
    "country": "BG",
    "name": "Devnya",
    "lat": "43.22222",
    "lng": "27.56944"
  },
  {
    "country": "BG",
    "name": "Devin",
    "lat": "41.74327",
    "lng": "24.40003"
  },
  {
    "country": "BG",
    "name": "Debelets",
    "lat": "43.03333",
    "lng": "25.61667"
  },
  {
    "country": "BG",
    "name": "Chuprene",
    "lat": "43.51806",
    "lng": "22.66611"
  },
  {
    "country": "BG",
    "name": "Chirpan",
    "lat": "42.2",
    "lng": "25.33333"
  },
  {
    "country": "BG",
    "name": "Chiprovtsi",
    "lat": "43.38417",
    "lng": "22.88083"
  },
  {
    "country": "BG",
    "name": "Cherven Bryag",
    "lat": "43.26667",
    "lng": "24.1"
  },
  {
    "country": "BG",
    "name": "Chernomorets",
    "lat": "42.44408",
    "lng": "27.63902"
  },
  {
    "country": "BG",
    "name": "Chepelare",
    "lat": "41.73333",
    "lng": "24.68333"
  },
  {
    "country": "BG",
    "name": "Chelopech",
    "lat": "42.7",
    "lng": "24.08333"
  },
  {
    "country": "BG",
    "name": "Chavdar",
    "lat": "42.65",
    "lng": "24.05"
  },
  {
    "country": "BG",
    "name": "Byala Slatina",
    "lat": "43.46667",
    "lng": "23.93333"
  },
  {
    "country": "BG",
    "name": "Byala Cherkva",
    "lat": "43.2",
    "lng": "25.3"
  },
  {
    "country": "BG",
    "name": "Byala",
    "lat": "42.87426",
    "lng": "27.88865"
  },
  {
    "country": "BG",
    "name": "Burgas",
    "lat": "42.50606",
    "lng": "27.46781"
  },
  {
    "country": "BG",
    "name": "Buhovo",
    "lat": "42.76667",
    "lng": "23.56667"
  },
  {
    "country": "BG",
    "name": "Brusartsi",
    "lat": "43.66075",
    "lng": "23.06732"
  },
  {
    "country": "BG",
    "name": "Brezovo",
    "lat": "42.35",
    "lng": "25.08333"
  },
  {
    "country": "BG",
    "name": "Breznik",
    "lat": "42.74085",
    "lng": "22.90723"
  },
  {
    "country": "BG",
    "name": "Bregovo",
    "lat": "44.15167",
    "lng": "22.6425"
  },
  {
    "country": "BG",
    "name": "Bratsigovo",
    "lat": "42.01667",
    "lng": "24.36667"
  },
  {
    "country": "BG",
    "name": "Bozhurishte",
    "lat": "42.75",
    "lng": "23.2"
  },
  {
    "country": "BG",
    "name": "Boynitsa",
    "lat": "43.9565",
    "lng": "22.53255"
  },
  {
    "country": "BG",
    "name": "Boychinovtsi",
    "lat": "43.47222",
    "lng": "23.33583"
  },
  {
    "country": "BG",
    "name": "Bov",
    "lat": "43.0325",
    "lng": "23.37806"
  },
  {
    "country": "BG",
    "name": "Botevgrad",
    "lat": "42.9",
    "lng": "23.78333"
  },
  {
    "country": "BG",
    "name": "Borovo",
    "lat": "43.50086",
    "lng": "25.80992"
  },
  {
    "country": "BG",
    "name": "Borovan",
    "lat": "43.43333",
    "lng": "23.75"
  },
  {
    "country": "BG",
    "name": "Borino",
    "lat": "41.68408",
    "lng": "24.293"
  },
  {
    "country": "BG",
    "name": "Bolyarovo",
    "lat": "42.14962",
    "lng": "26.81116"
  },
  {
    "country": "BG",
    "name": "Bobov Dol",
    "lat": "42.36256",
    "lng": "23.00324"
  },
  {
    "country": "BG",
    "name": "Boboshevo",
    "lat": "42.15296",
    "lng": "23.00146"
  },
  {
    "country": "BG",
    "name": "Blagoevgrad",
    "lat": "42.01667",
    "lng": "23.1"
  },
  {
    "country": "BG",
    "name": "Berkovitsa",
    "lat": "43.23611",
    "lng": "23.12583"
  },
  {
    "country": "BG",
    "name": "Belovo",
    "lat": "42.21239",
    "lng": "24.02081"
  },
  {
    "country": "BG",
    "name": "Belogradchik",
    "lat": "43.62722",
    "lng": "22.68361"
  },
  {
    "country": "BG",
    "name": "Belitsa",
    "lat": "41.95694",
    "lng": "23.5725"
  },
  {
    "country": "BG",
    "name": "Belene",
    "lat": "43.64594",
    "lng": "25.12627"
  },
  {
    "country": "BG",
    "name": "Batak",
    "lat": "41.94225",
    "lng": "24.21843"
  },
  {
    "country": "BG",
    "name": "Bata",
    "lat": "42.73802",
    "lng": "27.49643"
  },
  {
    "country": "BG",
    "name": "Bansko",
    "lat": "41.8383",
    "lng": "23.48851"
  },
  {
    "country": "BG",
    "name": "Banite",
    "lat": "41.61667",
    "lng": "25.01667"
  },
  {
    "country": "BG",
    "name": "Balchik",
    "lat": "43.42166",
    "lng": "28.15848"
  },
  {
    "country": "BG",
    "name": "Aytos",
    "lat": "42.7",
    "lng": "27.25"
  },
  {
    "country": "BG",
    "name": "Asenovgrad",
    "lat": "42.01667",
    "lng": "24.86667"
  },
  {
    "country": "BG",
    "name": "Asen",
    "lat": "42.65",
    "lng": "25.2"
  },
  {
    "country": "BG",
    "name": "Ardino",
    "lat": "41.58333",
    "lng": "25.13333"
  },
  {
    "country": "BG",
    "name": "Apriltsi",
    "lat": "42.84142",
    "lng": "24.91759"
  },
  {
    "country": "BG",
    "name": "Antonovo",
    "lat": "43.15",
    "lng": "26.16667"
  },
  {
    "country": "BG",
    "name": "Anton",
    "lat": "42.75",
    "lng": "24.28333"
  },
  {
    "country": "BG",
    "name": "Alfatar",
    "lat": "43.94525",
    "lng": "27.28751"
  },
  {
    "country": "BG",
    "name": "Aksakovo",
    "lat": "43.25615",
    "lng": "27.82105"
  },
  {
    "country": "BG",
    "name": "Ahtopol",
    "lat": "42.09768",
    "lng": "27.93961"
  },
  {
    "country": "BG",
    "name": "Zlatni Pyasatsi",
    "lat": "43.285",
    "lng": "28.0418"
  },
  {
    "country": "BG",
    "name": "Aheloy",
    "lat": "42.64987",
    "lng": "27.64838"
  },
  {
    "country": "BG",
    "name": "Balgarevo",
    "lat": "43.40296",
    "lng": "28.41189"
  },
  {
    "country": "BH",
    "name": "Sitrah",
    "lat": "26.15472",
    "lng": "50.62056"
  },
  {
    "country": "BH",
    "name": "Madīnat ‘Īsá",
    "lat": "26.17361",
    "lng": "50.54778"
  },
  {
    "country": "BH",
    "name": "Jidd Ḩafş",
    "lat": "26.21861",
    "lng": "50.54778"
  },
  {
    "country": "BH",
    "name": "Madīnat Ḩamad",
    "lat": "26.11528",
    "lng": "50.50694"
  },
  {
    "country": "BH",
    "name": "Dār Kulayb",
    "lat": "26.06861",
    "lng": "50.50389"
  },
  {
    "country": "BH",
    "name": "Al Muharraq",
    "lat": "26.25722",
    "lng": "50.61194"
  },
  {
    "country": "BH",
    "name": "Manama",
    "lat": "26.22787",
    "lng": "50.58565"
  },
  {
    "country": "BH",
    "name": "Al Ḩadd",
    "lat": "26.24556",
    "lng": "50.65417"
  },
  {
    "country": "BH",
    "name": "Ar Rifā‘",
    "lat": "26.13",
    "lng": "50.555"
  },
  {
    "country": "BI",
    "name": "Makamba",
    "lat": "-4.1348",
    "lng": "29.804"
  },
  {
    "country": "BI",
    "name": "Bururi",
    "lat": "-3.94877",
    "lng": "29.62438"
  },
  {
    "country": "BI",
    "name": "Rumonge",
    "lat": "-3.9736",
    "lng": "29.4386"
  },
  {
    "country": "BI",
    "name": "Mwaro",
    "lat": "-3.51128",
    "lng": "29.70334"
  },
  {
    "country": "BI",
    "name": "Muzinda",
    "lat": "-3.2617",
    "lng": "29.4206"
  },
  {
    "country": "BI",
    "name": "Isale",
    "lat": "-3.3489",
    "lng": "29.4839"
  },
  {
    "country": "BI",
    "name": "Bujumbura",
    "lat": "-3.3822",
    "lng": "29.3644"
  },
  {
    "country": "BI",
    "name": "Muramvya",
    "lat": "-3.2682",
    "lng": "29.6079"
  },
  {
    "country": "BI",
    "name": "Gitega",
    "lat": "-3.4264",
    "lng": "29.9308"
  },
  {
    "country": "BI",
    "name": "Ruyigi",
    "lat": "-3.47639",
    "lng": "30.24861"
  },
  {
    "country": "BI",
    "name": "Cankuzo",
    "lat": "-3.2186",
    "lng": "30.5528"
  },
  {
    "country": "BI",
    "name": "Karuzi",
    "lat": "-3.10139",
    "lng": "30.16278"
  },
  {
    "country": "BI",
    "name": "Bubanza",
    "lat": "-3.0804",
    "lng": "29.391"
  },
  {
    "country": "BI",
    "name": "Cibitoke",
    "lat": "-2.8869",
    "lng": "29.1248"
  },
  {
    "country": "BI",
    "name": "Buganda",
    "lat": "-2.9663",
    "lng": "29.1944"
  },
  {
    "country": "BI",
    "name": "Ngozi",
    "lat": "-2.9075",
    "lng": "29.8306"
  },
  {
    "country": "BI",
    "name": "Kayanza",
    "lat": "-2.9221",
    "lng": "29.6293"
  },
  {
    "country": "BI",
    "name": "Muyinga",
    "lat": "-2.8451",
    "lng": "30.3414"
  },
  {
    "country": "BI",
    "name": "Kirundo",
    "lat": "-2.5845",
    "lng": "30.0959"
  },
  {
    "country": "BI",
    "name": "Rutana",
    "lat": "-3.9279",
    "lng": "29.992"
  },
  {
    "country": "BJ",
    "name": "Zagnanado",
    "lat": "7.22097",
    "lng": "2.38335"
  },
  {
    "country": "BJ",
    "name": "Tchaourou",
    "lat": "8.88649",
    "lng": "2.59753"
  },
  {
    "country": "BJ",
    "name": "Tanguiéta",
    "lat": "10.62118",
    "lng": "1.26651"
  },
  {
    "country": "BJ",
    "name": "So-Ava",
    "lat": "6.49245",
    "lng": "2.40193"
  },
  {
    "country": "BJ",
    "name": "Semi",
    "lat": "6.36667",
    "lng": "2.61667"
  },
  {
    "country": "BJ",
    "name": "Sé",
    "lat": "6.7539",
    "lng": "2.10365"
  },
  {
    "country": "BJ",
    "name": "Savé",
    "lat": "8.03424",
    "lng": "2.4866"
  },
  {
    "country": "BJ",
    "name": "Savalou",
    "lat": "7.92807",
    "lng": "1.97558"
  },
  {
    "country": "BJ",
    "name": "Sakété",
    "lat": "6.73618",
    "lng": "2.65866"
  },
  {
    "country": "BJ",
    "name": "Porto-Novo",
    "lat": "6.49646",
    "lng": "2.60359"
  },
  {
    "country": "BJ",
    "name": "Pobé",
    "lat": "6.98008",
    "lng": "2.6649"
  },
  {
    "country": "BJ",
    "name": "Parakou",
    "lat": "9.33716",
    "lng": "2.63031"
  },
  {
    "country": "BJ",
    "name": "Pahou",
    "lat": "6.38774",
    "lng": "2.21423"
  },
  {
    "country": "BJ",
    "name": "Ouinhi",
    "lat": "7.08411",
    "lng": "2.48343"
  },
  {
    "country": "BJ",
    "name": "Ouidah",
    "lat": "6.36307",
    "lng": "2.08506"
  },
  {
    "country": "BJ",
    "name": "Nikki",
    "lat": "9.94009",
    "lng": "3.21075"
  },
  {
    "country": "BJ",
    "name": "Natitingou",
    "lat": "10.30416",
    "lng": "1.37962"
  },
  {
    "country": "BJ",
    "name": "Malanville",
    "lat": "11.86819",
    "lng": "3.38327"
  },
  {
    "country": "BJ",
    "name": "Lokossa",
    "lat": "6.63869",
    "lng": "1.71674"
  },
  {
    "country": "BJ",
    "name": "Kétou",
    "lat": "7.36332",
    "lng": "2.59978"
  },
  {
    "country": "BJ",
    "name": "Kandi",
    "lat": "11.13417",
    "lng": "2.93861"
  },
  {
    "country": "BJ",
    "name": "Hinvi",
    "lat": "6.76667",
    "lng": "2.16667"
  },
  {
    "country": "BJ",
    "name": "Hévié",
    "lat": "6.41667",
    "lng": "2.25"
  },
  {
    "country": "BJ",
    "name": "Guilmaro",
    "lat": "10.56583",
    "lng": "1.72444"
  },
  {
    "country": "BJ",
    "name": "Grand-Popo",
    "lat": "6.28036",
    "lng": "1.82251"
  },
  {
    "country": "BJ",
    "name": "Goumori",
    "lat": "11.18131",
    "lng": "2.29295"
  },
  {
    "country": "BJ",
    "name": "Dogbo",
    "lat": "6.79911",
    "lng": "1.78073"
  },
  {
    "country": "BJ",
    "name": "Djougou",
    "lat": "9.70853",
    "lng": "1.66598"
  },
  {
    "country": "BJ",
    "name": "Dassa-Zoumé",
    "lat": "7.75",
    "lng": "2.18333"
  },
  {
    "country": "BJ",
    "name": "Cové",
    "lat": "7.22097",
    "lng": "2.34017"
  },
  {
    "country": "BJ",
    "name": "Cotonou",
    "lat": "6.36536",
    "lng": "2.41833"
  },
  {
    "country": "BJ",
    "name": "Comé",
    "lat": "6.40764",
    "lng": "1.88198"
  },
  {
    "country": "BJ",
    "name": "Bohicon",
    "lat": "7.17826",
    "lng": "2.0667"
  },
  {
    "country": "BJ",
    "name": "Bétérou",
    "lat": "9.19916",
    "lng": "2.25855"
  },
  {
    "country": "BJ",
    "name": "Bembèrèkè",
    "lat": "10.22827",
    "lng": "2.66335"
  },
  {
    "country": "BJ",
    "name": "Bassila",
    "lat": "9.00814",
    "lng": "1.6654"
  },
  {
    "country": "BJ",
    "name": "Banikoara",
    "lat": "11.29845",
    "lng": "2.43856"
  },
  {
    "country": "BJ",
    "name": "Avakpa",
    "lat": "6.66239",
    "lng": "2.04249"
  },
  {
    "country": "BJ",
    "name": "Aplahoué",
    "lat": "6.93333",
    "lng": "1.68333"
  },
  {
    "country": "BJ",
    "name": "Allada",
    "lat": "6.66547",
    "lng": "2.15138"
  },
  {
    "country": "BJ",
    "name": "Adjohon",
    "lat": "6.71853",
    "lng": "2.47759"
  },
  {
    "country": "BJ",
    "name": "Abomey-Calavi",
    "lat": "6.44852",
    "lng": "2.35566"
  },
  {
    "country": "BJ",
    "name": "Abomey",
    "lat": "7.18286",
    "lng": "1.99119"
  },
  {
    "country": "BJ",
    "name": "Houinvigue",
    "lat": "6.8862",
    "lng": "2.4806"
  },
  {
    "country": "BJ",
    "name": "Kpomassè",
    "lat": "6.46216",
    "lng": "1.99362"
  },
  {
    "country": "BL",
    "name": "Gustavia",
    "lat": "17.89618",
    "lng": "-62.84978"
  },
  {
    "country": "BM",
    "name": "Saint George",
    "lat": "32.38167",
    "lng": "-64.67806"
  },
  {
    "country": "BM",
    "name": "Hamilton",
    "lat": "32.2949",
    "lng": "-64.78303"
  },
  {
    "country": "BN",
    "name": "Tutong",
    "lat": "4.8",
    "lng": "114.65"
  },
  {
    "country": "BN",
    "name": "Seria",
    "lat": "4.60637",
    "lng": "114.32476"
  },
  {
    "country": "BN",
    "name": "Kuala Belait",
    "lat": "4.58361",
    "lng": "114.2312"
  },
  {
    "country": "BN",
    "name": "Mentiri",
    "lat": "4.97058",
    "lng": "115.02078"
  },
  {
    "country": "BN",
    "name": "Kapok",
    "lat": "5.02447",
    "lng": "115.04664"
  },
  {
    "country": "BN",
    "name": "Bangar",
    "lat": "4.71667",
    "lng": "115.06667"
  },
  {
    "country": "BN",
    "name": "Bandar Seri Begawan",
    "lat": "4.89035",
    "lng": "114.94006"
  },
  {
    "country": "BO",
    "name": "San Pedro",
    "lat": "-18.28333",
    "lng": "-59.81667"
  },
  {
    "country": "BO",
    "name": "San Matías",
    "lat": "-16.36667",
    "lng": "-58.4"
  },
  {
    "country": "BO",
    "name": "Roboré",
    "lat": "-18.33473",
    "lng": "-59.76142"
  },
  {
    "country": "BO",
    "name": "Puerto Quijarro",
    "lat": "-17.78333",
    "lng": "-57.76667"
  },
  {
    "country": "BO",
    "name": "Nueva Manoa",
    "lat": "-9.71828",
    "lng": "-65.39544"
  },
  {
    "country": "BO",
    "name": "Yamparáez",
    "lat": "-19.18929",
    "lng": "-65.12329"
  },
  {
    "country": "BO",
    "name": "Yacuiba",
    "lat": "-22.01643",
    "lng": "-63.67753"
  },
  {
    "country": "BO",
    "name": "Warnes",
    "lat": "-17.5163",
    "lng": "-63.16778"
  },
  {
    "country": "BO",
    "name": "Viloco",
    "lat": "-16.95",
    "lng": "-67.55"
  },
  {
    "country": "BO",
    "name": "Villazón",
    "lat": "-22.08659",
    "lng": "-65.59422"
  },
  {
    "country": "BO",
    "name": "Villa Yapacaní",
    "lat": "-17.4",
    "lng": "-63.83333"
  },
  {
    "country": "BO",
    "name": "Villa Serrano",
    "lat": "-19.12489",
    "lng": "-64.32343"
  },
  {
    "country": "BO",
    "name": "Villamontes",
    "lat": "-21.26235",
    "lng": "-63.46903"
  },
  {
    "country": "BO",
    "name": "Villa Charcas",
    "lat": "-20.72278",
    "lng": "-64.88478"
  },
  {
    "country": "BO",
    "name": "Vallegrande",
    "lat": "-18.48923",
    "lng": "-64.10609"
  },
  {
    "country": "BO",
    "name": "Uyuni",
    "lat": "-20.45967",
    "lng": "-66.82503"
  },
  {
    "country": "BO",
    "name": "Urubichá",
    "lat": "-15.39286",
    "lng": "-62.94661"
  },
  {
    "country": "BO",
    "name": "Tupiza",
    "lat": "-21.44345",
    "lng": "-65.71875"
  },
  {
    "country": "BO",
    "name": "Trinidad",
    "lat": "-14.83333",
    "lng": "-64.9"
  },
  {
    "country": "BO",
    "name": "Totoral",
    "lat": "-18.49587",
    "lng": "-66.8738"
  },
  {
    "country": "BO",
    "name": "Totora",
    "lat": "-17.72662",
    "lng": "-65.1932"
  },
  {
    "country": "BO",
    "name": "Eucaliptus",
    "lat": "-17.58333",
    "lng": "-67.51667"
  },
  {
    "country": "BO",
    "name": "Tiquipaya",
    "lat": "-17.33801",
    "lng": "-66.21579"
  },
  {
    "country": "BO",
    "name": "Tiahuanaco",
    "lat": "-16.55228",
    "lng": "-68.67953"
  },
  {
    "country": "BO",
    "name": "Tarija",
    "lat": "-21.53549",
    "lng": "-64.72956"
  },
  {
    "country": "BO",
    "name": "Tarata",
    "lat": "-17.60898",
    "lng": "-66.02135"
  },
  {
    "country": "BO",
    "name": "Tarabuco",
    "lat": "-19.18168",
    "lng": "-64.91517"
  },
  {
    "country": "BO",
    "name": "Sucre",
    "lat": "-19.03332",
    "lng": "-65.26274"
  },
  {
    "country": "BO",
    "name": "Sorata",
    "lat": "-15.77305",
    "lng": "-68.64973"
  },
  {
    "country": "BO",
    "name": "Sipe Sipe",
    "lat": "-17.45",
    "lng": "-66.38333"
  },
  {
    "country": "BO",
    "name": "Santiago del Torno",
    "lat": "-17.98674",
    "lng": "-63.38118"
  },
  {
    "country": "BO",
    "name": "Santa Rosa del Sara",
    "lat": "-17.10916",
    "lng": "-63.59514"
  },
  {
    "country": "BO",
    "name": "Santa Rosa",
    "lat": "-14.16667",
    "lng": "-66.88333"
  },
  {
    "country": "BO",
    "name": "Santa Rita",
    "lat": "-17.96667",
    "lng": "-63.35"
  },
  {
    "country": "BO",
    "name": "Santa Cruz de la Sierra",
    "lat": "-17.78629",
    "lng": "-63.18117"
  },
  {
    "country": "BO",
    "name": "Santa Bárbara",
    "lat": "-20.91667",
    "lng": "-66.05"
  },
  {
    "country": "BO",
    "name": "Santa Ana de Yacuma",
    "lat": "-13.74406",
    "lng": "-65.42688"
  },
  {
    "country": "BO",
    "name": "San Ramón",
    "lat": "-13.28333",
    "lng": "-64.71667"
  },
  {
    "country": "BO",
    "name": "San Pedro",
    "lat": "-16.23717",
    "lng": "-68.85063"
  },
  {
    "country": "BO",
    "name": "San Pablo",
    "lat": "-16.21667",
    "lng": "-68.83333"
  },
  {
    "country": "BO",
    "name": "San Julian",
    "lat": "-17.78333",
    "lng": "-62.86667"
  },
  {
    "country": "BO",
    "name": "San Juan del Surutú",
    "lat": "-17.48333",
    "lng": "-63.7"
  },
  {
    "country": "BO",
    "name": "San Ignacio de Velasco",
    "lat": "-16.36667",
    "lng": "-60.95"
  },
  {
    "country": "BO",
    "name": "San Carlos",
    "lat": "-17.4",
    "lng": "-63.75"
  },
  {
    "country": "BO",
    "name": "San Borja",
    "lat": "-14.81667",
    "lng": "-66.85"
  },
  {
    "country": "BO",
    "name": "Samaipata",
    "lat": "-18.18005",
    "lng": "-63.87552"
  },
  {
    "country": "BO",
    "name": "Sacaba",
    "lat": "-17.39799",
    "lng": "-66.03825"
  },
  {
    "country": "BO",
    "name": "Rurrenabaque",
    "lat": "-14.44125",
    "lng": "-67.52781"
  },
  {
    "country": "BO",
    "name": "Riberalta",
    "lat": "-11.00654",
    "lng": "-66.06312"
  },
  {
    "country": "BO",
    "name": "Reyes",
    "lat": "-14.2952",
    "lng": "-67.33624"
  },
  {
    "country": "BO",
    "name": "Quime",
    "lat": "-16.98333",
    "lng": "-67.21667"
  },
  {
    "country": "BO",
    "name": "Quillacollo",
    "lat": "-17.39228",
    "lng": "-66.27838"
  },
  {
    "country": "BO",
    "name": "Punata",
    "lat": "-17.54234",
    "lng": "-65.83472"
  },
  {
    "country": "BO",
    "name": "Puesto de Pailas",
    "lat": "-17.65",
    "lng": "-62.8"
  },
  {
    "country": "BO",
    "name": "Potosí",
    "lat": "-19.58361",
    "lng": "-65.75306"
  },
  {
    "country": "BO",
    "name": "Portachuelo",
    "lat": "-17.35168",
    "lng": "-63.39282"
  },
  {
    "country": "BO",
    "name": "Poopó",
    "lat": "-18.38026",
    "lng": "-66.96695"
  },
  {
    "country": "BO",
    "name": "Paurito",
    "lat": "-17.88333",
    "lng": "-62.96667"
  },
  {
    "country": "BO",
    "name": "Patacamaya",
    "lat": "-17.2358",
    "lng": "-67.92169"
  },
  {
    "country": "BO",
    "name": "Pailón",
    "lat": "-17.65",
    "lng": "-62.75"
  },
  {
    "country": "BO",
    "name": "Padilla",
    "lat": "-19.30878",
    "lng": "-64.30273"
  },
  {
    "country": "BO",
    "name": "Oruro",
    "lat": "-17.98333",
    "lng": "-67.15"
  },
  {
    "country": "BO",
    "name": "Okinawa Número Uno",
    "lat": "-17.23333",
    "lng": "-62.81667"
  },
  {
    "country": "BO",
    "name": "Montero",
    "lat": "-17.33866",
    "lng": "-63.2505"
  },
  {
    "country": "BO",
    "name": "Monteagudo",
    "lat": "-19.79989",
    "lng": "-63.95461"
  },
  {
    "country": "BO",
    "name": "Mizque",
    "lat": "-17.94101",
    "lng": "-65.34016"
  },
  {
    "country": "BO",
    "name": "Mineros",
    "lat": "-17.11876",
    "lng": "-63.231"
  },
  {
    "country": "BO",
    "name": "Mapiri",
    "lat": "-15.25",
    "lng": "-68.16667"
  },
  {
    "country": "BO",
    "name": "Mairana",
    "lat": "-18.11919",
    "lng": "-63.95965"
  },
  {
    "country": "BO",
    "name": "Machacamarca",
    "lat": "-18.17251",
    "lng": "-67.02099"
  },
  {
    "country": "BO",
    "name": "Los Negros",
    "lat": "-17.73333",
    "lng": "-63.43333"
  },
  {
    "country": "BO",
    "name": "Llallagua",
    "lat": "-18.42426",
    "lng": "-66.58388"
  },
  {
    "country": "BO",
    "name": "Limoncito",
    "lat": "-18.03104",
    "lng": "-63.40523"
  },
  {
    "country": "BO",
    "name": "La Paz",
    "lat": "-16.5",
    "lng": "-68.15"
  },
  {
    "country": "BO",
    "name": "Lahuachaca",
    "lat": "-17.37054",
    "lng": "-67.67501"
  },
  {
    "country": "BO",
    "name": "La Bélgica",
    "lat": "-17.55",
    "lng": "-63.21667"
  },
  {
    "country": "BO",
    "name": "Jorochito",
    "lat": "-18.05514",
    "lng": "-63.42821"
  },
  {
    "country": "BO",
    "name": "Yumani",
    "lat": "-16.03574",
    "lng": "-69.14843"
  },
  {
    "country": "BO",
    "name": "Irpa Irpa",
    "lat": "-17.71667",
    "lng": "-66.26667"
  },
  {
    "country": "BO",
    "name": "Independencia",
    "lat": "-17.08389",
    "lng": "-66.81804"
  },
  {
    "country": "BO",
    "name": "Huatajata",
    "lat": "-16.2",
    "lng": "-68.68333"
  },
  {
    "country": "BO",
    "name": "Huarina",
    "lat": "-16.2",
    "lng": "-68.63333"
  },
  {
    "country": "BO",
    "name": "Huanuni",
    "lat": "-18.289",
    "lng": "-66.83583"
  },
  {
    "country": "BO",
    "name": "Huachacalla",
    "lat": "-18.79298",
    "lng": "-68.26157"
  },
  {
    "country": "BO",
    "name": "Guayaramerín",
    "lat": "-10.8258",
    "lng": "-65.3581"
  },
  {
    "country": "BO",
    "name": "Guanay",
    "lat": "-15.49756",
    "lng": "-67.88332"
  },
  {
    "country": "BO",
    "name": "Entre Ríos",
    "lat": "-21.52661",
    "lng": "-64.17299"
  },
  {
    "country": "BO",
    "name": "Curahuara de Carangas",
    "lat": "-17.86667",
    "lng": "-68.43333"
  },
  {
    "country": "BO",
    "name": "Cotoca",
    "lat": "-17.81667",
    "lng": "-63.05"
  },
  {
    "country": "BO",
    "name": "Cotoca",
    "lat": "-17.74959",
    "lng": "-62.83442"
  },
  {
    "country": "BO",
    "name": "Coroico",
    "lat": "-16.19386",
    "lng": "-67.72998"
  },
  {
    "country": "BO",
    "name": "Coripata",
    "lat": "-16.3",
    "lng": "-67.6"
  },
  {
    "country": "BO",
    "name": "Concepción",
    "lat": "-16.43333",
    "lng": "-60.9"
  },
  {
    "country": "BO",
    "name": "Comarapa",
    "lat": "-17.91537",
    "lng": "-64.53163"
  },
  {
    "country": "BO",
    "name": "Colquiri",
    "lat": "-17.38918",
    "lng": "-67.12671"
  },
  {
    "country": "BO",
    "name": "Colquechaca",
    "lat": "-18.70031",
    "lng": "-66.00397"
  },
  {
    "country": "BO",
    "name": "Colomi",
    "lat": "-17.35",
    "lng": "-65.86667"
  },
  {
    "country": "BO",
    "name": "Colchani",
    "lat": "-20.3",
    "lng": "-66.93333"
  },
  {
    "country": "BO",
    "name": "Colchani",
    "lat": "-17.31667",
    "lng": "-66.71667"
  },
  {
    "country": "BO",
    "name": "Cochabamba",
    "lat": "-17.3895",
    "lng": "-66.1568"
  },
  {
    "country": "BO",
    "name": "Cobija",
    "lat": "-11.02671",
    "lng": "-68.76918"
  },
  {
    "country": "BO",
    "name": "Cliza",
    "lat": "-17.58777",
    "lng": "-65.93253"
  },
  {
    "country": "BO",
    "name": "Chulumani",
    "lat": "-16.40855",
    "lng": "-67.5294"
  },
  {
    "country": "BO",
    "name": "Chimoré",
    "lat": "-16.99417",
    "lng": "-65.1533"
  },
  {
    "country": "BO",
    "name": "Charagua",
    "lat": "-19.79151",
    "lng": "-63.19864"
  },
  {
    "country": "BO",
    "name": "Challapata",
    "lat": "-18.90208",
    "lng": "-66.77048"
  },
  {
    "country": "BO",
    "name": "Capinota",
    "lat": "-17.71113",
    "lng": "-66.26082"
  },
  {
    "country": "BO",
    "name": "Camiri",
    "lat": "-20.03849",
    "lng": "-63.51833"
  },
  {
    "country": "BO",
    "name": "Camargo",
    "lat": "-20.64064",
    "lng": "-65.20893"
  },
  {
    "country": "BO",
    "name": "Buena Vista",
    "lat": "-17.4583",
    "lng": "-63.67126"
  },
  {
    "country": "BO",
    "name": "Boyuibe",
    "lat": "-20.43227",
    "lng": "-63.28147"
  },
  {
    "country": "BO",
    "name": "Betanzos",
    "lat": "-19.55293",
    "lng": "-65.45395"
  },
  {
    "country": "BO",
    "name": "Bermejo",
    "lat": "-22.73206",
    "lng": "-64.33724"
  },
  {
    "country": "BO",
    "name": "Batallas",
    "lat": "-16.3",
    "lng": "-68.53333"
  },
  {
    "country": "BO",
    "name": "Atocha",
    "lat": "-20.93515",
    "lng": "-66.22139"
  },
  {
    "country": "BO",
    "name": "Ascensión",
    "lat": "-15.7",
    "lng": "-63.08333"
  },
  {
    "country": "BO",
    "name": "Arani",
    "lat": "-17.56854",
    "lng": "-65.76883"
  },
  {
    "country": "BO",
    "name": "Andamarca",
    "lat": "-18.77934",
    "lng": "-67.50753"
  },
  {
    "country": "BO",
    "name": "Amarete",
    "lat": "-15.23675",
    "lng": "-68.98462"
  },
  {
    "country": "BO",
    "name": "Aiquile",
    "lat": "-18.20408",
    "lng": "-65.18068"
  },
  {
    "country": "BO",
    "name": "Achacachi",
    "lat": "-16.05",
    "lng": "-68.68333"
  },
  {
    "country": "BO",
    "name": "Abapó",
    "lat": "-18.88279",
    "lng": "-63.38026"
  },
  {
    "country": "BO",
    "name": "Cruz de Machacamarca",
    "lat": "-18.88395",
    "lng": "-68.41989"
  },
  {
    "country": "BO",
    "name": "Ascención de Guarayos",
    "lat": "-15.89299",
    "lng": "-63.18855"
  },
  {
    "country": "BO",
    "name": "Santa Fe",
    "lat": "-17.90818",
    "lng": "-63.03955"
  },
  {
    "country": "BO",
    "name": "San Julian",
    "lat": "-17.80623",
    "lng": "-62.89536"
  },
  {
    "country": "BO",
    "name": "Puearto Pailas",
    "lat": "-17.663",
    "lng": "-62.81227"
  },
  {
    "country": "BO",
    "name": "San Borja",
    "lat": "-14.85195",
    "lng": "-66.74954"
  },
  {
    "country": "BQ",
    "name": "Upper Hell's Gate",
    "lat": "17.643",
    "lng": "-63.22649"
  },
  {
    "country": "BQ",
    "name": "The Bottom",
    "lat": "17.6259",
    "lng": "-63.24919"
  },
  {
    "country": "BQ",
    "name": "Oranjestad",
    "lat": "17.48303",
    "lng": "-62.9864"
  },
  {
    "country": "BQ",
    "name": "Kralendijk",
    "lat": "12.15",
    "lng": "-68.26667"
  },
  {
    "country": "BQ",
    "name": "Dorp Tera Kora",
    "lat": "12.13333",
    "lng": "-68.26667"
  },
  {
    "country": "BQ",
    "name": "Dorp Rincón",
    "lat": "12.23333",
    "lng": "-68.33333"
  },
  {
    "country": "BQ",
    "name": "Dorp Antriol",
    "lat": "12.16667",
    "lng": "-68.26667"
  },
  {
    "country": "BR",
    "name": "Vitorino Freire",
    "lat": "-4.04238",
    "lng": "-45.23777"
  },
  {
    "country": "BR",
    "name": "Vitória do Mearim",
    "lat": "-3.46222",
    "lng": "-44.87056"
  },
  {
    "country": "BR",
    "name": "Vitória de Santo Antão",
    "lat": "-8.11806",
    "lng": "-35.29139"
  },
  {
    "country": "BR",
    "name": "Viseu",
    "lat": "-1.19667",
    "lng": "-46.14"
  },
  {
    "country": "BR",
    "name": "Conde",
    "lat": "-7.25972",
    "lng": "-34.9075"
  },
  {
    "country": "BR",
    "name": "Vigia",
    "lat": "-0.85833",
    "lng": "-48.14167"
  },
  {
    "country": "BR",
    "name": "Viçosa do Ceará",
    "lat": "-3.56222",
    "lng": "-41.09222"
  },
  {
    "country": "BR",
    "name": "Viçosa",
    "lat": "-9.37139",
    "lng": "-36.24083"
  },
  {
    "country": "BR",
    "name": "Vicência",
    "lat": "-7.65694",
    "lng": "-35.32667"
  },
  {
    "country": "BR",
    "name": "Viana",
    "lat": "-3.22028",
    "lng": "-45.00361"
  },
  {
    "country": "BR",
    "name": "Várzea Alegre",
    "lat": "-5.35",
    "lng": "-40.38333"
  },
  {
    "country": "BR",
    "name": "Varjota",
    "lat": "-4.19444",
    "lng": "-40.47667"
  },
  {
    "country": "BR",
    "name": "Vargem Grande",
    "lat": "-3.54306",
    "lng": "-43.91583"
  },
  {
    "country": "BR",
    "name": "Valença do Piauí",
    "lat": "-6.4075",
    "lng": "-41.74556"
  },
  {
    "country": "BR",
    "name": "Urucurituba",
    "lat": "-3.12845",
    "lng": "-58.15856"
  },
  {
    "country": "BR",
    "name": "Uruçuí",
    "lat": "-7.22944",
    "lng": "-44.55611"
  },
  {
    "country": "BR",
    "name": "Urucará",
    "lat": "-2.53639",
    "lng": "-57.76"
  },
  {
    "country": "BR",
    "name": "Uruburetama",
    "lat": "-3.625",
    "lng": "-39.50833"
  },
  {
    "country": "BR",
    "name": "Urbano Santos",
    "lat": "-3.20778",
    "lng": "-43.40361"
  },
  {
    "country": "BR",
    "name": "Upanema",
    "lat": "-5.64194",
    "lng": "-37.25778"
  },
  {
    "country": "BR",
    "name": "União dos Palmares",
    "lat": "-9.16278",
    "lng": "-36.03194"
  },
  {
    "country": "BR",
    "name": "União",
    "lat": "-4.58583",
    "lng": "-42.86417"
  },
  {
    "country": "BR",
    "name": "Umirim",
    "lat": "-3.67722",
    "lng": "-39.35028"
  },
  {
    "country": "BR",
    "name": "Umbuzeiro",
    "lat": "-7.69556",
    "lng": "-35.66361"
  },
  {
    "country": "BR",
    "name": "Umarizal",
    "lat": "-5.99056",
    "lng": "-37.81444"
  },
  {
    "country": "BR",
    "name": "Uiraúna",
    "lat": "-6.51833",
    "lng": "-38.41222"
  },
  {
    "country": "BR",
    "name": "Ubajara",
    "lat": "-3.85444",
    "lng": "-40.92111"
  },
  {
    "country": "BR",
    "name": "Uauá",
    "lat": "-9.84139",
    "lng": "-39.48167"
  },
  {
    "country": "BR",
    "name": "Tutóia",
    "lat": "-2.76194",
    "lng": "-42.27444"
  },
  {
    "country": "BR",
    "name": "Turiaçu",
    "lat": "-1.66333",
    "lng": "-45.37167"
  },
  {
    "country": "BR",
    "name": "Tupanatinga",
    "lat": "-8.75333",
    "lng": "-37.33972"
  },
  {
    "country": "BR",
    "name": "Tuntum",
    "lat": "-5.25806",
    "lng": "-44.64889"
  },
  {
    "country": "BR",
    "name": "Tucuruí",
    "lat": "-3.76585",
    "lng": "-49.67923"
  },
  {
    "country": "BR",
    "name": "Tucumã",
    "lat": "-0.18333",
    "lng": "-50.05"
  },
  {
    "country": "BR",
    "name": "Triunfo",
    "lat": "-6.56667",
    "lng": "-38.6"
  },
  {
    "country": "BR",
    "name": "Trindade",
    "lat": "-7.76194",
    "lng": "-40.26778"
  },
  {
    "country": "BR",
    "name": "Trairi",
    "lat": "-3.27778",
    "lng": "-39.26889"
  },
  {
    "country": "BR",
    "name": "Traipu",
    "lat": "-9.97056",
    "lng": "-37.00333"
  },
  {
    "country": "BR",
    "name": "Touros",
    "lat": "-5.19889",
    "lng": "-35.46083"
  },
  {
    "country": "BR",
    "name": "Toritama",
    "lat": "-8.00667",
    "lng": "-36.05667"
  },
  {
    "country": "BR",
    "name": "Tomé Açu",
    "lat": "-2.41889",
    "lng": "-48.15222"
  },
  {
    "country": "BR",
    "name": "Timon",
    "lat": "-5.09417",
    "lng": "-42.83667"
  },
  {
    "country": "BR",
    "name": "Timbiras",
    "lat": "-4.25528",
    "lng": "-43.94056"
  },
  {
    "country": "BR",
    "name": "Timbaúba",
    "lat": "-7.50528",
    "lng": "-35.31833"
  },
  {
    "country": "BR",
    "name": "Tianguá",
    "lat": "-3.73222",
    "lng": "-40.99167"
  },
  {
    "country": "BR",
    "name": "Terra Santa",
    "lat": "-2.10417",
    "lng": "-56.48694"
  },
  {
    "country": "BR",
    "name": "Teresina",
    "lat": "-5.08917",
    "lng": "-42.80194"
  },
  {
    "country": "BR",
    "name": "Teixeira",
    "lat": "-7.22278",
    "lng": "-37.25417"
  },
  {
    "country": "BR",
    "name": "Tavares",
    "lat": "-7.63583",
    "lng": "-37.87833"
  },
  {
    "country": "BR",
    "name": "São João dos Inhamuns",
    "lat": "-6",
    "lng": "-40.28333"
  },
  {
    "country": "BR",
    "name": "Taquaritinga do Norte",
    "lat": "-7.90306",
    "lng": "-36.04417"
  },
  {
    "country": "BR",
    "name": "Taquarana",
    "lat": "-9.645",
    "lng": "-36.49722"
  },
  {
    "country": "BR",
    "name": "Taperoá",
    "lat": "-7.2075",
    "lng": "-36.82667"
  },
  {
    "country": "BR",
    "name": "Tangará",
    "lat": "-6.19944",
    "lng": "-35.80167"
  },
  {
    "country": "BR",
    "name": "Tamboril",
    "lat": "-4.83222",
    "lng": "-40.32056"
  },
  {
    "country": "BR",
    "name": "Tamandaré",
    "lat": "-8.75632",
    "lng": "-35.09995"
  },
  {
    "country": "BR",
    "name": "Taipu",
    "lat": "-5.62167",
    "lng": "-35.59667"
  },
  {
    "country": "BR",
    "name": "Tabira",
    "lat": "-7.59083",
    "lng": "-37.53944"
  },
  {
    "country": "BR",
    "name": "Surubim",
    "lat": "-7.83306",
    "lng": "-35.75472"
  },
  {
    "country": "BR",
    "name": "Sumé",
    "lat": "-7.67167",
    "lng": "-36.88"
  },
  {
    "country": "BR",
    "name": "Sousa",
    "lat": "-6.75917",
    "lng": "-38.22806"
  },
  {
    "country": "BR",
    "name": "Soure",
    "lat": "-0.71667",
    "lng": "-48.52333"
  },
  {
    "country": "BR",
    "name": "Soledade",
    "lat": "-7.05722",
    "lng": "-36.36278"
  },
  {
    "country": "BR",
    "name": "Solânea",
    "lat": "-6.755",
    "lng": "-35.54"
  },
  {
    "country": "BR",
    "name": "Sobral",
    "lat": "-3.68611",
    "lng": "-40.34972"
  },
  {
    "country": "BR",
    "name": "Sirinhaém",
    "lat": "-8.59083",
    "lng": "-35.11611"
  },
  {
    "country": "BR",
    "name": "Simplício Mendes",
    "lat": "-7.85389",
    "lng": "-41.91028"
  },
  {
    "country": "BR",
    "name": "Simões",
    "lat": "-7.59889",
    "lng": "-40.81778"
  },
  {
    "country": "BR",
    "name": "Severiano Melo",
    "lat": "-5.77722",
    "lng": "-37.95778"
  },
  {
    "country": "BR",
    "name": "Sertânia",
    "lat": "-8.07361",
    "lng": "-37.26444"
  },
  {
    "country": "BR",
    "name": "Serra Talhada",
    "lat": "-7.99194",
    "lng": "-38.29833"
  },
  {
    "country": "BR",
    "name": "Serra Branca",
    "lat": "-6.53333",
    "lng": "-38.26667"
  },
  {
    "country": "BR",
    "name": "Senador Pompeu",
    "lat": "-5.58806",
    "lng": "-39.37167"
  },
  {
    "country": "BR",
    "name": "Senador José Porfírio",
    "lat": "-2.59083",
    "lng": "-51.95417"
  },
  {
    "country": "BR",
    "name": "Satuba",
    "lat": "-9.56333",
    "lng": "-35.82444"
  },
  {
    "country": "BR",
    "name": "São Tomé",
    "lat": "-5.9725",
    "lng": "-36.07528"
  },
  {
    "country": "BR",
    "name": "São Sebastião",
    "lat": "-9.93361",
    "lng": "-36.55417"
  },
  {
    "country": "BR",
    "name": "São Raimundo Nonato",
    "lat": "-9.01528",
    "lng": "-42.69944"
  },
  {
    "country": "BR",
    "name": "São Raimundo das Mangabeiras",
    "lat": "-7.02194",
    "lng": "-45.48111"
  },
  {
    "country": "BR",
    "name": "São Pedro do Piauí",
    "lat": "-5.92944",
    "lng": "-42.71861"
  },
  {
    "country": "BR",
    "name": "São Paulo do Potengi",
    "lat": "-5.895",
    "lng": "-35.76278"
  },
  {
    "country": "BR",
    "name": "São Miguel do Tapuio",
    "lat": "-5.50361",
    "lng": "-41.32333"
  },
  {
    "country": "BR",
    "name": "São Miguel dos Campos",
    "lat": "-9.78111",
    "lng": "-36.09361"
  },
  {
    "country": "BR",
    "name": "São Miguel do Guamá",
    "lat": "-1.62667",
    "lng": "-47.48333"
  },
  {
    "country": "BR",
    "name": "São Miguel",
    "lat": "-5.46667",
    "lng": "-35.36667"
  },
  {
    "country": "BR",
    "name": "São Mateus do Maranhão",
    "lat": "-4.04167",
    "lng": "-44.475"
  },
  {
    "country": "BR",
    "name": "São Luís do Quitunde",
    "lat": "-9.31833",
    "lng": "-35.56111"
  },
  {
    "country": "BR",
    "name": "São Luís",
    "lat": "-2.52972",
    "lng": "-44.30278"
  },
  {
    "country": "BR",
    "name": "São Lourenço da Mata",
    "lat": "-8.00222",
    "lng": "-35.01833"
  },
  {
    "country": "BR",
    "name": "São José do Egito",
    "lat": "-7.47889",
    "lng": "-37.27444"
  },
  {
    "country": "BR",
    "name": "São José do Campestre",
    "lat": "-6.31556",
    "lng": "-35.71389"
  },
  {
    "country": "BR",
    "name": "São José do Belmonte",
    "lat": "-7.86139",
    "lng": "-38.75972"
  },
  {
    "country": "BR",
    "name": "São José de Ribamar",
    "lat": "-2.56194",
    "lng": "-44.05417"
  },
  {
    "country": "BR",
    "name": "São José de Piranhas",
    "lat": "-7.12056",
    "lng": "-38.50194"
  },
  {
    "country": "BR",
    "name": "São José de Mipibu",
    "lat": "-6.07472",
    "lng": "-35.23778"
  },
  {
    "country": "BR",
    "name": "São José da Tapera",
    "lat": "-9.55833",
    "lng": "-37.38111"
  },
  {
    "country": "BR",
    "name": "São José da Laje",
    "lat": "-9.00972",
    "lng": "-36.05833"
  },
  {
    "country": "BR",
    "name": "São José da Coroa Grande",
    "lat": "-8.89778",
    "lng": "-35.14778"
  },
  {
    "country": "BR",
    "name": "São Joaquim do Monte",
    "lat": "-8.4325",
    "lng": "-35.80444"
  },
  {
    "country": "BR",
    "name": "São João dos Patos",
    "lat": "-6.495",
    "lng": "-43.70222"
  },
  {
    "country": "BR",
    "name": "São João do Piauí",
    "lat": "-8.35806",
    "lng": "-42.24667"
  },
  {
    "country": "BR",
    "name": "São João de Pirabas",
    "lat": "-0.77472",
    "lng": "-47.17722"
  },
  {
    "country": "BR",
    "name": "São João Batista",
    "lat": "-2.95528",
    "lng": "-44.80694"
  },
  {
    "country": "BR",
    "name": "São João",
    "lat": "-8.87556",
    "lng": "-36.36667"
  },
  {
    "country": "BR",
    "name": "São Gonçalo do Amarante",
    "lat": "-5.79333",
    "lng": "-35.32944"
  },
  {
    "country": "BR",
    "name": "São Gonçalo do Amarante",
    "lat": "-3.60722",
    "lng": "-38.96833"
  },
  {
    "country": "BR",
    "name": "São Geraldo do Araguaia",
    "lat": "-6.40056",
    "lng": "-48.555"
  },
  {
    "country": "BR",
    "name": "São Félix do Xingu",
    "lat": "-6.64472",
    "lng": "-51.995"
  },
  {
    "country": "BR",
    "name": "São Domingos do Maranhão",
    "lat": "-5.57583",
    "lng": "-44.38528"
  },
  {
    "country": "BR",
    "name": "São Caetano de Odivelas",
    "lat": "-0.75",
    "lng": "-48.02"
  },
  {
    "country": "BR",
    "name": "São Bernardo",
    "lat": "-3.36139",
    "lng": "-42.41778"
  },
  {
    "country": "BR",
    "name": "São Bento",
    "lat": "-6.28333",
    "lng": "-37.75"
  },
  {
    "country": "BR",
    "name": "São Bento",
    "lat": "-2.69583",
    "lng": "-44.82139"
  },
  {
    "country": "BR",
    "name": "São Benedito do Rio Preto",
    "lat": "-3.33361",
    "lng": "-43.52833"
  },
  {
    "country": "BR",
    "name": "Santo Antônio do Tauá",
    "lat": "-1.15194",
    "lng": "-48.12944"
  },
  {
    "country": "BR",
    "name": "Santo Antônio",
    "lat": "-6.31056",
    "lng": "-35.47889"
  },
  {
    "country": "BR",
    "name": "Santa Rita",
    "lat": "-7.11389",
    "lng": "-34.97806"
  },
  {
    "country": "BR",
    "name": "Santa Rita",
    "lat": "-3.86358",
    "lng": "-43.85999"
  },
  {
    "country": "BR",
    "name": "Santarém",
    "lat": "-2.44306",
    "lng": "-54.70833"
  },
  {
    "country": "BR",
    "name": "Santa Quitéria do Maranhão",
    "lat": "-3.51556",
    "lng": "-42.54667"
  },
  {
    "country": "BR",
    "name": "Santa Quitéria",
    "lat": "-4.33194",
    "lng": "-40.15667"
  },
  {
    "country": "BR",
    "name": "Santana do Mundaú",
    "lat": "-9.16806",
    "lng": "-36.22222"
  },
  {
    "country": "BR",
    "name": "Santana do Matos",
    "lat": "-5.9575",
    "lng": "-36.65556"
  },
  {
    "country": "BR",
    "name": "Santana do Ipanema",
    "lat": "-9.37833",
    "lng": "-37.24528"
  },
  {
    "country": "BR",
    "name": "Santana do Acaraú",
    "lat": "-3.46056",
    "lng": "-40.21222"
  },
  {
    "country": "BR",
    "name": "Santa Maria do Pará",
    "lat": "-1.35028",
    "lng": "-47.57556"
  },
  {
    "country": "BR",
    "name": "Santa Maria da Boa Vista",
    "lat": "-8.80778",
    "lng": "-39.82556"
  },
  {
    "country": "BR",
    "name": "Santa Luzia",
    "lat": "-7.64265",
    "lng": "-47.21738"
  },
  {
    "country": "BR",
    "name": "Santa Luzia",
    "lat": "-6.87222",
    "lng": "-36.91861"
  },
  {
    "country": "BR",
    "name": "Santa Inês",
    "lat": "-3.66667",
    "lng": "-45.38"
  },
  {
    "country": "BR",
    "name": "Santa Helena",
    "lat": "-2.23111",
    "lng": "-45.3"
  },
  {
    "country": "BR",
    "name": "Santa Cruz do Capibaribe",
    "lat": "-7.9575",
    "lng": "-36.20472"
  },
  {
    "country": "BR",
    "name": "Santa Cruz",
    "lat": "-6.22944",
    "lng": "-36.02278"
  },
  {
    "country": "BR",
    "name": "Salinópolis",
    "lat": "-0.61361",
    "lng": "-47.35611"
  },
  {
    "country": "BR",
    "name": "Salgueiro",
    "lat": "-8.07417",
    "lng": "-39.11917"
  },
  {
    "country": "BR",
    "name": "Salgado de São Félix",
    "lat": "-7.35694",
    "lng": "-35.44056"
  },
  {
    "country": "BR",
    "name": "Russas",
    "lat": "-4.94028",
    "lng": "-37.97583"
  },
  {
    "country": "BR",
    "name": "Rio Tinto",
    "lat": "-6.80306",
    "lng": "-35.08056"
  },
  {
    "country": "BR",
    "name": "Rio Largo",
    "lat": "-9.47833",
    "lng": "-35.85333"
  },
  {
    "country": "BR",
    "name": "Rio Formoso",
    "lat": "-8.66877",
    "lng": "-35.16277"
  },
  {
    "country": "BR",
    "name": "Ribeirão",
    "lat": "-8.51444",
    "lng": "-35.37778"
  },
  {
    "country": "BR",
    "name": "Riachão",
    "lat": "-7.36194",
    "lng": "-46.61722"
  },
  {
    "country": "BR",
    "name": "Reriutaba",
    "lat": "-4.14167",
    "lng": "-40.58222"
  },
  {
    "country": "BR",
    "name": "Remígio",
    "lat": "-6.94646",
    "lng": "-35.78039"
  },
  {
    "country": "BR",
    "name": "Regeneração",
    "lat": "-6.23122",
    "lng": "-42.68691"
  },
  {
    "country": "BR",
    "name": "Redenção",
    "lat": "-4.22583",
    "lng": "-38.73056"
  },
  {
    "country": "BR",
    "name": "Recife",
    "lat": "-8.05389",
    "lng": "-34.88111"
  },
  {
    "country": "BR",
    "name": "Raposa",
    "lat": "-6.51667",
    "lng": "-44.18333"
  },
  {
    "country": "BR",
    "name": "Quixeré",
    "lat": "-5.07417",
    "lng": "-37.98861"
  },
  {
    "country": "BR",
    "name": "Quixeramobim",
    "lat": "-5.19917",
    "lng": "-39.29278"
  },
  {
    "country": "BR",
    "name": "Quixadá",
    "lat": "-4.97139",
    "lng": "-39.01528"
  },
  {
    "country": "BR",
    "name": "Quipapá",
    "lat": "-8.82778",
    "lng": "-36.01167"
  },
  {
    "country": "BR",
    "name": "Quebrangulo",
    "lat": "-9.31889",
    "lng": "-36.47111"
  },
  {
    "country": "BR",
    "name": "Puxinanã",
    "lat": "-7.16111",
    "lng": "-35.96056"
  },
  {
    "country": "BR",
    "name": "Princesa Isabel",
    "lat": "-7.73667",
    "lng": "-37.99333"
  },
  {
    "country": "BR",
    "name": "Presidente Dutra",
    "lat": "-5.29",
    "lng": "-44.49"
  },
  {
    "country": "BR",
    "name": "Prainha",
    "lat": "-1.8",
    "lng": "-53.48"
  },
  {
    "country": "BR",
    "name": "Santana",
    "lat": "-0.05833",
    "lng": "-51.18167"
  },
  {
    "country": "BR",
    "name": "Porto Franco",
    "lat": "-6.33833",
    "lng": "-47.39917"
  },
  {
    "country": "BR",
    "name": "Porto de Moz",
    "lat": "-1.74833",
    "lng": "-52.23833"
  },
  {
    "country": "BR",
    "name": "Porto da Folha",
    "lat": "-9.91722",
    "lng": "-37.27833"
  },
  {
    "country": "BR",
    "name": "Porto Calvo",
    "lat": "-9.045",
    "lng": "-35.39833"
  },
  {
    "country": "BR",
    "name": "Porto",
    "lat": "-3.89333",
    "lng": "-42.71"
  },
  {
    "country": "BR",
    "name": "Portel",
    "lat": "-1.93556",
    "lng": "-50.82111"
  },
  {
    "country": "BR",
    "name": "Pombos",
    "lat": "-8.14139",
    "lng": "-35.39583"
  },
  {
    "country": "BR",
    "name": "Pombal",
    "lat": "-6.77028",
    "lng": "-37.80167"
  },
  {
    "country": "BR",
    "name": "Poço das Trincheiras",
    "lat": "-9.3125",
    "lng": "-37.28556"
  },
  {
    "country": "BR",
    "name": "Poço Branco",
    "lat": "-5.62278",
    "lng": "-35.66278"
  },
  {
    "country": "BR",
    "name": "Pocinhos",
    "lat": "-7.07667",
    "lng": "-36.06111"
  },
  {
    "country": "BR",
    "name": "Poção de Pedras",
    "lat": "-4.66667",
    "lng": "-44.85"
  },
  {
    "country": "BR",
    "name": "Pitimbu",
    "lat": "-7.47056",
    "lng": "-34.80861"
  },
  {
    "country": "BR",
    "name": "Pirpirituba",
    "lat": "-6.78",
    "lng": "-35.49861"
  },
  {
    "country": "BR",
    "name": "Piripiri",
    "lat": "-4.27333",
    "lng": "-41.77694"
  },
  {
    "country": "BR",
    "name": "Pirapemas",
    "lat": "-3.72667",
    "lng": "-44.22333"
  },
  {
    "country": "BR",
    "name": "Piracuruca",
    "lat": "-3.92806",
    "lng": "-41.70917"
  },
  {
    "country": "BR",
    "name": "Pio XII",
    "lat": "-3.8325",
    "lng": "-45.1525"
  },
  {
    "country": "BR",
    "name": "Pio IX",
    "lat": "-6.8375",
    "lng": "-40.57917"
  },
  {
    "country": "BR",
    "name": "Pinheiro",
    "lat": "-2.52139",
    "lng": "-45.0825"
  },
  {
    "country": "BR",
    "name": "Pindaré Mirim",
    "lat": "-3.60833",
    "lng": "-45.34333"
  },
  {
    "country": "BR",
    "name": "Pimenteiras",
    "lat": "-6.24528",
    "lng": "-41.41917"
  },
  {
    "country": "BR",
    "name": "Pilar",
    "lat": "-9.59722",
    "lng": "-35.95667"
  },
  {
    "country": "BR",
    "name": "Pilar",
    "lat": "-7.26722",
    "lng": "-35.26"
  },
  {
    "country": "BR",
    "name": "Picuí",
    "lat": "-6.51056",
    "lng": "-36.34694"
  },
  {
    "country": "BR",
    "name": "Picos",
    "lat": "-7.07694",
    "lng": "-41.46694"
  },
  {
    "country": "BR",
    "name": "Piancó",
    "lat": "-7.19806",
    "lng": "-37.92917"
  },
  {
    "country": "BR",
    "name": "Petrolina",
    "lat": "-9.39861",
    "lng": "-40.50083"
  },
  {
    "country": "BR",
    "name": "Jatobá",
    "lat": "-9.18306",
    "lng": "-38.26889"
  },
  {
    "country": "BR",
    "name": "Pesqueira",
    "lat": "-8.35778",
    "lng": "-36.69639"
  },
  {
    "country": "BR",
    "name": "Pentecoste",
    "lat": "-3.79278",
    "lng": "-39.27028"
  },
  {
    "country": "BR",
    "name": "Pendências",
    "lat": "-5.26",
    "lng": "-36.72222"
  },
  {
    "country": "BR",
    "name": "Penalva",
    "lat": "-3.29417",
    "lng": "-45.17361"
  },
  {
    "country": "BR",
    "name": "Pedro Velho",
    "lat": "-6.43917",
    "lng": "-35.22139"
  },
  {
    "country": "BR",
    "name": "Pedro II",
    "lat": "-4.42472",
    "lng": "-41.45861"
  },
  {
    "country": "BR",
    "name": "Pedras de Fogo",
    "lat": "-7.40194",
    "lng": "-35.11639"
  },
  {
    "country": "BR",
    "name": "Pedra Branca",
    "lat": "-5.45417",
    "lng": "-39.71722"
  },
  {
    "country": "BR",
    "name": "Pedra",
    "lat": "-8.49694",
    "lng": "-36.94083"
  },
  {
    "country": "BR",
    "name": "Paulo Ramos",
    "lat": "-4.21667",
    "lng": "-45.18333"
  },
  {
    "country": "BR",
    "name": "Paulo Afonso",
    "lat": "-9.40611",
    "lng": "-38.21472"
  },
  {
    "country": "BR",
    "name": "Paulista",
    "lat": "-7.94083",
    "lng": "-34.87306"
  },
  {
    "country": "BR",
    "name": "Paulista",
    "lat": "-6.59389",
    "lng": "-37.62417"
  },
  {
    "country": "BR",
    "name": "Patu",
    "lat": "-6.11",
    "lng": "-37.63667"
  },
  {
    "country": "BR",
    "name": "Patos",
    "lat": "-7.02444",
    "lng": "-37.28"
  },
  {
    "country": "BR",
    "name": "Pastos Bons",
    "lat": "-6.60167",
    "lng": "-44.07667"
  },
  {
    "country": "BR",
    "name": "Passira",
    "lat": "-7.995",
    "lng": "-35.58056"
  },
  {
    "country": "BR",
    "name": "Passagem Franca",
    "lat": "-6.17972",
    "lng": "-43.78361"
  },
  {
    "country": "BR",
    "name": "Parnarama",
    "lat": "-5.68167",
    "lng": "-43.09333"
  },
  {
    "country": "BR",
    "name": "Parnamirim",
    "lat": "-8.09056",
    "lng": "-39.57833"
  },
  {
    "country": "BR",
    "name": "Parnamirim",
    "lat": "-5.91556",
    "lng": "-35.26278"
  },
  {
    "country": "BR",
    "name": "Parnaíba",
    "lat": "-2.90472",
    "lng": "-41.77667"
  },
  {
    "country": "BR",
    "name": "Parintins",
    "lat": "-2.62833",
    "lng": "-56.73583"
  },
  {
    "country": "BR",
    "name": "Parelhas",
    "lat": "-6.68778",
    "lng": "-36.6575"
  },
  {
    "country": "BR",
    "name": "Parambu",
    "lat": "-6.21111",
    "lng": "-40.69444"
  },
  {
    "country": "BR",
    "name": "Paraipaba",
    "lat": "-3.43944",
    "lng": "-39.14833"
  },
  {
    "country": "BR",
    "name": "Paraibano",
    "lat": "-6.43306",
    "lng": "-43.98361"
  },
  {
    "country": "BR",
    "name": "Paragominas",
    "lat": "-2.96667",
    "lng": "-47.48333"
  },
  {
    "country": "BR",
    "name": "Paracuru",
    "lat": "-3.41",
    "lng": "-39.03056"
  },
  {
    "country": "BR",
    "name": "Pão de Açúcar",
    "lat": "-9.74833",
    "lng": "-37.43667"
  },
  {
    "country": "BR",
    "name": "Palmeirais",
    "lat": "-5.97778",
    "lng": "-43.06333"
  },
  {
    "country": "BR",
    "name": "Palmares",
    "lat": "-8.68333",
    "lng": "-35.59167"
  },
  {
    "country": "BR",
    "name": "Pacatuba",
    "lat": "-3.98417",
    "lng": "-38.62028"
  },
  {
    "country": "BR",
    "name": "Pacajus",
    "lat": "-4.1725",
    "lng": "-38.46056"
  },
  {
    "country": "BR",
    "name": "Ouricuri",
    "lat": "-7.8825",
    "lng": "-40.08167"
  },
  {
    "country": "BR",
    "name": "Ourém",
    "lat": "-1.55194",
    "lng": "-47.11444"
  },
  {
    "country": "BR",
    "name": "Orós",
    "lat": "-6.24444",
    "lng": "-38.91361"
  },
  {
    "country": "BR",
    "name": "Orobó",
    "lat": "-7.745",
    "lng": "-35.60222"
  },
  {
    "country": "BR",
    "name": "Oriximiná",
    "lat": "-1.76556",
    "lng": "-55.86611"
  },
  {
    "country": "BR",
    "name": "Olivença",
    "lat": "-9.51861",
    "lng": "-37.19056"
  },
  {
    "country": "BR",
    "name": "Olinda",
    "lat": "-8.00889",
    "lng": "-34.85528"
  },
  {
    "country": "BR",
    "name": "Oeiras do Pará",
    "lat": "-2.00306",
    "lng": "-49.85444"
  },
  {
    "country": "BR",
    "name": "Oeiras",
    "lat": "-7.02528",
    "lng": "-42.13111"
  },
  {
    "country": "BR",
    "name": "Ocara",
    "lat": "-4.49083",
    "lng": "-38.59667"
  },
  {
    "country": "BR",
    "name": "Óbidos",
    "lat": "-1.9175",
    "lng": "-55.51806"
  },
  {
    "country": "BR",
    "name": "Novo Oriente",
    "lat": "-5.53444",
    "lng": "-40.77417"
  },
  {
    "country": "BR",
    "name": "Novo Lino",
    "lat": "-8.915",
    "lng": "-35.64667"
  },
  {
    "country": "BR",
    "name": "Nova Russas",
    "lat": "-4.70667",
    "lng": "-40.56306"
  },
  {
    "country": "BR",
    "name": "Nova Olinda do Norte",
    "lat": "-3.89174",
    "lng": "-59.09542"
  },
  {
    "country": "BR",
    "name": "Nova Floresta",
    "lat": "-6.45528",
    "lng": "-36.20333"
  },
  {
    "country": "BR",
    "name": "Nova Cruz",
    "lat": "-6.47806",
    "lng": "-35.43389"
  },
  {
    "country": "BR",
    "name": "Nísia Floresta",
    "lat": "-6.09111",
    "lng": "-35.20861"
  },
  {
    "country": "BR",
    "name": "Nhamundá",
    "lat": "-2.18611",
    "lng": "-56.71306"
  },
  {
    "country": "BR",
    "name": "Nazaré da Mata",
    "lat": "-7.74167",
    "lng": "-35.22778"
  },
  {
    "country": "BR",
    "name": "Natuba",
    "lat": "-7.64139",
    "lng": "-35.55"
  },
  {
    "country": "BR",
    "name": "Natal",
    "lat": "-5.795",
    "lng": "-35.20944"
  },
  {
    "country": "BR",
    "name": "Murici",
    "lat": "-9.30667",
    "lng": "-35.94333"
  },
  {
    "country": "BR",
    "name": "Mulungu",
    "lat": "-7.02444",
    "lng": "-35.46194"
  },
  {
    "country": "BR",
    "name": "Muaná",
    "lat": "-1.52833",
    "lng": "-49.21667"
  },
  {
    "country": "BR",
    "name": "Morros",
    "lat": "-9.44667",
    "lng": "-46.30028"
  },
  {
    "country": "BR",
    "name": "Moreno",
    "lat": "-8.11861",
    "lng": "-35.09222"
  },
  {
    "country": "BR",
    "name": "Morada Nova",
    "lat": "-5.10667",
    "lng": "-38.3725"
  },
  {
    "country": "BR",
    "name": "Montes Altos",
    "lat": "-5.83333",
    "lng": "-47.06667"
  },
  {
    "country": "BR",
    "name": "Monteiro",
    "lat": "-7.88944",
    "lng": "-37.12"
  },
  {
    "country": "BR",
    "name": "Monte Alegre",
    "lat": "-5.88972",
    "lng": "-36.30139"
  },
  {
    "country": "BR",
    "name": "Monte Alegre",
    "lat": "-2.00082",
    "lng": "-54.08102"
  },
  {
    "country": "BR",
    "name": "Montanhas",
    "lat": "-6.48583",
    "lng": "-35.2875"
  },
  {
    "country": "BR",
    "name": "Monsenhor Gil",
    "lat": "-5.56417",
    "lng": "-42.60778"
  },
  {
    "country": "BR",
    "name": "Monção",
    "lat": "-3.49167",
    "lng": "-45.25111"
  },
  {
    "country": "BR",
    "name": "Mombaça",
    "lat": "-5.74306",
    "lng": "-39.6275"
  },
  {
    "country": "BR",
    "name": "Moju",
    "lat": "-1.88389",
    "lng": "-48.76889"
  },
  {
    "country": "BR",
    "name": "Mogeiro",
    "lat": "-7.29944",
    "lng": "-35.47944"
  },
  {
    "country": "BR",
    "name": "Mossoró",
    "lat": "-5.1875",
    "lng": "-37.34417"
  },
  {
    "country": "BR",
    "name": "Mocajuba",
    "lat": "-2.58417",
    "lng": "-49.50722"
  },
  {
    "country": "BR",
    "name": "Missão Velha",
    "lat": "-7.24972",
    "lng": "-39.14306"
  },
  {
    "country": "BR",
    "name": "Mirador",
    "lat": "-6.37083",
    "lng": "-44.36306"
  },
  {
    "country": "BR",
    "name": "Minador do Negrão",
    "lat": "-9.30528",
    "lng": "-36.86472"
  },
  {
    "country": "BR",
    "name": "Milagres",
    "lat": "-7.31333",
    "lng": "-38.94556"
  },
  {
    "country": "BR",
    "name": "Miguel Alves",
    "lat": "-4.16556",
    "lng": "-42.89528"
  },
  {
    "country": "BR",
    "name": "Messias",
    "lat": "-9.38333",
    "lng": "-35.84167"
  },
  {
    "country": "BR",
    "name": "Mazagão",
    "lat": "-0.115",
    "lng": "-51.28944"
  },
  {
    "country": "BR",
    "name": "Maués",
    "lat": "-3.38361",
    "lng": "-57.71861"
  },
  {
    "country": "BR",
    "name": "Matriz de Camaragibe",
    "lat": "-9.15167",
    "lng": "-35.53333"
  },
  {
    "country": "BR",
    "name": "Matinha",
    "lat": "-3.10056",
    "lng": "-45.03361"
  },
  {
    "country": "BR",
    "name": "Matias Olímpio",
    "lat": "-3.71583",
    "lng": "-42.55556"
  },
  {
    "country": "BR",
    "name": "Mata Grande",
    "lat": "-9.1175",
    "lng": "-37.73222"
  },
  {
    "country": "BR",
    "name": "Massaranduba",
    "lat": "-7.20028",
    "lng": "-35.78917"
  },
  {
    "country": "BR",
    "name": "Maribondo",
    "lat": "-9.57722",
    "lng": "-36.30528"
  },
  {
    "country": "BR",
    "name": "Mari",
    "lat": "-7.06",
    "lng": "-35.31944"
  },
  {
    "country": "BR",
    "name": "Marechal Deodoro",
    "lat": "-9.71028",
    "lng": "-35.895"
  },
  {
    "country": "BR",
    "name": "Marco",
    "lat": "-3.12389",
    "lng": "-40.14667"
  },
  {
    "country": "BR",
    "name": "Marapanim",
    "lat": "-0.7175",
    "lng": "-47.69972"
  },
  {
    "country": "BR",
    "name": "Maraial",
    "lat": "-8.7825",
    "lng": "-35.80889"
  },
  {
    "country": "BR",
    "name": "Maragogi",
    "lat": "-9.01222",
    "lng": "-35.2225"
  },
  {
    "country": "BR",
    "name": "Maracanaú",
    "lat": "-3.87667",
    "lng": "-38.62556"
  },
  {
    "country": "BR",
    "name": "Maracanã",
    "lat": "-0.76614",
    "lng": "-47.45371"
  },
  {
    "country": "BR",
    "name": "Maracaçumé",
    "lat": "-2.04278",
    "lng": "-45.95917"
  },
  {
    "country": "BR",
    "name": "Marabá",
    "lat": "-5.38146",
    "lng": "-49.13232"
  },
  {
    "country": "BR",
    "name": "Manaíra",
    "lat": "-7.70611",
    "lng": "-38.15444"
  },
  {
    "country": "BR",
    "name": "Mamanguape",
    "lat": "-6.83861",
    "lng": "-35.12611"
  },
  {
    "country": "BR",
    "name": "Major Isidoro",
    "lat": "-9.53222",
    "lng": "-36.985"
  },
  {
    "country": "BR",
    "name": "Maceió",
    "lat": "-9.66583",
    "lng": "-35.73528"
  },
  {
    "country": "BR",
    "name": "Macau",
    "lat": "-5.115",
    "lng": "-36.63444"
  },
  {
    "country": "BR",
    "name": "Macaparana",
    "lat": "-7.55472",
    "lng": "-35.45306"
  },
  {
    "country": "BR",
    "name": "Macapá",
    "lat": "0.03889",
    "lng": "-51.06639"
  },
  {
    "country": "BR",
    "name": "Macaíba",
    "lat": "-5.85833",
    "lng": "-35.35389"
  },
  {
    "country": "BR",
    "name": "Luzilândia",
    "lat": "-3.45778",
    "lng": "-42.37028"
  },
  {
    "country": "BR",
    "name": "Luís Correia",
    "lat": "-2.87917",
    "lng": "-41.66694"
  },
  {
    "country": "BR",
    "name": "Limoeiro do Norte",
    "lat": "-5.14556",
    "lng": "-38.09806"
  },
  {
    "country": "BR",
    "name": "Limoeiro do Ajuru",
    "lat": "-1.89528",
    "lng": "-49.38056"
  },
  {
    "country": "BR",
    "name": "Limoeiro de Anadia",
    "lat": "-9.74056",
    "lng": "-36.50278"
  },
  {
    "country": "BR",
    "name": "Limoeiro",
    "lat": "-7.87472",
    "lng": "-35.45028"
  },
  {
    "country": "BR",
    "name": "Lavras da Mangabeira",
    "lat": "-6.75333",
    "lng": "-38.96444"
  },
  {
    "country": "BR",
    "name": "Lajedo",
    "lat": "-8.66361",
    "lng": "-36.32"
  },
  {
    "country": "BR",
    "name": "Lago da Pedra",
    "lat": "-4.28674",
    "lng": "-45.23824"
  },
  {
    "country": "BR",
    "name": "Lagoa Seca",
    "lat": "-7.17083",
    "lng": "-35.85361"
  },
  {
    "country": "BR",
    "name": "Lagoa Nova",
    "lat": "-6.1",
    "lng": "-36.48333"
  },
  {
    "country": "BR",
    "name": "Lagoa do Itaenga",
    "lat": "-7.93611",
    "lng": "-35.29028"
  },
  {
    "country": "BR",
    "name": "Lagoa da Canoa",
    "lat": "-9.82972",
    "lng": "-36.73778"
  },
  {
    "country": "BR",
    "name": "Juruti",
    "lat": "-2.15222",
    "lng": "-56.09222"
  },
  {
    "country": "BR",
    "name": "Juru",
    "lat": "-7.53694",
    "lng": "-37.81861"
  },
  {
    "country": "BR",
    "name": "Juripiranga",
    "lat": "-7.37333",
    "lng": "-35.23806"
  },
  {
    "country": "BR",
    "name": "Junqueiro",
    "lat": "-9.92528",
    "lng": "-36.47583"
  },
  {
    "country": "BR",
    "name": "Jundiá",
    "lat": "-8.93472",
    "lng": "-35.57361"
  },
  {
    "country": "BR",
    "name": "Jucurutu",
    "lat": "-6.03389",
    "lng": "-37.02028"
  },
  {
    "country": "BR",
    "name": "Jucás",
    "lat": "-6.52528",
    "lng": "-39.5275"
  },
  {
    "country": "BR",
    "name": "Juazeiro do Norte",
    "lat": "-7.21306",
    "lng": "-39.31528"
  },
  {
    "country": "BR",
    "name": "Juàzeirinho",
    "lat": "-6.81667",
    "lng": "-38.05"
  },
  {
    "country": "BR",
    "name": "José de Freitas",
    "lat": "-4.75639",
    "lng": "-42.57556"
  },
  {
    "country": "BR",
    "name": "Joaquim Nabuco",
    "lat": "-8.62444",
    "lng": "-35.53333"
  },
  {
    "country": "BR",
    "name": "João Pessoa",
    "lat": "-7.115",
    "lng": "-34.86306"
  },
  {
    "country": "BR",
    "name": "João Câmara",
    "lat": "-5.5375",
    "lng": "-35.81972"
  },
  {
    "country": "BR",
    "name": "João Alfredo",
    "lat": "-7.85583",
    "lng": "-35.58833"
  },
  {
    "country": "BR",
    "name": "Girau do Ponciano",
    "lat": "-9.88417",
    "lng": "-36.82889"
  },
  {
    "country": "BR",
    "name": "Jardim do Seridó",
    "lat": "-6.58444",
    "lng": "-36.77444"
  },
  {
    "country": "BR",
    "name": "Jardim de Piranhas",
    "lat": "-6.37861",
    "lng": "-37.35194"
  },
  {
    "country": "BR",
    "name": "Jardim",
    "lat": "-3.46444",
    "lng": "-39.05667"
  },
  {
    "country": "BR",
    "name": "Jaicós",
    "lat": "-7.35917",
    "lng": "-41.13778"
  },
  {
    "country": "BR",
    "name": "Jaguaruana",
    "lat": "-4.83389",
    "lng": "-37.78111"
  },
  {
    "country": "BR",
    "name": "Jaguaribe",
    "lat": "-5.89056",
    "lng": "-38.62194"
  },
  {
    "country": "BR",
    "name": "Jacareacanga",
    "lat": "-6.22222",
    "lng": "-57.75278"
  },
  {
    "country": "BR",
    "name": "Jacaraú",
    "lat": "-6.61222",
    "lng": "-35.29278"
  },
  {
    "country": "BR",
    "name": "Jaboatão",
    "lat": "-8.18028",
    "lng": "-35.00139"
  },
  {
    "country": "BR",
    "name": "Itupiranga",
    "lat": "-5.13472",
    "lng": "-49.32667"
  },
  {
    "country": "BR",
    "name": "Itaueira",
    "lat": "-7.60333",
    "lng": "-43.02556"
  },
  {
    "country": "BR",
    "name": "Itatuba",
    "lat": "-7.375",
    "lng": "-35.62833"
  },
  {
    "country": "BR",
    "name": "Itaquitinga",
    "lat": "-7.66778",
    "lng": "-35.10167"
  },
  {
    "country": "BR",
    "name": "Itacoatiara",
    "lat": "-3.14306",
    "lng": "-58.44417"
  },
  {
    "country": "BR",
    "name": "Itaporanga",
    "lat": "-7.30444",
    "lng": "-38.15028"
  },
  {
    "country": "BR",
    "name": "Itapissuma",
    "lat": "-7.77639",
    "lng": "-34.89222"
  },
  {
    "country": "BR",
    "name": "Itapipoca",
    "lat": "-3.49444",
    "lng": "-39.57861"
  },
  {
    "country": "BR",
    "name": "Itapecuru Mirim",
    "lat": "-3.3925",
    "lng": "-44.35861"
  },
  {
    "country": "BR",
    "name": "Itapagé",
    "lat": "-3.68667",
    "lng": "-39.58611"
  },
  {
    "country": "BR",
    "name": "Itamaracá",
    "lat": "-7.74778",
    "lng": "-34.82556"
  },
  {
    "country": "BR",
    "name": "Itaituba",
    "lat": "-4.27611",
    "lng": "-55.98361"
  },
  {
    "country": "BR",
    "name": "Itaitinga",
    "lat": "-3.96944",
    "lng": "-38.52806"
  },
  {
    "country": "BR",
    "name": "Itainópolis",
    "lat": "-7.44694",
    "lng": "-41.47833"
  },
  {
    "country": "BR",
    "name": "Itaíba",
    "lat": "-8.9475",
    "lng": "-37.42278"
  },
  {
    "country": "BR",
    "name": "Itabaiana",
    "lat": "-7.32861",
    "lng": "-35.3325"
  },
  {
    "country": "BR",
    "name": "Irituia",
    "lat": "-1.77111",
    "lng": "-47.43806"
  },
  {
    "country": "BR",
    "name": "Irauçuba",
    "lat": "-3.74611",
    "lng": "-39.78333"
  },
  {
    "country": "BR",
    "name": "Ipueiras",
    "lat": "-7.03333",
    "lng": "-40.45"
  },
  {
    "country": "BR",
    "name": "Ipubi",
    "lat": "-7.65194",
    "lng": "-40.14889"
  },
  {
    "country": "BR",
    "name": "Ipu",
    "lat": "-4.32222",
    "lng": "-40.71083"
  },
  {
    "country": "BR",
    "name": "Ipojuca",
    "lat": "-8.39889",
    "lng": "-35.06389"
  },
  {
    "country": "BR",
    "name": "Ipanguaçu",
    "lat": "-5.49833",
    "lng": "-36.855"
  },
  {
    "country": "BR",
    "name": "Inhuma",
    "lat": "-6.66833",
    "lng": "-41.70778"
  },
  {
    "country": "BR",
    "name": "Inhapi",
    "lat": "-9.22139",
    "lng": "-37.74861"
  },
  {
    "country": "BR",
    "name": "Ingá",
    "lat": "-7.28083",
    "lng": "-35.60444"
  },
  {
    "country": "BR",
    "name": "Independência",
    "lat": "-5.39639",
    "lng": "-40.30861"
  },
  {
    "country": "BR",
    "name": "Imperatriz",
    "lat": "-5.52639",
    "lng": "-47.49167"
  },
  {
    "country": "BR",
    "name": "Imaculada",
    "lat": "-7.38972",
    "lng": "-37.50917"
  },
  {
    "country": "BR",
    "name": "Iguatu",
    "lat": "-6.35944",
    "lng": "-39.29861"
  },
  {
    "country": "BR",
    "name": "Igarapé Miri",
    "lat": "-1.975",
    "lng": "-48.95972"
  },
  {
    "country": "BR",
    "name": "Igarapé Açu",
    "lat": "-1.12889",
    "lng": "-47.62"
  },
  {
    "country": "BR",
    "name": "Igarassu",
    "lat": "-7.83417",
    "lng": "-34.90639"
  },
  {
    "country": "BR",
    "name": "Igaci",
    "lat": "-9.53694",
    "lng": "-36.63361"
  },
  {
    "country": "BR",
    "name": "Icó",
    "lat": "-6.40111",
    "lng": "-38.86222"
  },
  {
    "country": "BR",
    "name": "Icatu",
    "lat": "-2.77583",
    "lng": "-44.06583"
  },
  {
    "country": "BR",
    "name": "Ibimirim",
    "lat": "-8.54056",
    "lng": "-37.69028"
  },
  {
    "country": "BR",
    "name": "Ibiapina",
    "lat": "-3.92333",
    "lng": "-40.88944"
  },
  {
    "country": "BR",
    "name": "Ibateguara",
    "lat": "-8.9725",
    "lng": "-35.93944"
  },
  {
    "country": "BR",
    "name": "Humberto de Campos",
    "lat": "-2.59833",
    "lng": "-43.46111"
  },
  {
    "country": "BR",
    "name": "Horizonte",
    "lat": "-4.1",
    "lng": "-38.48333"
  },
  {
    "country": "BR",
    "name": "Hidrolândia",
    "lat": "-4.40806",
    "lng": "-40.43778"
  },
  {
    "country": "BR",
    "name": "Gurupá",
    "lat": "-1.405",
    "lng": "-51.64"
  },
  {
    "country": "BR",
    "name": "Gurinhém",
    "lat": "-7.12389",
    "lng": "-35.42444"
  },
  {
    "country": "BR",
    "name": "Guaraciaba do Norte",
    "lat": "-4.16694",
    "lng": "-40.7475"
  },
  {
    "country": "BR",
    "name": "Guarabira",
    "lat": "-6.85472",
    "lng": "-35.49"
  },
  {
    "country": "BR",
    "name": "Guajará",
    "lat": "-2.96667",
    "lng": "-57.66667"
  },
  {
    "country": "BR",
    "name": "Guaiúba",
    "lat": "-4.03972",
    "lng": "-38.63722"
  },
  {
    "country": "BR",
    "name": "Guabiraba",
    "lat": "-8.41667",
    "lng": "-35.66667"
  },
  {
    "country": "BR",
    "name": "Gravatá",
    "lat": "-8.20111",
    "lng": "-35.56472"
  },
  {
    "country": "BR",
    "name": "Granja",
    "lat": "-3.12028",
    "lng": "-40.82611"
  },
  {
    "country": "BR",
    "name": "Grajaú",
    "lat": "-5.81944",
    "lng": "-46.13861"
  },
  {
    "country": "BR",
    "name": "Governador Dix Sept Rosado",
    "lat": "-5.45889",
    "lng": "-37.52083"
  },
  {
    "country": "BR",
    "name": "Goianinha",
    "lat": "-6.26472",
    "lng": "-35.2125"
  },
  {
    "country": "BR",
    "name": "Goiana",
    "lat": "-7.56056",
    "lng": "-35.0025"
  },
  {
    "country": "BR",
    "name": "Glória do Goitá",
    "lat": "-8.00167",
    "lng": "-35.29278"
  },
  {
    "country": "BR",
    "name": "Gilbués",
    "lat": "-9.83167",
    "lng": "-45.34389"
  },
  {
    "country": "BR",
    "name": "Gararu",
    "lat": "-9.9675",
    "lng": "-37.08333"
  },
  {
    "country": "BR",
    "name": "Garanhuns",
    "lat": "-8.88202",
    "lng": "-36.50216"
  },
  {
    "country": "BR",
    "name": "Gameleira",
    "lat": "-8.58444",
    "lng": "-35.38667"
  },
  {
    "country": "BR",
    "name": "Fortuna",
    "lat": "-5.73333",
    "lng": "-44.15833"
  },
  {
    "country": "BR",
    "name": "Fortaleza",
    "lat": "-3.71722",
    "lng": "-38.54306"
  },
  {
    "country": "BR",
    "name": "Forquilha",
    "lat": "-3.79833",
    "lng": "-40.26056"
  },
  {
    "country": "BR",
    "name": "Floriano",
    "lat": "-6.76694",
    "lng": "-43.0225"
  },
  {
    "country": "BR",
    "name": "Floresta",
    "lat": "-8.60111",
    "lng": "-38.56861"
  },
  {
    "country": "BR",
    "name": "Flores",
    "lat": "-7.86806",
    "lng": "-37.97472"
  },
  {
    "country": "BR",
    "name": "Flexeiras",
    "lat": "-9.1975",
    "lng": "-35.78083"
  },
  {
    "country": "BR",
    "name": "Feira Nova",
    "lat": "-7.95083",
    "lng": "-35.38917"
  },
  {
    "country": "BR",
    "name": "Farias Brito",
    "lat": "-6.93056",
    "lng": "-39.56556"
  },
  {
    "country": "BR",
    "name": "Fagundes",
    "lat": "-7.355",
    "lng": "-35.775"
  },
  {
    "country": "BR",
    "name": "Exu",
    "lat": "-7.51194",
    "lng": "-39.72417"
  },
  {
    "country": "BR",
    "name": "Eusébio",
    "lat": "-3.89",
    "lng": "-38.45056"
  },
  {
    "country": "BR",
    "name": "Extremoz",
    "lat": "-5.70556",
    "lng": "-35.30722"
  },
  {
    "country": "BR",
    "name": "Estreito",
    "lat": "-5.78333",
    "lng": "-43.25"
  },
  {
    "country": "BR",
    "name": "Esperantinópolis",
    "lat": "-4.86667",
    "lng": "-44.70833"
  },
  {
    "country": "BR",
    "name": "Esperantina",
    "lat": "-3.90167",
    "lng": "-42.23361"
  },
  {
    "country": "BR",
    "name": "Esperança",
    "lat": "-7.03306",
    "lng": "-35.85722"
  },
  {
    "country": "BR",
    "name": "Escada",
    "lat": "-8.35917",
    "lng": "-35.22361"
  },
  {
    "country": "BR",
    "name": "Elesbão Veloso",
    "lat": "-6.20194",
    "lng": "-42.14028"
  },
  {
    "country": "BR",
    "name": "Dona Inês",
    "lat": "-6.61354",
    "lng": "-35.62654"
  },
  {
    "country": "BR",
    "name": "Dom Pedro",
    "lat": "-5.03749",
    "lng": "-44.43857"
  },
  {
    "country": "BR",
    "name": "Dois Riachos",
    "lat": "-9.3925",
    "lng": "-37.10056"
  },
  {
    "country": "BR",
    "name": "Desterro",
    "lat": "-7.29056",
    "lng": "-37.09389"
  },
  {
    "country": "BR",
    "name": "Demerval Lobão",
    "lat": "-5.35833",
    "lng": "-42.67639"
  },
  {
    "country": "BR",
    "name": "Delmiro Gouveia",
    "lat": "-9.38861",
    "lng": "-37.99917"
  },
  {
    "country": "BR",
    "name": "Custódia",
    "lat": "-8.0875",
    "lng": "-37.64306"
  },
  {
    "country": "BR",
    "name": "Cururupu",
    "lat": "-1.82833",
    "lng": "-44.86833"
  },
  {
    "country": "BR",
    "name": "Curuçá",
    "lat": "-0.72889",
    "lng": "-47.84806"
  },
  {
    "country": "BR",
    "name": "Currais Novos",
    "lat": "-6.26083",
    "lng": "-36.51778"
  },
  {
    "country": "BR",
    "name": "Curaçá",
    "lat": "-8.99028",
    "lng": "-39.90944"
  },
  {
    "country": "BR",
    "name": "Cupira",
    "lat": "-8.61667",
    "lng": "-35.95"
  },
  {
    "country": "BR",
    "name": "Cumaru",
    "lat": "-8.00611",
    "lng": "-35.69722"
  },
  {
    "country": "BR",
    "name": "Cuité",
    "lat": "-6.48361",
    "lng": "-36.15361"
  },
  {
    "country": "BR",
    "name": "Cruz do Espírito Santo",
    "lat": "-7.14",
    "lng": "-35.08639"
  },
  {
    "country": "BR",
    "name": "Cruz",
    "lat": "-2.9211",
    "lng": "-40.17589"
  },
  {
    "country": "BR",
    "name": "Crato",
    "lat": "-7.23417",
    "lng": "-39.40944"
  },
  {
    "country": "BR",
    "name": "Crateús",
    "lat": "-5.17833",
    "lng": "-40.6775"
  },
  {
    "country": "BR",
    "name": "Coroatá",
    "lat": "-4.13",
    "lng": "-44.12417"
  },
  {
    "country": "BR",
    "name": "Coremas",
    "lat": "-7.01444",
    "lng": "-37.94583"
  },
  {
    "country": "BR",
    "name": "Coreaú",
    "lat": "-3.53333",
    "lng": "-40.65667"
  },
  {
    "country": "BR",
    "name": "Condado",
    "lat": "-7.58583",
    "lng": "-35.10583"
  },
  {
    "country": "BR",
    "name": "Conceição do Araguaia",
    "lat": "-8.26441",
    "lng": "-49.26982"
  },
  {
    "country": "BR",
    "name": "Colônia Leopoldina",
    "lat": "-8.90889",
    "lng": "-35.725"
  },
  {
    "country": "BR",
    "name": "Colinas",
    "lat": "-6.02583",
    "lng": "-44.24917"
  },
  {
    "country": "BR",
    "name": "Coité do Nóia",
    "lat": "-9.63222",
    "lng": "-36.57861"
  },
  {
    "country": "BR",
    "name": "Coelho Neto",
    "lat": "-4.25667",
    "lng": "-43.01278"
  },
  {
    "country": "BR",
    "name": "Codó",
    "lat": "-4.45528",
    "lng": "-43.88556"
  },
  {
    "country": "BR",
    "name": "Cocal",
    "lat": "-3.47194",
    "lng": "-41.5575"
  },
  {
    "country": "BR",
    "name": "Chorozinho",
    "lat": "-4.30028",
    "lng": "-38.49778"
  },
  {
    "country": "BR",
    "name": "Chapadinha",
    "lat": "-3.74167",
    "lng": "-43.36028"
  },
  {
    "country": "BR",
    "name": "Chã Grande",
    "lat": "-8.23833",
    "lng": "-35.46167"
  },
  {
    "country": "BR",
    "name": "Cerro Corá",
    "lat": "-6.04556",
    "lng": "-36.34583"
  },
  {
    "country": "BR",
    "name": "Cedro",
    "lat": "-6.60667",
    "lng": "-39.06222"
  },
  {
    "country": "BR",
    "name": "Ceará Mirim",
    "lat": "-5.63444",
    "lng": "-35.42556"
  },
  {
    "country": "BR",
    "name": "Caxias",
    "lat": "-4.85889",
    "lng": "-43.35611"
  },
  {
    "country": "BR",
    "name": "Caucaia",
    "lat": "-3.73611",
    "lng": "-38.65306"
  },
  {
    "country": "BR",
    "name": "Catolé do Rocha",
    "lat": "-6.34389",
    "lng": "-37.74667"
  },
  {
    "country": "BR",
    "name": "Catende",
    "lat": "-8.66667",
    "lng": "-35.71667"
  },
  {
    "country": "BR",
    "name": "Castelo do Piauí",
    "lat": "-5.32222",
    "lng": "-41.5525"
  },
  {
    "country": "BR",
    "name": "Castanhal",
    "lat": "-1.29389",
    "lng": "-47.92639"
  },
  {
    "country": "BR",
    "name": "Cascavel",
    "lat": "-4.13306",
    "lng": "-38.24194"
  },
  {
    "country": "BR",
    "name": "Carutapera",
    "lat": "-1.195",
    "lng": "-46.02"
  },
  {
    "country": "BR",
    "name": "Caruaru",
    "lat": "-8.28333",
    "lng": "-35.97611"
  },
  {
    "country": "BR",
    "name": "Carpina",
    "lat": "-7.85083",
    "lng": "-35.25472"
  },
  {
    "country": "BR",
    "name": "Carolina",
    "lat": "-7.33561",
    "lng": "-47.46218"
  },
  {
    "country": "BR",
    "name": "Carnaíba",
    "lat": "-8.7",
    "lng": "-37.66667"
  },
  {
    "country": "BR",
    "name": "Caririaçu",
    "lat": "-7.04222",
    "lng": "-39.28361"
  },
  {
    "country": "BR",
    "name": "Cariré",
    "lat": "-3.95056",
    "lng": "-40.47333"
  },
  {
    "country": "BR",
    "name": "Careiro da Várzea",
    "lat": "-3.19695",
    "lng": "-59.82674"
  },
  {
    "country": "BR",
    "name": "Caraúbas",
    "lat": "-5.7925",
    "lng": "-37.55667"
  },
  {
    "country": "BR",
    "name": "Capoeiras",
    "lat": "-8.73472",
    "lng": "-36.62667"
  },
  {
    "country": "BR",
    "name": "Capitão Poço",
    "lat": "-1.74639",
    "lng": "-47.05944"
  },
  {
    "country": "BR",
    "name": "Capela",
    "lat": "-9.4075",
    "lng": "-36.07361"
  },
  {
    "country": "BR",
    "name": "Capanema",
    "lat": "-1.19583",
    "lng": "-47.18083"
  },
  {
    "country": "BR",
    "name": "Canto do Buriti",
    "lat": "-8.11",
    "lng": "-42.94444"
  },
  {
    "country": "BR",
    "name": "Cantanhede",
    "lat": "-3.63333",
    "lng": "-44.37667"
  },
  {
    "country": "BR",
    "name": "Canindé de São Francisco",
    "lat": "-9.66",
    "lng": "-37.78944"
  },
  {
    "country": "BR",
    "name": "Canindé",
    "lat": "-4.35889",
    "lng": "-39.31167"
  },
  {
    "country": "BR",
    "name": "Canhotinho",
    "lat": "-8.88222",
    "lng": "-36.19111"
  },
  {
    "country": "BR",
    "name": "Canguaretama",
    "lat": "-6.38",
    "lng": "-35.12889"
  },
  {
    "country": "BR",
    "name": "Cândido Mendes",
    "lat": "-1.44667",
    "lng": "-45.71667"
  },
  {
    "country": "BR",
    "name": "Campos Sales",
    "lat": "-7.07444",
    "lng": "-40.37611"
  },
  {
    "country": "BR",
    "name": "Campo Maior",
    "lat": "-4.82778",
    "lng": "-42.16861"
  },
  {
    "country": "BR",
    "name": "Campo Alegre",
    "lat": "-9.78194",
    "lng": "-36.35083"
  },
  {
    "country": "BR",
    "name": "Campina Grande",
    "lat": "-7.23056",
    "lng": "-35.88111"
  },
  {
    "country": "BR",
    "name": "Camocim de São Félix",
    "lat": "-8.35861",
    "lng": "-35.76194"
  },
  {
    "country": "BR",
    "name": "Camocim",
    "lat": "-2.90222",
    "lng": "-40.84111"
  },
  {
    "country": "BR",
    "name": "Cametá",
    "lat": "-2.24444",
    "lng": "-49.49583"
  },
  {
    "country": "BR",
    "name": "Cajueiro",
    "lat": "-9.71667",
    "lng": "-36.45"
  },
  {
    "country": "BR",
    "name": "Cajazeiras",
    "lat": "-6.89028",
    "lng": "-38.55528"
  },
  {
    "country": "BR",
    "name": "Caicó",
    "lat": "-6.45833",
    "lng": "-37.09778"
  },
  {
    "country": "BR",
    "name": "Caetés",
    "lat": "-8.77306",
    "lng": "-36.6225"
  },
  {
    "country": "BR",
    "name": "Cacimbinhas",
    "lat": "-9.40028",
    "lng": "-36.99028"
  },
  {
    "country": "BR",
    "name": "Cacimba de Dentro",
    "lat": "-6.64167",
    "lng": "-35.79"
  },
  {
    "country": "BR",
    "name": "Cachoeirinha",
    "lat": "-8.48639",
    "lng": "-36.23306"
  },
  {
    "country": "BR",
    "name": "Cabrobó",
    "lat": "-8.51417",
    "lng": "-39.31"
  },
  {
    "country": "BR",
    "name": "Cabo",
    "lat": "-8.28333",
    "lng": "-35.03333"
  },
  {
    "country": "BR",
    "name": "Cabedelo",
    "lat": "-6.98111",
    "lng": "-34.83389"
  },
  {
    "country": "BR",
    "name": "Caaporã",
    "lat": "-7.51556",
    "lng": "-34.90833"
  },
  {
    "country": "BR",
    "name": "Buriti dos Lopes",
    "lat": "-3.175",
    "lng": "-41.86694"
  },
  {
    "country": "BR",
    "name": "Buriti Bravo",
    "lat": "-5.83722",
    "lng": "-43.83361"
  },
  {
    "country": "BR",
    "name": "Bujaru",
    "lat": "-1.515",
    "lng": "-48.04472"
  },
  {
    "country": "BR",
    "name": "Buíque",
    "lat": "-8.62306",
    "lng": "-37.15583"
  },
  {
    "country": "BR",
    "name": "Breves",
    "lat": "-1.68222",
    "lng": "-50.48028"
  },
  {
    "country": "BR",
    "name": "Brejo Santo",
    "lat": "-7.49333",
    "lng": "-38.98722"
  },
  {
    "country": "BR",
    "name": "Brejo da Madre de Deus",
    "lat": "-8.14583",
    "lng": "-36.37111"
  },
  {
    "country": "BR",
    "name": "Brejo",
    "lat": "-3.68444",
    "lng": "-42.75028"
  },
  {
    "country": "BR",
    "name": "Brejinho",
    "lat": "-6.19083",
    "lng": "-35.35667"
  },
  {
    "country": "BR",
    "name": "Bragança",
    "lat": "-1.05361",
    "lng": "-46.76556"
  },
  {
    "country": "BR",
    "name": "Borba",
    "lat": "-4.39143",
    "lng": "-59.58864"
  },
  {
    "country": "BR",
    "name": "Boqueirão",
    "lat": "-7.48237",
    "lng": "-36.13422"
  },
  {
    "country": "BR",
    "name": "Bonito",
    "lat": "-8.47028",
    "lng": "-35.72861"
  },
  {
    "country": "BR",
    "name": "Bom Jesus",
    "lat": "-9.07444",
    "lng": "-44.35861"
  },
  {
    "country": "BR",
    "name": "Bom Jardim",
    "lat": "-7.79583",
    "lng": "-35.58722"
  },
  {
    "country": "BR",
    "name": "Bom Jardim",
    "lat": "-7.01667",
    "lng": "-46.48333"
  },
  {
    "country": "BR",
    "name": "Bom Conselho",
    "lat": "-9.16972",
    "lng": "-36.67972"
  },
  {
    "country": "BR",
    "name": "Boa Viagem",
    "lat": "-5.1275",
    "lng": "-39.73222"
  },
  {
    "country": "BR",
    "name": "Bezerros",
    "lat": "-8.23333",
    "lng": "-35.79694"
  },
  {
    "country": "BR",
    "name": "Bequimão",
    "lat": "-2.44889",
    "lng": "-44.7825"
  },
  {
    "country": "BR",
    "name": "Benevides",
    "lat": "-1.36139",
    "lng": "-48.24472"
  },
  {
    "country": "BR",
    "name": "Beneditinos",
    "lat": "-5.45",
    "lng": "-42.36667"
  },
  {
    "country": "BR",
    "name": "Belo Jardim",
    "lat": "-8.33556",
    "lng": "-36.42417"
  },
  {
    "country": "BR",
    "name": "Belém do Brejo do Cruz",
    "lat": "-6.18861",
    "lng": "-37.53583"
  },
  {
    "country": "BR",
    "name": "Belém de São Francisco",
    "lat": "-8.75389",
    "lng": "-38.96583"
  },
  {
    "country": "BR",
    "name": "Belém",
    "lat": "-6.69167",
    "lng": "-35.53333"
  },
  {
    "country": "BR",
    "name": "Belém",
    "lat": "-1.45583",
    "lng": "-48.50444"
  },
  {
    "country": "BR",
    "name": "Bela Cruz",
    "lat": "-3.05056",
    "lng": "-40.16778"
  },
  {
    "country": "BR",
    "name": "Beberibe",
    "lat": "-4.17972",
    "lng": "-38.13056"
  },
  {
    "country": "BR",
    "name": "Bayeux",
    "lat": "-7.125",
    "lng": "-34.93222"
  },
  {
    "country": "BR",
    "name": "Baturité",
    "lat": "-4.32861",
    "lng": "-38.88472"
  },
  {
    "country": "BR",
    "name": "Batalha",
    "lat": "-9.67778",
    "lng": "-37.12472"
  },
  {
    "country": "BR",
    "name": "Batalha",
    "lat": "-4.025",
    "lng": "-42.075"
  },
  {
    "country": "BR",
    "name": "Barroquinha",
    "lat": "-3.01889",
    "lng": "-41.13611"
  },
  {
    "country": "BR",
    "name": "Barro",
    "lat": "-6.71667",
    "lng": "-38.86667"
  },
  {
    "country": "BR",
    "name": "Barreiros",
    "lat": "-8.81833",
    "lng": "-35.18639"
  },
  {
    "country": "BR",
    "name": "Barreirinhas",
    "lat": "-2.75556",
    "lng": "-42.82591"
  },
  {
    "country": "BR",
    "name": "Barreirinha",
    "lat": "-2.79333",
    "lng": "-57.07"
  },
  {
    "country": "BR",
    "name": "Barras",
    "lat": "-4.24444",
    "lng": "-42.29444"
  },
  {
    "country": "BR",
    "name": "Barra do Corda",
    "lat": "-5.50556",
    "lng": "-45.24333"
  },
  {
    "country": "BR",
    "name": "Barra de Santo Antônio",
    "lat": "-9.40472",
    "lng": "-35.50722"
  },
  {
    "country": "BR",
    "name": "Barcarena",
    "lat": "-1.50583",
    "lng": "-48.62583"
  },
  {
    "country": "BR",
    "name": "Barbalha",
    "lat": "-7.31111",
    "lng": "-39.30417"
  },
  {
    "country": "BR",
    "name": "Baraúna",
    "lat": "-5.08",
    "lng": "-37.61667"
  },
  {
    "country": "BR",
    "name": "Bananeiras",
    "lat": "-6.75",
    "lng": "-35.63333"
  },
  {
    "country": "BR",
    "name": "Balsas",
    "lat": "-7.5325",
    "lng": "-46.03556"
  },
  {
    "country": "BR",
    "name": "Baião",
    "lat": "-2.79056",
    "lng": "-49.67167"
  },
  {
    "country": "BR",
    "name": "Bacabal",
    "lat": "-4.29167",
    "lng": "-44.79167"
  },
  {
    "country": "BR",
    "name": "Autazes",
    "lat": "-3.57972",
    "lng": "-59.13056"
  },
  {
    "country": "BR",
    "name": "Aurora",
    "lat": "-6.9425",
    "lng": "-38.9675"
  },
  {
    "country": "BR",
    "name": "Augusto Corrêa",
    "lat": "-1.02167",
    "lng": "-46.635"
  },
  {
    "country": "BR",
    "name": "Atalaia",
    "lat": "-9.50194",
    "lng": "-36.02278"
  },
  {
    "country": "BR",
    "name": "Assaré",
    "lat": "-6.87444",
    "lng": "-39.875"
  },
  {
    "country": "BR",
    "name": "Aroeiras",
    "lat": "-7.54528",
    "lng": "-35.7075"
  },
  {
    "country": "BR",
    "name": "Arês",
    "lat": "-6.19444",
    "lng": "-35.16028"
  },
  {
    "country": "BR",
    "name": "Areia Branca",
    "lat": "-4.95611",
    "lng": "-37.13694"
  },
  {
    "country": "BR",
    "name": "Areia",
    "lat": "-6.96333",
    "lng": "-35.69167"
  },
  {
    "country": "BR",
    "name": "Arcoverde",
    "lat": "-8.41889",
    "lng": "-37.05389"
  },
  {
    "country": "BR",
    "name": "Araruna",
    "lat": "-6.55833",
    "lng": "-35.74167"
  },
  {
    "country": "BR",
    "name": "Araripina",
    "lat": "-7.57611",
    "lng": "-40.49833"
  },
  {
    "country": "BR",
    "name": "Araripe",
    "lat": "-7.2125",
    "lng": "-40.04611"
  },
  {
    "country": "BR",
    "name": "Arari",
    "lat": "-3.45361",
    "lng": "-44.78"
  },
  {
    "country": "BR",
    "name": "Arara",
    "lat": "-6.82833",
    "lng": "-35.75833"
  },
  {
    "country": "BR",
    "name": "Arapiraca",
    "lat": "-9.7525",
    "lng": "-36.66111"
  },
  {
    "country": "BR",
    "name": "Araioses",
    "lat": "-2.89",
    "lng": "-41.90306"
  },
  {
    "country": "BR",
    "name": "Araguaína",
    "lat": "-7.19111",
    "lng": "-48.20722"
  },
  {
    "country": "BR",
    "name": "Araçoiaba",
    "lat": "-7.79028",
    "lng": "-35.09083"
  },
  {
    "country": "BR",
    "name": "Aracoiaba",
    "lat": "-4.37111",
    "lng": "-38.81417"
  },
  {
    "country": "BR",
    "name": "Aracati",
    "lat": "-4.56167",
    "lng": "-37.76972"
  },
  {
    "country": "BR",
    "name": "Aquiraz",
    "lat": "-3.90139",
    "lng": "-38.39111"
  },
  {
    "country": "BR",
    "name": "Apodi",
    "lat": "-5.66417",
    "lng": "-37.79889"
  },
  {
    "country": "BR",
    "name": "Angicos",
    "lat": "-5.66556",
    "lng": "-36.60111"
  },
  {
    "country": "BR",
    "name": "Ananindeua",
    "lat": "-1.36556",
    "lng": "-48.37222"
  },
  {
    "country": "BR",
    "name": "Anajatuba",
    "lat": "-3.26444",
    "lng": "-44.61972"
  },
  {
    "country": "BR",
    "name": "Anadia",
    "lat": "-9.68444",
    "lng": "-36.30417"
  },
  {
    "country": "BR",
    "name": "Amontada",
    "lat": "-3.36167",
    "lng": "-39.83167"
  },
  {
    "country": "BR",
    "name": "Amarante do Maranhão",
    "lat": "-5.56667",
    "lng": "-46.74222"
  },
  {
    "country": "BR",
    "name": "Amarante",
    "lat": "-6.24316",
    "lng": "-42.84544"
  },
  {
    "country": "BR",
    "name": "Amaraji",
    "lat": "-8.38306",
    "lng": "-35.4525"
  },
  {
    "country": "BR",
    "name": "Altos",
    "lat": "-5.03806",
    "lng": "-42.46"
  },
  {
    "country": "BR",
    "name": "Alto Longá",
    "lat": "-5.25111",
    "lng": "-42.21028"
  },
  {
    "country": "BR",
    "name": "Altinho",
    "lat": "-8.48972",
    "lng": "-36.05944"
  },
  {
    "country": "BR",
    "name": "Altamira",
    "lat": "-3.20333",
    "lng": "-52.20639"
  },
  {
    "country": "BR",
    "name": "Almeirim",
    "lat": "-1.52333",
    "lng": "-52.58167"
  },
  {
    "country": "BR",
    "name": "Alhandra",
    "lat": "-7.43861",
    "lng": "-34.91444"
  },
  {
    "country": "BR",
    "name": "Alexandria",
    "lat": "-6.4125",
    "lng": "-38.01583"
  },
  {
    "country": "BR",
    "name": "Alenquer",
    "lat": "-1.94167",
    "lng": "-54.73833"
  },
  {
    "country": "BR",
    "name": "Alcântara",
    "lat": "-2.4041",
    "lng": "-44.41669"
  },
  {
    "country": "BR",
    "name": "Alagoinha",
    "lat": "-6.95",
    "lng": "-35.545"
  },
  {
    "country": "BR",
    "name": "Alagoa Nova",
    "lat": "-7.07083",
    "lng": "-35.75833"
  },
  {
    "country": "BR",
    "name": "Alagoa Grande",
    "lat": "-7.15833",
    "lng": "-35.63"
  },
  {
    "country": "BR",
    "name": "Águas Belas",
    "lat": "-9.11139",
    "lng": "-37.12306"
  },
  {
    "country": "BR",
    "name": "Água Preta",
    "lat": "-8.7075",
    "lng": "-35.53056"
  },
  {
    "country": "BR",
    "name": "Água Branca",
    "lat": "-9.26083",
    "lng": "-37.93611"
  },
  {
    "country": "BR",
    "name": "Água Branca",
    "lat": "-5.89222",
    "lng": "-42.63611"
  },
  {
    "country": "BR",
    "name": "Agrestina",
    "lat": "-8.45806",
    "lng": "-35.94472"
  },
  {
    "country": "BR",
    "name": "Afuá",
    "lat": "-0.15667",
    "lng": "-50.38667"
  },
  {
    "country": "BR",
    "name": "Afonso Bezerra",
    "lat": "-5.49833",
    "lng": "-36.50556"
  },
  {
    "country": "BR",
    "name": "Afogados da Ingazeira",
    "lat": "-7.75083",
    "lng": "-37.63917"
  },
  {
    "country": "BR",
    "name": "Açu",
    "lat": "-5.57667",
    "lng": "-36.90861"
  },
  {
    "country": "BR",
    "name": "Acopiara",
    "lat": "-6.09528",
    "lng": "-39.4525"
  },
  {
    "country": "BR",
    "name": "Acaraú",
    "lat": "-2.88556",
    "lng": "-40.12"
  },
  {
    "country": "BR",
    "name": "Acará",
    "lat": "-1.96083",
    "lng": "-48.19667"
  },
  {
    "country": "BR",
    "name": "Abreu e Lima",
    "lat": "-7.91167",
    "lng": "-34.90278"
  },
  {
    "country": "BR",
    "name": "Abaetetuba",
    "lat": "-1.71806",
    "lng": "-48.8825"
  },
  {
    "country": "BR",
    "name": "Xique Xique",
    "lat": "-10.82294",
    "lng": "-42.72815"
  },
  {
    "country": "BR",
    "name": "Chavantes",
    "lat": "-23.03889",
    "lng": "-49.70944"
  },
  {
    "country": "BR",
    "name": "Xanxerê",
    "lat": "-26.87694",
    "lng": "-52.40417"
  },
  {
    "country": "BR",
    "name": "Votuporanga",
    "lat": "-20.42278",
    "lng": "-49.97278"
  },
  {
    "country": "BR",
    "name": "Votorantim",
    "lat": "-23.54667",
    "lng": "-47.43778"
  },
  {
    "country": "BR",
    "name": "Volta Redonda",
    "lat": "-22.52306",
    "lng": "-44.10417"
  },
  {
    "country": "BR",
    "name": "Vitória da Conquista",
    "lat": "-14.86611",
    "lng": "-40.83944"
  },
  {
    "country": "BR",
    "name": "Vitória",
    "lat": "-20.31944",
    "lng": "-40.33778"
  },
  {
    "country": "BR",
    "name": "Visconde do Rio Branco",
    "lat": "-21.01028",
    "lng": "-42.84056"
  },
  {
    "country": "BR",
    "name": "Viradouro",
    "lat": "-20.87306",
    "lng": "-48.29694"
  },
  {
    "country": "BR",
    "name": "Vinhedo",
    "lat": "-23.02972",
    "lng": "-46.97528"
  },
  {
    "country": "BR",
    "name": "Vila Velha",
    "lat": "-20.32972",
    "lng": "-40.2925"
  },
  {
    "country": "BR",
    "name": "Videira",
    "lat": "-27.00833",
    "lng": "-51.15167"
  },
  {
    "country": "BR",
    "name": "Viçosa",
    "lat": "-20.75389",
    "lng": "-42.88194"
  },
  {
    "country": "BR",
    "name": "Vianópolis",
    "lat": "-16.74194",
    "lng": "-48.51639"
  },
  {
    "country": "BR",
    "name": "Viana",
    "lat": "-20.39028",
    "lng": "-40.49611"
  },
  {
    "country": "BR",
    "name": "Viamão",
    "lat": "-30.08111",
    "lng": "-51.02333"
  },
  {
    "country": "BR",
    "name": "Vespasiano",
    "lat": "-19.69194",
    "lng": "-43.92333"
  },
  {
    "country": "BR",
    "name": "Veranópolis",
    "lat": "-28.93611",
    "lng": "-51.54944"
  },
  {
    "country": "BR",
    "name": "Vera Cruz",
    "lat": "-12.63333",
    "lng": "-41.03333"
  },
  {
    "country": "BR",
    "name": "Wenceslau Braz",
    "lat": "-23.87389",
    "lng": "-49.80278"
  },
  {
    "country": "BR",
    "name": "Venâncio Aires",
    "lat": "-29.60639",
    "lng": "-52.19194"
  },
  {
    "country": "BR",
    "name": "Vazante",
    "lat": "-17.98694",
    "lng": "-46.90778"
  },
  {
    "country": "BR",
    "name": "Vassouras",
    "lat": "-22.40389",
    "lng": "-43.6625"
  },
  {
    "country": "BR",
    "name": "Varzelândia",
    "lat": "-15.70139",
    "lng": "-44.0275"
  },
  {
    "country": "BR",
    "name": "Várzea Paulista",
    "lat": "-23.21139",
    "lng": "-46.82833"
  },
  {
    "country": "BR",
    "name": "Várzea Grande",
    "lat": "-15.64667",
    "lng": "-56.1325"
  },
  {
    "country": "BR",
    "name": "Várzea da Palma",
    "lat": "-17.5976",
    "lng": "-44.73367"
  },
  {
    "country": "BR",
    "name": "Varginha",
    "lat": "-21.55139",
    "lng": "-45.43028"
  },
  {
    "country": "BR",
    "name": "Vargem Grande do Sul",
    "lat": "-21.83222",
    "lng": "-46.89361"
  },
  {
    "country": "BR",
    "name": "Vargem Alta",
    "lat": "-20.67139",
    "lng": "-41.00694"
  },
  {
    "country": "BR",
    "name": "Valparaíso",
    "lat": "-21.22778",
    "lng": "-50.86833"
  },
  {
    "country": "BR",
    "name": "Valinhos",
    "lat": "-22.97056",
    "lng": "-46.99583"
  },
  {
    "country": "BR",
    "name": "Valente",
    "lat": "-11.41222",
    "lng": "-39.46194"
  },
  {
    "country": "BR",
    "name": "Valença",
    "lat": "-22.24556",
    "lng": "-43.70028"
  },
  {
    "country": "BR",
    "name": "Valença",
    "lat": "-13.37028",
    "lng": "-39.07306"
  },
  {
    "country": "BR",
    "name": "Vacaria",
    "lat": "-28.51222",
    "lng": "-50.93389"
  },
  {
    "country": "BR",
    "name": "Urussanga",
    "lat": "-28.51778",
    "lng": "-49.32083"
  },
  {
    "country": "BR",
    "name": "Urupês",
    "lat": "-21.20167",
    "lng": "-49.29"
  },
  {
    "country": "BR",
    "name": "Uruguaiana",
    "lat": "-29.75472",
    "lng": "-57.08833"
  },
  {
    "country": "BR",
    "name": "Uruçuca",
    "lat": "-14.59306",
    "lng": "-39.28444"
  },
  {
    "country": "BR",
    "name": "Uruana",
    "lat": "-15.5036",
    "lng": "-49.68266"
  },
  {
    "country": "BR",
    "name": "Uruaçu",
    "lat": "-14.52472",
    "lng": "-49.14083"
  },
  {
    "country": "BR",
    "name": "União da Vitória",
    "lat": "-26.23",
    "lng": "-51.08639"
  },
  {
    "country": "BR",
    "name": "Unaí",
    "lat": "-16.3575",
    "lng": "-46.90611"
  },
  {
    "country": "BR",
    "name": "Una",
    "lat": "-15.29333",
    "lng": "-39.07528"
  },
  {
    "country": "BR",
    "name": "Umuarama",
    "lat": "-23.76639",
    "lng": "-53.325"
  },
  {
    "country": "BR",
    "name": "Umbaúba",
    "lat": "-11.38333",
    "lng": "-37.65778"
  },
  {
    "country": "BR",
    "name": "Uberlândia",
    "lat": "-18.91861",
    "lng": "-48.27722"
  },
  {
    "country": "BR",
    "name": "Uberaba",
    "lat": "-19.74833",
    "lng": "-47.93194"
  },
  {
    "country": "BR",
    "name": "Ubatuba",
    "lat": "-23.43389",
    "lng": "-45.07111"
  },
  {
    "country": "BR",
    "name": "Ubatã",
    "lat": "-14.20906",
    "lng": "-39.52641"
  },
  {
    "country": "BR",
    "name": "Ubaitaba",
    "lat": "-14.3125",
    "lng": "-39.32333"
  },
  {
    "country": "BR",
    "name": "Ubaíra",
    "lat": "-13.26806",
    "lng": "-39.66278"
  },
  {
    "country": "BR",
    "name": "Ubá",
    "lat": "-21.12",
    "lng": "-42.94278"
  },
  {
    "country": "BR",
    "name": "Turmalina",
    "lat": "-17.28556",
    "lng": "-42.73"
  },
  {
    "country": "BR",
    "name": "Tupi Paulista",
    "lat": "-21.38111",
    "lng": "-51.57056"
  },
  {
    "country": "BR",
    "name": "Tupanciretã",
    "lat": "-29.08056",
    "lng": "-53.83583"
  },
  {
    "country": "BR",
    "name": "Tupaciguara",
    "lat": "-18.59222",
    "lng": "-48.705"
  },
  {
    "country": "BR",
    "name": "Tupã",
    "lat": "-21.93472",
    "lng": "-50.51361"
  },
  {
    "country": "BR",
    "name": "Tucano",
    "lat": "-10.95817",
    "lng": "-38.79084"
  },
  {
    "country": "BR",
    "name": "Tubarão",
    "lat": "-28.46667",
    "lng": "-49.00694"
  },
  {
    "country": "BR",
    "name": "Triunfo",
    "lat": "-29.94333",
    "lng": "-51.71806"
  },
  {
    "country": "BR",
    "name": "Trindade",
    "lat": "-16.64944",
    "lng": "-49.48889"
  },
  {
    "country": "BR",
    "name": "Três Rios",
    "lat": "-22.11667",
    "lng": "-43.20917"
  },
  {
    "country": "BR",
    "name": "Três Pontas",
    "lat": "-21.36667",
    "lng": "-45.5125"
  },
  {
    "country": "BR",
    "name": "Três Passos",
    "lat": "-27.45556",
    "lng": "-53.93194"
  },
  {
    "country": "BR",
    "name": "Três Lagoas",
    "lat": "-20.78765",
    "lng": "-51.70338"
  },
  {
    "country": "BR",
    "name": "Três de Maio",
    "lat": "-27.77333",
    "lng": "-54.24"
  },
  {
    "country": "BR",
    "name": "Três Coroas",
    "lat": "-29.51694",
    "lng": "-50.77778"
  },
  {
    "country": "BR",
    "name": "Três Corações",
    "lat": "-21.69694",
    "lng": "-45.25333"
  },
  {
    "country": "BR",
    "name": "Três Barras",
    "lat": "-26.10639",
    "lng": "-50.32222"
  },
  {
    "country": "BR",
    "name": "Tremembé",
    "lat": "-22.95833",
    "lng": "-45.54944"
  },
  {
    "country": "BR",
    "name": "Tremedal",
    "lat": "-14.97583",
    "lng": "-41.41083"
  },
  {
    "country": "BR",
    "name": "Tramandaí",
    "lat": "-29.98472",
    "lng": "-50.13361"
  },
  {
    "country": "BR",
    "name": "Torres",
    "lat": "-29.33528",
    "lng": "-49.72694"
  },
  {
    "country": "BR",
    "name": "Tomar do Geru",
    "lat": "-11.37333",
    "lng": "-37.84056"
  },
  {
    "country": "BR",
    "name": "Toledo",
    "lat": "-24.71361",
    "lng": "-53.74306"
  },
  {
    "country": "BR",
    "name": "Tocantins",
    "lat": "-21.175",
    "lng": "-43.01778"
  },
  {
    "country": "BR",
    "name": "Tobias Barreto",
    "lat": "-11.18389",
    "lng": "-37.99833"
  },
  {
    "country": "BR",
    "name": "Tiradentes",
    "lat": "-21.11028",
    "lng": "-44.17806"
  },
  {
    "country": "BR",
    "name": "Timóteo",
    "lat": "-19.58106",
    "lng": "-42.64953"
  },
  {
    "country": "BR",
    "name": "Timbó",
    "lat": "-26.82333",
    "lng": "-49.27167"
  },
  {
    "country": "BR",
    "name": "Tijucas",
    "lat": "-27.24139",
    "lng": "-48.63361"
  },
  {
    "country": "BR",
    "name": "Tietê",
    "lat": "-23.10194",
    "lng": "-47.71472"
  },
  {
    "country": "BR",
    "name": "Tibagi",
    "lat": "-24.50944",
    "lng": "-50.41361"
  },
  {
    "country": "BR",
    "name": "Teutônia",
    "lat": "-29.44806",
    "lng": "-51.80639"
  },
  {
    "country": "BR",
    "name": "Terra Roxa",
    "lat": "-23.85571",
    "lng": "-50.0314"
  },
  {
    "country": "BR",
    "name": "Terra Rica",
    "lat": "-22.70944",
    "lng": "-52.61694"
  },
  {
    "country": "BR",
    "name": "Terra Nova",
    "lat": "-12.36667",
    "lng": "-40.66667"
  },
  {
    "country": "BR",
    "name": "Terra Boa",
    "lat": "-23.76806",
    "lng": "-52.44417"
  },
  {
    "country": "BR",
    "name": "Teresópolis",
    "lat": "-22.4167",
    "lng": "-42.97822"
  },
  {
    "country": "BR",
    "name": "Terenos",
    "lat": "-20.44222",
    "lng": "-54.86028"
  },
  {
    "country": "BR",
    "name": "Teófilo Otoni",
    "lat": "-17.8575",
    "lng": "-41.50528"
  },
  {
    "country": "BR",
    "name": "Teodoro Sampaio",
    "lat": "-22.5325",
    "lng": "-52.1675"
  },
  {
    "country": "BR",
    "name": "Telêmaco Borba",
    "lat": "-24.32389",
    "lng": "-50.61556"
  },
  {
    "country": "BR",
    "name": "Taubaté",
    "lat": "-23.02639",
    "lng": "-45.55528"
  },
  {
    "country": "BR",
    "name": "Tatuí",
    "lat": "-23.35556",
    "lng": "-47.85694"
  },
  {
    "country": "BR",
    "name": "Tarumã",
    "lat": "-22.74667",
    "lng": "-50.57722"
  },
  {
    "country": "BR",
    "name": "Taquarituba",
    "lat": "-23.53306",
    "lng": "-49.24444"
  },
  {
    "country": "BR",
    "name": "Taquaritinga",
    "lat": "-21.40611",
    "lng": "-48.50472"
  },
  {
    "country": "BR",
    "name": "Taquari",
    "lat": "-29.79972",
    "lng": "-51.86444"
  },
  {
    "country": "BR",
    "name": "Taquara",
    "lat": "-29.65056",
    "lng": "-50.78056"
  },
  {
    "country": "BR",
    "name": "Tapiramutá",
    "lat": "-11.84722",
    "lng": "-40.79139"
  },
  {
    "country": "BR",
    "name": "Tapes",
    "lat": "-30.67333",
    "lng": "-51.39583"
  },
  {
    "country": "BR",
    "name": "Taperoá",
    "lat": "-13.53806",
    "lng": "-39.09861"
  },
  {
    "country": "BR",
    "name": "Tapejara",
    "lat": "-28.06806",
    "lng": "-52.01389"
  },
  {
    "country": "BR",
    "name": "Tapejara",
    "lat": "-23.73306",
    "lng": "-52.87333"
  },
  {
    "country": "BR",
    "name": "Tanhaçu",
    "lat": "-14.02139",
    "lng": "-41.24806"
  },
  {
    "country": "BR",
    "name": "Tanguá",
    "lat": "-22.73028",
    "lng": "-42.71417"
  },
  {
    "country": "BR",
    "name": "Tanabi",
    "lat": "-20.62639",
    "lng": "-49.64917"
  },
  {
    "country": "BR",
    "name": "Tambaú",
    "lat": "-21.705",
    "lng": "-47.27444"
  },
  {
    "country": "BR",
    "name": "Taiobeiras",
    "lat": "-15.80778",
    "lng": "-42.23306"
  },
  {
    "country": "BR",
    "name": "Taguatinga",
    "lat": "-12.40389",
    "lng": "-46.43611"
  },
  {
    "country": "BR",
    "name": "Taboão da Serra",
    "lat": "-23.62611",
    "lng": "-46.79167"
  },
  {
    "country": "BR",
    "name": "Tabatinga",
    "lat": "-21.71667",
    "lng": "-48.6875"
  },
  {
    "country": "BR",
    "name": "Suzano",
    "lat": "-23.5425",
    "lng": "-46.31083"
  },
  {
    "country": "BR",
    "name": "Sumaré",
    "lat": "-22.82194",
    "lng": "-47.26694"
  },
  {
    "country": "BR",
    "name": "Sorocaba",
    "lat": "-23.50167",
    "lng": "-47.45806"
  },
  {
    "country": "BR",
    "name": "Sombrio",
    "lat": "-29.11389",
    "lng": "-49.61667"
  },
  {
    "country": "BR",
    "name": "Soledade",
    "lat": "-28.81833",
    "lng": "-52.51028"
  },
  {
    "country": "BR",
    "name": "Socorro",
    "lat": "-22.59139",
    "lng": "-46.52889"
  },
  {
    "country": "BR",
    "name": "Sobradinho",
    "lat": "-12.83333",
    "lng": "-39.1"
  },
  {
    "country": "BR",
    "name": "Siqueira Campos",
    "lat": "-23.68889",
    "lng": "-49.83389"
  },
  {
    "country": "BR",
    "name": "Simão Dias",
    "lat": "-10.73833",
    "lng": "-37.81111"
  },
  {
    "country": "BR",
    "name": "Silvânia",
    "lat": "-16.65889",
    "lng": "-48.60806"
  },
  {
    "country": "BR",
    "name": "Silva Jardim",
    "lat": "-22.65083",
    "lng": "-42.39167"
  },
  {
    "country": "BR",
    "name": "Sidrolândia",
    "lat": "-20.93194",
    "lng": "-54.96139"
  },
  {
    "country": "BR",
    "name": "Siderópolis",
    "lat": "-28.59778",
    "lng": "-49.42444"
  },
  {
    "country": "BR",
    "name": "Severínia",
    "lat": "-20.80944",
    "lng": "-48.80278"
  },
  {
    "country": "BR",
    "name": "Sete Lagoas",
    "lat": "-19.46583",
    "lng": "-44.24667"
  },
  {
    "country": "BR",
    "name": "Sertãozinho",
    "lat": "-21.13778",
    "lng": "-47.99028"
  },
  {
    "country": "BR",
    "name": "Sertanópolis",
    "lat": "-23.05861",
    "lng": "-51.03639"
  },
  {
    "country": "BR",
    "name": "Serro",
    "lat": "-18.60472",
    "lng": "-43.37944"
  },
  {
    "country": "BR",
    "name": "Serrinha",
    "lat": "-11.66417",
    "lng": "-39.0075"
  },
  {
    "country": "BR",
    "name": "Serra Negra",
    "lat": "-22.61222",
    "lng": "-46.70056"
  },
  {
    "country": "BR",
    "name": "Serrana",
    "lat": "-21.21139",
    "lng": "-47.59556"
  },
  {
    "country": "BR",
    "name": "Serra",
    "lat": "-20.12861",
    "lng": "-40.30778"
  },
  {
    "country": "BR",
    "name": "Seropédica",
    "lat": "-22.74389",
    "lng": "-43.7075"
  },
  {
    "country": "BR",
    "name": "Senhor do Bonfim",
    "lat": "-10.46139",
    "lng": "-40.18944"
  },
  {
    "country": "BR",
    "name": "Sengés",
    "lat": "-24.11335",
    "lng": "-49.46315"
  },
  {
    "country": "BR",
    "name": "Senador Canedo",
    "lat": "-16.70806",
    "lng": "-49.09306"
  },
  {
    "country": "BR",
    "name": "Seabra",
    "lat": "-12.41713",
    "lng": "-41.77049"
  },
  {
    "country": "BR",
    "name": "Schroeder",
    "lat": "-26.4125",
    "lng": "-49.07306"
  },
  {
    "country": "BR",
    "name": "Saubara",
    "lat": "-12.7375",
    "lng": "-38.76861"
  },
  {
    "country": "BR",
    "name": "Sarzedo",
    "lat": "-20.03528",
    "lng": "-44.14472"
  },
  {
    "country": "BR",
    "name": "Sarandi",
    "lat": "-27.94389",
    "lng": "-52.92306"
  },
  {
    "country": "BR",
    "name": "Sarandi",
    "lat": "-23.44361",
    "lng": "-51.87389"
  },
  {
    "country": "BR",
    "name": "Saquarema",
    "lat": "-22.92",
    "lng": "-42.51028"
  },
  {
    "country": "BR",
    "name": "Sapucaia",
    "lat": "-29.83333",
    "lng": "-51.15"
  },
  {
    "country": "BR",
    "name": "Sapucaia",
    "lat": "-21.995",
    "lng": "-42.91444"
  },
  {
    "country": "BR",
    "name": "Sapiranga",
    "lat": "-29.63806",
    "lng": "-51.00694"
  },
  {
    "country": "BR",
    "name": "São Vicente",
    "lat": "-23.96306",
    "lng": "-46.39194"
  },
  {
    "country": "BR",
    "name": "São Simão",
    "lat": "-21.47917",
    "lng": "-47.55083"
  },
  {
    "country": "BR",
    "name": "São Sepé",
    "lat": "-30.16056",
    "lng": "-53.56528"
  },
  {
    "country": "BR",
    "name": "São Sebastião do Passé",
    "lat": "-12.5125",
    "lng": "-38.49528"
  },
  {
    "country": "BR",
    "name": "São Sebastião do Paraíso",
    "lat": "-20.91694",
    "lng": "-46.99139"
  },
  {
    "country": "BR",
    "name": "São Sebastião do Caí",
    "lat": "-29.58667",
    "lng": "-51.37556"
  },
  {
    "country": "BR",
    "name": "São Sebastião",
    "lat": "-23.76",
    "lng": "-45.40972"
  },
  {
    "country": "BR",
    "name": "São Roque",
    "lat": "-23.52917",
    "lng": "-47.13528"
  },
  {
    "country": "BR",
    "name": "São Pedro do Sul",
    "lat": "-29.62056",
    "lng": "-54.17889"
  },
  {
    "country": "BR",
    "name": "São Pedro da Aldeia",
    "lat": "-22.83917",
    "lng": "-42.10278"
  },
  {
    "country": "BR",
    "name": "São Pedro",
    "lat": "-22.54861",
    "lng": "-47.91389"
  },
  {
    "country": "BR",
    "name": "São Paulo",
    "lat": "-23.5475",
    "lng": "-46.63611"
  },
  {
    "country": "BR",
    "name": "São Miguel do Iguaçu",
    "lat": "-25.34806",
    "lng": "-54.23778"
  },
  {
    "country": "BR",
    "name": "São Miguel do Araguaia",
    "lat": "-13.275",
    "lng": "-50.16278"
  },
  {
    "country": "BR",
    "name": "São Mateus do Sul",
    "lat": "-25.87417",
    "lng": "-50.38278"
  },
  {
    "country": "BR",
    "name": "São Mateus",
    "lat": "-18.72011",
    "lng": "-39.85891"
  },
  {
    "country": "BR",
    "name": "São Marcos",
    "lat": "-28.97111",
    "lng": "-51.06806"
  },
  {
    "country": "BR",
    "name": "São Manuel",
    "lat": "-22.73111",
    "lng": "-48.57056"
  },
  {
    "country": "BR",
    "name": "São Luiz Gonzaga",
    "lat": "-28.40833",
    "lng": "-54.96083"
  },
  {
    "country": "BR",
    "name": "São Luís de Montes Belos",
    "lat": "-16.525",
    "lng": "-50.37222"
  },
  {
    "country": "BR",
    "name": "São Lourenço do Sul",
    "lat": "-31.36528",
    "lng": "-51.97833"
  },
  {
    "country": "BR",
    "name": "São Lourenço do Oeste",
    "lat": "-26.35917",
    "lng": "-52.85111"
  },
  {
    "country": "BR",
    "name": "São Lourenço da Serra",
    "lat": "-23.8525",
    "lng": "-46.9425"
  },
  {
    "country": "BR",
    "name": "São Lourenço",
    "lat": "-22.11639",
    "lng": "-45.05444"
  },
  {
    "country": "BR",
    "name": "São Leopoldo",
    "lat": "-29.76028",
    "lng": "-51.14722"
  },
  {
    "country": "BR",
    "name": "São José dos Pinhais",
    "lat": "-25.5302",
    "lng": "-49.20836"
  },
  {
    "country": "BR",
    "name": "São José dos Campos",
    "lat": "-23.17944",
    "lng": "-45.88694"
  },
  {
    "country": "BR",
    "name": "São José do Rio Preto",
    "lat": "-20.81972",
    "lng": "-49.37944"
  },
  {
    "country": "BR",
    "name": "São José do Rio Pardo",
    "lat": "-21.59556",
    "lng": "-46.88861"
  },
  {
    "country": "BR",
    "name": "São José do Calçado",
    "lat": "-21.02528",
    "lng": "-41.65444"
  },
  {
    "country": "BR",
    "name": "São José",
    "lat": "-28.21171",
    "lng": "-49.1632"
  },
  {
    "country": "BR",
    "name": "São Joaquim de Bicas",
    "lat": "-20.04917",
    "lng": "-44.27389"
  },
  {
    "country": "BR",
    "name": "São Joaquim da Barra",
    "lat": "-20.58139",
    "lng": "-47.85472"
  },
  {
    "country": "BR",
    "name": "São Joaquim",
    "lat": "-28.29389",
    "lng": "-49.93167"
  },
  {
    "country": "BR",
    "name": "São João Nepomuceno",
    "lat": "-21.54",
    "lng": "-43.01056"
  },
  {
    "country": "BR",
    "name": "São João Evangelista",
    "lat": "-18.54778",
    "lng": "-42.76333"
  },
  {
    "country": "BR",
    "name": "São João do Paraíso",
    "lat": "-15.31361",
    "lng": "-42.01444"
  },
  {
    "country": "BR",
    "name": "São João de Meriti",
    "lat": "-22.80389",
    "lng": "-43.37222"
  },
  {
    "country": "BR",
    "name": "São João del Rei",
    "lat": "-21.13556",
    "lng": "-44.26167"
  },
  {
    "country": "BR",
    "name": "São João da Ponte",
    "lat": "-15.92917",
    "lng": "-44.00778"
  },
  {
    "country": "BR",
    "name": "São João da Boa Vista",
    "lat": "-21.96917",
    "lng": "-46.79806"
  },
  {
    "country": "BR",
    "name": "São João da Barra",
    "lat": "-21.64028",
    "lng": "-41.05111"
  },
  {
    "country": "BR",
    "name": "São João Batista",
    "lat": "-27.27611",
    "lng": "-48.84944"
  },
  {
    "country": "BR",
    "name": "São Jerônimo",
    "lat": "-29.95917",
    "lng": "-51.72222"
  },
  {
    "country": "BR",
    "name": "São Gotardo",
    "lat": "-19.31111",
    "lng": "-46.04889"
  },
  {
    "country": "BR",
    "name": "São Gonçalo dos Campos",
    "lat": "-12.43333",
    "lng": "-38.96667"
  },
  {
    "country": "BR",
    "name": "São Gonçalo do Sapucaí",
    "lat": "-21.89222",
    "lng": "-45.59528"
  },
  {
    "country": "BR",
    "name": "São Gonçalo",
    "lat": "-22.82694",
    "lng": "-43.05389"
  },
  {
    "country": "BR",
    "name": "São Gabriel",
    "lat": "-30.33639",
    "lng": "-54.32"
  },
  {
    "country": "BR",
    "name": "São Francisco do Sul",
    "lat": "-26.24333",
    "lng": "-48.63806"
  },
  {
    "country": "BR",
    "name": "São Francisco do Conde",
    "lat": "-12.6275",
    "lng": "-38.68"
  },
  {
    "country": "BR",
    "name": "São Francisco de Paula",
    "lat": "-29.44806",
    "lng": "-50.58361"
  },
  {
    "country": "BR",
    "name": "São Francisco de Assis",
    "lat": "-29.55028",
    "lng": "-55.13111"
  },
  {
    "country": "BR",
    "name": "São Francisco",
    "lat": "-15.94861",
    "lng": "-44.86444"
  },
  {
    "country": "BR",
    "name": "São Fidélis",
    "lat": "-21.64611",
    "lng": "-41.74694"
  },
  {
    "country": "BR",
    "name": "São Felipe",
    "lat": "-14.8386",
    "lng": "-41.39174"
  },
  {
    "country": "BR",
    "name": "São Domingos do Prata",
    "lat": "-19.865",
    "lng": "-42.96833"
  },
  {
    "country": "BR",
    "name": "São Domingos",
    "lat": "-13.39833",
    "lng": "-46.31833"
  },
  {
    "country": "BR",
    "name": "São Desidério",
    "lat": "-12.36333",
    "lng": "-44.97333"
  },
  {
    "country": "BR",
    "name": "São Cristóvão",
    "lat": "-11.01472",
    "lng": "-37.20639"
  },
  {
    "country": "BR",
    "name": "São Carlos",
    "lat": "-22.0175",
    "lng": "-47.89083"
  },
  {
    "country": "BR",
    "name": "São Caetano do Sul",
    "lat": "-23.62306",
    "lng": "-46.55111"
  },
  {
    "country": "BR",
    "name": "São Borja",
    "lat": "-28.66056",
    "lng": "-56.00444"
  },
  {
    "country": "BR",
    "name": "São Bernardo do Campo",
    "lat": "-23.69389",
    "lng": "-46.565"
  },
  {
    "country": "BR",
    "name": "São Bento do Sul",
    "lat": "-26.25028",
    "lng": "-49.37861"
  },
  {
    "country": "BR",
    "name": "Santos Dumont",
    "lat": "-21.45667",
    "lng": "-43.5525"
  },
  {
    "country": "BR",
    "name": "Santos",
    "lat": "-23.96083",
    "lng": "-46.33361"
  },
  {
    "country": "BR",
    "name": "Santo Estêvão",
    "lat": "-12.43028",
    "lng": "-39.25139"
  },
  {
    "country": "BR",
    "name": "Santo Augusto",
    "lat": "-27.85083",
    "lng": "-53.77722"
  },
  {
    "country": "BR",
    "name": "Santo Antônio do Sudoeste",
    "lat": "-26.07361",
    "lng": "-53.72528"
  },
  {
    "country": "BR",
    "name": "Santo Antônio do Monte",
    "lat": "-20.08722",
    "lng": "-45.29361"
  },
  {
    "country": "BR",
    "name": "Santo Antônio do Leverger",
    "lat": "-15.86556",
    "lng": "-56.07667"
  },
  {
    "country": "BR",
    "name": "Santo Antônio do Amparo",
    "lat": "-20.94639",
    "lng": "-44.91889"
  },
  {
    "country": "BR",
    "name": "Santo Antônio de Posse",
    "lat": "-22.60611",
    "lng": "-46.91944"
  },
  {
    "country": "BR",
    "name": "Santo Antônio de Pádua",
    "lat": "-21.53944",
    "lng": "-42.18028"
  },
  {
    "country": "BR",
    "name": "Santo Antônio de Jesus",
    "lat": "-12.96889",
    "lng": "-39.26139"
  },
  {
    "country": "BR",
    "name": "Santo Antônio da Platina",
    "lat": "-23.295",
    "lng": "-50.07722"
  },
  {
    "country": "BR",
    "name": "Santo Ângelo",
    "lat": "-28.29917",
    "lng": "-54.26306"
  },
  {
    "country": "BR",
    "name": "Santo André",
    "lat": "-23.66389",
    "lng": "-46.53833"
  },
  {
    "country": "BR",
    "name": "Santo Anastácio",
    "lat": "-21.83833",
    "lng": "-51.61028"
  },
  {
    "country": "BR",
    "name": "Santo Amaro das Brotas",
    "lat": "-10.78889",
    "lng": "-37.05444"
  },
  {
    "country": "BR",
    "name": "Santo Amaro da Imperatriz",
    "lat": "-27.68806",
    "lng": "-48.77861"
  },
  {
    "country": "BR",
    "name": "Santo Amaro",
    "lat": "-12.54667",
    "lng": "-38.71194"
  },
  {
    "country": "BR",
    "name": "Santiago",
    "lat": "-29.19167",
    "lng": "-54.86722"
  },
  {
    "country": "BR",
    "name": "Santa Vitória do Palmar",
    "lat": "-33.51889",
    "lng": "-53.36806"
  },
  {
    "country": "BR",
    "name": "Santa Vitória",
    "lat": "-18.83861",
    "lng": "-50.12139"
  },
  {
    "country": "BR",
    "name": "Santa Teresa",
    "lat": "-19.93556",
    "lng": "-40.60028"
  },
  {
    "country": "BR",
    "name": "Santa Rosa de Viterbo",
    "lat": "-21.47278",
    "lng": "-47.36306"
  },
  {
    "country": "BR",
    "name": "Santa Rosa",
    "lat": "-27.87083",
    "lng": "-54.48139"
  },
  {
    "country": "BR",
    "name": "Santa Rita do Sapucaí",
    "lat": "-22.25222",
    "lng": "-45.70333"
  },
  {
    "country": "BR",
    "name": "Santa Rita do Passa Quatro",
    "lat": "-21.71028",
    "lng": "-47.47806"
  },
  {
    "country": "BR",
    "name": "Santana do Paraíso",
    "lat": "-19.36361",
    "lng": "-42.56861"
  },
  {
    "country": "BR",
    "name": "Santana do Livramento",
    "lat": "-30.89083",
    "lng": "-55.53278"
  },
  {
    "country": "BR",
    "name": "Santana de Parnaíba",
    "lat": "-23.44417",
    "lng": "-46.91778"
  },
  {
    "country": "BR",
    "name": "Santana",
    "lat": "-14.46667",
    "lng": "-41.8"
  },
  {
    "country": "BR",
    "name": "Santa Maria do Suaçuí",
    "lat": "-18.19028",
    "lng": "-42.41417"
  },
  {
    "country": "BR",
    "name": "Santa Maria da Vitória",
    "lat": "-13.38814",
    "lng": "-44.19868"
  },
  {
    "country": "BR",
    "name": "Santa Maria",
    "lat": "-29.68417",
    "lng": "-53.80694"
  },
  {
    "country": "BR",
    "name": "Santa Luzia",
    "lat": "-19.76972",
    "lng": "-43.85139"
  },
  {
    "country": "BR",
    "name": "Santaluz",
    "lat": "-11.25583",
    "lng": "-39.37472"
  },
  {
    "country": "BR",
    "name": "Santa Leopoldina",
    "lat": "-20.10056",
    "lng": "-40.52972"
  },
  {
    "country": "BR",
    "name": "Santa Isabel",
    "lat": "-23.31556",
    "lng": "-46.22139"
  },
  {
    "country": "BR",
    "name": "Santa Inês",
    "lat": "-13.29222",
    "lng": "-39.81889"
  },
  {
    "country": "BR",
    "name": "Santa Helena de Goiás",
    "lat": "-17.81361",
    "lng": "-50.59694"
  },
  {
    "country": "BR",
    "name": "Santa Gertrudes",
    "lat": "-22.45667",
    "lng": "-47.53028"
  },
  {
    "country": "BR",
    "name": "Santa Fé do Sul",
    "lat": "-20.21111",
    "lng": "-50.92583"
  },
  {
    "country": "BR",
    "name": "Santa Cruz do Sul",
    "lat": "-29.7175",
    "lng": "-52.42583"
  },
  {
    "country": "BR",
    "name": "Santa Cruz do Rio Pardo",
    "lat": "-22.89889",
    "lng": "-49.6325"
  },
  {
    "country": "BR",
    "name": "Santa Cruz das Palmeiras",
    "lat": "-21.82694",
    "lng": "-47.24861"
  },
  {
    "country": "BR",
    "name": "Santa Cruz Cabrália",
    "lat": "-16.27806",
    "lng": "-39.02472"
  },
  {
    "country": "BR",
    "name": "Santa Cecília",
    "lat": "-26.96083",
    "lng": "-50.42694"
  },
  {
    "country": "BR",
    "name": "Santa Branca",
    "lat": "-23.39667",
    "lng": "-45.88389"
  },
  {
    "country": "BR",
    "name": "Santa Bárbara d'Oeste",
    "lat": "-22.75361",
    "lng": "-47.41361"
  },
  {
    "country": "BR",
    "name": "Santa Adélia",
    "lat": "-21.24278",
    "lng": "-48.80417"
  },
  {
    "country": "BR",
    "name": "Sananduva",
    "lat": "-27.94972",
    "lng": "-51.80667"
  },
  {
    "country": "BR",
    "name": "Salvador",
    "lat": "-12.97111",
    "lng": "-38.51083"
  },
  {
    "country": "BR",
    "name": "Salto de Pirapora",
    "lat": "-23.64889",
    "lng": "-47.57333"
  },
  {
    "country": "BR",
    "name": "Salto",
    "lat": "-23.20083",
    "lng": "-47.28694"
  },
  {
    "country": "BR",
    "name": "Salinas",
    "lat": "-16.17028",
    "lng": "-42.29028"
  },
  {
    "country": "BR",
    "name": "Salgado",
    "lat": "-11.03194",
    "lng": "-37.475"
  },
  {
    "country": "BR",
    "name": "Sacramento",
    "lat": "-19.86528",
    "lng": "-47.44"
  },
  {
    "country": "BR",
    "name": "Sabinópolis",
    "lat": "-18.66611",
    "lng": "-43.08389"
  },
  {
    "country": "BR",
    "name": "Ruy Barbosa",
    "lat": "-12.28389",
    "lng": "-40.49389"
  },
  {
    "country": "BR",
    "name": "Rubiataba",
    "lat": "-15.16444",
    "lng": "-49.80333"
  },
  {
    "country": "BR",
    "name": "Rosário Oeste",
    "lat": "-14.83611",
    "lng": "-56.4275"
  },
  {
    "country": "BR",
    "name": "Rosário do Sul",
    "lat": "-30.25833",
    "lng": "-54.91417"
  },
  {
    "country": "BR",
    "name": "Rondonópolis",
    "lat": "-16.47083",
    "lng": "-54.63556"
  },
  {
    "country": "BR",
    "name": "Rolante",
    "lat": "-29.65056",
    "lng": "-50.57583"
  },
  {
    "country": "BR",
    "name": "Rolândia",
    "lat": "-23.30972",
    "lng": "-51.36917"
  },
  {
    "country": "BR",
    "name": "Rodeio",
    "lat": "-26.92278",
    "lng": "-49.36639"
  },
  {
    "country": "BR",
    "name": "Rio Verde de Mato Grosso",
    "lat": "-18.91806",
    "lng": "-54.84417"
  },
  {
    "country": "BR",
    "name": "Rio Tavares",
    "lat": "-27.64529",
    "lng": "-48.47486"
  },
  {
    "country": "BR",
    "name": "Rio Real",
    "lat": "-11.48472",
    "lng": "-37.93278"
  },
  {
    "country": "BR",
    "name": "Rio Pomba",
    "lat": "-21.27472",
    "lng": "-43.17917"
  },
  {
    "country": "BR",
    "name": "Rio Piracicaba",
    "lat": "-19.92917",
    "lng": "-43.17417"
  },
  {
    "country": "BR",
    "name": "Rio Pardo de Minas",
    "lat": "-15.60972",
    "lng": "-42.53972"
  },
  {
    "country": "BR",
    "name": "Rio Pardo",
    "lat": "-29.98972",
    "lng": "-52.37806"
  },
  {
    "country": "BR",
    "name": "Rio Novo do Sul",
    "lat": "-20.8625",
    "lng": "-40.93639"
  },
  {
    "country": "BR",
    "name": "Rio Novo",
    "lat": "-21.47703",
    "lng": "-43.12589"
  },
  {
    "country": "BR",
    "name": "Rio Negro",
    "lat": "-26.10583",
    "lng": "-49.7975"
  },
  {
    "country": "BR",
    "name": "Rio Negrinho",
    "lat": "-26.25444",
    "lng": "-49.51833"
  },
  {
    "country": "BR",
    "name": "Riolândia",
    "lat": "-19.98083",
    "lng": "-49.68194"
  },
  {
    "country": "BR",
    "name": "Rio Grande da Serra",
    "lat": "-23.74417",
    "lng": "-46.39833"
  },
  {
    "country": "BR",
    "name": "Rio Grande",
    "lat": "-32.035",
    "lng": "-52.09861"
  },
  {
    "country": "BR",
    "name": "Rio do Sul",
    "lat": "-27.21417",
    "lng": "-49.64306"
  },
  {
    "country": "BR",
    "name": "Rio de Janeiro",
    "lat": "-22.90642",
    "lng": "-43.18223"
  },
  {
    "country": "BR",
    "name": "Rio das Pedras",
    "lat": "-22.84333",
    "lng": "-47.60611"
  },
  {
    "country": "BR",
    "name": "Rio das Ostras",
    "lat": "-22.52694",
    "lng": "-41.945"
  },
  {
    "country": "BR",
    "name": "Rio Claro",
    "lat": "-22.72306",
    "lng": "-44.13556"
  },
  {
    "country": "BR",
    "name": "Rio Claro",
    "lat": "-22.41139",
    "lng": "-47.56139"
  },
  {
    "country": "BR",
    "name": "Rio Casca",
    "lat": "-20.22611",
    "lng": "-42.65083"
  },
  {
    "country": "BR",
    "name": "Rio Brilhante",
    "lat": "-21.80194",
    "lng": "-54.54639"
  },
  {
    "country": "BR",
    "name": "Rio Branco do Sul",
    "lat": "-25.19",
    "lng": "-49.31417"
  },
  {
    "country": "BR",
    "name": "Rio Bonito",
    "lat": "-22.70861",
    "lng": "-42.60972"
  },
  {
    "country": "BR",
    "name": "Rio Bananal",
    "lat": "-19.265",
    "lng": "-40.33333"
  },
  {
    "country": "BR",
    "name": "Ribeirópolis",
    "lat": "-10.53944",
    "lng": "-37.41667"
  },
  {
    "country": "BR",
    "name": "Ribeirão Preto",
    "lat": "-21.1775",
    "lng": "-47.81028"
  },
  {
    "country": "BR",
    "name": "Ribeirão Pires",
    "lat": "-23.71056",
    "lng": "-46.41333"
  },
  {
    "country": "BR",
    "name": "Ribeirão das Neves",
    "lat": "-19.76694",
    "lng": "-44.08667"
  },
  {
    "country": "BR",
    "name": "Ribeirão da Ilha",
    "lat": "-27.69934",
    "lng": "-48.53219"
  },
  {
    "country": "BR",
    "name": "Ribeirão Branco",
    "lat": "-24.22083",
    "lng": "-48.76556"
  },
  {
    "country": "BR",
    "name": "Ribeirão Bonito",
    "lat": "-22.06667",
    "lng": "-48.17611"
  },
  {
    "country": "BR",
    "name": "Ribeira do Pombal",
    "lat": "-10.83444",
    "lng": "-38.53583"
  },
  {
    "country": "BR",
    "name": "Ribas do Rio Pardo",
    "lat": "-20.44306",
    "lng": "-53.75917"
  },
  {
    "country": "BR",
    "name": "Rialma",
    "lat": "-15.315",
    "lng": "-49.58444"
  },
  {
    "country": "BR",
    "name": "Riacho de Santana",
    "lat": "-13.60917",
    "lng": "-42.93889"
  },
  {
    "country": "BR",
    "name": "Riachão do Jacuípe",
    "lat": "-11.80694",
    "lng": "-39.38556"
  },
  {
    "country": "BR",
    "name": "Riachão do Dantas",
    "lat": "-11.06889",
    "lng": "-37.725"
  },
  {
    "country": "BR",
    "name": "Riachão das Neves",
    "lat": "-11.74611",
    "lng": "-44.91"
  },
  {
    "country": "BR",
    "name": "Resplendor",
    "lat": "-19.32556",
    "lng": "-41.25528"
  },
  {
    "country": "BR",
    "name": "Reserva",
    "lat": "-24.65028",
    "lng": "-50.85056"
  },
  {
    "country": "BR",
    "name": "Resende",
    "lat": "-22.46889",
    "lng": "-44.44667"
  },
  {
    "country": "BR",
    "name": "Registro",
    "lat": "-24.4875",
    "lng": "-47.84361"
  },
  {
    "country": "BR",
    "name": "Regente Feijó",
    "lat": "-22.22139",
    "lng": "-51.30278"
  },
  {
    "country": "BR",
    "name": "Recreio",
    "lat": "-21.525",
    "lng": "-42.46917"
  },
  {
    "country": "BR",
    "name": "Realeza",
    "lat": "-25.76889",
    "lng": "-53.5325"
  },
  {
    "country": "BR",
    "name": "Raposos",
    "lat": "-19.96722",
    "lng": "-43.80417"
  },
  {
    "country": "BR",
    "name": "Rancharia",
    "lat": "-22.22917",
    "lng": "-50.89306"
  },
  {
    "country": "BR",
    "name": "Quirinópolis",
    "lat": "-18.44833",
    "lng": "-50.45167"
  },
  {
    "country": "BR",
    "name": "Quijingue",
    "lat": "-10.7525",
    "lng": "-39.20917"
  },
  {
    "country": "BR",
    "name": "Queimados",
    "lat": "-22.71611",
    "lng": "-43.55528"
  },
  {
    "country": "BR",
    "name": "Queimadas",
    "lat": "-10.97833",
    "lng": "-39.62639"
  },
  {
    "country": "BR",
    "name": "Quatro Barras",
    "lat": "-25.36556",
    "lng": "-49.07694"
  },
  {
    "country": "BR",
    "name": "Quatis",
    "lat": "-22.40722",
    "lng": "-44.25806"
  },
  {
    "country": "BR",
    "name": "Quatá",
    "lat": "-22.2475",
    "lng": "-50.69833"
  },
  {
    "country": "BR",
    "name": "Quaraí",
    "lat": "-30.3875",
    "lng": "-56.45139"
  },
  {
    "country": "BR",
    "name": "Prudentópolis",
    "lat": "-25.21306",
    "lng": "-50.97778"
  },
  {
    "country": "BR",
    "name": "Propriá",
    "lat": "-10.21111",
    "lng": "-36.84028"
  },
  {
    "country": "BR",
    "name": "Promissão",
    "lat": "-21.53667",
    "lng": "-49.85806"
  },
  {
    "country": "BR",
    "name": "Presidente Venceslau",
    "lat": "-21.87611",
    "lng": "-51.84389"
  },
  {
    "country": "BR",
    "name": "Presidente Prudente",
    "lat": "-22.12556",
    "lng": "-51.38889"
  },
  {
    "country": "BR",
    "name": "Presidente Olegário",
    "lat": "-18.41778",
    "lng": "-46.41806"
  },
  {
    "country": "BR",
    "name": "Presidente Epitácio",
    "lat": "-21.76333",
    "lng": "-52.11556"
  },
  {
    "country": "BR",
    "name": "Presidente Bernardes",
    "lat": "-22.00611",
    "lng": "-51.55306"
  },
  {
    "country": "BR",
    "name": "Prata",
    "lat": "-19.30722",
    "lng": "-48.92417"
  },
  {
    "country": "BR",
    "name": "Praia Grande",
    "lat": "-24.00583",
    "lng": "-46.40278"
  },
  {
    "country": "BR",
    "name": "Pradópolis",
    "lat": "-21.35944",
    "lng": "-48.06556"
  },
  {
    "country": "BR",
    "name": "Prado",
    "lat": "-17.34111",
    "lng": "-39.22083"
  },
  {
    "country": "BR",
    "name": "Poxoréo",
    "lat": "-15.83722",
    "lng": "-54.38917"
  },
  {
    "country": "BR",
    "name": "Pouso Alegre",
    "lat": "-22.23",
    "lng": "-45.93639"
  },
  {
    "country": "BR",
    "name": "Posse",
    "lat": "-14.09306",
    "lng": "-46.36944"
  },
  {
    "country": "BR",
    "name": "Porto União",
    "lat": "-26.23806",
    "lng": "-51.07833"
  },
  {
    "country": "BR",
    "name": "Porto Seguro",
    "lat": "-16.44972",
    "lng": "-39.06472"
  },
  {
    "country": "BR",
    "name": "Porto Real do Colégio",
    "lat": "-10.18583",
    "lng": "-36.84"
  },
  {
    "country": "BR",
    "name": "Porto Real",
    "lat": "-22.41972",
    "lng": "-44.29028"
  },
  {
    "country": "BR",
    "name": "Porto Murtinho",
    "lat": "-21.69889",
    "lng": "-57.8825"
  },
  {
    "country": "BR",
    "name": "Porto Ferreira",
    "lat": "-21.85389",
    "lng": "-47.47917"
  },
  {
    "country": "BR",
    "name": "Porto Feliz",
    "lat": "-23.21472",
    "lng": "-47.52389"
  },
  {
    "country": "BR",
    "name": "Porto Belo",
    "lat": "-27.15778",
    "lng": "-48.55306"
  },
  {
    "country": "BR",
    "name": "Pôrto Barra do Ivinheima",
    "lat": "-22.96667",
    "lng": "-53.66667"
  },
  {
    "country": "BR",
    "name": "Porto Alegre",
    "lat": "-30.03306",
    "lng": "-51.23"
  },
  {
    "country": "BR",
    "name": "Porteirinha",
    "lat": "-15.74333",
    "lng": "-43.02833"
  },
  {
    "country": "BR",
    "name": "Portão",
    "lat": "-29.70167",
    "lng": "-51.24194"
  },
  {
    "country": "BR",
    "name": "Porecatu",
    "lat": "-22.75583",
    "lng": "-51.37917"
  },
  {
    "country": "BR",
    "name": "Porciúncula",
    "lat": "-20.96278",
    "lng": "-42.04083"
  },
  {
    "country": "BR",
    "name": "Porangatu",
    "lat": "-13.44083",
    "lng": "-49.14861"
  },
  {
    "country": "BR",
    "name": "Porangaba",
    "lat": "-23.17583",
    "lng": "-48.125"
  },
  {
    "country": "BR",
    "name": "Ponto Novo",
    "lat": "-10.86278",
    "lng": "-40.13361"
  },
  {
    "country": "BR",
    "name": "Pontes e Lacerda",
    "lat": "-15.22611",
    "lng": "-59.33528"
  },
  {
    "country": "BR",
    "name": "Ponte Nova",
    "lat": "-20.41639",
    "lng": "-42.90861"
  },
  {
    "country": "BR",
    "name": "Ponta Porã",
    "lat": "-22.53611",
    "lng": "-55.72556"
  },
  {
    "country": "BR",
    "name": "Pontalina",
    "lat": "-17.525",
    "lng": "-49.44722"
  },
  {
    "country": "BR",
    "name": "Pontal",
    "lat": "-21.0225",
    "lng": "-48.03722"
  },
  {
    "country": "BR",
    "name": "Ponta Grossa",
    "lat": "-25.095",
    "lng": "-50.16194"
  },
  {
    "country": "BR",
    "name": "Pompéu",
    "lat": "-19.22444",
    "lng": "-44.93528"
  },
  {
    "country": "BR",
    "name": "Pompéia",
    "lat": "-22.10861",
    "lng": "-50.17167"
  },
  {
    "country": "BR",
    "name": "Pomerode",
    "lat": "-26.74056",
    "lng": "-49.17694"
  },
  {
    "country": "BR",
    "name": "Poço Verde",
    "lat": "-10.70833",
    "lng": "-38.18333"
  },
  {
    "country": "BR",
    "name": "Poços de Caldas",
    "lat": "-21.78778",
    "lng": "-46.56139"
  },
  {
    "country": "BR",
    "name": "Poconé",
    "lat": "-16.25667",
    "lng": "-56.62278"
  },
  {
    "country": "BR",
    "name": "Poções",
    "lat": "-14.52972",
    "lng": "-40.36528"
  },
  {
    "country": "BR",
    "name": "Poá",
    "lat": "-23.52806",
    "lng": "-46.34472"
  },
  {
    "country": "BR",
    "name": "Planaltina",
    "lat": "-15.45278",
    "lng": "-47.61417"
  },
  {
    "country": "BR",
    "name": "Piúma",
    "lat": "-20.83778",
    "lng": "-40.72194"
  },
  {
    "country": "BR",
    "name": "Piuí",
    "lat": "-20.46528",
    "lng": "-45.95806"
  },
  {
    "country": "BR",
    "name": "Pitangui",
    "lat": "-19.68278",
    "lng": "-44.89028"
  },
  {
    "country": "BR",
    "name": "Pitangueiras",
    "lat": "-21.00944",
    "lng": "-48.22167"
  },
  {
    "country": "BR",
    "name": "Pitanga",
    "lat": "-24.75722",
    "lng": "-51.76139"
  },
  {
    "country": "BR",
    "name": "Piritiba",
    "lat": "-11.73028",
    "lng": "-40.55528"
  },
  {
    "country": "BR",
    "name": "Pires do Rio",
    "lat": "-17.29972",
    "lng": "-48.27944"
  },
  {
    "country": "BR",
    "name": "Pirenópolis",
    "lat": "-15.85072",
    "lng": "-48.96087"
  },
  {
    "country": "BR",
    "name": "Piraquara",
    "lat": "-25.44227",
    "lng": "-49.06795"
  },
  {
    "country": "BR",
    "name": "Pirapozinho",
    "lat": "-22.27528",
    "lng": "-51.5"
  },
  {
    "country": "BR",
    "name": "Pirapora do Bom Jesus",
    "lat": "-23.39694",
    "lng": "-47.00222"
  },
  {
    "country": "BR",
    "name": "Pirapora",
    "lat": "-17.345",
    "lng": "-44.94194"
  },
  {
    "country": "BR",
    "name": "Piranhas",
    "lat": "-16.42694",
    "lng": "-51.82222"
  },
  {
    "country": "BR",
    "name": "Pirajuí",
    "lat": "-21.99861",
    "lng": "-49.45722"
  },
  {
    "country": "BR",
    "name": "Piraju",
    "lat": "-23.19361",
    "lng": "-49.38389"
  },
  {
    "country": "BR",
    "name": "Piraí do Sul",
    "lat": "-24.52611",
    "lng": "-49.94861"
  },
  {
    "country": "BR",
    "name": "Piraí",
    "lat": "-22.62917",
    "lng": "-43.89806"
  },
  {
    "country": "BR",
    "name": "Pirassununga",
    "lat": "-21.99611",
    "lng": "-47.42583"
  },
  {
    "country": "BR",
    "name": "Piracicaba",
    "lat": "-22.72528",
    "lng": "-47.64917"
  },
  {
    "country": "BR",
    "name": "Piracanjuba",
    "lat": "-17.30278",
    "lng": "-49.01667"
  },
  {
    "country": "BR",
    "name": "Piracaia",
    "lat": "-23.05389",
    "lng": "-46.35806"
  },
  {
    "country": "BR",
    "name": "Piquete",
    "lat": "-22.61361",
    "lng": "-45.17611"
  },
  {
    "country": "BR",
    "name": "Pinheiros",
    "lat": "-29.78333",
    "lng": "-52.73333"
  },
  {
    "country": "BR",
    "name": "Pinheiro Machado",
    "lat": "-31.57833",
    "lng": "-53.38111"
  },
  {
    "country": "BR",
    "name": "Pinheiral",
    "lat": "-22.51278",
    "lng": "-44.00056"
  },
  {
    "country": "BR",
    "name": "Pinhão",
    "lat": "-25.69556",
    "lng": "-51.65972"
  },
  {
    "country": "BR",
    "name": "Espírito Santo do Pinhal",
    "lat": "-22.11583",
    "lng": "-46.68278"
  },
  {
    "country": "BR",
    "name": "Pindorama",
    "lat": "-21.18583",
    "lng": "-48.90722"
  },
  {
    "country": "BR",
    "name": "Pindobaçu",
    "lat": "-10.74167",
    "lng": "-40.36083"
  },
  {
    "country": "BR",
    "name": "Pindamonhangaba",
    "lat": "-22.92389",
    "lng": "-45.46167"
  },
  {
    "country": "BR",
    "name": "Pilar do Sul",
    "lat": "-23.81306",
    "lng": "-47.71639"
  },
  {
    "country": "BR",
    "name": "Piedade",
    "lat": "-23.71194",
    "lng": "-47.42778"
  },
  {
    "country": "BR",
    "name": "Piaçabuçu",
    "lat": "-10.40556",
    "lng": "-36.43444"
  },
  {
    "country": "BR",
    "name": "Petrópolis",
    "lat": "-22.505",
    "lng": "-43.17861"
  },
  {
    "country": "BR",
    "name": "Petrolina de Goiás",
    "lat": "-16.095",
    "lng": "-49.33806"
  },
  {
    "country": "BR",
    "name": "Peruíbe",
    "lat": "-24.32",
    "lng": "-46.99833"
  },
  {
    "country": "BR",
    "name": "Pereira Barreto",
    "lat": "-20.63833",
    "lng": "-51.10917"
  },
  {
    "country": "BR",
    "name": "Perdões",
    "lat": "-21.09083",
    "lng": "-45.09139"
  },
  {
    "country": "BR",
    "name": "Penha",
    "lat": "-26.76944",
    "lng": "-48.64583"
  },
  {
    "country": "BR",
    "name": "Penedo",
    "lat": "-10.29028",
    "lng": "-36.58639"
  },
  {
    "country": "BR",
    "name": "Penápolis",
    "lat": "-21.41972",
    "lng": "-50.0775"
  },
  {
    "country": "BR",
    "name": "Pelotas",
    "lat": "-31.77194",
    "lng": "-52.3425"
  },
  {
    "country": "BR",
    "name": "Pedro Leopoldo",
    "lat": "-19.61806",
    "lng": "-44.04306"
  },
  {
    "country": "BR",
    "name": "Pedreira",
    "lat": "-22.74194",
    "lng": "-46.90139"
  },
  {
    "country": "BR",
    "name": "Pedregulho",
    "lat": "-20.25694",
    "lng": "-47.47667"
  },
  {
    "country": "BR",
    "name": "Pedra Azul",
    "lat": "-16.00528",
    "lng": "-41.29722"
  },
  {
    "country": "BR",
    "name": "Pederneiras",
    "lat": "-22.35167",
    "lng": "-48.775"
  },
  {
    "country": "BR",
    "name": "Peçanha",
    "lat": "-18.54861",
    "lng": "-42.55694"
  },
  {
    "country": "BR",
    "name": "Peabiru",
    "lat": "-23.91278",
    "lng": "-52.34306"
  },
  {
    "country": "BR",
    "name": "Paulínia",
    "lat": "-22.76111",
    "lng": "-47.15417"
  },
  {
    "country": "BR",
    "name": "Pau Brasil",
    "lat": "-15.46417",
    "lng": "-39.65111"
  },
  {
    "country": "BR",
    "name": "Patrocínio",
    "lat": "-18.94389",
    "lng": "-46.9925"
  },
  {
    "country": "BR",
    "name": "Patos de Minas",
    "lat": "-18.57889",
    "lng": "-46.51806"
  },
  {
    "country": "BR",
    "name": "Pato Branco",
    "lat": "-26.22861",
    "lng": "-52.67056"
  },
  {
    "country": "BR",
    "name": "Paty do Alferes",
    "lat": "-22.42861",
    "lng": "-43.41861"
  },
  {
    "country": "BR",
    "name": "Passos",
    "lat": "-20.71889",
    "lng": "-46.60972"
  },
  {
    "country": "BR",
    "name": "Passo Fundo",
    "lat": "-28.26278",
    "lng": "-52.40667"
  },
  {
    "country": "BR",
    "name": "Passa Quatro",
    "lat": "-22.39028",
    "lng": "-44.96667"
  },
  {
    "country": "BR",
    "name": "Parobé",
    "lat": "-29.62861",
    "lng": "-50.83472"
  },
  {
    "country": "BR",
    "name": "Pariquera Açu",
    "lat": "-24.715",
    "lng": "-47.88111"
  },
  {
    "country": "BR",
    "name": "Paripiranga",
    "lat": "-10.6875",
    "lng": "-37.86167"
  },
  {
    "country": "BR",
    "name": "Paraúna",
    "lat": "-16.94778",
    "lng": "-50.44861"
  },
  {
    "country": "BR",
    "name": "Paratinga",
    "lat": "-12.69056",
    "lng": "-43.18417"
  },
  {
    "country": "BR",
    "name": "Paraty",
    "lat": "-23.21778",
    "lng": "-44.71306"
  },
  {
    "country": "BR",
    "name": "Paranhos",
    "lat": "-23.89278",
    "lng": "-55.43111"
  },
  {
    "country": "BR",
    "name": "Paranavaí",
    "lat": "-23.07306",
    "lng": "-52.46528"
  },
  {
    "country": "BR",
    "name": "Paranapanema",
    "lat": "-23.3863",
    "lng": "-48.72441"
  },
  {
    "country": "BR",
    "name": "Paranaíba",
    "lat": "-19.67722",
    "lng": "-51.19083"
  },
  {
    "country": "BR",
    "name": "Paranaguá",
    "lat": "-25.51626",
    "lng": "-48.52537"
  },
  {
    "country": "BR",
    "name": "Paramirim",
    "lat": "-13.4425",
    "lng": "-42.23889"
  },
  {
    "country": "BR",
    "name": "Paraisópolis",
    "lat": "-22.55417",
    "lng": "-45.78"
  },
  {
    "country": "BR",
    "name": "Paraíso",
    "lat": "-21.01639",
    "lng": "-48.77361"
  },
  {
    "country": "BR",
    "name": "Paraíso das Águas",
    "lat": "-19.0175",
    "lng": "-53.01222"
  },
  {
    "country": "BR",
    "name": "Paraíba do Sul",
    "lat": "-22.15847",
    "lng": "-43.29321"
  },
  {
    "country": "BR",
    "name": "Paraguaçu Paulista",
    "lat": "-22.41278",
    "lng": "-50.57583"
  },
  {
    "country": "BR",
    "name": "Paraguaçu",
    "lat": "-21.54722",
    "lng": "-45.7375"
  },
  {
    "country": "BR",
    "name": "Pará de Minas",
    "lat": "-19.86028",
    "lng": "-44.60833"
  },
  {
    "country": "BR",
    "name": "Paracatu",
    "lat": "-17.22222",
    "lng": "-46.87472"
  },
  {
    "country": "BR",
    "name": "Paracambi",
    "lat": "-22.60829",
    "lng": "-43.7084"
  },
  {
    "country": "BR",
    "name": "Papagaios",
    "lat": "-19.44917",
    "lng": "-44.74778"
  },
  {
    "country": "BR",
    "name": "Pantano do Sul",
    "lat": "-27.77972",
    "lng": "-48.50861"
  },
  {
    "country": "BR",
    "name": "Panorama",
    "lat": "-21.35639",
    "lng": "-51.85972"
  },
  {
    "country": "BR",
    "name": "Pancas",
    "lat": "-19.225",
    "lng": "-40.85139"
  },
  {
    "country": "BR",
    "name": "Panambi",
    "lat": "-28.2925",
    "lng": "-53.50167"
  },
  {
    "country": "BR",
    "name": "Palotina",
    "lat": "-24.28389",
    "lng": "-53.84"
  },
  {
    "country": "BR",
    "name": "Palmital",
    "lat": "-22.78889",
    "lng": "-50.2175"
  },
  {
    "country": "BR",
    "name": "Palmeiras de Goiás",
    "lat": "-16.805",
    "lng": "-49.92583"
  },
  {
    "country": "BR",
    "name": "Palmeira das Missões",
    "lat": "-27.89944",
    "lng": "-53.31361"
  },
  {
    "country": "BR",
    "name": "Palmeira",
    "lat": "-25.42944",
    "lng": "-50.00639"
  },
  {
    "country": "BR",
    "name": "Palmas de Monte Alto",
    "lat": "-14.26722",
    "lng": "-43.16194"
  },
  {
    "country": "BR",
    "name": "Palmas",
    "lat": "-26.48417",
    "lng": "-51.99056"
  },
  {
    "country": "BR",
    "name": "Palmares do Sul",
    "lat": "-30.25778",
    "lng": "-50.50972"
  },
  {
    "country": "BR",
    "name": "Palhoça",
    "lat": "-27.64528",
    "lng": "-48.66778"
  },
  {
    "country": "BR",
    "name": "Paiçandu",
    "lat": "-23.4575",
    "lng": "-52.04861"
  },
  {
    "country": "BR",
    "name": "Padre Paraíso",
    "lat": "-17.07417",
    "lng": "-41.48444"
  },
  {
    "country": "BR",
    "name": "Padre Bernardo",
    "lat": "-15.16595",
    "lng": "-48.28281"
  },
  {
    "country": "BR",
    "name": "Pacatuba",
    "lat": "-10.45333",
    "lng": "-36.65139"
  },
  {
    "country": "BR",
    "name": "Pacaembu",
    "lat": "-21.56222",
    "lng": "-51.26056"
  },
  {
    "country": "BR",
    "name": "Ouro Preto",
    "lat": "-20.39484",
    "lng": "-43.50517"
  },
  {
    "country": "BR",
    "name": "Ouro Branco",
    "lat": "-20.52334",
    "lng": "-43.69486"
  },
  {
    "country": "BR",
    "name": "Ourinhos",
    "lat": "-22.97889",
    "lng": "-49.87056"
  },
  {
    "country": "BR",
    "name": "Otacílio Costa",
    "lat": "-27.48306",
    "lng": "-50.12194"
  },
  {
    "country": "BR",
    "name": "Osvaldo Cruz",
    "lat": "-21.79667",
    "lng": "-50.87861"
  },
  {
    "country": "BR",
    "name": "Osório",
    "lat": "-29.88667",
    "lng": "-50.26972"
  },
  {
    "country": "BR",
    "name": "Osasco",
    "lat": "-23.5325",
    "lng": "-46.79167"
  },
  {
    "country": "BR",
    "name": "Ortigueira",
    "lat": "-24.20833",
    "lng": "-50.94944"
  },
  {
    "country": "BR",
    "name": "Orleans",
    "lat": "-28.35889",
    "lng": "-49.29139"
  },
  {
    "country": "BR",
    "name": "Orlândia",
    "lat": "-20.72028",
    "lng": "-47.88667"
  },
  {
    "country": "BR",
    "name": "Orizona",
    "lat": "-17.03139",
    "lng": "-48.29583"
  },
  {
    "country": "BR",
    "name": "Oliveira dos Brejinhos",
    "lat": "-12.31694",
    "lng": "-42.89611"
  },
  {
    "country": "BR",
    "name": "Oliveira",
    "lat": "-20.69639",
    "lng": "-44.82722"
  },
  {
    "country": "BR",
    "name": "Olindina",
    "lat": "-11.36667",
    "lng": "-38.33333"
  },
  {
    "country": "BR",
    "name": "Olímpia",
    "lat": "-20.73722",
    "lng": "-48.91472"
  },
  {
    "country": "BR",
    "name": "Nuporanga",
    "lat": "-20.73095",
    "lng": "-47.75177"
  },
  {
    "country": "BR",
    "name": "Novo Horizonte",
    "lat": "-21.46806",
    "lng": "-49.22083"
  },
  {
    "country": "BR",
    "name": "Novo Hamburgo",
    "lat": "-29.67833",
    "lng": "-51.13056"
  },
  {
    "country": "BR",
    "name": "Novo Cruzeiro",
    "lat": "-17.46806",
    "lng": "-41.87528"
  },
  {
    "country": "BR",
    "name": "Nova Viçosa",
    "lat": "-17.89194",
    "lng": "-39.37194"
  },
  {
    "country": "BR",
    "name": "Nova Venécia",
    "lat": "-18.71056",
    "lng": "-40.40056"
  },
  {
    "country": "BR",
    "name": "Nova Soure",
    "lat": "-11.23333",
    "lng": "-38.48333"
  },
  {
    "country": "BR",
    "name": "Nova Prata",
    "lat": "-28.78389",
    "lng": "-51.61"
  },
  {
    "country": "BR",
    "name": "Nova Petrópolis",
    "lat": "-29.37639",
    "lng": "-51.11444"
  },
  {
    "country": "BR",
    "name": "Nova Olímpia",
    "lat": "-14.79722",
    "lng": "-57.28806"
  },
  {
    "country": "BR",
    "name": "Nova Odessa",
    "lat": "-22.7775",
    "lng": "-47.29583"
  },
  {
    "country": "BR",
    "name": "Nova Londrina",
    "lat": "-22.76583",
    "lng": "-52.985"
  },
  {
    "country": "BR",
    "name": "Nova Lima",
    "lat": "-19.98556",
    "lng": "-43.84667"
  },
  {
    "country": "BR",
    "name": "Nova Iguaçu",
    "lat": "-22.75917",
    "lng": "-43.45111"
  },
  {
    "country": "BR",
    "name": "Nova Granada",
    "lat": "-20.53389",
    "lng": "-49.31417"
  },
  {
    "country": "BR",
    "name": "Nova Friburgo",
    "lat": "-22.28194",
    "lng": "-42.53111"
  },
  {
    "country": "BR",
    "name": "Nova Era",
    "lat": "-19.75",
    "lng": "-43.0375"
  },
  {
    "country": "BR",
    "name": "Nova Aurora",
    "lat": "-22.86667",
    "lng": "-52.56667"
  },
  {
    "country": "BR",
    "name": "Nossa Senhora do Socorro",
    "lat": "-10.855",
    "lng": "-37.12611"
  },
  {
    "country": "BR",
    "name": "Nossa Senhora das Dores",
    "lat": "-10.49167",
    "lng": "-37.19333"
  },
  {
    "country": "BR",
    "name": "Nossa Senhora da Glória",
    "lat": "-10.21833",
    "lng": "-37.42028"
  },
  {
    "country": "BR",
    "name": "Nortelândia",
    "lat": "-14.45472",
    "lng": "-56.80278"
  },
  {
    "country": "BR",
    "name": "Nobres",
    "lat": "-14.72028",
    "lng": "-56.3275"
  },
  {
    "country": "BR",
    "name": "Niterói",
    "lat": "-22.88333",
    "lng": "-43.10361"
  },
  {
    "country": "BR",
    "name": "Niquelândia",
    "lat": "-14.47389",
    "lng": "-48.45972"
  },
  {
    "country": "BR",
    "name": "Nilópolis",
    "lat": "-22.8075",
    "lng": "-43.41389"
  },
  {
    "country": "BR",
    "name": "Nhandeara",
    "lat": "-20.6897",
    "lng": "-50.0407"
  },
  {
    "country": "BR",
    "name": "Nerópolis",
    "lat": "-16.40639",
    "lng": "-49.21861"
  },
  {
    "country": "BR",
    "name": "Nepomuceno",
    "lat": "-21.23342",
    "lng": "-45.23488"
  },
  {
    "country": "BR",
    "name": "Neópolis",
    "lat": "-10.32",
    "lng": "-36.57944"
  },
  {
    "country": "BR",
    "name": "Nazaré",
    "lat": "-13.035",
    "lng": "-39.01444"
  },
  {
    "country": "BR",
    "name": "Naviraí",
    "lat": "-23.065",
    "lng": "-54.19056"
  },
  {
    "country": "BR",
    "name": "Navegantes",
    "lat": "-26.89889",
    "lng": "-48.65417"
  },
  {
    "country": "BR",
    "name": "Natividade",
    "lat": "-21.04222",
    "lng": "-41.97333"
  },
  {
    "country": "BR",
    "name": "Não Me Toque",
    "lat": "-28.45917",
    "lng": "-52.82083"
  },
  {
    "country": "BR",
    "name": "Nanuque",
    "lat": "-17.83917",
    "lng": "-40.35389"
  },
  {
    "country": "BR",
    "name": "Muzambinho",
    "lat": "-21.37583",
    "lng": "-46.52556"
  },
  {
    "country": "BR",
    "name": "Mutum",
    "lat": "-19.8",
    "lng": "-41.43833"
  },
  {
    "country": "BR",
    "name": "Mutuípe",
    "lat": "-13.22861",
    "lng": "-39.50472"
  },
  {
    "country": "BR",
    "name": "Muritiba",
    "lat": "-12.91667",
    "lng": "-39.25"
  },
  {
    "country": "BR",
    "name": "Muriaé",
    "lat": "-21.13056",
    "lng": "-42.36639"
  },
  {
    "country": "BR",
    "name": "Muniz Freire",
    "lat": "-20.46417",
    "lng": "-41.41306"
  },
  {
    "country": "BR",
    "name": "Mundo Novo",
    "lat": "-11.85889",
    "lng": "-40.4725"
  },
  {
    "country": "BR",
    "name": "Mucurici",
    "lat": "-18.09333",
    "lng": "-40.51583"
  },
  {
    "country": "BR",
    "name": "Mucuri",
    "lat": "-18.08639",
    "lng": "-39.55083"
  },
  {
    "country": "BR",
    "name": "Mozarlândia",
    "lat": "-14.74472",
    "lng": "-50.57056"
  },
  {
    "country": "BR",
    "name": "Morro do Chapéu",
    "lat": "-11.54852",
    "lng": "-41.15804"
  },
  {
    "country": "BR",
    "name": "Morro da Fumaça",
    "lat": "-28.65083",
    "lng": "-49.21"
  },
  {
    "country": "BR",
    "name": "Morro Agudo",
    "lat": "-20.73139",
    "lng": "-48.05778"
  },
  {
    "country": "BR",
    "name": "Morrinhos",
    "lat": "-17.73111",
    "lng": "-49.09944"
  },
  {
    "country": "BR",
    "name": "Moreira Sales",
    "lat": "-24.06222",
    "lng": "-53.00694"
  },
  {
    "country": "BR",
    "name": "Monte Sião",
    "lat": "-22.4325",
    "lng": "-46.5725"
  },
  {
    "country": "BR",
    "name": "Montes Claros",
    "lat": "-16.735",
    "lng": "-43.86167"
  },
  {
    "country": "BR",
    "name": "Monte Santo de Minas",
    "lat": "-21.18972",
    "lng": "-46.98028"
  },
  {
    "country": "BR",
    "name": "Monte Santo",
    "lat": "-10.43778",
    "lng": "-39.33278"
  },
  {
    "country": "BR",
    "name": "Montenegro",
    "lat": "-29.68861",
    "lng": "-51.46111"
  },
  {
    "country": "BR",
    "name": "Monte Mor",
    "lat": "-22.94667",
    "lng": "-47.31583"
  },
  {
    "country": "BR",
    "name": "Monte Carmelo",
    "lat": "-18.72472",
    "lng": "-47.49861"
  },
  {
    "country": "BR",
    "name": "Monte Azul Paulista",
    "lat": "-20.90722",
    "lng": "-48.64139"
  },
  {
    "country": "BR",
    "name": "Monte Azul",
    "lat": "-15.155",
    "lng": "-42.87472"
  },
  {
    "country": "BR",
    "name": "Monte Aprazível",
    "lat": "-20.7725",
    "lng": "-49.71417"
  },
  {
    "country": "BR",
    "name": "Monte Alto",
    "lat": "-21.26111",
    "lng": "-48.49639"
  },
  {
    "country": "BR",
    "name": "Monte Alegre de Sergipe",
    "lat": "-10.02722",
    "lng": "-37.56222"
  },
  {
    "country": "BR",
    "name": "Monte Alegre de Minas",
    "lat": "-18.87056",
    "lng": "-48.88083"
  },
  {
    "country": "BR",
    "name": "Montanha",
    "lat": "-18.12694",
    "lng": "-40.36333"
  },
  {
    "country": "BR",
    "name": "Mongaguá",
    "lat": "-24.09306",
    "lng": "-46.62083"
  },
  {
    "country": "BR",
    "name": "Moita Bonita",
    "lat": "-10.5775",
    "lng": "-37.34278"
  },
  {
    "country": "BR",
    "name": "Mogi Mirim",
    "lat": "-22.43194",
    "lng": "-46.95778"
  },
  {
    "country": "BR",
    "name": "Mogi Guaçu",
    "lat": "-22.3677",
    "lng": "-46.94552"
  },
  {
    "country": "BR",
    "name": "Mogi das Cruzes",
    "lat": "-23.52278",
    "lng": "-46.18833"
  },
  {
    "country": "BR",
    "name": "Mococa",
    "lat": "-21.46778",
    "lng": "-47.00472"
  },
  {
    "country": "BR",
    "name": "Mirante do Paranapanema",
    "lat": "-22.29194",
    "lng": "-51.90639"
  },
  {
    "country": "BR",
    "name": "Mirandopólis",
    "lat": "-21.13361",
    "lng": "-51.10167"
  },
  {
    "country": "BR",
    "name": "Miranda",
    "lat": "-20.24056",
    "lng": "-56.37833"
  },
  {
    "country": "BR",
    "name": "Miraí",
    "lat": "-21.19528",
    "lng": "-42.61417"
  },
  {
    "country": "BR",
    "name": "Miracema",
    "lat": "-21.41222",
    "lng": "-42.19667"
  },
  {
    "country": "BR",
    "name": "Miracatu",
    "lat": "-24.28139",
    "lng": "-47.45972"
  },
  {
    "country": "BR",
    "name": "Mirabela",
    "lat": "-16.26278",
    "lng": "-44.16444"
  },
  {
    "country": "BR",
    "name": "Mineiros",
    "lat": "-17.56944",
    "lng": "-52.55111"
  },
  {
    "country": "BR",
    "name": "Minas Novas",
    "lat": "-17.21861",
    "lng": "-42.59028"
  },
  {
    "country": "BR",
    "name": "Mimoso do Sul",
    "lat": "-21.06417",
    "lng": "-41.36639"
  },
  {
    "country": "BR",
    "name": "Miguel Pereira",
    "lat": "-22.45389",
    "lng": "-43.46889"
  },
  {
    "country": "BR",
    "name": "Miguelópolis",
    "lat": "-20.17944",
    "lng": "-48.03194"
  },
  {
    "country": "BR",
    "name": "Miguel Calmon",
    "lat": "-11.42889",
    "lng": "-40.595"
  },
  {
    "country": "BR",
    "name": "Mendes",
    "lat": "-22.52667",
    "lng": "-43.73278"
  },
  {
    "country": "BR",
    "name": "Medina",
    "lat": "-16.2225",
    "lng": "-41.47694"
  },
  {
    "country": "BR",
    "name": "Medianeira",
    "lat": "-25.29528",
    "lng": "-54.09389"
  },
  {
    "country": "BR",
    "name": "Medeiros Neto",
    "lat": "-17.37389",
    "lng": "-40.22056"
  },
  {
    "country": "BR",
    "name": "Mauá",
    "lat": "-23.66778",
    "lng": "-46.46139"
  },
  {
    "country": "BR",
    "name": "Matozinhos",
    "lat": "-19.55778",
    "lng": "-44.08139"
  },
  {
    "country": "BR",
    "name": "Mato Verde",
    "lat": "-15.39722",
    "lng": "-42.86639"
  },
  {
    "country": "BR",
    "name": "Matipó",
    "lat": "-20.28389",
    "lng": "-42.34111"
  },
  {
    "country": "BR",
    "name": "Matias Barbosa",
    "lat": "-21.86917",
    "lng": "-43.31944"
  },
  {
    "country": "BR",
    "name": "Mateus Leme",
    "lat": "-19.98639",
    "lng": "-44.42778"
  },
  {
    "country": "BR",
    "name": "Matelândia",
    "lat": "-25.24083",
    "lng": "-53.99639"
  },
  {
    "country": "BR",
    "name": "Matão",
    "lat": "-21.60333",
    "lng": "-48.36583"
  },
  {
    "country": "BR",
    "name": "Mata de São João",
    "lat": "-12.53028",
    "lng": "-38.29917"
  },
  {
    "country": "BR",
    "name": "Mascote",
    "lat": "-15.56306",
    "lng": "-39.3025"
  },
  {
    "country": "BR",
    "name": "Maruim",
    "lat": "-10.7375",
    "lng": "-37.08167"
  },
  {
    "country": "BR",
    "name": "Martinópolis",
    "lat": "-22.14583",
    "lng": "-51.17083"
  },
  {
    "country": "BR",
    "name": "Martinho Campos",
    "lat": "-19.33167",
    "lng": "-45.23694"
  },
  {
    "country": "BR",
    "name": "Maringá",
    "lat": "-23.42528",
    "lng": "-51.93861"
  },
  {
    "country": "BR",
    "name": "Marília",
    "lat": "-22.21389",
    "lng": "-49.94583"
  },
  {
    "country": "BR",
    "name": "Marilândia",
    "lat": "-19.41278",
    "lng": "-40.54167"
  },
  {
    "country": "BR",
    "name": "Maricá",
    "lat": "-22.91944",
    "lng": "-42.81861"
  },
  {
    "country": "BR",
    "name": "Mariana",
    "lat": "-20.37778",
    "lng": "-43.41611"
  },
  {
    "country": "BR",
    "name": "Marialva",
    "lat": "-23.485",
    "lng": "-51.79167"
  },
  {
    "country": "BR",
    "name": "Marechal Floriano",
    "lat": "-20.41278",
    "lng": "-40.68306"
  },
  {
    "country": "BR",
    "name": "Marechal Cândido Rondon",
    "lat": "-24.55611",
    "lng": "-54.05667"
  },
  {
    "country": "BR",
    "name": "Mar de Espanha",
    "lat": "-21.86722",
    "lng": "-43.00972"
  },
  {
    "country": "BR",
    "name": "Marau",
    "lat": "-28.44917",
    "lng": "-52.2"
  },
  {
    "country": "BR",
    "name": "Maraú",
    "lat": "-14.10395",
    "lng": "-39.0149"
  },
  {
    "country": "BR",
    "name": "Marataizes",
    "lat": "-21.04333",
    "lng": "-40.82444"
  },
  {
    "country": "BR",
    "name": "Maragogipe",
    "lat": "-12.77778",
    "lng": "-38.91944"
  },
  {
    "country": "BR",
    "name": "Maracás",
    "lat": "-13.44111",
    "lng": "-40.43083"
  },
  {
    "country": "BR",
    "name": "Maracaju",
    "lat": "-21.61444",
    "lng": "-55.16833"
  },
  {
    "country": "BR",
    "name": "Maracaí",
    "lat": "-22.61056",
    "lng": "-50.66722"
  },
  {
    "country": "BR",
    "name": "Mantenópolis",
    "lat": "-18.8625",
    "lng": "-41.12278"
  },
  {
    "country": "BR",
    "name": "Manhumirim",
    "lat": "-20.35778",
    "lng": "-41.95806"
  },
  {
    "country": "BR",
    "name": "Manhuaçu",
    "lat": "-20.25806",
    "lng": "-42.03361"
  },
  {
    "country": "BR",
    "name": "Mangaratiba",
    "lat": "-22.95972",
    "lng": "-44.04056"
  },
  {
    "country": "BR",
    "name": "Manga",
    "lat": "-14.75583",
    "lng": "-43.93222"
  },
  {
    "country": "BR",
    "name": "Mandaguari",
    "lat": "-23.5475",
    "lng": "-51.67083"
  },
  {
    "country": "BR",
    "name": "Mandaguaçu",
    "lat": "-23.34722",
    "lng": "-52.09528"
  },
  {
    "country": "BR",
    "name": "Malhador",
    "lat": "-10.65778",
    "lng": "-37.30472"
  },
  {
    "country": "BR",
    "name": "Malacacheta",
    "lat": "-17.84222",
    "lng": "-42.07667"
  },
  {
    "country": "BR",
    "name": "Mairiporã",
    "lat": "-23.31861",
    "lng": "-46.58667"
  },
  {
    "country": "BR",
    "name": "Mairinque",
    "lat": "-23.54583",
    "lng": "-47.18333"
  },
  {
    "country": "BR",
    "name": "Mairi",
    "lat": "-11.71139",
    "lng": "-40.14889"
  },
  {
    "country": "BR",
    "name": "Mafra",
    "lat": "-26.11139",
    "lng": "-49.80528"
  },
  {
    "country": "BR",
    "name": "Madre de Deus",
    "lat": "-12.74083",
    "lng": "-38.62083"
  },
  {
    "country": "BR",
    "name": "Machado",
    "lat": "-21.67472",
    "lng": "-45.91972"
  },
  {
    "country": "BR",
    "name": "Macaúbas",
    "lat": "-13.01944",
    "lng": "-42.69861"
  },
  {
    "country": "BR",
    "name": "Macatuba",
    "lat": "-22.50222",
    "lng": "-48.71139"
  },
  {
    "country": "BR",
    "name": "Macaé",
    "lat": "-22.38484",
    "lng": "-41.78324"
  },
  {
    "country": "BR",
    "name": "Luziânia",
    "lat": "-16.2525",
    "lng": "-47.95028"
  },
  {
    "country": "BR",
    "name": "Luz",
    "lat": "-19.80139",
    "lng": "-45.68556"
  },
  {
    "country": "BR",
    "name": "Lucélia",
    "lat": "-21.72028",
    "lng": "-51.01889"
  },
  {
    "country": "BR",
    "name": "Lucas",
    "lat": "-16.33333",
    "lng": "-55.93333"
  },
  {
    "country": "BR",
    "name": "Louveira",
    "lat": "-23.08639",
    "lng": "-46.95056"
  },
  {
    "country": "BR",
    "name": "Lorena",
    "lat": "-22.73083",
    "lng": "-45.12472"
  },
  {
    "country": "BR",
    "name": "Londrina",
    "lat": "-23.31028",
    "lng": "-51.16278"
  },
  {
    "country": "BR",
    "name": "Loanda",
    "lat": "-22.92306",
    "lng": "-53.13722"
  },
  {
    "country": "BR",
    "name": "Livramento do Brumado",
    "lat": "-13.65145",
    "lng": "-41.84564"
  },
  {
    "country": "BR",
    "name": "Lins",
    "lat": "-21.67861",
    "lng": "-49.7425"
  },
  {
    "country": "BR",
    "name": "Linhares",
    "lat": "-19.39111",
    "lng": "-40.07222"
  },
  {
    "country": "BR",
    "name": "Limeira",
    "lat": "-22.56472",
    "lng": "-47.40167"
  },
  {
    "country": "BR",
    "name": "Lima Duarte",
    "lat": "-21.8425",
    "lng": "-43.79306"
  },
  {
    "country": "BR",
    "name": "Leopoldina",
    "lat": "-21.53194",
    "lng": "-42.64306"
  },
  {
    "country": "BR",
    "name": "Lençóis Paulista",
    "lat": "-22.59861",
    "lng": "-48.80028"
  },
  {
    "country": "BR",
    "name": "Leme",
    "lat": "-22.18556",
    "lng": "-47.39028"
  },
  {
    "country": "BR",
    "name": "Lavras",
    "lat": "-21.24528",
    "lng": "-44.99972"
  },
  {
    "country": "BR",
    "name": "Lauro Muller",
    "lat": "-28.39278",
    "lng": "-49.39667"
  },
  {
    "country": "BR",
    "name": "Laranjeiras do Sul",
    "lat": "-25.40778",
    "lng": "-52.41611"
  },
  {
    "country": "BR",
    "name": "Laranjeiras",
    "lat": "-10.80639",
    "lng": "-37.17"
  },
  {
    "country": "BR",
    "name": "Laranjal Paulista",
    "lat": "-23.04972",
    "lng": "-47.83667"
  },
  {
    "country": "BR",
    "name": "Laranja da Terra",
    "lat": "-19.89889",
    "lng": "-41.05667"
  },
  {
    "country": "BR",
    "name": "Lapão",
    "lat": "-11.38333",
    "lng": "-41.83194"
  },
  {
    "country": "BR",
    "name": "Lapa",
    "lat": "-25.76972",
    "lng": "-49.71583"
  },
  {
    "country": "BR",
    "name": "Lambari",
    "lat": "-21.97556",
    "lng": "-45.35028"
  },
  {
    "country": "BR",
    "name": "Lajinha",
    "lat": "-20.15139",
    "lng": "-41.62278"
  },
  {
    "country": "BR",
    "name": "Lages",
    "lat": "-27.81611",
    "lng": "-50.32611"
  },
  {
    "country": "BR",
    "name": "Lajeado",
    "lat": "-29.46694",
    "lng": "-51.96139"
  },
  {
    "country": "BR",
    "name": "Laje",
    "lat": "-10.18708",
    "lng": "-40.97076"
  },
  {
    "country": "BR",
    "name": "Laguna",
    "lat": "-28.4825",
    "lng": "-48.78083"
  },
  {
    "country": "BR",
    "name": "Lagoa Vermelha",
    "lat": "-28.20861",
    "lng": "-51.52583"
  },
  {
    "country": "BR",
    "name": "Lagoa Santa",
    "lat": "-19.63006",
    "lng": "-43.9009"
  },
  {
    "country": "BR",
    "name": "Lagoa Formosa",
    "lat": "-18.77861",
    "lng": "-46.4075"
  },
  {
    "country": "BR",
    "name": "Lagoa da Prata",
    "lat": "-20.0225",
    "lng": "-45.54361"
  },
  {
    "country": "BR",
    "name": "Lagoa",
    "lat": "-27.60491",
    "lng": "-48.46713"
  },
  {
    "country": "BR",
    "name": "Lagarto",
    "lat": "-10.91722",
    "lng": "-37.65"
  },
  {
    "country": "BR",
    "name": "Ladário",
    "lat": "-19.00472",
    "lng": "-57.60167"
  },
  {
    "country": "BR",
    "name": "Juquitiba",
    "lat": "-23.93167",
    "lng": "-47.06833"
  },
  {
    "country": "BR",
    "name": "Juquiá",
    "lat": "-24.32083",
    "lng": "-47.63472"
  },
  {
    "country": "BR",
    "name": "Junqueirópolis",
    "lat": "-21.51472",
    "lng": "-51.43361"
  },
  {
    "country": "BR",
    "name": "Jundiaí",
    "lat": "-23.18639",
    "lng": "-46.88417"
  },
  {
    "country": "BR",
    "name": "Júlio de Castilhos",
    "lat": "-29.22694",
    "lng": "-53.68167"
  },
  {
    "country": "BR",
    "name": "Juiz de Fora",
    "lat": "-21.76417",
    "lng": "-43.35028"
  },
  {
    "country": "BR",
    "name": "Juatuba",
    "lat": "-19.95194",
    "lng": "-44.34278"
  },
  {
    "country": "BR",
    "name": "José Bonifácio",
    "lat": "-21.05278",
    "lng": "-49.68833"
  },
  {
    "country": "BR",
    "name": "Joinville",
    "lat": "-26.30444",
    "lng": "-48.84556"
  },
  {
    "country": "BR",
    "name": "João Pinheiro",
    "lat": "-17.7425",
    "lng": "-46.1725"
  },
  {
    "country": "BR",
    "name": "João Neiva",
    "lat": "-19.7575",
    "lng": "-40.38556"
  },
  {
    "country": "BR",
    "name": "João Monlevade",
    "lat": "-19.81",
    "lng": "-43.17361"
  },
  {
    "country": "BR",
    "name": "Joanópolis",
    "lat": "-22.93028",
    "lng": "-46.27556"
  },
  {
    "country": "BR",
    "name": "Joaíma",
    "lat": "-16.65417",
    "lng": "-41.03056"
  },
  {
    "country": "BR",
    "name": "Joaçaba",
    "lat": "-27.17806",
    "lng": "-51.50472"
  },
  {
    "country": "BR",
    "name": "Jitaúna",
    "lat": "-14.01274",
    "lng": "-39.89833"
  },
  {
    "country": "BR",
    "name": "Jetibá",
    "lat": "-20.02069",
    "lng": "-40.68145"
  },
  {
    "country": "BR",
    "name": "Jerônimo Monteiro",
    "lat": "-20.78944",
    "lng": "-41.395"
  },
  {
    "country": "BR",
    "name": "Jeremoabo",
    "lat": "-10.075",
    "lng": "-38.48083"
  },
  {
    "country": "BR",
    "name": "Jequitinhonha",
    "lat": "-16.43389",
    "lng": "-41.00333"
  },
  {
    "country": "BR",
    "name": "Jequié",
    "lat": "-13.85875",
    "lng": "-40.08512"
  },
  {
    "country": "BR",
    "name": "Jaú",
    "lat": "-22.29639",
    "lng": "-48.55778"
  },
  {
    "country": "BR",
    "name": "Jataizinho",
    "lat": "-23.25417",
    "lng": "-50.98"
  },
  {
    "country": "BR",
    "name": "Jataí",
    "lat": "-17.87939",
    "lng": "-51.72166"
  },
  {
    "country": "BR",
    "name": "Jarinu",
    "lat": "-23.10139",
    "lng": "-46.72833"
  },
  {
    "country": "BR",
    "name": "Jardinópolis",
    "lat": "-21.01778",
    "lng": "-47.76389"
  },
  {
    "country": "BR",
    "name": "Jardim",
    "lat": "-21.48028",
    "lng": "-56.13806"
  },
  {
    "country": "BR",
    "name": "Jaraguá do Sul",
    "lat": "-26.48611",
    "lng": "-49.06667"
  },
  {
    "country": "BR",
    "name": "Jaraguá",
    "lat": "-15.75694",
    "lng": "-49.33444"
  },
  {
    "country": "BR",
    "name": "Japoatã",
    "lat": "-10.34667",
    "lng": "-36.80111"
  },
  {
    "country": "BR",
    "name": "Japeri",
    "lat": "-22.64306",
    "lng": "-43.65333"
  },
  {
    "country": "BR",
    "name": "Japaratuba",
    "lat": "-10.59333",
    "lng": "-36.94028"
  },
  {
    "country": "BR",
    "name": "Januária",
    "lat": "-15.48866",
    "lng": "-44.35988"
  },
  {
    "country": "BR",
    "name": "Jandira",
    "lat": "-23.5275",
    "lng": "-46.9025"
  },
  {
    "country": "BR",
    "name": "Jandaia do Sul",
    "lat": "-23.60306",
    "lng": "-51.64333"
  },
  {
    "country": "BR",
    "name": "Janaúba",
    "lat": "-15.8025",
    "lng": "-43.30889"
  },
  {
    "country": "BR",
    "name": "Jales",
    "lat": "-20.26889",
    "lng": "-50.54583"
  },
  {
    "country": "BR",
    "name": "Jaguaruna",
    "lat": "-28.62145",
    "lng": "-49.02529"
  },
  {
    "country": "BR",
    "name": "Jaguariúna",
    "lat": "-22.70556",
    "lng": "-46.98583"
  },
  {
    "country": "BR",
    "name": "Jaguariaíva",
    "lat": "-24.24423",
    "lng": "-49.70932"
  },
  {
    "country": "BR",
    "name": "Jaguarari",
    "lat": "-10.26389",
    "lng": "-40.19583"
  },
  {
    "country": "BR",
    "name": "Jaguarão",
    "lat": "-32.56611",
    "lng": "-53.37583"
  },
  {
    "country": "BR",
    "name": "Jaguaquara",
    "lat": "-13.53056",
    "lng": "-39.97083"
  },
  {
    "country": "BR",
    "name": "Jacutinga",
    "lat": "-22.28556",
    "lng": "-46.61222"
  },
  {
    "country": "BR",
    "name": "Jacupiranga",
    "lat": "-24.6925",
    "lng": "-48.00222"
  },
  {
    "country": "BR",
    "name": "Jacobina",
    "lat": "-11.18143",
    "lng": "-40.51372"
  },
  {
    "country": "BR",
    "name": "Jaciara",
    "lat": "-15.96528",
    "lng": "-54.96833"
  },
  {
    "country": "BR",
    "name": "Jacarezinho",
    "lat": "-23.16056",
    "lng": "-49.96944"
  },
  {
    "country": "BR",
    "name": "Jacareí",
    "lat": "-23.30528",
    "lng": "-45.96583"
  },
  {
    "country": "BR",
    "name": "Jaboticabal",
    "lat": "-21.25472",
    "lng": "-48.32222"
  },
  {
    "country": "BR",
    "name": "Ivoti",
    "lat": "-29.59111",
    "lng": "-51.16056"
  },
  {
    "country": "BR",
    "name": "Iúna",
    "lat": "-20.34583",
    "lng": "-41.53583"
  },
  {
    "country": "BR",
    "name": "Ituverava",
    "lat": "-20.33944",
    "lng": "-47.78056"
  },
  {
    "country": "BR",
    "name": "Iturama",
    "lat": "-19.72806",
    "lng": "-50.19556"
  },
  {
    "country": "BR",
    "name": "Itupeva",
    "lat": "-23.15306",
    "lng": "-47.05778"
  },
  {
    "country": "BR",
    "name": "Itumbiara",
    "lat": "-18.41917",
    "lng": "-49.21528"
  },
  {
    "country": "BR",
    "name": "Ituiutaba",
    "lat": "-18.97428",
    "lng": "-49.46212"
  },
  {
    "country": "BR",
    "name": "Ituberá",
    "lat": "-13.73538",
    "lng": "-39.14785"
  },
  {
    "country": "BR",
    "name": "Ituaçu",
    "lat": "-13.81333",
    "lng": "-41.29667"
  },
  {
    "country": "BR",
    "name": "Itu",
    "lat": "-23.26417",
    "lng": "-47.29917"
  },
  {
    "country": "BR",
    "name": "Itororó",
    "lat": "-15.11694",
    "lng": "-40.07028"
  },
  {
    "country": "BR",
    "name": "Itiruçu",
    "lat": "-13.53167",
    "lng": "-40.15028"
  },
  {
    "country": "BR",
    "name": "Itirapina",
    "lat": "-22.25278",
    "lng": "-47.82278"
  },
  {
    "country": "BR",
    "name": "Itinga",
    "lat": "-16.61306",
    "lng": "-41.76528"
  },
  {
    "country": "BR",
    "name": "Itaúna",
    "lat": "-20.07528",
    "lng": "-44.57639"
  },
  {
    "country": "BR",
    "name": "Itaú de Minas",
    "lat": "-20.73944",
    "lng": "-46.75222"
  },
  {
    "country": "BR",
    "name": "Itatinga",
    "lat": "-23.10167",
    "lng": "-48.61583"
  },
  {
    "country": "BR",
    "name": "Itatiba",
    "lat": "-23.00583",
    "lng": "-46.83889"
  },
  {
    "country": "BR",
    "name": "Itatiaia",
    "lat": "-22.49611",
    "lng": "-44.56333"
  },
  {
    "country": "BR",
    "name": "Itararé",
    "lat": "-24.1125",
    "lng": "-49.33167"
  },
  {
    "country": "BR",
    "name": "Itarantim",
    "lat": "-15.65972",
    "lng": "-40.06556"
  },
  {
    "country": "BR",
    "name": "Itarana",
    "lat": "-19.87389",
    "lng": "-40.87528"
  },
  {
    "country": "BR",
    "name": "Itaqui",
    "lat": "-29.12528",
    "lng": "-56.55306"
  },
  {
    "country": "BR",
    "name": "Itaquaquecetuba",
    "lat": "-23.48611",
    "lng": "-46.34833"
  },
  {
    "country": "BR",
    "name": "Itapuranga",
    "lat": "-15.56222",
    "lng": "-49.94861"
  },
  {
    "country": "BR",
    "name": "Itapuí",
    "lat": "-22.23333",
    "lng": "-48.71917"
  },
  {
    "country": "BR",
    "name": "Itaporanga",
    "lat": "-23.70778",
    "lng": "-49.48972"
  },
  {
    "country": "BR",
    "name": "Itápolis",
    "lat": "-21.59556",
    "lng": "-48.81278"
  },
  {
    "country": "BR",
    "name": "Itapirapuã",
    "lat": "-15.82333",
    "lng": "-50.61333"
  },
  {
    "country": "BR",
    "name": "Itapira",
    "lat": "-22.43611",
    "lng": "-46.82167"
  },
  {
    "country": "BR",
    "name": "Itapicuru",
    "lat": "-11.31667",
    "lng": "-38.23333"
  },
  {
    "country": "BR",
    "name": "Itapevi",
    "lat": "-23.54889",
    "lng": "-46.93417"
  },
  {
    "country": "BR",
    "name": "Itapeva",
    "lat": "-23.98222",
    "lng": "-48.87556"
  },
  {
    "country": "BR",
    "name": "Itapetininga",
    "lat": "-23.59167",
    "lng": "-48.05306"
  },
  {
    "country": "BR",
    "name": "Itapetinga",
    "lat": "-15.24889",
    "lng": "-40.24778"
  },
  {
    "country": "BR",
    "name": "Itaperuna",
    "lat": "-21.205",
    "lng": "-41.88778"
  },
  {
    "country": "BR",
    "name": "Itaperuçu",
    "lat": "-25.22",
    "lng": "-49.34778"
  },
  {
    "country": "BR",
    "name": "Itapemirim",
    "lat": "-21.01111",
    "lng": "-40.83389"
  },
  {
    "country": "BR",
    "name": "Itapema",
    "lat": "-27.09028",
    "lng": "-48.61139"
  },
  {
    "country": "BR",
    "name": "Itapecerica da Serra",
    "lat": "-23.71694",
    "lng": "-46.84917"
  },
  {
    "country": "BR",
    "name": "Itapecerica",
    "lat": "-20.4725",
    "lng": "-45.12556"
  },
  {
    "country": "BR",
    "name": "Itaparica",
    "lat": "-12.88833",
    "lng": "-38.67861"
  },
  {
    "country": "BR",
    "name": "Itapaci",
    "lat": "-14.95083",
    "lng": "-49.54944"
  },
  {
    "country": "BR",
    "name": "Itaocara",
    "lat": "-21.66917",
    "lng": "-42.07611"
  },
  {
    "country": "BR",
    "name": "Itanhém",
    "lat": "-17.16639",
    "lng": "-40.33"
  },
  {
    "country": "BR",
    "name": "Itanhandu",
    "lat": "-22.29583",
    "lng": "-44.93472"
  },
  {
    "country": "BR",
    "name": "Itanhaém",
    "lat": "-24.18306",
    "lng": "-46.78889"
  },
  {
    "country": "BR",
    "name": "Itambé",
    "lat": "-15.245",
    "lng": "-40.62444"
  },
  {
    "country": "BR",
    "name": "Itambacuri",
    "lat": "-18.03111",
    "lng": "-41.685"
  },
  {
    "country": "BR",
    "name": "Itamarandiba",
    "lat": "-17.85722",
    "lng": "-42.85889"
  },
  {
    "country": "BR",
    "name": "Itamaraju",
    "lat": "-17.03917",
    "lng": "-39.53111"
  },
  {
    "country": "BR",
    "name": "Itajuípe",
    "lat": "-14.67806",
    "lng": "-39.375"
  },
  {
    "country": "BR",
    "name": "Itajubá",
    "lat": "-22.42556",
    "lng": "-45.45278"
  },
  {
    "country": "BR",
    "name": "Itajobi",
    "lat": "-21.31806",
    "lng": "-49.05444"
  },
  {
    "country": "BR",
    "name": "Itagibá",
    "lat": "-14.28361",
    "lng": "-39.84278"
  },
  {
    "country": "BR",
    "name": "Itajaí",
    "lat": "-26.90778",
    "lng": "-48.66194"
  },
  {
    "country": "BR",
    "name": "Itaí",
    "lat": "-23.41778",
    "lng": "-49.09056"
  },
  {
    "country": "BR",
    "name": "Itaguaí",
    "lat": "-22.85222",
    "lng": "-43.77528"
  },
  {
    "country": "BR",
    "name": "Itaguaçu",
    "lat": "-19.80194",
    "lng": "-40.85556"
  },
  {
    "country": "BR",
    "name": "Itagi",
    "lat": "-14.16278",
    "lng": "-40.00611"
  },
  {
    "country": "BR",
    "name": "Itacaré",
    "lat": "-14.2789",
    "lng": "-38.99584"
  },
  {
    "country": "BR",
    "name": "Itacarambi",
    "lat": "-15.10222",
    "lng": "-44.09194"
  },
  {
    "country": "BR",
    "name": "Itabuna",
    "lat": "-14.78556",
    "lng": "-39.28028"
  },
  {
    "country": "BR",
    "name": "Itaboraí",
    "lat": "-22.74444",
    "lng": "-42.85944"
  },
  {
    "country": "BR",
    "name": "Itabirito",
    "lat": "-20.25333",
    "lng": "-43.80139"
  },
  {
    "country": "BR",
    "name": "Itabira",
    "lat": "-19.61917",
    "lng": "-43.22694"
  },
  {
    "country": "BR",
    "name": "Itaberaí",
    "lat": "-16.02028",
    "lng": "-49.81028"
  },
  {
    "country": "BR",
    "name": "Itaberaba",
    "lat": "-12.5275",
    "lng": "-40.30694"
  },
  {
    "country": "BR",
    "name": "Itaberá",
    "lat": "-23.86194",
    "lng": "-49.13722"
  },
  {
    "country": "BR",
    "name": "Itabaianinha",
    "lat": "-11.27389",
    "lng": "-37.79"
  },
  {
    "country": "BR",
    "name": "Itabaiana",
    "lat": "-10.685",
    "lng": "-37.42528"
  },
  {
    "country": "BR",
    "name": "Irupi",
    "lat": "-20.34528",
    "lng": "-41.64111"
  },
  {
    "country": "BR",
    "name": "Irecê",
    "lat": "-11.30417",
    "lng": "-41.85583"
  },
  {
    "country": "BR",
    "name": "Irati",
    "lat": "-25.46722",
    "lng": "-50.65111"
  },
  {
    "country": "BR",
    "name": "Irará",
    "lat": "-12.05",
    "lng": "-38.76667"
  },
  {
    "country": "BR",
    "name": "Iraquara",
    "lat": "-12.24861",
    "lng": "-41.61944"
  },
  {
    "country": "BR",
    "name": "Iracemápolis",
    "lat": "-22.58056",
    "lng": "-47.51861"
  },
  {
    "country": "BR",
    "name": "Ipuã",
    "lat": "-20.43806",
    "lng": "-48.01222"
  },
  {
    "country": "BR",
    "name": "Iporã",
    "lat": "-24.00306",
    "lng": "-53.70417"
  },
  {
    "country": "BR",
    "name": "Iporá",
    "lat": "-16.44194",
    "lng": "-51.11778"
  },
  {
    "country": "BR",
    "name": "Ipirá",
    "lat": "-12.15833",
    "lng": "-39.73722"
  },
  {
    "country": "BR",
    "name": "Ipiaú",
    "lat": "-14.13449",
    "lng": "-39.73948"
  },
  {
    "country": "BR",
    "name": "Iperó",
    "lat": "-23.35028",
    "lng": "-47.68861"
  },
  {
    "country": "BR",
    "name": "Ipauçu",
    "lat": "-23.05667",
    "lng": "-49.62639"
  },
  {
    "country": "BR",
    "name": "Ipatinga",
    "lat": "-19.46833",
    "lng": "-42.53667"
  },
  {
    "country": "BR",
    "name": "Ipameri",
    "lat": "-17.72194",
    "lng": "-48.15972"
  },
  {
    "country": "BR",
    "name": "Ipaba",
    "lat": "-19.41361",
    "lng": "-42.41944"
  },
  {
    "country": "BR",
    "name": "Inhumas",
    "lat": "-16.35778",
    "lng": "-49.49611"
  },
  {
    "country": "BR",
    "name": "Inhapim",
    "lat": "-19.54917",
    "lng": "-42.12"
  },
  {
    "country": "BR",
    "name": "Inhambupe",
    "lat": "-11.78444",
    "lng": "-38.35306"
  },
  {
    "country": "BR",
    "name": "Indiaroba",
    "lat": "-11.51917",
    "lng": "-37.51167"
  },
  {
    "country": "BR",
    "name": "Indaiatuba",
    "lat": "-23.08842",
    "lng": "-47.2119"
  },
  {
    "country": "BR",
    "name": "Indaial",
    "lat": "-26.89778",
    "lng": "-49.23167"
  },
  {
    "country": "BR",
    "name": "Imbituva",
    "lat": "-25.23",
    "lng": "-50.60444"
  },
  {
    "country": "BR",
    "name": "Imbituba",
    "lat": "-28.24",
    "lng": "-48.67028"
  },
  {
    "country": "BR",
    "name": "Ilhéus",
    "lat": "-14.79364",
    "lng": "-39.03949"
  },
  {
    "country": "BR",
    "name": "Ilha Solteira",
    "lat": "-20.43278",
    "lng": "-51.3425"
  },
  {
    "country": "BR",
    "name": "Ilhabela",
    "lat": "-23.77806",
    "lng": "-45.35806"
  },
  {
    "country": "BR",
    "name": "Ijuí",
    "lat": "-28.38778",
    "lng": "-53.91472"
  },
  {
    "country": "BR",
    "name": "Iguatemi",
    "lat": "-23.68028",
    "lng": "-54.56111"
  },
  {
    "country": "BR",
    "name": "Iguape",
    "lat": "-24.70806",
    "lng": "-47.55528"
  },
  {
    "country": "BR",
    "name": "Iguaí",
    "lat": "-14.75639",
    "lng": "-40.08917"
  },
  {
    "country": "BR",
    "name": "Iguaba Grande",
    "lat": "-22.83917",
    "lng": "-42.22889"
  },
  {
    "country": "BR",
    "name": "Igrejinha",
    "lat": "-29.57444",
    "lng": "-50.79028"
  },
  {
    "country": "BR",
    "name": "Igreja Nova",
    "lat": "-10.12528",
    "lng": "-36.66194"
  },
  {
    "country": "BR",
    "name": "Igarapé",
    "lat": "-20.07028",
    "lng": "-44.30167"
  },
  {
    "country": "BR",
    "name": "Igarapava",
    "lat": "-20.03833",
    "lng": "-47.74694"
  },
  {
    "country": "BR",
    "name": "Igaraçu do Tietê",
    "lat": "-22.50917",
    "lng": "-48.55778"
  },
  {
    "country": "BR",
    "name": "Iconha",
    "lat": "-20.79306",
    "lng": "-40.81111"
  },
  {
    "country": "BR",
    "name": "Içara",
    "lat": "-28.71333",
    "lng": "-49.3"
  },
  {
    "country": "BR",
    "name": "Ibotirama",
    "lat": "-12.18528",
    "lng": "-43.22056"
  },
  {
    "country": "BR",
    "name": "Ibiúna",
    "lat": "-23.65639",
    "lng": "-47.2225"
  },
  {
    "country": "BR",
    "name": "Ibitinga",
    "lat": "-21.75778",
    "lng": "-48.82889"
  },
  {
    "country": "BR",
    "name": "Ibirubá",
    "lat": "-28.6275",
    "lng": "-53.08972"
  },
  {
    "country": "BR",
    "name": "Ibirité",
    "lat": "-20.02194",
    "lng": "-44.05889"
  },
  {
    "country": "BR",
    "name": "Ibirataia",
    "lat": "-14.06694",
    "lng": "-39.64056"
  },
  {
    "country": "BR",
    "name": "Ibirapitanga",
    "lat": "-14.16417",
    "lng": "-39.37361"
  },
  {
    "country": "BR",
    "name": "Ibirama",
    "lat": "-27.05694",
    "lng": "-49.51778"
  },
  {
    "country": "BR",
    "name": "Ibiraçu",
    "lat": "-19.83194",
    "lng": "-40.36972"
  },
  {
    "country": "BR",
    "name": "Ibiporã",
    "lat": "-23.26917",
    "lng": "-51.04806"
  },
  {
    "country": "BR",
    "name": "Ibipeba",
    "lat": "-11.64083",
    "lng": "-42.01111"
  },
  {
    "country": "BR",
    "name": "Ibicuí",
    "lat": "-14.84167",
    "lng": "-39.98667"
  },
  {
    "country": "BR",
    "name": "Ibicaraí",
    "lat": "-14.865",
    "lng": "-39.5875"
  },
  {
    "country": "BR",
    "name": "Ibiá",
    "lat": "-19.47833",
    "lng": "-46.53889"
  },
  {
    "country": "BR",
    "name": "Ibatiba",
    "lat": "-20.23389",
    "lng": "-41.51056"
  },
  {
    "country": "BR",
    "name": "Ibaté",
    "lat": "-21.95472",
    "lng": "-47.99667"
  },
  {
    "country": "BR",
    "name": "Ibaiti",
    "lat": "-23.84861",
    "lng": "-50.18778"
  },
  {
    "country": "BR",
    "name": "Iaçu",
    "lat": "-12.76722",
    "lng": "-40.21167"
  },
  {
    "country": "BR",
    "name": "Iaciara",
    "lat": "-14.09583",
    "lng": "-46.63167"
  },
  {
    "country": "BR",
    "name": "Hortolândia",
    "lat": "-22.85833",
    "lng": "-47.22"
  },
  {
    "country": "BR",
    "name": "Horizontina",
    "lat": "-27.62583",
    "lng": "-54.30778"
  },
  {
    "country": "BR",
    "name": "Hidrolândia",
    "lat": "-16.96222",
    "lng": "-49.22806"
  },
  {
    "country": "BR",
    "name": "Herval",
    "lat": "-32.02361",
    "lng": "-53.39556"
  },
  {
    "country": "BR",
    "name": "Gurupi",
    "lat": "-11.72917",
    "lng": "-49.06861"
  },
  {
    "country": "BR",
    "name": "Guiratinga",
    "lat": "-16.34534",
    "lng": "-53.76177"
  },
  {
    "country": "BR",
    "name": "Guia Lopes da Laguna",
    "lat": "-21.45778",
    "lng": "-56.11417"
  },
  {
    "country": "BR",
    "name": "Guaxupé",
    "lat": "-21.30528",
    "lng": "-46.71278"
  },
  {
    "country": "BR",
    "name": "Guarulhos",
    "lat": "-23.46278",
    "lng": "-46.53333"
  },
  {
    "country": "BR",
    "name": "Guarujá",
    "lat": "-23.99306",
    "lng": "-46.25639"
  },
  {
    "country": "BR",
    "name": "Guariba",
    "lat": "-21.36",
    "lng": "-48.22833"
  },
  {
    "country": "BR",
    "name": "Guaratuba",
    "lat": "-25.88278",
    "lng": "-48.57472"
  },
  {
    "country": "BR",
    "name": "Guaratinguetá",
    "lat": "-22.81639",
    "lng": "-45.1925"
  },
  {
    "country": "BR",
    "name": "Guaratinga",
    "lat": "-16.58564",
    "lng": "-39.78189"
  },
  {
    "country": "BR",
    "name": "Guararema",
    "lat": "-23.415",
    "lng": "-46.035"
  },
  {
    "country": "BR",
    "name": "Guararapes",
    "lat": "-21.26083",
    "lng": "-50.64278"
  },
  {
    "country": "BR",
    "name": "Guarapuava",
    "lat": "-25.39048",
    "lng": "-51.46541"
  },
  {
    "country": "BR",
    "name": "Guarapari",
    "lat": "-20.67182",
    "lng": "-40.50196"
  },
  {
    "country": "BR",
    "name": "Guaraniaçu",
    "lat": "-25.10083",
    "lng": "-52.87806"
  },
  {
    "country": "BR",
    "name": "Guaranésia",
    "lat": "-21.29917",
    "lng": "-46.8025"
  },
  {
    "country": "BR",
    "name": "Guaramirim",
    "lat": "-26.47306",
    "lng": "-49.00278"
  },
  {
    "country": "BR",
    "name": "Guará",
    "lat": "-20.42833",
    "lng": "-47.82417"
  },
  {
    "country": "BR",
    "name": "Guaporé",
    "lat": "-28.84556",
    "lng": "-51.89028"
  },
  {
    "country": "BR",
    "name": "Guapó",
    "lat": "-16.83056",
    "lng": "-49.53194"
  },
  {
    "country": "BR",
    "name": "Guapimirim",
    "lat": "-22.53722",
    "lng": "-42.98194"
  },
  {
    "country": "BR",
    "name": "Guapiaçu",
    "lat": "-20.795",
    "lng": "-49.22028"
  },
  {
    "country": "BR",
    "name": "Guanhães",
    "lat": "-18.775",
    "lng": "-42.9325"
  },
  {
    "country": "BR",
    "name": "Guanambi",
    "lat": "-14.22333",
    "lng": "-42.78139"
  },
  {
    "country": "BR",
    "name": "Guaíra",
    "lat": "-20.31833",
    "lng": "-48.31056"
  },
  {
    "country": "BR",
    "name": "Guaçuí",
    "lat": "-20.77556",
    "lng": "-41.67944"
  },
  {
    "country": "BR",
    "name": "Gravataí",
    "lat": "-29.94218",
    "lng": "-50.99278"
  },
  {
    "country": "BR",
    "name": "Governador Valadares",
    "lat": "-18.85111",
    "lng": "-41.94944"
  },
  {
    "country": "BR",
    "name": "Goiatuba",
    "lat": "-18.0125",
    "lng": "-49.35472"
  },
  {
    "country": "BR",
    "name": "Goiás",
    "lat": "-15.93444",
    "lng": "-50.14028"
  },
  {
    "country": "BR",
    "name": "Goianira",
    "lat": "-16.49611",
    "lng": "-49.42639"
  },
  {
    "country": "BR",
    "name": "Goiânia",
    "lat": "-16.67861",
    "lng": "-49.25389"
  },
  {
    "country": "BR",
    "name": "Goianésia",
    "lat": "-15.3175",
    "lng": "-49.1175"
  },
  {
    "country": "BR",
    "name": "Goianápolis",
    "lat": "-16.51056",
    "lng": "-49.02389"
  },
  {
    "country": "BR",
    "name": "Giruá",
    "lat": "-28.02833",
    "lng": "-54.34972"
  },
  {
    "country": "BR",
    "name": "General Salgado",
    "lat": "-20.64833",
    "lng": "-50.36056"
  },
  {
    "country": "BR",
    "name": "Gaspar",
    "lat": "-26.93139",
    "lng": "-48.95889"
  },
  {
    "country": "BR",
    "name": "Garibaldi",
    "lat": "-29.25611",
    "lng": "-51.53361"
  },
  {
    "country": "BR",
    "name": "Garça",
    "lat": "-22.21056",
    "lng": "-49.65611"
  },
  {
    "country": "BR",
    "name": "Gandu",
    "lat": "-13.74389",
    "lng": "-39.48667"
  },
  {
    "country": "BR",
    "name": "Fundão",
    "lat": "-19.93408",
    "lng": "-40.40473"
  },
  {
    "country": "BR",
    "name": "Frutal",
    "lat": "-20.02472",
    "lng": "-48.94056"
  },
  {
    "country": "BR",
    "name": "Frei Paulo",
    "lat": "-10.54944",
    "lng": "-37.53444"
  },
  {
    "country": "BR",
    "name": "Frederico Westphalen",
    "lat": "-27.35917",
    "lng": "-53.39444"
  },
  {
    "country": "BR",
    "name": "Franco da Rocha",
    "lat": "-23.32167",
    "lng": "-46.72694"
  },
  {
    "country": "BR",
    "name": "Francisco Sá",
    "lat": "-16.47583",
    "lng": "-43.48833"
  },
  {
    "country": "BR",
    "name": "Francisco Morato",
    "lat": "-23.28167",
    "lng": "-46.74528"
  },
  {
    "country": "BR",
    "name": "Francisco Beltrão",
    "lat": "-26.08111",
    "lng": "-53.055"
  },
  {
    "country": "BR",
    "name": "Franca",
    "lat": "-20.53861",
    "lng": "-47.40083"
  },
  {
    "country": "BR",
    "name": "Foz do Iguaçu",
    "lat": "-25.54778",
    "lng": "-54.58806"
  },
  {
    "country": "BR",
    "name": "Forquilhinha",
    "lat": "-28.7475",
    "lng": "-49.47222"
  },
  {
    "country": "BR",
    "name": "Formosa do Rio Preto",
    "lat": "-11.04833",
    "lng": "-45.19306"
  },
  {
    "country": "BR",
    "name": "Formosa",
    "lat": "-15.53722",
    "lng": "-47.33444"
  },
  {
    "country": "BR",
    "name": "Formiga",
    "lat": "-20.46444",
    "lng": "-45.42639"
  },
  {
    "country": "BR",
    "name": "Paulista Flórida",
    "lat": "-21.6",
    "lng": "-51.2"
  },
  {
    "country": "BR",
    "name": "Florianópolis",
    "lat": "-27.59667",
    "lng": "-48.54917"
  },
  {
    "country": "BR",
    "name": "Florestópolis",
    "lat": "-22.86333",
    "lng": "-51.38722"
  },
  {
    "country": "BR",
    "name": "Flores da Cunha",
    "lat": "-29.02889",
    "lng": "-51.18167"
  },
  {
    "country": "BR",
    "name": "Firminópolis",
    "lat": "-16.58194",
    "lng": "-50.305"
  },
  {
    "country": "BR",
    "name": "Ferraz de Vasconcelos",
    "lat": "-23.54083",
    "lng": "-46.36861"
  },
  {
    "country": "BR",
    "name": "Fernandópolis",
    "lat": "-20.28389",
    "lng": "-50.24639"
  },
  {
    "country": "BR",
    "name": "Feira de Santana",
    "lat": "-12.26667",
    "lng": "-38.96667"
  },
  {
    "country": "BR",
    "name": "Faxinal",
    "lat": "-24.00028",
    "lng": "-51.31944"
  },
  {
    "country": "BR",
    "name": "Fartura",
    "lat": "-23.38833",
    "lng": "-49.51"
  },
  {
    "country": "BR",
    "name": "Farroupilha",
    "lat": "-29.225",
    "lng": "-51.34778"
  },
  {
    "country": "BR",
    "name": "Extrema",
    "lat": "-22.85472",
    "lng": "-46.31833"
  },
  {
    "country": "BR",
    "name": "Eunápolis",
    "lat": "-16.3775",
    "lng": "-39.58028"
  },
  {
    "country": "BR",
    "name": "Euclides da Cunha",
    "lat": "-10.5075",
    "lng": "-39.01583"
  },
  {
    "country": "BR",
    "name": "Estrela",
    "lat": "-28.06111",
    "lng": "-50.93833"
  },
  {
    "country": "BR",
    "name": "Esteio",
    "lat": "-29.86139",
    "lng": "-51.17917"
  },
  {
    "country": "BR",
    "name": "Estância Velha",
    "lat": "-29.64833",
    "lng": "-51.17389"
  },
  {
    "country": "BR",
    "name": "Estância",
    "lat": "-11.26833",
    "lng": "-37.43833"
  },
  {
    "country": "BR",
    "name": "Espumoso",
    "lat": "-28.72472",
    "lng": "-52.84972"
  },
  {
    "country": "BR",
    "name": "Esplanada",
    "lat": "-11.79611",
    "lng": "-37.945"
  },
  {
    "country": "BR",
    "name": "Espinosa",
    "lat": "-14.92611",
    "lng": "-42.81917"
  },
  {
    "country": "BR",
    "name": "Espera Feliz",
    "lat": "-20.65028",
    "lng": "-41.90722"
  },
  {
    "country": "BR",
    "name": "Esmeraldas",
    "lat": "-19.7625",
    "lng": "-44.31389"
  },
  {
    "country": "BR",
    "name": "Erechim",
    "lat": "-27.63461",
    "lng": "-52.2754"
  },
  {
    "country": "BR",
    "name": "Entre Rios",
    "lat": "-11.94194",
    "lng": "-38.08444"
  },
  {
    "country": "BR",
    "name": "Engenheiro Beltrão",
    "lat": "-23.79722",
    "lng": "-52.26917"
  },
  {
    "country": "BR",
    "name": "Encruzilhada do Sul",
    "lat": "-30.54389",
    "lng": "-52.52194"
  },
  {
    "country": "BR",
    "name": "Encruzilhada",
    "lat": "-15.53139",
    "lng": "-40.90944"
  },
  {
    "country": "BR",
    "name": "Encantado",
    "lat": "-29.23611",
    "lng": "-51.86972"
  },
  {
    "country": "BR",
    "name": "Embu Guaçu",
    "lat": "-23.83222",
    "lng": "-46.81139"
  },
  {
    "country": "BR",
    "name": "Embu",
    "lat": "-23.64889",
    "lng": "-46.85222"
  },
  {
    "country": "BR",
    "name": "Elói Mendes",
    "lat": "-21.61",
    "lng": "-45.56528"
  },
  {
    "country": "BR",
    "name": "Elias Fausto",
    "lat": "-23.04278",
    "lng": "-47.37389"
  },
  {
    "country": "BR",
    "name": "Eldorado",
    "lat": "-23.78694",
    "lng": "-54.28361"
  },
  {
    "country": "BR",
    "name": "Edéia",
    "lat": "-17.33833",
    "lng": "-49.93139"
  },
  {
    "country": "BR",
    "name": "Ecoporanga",
    "lat": "-18.37333",
    "lng": "-40.83056"
  },
  {
    "country": "BR",
    "name": "Duque de Caxias",
    "lat": "-22.78556",
    "lng": "-43.31167"
  },
  {
    "country": "BR",
    "name": "Duartina",
    "lat": "-22.41444",
    "lng": "-49.40389"
  },
  {
    "country": "BR",
    "name": "Dourados",
    "lat": "-22.22111",
    "lng": "-54.80556"
  },
  {
    "country": "BR",
    "name": "Dores do Indaiá",
    "lat": "-19.46333",
    "lng": "-45.60167"
  },
  {
    "country": "BR",
    "name": "Dom Pedrito",
    "lat": "-30.98278",
    "lng": "-54.67306"
  },
  {
    "country": "BR",
    "name": "Domingos Martins",
    "lat": "-20.36333",
    "lng": "-40.65917"
  },
  {
    "country": "BR",
    "name": "Dois Vizinhos",
    "lat": "-25.73361",
    "lng": "-53.05722"
  },
  {
    "country": "BR",
    "name": "Dois Córregos",
    "lat": "-22.36611",
    "lng": "-48.38028"
  },
  {
    "country": "BR",
    "name": "Divinópolis",
    "lat": "-20.14355",
    "lng": "-44.89065"
  },
  {
    "country": "BR",
    "name": "Divino das Laranjeiras",
    "lat": "-18.77778",
    "lng": "-41.47972"
  },
  {
    "country": "BR",
    "name": "Diamantino",
    "lat": "-14.40861",
    "lng": "-56.44611"
  },
  {
    "country": "BR",
    "name": "Diamantina",
    "lat": "-18.24692",
    "lng": "-43.60345"
  },
  {
    "country": "BR",
    "name": "Diadema",
    "lat": "-23.68611",
    "lng": "-46.62278"
  },
  {
    "country": "BR",
    "name": "Descalvado",
    "lat": "-21.90389",
    "lng": "-47.61944"
  },
  {
    "country": "BR",
    "name": "Curvelo",
    "lat": "-18.75639",
    "lng": "-44.43083"
  },
  {
    "country": "BR",
    "name": "Curitibanos",
    "lat": "-27.28278",
    "lng": "-50.58444"
  },
  {
    "country": "BR",
    "name": "Curitiba",
    "lat": "-25.42778",
    "lng": "-49.27306"
  },
  {
    "country": "BR",
    "name": "Cunha",
    "lat": "-23.07444",
    "lng": "-44.95972"
  },
  {
    "country": "BR",
    "name": "Cuiabá",
    "lat": "-15.59611",
    "lng": "-56.09667"
  },
  {
    "country": "BR",
    "name": "Cubatão",
    "lat": "-23.895",
    "lng": "-46.42528"
  },
  {
    "country": "BR",
    "name": "Cruzília",
    "lat": "-21.83861",
    "lng": "-44.80833"
  },
  {
    "country": "BR",
    "name": "Cruzeiro do Oeste",
    "lat": "-23.785",
    "lng": "-53.07333"
  },
  {
    "country": "BR",
    "name": "Cruzeiro",
    "lat": "-22.57316",
    "lng": "-44.97108"
  },
  {
    "country": "BR",
    "name": "Cruz das Almas",
    "lat": "-12.67",
    "lng": "-39.10194"
  },
  {
    "country": "BR",
    "name": "Cruz Alta",
    "lat": "-28.64397",
    "lng": "-53.60633"
  },
  {
    "country": "BR",
    "name": "Crixás",
    "lat": "-14.54889",
    "lng": "-49.96917"
  },
  {
    "country": "BR",
    "name": "Cristinápolis",
    "lat": "-11.47556",
    "lng": "-37.75528"
  },
  {
    "country": "BR",
    "name": "Cristalina",
    "lat": "-16.76769",
    "lng": "-47.6153"
  },
  {
    "country": "BR",
    "name": "Criciúma",
    "lat": "-28.6775",
    "lng": "-49.36972"
  },
  {
    "country": "BR",
    "name": "Cravinhos",
    "lat": "-21.34028",
    "lng": "-47.72944"
  },
  {
    "country": "BR",
    "name": "Coxim",
    "lat": "-18.50667",
    "lng": "-54.76"
  },
  {
    "country": "BR",
    "name": "Cotia",
    "lat": "-23.60389",
    "lng": "-46.91917"
  },
  {
    "country": "BR",
    "name": "Costa Rica",
    "lat": "-23.41667",
    "lng": "-54.65"
  },
  {
    "country": "BR",
    "name": "Cosmópolis",
    "lat": "-22.64583",
    "lng": "-47.19611"
  },
  {
    "country": "BR",
    "name": "Coruripe",
    "lat": "-10.12556",
    "lng": "-36.17556"
  },
  {
    "country": "BR",
    "name": "Corupá",
    "lat": "-26.42528",
    "lng": "-49.24306"
  },
  {
    "country": "BR",
    "name": "Corumbá",
    "lat": "-19.00917",
    "lng": "-57.65333"
  },
  {
    "country": "BR",
    "name": "Correntina",
    "lat": "-13.34333",
    "lng": "-44.63667"
  },
  {
    "country": "BR",
    "name": "Correia Pinto",
    "lat": "-27.58472",
    "lng": "-50.36111"
  },
  {
    "country": "BR",
    "name": "Coronel Vivida",
    "lat": "-25.97972",
    "lng": "-52.56778"
  },
  {
    "country": "BR",
    "name": "Coronel Fabriciano",
    "lat": "-19.51861",
    "lng": "-42.62889"
  },
  {
    "country": "BR",
    "name": "Coromandel",
    "lat": "-18.47333",
    "lng": "-47.20028"
  },
  {
    "country": "BR",
    "name": "Cornélio Procópio",
    "lat": "-23.18111",
    "lng": "-50.64667"
  },
  {
    "country": "BR",
    "name": "Corinto",
    "lat": "-18.38083",
    "lng": "-44.45639"
  },
  {
    "country": "BR",
    "name": "Cordeirópolis",
    "lat": "-22.48194",
    "lng": "-47.45667"
  },
  {
    "country": "BR",
    "name": "Cordeiro",
    "lat": "-22.02861",
    "lng": "-42.36083"
  },
  {
    "country": "BR",
    "name": "Corbélia",
    "lat": "-24.79889",
    "lng": "-53.30667"
  },
  {
    "country": "BR",
    "name": "Coração de Maria",
    "lat": "-12.23333",
    "lng": "-38.75"
  },
  {
    "country": "BR",
    "name": "Coração de Jesus",
    "lat": "-16.68528",
    "lng": "-44.365"
  },
  {
    "country": "BR",
    "name": "Contagem",
    "lat": "-19.93167",
    "lng": "-44.05361"
  },
  {
    "country": "BR",
    "name": "Conselheiro Pena",
    "lat": "-19.17222",
    "lng": "-41.47222"
  },
  {
    "country": "BR",
    "name": "Conselheiro Lafaiete",
    "lat": "-20.66028",
    "lng": "-43.78611"
  },
  {
    "country": "BR",
    "name": "Congonhas",
    "lat": "-20.50525",
    "lng": "-43.8588"
  },
  {
    "country": "BR",
    "name": "Conde",
    "lat": "-11.81361",
    "lng": "-37.61056"
  },
  {
    "country": "BR",
    "name": "Concórdia",
    "lat": "-27.23417",
    "lng": "-52.02778"
  },
  {
    "country": "BR",
    "name": "Conchas",
    "lat": "-23.01528",
    "lng": "-48.01056"
  },
  {
    "country": "BR",
    "name": "Conchal",
    "lat": "-22.33028",
    "lng": "-47.1725"
  },
  {
    "country": "BR",
    "name": "Conceição do Rio Verde",
    "lat": "-21.88083",
    "lng": "-45.08528"
  },
  {
    "country": "BR",
    "name": "Conceição do Mato Dentro",
    "lat": "-19.03722",
    "lng": "-43.425"
  },
  {
    "country": "BR",
    "name": "Conceição do Coité",
    "lat": "-11.56389",
    "lng": "-39.28278"
  },
  {
    "country": "BR",
    "name": "Conceição do Castelo",
    "lat": "-20.36833",
    "lng": "-41.24389"
  },
  {
    "country": "BR",
    "name": "Conceição do Almeida",
    "lat": "-12.77944",
    "lng": "-39.17"
  },
  {
    "country": "BR",
    "name": "Conceição do Jacuípe",
    "lat": "-12.31667",
    "lng": "-38.76667"
  },
  {
    "country": "BR",
    "name": "Conceição das Alagoas",
    "lat": "-19.91472",
    "lng": "-48.38833"
  },
  {
    "country": "BR",
    "name": "Conceição da Feira",
    "lat": "-12.50583",
    "lng": "-38.99861"
  },
  {
    "country": "BR",
    "name": "Conceição da Barra",
    "lat": "-18.59333",
    "lng": "-39.73222"
  },
  {
    "country": "BR",
    "name": "Colorado",
    "lat": "-22.8375",
    "lng": "-51.97306"
  },
  {
    "country": "BR",
    "name": "Colombo",
    "lat": "-25.29167",
    "lng": "-49.22417"
  },
  {
    "country": "BR",
    "name": "Colatina",
    "lat": "-19.53944",
    "lng": "-40.63056"
  },
  {
    "country": "BR",
    "name": "Cocal",
    "lat": "-28.60321",
    "lng": "-49.32767"
  },
  {
    "country": "BR",
    "name": "Coaraci",
    "lat": "-14.64083",
    "lng": "-39.55111"
  },
  {
    "country": "BR",
    "name": "Clevelândia",
    "lat": "-26.39583",
    "lng": "-52.47083"
  },
  {
    "country": "BR",
    "name": "Cláudio",
    "lat": "-20.44333",
    "lng": "-44.76583"
  },
  {
    "country": "BR",
    "name": "Cipó",
    "lat": "-11.09972",
    "lng": "-38.51361"
  },
  {
    "country": "BR",
    "name": "Cidreira",
    "lat": "-30.18111",
    "lng": "-50.20556"
  },
  {
    "country": "BR",
    "name": "Cícero Dantas",
    "lat": "-10.6",
    "lng": "-38.38333"
  },
  {
    "country": "BR",
    "name": "Cianorte",
    "lat": "-23.66333",
    "lng": "-52.605"
  },
  {
    "country": "BR",
    "name": "Chuí",
    "lat": "-33.69111",
    "lng": "-53.45667"
  },
  {
    "country": "BR",
    "name": "Chopinzinho",
    "lat": "-25.85583",
    "lng": "-52.52333"
  },
  {
    "country": "BR",
    "name": "Nova Xavantina",
    "lat": "-14.66463",
    "lng": "-52.35558"
  },
  {
    "country": "BR",
    "name": "Charqueadas",
    "lat": "-29.95472",
    "lng": "-51.62528"
  },
  {
    "country": "BR",
    "name": "Charqueada",
    "lat": "-22.50972",
    "lng": "-47.77806"
  },
  {
    "country": "BR",
    "name": "Chapecó",
    "lat": "-27.09639",
    "lng": "-52.61833"
  },
  {
    "country": "BR",
    "name": "Chapada dos Guimarães",
    "lat": "-15.46056",
    "lng": "-55.74972"
  },
  {
    "country": "BR",
    "name": "Cerro Largo",
    "lat": "-28.14861",
    "lng": "-54.73806"
  },
  {
    "country": "BR",
    "name": "Cerquilho",
    "lat": "-23.165",
    "lng": "-47.74361"
  },
  {
    "country": "BR",
    "name": "Cerqueira César",
    "lat": "-23.03556",
    "lng": "-49.16611"
  },
  {
    "country": "BR",
    "name": "Ceres",
    "lat": "-15.30833",
    "lng": "-49.59833"
  },
  {
    "country": "BR",
    "name": "Centralina",
    "lat": "-18.58389",
    "lng": "-49.19944"
  },
  {
    "country": "BR",
    "name": "Centenário do Sul",
    "lat": "-22.82111",
    "lng": "-51.59528"
  },
  {
    "country": "BR",
    "name": "Celso Ramos",
    "lat": "-27.63444",
    "lng": "-51.33639"
  },
  {
    "country": "BR",
    "name": "Caxias do Sul",
    "lat": "-29.16806",
    "lng": "-51.17944"
  },
  {
    "country": "BR",
    "name": "Caxambu",
    "lat": "-21.97722",
    "lng": "-44.9325"
  },
  {
    "country": "BR",
    "name": "Cavalcante",
    "lat": "-13.7975",
    "lng": "-47.45833"
  },
  {
    "country": "BR",
    "name": "Catu",
    "lat": "-12.35306",
    "lng": "-38.37889"
  },
  {
    "country": "BR",
    "name": "Catanduva",
    "lat": "-21.13778",
    "lng": "-48.97278"
  },
  {
    "country": "BR",
    "name": "Catalão",
    "lat": "-18.16583",
    "lng": "-47.94639"
  },
  {
    "country": "BR",
    "name": "Cataguases",
    "lat": "-21.38917",
    "lng": "-42.69667"
  },
  {
    "country": "BR",
    "name": "Castro Alves",
    "lat": "-12.76556",
    "lng": "-39.42833"
  },
  {
    "country": "BR",
    "name": "Castro",
    "lat": "-24.78927",
    "lng": "-50.01225"
  },
  {
    "country": "BR",
    "name": "Castilho",
    "lat": "-20.87222",
    "lng": "-51.4875"
  },
  {
    "country": "BR",
    "name": "Castelo",
    "lat": "-20.60361",
    "lng": "-41.18472"
  },
  {
    "country": "BR",
    "name": "Cassilândia",
    "lat": "-19.11333",
    "lng": "-51.73417"
  },
  {
    "country": "BR",
    "name": "Cássia",
    "lat": "-20.58306",
    "lng": "-46.92194"
  },
  {
    "country": "BR",
    "name": "Casimiro de Abreu",
    "lat": "-22.48056",
    "lng": "-42.20417"
  },
  {
    "country": "BR",
    "name": "Cascavel",
    "lat": "-24.95583",
    "lng": "-53.45528"
  },
  {
    "country": "BR",
    "name": "Casa Branca",
    "lat": "-21.77389",
    "lng": "-47.08639"
  },
  {
    "country": "BR",
    "name": "Carmo do Rio Verde",
    "lat": "-15.35361",
    "lng": "-49.7075"
  },
  {
    "country": "BR",
    "name": "Carmo do Rio Claro",
    "lat": "-20.97194",
    "lng": "-46.11889"
  },
  {
    "country": "BR",
    "name": "Carmo do Paranaíba",
    "lat": "-19.00083",
    "lng": "-46.31611"
  },
  {
    "country": "BR",
    "name": "Carmo do Cajuru",
    "lat": "-20.18417",
    "lng": "-44.77111"
  },
  {
    "country": "BR",
    "name": "Carmo",
    "lat": "-21.93361",
    "lng": "-42.60861"
  },
  {
    "country": "BR",
    "name": "Carlos Chagas",
    "lat": "-17.70306",
    "lng": "-40.76639"
  },
  {
    "country": "BR",
    "name": "Carlos Barbosa",
    "lat": "-29.2975",
    "lng": "-51.50361"
  },
  {
    "country": "BR",
    "name": "Carira",
    "lat": "-10.36083",
    "lng": "-37.70111"
  },
  {
    "country": "BR",
    "name": "Carinhanha",
    "lat": "-14.30472",
    "lng": "-43.765"
  },
  {
    "country": "BR",
    "name": "Cardoso",
    "lat": "-20.08194",
    "lng": "-49.91417"
  },
  {
    "country": "BR",
    "name": "Carazinho",
    "lat": "-28.28389",
    "lng": "-52.78639"
  },
  {
    "country": "BR",
    "name": "Caratinga",
    "lat": "-19.78972",
    "lng": "-42.13917"
  },
  {
    "country": "BR",
    "name": "Caarapó",
    "lat": "-22.63417",
    "lng": "-54.82222"
  },
  {
    "country": "BR",
    "name": "Carapicuíba",
    "lat": "-23.52272",
    "lng": "-46.835"
  },
  {
    "country": "BR",
    "name": "Carangola",
    "lat": "-20.73306",
    "lng": "-42.02944"
  },
  {
    "country": "BR",
    "name": "Carandaí",
    "lat": "-20.95361",
    "lng": "-43.80639"
  },
  {
    "country": "BR",
    "name": "Carambeí",
    "lat": "-24.9526",
    "lng": "-50.1159"
  },
  {
    "country": "BR",
    "name": "Caraí",
    "lat": "-17.18889",
    "lng": "-41.69472"
  },
  {
    "country": "BR",
    "name": "Caraguatatuba",
    "lat": "-23.62028",
    "lng": "-45.41306"
  },
  {
    "country": "BR",
    "name": "Capivari",
    "lat": "-22.995",
    "lng": "-47.50778"
  },
  {
    "country": "BR",
    "name": "Capitólio",
    "lat": "-20.61528",
    "lng": "-46.05"
  },
  {
    "country": "BR",
    "name": "Capinzal",
    "lat": "-27.34361",
    "lng": "-51.61194"
  },
  {
    "country": "BR",
    "name": "Capinópolis",
    "lat": "-18.68194",
    "lng": "-49.56972"
  },
  {
    "country": "BR",
    "name": "Capim Grosso",
    "lat": "-11.38111",
    "lng": "-40.01278"
  },
  {
    "country": "BR",
    "name": "Capelinha",
    "lat": "-17.69139",
    "lng": "-42.51583"
  },
  {
    "country": "BR",
    "name": "Capela do Alto",
    "lat": "-23.47056",
    "lng": "-47.73472"
  },
  {
    "country": "BR",
    "name": "Capela",
    "lat": "-10.50333",
    "lng": "-37.05278"
  },
  {
    "country": "BR",
    "name": "Capão da Canoa",
    "lat": "-29.74556",
    "lng": "-50.00972"
  },
  {
    "country": "BR",
    "name": "Capâo Bonito",
    "lat": "-24.00583",
    "lng": "-48.34944"
  },
  {
    "country": "BR",
    "name": "Cantagalo",
    "lat": "-21.98111",
    "lng": "-42.36806"
  },
  {
    "country": "BR",
    "name": "Canoinhas",
    "lat": "-26.17722",
    "lng": "-50.39"
  },
  {
    "country": "BR",
    "name": "Canoas",
    "lat": "-29.91778",
    "lng": "-51.18361"
  },
  {
    "country": "BR",
    "name": "Canguçu",
    "lat": "-31.395",
    "lng": "-52.67556"
  },
  {
    "country": "BR",
    "name": "Canela",
    "lat": "-29.35622",
    "lng": "-50.81357"
  },
  {
    "country": "BR",
    "name": "Cândido Mota",
    "lat": "-22.74639",
    "lng": "-50.38694"
  },
  {
    "country": "BR",
    "name": "Cândido de Abreu",
    "lat": "-24.56694",
    "lng": "-51.33333"
  },
  {
    "country": "BR",
    "name": "Candelária",
    "lat": "-29.66917",
    "lng": "-52.78889"
  },
  {
    "country": "BR",
    "name": "Canavieiras",
    "lat": "-15.675",
    "lng": "-38.94722"
  },
  {
    "country": "BR",
    "name": "Canarana",
    "lat": "-11.68472",
    "lng": "-41.76889"
  },
  {
    "country": "BR",
    "name": "Cananéia",
    "lat": "-25.01472",
    "lng": "-47.92667"
  },
  {
    "country": "BR",
    "name": "Campo Verde",
    "lat": "-20.41667",
    "lng": "-54.06667"
  },
  {
    "country": "BR",
    "name": "Campos Novos",
    "lat": "-27.40167",
    "lng": "-51.225"
  },
  {
    "country": "BR",
    "name": "Campos Gerais",
    "lat": "-21.235",
    "lng": "-45.75861"
  },
  {
    "country": "BR",
    "name": "Campos do Jordão",
    "lat": "-22.73944",
    "lng": "-45.59139"
  },
  {
    "country": "BR",
    "name": "Campos Belos",
    "lat": "-13.03667",
    "lng": "-46.77167"
  },
  {
    "country": "BR",
    "name": "Campos Altos",
    "lat": "-19.69611",
    "lng": "-46.17139"
  },
  {
    "country": "BR",
    "name": "Campos dos Goytacazes",
    "lat": "-21.75227",
    "lng": "-41.33044"
  },
  {
    "country": "BR",
    "name": "Campo Mourão",
    "lat": "-24.04309",
    "lng": "-52.37929"
  },
  {
    "country": "BR",
    "name": "Campo Largo",
    "lat": "-25.45955",
    "lng": "-49.53014"
  },
  {
    "country": "BR",
    "name": "Campo Grande",
    "lat": "-20.44278",
    "lng": "-54.64639"
  },
  {
    "country": "BR",
    "name": "Campo Grande",
    "lat": "-10.23333",
    "lng": "-36.5"
  },
  {
    "country": "BR",
    "name": "Campo Formoso",
    "lat": "-10.5075",
    "lng": "-40.32139"
  },
  {
    "country": "BR",
    "name": "Campo do Brito",
    "lat": "-10.73333",
    "lng": "-37.49333"
  },
  {
    "country": "BR",
    "name": "Campo Belo",
    "lat": "-20.89722",
    "lng": "-45.27722"
  },
  {
    "country": "BR",
    "name": "Campina Verde",
    "lat": "-19.53791",
    "lng": "-49.48813"
  },
  {
    "country": "BR",
    "name": "Campinas",
    "lat": "-22.90556",
    "lng": "-47.06083"
  },
  {
    "country": "BR",
    "name": "Campina Grande do Sul",
    "lat": "-25.30556",
    "lng": "-49.05528"
  },
  {
    "country": "BR",
    "name": "Campestre",
    "lat": "-21.71111",
    "lng": "-46.24639"
  },
  {
    "country": "BR",
    "name": "Campanha",
    "lat": "-21.83611",
    "lng": "-45.40056"
  },
  {
    "country": "BR",
    "name": "Cambuquira",
    "lat": "-21.85222",
    "lng": "-45.29583"
  },
  {
    "country": "BR",
    "name": "Cambuí",
    "lat": "-22.61222",
    "lng": "-46.0575"
  },
  {
    "country": "BR",
    "name": "Cambuci",
    "lat": "-21.57528",
    "lng": "-41.91111"
  },
  {
    "country": "BR",
    "name": "Cambé",
    "lat": "-23.27583",
    "lng": "-51.27833"
  },
  {
    "country": "BR",
    "name": "Cambará",
    "lat": "-23.04639",
    "lng": "-50.07361"
  },
  {
    "country": "BR",
    "name": "Camaquã",
    "lat": "-30.85111",
    "lng": "-51.81222"
  },
  {
    "country": "BR",
    "name": "Camapuã",
    "lat": "-19.53139",
    "lng": "-54.04389"
  },
  {
    "country": "BR",
    "name": "Camanducaia",
    "lat": "-22.75528",
    "lng": "-46.14472"
  },
  {
    "country": "BR",
    "name": "Camamu",
    "lat": "-13.94472",
    "lng": "-39.10389"
  },
  {
    "country": "BR",
    "name": "Camaçari",
    "lat": "-12.6975",
    "lng": "-38.32417"
  },
  {
    "country": "BR",
    "name": "Caldas Novas",
    "lat": "-17.74431",
    "lng": "-48.62789"
  },
  {
    "country": "BR",
    "name": "Cajuru",
    "lat": "-21.27528",
    "lng": "-47.30417"
  },
  {
    "country": "BR",
    "name": "Cajati",
    "lat": "-24.73611",
    "lng": "-48.12278"
  },
  {
    "country": "BR",
    "name": "Cajamar",
    "lat": "-23.35611",
    "lng": "-46.87694"
  },
  {
    "country": "BR",
    "name": "Caieiras",
    "lat": "-23.36417",
    "lng": "-46.74056"
  },
  {
    "country": "BR",
    "name": "Caiapônia",
    "lat": "-16.95667",
    "lng": "-51.81028"
  },
  {
    "country": "BR",
    "name": "Cafelândia",
    "lat": "-21.8025",
    "lng": "-49.61"
  },
  {
    "country": "BR",
    "name": "Cafarnaum",
    "lat": "-11.69361",
    "lng": "-41.46833"
  },
  {
    "country": "BR",
    "name": "Caetité",
    "lat": "-14.06944",
    "lng": "-42.475"
  },
  {
    "country": "BR",
    "name": "Caeté",
    "lat": "-19.88",
    "lng": "-43.66972"
  },
  {
    "country": "BR",
    "name": "Caculé",
    "lat": "-14.50333",
    "lng": "-42.22222"
  },
  {
    "country": "BR",
    "name": "Caçu",
    "lat": "-18.55667",
    "lng": "-51.13083"
  },
  {
    "country": "BR",
    "name": "Caconde",
    "lat": "-21.52944",
    "lng": "-46.64389"
  },
  {
    "country": "BR",
    "name": "Cachoeiro de Itapemirim",
    "lat": "-20.84889",
    "lng": "-41.11278"
  },
  {
    "country": "BR",
    "name": "Cachoeirinha",
    "lat": "-29.95111",
    "lng": "-51.09389"
  },
  {
    "country": "BR",
    "name": "Cachoeiras de Macacu",
    "lat": "-22.4625",
    "lng": "-42.65306"
  },
  {
    "country": "BR",
    "name": "Cachoeira do Sul",
    "lat": "-30.03917",
    "lng": "-52.89389"
  },
  {
    "country": "BR",
    "name": "Cachoeira",
    "lat": "-12.60139",
    "lng": "-38.96576"
  },
  {
    "country": "BR",
    "name": "Cacequi",
    "lat": "-29.88361",
    "lng": "-54.825"
  },
  {
    "country": "BR",
    "name": "Caçapava do Sul",
    "lat": "-30.51436",
    "lng": "-53.48496"
  },
  {
    "country": "BR",
    "name": "Caçapava",
    "lat": "-23.10083",
    "lng": "-45.70694"
  },
  {
    "country": "BR",
    "name": "Caçador",
    "lat": "-26.77528",
    "lng": "-51.015"
  },
  {
    "country": "BR",
    "name": "Cabreúva",
    "lat": "-23.3075",
    "lng": "-47.13278"
  },
  {
    "country": "BR",
    "name": "Cabo Frio",
    "lat": "-22.88717",
    "lng": "-42.02622"
  },
  {
    "country": "BR",
    "name": "Butiá",
    "lat": "-30.11972",
    "lng": "-51.96222"
  },
  {
    "country": "BR",
    "name": "Buritizeiro",
    "lat": "-17.35111",
    "lng": "-44.96222"
  },
  {
    "country": "BR",
    "name": "Buritis",
    "lat": "-15.61778",
    "lng": "-46.42333"
  },
  {
    "country": "BR",
    "name": "Buriti Alegre",
    "lat": "-18.14",
    "lng": "-49.04028"
  },
  {
    "country": "BR",
    "name": "Buritama",
    "lat": "-21.06611",
    "lng": "-50.14722"
  },
  {
    "country": "BR",
    "name": "Buri",
    "lat": "-23.7975",
    "lng": "-48.59278"
  },
  {
    "country": "BR",
    "name": "Boquim",
    "lat": "-11.14694",
    "lng": "-37.62056"
  },
  {
    "country": "BR",
    "name": "Buerarema",
    "lat": "-14.95944",
    "lng": "-39.29972"
  },
  {
    "country": "BR",
    "name": "Bueno Brandão",
    "lat": "-22.44083",
    "lng": "-46.35083"
  },
  {
    "country": "BR",
    "name": "Brusque",
    "lat": "-27.09795",
    "lng": "-48.91281"
  },
  {
    "country": "BR",
    "name": "Brumado",
    "lat": "-14.20361",
    "lng": "-41.66528"
  },
  {
    "country": "BR",
    "name": "Brumadinho",
    "lat": "-20.14333",
    "lng": "-44.19972"
  },
  {
    "country": "BR",
    "name": "Brotas",
    "lat": "-22.28417",
    "lng": "-48.12667"
  },
  {
    "country": "BR",
    "name": "Brodósqui",
    "lat": "-20.99139",
    "lng": "-47.65861"
  },
  {
    "country": "BR",
    "name": "Brasília de Minas",
    "lat": "-16.20639",
    "lng": "-44.43333"
  },
  {
    "country": "BR",
    "name": "Brasília",
    "lat": "-15.77972",
    "lng": "-47.92972"
  },
  {
    "country": "BR",
    "name": "Bragança Paulista",
    "lat": "-22.9527",
    "lng": "-46.54418"
  },
  {
    "country": "BR",
    "name": "Braço do Norte",
    "lat": "-28.275",
    "lng": "-49.16556"
  },
  {
    "country": "BR",
    "name": "Botucatu",
    "lat": "-22.88583",
    "lng": "-48.445"
  },
  {
    "country": "BR",
    "name": "Botelhos",
    "lat": "-21.63333",
    "lng": "-46.395"
  },
  {
    "country": "BR",
    "name": "Borda da Mata",
    "lat": "-22.27417",
    "lng": "-46.16528"
  },
  {
    "country": "BR",
    "name": "Borborema",
    "lat": "-21.61972",
    "lng": "-49.07361"
  },
  {
    "country": "BR",
    "name": "Boracéia",
    "lat": "-22.19306",
    "lng": "-48.77889"
  },
  {
    "country": "BR",
    "name": "Boquira",
    "lat": "-12.82306",
    "lng": "-42.73056"
  },
  {
    "country": "BR",
    "name": "Bonito",
    "lat": "-21.12111",
    "lng": "-56.48194"
  },
  {
    "country": "BR",
    "name": "Bom Sucesso",
    "lat": "-21.03306",
    "lng": "-44.75806"
  },
  {
    "country": "BR",
    "name": "Bom Jesus dos Perdões",
    "lat": "-23.135",
    "lng": "-46.46528"
  },
  {
    "country": "BR",
    "name": "Bom Jesus do Itabapoana",
    "lat": "-21.13389",
    "lng": "-41.67972"
  },
  {
    "country": "BR",
    "name": "Bom Jesus do Galho",
    "lat": "-19.82889",
    "lng": "-42.31611"
  },
  {
    "country": "BR",
    "name": "Bom Jesus da Lapa",
    "lat": "-13.255",
    "lng": "-43.41806"
  },
  {
    "country": "BR",
    "name": "Bom Despacho",
    "lat": "-19.73639",
    "lng": "-45.25222"
  },
  {
    "country": "BR",
    "name": "Boituva",
    "lat": "-23.28333",
    "lng": "-47.67222"
  },
  {
    "country": "BR",
    "name": "Bocaiúva",
    "lat": "-17.10778",
    "lng": "-43.815"
  },
  {
    "country": "BR",
    "name": "Boa Esperança do Sul",
    "lat": "-21.9925",
    "lng": "-48.39083"
  },
  {
    "country": "BR",
    "name": "Boa Esperança",
    "lat": "-21.09",
    "lng": "-45.56583"
  },
  {
    "country": "BR",
    "name": "Boa Esperança",
    "lat": "-18.54",
    "lng": "-40.29583"
  },
  {
    "country": "BR",
    "name": "Blumenau",
    "lat": "-26.91944",
    "lng": "-49.06611"
  },
  {
    "country": "BR",
    "name": "Biritiba Mirim",
    "lat": "-23.5725",
    "lng": "-46.03861"
  },
  {
    "country": "BR",
    "name": "Birigui",
    "lat": "-21.28861",
    "lng": "-50.34"
  },
  {
    "country": "BR",
    "name": "Biguaçu",
    "lat": "-27.49417",
    "lng": "-48.65556"
  },
  {
    "country": "BR",
    "name": "Bicas",
    "lat": "-21.72528",
    "lng": "-43.05944"
  },
  {
    "country": "BR",
    "name": "Betim",
    "lat": "-19.96778",
    "lng": "-44.19833"
  },
  {
    "country": "BR",
    "name": "Bertioga",
    "lat": "-23.85444",
    "lng": "-46.13861"
  },
  {
    "country": "BR",
    "name": "Bernardino de Campos",
    "lat": "-23.01306",
    "lng": "-49.47417"
  },
  {
    "country": "BR",
    "name": "Bento Gonçalves",
    "lat": "-29.17139",
    "lng": "-51.51917"
  },
  {
    "country": "BR",
    "name": "Belo Oriente",
    "lat": "-19.22",
    "lng": "-42.48361"
  },
  {
    "country": "BR",
    "name": "Belo Horizonte",
    "lat": "-19.92083",
    "lng": "-43.93778"
  },
  {
    "country": "BR",
    "name": "Belmonte",
    "lat": "-15.86104",
    "lng": "-38.88143"
  },
  {
    "country": "BR",
    "name": "Belford Roxo",
    "lat": "-22.76417",
    "lng": "-43.39944"
  },
  {
    "country": "BR",
    "name": "Bela Vista do Paraíso",
    "lat": "-22.99667",
    "lng": "-51.19056"
  },
  {
    "country": "BR",
    "name": "Bela Vista de Goiás",
    "lat": "-16.97278",
    "lng": "-48.95333"
  },
  {
    "country": "BR",
    "name": "Bela Vista",
    "lat": "-22.10889",
    "lng": "-56.52111"
  },
  {
    "country": "BR",
    "name": "Bebedouro",
    "lat": "-20.94944",
    "lng": "-48.47917"
  },
  {
    "country": "BR",
    "name": "Bauru",
    "lat": "-22.31472",
    "lng": "-49.06056"
  },
  {
    "country": "BR",
    "name": "Batatais",
    "lat": "-20.89111",
    "lng": "-47.585"
  },
  {
    "country": "BR",
    "name": "Bataiporã",
    "lat": "-22.29528",
    "lng": "-53.27111"
  },
  {
    "country": "BR",
    "name": "Bastos",
    "lat": "-21.92194",
    "lng": "-50.73389"
  },
  {
    "country": "BR",
    "name": "Barueri",
    "lat": "-23.51056",
    "lng": "-46.87611"
  },
  {
    "country": "BR",
    "name": "Barroso",
    "lat": "-21.18694",
    "lng": "-43.97583"
  },
  {
    "country": "BR",
    "name": "Barro Alto",
    "lat": "-14.97083",
    "lng": "-48.91583"
  },
  {
    "country": "BR",
    "name": "Barro Alto",
    "lat": "-11.76083",
    "lng": "-41.91167"
  },
  {
    "country": "BR",
    "name": "Barrinha",
    "lat": "-21.19361",
    "lng": "-48.16389"
  },
  {
    "country": "BR",
    "name": "Barretos",
    "lat": "-20.55722",
    "lng": "-48.56778"
  },
  {
    "country": "BR",
    "name": "Barreiro do Jaíba",
    "lat": "-15.61532",
    "lng": "-43.59187"
  },
  {
    "country": "BR",
    "name": "Barreiras",
    "lat": "-12.15278",
    "lng": "-44.99"
  },
  {
    "country": "BR",
    "name": "Barra Velha",
    "lat": "-26.63222",
    "lng": "-48.68472"
  },
  {
    "country": "BR",
    "name": "Barra Mansa",
    "lat": "-22.54417",
    "lng": "-44.17139"
  },
  {
    "country": "BR",
    "name": "Barra dos Coqueiros",
    "lat": "-10.90889",
    "lng": "-37.03861"
  },
  {
    "country": "BR",
    "name": "Barra do Piraí",
    "lat": "-22.47",
    "lng": "-43.82556"
  },
  {
    "country": "BR",
    "name": "Barra do Garças",
    "lat": "-15.89",
    "lng": "-52.25667"
  },
  {
    "country": "BR",
    "name": "Barra do Bugres",
    "lat": "-15.0725",
    "lng": "-57.18111"
  },
  {
    "country": "BR",
    "name": "Barra de São Francisco",
    "lat": "-18.755",
    "lng": "-40.89083"
  },
  {
    "country": "BR",
    "name": "Barra da Estiva",
    "lat": "-13.62611",
    "lng": "-41.32694"
  },
  {
    "country": "BR",
    "name": "Barra Bonita",
    "lat": "-22.49472",
    "lng": "-48.55806"
  },
  {
    "country": "BR",
    "name": "Barra",
    "lat": "-11.08944",
    "lng": "-43.14167"
  },
  {
    "country": "BR",
    "name": "Bariri",
    "lat": "-22.07444",
    "lng": "-48.74028"
  },
  {
    "country": "BR",
    "name": "Barbacena",
    "lat": "-21.22583",
    "lng": "-43.77361"
  },
  {
    "country": "BR",
    "name": "Barão de Melgaço",
    "lat": "-16.19444",
    "lng": "-55.9675"
  },
  {
    "country": "BR",
    "name": "Barão de Cocais",
    "lat": "-19.94583",
    "lng": "-43.48722"
  },
  {
    "country": "BR",
    "name": "Bandeirantes",
    "lat": "-23.11",
    "lng": "-50.3675"
  },
  {
    "country": "BR",
    "name": "Bambuí",
    "lat": "-20.00639",
    "lng": "-45.97694"
  },
  {
    "country": "BR",
    "name": "Balneário Camboriú",
    "lat": "-26.99056",
    "lng": "-48.63472"
  },
  {
    "country": "BR",
    "name": "Baixo Guandu",
    "lat": "-19.51889",
    "lng": "-41.01583"
  },
  {
    "country": "BR",
    "name": "Baixa Grande",
    "lat": "-11.95972",
    "lng": "-40.16806"
  },
  {
    "country": "BR",
    "name": "Bagé",
    "lat": "-31.33139",
    "lng": "-54.10694"
  },
  {
    "country": "BR",
    "name": "Baependi",
    "lat": "-21.95889",
    "lng": "-44.89"
  },
  {
    "country": "BR",
    "name": "Bady Bassitt",
    "lat": "-20.91806",
    "lng": "-49.44528"
  },
  {
    "country": "BR",
    "name": "Avaré",
    "lat": "-23.09861",
    "lng": "-48.92583"
  },
  {
    "country": "BR",
    "name": "Auriflama",
    "lat": "-20.68556",
    "lng": "-50.55472"
  },
  {
    "country": "BR",
    "name": "Atibaia",
    "lat": "-23.11694",
    "lng": "-46.55028"
  },
  {
    "country": "BR",
    "name": "Astorga",
    "lat": "-23.2325",
    "lng": "-51.66556"
  },
  {
    "country": "BR",
    "name": "Astolfo Dutra",
    "lat": "-21.31528",
    "lng": "-42.86222"
  },
  {
    "country": "BR",
    "name": "Assis",
    "lat": "-22.66167",
    "lng": "-50.41222"
  },
  {
    "country": "BR",
    "name": "Assaí",
    "lat": "-23.37333",
    "lng": "-50.84139"
  },
  {
    "country": "BR",
    "name": "Arujá",
    "lat": "-23.39611",
    "lng": "-46.32083"
  },
  {
    "country": "BR",
    "name": "Artur Nogueira",
    "lat": "-22.57306",
    "lng": "-47.1725"
  },
  {
    "country": "BR",
    "name": "Arroio Grande",
    "lat": "-32.2375",
    "lng": "-53.08694"
  },
  {
    "country": "BR",
    "name": "Arroio dos Ratos",
    "lat": "-30.07722",
    "lng": "-51.72917"
  },
  {
    "country": "BR",
    "name": "Arroio do Meio",
    "lat": "-29.40111",
    "lng": "-51.945"
  },
  {
    "country": "BR",
    "name": "Arraial do Cabo",
    "lat": "-22.96611",
    "lng": "-42.02778"
  },
  {
    "country": "BR",
    "name": "Armação de Búzios",
    "lat": "-22.74694",
    "lng": "-41.88167"
  },
  {
    "country": "BR",
    "name": "Armação",
    "lat": "-27.74963",
    "lng": "-48.50713"
  },
  {
    "country": "BR",
    "name": "Arinos",
    "lat": "-15.91694",
    "lng": "-46.10556"
  },
  {
    "country": "BR",
    "name": "Arenápolis",
    "lat": "-14.45028",
    "lng": "-56.84611"
  },
  {
    "country": "BR",
    "name": "Areia Branca",
    "lat": "-10.75778",
    "lng": "-37.31528"
  },
  {
    "country": "BR",
    "name": "Areal",
    "lat": "-22.23056",
    "lng": "-43.10556"
  },
  {
    "country": "BR",
    "name": "Areado",
    "lat": "-21.35861",
    "lng": "-46.14556"
  },
  {
    "country": "BR",
    "name": "Arcos",
    "lat": "-20.28194",
    "lng": "-45.53944"
  },
  {
    "country": "BR",
    "name": "Araxá",
    "lat": "-19.59333",
    "lng": "-46.94056"
  },
  {
    "country": "BR",
    "name": "Araucária",
    "lat": "-25.59306",
    "lng": "-49.41028"
  },
  {
    "country": "BR",
    "name": "Arauá",
    "lat": "-11.26222",
    "lng": "-37.61972"
  },
  {
    "country": "BR",
    "name": "Araruama",
    "lat": "-22.87278",
    "lng": "-42.34306"
  },
  {
    "country": "BR",
    "name": "Araras",
    "lat": "-22.35694",
    "lng": "-47.38417"
  },
  {
    "country": "BR",
    "name": "Araraquara",
    "lat": "-21.79444",
    "lng": "-48.17556"
  },
  {
    "country": "BR",
    "name": "Araranguá",
    "lat": "-28.93575",
    "lng": "-49.49538"
  },
  {
    "country": "BR",
    "name": "Arapongas",
    "lat": "-23.41944",
    "lng": "-51.42444"
  },
  {
    "country": "BR",
    "name": "Araguari",
    "lat": "-18.64722",
    "lng": "-48.18722"
  },
  {
    "country": "BR",
    "name": "Araguaiana",
    "lat": "-15.73389",
    "lng": "-51.83139"
  },
  {
    "country": "BR",
    "name": "Aragarças",
    "lat": "-15.8975",
    "lng": "-52.25083"
  },
  {
    "country": "BR",
    "name": "Araçuaí",
    "lat": "-16.84972",
    "lng": "-42.07028"
  },
  {
    "country": "BR",
    "name": "Aracruz",
    "lat": "-19.82028",
    "lng": "-40.27333"
  },
  {
    "country": "BR",
    "name": "Araçoiaba da Serra",
    "lat": "-23.50528",
    "lng": "-47.61417"
  },
  {
    "country": "BR",
    "name": "Araci",
    "lat": "-11.33333",
    "lng": "-38.96667"
  },
  {
    "country": "BR",
    "name": "Araçatuba",
    "lat": "-21.20889",
    "lng": "-50.43278"
  },
  {
    "country": "BR",
    "name": "Aracaju",
    "lat": "-10.91111",
    "lng": "-37.07167"
  },
  {
    "country": "BR",
    "name": "Aquidauana",
    "lat": "-20.47111",
    "lng": "-55.78722"
  },
  {
    "country": "BR",
    "name": "Aquidabã",
    "lat": "-10.28139",
    "lng": "-37.01861"
  },
  {
    "country": "BR",
    "name": "Apucarana",
    "lat": "-23.55083",
    "lng": "-51.46083"
  },
  {
    "country": "BR",
    "name": "Apiaí",
    "lat": "-24.50944",
    "lng": "-48.8425"
  },
  {
    "country": "BR",
    "name": "Aparecida do Taboado",
    "lat": "-20.08667",
    "lng": "-51.09361"
  },
  {
    "country": "BR",
    "name": "Aparecida",
    "lat": "-22.84694",
    "lng": "-45.22972"
  },
  {
    "country": "BR",
    "name": "Antonina",
    "lat": "-25.42861",
    "lng": "-48.71194"
  },
  {
    "country": "BR",
    "name": "Anitápolis",
    "lat": "-27.90194",
    "lng": "-49.12861"
  },
  {
    "country": "BR",
    "name": "Anicuns",
    "lat": "-16.46111",
    "lng": "-49.96167"
  },
  {
    "country": "BR",
    "name": "Anguera",
    "lat": "-12.15111",
    "lng": "-39.24639"
  },
  {
    "country": "BR",
    "name": "Angra dos Reis",
    "lat": "-23.00667",
    "lng": "-44.31806"
  },
  {
    "country": "BR",
    "name": "Angatuba",
    "lat": "-23.48972",
    "lng": "-48.41278"
  },
  {
    "country": "BR",
    "name": "Andrelândia",
    "lat": "-21.73972",
    "lng": "-44.30917"
  },
  {
    "country": "BR",
    "name": "Andradina",
    "lat": "-20.89611",
    "lng": "-51.37944"
  },
  {
    "country": "BR",
    "name": "Andradas",
    "lat": "-22.06806",
    "lng": "-46.56917"
  },
  {
    "country": "BR",
    "name": "Anastácio",
    "lat": "-20.48361",
    "lng": "-55.80694"
  },
  {
    "country": "BR",
    "name": "Anápolis",
    "lat": "-16.32667",
    "lng": "-48.95278"
  },
  {
    "country": "BR",
    "name": "Anagé",
    "lat": "-14.61222",
    "lng": "-41.13556"
  },
  {
    "country": "BR",
    "name": "Ampére",
    "lat": "-25.915",
    "lng": "-53.47278"
  },
  {
    "country": "BR",
    "name": "Amparo",
    "lat": "-22.70111",
    "lng": "-46.76444"
  },
  {
    "country": "BR",
    "name": "Américo Brasiliense",
    "lat": "-21.72444",
    "lng": "-48.10167"
  },
  {
    "country": "BR",
    "name": "Americana",
    "lat": "-22.73917",
    "lng": "-47.33139"
  },
  {
    "country": "BR",
    "name": "América Dourada",
    "lat": "-11.45528",
    "lng": "-41.43611"
  },
  {
    "country": "BR",
    "name": "Amargosa",
    "lat": "-13.03028",
    "lng": "-39.60472"
  },
  {
    "country": "BR",
    "name": "Alvorada",
    "lat": "-12.48",
    "lng": "-49.12472"
  },
  {
    "country": "BR",
    "name": "Alvinópolis",
    "lat": "-20.10667",
    "lng": "-43.04889"
  },
  {
    "country": "BR",
    "name": "Álvares Machado",
    "lat": "-22.07944",
    "lng": "-51.47194"
  },
  {
    "country": "BR",
    "name": "Alto Piquiri",
    "lat": "-24.02806",
    "lng": "-53.44056"
  },
  {
    "country": "BR",
    "name": "Alto Paraná",
    "lat": "-23.12889",
    "lng": "-52.31889"
  },
  {
    "country": "BR",
    "name": "Altãnia",
    "lat": "-23.87444",
    "lng": "-53.90167"
  },
  {
    "country": "BR",
    "name": "Alto Araguaia",
    "lat": "-17.31472",
    "lng": "-53.21528"
  },
  {
    "country": "BR",
    "name": "Altinópolis",
    "lat": "-21.02556",
    "lng": "-47.37389"
  },
  {
    "country": "BR",
    "name": "Alterosa",
    "lat": "-21.24917",
    "lng": "-46.14306"
  },
  {
    "country": "BR",
    "name": "Alpinópolis",
    "lat": "-20.86361",
    "lng": "-46.38806"
  },
  {
    "country": "BR",
    "name": "Almirante Tamandaré",
    "lat": "-25.32472",
    "lng": "-49.31"
  },
  {
    "country": "BR",
    "name": "Almenara",
    "lat": "-16.18361",
    "lng": "-40.69444"
  },
  {
    "country": "BR",
    "name": "Alfredo Chaves",
    "lat": "-20.635",
    "lng": "-40.74972"
  },
  {
    "country": "BR",
    "name": "Alfenas",
    "lat": "-21.42917",
    "lng": "-45.94722"
  },
  {
    "country": "BR",
    "name": "Além Paraíba",
    "lat": "-21.88778",
    "lng": "-42.70444"
  },
  {
    "country": "BR",
    "name": "Alegrete",
    "lat": "-29.78306",
    "lng": "-55.79194"
  },
  {
    "country": "BR",
    "name": "Alegre",
    "lat": "-20.76361",
    "lng": "-41.53306"
  },
  {
    "country": "BR",
    "name": "Alagoinhas",
    "lat": "-12.13556",
    "lng": "-38.41917"
  },
  {
    "country": "BR",
    "name": "Aimorés",
    "lat": "-19.49583",
    "lng": "-41.06389"
  },
  {
    "country": "BR",
    "name": "Águia Branca",
    "lat": "-18.98306",
    "lng": "-40.74028"
  },
  {
    "country": "BR",
    "name": "Agudos",
    "lat": "-22.46917",
    "lng": "-48.9875"
  },
  {
    "country": "BR",
    "name": "Águas Vermelhas",
    "lat": "-15.74722",
    "lng": "-41.46"
  },
  {
    "country": "BR",
    "name": "Águas Formosas",
    "lat": "-17.08222",
    "lng": "-40.93583"
  },
  {
    "country": "BR",
    "name": "Águas de Lindóia",
    "lat": "-22.47639",
    "lng": "-46.63278"
  },
  {
    "country": "BR",
    "name": "Aguaí",
    "lat": "-22.05944",
    "lng": "-46.97861"
  },
  {
    "country": "BR",
    "name": "Afonso Cláudio",
    "lat": "-20.07417",
    "lng": "-41.12389"
  },
  {
    "country": "BR",
    "name": "Adamantina",
    "lat": "-21.68528",
    "lng": "-51.0725"
  },
  {
    "country": "BR",
    "name": "Açucena",
    "lat": "-19.07306",
    "lng": "-42.54639"
  },
  {
    "country": "BR",
    "name": "Acajutiba",
    "lat": "-11.66222",
    "lng": "-38.01722"
  },
  {
    "country": "BR",
    "name": "Abaeté",
    "lat": "-19.16",
    "lng": "-45.44583"
  },
  {
    "country": "BR",
    "name": "Abadiânia",
    "lat": "-16.20417",
    "lng": "-48.70694"
  },
  {
    "country": "BR",
    "name": "Guaíba",
    "lat": "-30.11389",
    "lng": "-51.325"
  },
  {
    "country": "BR",
    "name": "Palmas",
    "lat": "-10.16745",
    "lng": "-48.32766"
  },
  {
    "country": "BR",
    "name": "Pontal do Paraná",
    "lat": "-25.67361",
    "lng": "-48.51111"
  },
  {
    "country": "BR",
    "name": "Uarini",
    "lat": "-2.99",
    "lng": "-65.10833"
  },
  {
    "country": "BR",
    "name": "Tonantins",
    "lat": "-2.87306",
    "lng": "-67.80222"
  },
  {
    "country": "BR",
    "name": "Tefé",
    "lat": "-3.36841",
    "lng": "-64.72054"
  },
  {
    "country": "BR",
    "name": "Marechal Thaumaturgo",
    "lat": "-8.94111",
    "lng": "-72.79167"
  },
  {
    "country": "BR",
    "name": "Tarauacá",
    "lat": "-8.16139",
    "lng": "-70.76556"
  },
  {
    "country": "BR",
    "name": "Tabatinga",
    "lat": "-4.23116",
    "lng": "-69.93858"
  },
  {
    "country": "BR",
    "name": "Sena Madureira",
    "lat": "-9.06341",
    "lng": "-68.67245"
  },
  {
    "country": "BR",
    "name": "São Paulo de Olivença",
    "lat": "-3.37833",
    "lng": "-68.8725"
  },
  {
    "country": "BR",
    "name": "São Gabriel da Cachoeira",
    "lat": "-0.1181",
    "lng": "-67.08527"
  },
  {
    "country": "BR",
    "name": "Santo Antônio do Içá",
    "lat": "-3.10222",
    "lng": "-67.93972"
  },
  {
    "country": "BR",
    "name": "Santa Isabel do Rio Negro",
    "lat": "-0.41389",
    "lng": "-65.01917"
  },
  {
    "country": "BR",
    "name": "Rio Branco",
    "lat": "-9.97472",
    "lng": "-67.81"
  },
  {
    "country": "BR",
    "name": "Porto Walter",
    "lat": "-8.26861",
    "lng": "-72.74389"
  },
  {
    "country": "BR",
    "name": "Porto Velho",
    "lat": "-8.76194",
    "lng": "-63.90389"
  },
  {
    "country": "BR",
    "name": "Pauini",
    "lat": "-7.71361",
    "lng": "-66.97639"
  },
  {
    "country": "BR",
    "name": "Novo Aripuanã",
    "lat": "-5.12056",
    "lng": "-60.37972"
  },
  {
    "country": "BR",
    "name": "Maraã",
    "lat": "-1.82403",
    "lng": "-65.35883"
  },
  {
    "country": "BR",
    "name": "Manoel Urbano",
    "lat": "-8.83889",
    "lng": "-69.25972"
  },
  {
    "country": "BR",
    "name": "Manicoré",
    "lat": "-5.80917",
    "lng": "-61.30028"
  },
  {
    "country": "BR",
    "name": "Mâncio Lima",
    "lat": "-7.61417",
    "lng": "-72.89583"
  },
  {
    "country": "BR",
    "name": "Manaus",
    "lat": "-3.10194",
    "lng": "-60.025"
  },
  {
    "country": "BR",
    "name": "Manaquiri",
    "lat": "-3.31667",
    "lng": "-60.35"
  },
  {
    "country": "BR",
    "name": "Manacapuru",
    "lat": "-3.29972",
    "lng": "-60.62056"
  },
  {
    "country": "BR",
    "name": "Jutaí",
    "lat": "-5.18333",
    "lng": "-68.9"
  },
  {
    "country": "BR",
    "name": "Humaitá",
    "lat": "-7.51651",
    "lng": "-63.03105"
  },
  {
    "country": "BR",
    "name": "Fonte Boa",
    "lat": "-2.51389",
    "lng": "-66.09167"
  },
  {
    "country": "BR",
    "name": "Feijó",
    "lat": "-8.1654",
    "lng": "-70.35486"
  },
  {
    "country": "BR",
    "name": "Envira",
    "lat": "-7.3",
    "lng": "-70.21667"
  },
  {
    "country": "BR",
    "name": "Eirunepé",
    "lat": "-6.66028",
    "lng": "-69.87361"
  },
  {
    "country": "BR",
    "name": "Cruzeiro do Sul",
    "lat": "-7.62759",
    "lng": "-72.67756"
  },
  {
    "country": "BR",
    "name": "Codajás",
    "lat": "-3.83667",
    "lng": "-62.05694"
  },
  {
    "country": "BR",
    "name": "Coari",
    "lat": "-4.085",
    "lng": "-63.14139"
  },
  {
    "country": "BR",
    "name": "Carauari",
    "lat": "-4.88278",
    "lng": "-66.89583"
  },
  {
    "country": "BR",
    "name": "Canutama",
    "lat": "-6.53389",
    "lng": "-64.38306"
  },
  {
    "country": "BR",
    "name": "Boca do Acre",
    "lat": "-8.75222",
    "lng": "-67.39778"
  },
  {
    "country": "BR",
    "name": "Boa Vista",
    "lat": "2.81972",
    "lng": "-60.67333"
  },
  {
    "country": "BR",
    "name": "Benjamin Constant",
    "lat": "-4.37555",
    "lng": "-70.03179"
  },
  {
    "country": "BR",
    "name": "Barcelos",
    "lat": "-0.97357",
    "lng": "-62.9269"
  },
  {
    "country": "BR",
    "name": "Ariquemes",
    "lat": "-9.91333",
    "lng": "-63.04083"
  },
  {
    "country": "BR",
    "name": "Aripuanã",
    "lat": "-9.16667",
    "lng": "-60.63333"
  },
  {
    "country": "BR",
    "name": "Anori",
    "lat": "-3.77278",
    "lng": "-61.64417"
  },
  {
    "country": "BR",
    "name": "Alvarães",
    "lat": "-3.22083",
    "lng": "-64.80417"
  },
  {
    "country": "BR",
    "name": "Iranduba",
    "lat": "-3.28472",
    "lng": "-60.18611"
  },
  {
    "country": "BR",
    "name": "Xapuri",
    "lat": "-10.65167",
    "lng": "-68.50444"
  },
  {
    "country": "BR",
    "name": "Vilhena",
    "lat": "-12.74056",
    "lng": "-60.14583"
  },
  {
    "country": "BR",
    "name": "Senador Guiomard",
    "lat": "-10.1497",
    "lng": "-67.73741"
  },
  {
    "country": "BR",
    "name": "Presidente Médici",
    "lat": "-11.17528",
    "lng": "-61.90139"
  },
  {
    "country": "BR",
    "name": "Pôsto Fiscal Rolim de Moura",
    "lat": "-13.08271",
    "lng": "-62.27726"
  },
  {
    "country": "BR",
    "name": "Plácido de Castro",
    "lat": "-10.33528",
    "lng": "-67.18556"
  },
  {
    "country": "BR",
    "name": "Pimenta Bueno",
    "lat": "-11.6725",
    "lng": "-61.19361"
  },
  {
    "country": "BR",
    "name": "Ouro Preto do Oeste",
    "lat": "-10.74806",
    "lng": "-62.21583"
  },
  {
    "country": "BR",
    "name": "Ji Paraná",
    "lat": "-10.88528",
    "lng": "-61.95167"
  },
  {
    "country": "BR",
    "name": "Jaru",
    "lat": "-10.43889",
    "lng": "-62.46639"
  },
  {
    "country": "BR",
    "name": "Guajará Mirim",
    "lat": "-10.78356",
    "lng": "-65.33552"
  },
  {
    "country": "BR",
    "name": "Cacoal",
    "lat": "-11.43861",
    "lng": "-61.44722"
  },
  {
    "country": "BR",
    "name": "Brasiléia",
    "lat": "-11.01611",
    "lng": "-68.74806"
  },
  {
    "country": "BR",
    "name": "Alta Floresta",
    "lat": "-9.87556",
    "lng": "-56.08611"
  },
  {
    "country": "BR",
    "name": "Aparecida de Goiânia",
    "lat": "-16.82333",
    "lng": "-49.24389"
  },
  {
    "country": "BR",
    "name": "Araguanã",
    "lat": "-2.94639",
    "lng": "-45.66098"
  },
  {
    "country": "BR",
    "name": "Campinas",
    "lat": "-27.59444",
    "lng": "-48.60694"
  },
  {
    "country": "BR",
    "name": "Campo Limpo Paulista",
    "lat": "-23.20639",
    "lng": "-46.78444"
  },
  {
    "country": "BR",
    "name": "Fernando de Noronha (Distrito Estadual)",
    "lat": "-3.84028",
    "lng": "-32.41083"
  },
  {
    "country": "BR",
    "name": "Jaboatão dos Guararapes",
    "lat": "-8.11278",
    "lng": "-35.01472"
  },
  {
    "country": "BR",
    "name": "Lago dos Rodrigues",
    "lat": "-4.61304",
    "lng": "-44.98009"
  },
  {
    "country": "BR",
    "name": "Lauro de Freitas",
    "lat": "-12.89444",
    "lng": "-38.32722"
  },
  {
    "country": "BR",
    "name": "Lucas do Rio Verde",
    "lat": "-13.07045",
    "lng": "-55.9235"
  },
  {
    "country": "BR",
    "name": "Paulo Ramos",
    "lat": "-4.44389",
    "lng": "-45.24056"
  },
  {
    "country": "BR",
    "name": "Pinhais",
    "lat": "-25.44472",
    "lng": "-49.1925"
  },
  {
    "country": "BR",
    "name": "Portelândia",
    "lat": "-17.35361",
    "lng": "-52.67861"
  },
  {
    "country": "BR",
    "name": "Rio Preto da Eva",
    "lat": "-2.69795",
    "lng": "-59.70172"
  },
  {
    "country": "BR",
    "name": "Santa Maria de Jetibá",
    "lat": "-20.02745",
    "lng": "-40.74336"
  },
  {
    "country": "BR",
    "name": "Simões Filho",
    "lat": "-12.78444",
    "lng": "-38.40389"
  },
  {
    "country": "BR",
    "name": "Sinop",
    "lat": "-11.86417",
    "lng": "-55.5025"
  },
  {
    "country": "BR",
    "name": "Teixeira de Freitas",
    "lat": "-17.535",
    "lng": "-39.74194"
  },
  {
    "country": "BR",
    "name": "Vargem Grande Paulista",
    "lat": "-23.60333",
    "lng": "-47.02639"
  },
  {
    "country": "BR",
    "name": "Cambebba",
    "lat": "-3.62092",
    "lng": "-38.82913"
  },
  {
    "country": "BR",
    "name": "Itacorubi",
    "lat": "-27.58315",
    "lng": "-48.49503"
  },
  {
    "country": "BR",
    "name": "Corrego Grande",
    "lat": "-27.60141",
    "lng": "-48.50593"
  },
  {
    "country": "BR",
    "name": "Santa Monica",
    "lat": "-27.59137",
    "lng": "-48.50756"
  },
  {
    "country": "BR",
    "name": "Carvoeira",
    "lat": "-27.59898",
    "lng": "-48.52618"
  },
  {
    "country": "BR",
    "name": "Trindade",
    "lat": "-27.58612",
    "lng": "-48.52335"
  },
  {
    "country": "BR",
    "name": "Morro da Cruz",
    "lat": "-27.5849",
    "lng": "-48.53562"
  },
  {
    "country": "BR",
    "name": "Saco dos Limoes",
    "lat": "-27.60864",
    "lng": "-48.53605"
  },
  {
    "country": "BR",
    "name": "Pantanal",
    "lat": "-27.60985",
    "lng": "-48.51648"
  },
  {
    "country": "BR",
    "name": "Costeira do Pirajubae",
    "lat": "-27.63586",
    "lng": "-48.5212"
  },
  {
    "country": "BR",
    "name": "Carianos",
    "lat": "-27.66088",
    "lng": "-48.54318"
  },
  {
    "country": "BR",
    "name": "Tapera",
    "lat": "-27.68528",
    "lng": "-48.55124"
  },
  {
    "country": "BR",
    "name": "Freguesia do Ribeirao da Ilha",
    "lat": "-27.71773",
    "lng": "-48.56266"
  },
  {
    "country": "BR",
    "name": "Atins",
    "lat": "-2.57017",
    "lng": "-42.74229"
  },
  {
    "country": "BR",
    "name": "Residencia Moacir PU5BHV",
    "lat": "-26.90967",
    "lng": "-49.36547"
  },
  {
    "country": "BR",
    "name": "Beira Rio",
    "lat": "-12.25438",
    "lng": "-42.75529"
  },
  {
    "country": "BR",
    "name": "Butia Inferior",
    "lat": "-28.07115",
    "lng": "-54.88533"
  },
  {
    "country": "BR",
    "name": "Nova Olina do Marnhao",
    "lat": "-2.84206",
    "lng": "-45.69789"
  },
  {
    "country": "BR",
    "name": "Planaltina",
    "lat": "-15.61791",
    "lng": "-47.64874"
  },
  {
    "country": "BR",
    "name": "Extrema",
    "lat": "-9.77136",
    "lng": "-66.35583"
  },
  {
    "country": "BS",
    "name": "West End",
    "lat": "26.68711",
    "lng": "-78.97702"
  },
  {
    "country": "BS",
    "name": "Spanish Wells",
    "lat": "25.54717",
    "lng": "-76.76405"
  },
  {
    "country": "BS",
    "name": "San Andros",
    "lat": "25.06667",
    "lng": "-78.05"
  },
  {
    "country": "BS",
    "name": "Port Nelson",
    "lat": "23.64967",
    "lng": "-74.84157"
  },
  {
    "country": "BS",
    "name": "Nassau",
    "lat": "25.05823",
    "lng": "-77.34306"
  },
  {
    "country": "BS",
    "name": "Matthew Town",
    "lat": "20.94982",
    "lng": "-73.67346"
  },
  {
    "country": "BS",
    "name": "Masons Bay",
    "lat": "22.54352",
    "lng": "-73.8778"
  },
  {
    "country": "BS",
    "name": "Marsh Harbour",
    "lat": "26.54124",
    "lng": "-77.0636"
  },
  {
    "country": "BS",
    "name": "Lucaya",
    "lat": "26.53333",
    "lng": "-78.66667"
  },
  {
    "country": "BS",
    "name": "High Rock",
    "lat": "26.60999",
    "lng": "-78.27863"
  },
  {
    "country": "BS",
    "name": "Hard Bargain",
    "lat": "26.31667",
    "lng": "-77.56667"
  },
  {
    "country": "BS",
    "name": "Governor’s Harbour",
    "lat": "25.16667",
    "lng": "-76.23333"
  },
  {
    "country": "BS",
    "name": "George Town",
    "lat": "23.51616",
    "lng": "-75.78665"
  },
  {
    "country": "BS",
    "name": "Freeport",
    "lat": "26.53333",
    "lng": "-78.7"
  },
  {
    "country": "BS",
    "name": "Dunmore Town",
    "lat": "25.50216",
    "lng": "-76.63633"
  },
  {
    "country": "BS",
    "name": "Duncan Town",
    "lat": "22.19083",
    "lng": "-75.72583"
  },
  {
    "country": "BS",
    "name": "Cooper’s Town",
    "lat": "26.87137",
    "lng": "-77.51131"
  },
  {
    "country": "BS",
    "name": "Colonel Hill",
    "lat": "22.7545",
    "lng": "-74.20415"
  },
  {
    "country": "BS",
    "name": "Cockburn Town",
    "lat": "24.05179",
    "lng": "-74.53138"
  },
  {
    "country": "BS",
    "name": "Clarence Town",
    "lat": "23.1",
    "lng": "-74.98333"
  },
  {
    "country": "BS",
    "name": "Black Point",
    "lat": "24.1",
    "lng": "-76.38333"
  },
  {
    "country": "BS",
    "name": "Arthur’s Town",
    "lat": "24.6224",
    "lng": "-75.67151"
  },
  {
    "country": "BS",
    "name": "Andros Town",
    "lat": "24.70502",
    "lng": "-77.76912"
  },
  {
    "country": "BS",
    "name": "Alice Town",
    "lat": "25.728",
    "lng": "-79.29721"
  },
  {
    "country": "BS",
    "name": "Abraham’s Bay",
    "lat": "22.36667",
    "lng": "-72.96667"
  },
  {
    "country": "BT",
    "name": "Wangdue Phodrang",
    "lat": "27.48615",
    "lng": "89.89915"
  },
  {
    "country": "BT",
    "name": "Trongsa",
    "lat": "27.5026",
    "lng": "90.50716"
  },
  {
    "country": "BT",
    "name": "Thimphu",
    "lat": "27.46609",
    "lng": "89.64191"
  },
  {
    "country": "BT",
    "name": "Trashi Yangtse",
    "lat": "27.6116",
    "lng": "91.498"
  },
  {
    "country": "BT",
    "name": "Trashigang",
    "lat": "27.3331",
    "lng": "91.55424"
  },
  {
    "country": "BT",
    "name": "Daga",
    "lat": "27.07529",
    "lng": "89.87688"
  },
  {
    "country": "BT",
    "name": "Shemgang",
    "lat": "27.21689",
    "lng": "90.65793"
  },
  {
    "country": "BT",
    "name": "Sarpang",
    "lat": "26.86395",
    "lng": "90.26745"
  },
  {
    "country": "BT",
    "name": "Punākha",
    "lat": "27.59137",
    "lng": "89.87743"
  },
  {
    "country": "BT",
    "name": "Phuntsholing",
    "lat": "26.85164",
    "lng": "89.38837"
  },
  {
    "country": "BT",
    "name": "Paro",
    "lat": "27.4305",
    "lng": "89.41334"
  },
  {
    "country": "BT",
    "name": "Pajo",
    "lat": "27.53333",
    "lng": "89.88333"
  },
  {
    "country": "BT",
    "name": "Mongar",
    "lat": "27.27471",
    "lng": "91.23963"
  },
  {
    "country": "BT",
    "name": "Lhuentse",
    "lat": "27.66787",
    "lng": "91.18393"
  },
  {
    "country": "BT",
    "name": "Ha",
    "lat": "27.38747",
    "lng": "89.28074"
  },
  {
    "country": "BT",
    "name": "Gasa",
    "lat": "27.90372",
    "lng": "89.72689"
  },
  {
    "country": "BT",
    "name": "Daphu",
    "lat": "26.96667",
    "lng": "89.38333"
  },
  {
    "country": "BT",
    "name": "Tsirang",
    "lat": "27.0219",
    "lng": "90.12291"
  },
  {
    "country": "BT",
    "name": "Tsimasham",
    "lat": "27.0989",
    "lng": "89.53604"
  },
  {
    "country": "BT",
    "name": "Jakar",
    "lat": "27.54918",
    "lng": "90.7525"
  },
  {
    "country": "BT",
    "name": "Panbang",
    "lat": "26.86667",
    "lng": "90.98333"
  },
  {
    "country": "BT",
    "name": "Samtse",
    "lat": "26.89903",
    "lng": "89.09951"
  },
  {
    "country": "BT",
    "name": "Pemagatshel",
    "lat": "27.03795",
    "lng": "91.40305"
  },
  {
    "country": "BT",
    "name": "Samdrup Jongkhar",
    "lat": "26.80069",
    "lng": "91.50519"
  },
  {
    "country": "BT",
    "name": "Lungtenzampa",
    "lat": "27.46821",
    "lng": "89.64441"
  },
  {
    "country": "BW",
    "name": "Werda",
    "lat": "-25.26667",
    "lng": "23.28333"
  },
  {
    "country": "BW",
    "name": "Tshabong",
    "lat": "-26.05",
    "lng": "22.45"
  },
  {
    "country": "BW",
    "name": "Tsau",
    "lat": "-20.15",
    "lng": "22.45"
  },
  {
    "country": "BW",
    "name": "Tonota",
    "lat": "-21.44236",
    "lng": "27.46153"
  },
  {
    "country": "BW",
    "name": "Tobane",
    "lat": "-21.95",
    "lng": "27.9"
  },
  {
    "country": "BW",
    "name": "Thamaga",
    "lat": "-24.67014",
    "lng": "25.53975"
  },
  {
    "country": "BW",
    "name": "Tamasane",
    "lat": "-22.4184",
    "lng": "27.40127"
  },
  {
    "country": "BW",
    "name": "Sua",
    "lat": "-20.05",
    "lng": "26.2"
  },
  {
    "country": "BW",
    "name": "Shakawe",
    "lat": "-18.36536",
    "lng": "21.84219"
  },
  {
    "country": "BW",
    "name": "Serowe",
    "lat": "-22.38754",
    "lng": "26.71077"
  },
  {
    "country": "BW",
    "name": "Selebi-Phikwe",
    "lat": "-21.97895",
    "lng": "27.84296"
  },
  {
    "country": "BW",
    "name": "Sekoma",
    "lat": "-24.4",
    "lng": "23.88333"
  },
  {
    "country": "BW",
    "name": "Sehithwa",
    "lat": "-20.46667",
    "lng": "22.71667"
  },
  {
    "country": "BW",
    "name": "Sefophe",
    "lat": "-22.18333",
    "lng": "27.96667"
  },
  {
    "country": "BW",
    "name": "Sebina",
    "lat": "-20.86667",
    "lng": "27.25"
  },
  {
    "country": "BW",
    "name": "Ratholo",
    "lat": "-22.72454",
    "lng": "27.57199"
  },
  {
    "country": "BW",
    "name": "Ramotswa",
    "lat": "-24.87158",
    "lng": "25.86989"
  },
  {
    "country": "BW",
    "name": "Ramokgonami",
    "lat": "-22.8645",
    "lng": "27.42391"
  },
  {
    "country": "BW",
    "name": "Rakops",
    "lat": "-21.02257",
    "lng": "24.36052"
  },
  {
    "country": "BW",
    "name": "Pilikwe",
    "lat": "-22.79904",
    "lng": "27.19376"
  },
  {
    "country": "BW",
    "name": "Pilane",
    "lat": "-24.45",
    "lng": "26.13333"
  },
  {
    "country": "BW",
    "name": "Pandamatenga",
    "lat": "-18.52779",
    "lng": "25.62698"
  },
  {
    "country": "BW",
    "name": "Palapye",
    "lat": "-22.54605",
    "lng": "27.12507"
  },
  {
    "country": "BW",
    "name": "Otse",
    "lat": "-25.01667",
    "lng": "25.73333"
  },
  {
    "country": "BW",
    "name": "Orapa",
    "lat": "-21.3115",
    "lng": "25.37642"
  },
  {
    "country": "BW",
    "name": "Nokaneng",
    "lat": "-19.66667",
    "lng": "22.26667"
  },
  {
    "country": "BW",
    "name": "Nata",
    "lat": "-20.21667",
    "lng": "26.18333"
  },
  {
    "country": "BW",
    "name": "Mosopa",
    "lat": "-24.7718",
    "lng": "25.42156"
  },
  {
    "country": "BW",
    "name": "Mosetse",
    "lat": "-20.75",
    "lng": "26.65"
  },
  {
    "country": "BW",
    "name": "Mopipi",
    "lat": "-21.18333",
    "lng": "24.88333"
  },
  {
    "country": "BW",
    "name": "Mookane",
    "lat": "-23.68805",
    "lng": "26.65948"
  },
  {
    "country": "BW",
    "name": "Maunatlala",
    "lat": "-22.59701",
    "lng": "27.63006"
  },
  {
    "country": "BW",
    "name": "Molepolole",
    "lat": "-24.40659",
    "lng": "25.49508"
  },
  {
    "country": "BW",
    "name": "Makobeng",
    "lat": "-22.99637",
    "lng": "27.66766"
  },
  {
    "country": "BW",
    "name": "Moijabana",
    "lat": "-22.43333",
    "lng": "26.41667"
  },
  {
    "country": "BW",
    "name": "Mogoditshane",
    "lat": "-24.62694",
    "lng": "25.86556"
  },
  {
    "country": "BW",
    "name": "Mogapinyana",
    "lat": "-22.36667",
    "lng": "27.6"
  },
  {
    "country": "BW",
    "name": "Mogapi",
    "lat": "-22.32301",
    "lng": "27.83492"
  },
  {
    "country": "BW",
    "name": "Mochudi",
    "lat": "-24.41667",
    "lng": "26.15"
  },
  {
    "country": "BW",
    "name": "Mmathubudukwane",
    "lat": "-24.6",
    "lng": "26.43333"
  },
  {
    "country": "BW",
    "name": "Maun",
    "lat": "-19.98333",
    "lng": "23.41667"
  },
  {
    "country": "BW",
    "name": "Mathakola",
    "lat": "-22.72125",
    "lng": "27.31057"
  },
  {
    "country": "BW",
    "name": "Mathathane",
    "lat": "-22.26875",
    "lng": "28.74946"
  },
  {
    "country": "BW",
    "name": "Mathambgwane",
    "lat": "-20.99075",
    "lng": "27.33158"
  },
  {
    "country": "BW",
    "name": "Masunga",
    "lat": "-20.62455",
    "lng": "27.44875"
  },
  {
    "country": "BW",
    "name": "Manyana",
    "lat": "-23.4",
    "lng": "21.71667"
  },
  {
    "country": "BW",
    "name": "Makwata",
    "lat": "-23.28333",
    "lng": "27.3"
  },
  {
    "country": "BW",
    "name": "Makoba",
    "lat": "-23.48333",
    "lng": "27.11667"
  },
  {
    "country": "BW",
    "name": "Makaleng",
    "lat": "-20.9",
    "lng": "27.28333"
  },
  {
    "country": "BW",
    "name": "Mahalapye",
    "lat": "-23.10407",
    "lng": "26.81421"
  },
  {
    "country": "BW",
    "name": "Magothla",
    "lat": "-23.56667",
    "lng": "27"
  },
  {
    "country": "BW",
    "name": "Machaneng",
    "lat": "-23.18621",
    "lng": "27.48856"
  },
  {
    "country": "BW",
    "name": "Mabuli",
    "lat": "-25.78333",
    "lng": "24.6"
  },
  {
    "country": "BW",
    "name": "Maapi",
    "lat": "-22.75785",
    "lng": "27.35001"
  },
  {
    "country": "BW",
    "name": "Lokwabe",
    "lat": "-24.16667",
    "lng": "21.83333"
  },
  {
    "country": "BW",
    "name": "Lobatse",
    "lat": "-25.22435",
    "lng": "25.67728"
  },
  {
    "country": "BW",
    "name": "Letlhakeng",
    "lat": "-24.09442",
    "lng": "25.02977"
  },
  {
    "country": "BW",
    "name": "Letlhakane",
    "lat": "-21.41494",
    "lng": "25.59263"
  },
  {
    "country": "BW",
    "name": "Lenchwe Le Tau",
    "lat": "-24.38333",
    "lng": "25.85"
  },
  {
    "country": "BW",
    "name": "Lehututu",
    "lat": "-23.96667",
    "lng": "21.86667"
  },
  {
    "country": "BW",
    "name": "Letsheng",
    "lat": "-22.66384",
    "lng": "27.2239"
  },
  {
    "country": "BW",
    "name": "Kurametsi",
    "lat": "-23.4",
    "lng": "27.06667"
  },
  {
    "country": "BW",
    "name": "Kopong",
    "lat": "-24.48333",
    "lng": "25.88333"
  },
  {
    "country": "BW",
    "name": "Khudumelapye",
    "lat": "-23.88333",
    "lng": "24.75"
  },
  {
    "country": "BW",
    "name": "Khakhea",
    "lat": "-24.68954",
    "lng": "23.49403"
  },
  {
    "country": "BW",
    "name": "Kasane",
    "lat": "-17.80165",
    "lng": "25.16024"
  },
  {
    "country": "BW",
    "name": "Kanye",
    "lat": "-24.96675",
    "lng": "25.33273"
  },
  {
    "country": "BW",
    "name": "Kang",
    "lat": "-23.67518",
    "lng": "22.78762"
  },
  {
    "country": "BW",
    "name": "Kalamare",
    "lat": "-22.93369",
    "lng": "26.57032"
  },
  {
    "country": "BW",
    "name": "Janeng",
    "lat": "-25.41667",
    "lng": "25.55"
  },
  {
    "country": "BW",
    "name": "Hukuntsi",
    "lat": "-23.9988",
    "lng": "21.77962"
  },
  {
    "country": "BW",
    "name": "Gweta",
    "lat": "-20.18333",
    "lng": "25.23333"
  },
  {
    "country": "BW",
    "name": "Gobojango",
    "lat": "-21.8327",
    "lng": "28.72882"
  },
  {
    "country": "BW",
    "name": "Ghanzi",
    "lat": "-21.69785",
    "lng": "21.64581"
  },
  {
    "country": "BW",
    "name": "Gaborone",
    "lat": "-24.65451",
    "lng": "25.90859"
  },
  {
    "country": "BW",
    "name": "Gabane",
    "lat": "-24.66667",
    "lng": "25.78222"
  },
  {
    "country": "BW",
    "name": "Francistown",
    "lat": "-21.17",
    "lng": "27.50778"
  },
  {
    "country": "BW",
    "name": "Dutlwe",
    "lat": "-23.98333",
    "lng": "23.9"
  },
  {
    "country": "BW",
    "name": "Dukwe",
    "lat": "-20.58333",
    "lng": "26.41667"
  },
  {
    "country": "BW",
    "name": "Dekar",
    "lat": "-21.53333",
    "lng": "21.93333"
  },
  {
    "country": "BW",
    "name": "Botlhapatlou",
    "lat": "-24.02591",
    "lng": "25.48976"
  },
  {
    "country": "BW",
    "name": "Bokaa",
    "lat": "-24.45",
    "lng": "26.01667"
  },
  {
    "country": "BW",
    "name": "Gaphatshwe",
    "lat": "-24.57389",
    "lng": "25.83417"
  },
  {
    "country": "BW",
    "name": "Metsemotlhaba",
    "lat": "-24.55139",
    "lng": "25.80306"
  },
  {
    "country": "BW",
    "name": "Mmopone",
    "lat": "-24.56694",
    "lng": "25.87417"
  },
  {
    "country": "BW",
    "name": "Nkoyaphiri",
    "lat": "-24.63222",
    "lng": "25.83139"
  },
  {
    "country": "BW",
    "name": "Jwaneng",
    "lat": "-24.60167",
    "lng": "24.72806"
  },
  {
    "country": "BY",
    "name": "Indura",
    "lat": "53.4605",
    "lng": "23.8823"
  },
  {
    "country": "BY",
    "name": "Skidel’",
    "lat": "53.5904",
    "lng": "24.2478"
  },
  {
    "country": "BY",
    "name": "Znamenka",
    "lat": "51.88168",
    "lng": "23.65545"
  },
  {
    "country": "BY",
    "name": "Horad Zhodzina",
    "lat": "54.0985",
    "lng": "28.3331"
  },
  {
    "country": "BY",
    "name": "Zhlobin",
    "lat": "52.8926",
    "lng": "30.024"
  },
  {
    "country": "BY",
    "name": "Zhytkavichy",
    "lat": "52.2168",
    "lng": "27.8561"
  },
  {
    "country": "BY",
    "name": "Zhirovichi",
    "lat": "53.0131",
    "lng": "25.3443"
  },
  {
    "country": "BY",
    "name": "Zhaludok",
    "lat": "53.5974",
    "lng": "24.9828"
  },
  {
    "country": "BY",
    "name": "Zhdanovichy",
    "lat": "53.9432",
    "lng": "27.425"
  },
  {
    "country": "BY",
    "name": "Zhabinka",
    "lat": "52.1984",
    "lng": "24.0115"
  },
  {
    "country": "BY",
    "name": "Zyembin",
    "lat": "54.3579",
    "lng": "28.2207"
  },
  {
    "country": "BY",
    "name": "Zel’va",
    "lat": "53.1504",
    "lng": "24.8153"
  },
  {
    "country": "BY",
    "name": "Zaslawye",
    "lat": "54.0114",
    "lng": "27.2695"
  },
  {
    "country": "BY",
    "name": "Zamostochye",
    "lat": "53.8198",
    "lng": "27.8685"
  },
  {
    "country": "BY",
    "name": "Yel’sk",
    "lat": "51.8141",
    "lng": "29.1522"
  },
  {
    "country": "BY",
    "name": "Yalizava",
    "lat": "53.3994",
    "lng": "29.0048"
  },
  {
    "country": "BY",
    "name": "Vysokaye",
    "lat": "52.37091",
    "lng": "23.37083"
  },
  {
    "country": "BY",
    "name": "Voranava",
    "lat": "54.1492",
    "lng": "25.3112"
  },
  {
    "country": "BY",
    "name": "Vitebsk",
    "lat": "55.1904",
    "lng": "30.2049"
  },
  {
    "country": "BY",
    "name": "Vishow",
    "lat": "53.9805",
    "lng": "29.9925"
  },
  {
    "country": "BY",
    "name": "Vishnyeva",
    "lat": "54.7102",
    "lng": "26.5228"
  },
  {
    "country": "BY",
    "name": "Vilyeyka",
    "lat": "54.4914",
    "lng": "26.9111"
  },
  {
    "country": "BY",
    "name": "Vidzy",
    "lat": "55.3945",
    "lng": "26.6305"
  },
  {
    "country": "BY",
    "name": "Veyno",
    "lat": "53.83333",
    "lng": "30.38333"
  },
  {
    "country": "BY",
    "name": "Vyetka",
    "lat": "52.5591",
    "lng": "31.1794"
  },
  {
    "country": "BY",
    "name": "Vyerkhnyadzvinsk",
    "lat": "55.7777",
    "lng": "27.9389"
  },
  {
    "country": "BY",
    "name": "Volkovysk",
    "lat": "53.1561",
    "lng": "24.4513"
  },
  {
    "country": "BY",
    "name": "Vasilyevichy",
    "lat": "52.2512",
    "lng": "29.8288"
  },
  {
    "country": "BY",
    "name": "Valozhyn",
    "lat": "54.0892",
    "lng": "26.5266"
  },
  {
    "country": "BY",
    "name": "Uzda",
    "lat": "53.4627",
    "lng": "27.2137"
  },
  {
    "country": "BY",
    "name": "Ushachy",
    "lat": "55.179",
    "lng": "28.6158"
  },
  {
    "country": "BY",
    "name": "Urechcha",
    "lat": "52.9479",
    "lng": "27.893"
  },
  {
    "country": "BY",
    "name": "Turaw",
    "lat": "52.0683",
    "lng": "27.735"
  },
  {
    "country": "BY",
    "name": "Talachyn",
    "lat": "54.4087",
    "lng": "29.6955"
  },
  {
    "country": "BY",
    "name": "Tsimkavichy",
    "lat": "53.0672",
    "lng": "26.9902"
  },
  {
    "country": "BY",
    "name": "Tsyelyakhany",
    "lat": "52.5175",
    "lng": "25.8429"
  },
  {
    "country": "BY",
    "name": "Svislach",
    "lat": "53.03474",
    "lng": "24.09829"
  },
  {
    "country": "BY",
    "name": "Svir",
    "lat": "54.8517",
    "lng": "26.395"
  },
  {
    "country": "BY",
    "name": "Svyetlahorsk",
    "lat": "52.6329",
    "lng": "29.7389"
  },
  {
    "country": "BY",
    "name": "Stowbtsy",
    "lat": "53.4785",
    "lng": "26.7434"
  },
  {
    "country": "BY",
    "name": "Stolin",
    "lat": "51.89115",
    "lng": "26.84597"
  },
  {
    "country": "BY",
    "name": "Staryya Darohi",
    "lat": "53.0402",
    "lng": "28.267"
  },
  {
    "country": "BY",
    "name": "Starobin",
    "lat": "52.7267",
    "lng": "27.4606"
  },
  {
    "country": "BY",
    "name": "Stan’kava",
    "lat": "53.6292",
    "lng": "27.229"
  },
  {
    "country": "BY",
    "name": "Sasnovy Bor",
    "lat": "52.5194",
    "lng": "29.5988"
  },
  {
    "country": "BY",
    "name": "Sapotskin",
    "lat": "53.8329",
    "lng": "23.6598"
  },
  {
    "country": "BY",
    "name": "Soly",
    "lat": "54.51301",
    "lng": "26.19381"
  },
  {
    "country": "BY",
    "name": "Snow",
    "lat": "53.2201",
    "lng": "26.401"
  },
  {
    "country": "BY",
    "name": "Smarhon’",
    "lat": "54.4798",
    "lng": "26.3957"
  },
  {
    "country": "BY",
    "name": "Horad Smalyavichy",
    "lat": "54.0249",
    "lng": "28.0894"
  },
  {
    "country": "BY",
    "name": "Smilavichy",
    "lat": "53.7496",
    "lng": "28.0115"
  },
  {
    "country": "BY",
    "name": "Slutsk",
    "lat": "53.0274",
    "lng": "27.5597"
  },
  {
    "country": "BY",
    "name": "Slonim",
    "lat": "53.0869",
    "lng": "25.3163"
  },
  {
    "country": "BY",
    "name": "Slabada",
    "lat": "54.0087",
    "lng": "27.8866"
  },
  {
    "country": "BY",
    "name": "Slawharad",
    "lat": "53.4429",
    "lng": "31.0014"
  },
  {
    "country": "BY",
    "name": "Shklow",
    "lat": "54.2131",
    "lng": "30.2877"
  },
  {
    "country": "BY",
    "name": "Shchuchyn",
    "lat": "53.6014",
    "lng": "24.7465"
  },
  {
    "country": "BY",
    "name": "Sharkawshchyna",
    "lat": "55.3689",
    "lng": "27.4686"
  },
  {
    "country": "BY",
    "name": "Syanno",
    "lat": "54.8108",
    "lng": "29.7086"
  },
  {
    "country": "BY",
    "name": "Syenitsa",
    "lat": "53.8313",
    "lng": "27.5343"
  },
  {
    "country": "BY",
    "name": "Syomkava",
    "lat": "54.0101",
    "lng": "27.441"
  },
  {
    "country": "BY",
    "name": "Sarachy",
    "lat": "52.7867",
    "lng": "28.0186"
  },
  {
    "country": "BY",
    "name": "Samakhvalavichy",
    "lat": "53.7396",
    "lng": "27.5037"
  },
  {
    "country": "BY",
    "name": "Salihorsk",
    "lat": "52.7876",
    "lng": "27.5415"
  },
  {
    "country": "BY",
    "name": "Ruzhany",
    "lat": "52.86322",
    "lng": "24.89357"
  },
  {
    "country": "BY",
    "name": "Rudzyensk",
    "lat": "53.5983",
    "lng": "27.8621"
  },
  {
    "country": "BY",
    "name": "Rasony",
    "lat": "55.9058",
    "lng": "28.8135"
  },
  {
    "country": "BY",
    "name": "Ross’",
    "lat": "53.28451",
    "lng": "24.40335"
  },
  {
    "country": "BY",
    "name": "Rahachow",
    "lat": "53.0934",
    "lng": "30.0495"
  },
  {
    "country": "BY",
    "name": "Rechytsa",
    "lat": "52.3617",
    "lng": "30.3916"
  },
  {
    "country": "BY",
    "name": "Rakaw",
    "lat": "53.9674",
    "lng": "27.0562"
  },
  {
    "country": "BY",
    "name": "Radashkovichy",
    "lat": "54.1554",
    "lng": "27.2412"
  },
  {
    "country": "BY",
    "name": "Pukhavichy",
    "lat": "53.5297",
    "lng": "28.2467"
  },
  {
    "country": "BY",
    "name": "Pruzhany",
    "lat": "52.556",
    "lng": "24.4573"
  },
  {
    "country": "BY",
    "name": "Prawdzinski",
    "lat": "53.5248",
    "lng": "27.8303"
  },
  {
    "country": "BY",
    "name": "Polatsk",
    "lat": "55.4879",
    "lng": "28.7856"
  },
  {
    "country": "BY",
    "name": "Plyeshchanitsy",
    "lat": "54.4235",
    "lng": "27.8301"
  },
  {
    "country": "BY",
    "name": "Pinsk",
    "lat": "52.1229",
    "lng": "26.0951"
  },
  {
    "country": "BY",
    "name": "Pyatryshki",
    "lat": "54.0686",
    "lng": "27.2179"
  },
  {
    "country": "BY",
    "name": "Pyetrykaw",
    "lat": "52.1289",
    "lng": "28.4921"
  },
  {
    "country": "BY",
    "name": "Pastavy",
    "lat": "55.11676",
    "lng": "26.83263"
  },
  {
    "country": "BY",
    "name": "Parychy",
    "lat": "52.8042",
    "lng": "29.4176"
  },
  {
    "country": "BY",
    "name": "Azyartso",
    "lat": "53.8397",
    "lng": "27.3917"
  },
  {
    "country": "BY",
    "name": "Osveya",
    "lat": "56.0147",
    "lng": "28.11049"
  },
  {
    "country": "BY",
    "name": "Astravyets",
    "lat": "54.61378",
    "lng": "25.95537"
  },
  {
    "country": "BY",
    "name": "Astrashytski Haradok",
    "lat": "54.0651",
    "lng": "27.695"
  },
  {
    "country": "BY",
    "name": "Asnyezhytsy",
    "lat": "52.1891",
    "lng": "26.1299"
  },
  {
    "country": "BY",
    "name": "Asipovichy",
    "lat": "53.3011",
    "lng": "28.6386"
  },
  {
    "country": "BY",
    "name": "Orsha",
    "lat": "54.5081",
    "lng": "30.4172"
  },
  {
    "country": "BY",
    "name": "Aktsyabrski",
    "lat": "52.644",
    "lng": "28.8801"
  },
  {
    "country": "BY",
    "name": "Novy Svyerzhan’",
    "lat": "53.4542",
    "lng": "26.7301"
  },
  {
    "country": "BY",
    "name": "Kadino",
    "lat": "53.88389",
    "lng": "30.52028"
  },
  {
    "country": "BY",
    "name": "Novoye Medvezhino",
    "lat": "53.88333",
    "lng": "27.45"
  },
  {
    "country": "BY",
    "name": "Novosel’ye",
    "lat": "53.9162",
    "lng": "27.2009"
  },
  {
    "country": "BY",
    "name": "Novolukoml’",
    "lat": "54.66192",
    "lng": "29.15016"
  },
  {
    "country": "BY",
    "name": "Novaya Huta",
    "lat": "52.1032",
    "lng": "30.9837"
  },
  {
    "country": "BY",
    "name": "Nasilava",
    "lat": "54.30441",
    "lng": "26.78209"
  },
  {
    "country": "BY",
    "name": "Nyasvizh",
    "lat": "53.2189",
    "lng": "26.6779"
  },
  {
    "country": "BY",
    "name": "Nyakhachava",
    "lat": "52.644",
    "lng": "25.2027"
  },
  {
    "country": "BY",
    "name": "Navapolatsk",
    "lat": "55.5318",
    "lng": "28.5987"
  },
  {
    "country": "BY",
    "name": "Novogrudok",
    "lat": "53.5942",
    "lng": "25.8191"
  },
  {
    "country": "BY",
    "name": "Narowlya",
    "lat": "51.7961",
    "lng": "29.5004"
  },
  {
    "country": "BY",
    "name": "Narach",
    "lat": "54.9102",
    "lng": "26.708"
  },
  {
    "country": "BY",
    "name": "Narach",
    "lat": "54.5652",
    "lng": "26.7314"
  },
  {
    "country": "BY",
    "name": "Myshkavichy",
    "lat": "53.2172",
    "lng": "29.512"
  },
  {
    "country": "BY",
    "name": "Myadzyel",
    "lat": "54.8789",
    "lng": "26.9371"
  },
  {
    "country": "BY",
    "name": "Mstsislaw",
    "lat": "54.0185",
    "lng": "31.7217"
  },
  {
    "country": "BY",
    "name": "Motal’",
    "lat": "52.3138",
    "lng": "25.6072"
  },
  {
    "country": "BY",
    "name": "Mosar",
    "lat": "55.2232",
    "lng": "27.4609"
  },
  {
    "country": "BY",
    "name": "Mir",
    "lat": "53.4544",
    "lng": "26.467"
  },
  {
    "country": "BY",
    "name": "Myory",
    "lat": "55.6222",
    "lng": "27.6281"
  },
  {
    "country": "BY",
    "name": "Minsk",
    "lat": "53.9",
    "lng": "27.56667"
  },
  {
    "country": "BY",
    "name": "Mikashevichy",
    "lat": "52.2173",
    "lng": "27.476"
  },
  {
    "country": "BY",
    "name": "Myazhysyatki",
    "lat": "53.7776",
    "lng": "30.1765"
  },
  {
    "country": "BY",
    "name": "Mazyr",
    "lat": "52.0495",
    "lng": "29.2456"
  },
  {
    "country": "BY",
    "name": "Mosty",
    "lat": "53.4122",
    "lng": "24.5387"
  },
  {
    "country": "BY",
    "name": "Mar’’ina Horka",
    "lat": "53.509",
    "lng": "28.147"
  },
  {
    "country": "BY",
    "name": "Malaryta",
    "lat": "51.7905",
    "lng": "24.074"
  },
  {
    "country": "BY",
    "name": "Maladzyechna",
    "lat": "54.3167",
    "lng": "26.854"
  },
  {
    "country": "BY",
    "name": "Mahilyow",
    "lat": "53.9168",
    "lng": "30.3449"
  },
  {
    "country": "BY",
    "name": "Machulishchy",
    "lat": "53.7788",
    "lng": "27.5948"
  },
  {
    "country": "BY",
    "name": "Lyubcha",
    "lat": "53.7522",
    "lng": "26.0603"
  },
  {
    "country": "BY",
    "name": "Lyuban’",
    "lat": "52.7985",
    "lng": "28.0048"
  },
  {
    "country": "BY",
    "name": "Lyntupy",
    "lat": "55.0516",
    "lng": "26.3103"
  },
  {
    "country": "BY",
    "name": "Lyepyel’",
    "lat": "54.8814",
    "lng": "28.699"
  },
  {
    "country": "BY",
    "name": "Lyakhavichy",
    "lat": "53.0388",
    "lng": "26.2656"
  },
  {
    "country": "BY",
    "name": "Luninyets",
    "lat": "52.2472",
    "lng": "26.8047"
  },
  {
    "country": "BY",
    "name": "Luhavaya Slabada",
    "lat": "53.7823",
    "lng": "27.8434"
  },
  {
    "country": "BY",
    "name": "Loyew",
    "lat": "51.9458",
    "lng": "30.7953"
  },
  {
    "country": "BY",
    "name": "Loshnitsa",
    "lat": "54.2796",
    "lng": "28.7649"
  },
  {
    "country": "BY",
    "name": "Lahoysk",
    "lat": "54.2064",
    "lng": "27.8512"
  },
  {
    "country": "BY",
    "name": "Lyozna",
    "lat": "55.0247",
    "lng": "30.797"
  },
  {
    "country": "BY",
    "name": "Lida",
    "lat": "53.88333",
    "lng": "25.29972"
  },
  {
    "country": "BY",
    "name": "Lyel’chytsy",
    "lat": "51.7862",
    "lng": "28.3288"
  },
  {
    "country": "BY",
    "name": "Lahishyn",
    "lat": "52.339",
    "lng": "25.9867"
  },
  {
    "country": "BY",
    "name": "Krychaw",
    "lat": "53.7125",
    "lng": "31.717"
  },
  {
    "country": "BY",
    "name": "Krupki",
    "lat": "54.3178",
    "lng": "29.1374"
  },
  {
    "country": "BY",
    "name": "Kruhlaye",
    "lat": "54.2497",
    "lng": "29.7968"
  },
  {
    "country": "BY",
    "name": "Kryvichy",
    "lat": "54.7132",
    "lng": "27.2886"
  },
  {
    "country": "BY",
    "name": "Kreva",
    "lat": "54.3118",
    "lng": "26.2916"
  },
  {
    "country": "BY",
    "name": "Krasnyy Bereg",
    "lat": "53.3291",
    "lng": "30.1929"
  },
  {
    "country": "BY",
    "name": "Krasnaye",
    "lat": "54.2438",
    "lng": "27.0758"
  },
  {
    "country": "BY",
    "name": "Krasnosel’skiy",
    "lat": "53.2645",
    "lng": "24.4301"
  },
  {
    "country": "BY",
    "name": "Krasnapollye",
    "lat": "53.3353",
    "lng": "31.3999"
  },
  {
    "country": "BY",
    "name": "Chyrvonaya Slabada",
    "lat": "52.8522",
    "lng": "27.1698"
  },
  {
    "country": "BY",
    "name": "Kastsyukowka",
    "lat": "52.5387",
    "lng": "30.9173"
  },
  {
    "country": "BY",
    "name": "Kastsyukovichy",
    "lat": "53.3525",
    "lng": "32.0514"
  },
  {
    "country": "BY",
    "name": "Kosava",
    "lat": "52.7583",
    "lng": "25.1554"
  },
  {
    "country": "BY",
    "name": "Korolëv Stan",
    "lat": "53.9865",
    "lng": "27.7982"
  },
  {
    "country": "BY",
    "name": "Karma",
    "lat": "53.1301",
    "lng": "30.8016"
  },
  {
    "country": "BY",
    "name": "Karanyowka",
    "lat": "52.3506",
    "lng": "31.1121"
  },
  {
    "country": "BY",
    "name": "Karelichy",
    "lat": "53.5648",
    "lng": "26.1406"
  },
  {
    "country": "BY",
    "name": "Kapyl’",
    "lat": "53.1516",
    "lng": "27.0913"
  },
  {
    "country": "BY",
    "name": "Konstantinovo",
    "lat": "54.6593",
    "lng": "29.2684"
  },
  {
    "country": "BY",
    "name": "Kalodzishchy",
    "lat": "53.944",
    "lng": "27.7823"
  },
  {
    "country": "BY",
    "name": "Kokhanava",
    "lat": "54.4611",
    "lng": "30.0018"
  },
  {
    "country": "BY",
    "name": "Kobryn",
    "lat": "52.2138",
    "lng": "24.3564"
  },
  {
    "country": "BY",
    "name": "Klimavichy",
    "lat": "53.6079",
    "lng": "31.9586"
  },
  {
    "country": "BY",
    "name": "Klichaw",
    "lat": "53.4923",
    "lng": "29.3356"
  },
  {
    "country": "BY",
    "name": "Klyetsk",
    "lat": "53.0635",
    "lng": "26.6321"
  },
  {
    "country": "BY",
    "name": "Kirawsk",
    "lat": "53.2693",
    "lng": "29.4752"
  },
  {
    "country": "BY",
    "name": "Khoyniki",
    "lat": "51.8911",
    "lng": "29.9552"
  },
  {
    "country": "BY",
    "name": "Khotsimsk",
    "lat": "53.4086",
    "lng": "32.578"
  },
  {
    "country": "BY",
    "name": "Kholopenichi",
    "lat": "54.51746",
    "lng": "28.95645"
  },
  {
    "country": "BY",
    "name": "Khodasy",
    "lat": "53.9266",
    "lng": "31.4779"
  },
  {
    "country": "BY",
    "name": "Khal’ch",
    "lat": "52.5643",
    "lng": "31.1364"
  },
  {
    "country": "BY",
    "name": "Kamyanyuki",
    "lat": "52.55757",
    "lng": "23.80525"
  },
  {
    "country": "BY",
    "name": "Kamyennyya Lavy",
    "lat": "54.0898",
    "lng": "30.2962"
  },
  {
    "country": "BY",
    "name": "Kamyanyets",
    "lat": "52.40013",
    "lng": "23.81"
  },
  {
    "country": "BY",
    "name": "Kalinkavichy",
    "lat": "52.1323",
    "lng": "29.3257"
  },
  {
    "country": "BY",
    "name": "Iwye",
    "lat": "53.9299",
    "lng": "25.7727"
  },
  {
    "country": "BY",
    "name": "Ivyanyets",
    "lat": "53.8864",
    "lng": "26.7432"
  },
  {
    "country": "BY",
    "name": "Ivatsevichy",
    "lat": "52.709",
    "lng": "25.3401"
  },
  {
    "country": "BY",
    "name": "Ivanava",
    "lat": "52.1451",
    "lng": "25.5365"
  },
  {
    "country": "BY",
    "name": "Il’ya",
    "lat": "54.4167",
    "lng": "27.2958"
  },
  {
    "country": "BY",
    "name": "Hrodna",
    "lat": "53.6884",
    "lng": "23.8258"
  },
  {
    "country": "BY",
    "name": "Horki",
    "lat": "54.2862",
    "lng": "30.9863"
  },
  {
    "country": "BY",
    "name": "Gomel",
    "lat": "52.4345",
    "lng": "30.9754"
  },
  {
    "country": "BY",
    "name": "Hlybokaye",
    "lat": "55.1384",
    "lng": "27.6905"
  },
  {
    "country": "BY",
    "name": "Hantsavichy",
    "lat": "52.758",
    "lng": "26.43"
  },
  {
    "country": "BY",
    "name": "Hotsk",
    "lat": "52.5215",
    "lng": "27.1385"
  },
  {
    "country": "BY",
    "name": "Haradok",
    "lat": "55.4624",
    "lng": "29.9845"
  },
  {
    "country": "BY",
    "name": "Haradzishcha",
    "lat": "53.3247",
    "lng": "26.0107"
  },
  {
    "country": "BY",
    "name": "Haradzyeya",
    "lat": "53.3121",
    "lng": "26.538"
  },
  {
    "country": "BY",
    "name": "Hal’shany",
    "lat": "54.2585",
    "lng": "26.0144"
  },
  {
    "country": "BY",
    "name": "Hlusk",
    "lat": "52.903",
    "lng": "28.6845"
  },
  {
    "country": "BY",
    "name": "Hlusha",
    "lat": "53.0868",
    "lng": "28.8567"
  },
  {
    "country": "BY",
    "name": "Hyeranyony",
    "lat": "54.1159",
    "lng": "25.5773"
  },
  {
    "country": "BY",
    "name": "Hatava",
    "lat": "53.7829",
    "lng": "27.6407"
  },
  {
    "country": "BY",
    "name": "Dzyarzhynsk",
    "lat": "53.6832",
    "lng": "27.138"
  },
  {
    "country": "BY",
    "name": "Dyatlovo",
    "lat": "53.4631",
    "lng": "25.4068"
  },
  {
    "country": "BY",
    "name": "Dukora",
    "lat": "53.6786",
    "lng": "27.94"
  },
  {
    "country": "BY",
    "name": "Dubrowna",
    "lat": "54.5716",
    "lng": "30.691"
  },
  {
    "country": "BY",
    "name": "Drybin",
    "lat": "54.1192",
    "lng": "31.0939"
  },
  {
    "country": "BY",
    "name": "Druya",
    "lat": "55.7906",
    "lng": "27.4505"
  },
  {
    "country": "BY",
    "name": "Drahichyn",
    "lat": "52.1874",
    "lng": "25.1597"
  },
  {
    "country": "BY",
    "name": "Dowsk",
    "lat": "53.1571",
    "lng": "30.4601"
  },
  {
    "country": "BY",
    "name": "Damachava",
    "lat": "51.75",
    "lng": "23.6"
  },
  {
    "country": "BY",
    "name": "Dokshytsy",
    "lat": "54.8918",
    "lng": "27.7667"
  },
  {
    "country": "BY",
    "name": "Dobrush",
    "lat": "52.4089",
    "lng": "31.3237"
  },
  {
    "country": "BY",
    "name": "Dzisna",
    "lat": "55.5676",
    "lng": "28.2076"
  },
  {
    "country": "BY",
    "name": "Davyd-Haradok",
    "lat": "52.0566",
    "lng": "27.2161"
  },
  {
    "country": "BY",
    "name": "Dashkawka",
    "lat": "53.7352",
    "lng": "30.2625"
  },
  {
    "country": "BY",
    "name": "Chervyen’",
    "lat": "53.7059",
    "lng": "28.4313"
  },
  {
    "country": "BY",
    "name": "Charnawchytsy",
    "lat": "52.21948",
    "lng": "23.74043"
  },
  {
    "country": "BY",
    "name": "Cherykaw",
    "lat": "53.5689",
    "lng": "31.3831"
  },
  {
    "country": "BY",
    "name": "Chachersk",
    "lat": "52.9164",
    "lng": "30.9179"
  },
  {
    "country": "BY",
    "name": "Chavusy",
    "lat": "53.8098",
    "lng": "30.9717"
  },
  {
    "country": "BY",
    "name": "Chashniki",
    "lat": "54.8584",
    "lng": "29.1608"
  },
  {
    "country": "BY",
    "name": "Bykhaw",
    "lat": "53.521",
    "lng": "30.2454"
  },
  {
    "country": "BY",
    "name": "Byaroza",
    "lat": "52.5314",
    "lng": "24.9786"
  },
  {
    "country": "BY",
    "name": "Buynichy",
    "lat": "53.8536",
    "lng": "30.2671"
  },
  {
    "country": "BY",
    "name": "Buda-Kashalyova",
    "lat": "52.7179",
    "lng": "30.5701"
  },
  {
    "country": "BY",
    "name": "Brest",
    "lat": "52.09755",
    "lng": "23.68775"
  },
  {
    "country": "BY",
    "name": "Braslaw",
    "lat": "55.6413",
    "lng": "27.0418"
  },
  {
    "country": "BY",
    "name": "Brahin",
    "lat": "51.787",
    "lng": "30.2677"
  },
  {
    "country": "BY",
    "name": "Turets-Bayary",
    "lat": "54.3785",
    "lng": "26.6581"
  },
  {
    "country": "BY",
    "name": "Baruny",
    "lat": "54.3171",
    "lng": "26.1376"
  },
  {
    "country": "BY",
    "name": "Vyaliki Trastsyanets",
    "lat": "53.851",
    "lng": "27.7139"
  },
  {
    "country": "BY",
    "name": "Vyalikaya Byerastavitsa",
    "lat": "53.196",
    "lng": "24.0166"
  },
  {
    "country": "BY",
    "name": "Bobr",
    "lat": "54.342",
    "lng": "29.2736"
  },
  {
    "country": "BY",
    "name": "Blon’",
    "lat": "53.5269",
    "lng": "28.1732"
  },
  {
    "country": "BY",
    "name": "Byarozawka",
    "lat": "53.72406",
    "lng": "25.49709"
  },
  {
    "country": "BY",
    "name": "Byerazino",
    "lat": "53.8391",
    "lng": "28.9879"
  },
  {
    "country": "BY",
    "name": "Byalynichy",
    "lat": "53.9994",
    "lng": "29.7141"
  },
  {
    "country": "BY",
    "name": "Byelaazyorsk",
    "lat": "52.4731",
    "lng": "25.1784"
  },
  {
    "country": "BY",
    "name": "Byahoml’",
    "lat": "54.7316",
    "lng": "28.0577"
  },
  {
    "country": "BY",
    "name": "Barysaw",
    "lat": "54.2279",
    "lng": "28.505"
  },
  {
    "country": "BY",
    "name": "Baranovichi",
    "lat": "53.1327",
    "lng": "26.0139"
  },
  {
    "country": "BY",
    "name": "Baran’",
    "lat": "54.4784",
    "lng": "30.3159"
  },
  {
    "country": "BY",
    "name": "Babruysk",
    "lat": "53.1384",
    "lng": "29.2214"
  },
  {
    "country": "BY",
    "name": "Ashmyany",
    "lat": "54.421",
    "lng": "25.936"
  },
  {
    "country": "BY",
    "name": "Antopal’",
    "lat": "52.2038",
    "lng": "24.7863"
  },
  {
    "country": "BY",
    "name": "Balbasava",
    "lat": "54.4207",
    "lng": "30.2909"
  },
  {
    "country": "BY",
    "name": "Ramanavichy",
    "lat": "53.8653",
    "lng": "30.5597"
  },
  {
    "country": "BY",
    "name": "Palykavichy Pyershyya",
    "lat": "53.9854",
    "lng": "30.36"
  },
  {
    "country": "BY",
    "name": "Horad Kobryn",
    "lat": "52.21611",
    "lng": "24.36639"
  },
  {
    "country": "BY",
    "name": "Horad Luninyets",
    "lat": "52.25028",
    "lng": "26.79944"
  },
  {
    "country": "BY",
    "name": "Horad Pinsk",
    "lat": "52.12139",
    "lng": "26.07278"
  },
  {
    "country": "BY",
    "name": "Horad Orsha",
    "lat": "54.51528",
    "lng": "30.40528"
  },
  {
    "country": "BY",
    "name": "Horad Rechytsa",
    "lat": "52.36389",
    "lng": "30.39472"
  },
  {
    "country": "BY",
    "name": "Horad Krychaw",
    "lat": "53.69889",
    "lng": "31.71417"
  },
  {
    "country": "BY",
    "name": "Fanipol",
    "lat": "53.74998",
    "lng": "27.33338"
  },
  {
    "country": "BY",
    "name": "Khatsyezhyna",
    "lat": "53.9094",
    "lng": "27.3069"
  },
  {
    "country": "BY",
    "name": "Schomyslitsa",
    "lat": "53.8211",
    "lng": "27.4522"
  },
  {
    "country": "BY",
    "name": "Yubilyeyny",
    "lat": "53.8191",
    "lng": "27.5215"
  },
  {
    "country": "BY",
    "name": "Atolina",
    "lat": "53.7817",
    "lng": "27.4346"
  },
  {
    "country": "BY",
    "name": "Pryvol’ny",
    "lat": "53.7969",
    "lng": "27.7967"
  },
  {
    "country": "BY",
    "name": "Enyerhyetykaw",
    "lat": "53.5871",
    "lng": "27.0535"
  },
  {
    "country": "BY",
    "name": "Svislach",
    "lat": "53.6404",
    "lng": "27.9199"
  },
  {
    "country": "BY",
    "name": "Druzhny",
    "lat": "53.6238",
    "lng": "27.8977"
  },
  {
    "country": "BY",
    "name": "Malinovka",
    "lat": "53.8579",
    "lng": "27.4374"
  },
  {
    "country": "BY",
    "name": "Peramoga",
    "lat": "52.3973",
    "lng": "31.071"
  },
  {
    "country": "BY",
    "name": "Borovlyany",
    "lat": "54.0022",
    "lng": "27.6754"
  },
  {
    "country": "BY",
    "name": "Chyst’",
    "lat": "54.2698",
    "lng": "27.1067"
  },
  {
    "country": "BY",
    "name": "Lyeskawka",
    "lat": "54.0024",
    "lng": "27.7108"
  },
  {
    "country": "BY",
    "name": "Lyasny",
    "lat": "54.0072",
    "lng": "27.6963"
  },
  {
    "country": "BY",
    "name": "Bal’shavik",
    "lat": "54.0036",
    "lng": "27.5669"
  },
  {
    "country": "BY",
    "name": "Usiazh",
    "lat": "54.07598",
    "lng": "28.00698"
  },
  {
    "country": "BY",
    "name": "Октябрьский",
    "lat": "54.04059",
    "lng": "28.19813"
  },
  {
    "country": "BY",
    "name": "Michanovichi",
    "lat": "53.73937",
    "lng": "27.69276"
  },
  {
    "country": "BY",
    "name": "Posëlok Voskhod",
    "lat": "53.7766",
    "lng": "30.3497"
  },
  {
    "country": "BZ",
    "name": "Shipyard",
    "lat": "17.89382",
    "lng": "-88.65452"
  },
  {
    "country": "BZ",
    "name": "San Pedro",
    "lat": "17.91598",
    "lng": "-87.9659"
  },
  {
    "country": "BZ",
    "name": "San Ignacio",
    "lat": "17.1588",
    "lng": "-89.0696"
  },
  {
    "country": "BZ",
    "name": "Punta Gorda",
    "lat": "16.09835",
    "lng": "-88.8097"
  },
  {
    "country": "BZ",
    "name": "Placencia",
    "lat": "16.51419",
    "lng": "-88.36647"
  },
  {
    "country": "BZ",
    "name": "Orange Walk",
    "lat": "18.08124",
    "lng": "-88.56328"
  },
  {
    "country": "BZ",
    "name": "Dangriga",
    "lat": "16.9697",
    "lng": "-88.23313"
  },
  {
    "country": "BZ",
    "name": "Corozal",
    "lat": "18.39375",
    "lng": "-88.38849"
  },
  {
    "country": "BZ",
    "name": "Benque Viejo el Carmen",
    "lat": "17.075",
    "lng": "-89.13917"
  },
  {
    "country": "BZ",
    "name": "Belmopan",
    "lat": "17.25",
    "lng": "-88.76667"
  },
  {
    "country": "BZ",
    "name": "Belize City",
    "lat": "17.49952",
    "lng": "-88.19756"
  },
  {
    "country": "BZ",
    "name": "Valley of Peace",
    "lat": "17.33472",
    "lng": "-88.83472"
  },
  {
    "country": "CA",
    "name": "Abbotsford",
    "lat": "49.05798",
    "lng": "-122.25257"
  },
  {
    "country": "CA",
    "name": "Acton Vale",
    "lat": "45.65007",
    "lng": "-72.56582"
  },
  {
    "country": "CA",
    "name": "Adstock",
    "lat": "46.05007",
    "lng": "-71.08235"
  },
  {
    "country": "CA",
    "name": "Agassiz",
    "lat": "49.23298",
    "lng": "-121.76926"
  },
  {
    "country": "CA",
    "name": "Airdrie",
    "lat": "51.30011",
    "lng": "-114.03528"
  },
  {
    "country": "CA",
    "name": "Ajax",
    "lat": "43.85012",
    "lng": "-79.03288"
  },
  {
    "country": "CA",
    "name": "Albanel",
    "lat": "48.88324",
    "lng": "-72.44867"
  },
  {
    "country": "CA",
    "name": "Alberton",
    "lat": "46.81685",
    "lng": "-64.06542"
  },
  {
    "country": "CA",
    "name": "Alma",
    "lat": "48.55009",
    "lng": "-71.6491"
  },
  {
    "country": "CA",
    "name": "Altona",
    "lat": "49.10469",
    "lng": "-97.55961"
  },
  {
    "country": "CA",
    "name": "Amherst",
    "lat": "45.83345",
    "lng": "-64.19874"
  },
  {
    "country": "CA",
    "name": "Amherstburg",
    "lat": "42.11679",
    "lng": "-83.04985"
  },
  {
    "country": "CA",
    "name": "Amos",
    "lat": "48.56688",
    "lng": "-78.11624"
  },
  {
    "country": "CA",
    "name": "Ange-Gardien",
    "lat": "45.35008",
    "lng": "-72.93244"
  },
  {
    "country": "CA",
    "name": "Angus",
    "lat": "44.31681",
    "lng": "-79.88295"
  },
  {
    "country": "CA",
    "name": "Anmore",
    "lat": "49.31637",
    "lng": "-122.85263"
  },
  {
    "country": "CA",
    "name": "Antigonish",
    "lat": "45.61685",
    "lng": "-61.99858"
  },
  {
    "country": "CA",
    "name": "Armstrong",
    "lat": "50.44979",
    "lng": "-119.20235"
  },
  {
    "country": "CA",
    "name": "Arnprior",
    "lat": "45.43341",
    "lng": "-76.34939"
  },
  {
    "country": "CA",
    "name": "Asbestos",
    "lat": "45.76678",
    "lng": "-71.9324"
  },
  {
    "country": "CA",
    "name": "Ashcroft",
    "lat": "50.72372",
    "lng": "-121.28207"
  },
  {
    "country": "CA",
    "name": "Assiniboia",
    "lat": "49.63336",
    "lng": "-105.98446"
  },
  {
    "country": "CA",
    "name": "Athabasca",
    "lat": "54.71687",
    "lng": "-113.28537"
  },
  {
    "country": "CA",
    "name": "Atikokan",
    "lat": "48.75667",
    "lng": "-91.62409"
  },
  {
    "country": "CA",
    "name": "Aylmer",
    "lat": "42.76679",
    "lng": "-80.98302"
  },
  {
    "country": "CA",
    "name": "Baie-Comeau",
    "lat": "49.21679",
    "lng": "-68.14894"
  },
  {
    "country": "CA",
    "name": "Baie-D'Urfé",
    "lat": "45.41397",
    "lng": "-73.91586"
  },
  {
    "country": "CA",
    "name": "Bancroft",
    "lat": "45.05752",
    "lng": "-77.85702"
  },
  {
    "country": "CA",
    "name": "Banff",
    "lat": "51.17622",
    "lng": "-115.56982"
  },
  {
    "country": "CA",
    "name": "Barraute",
    "lat": "48.43349",
    "lng": "-77.63279"
  },
  {
    "country": "CA",
    "name": "Barrhead",
    "lat": "54.13345",
    "lng": "-114.40211"
  },
  {
    "country": "CA",
    "name": "Barrie",
    "lat": "44.40011",
    "lng": "-79.66634"
  },
  {
    "country": "CA",
    "name": "Bassano",
    "lat": "50.78342",
    "lng": "-112.46854"
  },
  {
    "country": "CA",
    "name": "Bay Roberts",
    "lat": "47.59989",
    "lng": "-53.26478"
  },
  {
    "country": "CA",
    "name": "Beaconsfield",
    "lat": "45.43341",
    "lng": "-73.86586"
  },
  {
    "country": "CA",
    "name": "Beauharnois",
    "lat": "45.31341",
    "lng": "-73.8725"
  },
  {
    "country": "CA",
    "name": "Beaumont",
    "lat": "53.35013",
    "lng": "-113.41871"
  },
  {
    "country": "CA",
    "name": "Beausejour",
    "lat": "50.0622",
    "lng": "-96.51669"
  },
  {
    "country": "CA",
    "name": "Beaverlodge",
    "lat": "55.21664",
    "lng": "-119.43605"
  },
  {
    "country": "CA",
    "name": "Bécancour",
    "lat": "46.33336",
    "lng": "-72.43241"
  },
  {
    "country": "CA",
    "name": "Bedford",
    "lat": "45.11678",
    "lng": "-72.98244"
  },
  {
    "country": "CA",
    "name": "Belfast",
    "lat": "46.08341",
    "lng": "-62.88197"
  },
  {
    "country": "CA",
    "name": "Belleville",
    "lat": "44.16682",
    "lng": "-77.38277"
  },
  {
    "country": "CA",
    "name": "Bells Corners",
    "lat": "45.31588",
    "lng": "-75.83012"
  },
  {
    "country": "CA",
    "name": "Beloeil",
    "lat": "45.56839",
    "lng": "-73.20568"
  },
  {
    "country": "CA",
    "name": "Berthierville",
    "lat": "46.08336",
    "lng": "-73.18245"
  },
  {
    "country": "CA",
    "name": "Berwick",
    "lat": "45.05015",
    "lng": "-64.73208"
  },
  {
    "country": "CA",
    "name": "Biggar",
    "lat": "52.0668",
    "lng": "-108.00135"
  },
  {
    "country": "CA",
    "name": "Binbrook",
    "lat": "43.12135",
    "lng": "-79.81104"
  },
  {
    "country": "CA",
    "name": "Black Diamond",
    "lat": "50.70011",
    "lng": "-114.2353"
  },
  {
    "country": "CA",
    "name": "Blackfalds",
    "lat": "52.38342",
    "lng": "-113.7853"
  },
  {
    "country": "CA",
    "name": "Blainville",
    "lat": "45.66678",
    "lng": "-73.88249"
  },
  {
    "country": "CA",
    "name": "Bluewater",
    "lat": "43.46679",
    "lng": "-81.59977"
  },
  {
    "country": "CA",
    "name": "Boisbriand",
    "lat": "45.61678",
    "lng": "-73.83249"
  },
  {
    "country": "CA",
    "name": "Bois-des-Filion",
    "lat": "45.66678",
    "lng": "-73.74918"
  },
  {
    "country": "CA",
    "name": "Boissevain",
    "lat": "49.23062",
    "lng": "-100.05586"
  },
  {
    "country": "CA",
    "name": "Bon Accord",
    "lat": "53.83345",
    "lng": "-113.41872"
  },
  {
    "country": "CA",
    "name": "Bonavista",
    "lat": "48.64989",
    "lng": "-53.11474"
  },
  {
    "country": "CA",
    "name": "Bonnyville",
    "lat": "54.26684",
    "lng": "-110.73505"
  },
  {
    "country": "CA",
    "name": "Botwood",
    "lat": "49.14994",
    "lng": "-55.34819"
  },
  {
    "country": "CA",
    "name": "Boucherville",
    "lat": "45.59104",
    "lng": "-73.43605"
  },
  {
    "country": "CA",
    "name": "Bouctouche",
    "lat": "46.46844",
    "lng": "-64.73905"
  },
  {
    "country": "CA",
    "name": "Bourget",
    "lat": "45.4334",
    "lng": "-75.1493"
  },
  {
    "country": "CA",
    "name": "Bowen Island",
    "lat": "49.3847",
    "lng": "-123.33622"
  },
  {
    "country": "CA",
    "name": "Bow Island",
    "lat": "49.86676",
    "lng": "-111.36843"
  },
  {
    "country": "CA",
    "name": "Bracebridge",
    "lat": "45.03341",
    "lng": "-79.31633"
  },
  {
    "country": "CA",
    "name": "Brampton",
    "lat": "43.68341",
    "lng": "-79.76633"
  },
  {
    "country": "CA",
    "name": "Brandon",
    "lat": "49.84692",
    "lng": "-99.95306"
  },
  {
    "country": "CA",
    "name": "Brant",
    "lat": "43.1334",
    "lng": "-80.34967"
  },
  {
    "country": "CA",
    "name": "Brantford",
    "lat": "43.1334",
    "lng": "-80.26636"
  },
  {
    "country": "CA",
    "name": "Bridgewater",
    "lat": "44.37856",
    "lng": "-64.51882"
  },
  {
    "country": "CA",
    "name": "Brockville",
    "lat": "44.59132",
    "lng": "-75.68705"
  },
  {
    "country": "CA",
    "name": "Bromont",
    "lat": "45.31678",
    "lng": "-72.64912"
  },
  {
    "country": "CA",
    "name": "Brooks",
    "lat": "50.58341",
    "lng": "-111.88509"
  },
  {
    "country": "CA",
    "name": "Brossard",
    "lat": "45.45008",
    "lng": "-73.46583"
  },
  {
    "country": "CA",
    "name": "Brownsburg-Chatham",
    "lat": "45.68342",
    "lng": "-74.4159"
  },
  {
    "country": "CA",
    "name": "Burgeo",
    "lat": "47.61668",
    "lng": "-57.61516"
  },
  {
    "country": "CA",
    "name": "Burlington",
    "lat": "43.38621",
    "lng": "-79.83713"
  },
  {
    "country": "CA",
    "name": "Burnaby",
    "lat": "49.26636",
    "lng": "-122.95263"
  },
  {
    "country": "CA",
    "name": "Burns Lake",
    "lat": "54.22972",
    "lng": "-125.76084"
  },
  {
    "country": "CA",
    "name": "Cache Creek",
    "lat": "50.81011",
    "lng": "-121.3246"
  },
  {
    "country": "CA",
    "name": "Calgary",
    "lat": "51.05011",
    "lng": "-114.08529"
  },
  {
    "country": "CA",
    "name": "Calmar",
    "lat": "53.26683",
    "lng": "-113.81874"
  },
  {
    "country": "CA",
    "name": "Cambridge",
    "lat": "43.3601",
    "lng": "-80.31269"
  },
  {
    "country": "CA",
    "name": "Camlachie",
    "lat": "43.03596",
    "lng": "-82.1616"
  },
  {
    "country": "CA",
    "name": "Campbell River",
    "lat": "50.01634",
    "lng": "-125.24459"
  },
  {
    "country": "CA",
    "name": "Camrose",
    "lat": "53.01684",
    "lng": "-112.83525"
  },
  {
    "country": "CA",
    "name": "Candiac",
    "lat": "45.38338",
    "lng": "-73.51587"
  },
  {
    "country": "CA",
    "name": "Canmore",
    "lat": "51.08335",
    "lng": "-115.35206"
  },
  {
    "country": "CA",
    "name": "Canora",
    "lat": "51.63328",
    "lng": "-102.43425"
  },
  {
    "country": "CA",
    "name": "Cantley",
    "lat": "45.5668",
    "lng": "-75.78265"
  },
  {
    "country": "CA",
    "name": "Cap-Chat",
    "lat": "49.10009",
    "lng": "-66.68212"
  },
  {
    "country": "CA",
    "name": "Carberry",
    "lat": "49.86893",
    "lng": "-99.36021"
  },
  {
    "country": "CA",
    "name": "Carbonear",
    "lat": "47.73319",
    "lng": "-53.21478"
  },
  {
    "country": "CA",
    "name": "Cardston",
    "lat": "49.19998",
    "lng": "-113.3019"
  },
  {
    "country": "CA",
    "name": "Carignan",
    "lat": "45.45008",
    "lng": "-73.29916"
  },
  {
    "country": "CA",
    "name": "Carleton Place",
    "lat": "45.13341",
    "lng": "-76.14938"
  },
  {
    "country": "CA",
    "name": "Carlyle",
    "lat": "49.63334",
    "lng": "-102.26765"
  },
  {
    "country": "CA",
    "name": "Carman",
    "lat": "49.4992",
    "lng": "-98.00156"
  },
  {
    "country": "CA",
    "name": "Carstairs",
    "lat": "51.56681",
    "lng": "-114.102"
  },
  {
    "country": "CA",
    "name": "Casselman",
    "lat": "45.3168",
    "lng": "-75.0826"
  },
  {
    "country": "CA",
    "name": "Castlegar",
    "lat": "49.29984",
    "lng": "-117.66894"
  },
  {
    "country": "CA",
    "name": "Catalina",
    "lat": "48.51659",
    "lng": "-53.08135"
  },
  {
    "country": "CA",
    "name": "Chambly",
    "lat": "45.45008",
    "lng": "-73.28246"
  },
  {
    "country": "CA",
    "name": "Chambord",
    "lat": "48.43339",
    "lng": "-72.06583"
  },
  {
    "country": "CA",
    "name": "Channel-Port aux Basques",
    "lat": "47.57286",
    "lng": "-59.13808"
  },
  {
    "country": "CA",
    "name": "Chapais",
    "lat": "49.78344",
    "lng": "-74.84919"
  },
  {
    "country": "CA",
    "name": "Charlemagne",
    "lat": "45.71678",
    "lng": "-73.48247"
  },
  {
    "country": "CA",
    "name": "Charlottetown",
    "lat": "46.23899",
    "lng": "-63.13414"
  },
  {
    "country": "CA",
    "name": "Chase",
    "lat": "50.8165",
    "lng": "-119.68571"
  },
  {
    "country": "CA",
    "name": "Châteauguay",
    "lat": "45.38338",
    "lng": "-73.74919"
  },
  {
    "country": "CA",
    "name": "Chatham",
    "lat": "42.41224",
    "lng": "-82.18494"
  },
  {
    "country": "CA",
    "name": "Chertsey",
    "lat": "46.07109",
    "lng": "-73.89095"
  },
  {
    "country": "CA",
    "name": "Chester",
    "lat": "44.54225",
    "lng": "-64.23891"
  },
  {
    "country": "CA",
    "name": "Chestermere",
    "lat": "51.03341",
    "lng": "-113.81867"
  },
  {
    "country": "CA",
    "name": "Chetwynd",
    "lat": "55.69988",
    "lng": "-121.63627"
  },
  {
    "country": "CA",
    "name": "Chibougamau",
    "lat": "49.91684",
    "lng": "-74.36586"
  },
  {
    "country": "CA",
    "name": "Chilliwack",
    "lat": "49.16638",
    "lng": "-121.95257"
  },
  {
    "country": "CA",
    "name": "Chute-aux-Outardes",
    "lat": "49.11679",
    "lng": "-68.39896"
  },
  {
    "country": "CA",
    "name": "Clarence-Rockland",
    "lat": "45.5501",
    "lng": "-75.29101"
  },
  {
    "country": "CA",
    "name": "Clarenville-Shoal Harbour",
    "lat": "48.1805",
    "lng": "-53.96982"
  },
  {
    "country": "CA",
    "name": "Claresholm",
    "lat": "50.03332",
    "lng": "-113.58524"
  },
  {
    "country": "CA",
    "name": "Clyde River",
    "lat": "70.46916",
    "lng": "-68.59143"
  },
  {
    "country": "CA",
    "name": "Coaldale",
    "lat": "49.7167",
    "lng": "-112.61854"
  },
  {
    "country": "CA",
    "name": "Coalhurst",
    "lat": "49.7464",
    "lng": "-112.93246"
  },
  {
    "country": "CA",
    "name": "Coaticook",
    "lat": "45.13339",
    "lng": "-71.79907"
  },
  {
    "country": "CA",
    "name": "Cobourg",
    "lat": "43.95977",
    "lng": "-78.16515"
  },
  {
    "country": "CA",
    "name": "Cochrane",
    "lat": "51.18341",
    "lng": "-114.46871"
  },
  {
    "country": "CA",
    "name": "Cold Lake",
    "lat": "54.46525",
    "lng": "-110.18154"
  },
  {
    "country": "CA",
    "name": "Collingwood",
    "lat": "44.4834",
    "lng": "-80.21638"
  },
  {
    "country": "CA",
    "name": "Colwood",
    "lat": "48.43293",
    "lng": "-123.48591"
  },
  {
    "country": "CA",
    "name": "Conception Bay South",
    "lat": "47.49989",
    "lng": "-52.99806"
  },
  {
    "country": "CA",
    "name": "Concord",
    "lat": "43.80011",
    "lng": "-79.48291"
  },
  {
    "country": "CA",
    "name": "Contrecoeur",
    "lat": "45.85008",
    "lng": "-73.23245"
  },
  {
    "country": "CA",
    "name": "Cookshire-Eaton",
    "lat": "45.41675",
    "lng": "-71.6324"
  },
  {
    "country": "CA",
    "name": "Coquitlam",
    "lat": "49.28297",
    "lng": "-122.75262"
  },
  {
    "country": "CA",
    "name": "Corner Brook",
    "lat": "48.95001",
    "lng": "-57.95202"
  },
  {
    "country": "CA",
    "name": "Cornwall",
    "lat": "46.22652",
    "lng": "-63.21809"
  },
  {
    "country": "CA",
    "name": "Cornwall",
    "lat": "45.01809",
    "lng": "-74.72815"
  },
  {
    "country": "CA",
    "name": "Côte-Saint-Luc",
    "lat": "45.46536",
    "lng": "-73.66585"
  },
  {
    "country": "CA",
    "name": "Courtenay",
    "lat": "49.68657",
    "lng": "-124.9936"
  },
  {
    "country": "CA",
    "name": "Cowansville",
    "lat": "45.20008",
    "lng": "-72.74913"
  },
  {
    "country": "CA",
    "name": "Crabtree",
    "lat": "45.96677",
    "lng": "-73.46586"
  },
  {
    "country": "CA",
    "name": "Cranbrook",
    "lat": "49.49991",
    "lng": "-115.76879"
  },
  {
    "country": "CA",
    "name": "Creston",
    "lat": "49.09987",
    "lng": "-116.50211"
  },
  {
    "country": "CA",
    "name": "Crossfield",
    "lat": "51.43341",
    "lng": "-114.03528"
  },
  {
    "country": "CA",
    "name": "Cumberland",
    "lat": "49.61634",
    "lng": "-125.03613"
  },
  {
    "country": "CA",
    "name": "Dalmeny",
    "lat": "52.33339",
    "lng": "-106.76792"
  },
  {
    "country": "CA",
    "name": "Danville",
    "lat": "45.78337",
    "lng": "-72.0158"
  },
  {
    "country": "CA",
    "name": "Dartmouth",
    "lat": "44.67134",
    "lng": "-63.57719"
  },
  {
    "country": "CA",
    "name": "Dauphin",
    "lat": "51.14941",
    "lng": "-100.05023"
  },
  {
    "country": "CA",
    "name": "Daveluyville",
    "lat": "46.20006",
    "lng": "-72.13239"
  },
  {
    "country": "CA",
    "name": "Dawson Creek",
    "lat": "55.75984",
    "lng": "-120.2403"
  },
  {
    "country": "CA",
    "name": "Deep River",
    "lat": "46.10012",
    "lng": "-77.49949"
  },
  {
    "country": "CA",
    "name": "Deer Lake",
    "lat": "49.16671",
    "lng": "-57.43163"
  },
  {
    "country": "CA",
    "name": "Delaware",
    "lat": "42.91679",
    "lng": "-81.41646"
  },
  {
    "country": "CA",
    "name": "Deloraine",
    "lat": "49.19082",
    "lng": "-100.49477"
  },
  {
    "country": "CA",
    "name": "Delson",
    "lat": "45.36678",
    "lng": "-73.54917"
  },
  {
    "country": "CA",
    "name": "Delta",
    "lat": "49.14399",
    "lng": "-122.9068"
  },
  {
    "country": "CA",
    "name": "Denman Island",
    "lat": "49.53294",
    "lng": "-124.8195"
  },
  {
    "country": "CA",
    "name": "Deseronto",
    "lat": "44.20012",
    "lng": "-77.04944"
  },
  {
    "country": "CA",
    "name": "Deux-Montagnes",
    "lat": "45.53455",
    "lng": "-73.90168"
  },
  {
    "country": "CA",
    "name": "Devon",
    "lat": "53.36683",
    "lng": "-113.73533"
  },
  {
    "country": "CA",
    "name": "Didsbury",
    "lat": "51.66681",
    "lng": "-114.13529"
  },
  {
    "country": "CA",
    "name": "Dieppe",
    "lat": "46.07844",
    "lng": "-64.68735"
  },
  {
    "country": "CA",
    "name": "Digby",
    "lat": "44.62188",
    "lng": "-65.7586"
  },
  {
    "country": "CA",
    "name": "Dolbeau-Mistassini",
    "lat": "48.8786",
    "lng": "-72.23142"
  },
  {
    "country": "CA",
    "name": "Dollard-Des Ormeaux",
    "lat": "45.49452",
    "lng": "-73.82419"
  },
  {
    "country": "CA",
    "name": "Dorchester",
    "lat": "42.98339",
    "lng": "-81.06643"
  },
  {
    "country": "CA",
    "name": "Dorval",
    "lat": "45.4473",
    "lng": "-73.75335"
  },
  {
    "country": "CA",
    "name": "Drayton Valley",
    "lat": "53.21682",
    "lng": "-114.98544"
  },
  {
    "country": "CA",
    "name": "Drummondville",
    "lat": "45.88336",
    "lng": "-72.48241"
  },
  {
    "country": "CA",
    "name": "Dryden",
    "lat": "49.78334",
    "lng": "-92.75032"
  },
  {
    "country": "CA",
    "name": "Duncan",
    "lat": "48.78293",
    "lng": "-123.70266"
  },
  {
    "country": "CA",
    "name": "Dunham",
    "lat": "45.13338",
    "lng": "-72.79913"
  },
  {
    "country": "CA",
    "name": "Ear Falls",
    "lat": "50.63955",
    "lng": "-93.23526"
  },
  {
    "country": "CA",
    "name": "East Angus",
    "lat": "45.48338",
    "lng": "-71.66577"
  },
  {
    "country": "CA",
    "name": "Edmonton",
    "lat": "53.55014",
    "lng": "-113.46871"
  },
  {
    "country": "CA",
    "name": "Edson",
    "lat": "53.58345",
    "lng": "-116.43559"
  },
  {
    "country": "CA",
    "name": "Elkford",
    "lat": "50.05007",
    "lng": "-114.8854"
  },
  {
    "country": "CA",
    "name": "Elk Point",
    "lat": "53.90017",
    "lng": "-110.9017"
  },
  {
    "country": "CA",
    "name": "Elliot Lake",
    "lat": "46.38336",
    "lng": "-82.63315"
  },
  {
    "country": "CA",
    "name": "Enderby",
    "lat": "50.5498",
    "lng": "-119.15234"
  },
  {
    "country": "CA",
    "name": "Englehart",
    "lat": "47.81686",
    "lng": "-79.8664"
  },
  {
    "country": "CA",
    "name": "Espanola",
    "lat": "46.25837",
    "lng": "-81.76649"
  },
  {
    "country": "CA",
    "name": "Esterhazy",
    "lat": "50.65001",
    "lng": "-102.08426"
  },
  {
    "country": "CA",
    "name": "Estevan",
    "lat": "49.13337",
    "lng": "-102.98422"
  },
  {
    "country": "CA",
    "name": "Etobicoke",
    "lat": "43.65421",
    "lng": "-79.56711"
  },
  {
    "country": "CA",
    "name": "Fairview",
    "lat": "56.06675",
    "lng": "-118.38606"
  },
  {
    "country": "CA",
    "name": "Falher",
    "lat": "55.73339",
    "lng": "-117.20262"
  },
  {
    "country": "CA",
    "name": "Fall River",
    "lat": "44.81685",
    "lng": "-63.6154"
  },
  {
    "country": "CA",
    "name": "Farnham",
    "lat": "45.28338",
    "lng": "-72.98244"
  },
  {
    "country": "CA",
    "name": "Ferme-Neuve",
    "lat": "46.70011",
    "lng": "-75.44929"
  },
  {
    "country": "CA",
    "name": "Fermont",
    "lat": "52.78345",
    "lng": "-67.08204"
  },
  {
    "country": "CA",
    "name": "Fernie",
    "lat": "49.49996",
    "lng": "-115.06871"
  },
  {
    "country": "CA",
    "name": "Flin Flon",
    "lat": "54.76703",
    "lng": "-101.87433"
  },
  {
    "country": "CA",
    "name": "Foam Lake",
    "lat": "51.65001",
    "lng": "-103.53431"
  },
  {
    "country": "CA",
    "name": "Fort-Coulonge",
    "lat": "45.85011",
    "lng": "-76.73272"
  },
  {
    "country": "CA",
    "name": "Fort Erie",
    "lat": "42.90012",
    "lng": "-78.93286"
  },
  {
    "country": "CA",
    "name": "Fort Frances",
    "lat": "48.61667",
    "lng": "-93.4003"
  },
  {
    "country": "CA",
    "name": "Fort Macleod",
    "lat": "49.71671",
    "lng": "-113.41857"
  },
  {
    "country": "CA",
    "name": "Fort McMurray",
    "lat": "56.72676",
    "lng": "-111.38103"
  },
  {
    "country": "CA",
    "name": "Fort McPherson",
    "lat": "67.43863",
    "lng": "-134.88543"
  },
  {
    "country": "CA",
    "name": "Fort Nelson",
    "lat": "58.80533",
    "lng": "-122.7002"
  },
  {
    "country": "CA",
    "name": "Fort Saskatchewan",
    "lat": "53.71684",
    "lng": "-113.2187"
  },
  {
    "country": "CA",
    "name": "Fort Smith",
    "lat": "60.00439",
    "lng": "-111.88871"
  },
  {
    "country": "CA",
    "name": "Fort St. John",
    "lat": "56.24988",
    "lng": "-120.85292"
  },
  {
    "country": "CA",
    "name": "Fox Creek",
    "lat": "54.40007",
    "lng": "-116.80238"
  },
  {
    "country": "CA",
    "name": "Franklin",
    "lat": "45.03338",
    "lng": "-73.91591"
  },
  {
    "country": "CA",
    "name": "Fredericton",
    "lat": "45.94541",
    "lng": "-66.66558"
  },
  {
    "country": "CA",
    "name": "Fruitvale",
    "lat": "49.11654",
    "lng": "-117.55222"
  },
  {
    "country": "CA",
    "name": "Gambo",
    "lat": "48.7832",
    "lng": "-54.21482"
  },
  {
    "country": "CA",
    "name": "Gananoque",
    "lat": "44.33342",
    "lng": "-76.16607"
  },
  {
    "country": "CA",
    "name": "Gaspé",
    "lat": "48.83341",
    "lng": "-64.48194"
  },
  {
    "country": "CA",
    "name": "Gatineau",
    "lat": "45.47723",
    "lng": "-75.70164"
  },
  {
    "country": "CA",
    "name": "Gibbons",
    "lat": "53.83345",
    "lng": "-113.33531"
  },
  {
    "country": "CA",
    "name": "Gibsons",
    "lat": "49.39539",
    "lng": "-123.50555"
  },
  {
    "country": "CA",
    "name": "Gimli",
    "lat": "50.63362",
    "lng": "-96.99066"
  },
  {
    "country": "CA",
    "name": "Gjoa Haven",
    "lat": "68.62602",
    "lng": "-95.87836"
  },
  {
    "country": "CA",
    "name": "Glace Bay",
    "lat": "46.19695",
    "lng": "-59.95698"
  },
  {
    "country": "CA",
    "name": "Goderich",
    "lat": "43.74171",
    "lng": "-81.71339"
  },
  {
    "country": "CA",
    "name": "Golden",
    "lat": "51.29995",
    "lng": "-116.9689"
  },
  {
    "country": "CA",
    "name": "Granby",
    "lat": "45.40008",
    "lng": "-72.73243"
  },
  {
    "country": "CA",
    "name": "Grand Bank",
    "lat": "47.09995",
    "lng": "-55.76504"
  },
  {
    "country": "CA",
    "name": "Grande Cache",
    "lat": "53.88335",
    "lng": "-119.13585"
  },
  {
    "country": "CA",
    "name": "Grande Prairie",
    "lat": "55.16667",
    "lng": "-118.80271"
  },
  {
    "country": "CA",
    "name": "Grand Falls-Windsor",
    "lat": "48.93324",
    "lng": "-55.66492"
  },
  {
    "country": "CA",
    "name": "Grand Forks",
    "lat": "49.03309",
    "lng": "-118.4356"
  },
  {
    "country": "CA",
    "name": "Greater Sudbury",
    "lat": "46.49",
    "lng": "-80.99001"
  },
  {
    "country": "CA",
    "name": "Gravelbourg",
    "lat": "49.88336",
    "lng": "-106.55122"
  },
  {
    "country": "CA",
    "name": "Gravenhurst",
    "lat": "44.91681",
    "lng": "-79.36633"
  },
  {
    "country": "CA",
    "name": "Greater Napanee",
    "lat": "44.25012",
    "lng": "-76.94944"
  },
  {
    "country": "CA",
    "name": "Greenstone",
    "lat": "49.73343",
    "lng": "-87.16668"
  },
  {
    "country": "CA",
    "name": "Greenwood",
    "lat": "44.97413",
    "lng": "-64.93169"
  },
  {
    "country": "CA",
    "name": "Grimshaw",
    "lat": "56.18339",
    "lng": "-117.6027"
  },
  {
    "country": "CA",
    "name": "Guelph",
    "lat": "43.54594",
    "lng": "-80.25599"
  },
  {
    "country": "CA",
    "name": "Haines Junction",
    "lat": "60.75216",
    "lng": "-137.51082"
  },
  {
    "country": "CA",
    "name": "Hamilton",
    "lat": "43.25011",
    "lng": "-79.84963"
  },
  {
    "country": "CA",
    "name": "Hampstead",
    "lat": "45.48064",
    "lng": "-73.66307"
  },
  {
    "country": "CA",
    "name": "Hampton",
    "lat": "45.52876",
    "lng": "-65.85354"
  },
  {
    "country": "CA",
    "name": "Hanceville",
    "lat": "51.91922",
    "lng": "-123.04458"
  },
  {
    "country": "CA",
    "name": "Hanna",
    "lat": "51.63343",
    "lng": "-111.90181"
  },
  {
    "country": "CA",
    "name": "Hanover",
    "lat": "44.15009",
    "lng": "-81.03303"
  },
  {
    "country": "CA",
    "name": "Hantsport",
    "lat": "45.06685",
    "lng": "-64.16544"
  },
  {
    "country": "CA",
    "name": "Happy Valley-Goose Bay",
    "lat": "53.3038",
    "lng": "-60.32576"
  },
  {
    "country": "CA",
    "name": "Harbour Breton",
    "lat": "47.48325",
    "lng": "-55.79833"
  },
  {
    "country": "CA",
    "name": "Havre-Saint-Pierre",
    "lat": "50.24342",
    "lng": "-63.60264"
  },
  {
    "country": "CA",
    "name": "Hawkesbury",
    "lat": "45.60009",
    "lng": "-74.61595"
  },
  {
    "country": "CA",
    "name": "Hay River",
    "lat": "60.81555",
    "lng": "-115.79993"
  },
  {
    "country": "CA",
    "name": "Headingley",
    "lat": "49.8753",
    "lng": "-97.40896"
  },
  {
    "country": "CA",
    "name": "Hearst",
    "lat": "49.68351",
    "lng": "-83.66654"
  },
  {
    "country": "CA",
    "name": "High Level",
    "lat": "58.51688",
    "lng": "-117.13605"
  },
  {
    "country": "CA",
    "name": "High Prairie",
    "lat": "55.4334",
    "lng": "-116.4858"
  },
  {
    "country": "CA",
    "name": "High River",
    "lat": "50.58341",
    "lng": "-113.86867"
  },
  {
    "country": "CA",
    "name": "Hinton",
    "lat": "53.40009",
    "lng": "-117.58567"
  },
  {
    "country": "CA",
    "name": "Hope",
    "lat": "49.38299",
    "lng": "-121.44144"
  },
  {
    "country": "CA",
    "name": "Hornby Island",
    "lat": "49.53448",
    "lng": "-124.66923"
  },
  {
    "country": "CA",
    "name": "Hornepayne",
    "lat": "49.21451",
    "lng": "-84.77617"
  },
  {
    "country": "CA",
    "name": "Houston",
    "lat": "54.39976",
    "lng": "-126.67008"
  },
  {
    "country": "CA",
    "name": "Hudson",
    "lat": "45.45008",
    "lng": "-74.14922"
  },
  {
    "country": "CA",
    "name": "Hudson Bay",
    "lat": "52.85003",
    "lng": "-102.38425"
  },
  {
    "country": "CA",
    "name": "Humboldt",
    "lat": "52.20005",
    "lng": "-105.1255"
  },
  {
    "country": "CA",
    "name": "Huntingdon",
    "lat": "45.08339",
    "lng": "-74.16593"
  },
  {
    "country": "CA",
    "name": "Huntsville",
    "lat": "45.33341",
    "lng": "-79.21632"
  },
  {
    "country": "CA",
    "name": "Huron East",
    "lat": "43.61679",
    "lng": "-81.29975"
  },
  {
    "country": "CA",
    "name": "Indian Head",
    "lat": "50.53336",
    "lng": "-103.66775"
  },
  {
    "country": "CA",
    "name": "Ingersoll",
    "lat": "43.03339",
    "lng": "-80.88302"
  },
  {
    "country": "CA",
    "name": "Innisfil",
    "lat": "44.30011",
    "lng": "-79.64964"
  },
  {
    "country": "CA",
    "name": "Inuvik",
    "lat": "68.34986",
    "lng": "-133.72181"
  },
  {
    "country": "CA",
    "name": "Invermere",
    "lat": "50.51666",
    "lng": "-116.03538"
  },
  {
    "country": "CA",
    "name": "Iqaluit",
    "lat": "63.74697",
    "lng": "-68.51727"
  },
  {
    "country": "CA",
    "name": "Iroquois Falls",
    "lat": "48.76688",
    "lng": "-80.68307"
  },
  {
    "country": "CA",
    "name": "Irricana",
    "lat": "51.32372",
    "lng": "-113.60475"
  },
  {
    "country": "CA",
    "name": "Jasper Park Lodge",
    "lat": "52.88633",
    "lng": "-118.05625"
  },
  {
    "country": "CA",
    "name": "Joliette",
    "lat": "46.0164",
    "lng": "-73.4236"
  },
  {
    "country": "CA",
    "name": "Kamloops",
    "lat": "50.66648",
    "lng": "-120.3192"
  },
  {
    "country": "CA",
    "name": "Kamsack",
    "lat": "51.56668",
    "lng": "-101.90093"
  },
  {
    "country": "CA",
    "name": "Kapuskasing",
    "lat": "49.41694",
    "lng": "-82.43308"
  },
  {
    "country": "CA",
    "name": "Kelowna",
    "lat": "49.88307",
    "lng": "-119.48568"
  },
  {
    "country": "CA",
    "name": "Kenora",
    "lat": "49.76741",
    "lng": "-94.48985"
  },
  {
    "country": "CA",
    "name": "Kensington",
    "lat": "46.43343",
    "lng": "-63.64871"
  },
  {
    "country": "CA",
    "name": "Kentville",
    "lat": "45.0771",
    "lng": "-64.49605"
  },
  {
    "country": "CA",
    "name": "Kerrobert",
    "lat": "51.91682",
    "lng": "-109.13479"
  },
  {
    "country": "CA",
    "name": "Keswick",
    "lat": "44.25011",
    "lng": "-79.46632"
  },
  {
    "country": "CA",
    "name": "Killam",
    "lat": "52.78344",
    "lng": "-111.85175"
  },
  {
    "country": "CA",
    "name": "Killarney",
    "lat": "49.18332",
    "lng": "-99.66364"
  },
  {
    "country": "CA",
    "name": "Kimberley",
    "lat": "49.67071",
    "lng": "-115.9776"
  },
  {
    "country": "CA",
    "name": "Kincardine",
    "lat": "44.18339",
    "lng": "-81.63307"
  },
  {
    "country": "CA",
    "name": "Kindersley",
    "lat": "51.46681",
    "lng": "-109.16818"
  },
  {
    "country": "CA",
    "name": "Kingsey Falls",
    "lat": "45.85007",
    "lng": "-72.0658"
  },
  {
    "country": "CA",
    "name": "Kingston",
    "lat": "44.22976",
    "lng": "-76.48098"
  },
  {
    "country": "CA",
    "name": "Kirkland",
    "lat": "45.45008",
    "lng": "-73.86586"
  },
  {
    "country": "CA",
    "name": "Kirkland Lake",
    "lat": "48.14461",
    "lng": "-80.03767"
  },
  {
    "country": "CA",
    "name": "Kitchener",
    "lat": "43.42537",
    "lng": "-80.5112"
  },
  {
    "country": "CA",
    "name": "Kitimat",
    "lat": "54.05244",
    "lng": "-128.65342"
  },
  {
    "country": "CA",
    "name": "Kugluktuk",
    "lat": "67.82743",
    "lng": "-115.09649"
  },
  {
    "country": "CA",
    "name": "Labelle",
    "lat": "46.28339",
    "lng": "-74.73255"
  },
  {
    "country": "CA",
    "name": "Labrador City",
    "lat": "52.94626",
    "lng": "-66.91137"
  },
  {
    "country": "CA",
    "name": "La Broquerie",
    "lat": "49.51688",
    "lng": "-96.50029"
  },
  {
    "country": "CA",
    "name": "Lac-Brome",
    "lat": "45.21678",
    "lng": "-72.51581"
  },
  {
    "country": "CA",
    "name": "Lac du Bonnet",
    "lat": "50.2536",
    "lng": "-96.06116"
  },
  {
    "country": "CA",
    "name": "Lachute",
    "lat": "45.65008",
    "lng": "-74.33253"
  },
  {
    "country": "CA",
    "name": "Lac La Biche",
    "lat": "54.7669",
    "lng": "-111.96861"
  },
  {
    "country": "CA",
    "name": "Lac-Mégantic",
    "lat": "45.58338",
    "lng": "-70.88234"
  },
  {
    "country": "CA",
    "name": "Lacolle",
    "lat": "45.08338",
    "lng": "-73.36585"
  },
  {
    "country": "CA",
    "name": "Lacombe",
    "lat": "52.46681",
    "lng": "-113.7353"
  },
  {
    "country": "CA",
    "name": "La Conception",
    "lat": "46.15009",
    "lng": "-74.69925"
  },
  {
    "country": "CA",
    "name": "Ladysmith",
    "lat": "48.99016",
    "lng": "-123.81699"
  },
  {
    "country": "CA",
    "name": "Lake Cowichan",
    "lat": "48.82495",
    "lng": "-124.05461"
  },
  {
    "country": "CA",
    "name": "Lambton Shores",
    "lat": "43.16678",
    "lng": "-81.93309"
  },
  {
    "country": "CA",
    "name": "La Minerve",
    "lat": "46.25009",
    "lng": "-74.93257"
  },
  {
    "country": "CA",
    "name": "Lamont",
    "lat": "53.76686",
    "lng": "-112.80195"
  },
  {
    "country": "CA",
    "name": "Langenburg",
    "lat": "50.84999",
    "lng": "-101.71763"
  },
  {
    "country": "CA",
    "name": "Langford",
    "lat": "48.44963",
    "lng": "-123.50261"
  },
  {
    "country": "CA",
    "name": "Langham",
    "lat": "52.3668",
    "lng": "-106.96793"
  },
  {
    "country": "CA",
    "name": "Langley",
    "lat": "49.10107",
    "lng": "-122.65883"
  },
  {
    "country": "CA",
    "name": "Lanigan",
    "lat": "51.85006",
    "lng": "-105.03443"
  },
  {
    "country": "CA",
    "name": "Lanoraie",
    "lat": "45.96677",
    "lng": "-73.21585"
  },
  {
    "country": "CA",
    "name": "La Prairie",
    "lat": "45.41678",
    "lng": "-73.49917"
  },
  {
    "country": "CA",
    "name": "La Ronge",
    "lat": "55.10013",
    "lng": "-105.28422"
  },
  {
    "country": "CA",
    "name": "La Sarre",
    "lat": "48.80019",
    "lng": "-79.19964"
  },
  {
    "country": "CA",
    "name": "L'Assomption",
    "lat": "45.82318",
    "lng": "-73.4294"
  },
  {
    "country": "CA",
    "name": "La Tuque",
    "lat": "47.43337",
    "lng": "-72.7824"
  },
  {
    "country": "CA",
    "name": "Laval",
    "lat": "45.56995",
    "lng": "-73.692"
  },
  {
    "country": "CA",
    "name": "Lavaltrie",
    "lat": "45.88338",
    "lng": "-73.28245"
  },
  {
    "country": "CA",
    "name": "Lebel-sur-Quévillon",
    "lat": "49.05018",
    "lng": "-76.98273"
  },
  {
    "country": "CA",
    "name": "Leduc",
    "lat": "53.26682",
    "lng": "-113.55201"
  },
  {
    "country": "CA",
    "name": "L'Épiphanie",
    "lat": "45.85008",
    "lng": "-73.48246"
  },
  {
    "country": "CA",
    "name": "Les Cèdres",
    "lat": "45.30008",
    "lng": "-74.04922"
  },
  {
    "country": "CA",
    "name": "Les Coteaux",
    "lat": "45.28338",
    "lng": "-74.23254"
  },
  {
    "country": "CA",
    "name": "Lethbridge",
    "lat": "49.69999",
    "lng": "-112.81856"
  },
  {
    "country": "CA",
    "name": "Lewisporte",
    "lat": "49.24993",
    "lng": "-55.04816"
  },
  {
    "country": "CA",
    "name": "L'Île-Perrot",
    "lat": "45.38338",
    "lng": "-73.9492"
  },
  {
    "country": "CA",
    "name": "Lindsay",
    "lat": "44.35012",
    "lng": "-78.73286"
  },
  {
    "country": "CA",
    "name": "Lions Bay",
    "lat": "49.45218",
    "lng": "-123.2376"
  },
  {
    "country": "CA",
    "name": "Little Current",
    "lat": "45.97927",
    "lng": "-81.9248"
  },
  {
    "country": "CA",
    "name": "Lloydminster",
    "lat": "53.27237",
    "lng": "-110.02256"
  },
  {
    "country": "CA",
    "name": "Logan Lake",
    "lat": "50.49976",
    "lng": "-120.80253"
  },
  {
    "country": "CA",
    "name": "London",
    "lat": "42.98339",
    "lng": "-81.23304"
  },
  {
    "country": "CA",
    "name": "Longueuil",
    "lat": "45.53121",
    "lng": "-73.51806"
  },
  {
    "country": "CA",
    "name": "Lorraine",
    "lat": "45.68338",
    "lng": "-73.78249"
  },
  {
    "country": "CA",
    "name": "Louiseville",
    "lat": "46.25594",
    "lng": "-72.94145"
  },
  {
    "country": "CA",
    "name": "Lumby",
    "lat": "50.24979",
    "lng": "-118.96904"
  },
  {
    "country": "CA",
    "name": "Lumsden",
    "lat": "50.65009",
    "lng": "-104.86783"
  },
  {
    "country": "CA",
    "name": "Lunenburg",
    "lat": "44.37847",
    "lng": "-64.31658"
  },
  {
    "country": "CA",
    "name": "Lutes Mountain",
    "lat": "46.13544",
    "lng": "-64.90504"
  },
  {
    "country": "CA",
    "name": "Macamic",
    "lat": "48.75018",
    "lng": "-78.99962"
  },
  {
    "country": "CA",
    "name": "Macklin",
    "lat": "52.33344",
    "lng": "-109.93484"
  },
  {
    "country": "CA",
    "name": "Magog",
    "lat": "45.26678",
    "lng": "-72.14909"
  },
  {
    "country": "CA",
    "name": "Magrath",
    "lat": "49.41668",
    "lng": "-112.86856"
  },
  {
    "country": "CA",
    "name": "Malartic",
    "lat": "48.13348",
    "lng": "-78.13283"
  },
  {
    "country": "CA",
    "name": "Mandeville",
    "lat": "46.36677",
    "lng": "-73.34915"
  },
  {
    "country": "CA",
    "name": "Maniwaki",
    "lat": "46.38341",
    "lng": "-75.96605"
  },
  {
    "country": "CA",
    "name": "Manning",
    "lat": "56.91683",
    "lng": "-117.61945"
  },
  {
    "country": "CA",
    "name": "Maple Creek",
    "lat": "49.91678",
    "lng": "-109.48481"
  },
  {
    "country": "CA",
    "name": "Maple Ridge",
    "lat": "53.50172",
    "lng": "-113.36274"
  },
  {
    "country": "CA",
    "name": "Maple Ridge",
    "lat": "49.21939",
    "lng": "-122.60193"
  },
  {
    "country": "CA",
    "name": "Marathon",
    "lat": "48.7501",
    "lng": "-86.43322"
  },
  {
    "country": "CA",
    "name": "Marieville",
    "lat": "45.43338",
    "lng": "-73.16585"
  },
  {
    "country": "CA",
    "name": "Markham",
    "lat": "43.86682",
    "lng": "-79.2663"
  },
  {
    "country": "CA",
    "name": "Martensville",
    "lat": "52.28339",
    "lng": "-106.66792"
  },
  {
    "country": "CA",
    "name": "Marystown",
    "lat": "47.16663",
    "lng": "-55.14829"
  },
  {
    "country": "CA",
    "name": "Mascouche",
    "lat": "45.74965",
    "lng": "-73.59956"
  },
  {
    "country": "CA",
    "name": "Maskinongé",
    "lat": "46.2286",
    "lng": "-73.01917"
  },
  {
    "country": "CA",
    "name": "Matagami",
    "lat": "49.75018",
    "lng": "-77.63277"
  },
  {
    "country": "CA",
    "name": "Mattawa",
    "lat": "46.31681",
    "lng": "-78.69957"
  },
  {
    "country": "CA",
    "name": "Mayerthorpe",
    "lat": "53.95015",
    "lng": "-115.13547"
  },
  {
    "country": "CA",
    "name": "Meadow Lake",
    "lat": "54.13348",
    "lng": "-108.43471"
  },
  {
    "country": "CA",
    "name": "Medicine Hat",
    "lat": "50.03928",
    "lng": "-110.67661"
  },
  {
    "country": "CA",
    "name": "Melfort",
    "lat": "52.86673",
    "lng": "-104.61768"
  },
  {
    "country": "CA",
    "name": "Melita",
    "lat": "49.26811",
    "lng": "-100.99669"
  },
  {
    "country": "CA",
    "name": "Melville",
    "lat": "50.91671",
    "lng": "-102.80099"
  },
  {
    "country": "CA",
    "name": "Mercier",
    "lat": "45.31678",
    "lng": "-73.74919"
  },
  {
    "country": "CA",
    "name": "Merritt",
    "lat": "50.11225",
    "lng": "-120.7942"
  },
  {
    "country": "CA",
    "name": "Metchosin",
    "lat": "48.38293",
    "lng": "-123.53591"
  },
  {
    "country": "CA",
    "name": "Middleton",
    "lat": "44.94284",
    "lng": "-65.07022"
  },
  {
    "country": "CA",
    "name": "Midland",
    "lat": "44.7501",
    "lng": "-79.88296"
  },
  {
    "country": "CA",
    "name": "Millet",
    "lat": "53.10013",
    "lng": "-113.4687"
  },
  {
    "country": "CA",
    "name": "Milton",
    "lat": "43.51681",
    "lng": "-79.88294"
  },
  {
    "country": "CA",
    "name": "Minnedosa",
    "lat": "50.24532",
    "lng": "-99.84364"
  },
  {
    "country": "CA",
    "name": "Mirabel",
    "lat": "45.65008",
    "lng": "-74.08251"
  },
  {
    "country": "CA",
    "name": "Miramichi",
    "lat": "47.02895",
    "lng": "-65.50186"
  },
  {
    "country": "CA",
    "name": "Mississauga",
    "lat": "43.5789",
    "lng": "-79.6583"
  },
  {
    "country": "CA",
    "name": "Moncton",
    "lat": "46.09454",
    "lng": "-64.7965"
  },
  {
    "country": "CA",
    "name": "Montague",
    "lat": "46.16681",
    "lng": "-62.64866"
  },
  {
    "country": "CA",
    "name": "Mont-Laurier",
    "lat": "46.55011",
    "lng": "-75.4993"
  },
  {
    "country": "CA",
    "name": "Montréal",
    "lat": "45.50884",
    "lng": "-73.58781"
  },
  {
    "country": "CA",
    "name": "Montréal-Est",
    "lat": "45.63202",
    "lng": "-73.5075"
  },
  {
    "country": "CA",
    "name": "Montréal-Ouest",
    "lat": "45.45286",
    "lng": "-73.64918"
  },
  {
    "country": "CA",
    "name": "Mont-Royal",
    "lat": "45.51675",
    "lng": "-73.64918"
  },
  {
    "country": "CA",
    "name": "Mont-Saint-Grégoire",
    "lat": "45.33338",
    "lng": "-73.16585"
  },
  {
    "country": "CA",
    "name": "Mont-Saint-Hilaire",
    "lat": "45.56515",
    "lng": "-73.1868"
  },
  {
    "country": "CA",
    "name": "Mont-Tremblant",
    "lat": "46.21274",
    "lng": "-74.58438"
  },
  {
    "country": "CA",
    "name": "Moose Jaw",
    "lat": "50.40005",
    "lng": "-105.53445"
  },
  {
    "country": "CA",
    "name": "Moosomin",
    "lat": "50.13332",
    "lng": "-101.66766"
  },
  {
    "country": "CA",
    "name": "Morden",
    "lat": "49.1919",
    "lng": "-98.10136"
  },
  {
    "country": "CA",
    "name": "Morin-Heights",
    "lat": "45.90009",
    "lng": "-74.24922"
  },
  {
    "country": "CA",
    "name": "Morinville",
    "lat": "53.80014",
    "lng": "-113.65203"
  },
  {
    "country": "CA",
    "name": "Morris",
    "lat": "49.35499",
    "lng": "-97.36567"
  },
  {
    "country": "CA",
    "name": "Morrisburg",
    "lat": "44.9001",
    "lng": "-75.18261"
  },
  {
    "country": "CA",
    "name": "Mount Pearl",
    "lat": "47.51659",
    "lng": "-52.78135"
  },
  {
    "country": "CA",
    "name": "Nackawic",
    "lat": "45.99666",
    "lng": "-67.24028"
  },
  {
    "country": "CA",
    "name": "Nakusp",
    "lat": "50.24987",
    "lng": "-117.80226"
  },
  {
    "country": "CA",
    "name": "Nanaimo",
    "lat": "49.16638",
    "lng": "-123.94003"
  },
  {
    "country": "CA",
    "name": "Nanton",
    "lat": "50.35008",
    "lng": "-113.76866"
  },
  {
    "country": "CA",
    "name": "Napierville",
    "lat": "45.18648",
    "lng": "-73.40468"
  },
  {
    "country": "CA",
    "name": "Neebing",
    "lat": "48.1668",
    "lng": "-89.41683"
  },
  {
    "country": "CA",
    "name": "Neepawa",
    "lat": "50.22892",
    "lng": "-99.46642"
  },
  {
    "country": "CA",
    "name": "Nelson",
    "lat": "49.49985",
    "lng": "-117.28553"
  },
  {
    "country": "CA",
    "name": "Nepean",
    "lat": "45.35215",
    "lng": "-75.73975"
  },
  {
    "country": "CA",
    "name": "New Glasgow",
    "lat": "45.58344",
    "lng": "-62.64863"
  },
  {
    "country": "CA",
    "name": "Newmarket",
    "lat": "44.05011",
    "lng": "-79.46631"
  },
  {
    "country": "CA",
    "name": "New Westminster",
    "lat": "49.20678",
    "lng": "-122.91092"
  },
  {
    "country": "CA",
    "name": "Niagara Falls",
    "lat": "43.10012",
    "lng": "-79.06627"
  },
  {
    "country": "CA",
    "name": "Nicolet",
    "lat": "46.21676",
    "lng": "-72.61582"
  },
  {
    "country": "CA",
    "name": "Nipawin",
    "lat": "53.36678",
    "lng": "-104.00092"
  },
  {
    "country": "CA",
    "name": "Niverville",
    "lat": "49.60559",
    "lng": "-97.04234"
  },
  {
    "country": "CA",
    "name": "Norfolk County",
    "lat": "42.8334",
    "lng": "-80.38297"
  },
  {
    "country": "CA",
    "name": "Normandin",
    "lat": "48.83328",
    "lng": "-72.53209"
  },
  {
    "country": "CA",
    "name": "Norman Wells",
    "lat": "65.28201",
    "lng": "-126.8329"
  },
  {
    "country": "CA",
    "name": "North Battleford",
    "lat": "52.77972",
    "lng": "-108.2967"
  },
  {
    "country": "CA",
    "name": "North Bay",
    "lat": "46.3168",
    "lng": "-79.46633"
  },
  {
    "country": "CA",
    "name": "North Cowichan",
    "lat": "48.84133",
    "lng": "-123.68596"
  },
  {
    "country": "CA",
    "name": "North Perth",
    "lat": "43.7251",
    "lng": "-80.96723"
  },
  {
    "country": "CA",
    "name": "North Saanich",
    "lat": "48.66634",
    "lng": "-123.41933"
  },
  {
    "country": "CA",
    "name": "North Vancouver",
    "lat": "49.31636",
    "lng": "-123.06934"
  },
  {
    "country": "CA",
    "name": "North York",
    "lat": "43.76681",
    "lng": "-79.4163"
  },
  {
    "country": "CA",
    "name": "Notre-Dame-de-Grâce",
    "lat": "45.47675",
    "lng": "-73.61432"
  },
  {
    "country": "CA",
    "name": "Notre-Dame-de-l'Île-Perrot",
    "lat": "45.36678",
    "lng": "-73.9325"
  },
  {
    "country": "CA",
    "name": "Notre-Dame-des-Prairies",
    "lat": "46.05007",
    "lng": "-73.43245"
  },
  {
    "country": "CA",
    "name": "Oak Bay",
    "lat": "48.44964",
    "lng": "-123.3026"
  },
  {
    "country": "CA",
    "name": "Oakville",
    "lat": "43.45011",
    "lng": "-79.68292"
  },
  {
    "country": "CA",
    "name": "Oka",
    "lat": "45.46489",
    "lng": "-74.08892"
  },
  {
    "country": "CA",
    "name": "Okotoks",
    "lat": "50.72885",
    "lng": "-113.98281"
  },
  {
    "country": "CA",
    "name": "Olds",
    "lat": "51.78341",
    "lng": "-114.10199"
  },
  {
    "country": "CA",
    "name": "Oliver",
    "lat": "49.18306",
    "lng": "-119.5524"
  },
  {
    "country": "CA",
    "name": "Orangeville",
    "lat": "43.9168",
    "lng": "-80.09967"
  },
  {
    "country": "CA",
    "name": "Orillia",
    "lat": "44.60868",
    "lng": "-79.42068"
  },
  {
    "country": "CA",
    "name": "Ormstown",
    "lat": "45.13338",
    "lng": "-73.99922"
  },
  {
    "country": "CA",
    "name": "Oromocto",
    "lat": "45.83512",
    "lng": "-66.47917"
  },
  {
    "country": "CA",
    "name": "Oshawa",
    "lat": "43.90012",
    "lng": "-78.84957"
  },
  {
    "country": "CA",
    "name": "Osoyoos",
    "lat": "49.03306",
    "lng": "-119.45237"
  },
  {
    "country": "CA",
    "name": "Ottawa",
    "lat": "45.41117",
    "lng": "-75.69812"
  },
  {
    "country": "CA",
    "name": "Otterburn Park",
    "lat": "45.53338",
    "lng": "-73.21585"
  },
  {
    "country": "CA",
    "name": "Outlook",
    "lat": "51.50008",
    "lng": "-107.05128"
  },
  {
    "country": "CA",
    "name": "Owen Sound",
    "lat": "44.56717",
    "lng": "-80.94349"
  },
  {
    "country": "CA",
    "name": "Oxbow",
    "lat": "49.23335",
    "lng": "-102.1676"
  },
  {
    "country": "CA",
    "name": "Oxford",
    "lat": "45.73345",
    "lng": "-63.86542"
  },
  {
    "country": "CA",
    "name": "Pangnirtung",
    "lat": "66.14642",
    "lng": "-65.69996"
  },
  {
    "country": "CA",
    "name": "Papineauville",
    "lat": "45.6168",
    "lng": "-75.01599"
  },
  {
    "country": "CA",
    "name": "Parksville",
    "lat": "49.31947",
    "lng": "-124.31575"
  },
  {
    "country": "CA",
    "name": "Parrsboro",
    "lat": "45.40567",
    "lng": "-64.32585"
  },
  {
    "country": "CA",
    "name": "Parry Sound",
    "lat": "45.34732",
    "lng": "-80.03527"
  },
  {
    "country": "CA",
    "name": "Pasadena",
    "lat": "49.01671",
    "lng": "-57.59837"
  },
  {
    "country": "CA",
    "name": "Peace River",
    "lat": "56.23715",
    "lng": "-117.29176"
  },
  {
    "country": "CA",
    "name": "Peachland",
    "lat": "49.76647",
    "lng": "-119.73568"
  },
  {
    "country": "CA",
    "name": "Pemberton",
    "lat": "50.31641",
    "lng": "-122.80273"
  },
  {
    "country": "CA",
    "name": "Pembroke",
    "lat": "45.81681",
    "lng": "-77.11616"
  },
  {
    "country": "CA",
    "name": "Penhold",
    "lat": "52.13342",
    "lng": "-113.8687"
  },
  {
    "country": "CA",
    "name": "Penticton",
    "lat": "49.48062",
    "lng": "-119.58584"
  },
  {
    "country": "CA",
    "name": "Perth",
    "lat": "44.90011",
    "lng": "-76.24939"
  },
  {
    "country": "CA",
    "name": "Petawawa",
    "lat": "45.89452",
    "lng": "-77.28007"
  },
  {
    "country": "CA",
    "name": "Peterborough",
    "lat": "44.30012",
    "lng": "-78.31623"
  },
  {
    "country": "CA",
    "name": "Petrolia",
    "lat": "42.86678",
    "lng": "-82.14981"
  },
  {
    "country": "CA",
    "name": "Pickering",
    "lat": "43.90012",
    "lng": "-79.13289"
  },
  {
    "country": "CA",
    "name": "Picton",
    "lat": "44.00012",
    "lng": "-77.13275"
  },
  {
    "country": "CA",
    "name": "Pictou",
    "lat": "45.67875",
    "lng": "-62.70936"
  },
  {
    "country": "CA",
    "name": "Picture Butte",
    "lat": "49.8833",
    "lng": "-112.78516"
  },
  {
    "country": "CA",
    "name": "Piedmont",
    "lat": "45.90008",
    "lng": "-74.13251"
  },
  {
    "country": "CA",
    "name": "Pierreville",
    "lat": "46.07034",
    "lng": "-72.81125"
  },
  {
    "country": "CA",
    "name": "Pilot Butte",
    "lat": "50.46678",
    "lng": "-104.41778"
  },
  {
    "country": "CA",
    "name": "Pincher Creek",
    "lat": "49.48328",
    "lng": "-113.95195"
  },
  {
    "country": "CA",
    "name": "Pincourt",
    "lat": "45.38338",
    "lng": "-73.9825"
  },
  {
    "country": "CA",
    "name": "Pitt Meadows",
    "lat": "49.22119",
    "lng": "-122.68965"
  },
  {
    "country": "CA",
    "name": "Pointe-Calumet",
    "lat": "45.50008",
    "lng": "-73.9659"
  },
  {
    "country": "CA",
    "name": "Pointe-Claire",
    "lat": "45.44868",
    "lng": "-73.81669"
  },
  {
    "country": "CA",
    "name": "Ponoka",
    "lat": "52.6768",
    "lng": "-113.58147"
  },
  {
    "country": "CA",
    "name": "Pont Rouge",
    "lat": "48.88332",
    "lng": "-72.08247"
  },
  {
    "country": "CA",
    "name": "Portage la Prairie",
    "lat": "49.97282",
    "lng": "-98.29263"
  },
  {
    "country": "CA",
    "name": "Port Alberni",
    "lat": "49.24133",
    "lng": "-124.8028"
  },
  {
    "country": "CA",
    "name": "Port-Cartier",
    "lat": "50.03339",
    "lng": "-66.86545"
  },
  {
    "country": "CA",
    "name": "Port Colborne",
    "lat": "42.90012",
    "lng": "-79.23288"
  },
  {
    "country": "CA",
    "name": "Port Hawkesbury",
    "lat": "45.61685",
    "lng": "-61.34853"
  },
  {
    "country": "CA",
    "name": "Port Moody",
    "lat": "49.28297",
    "lng": "-122.85263"
  },
  {
    "country": "CA",
    "name": "Powassan",
    "lat": "46.0334",
    "lng": "-79.34961"
  },
  {
    "country": "CA",
    "name": "Powell River",
    "lat": "49.83278",
    "lng": "-124.52368"
  },
  {
    "country": "CA",
    "name": "Preeceville",
    "lat": "51.94998",
    "lng": "-102.66766"
  },
  {
    "country": "CA",
    "name": "Prescott",
    "lat": "44.71681",
    "lng": "-75.51604"
  },
  {
    "country": "CA",
    "name": "Prévost",
    "lat": "45.86678",
    "lng": "-74.08251"
  },
  {
    "country": "CA",
    "name": "Prince Albert",
    "lat": "53.20008",
    "lng": "-105.76772"
  },
  {
    "country": "CA",
    "name": "Prince Edward",
    "lat": "44.00012",
    "lng": "-77.24946"
  },
  {
    "country": "CA",
    "name": "Prince George",
    "lat": "53.9166",
    "lng": "-122.75301"
  },
  {
    "country": "CA",
    "name": "Prince Rupert",
    "lat": "54.31507",
    "lng": "-130.32098"
  },
  {
    "country": "CA",
    "name": "Princeton",
    "lat": "49.45802",
    "lng": "-120.51076"
  },
  {
    "country": "CA",
    "name": "Princeville",
    "lat": "45.76684",
    "lng": "-61.29853"
  },
  {
    "country": "CA",
    "name": "Provost",
    "lat": "52.35014",
    "lng": "-110.26828"
  },
  {
    "country": "CA",
    "name": "Quesnel",
    "lat": "52.97842",
    "lng": "-122.4931"
  },
  {
    "country": "CA",
    "name": "Quinte West",
    "lat": "44.18342",
    "lng": "-77.56618"
  },
  {
    "country": "CA",
    "name": "Rankin Inlet",
    "lat": "62.80906",
    "lng": "-92.08534"
  },
  {
    "country": "CA",
    "name": "Rawdon",
    "lat": "46.05007",
    "lng": "-73.71587"
  },
  {
    "country": "CA",
    "name": "Raymond",
    "lat": "49.44998",
    "lng": "-112.65185"
  },
  {
    "country": "CA",
    "name": "Rayside-Balfour",
    "lat": "46.60873",
    "lng": "-81.20763"
  },
  {
    "country": "CA",
    "name": "Red Deer",
    "lat": "52.26682",
    "lng": "-113.802"
  },
  {
    "country": "CA",
    "name": "Red Lake",
    "lat": "51.01678",
    "lng": "-93.82736"
  },
  {
    "country": "CA",
    "name": "Regina",
    "lat": "50.45008",
    "lng": "-104.6178"
  },
  {
    "country": "CA",
    "name": "Renfrew",
    "lat": "45.46681",
    "lng": "-76.68272"
  },
  {
    "country": "CA",
    "name": "Repentigny",
    "lat": "45.74222",
    "lng": "-73.45008"
  },
  {
    "country": "CA",
    "name": "Revelstoke",
    "lat": "50.99712",
    "lng": "-118.1953"
  },
  {
    "country": "CA",
    "name": "Richelieu",
    "lat": "45.44336",
    "lng": "-73.24602"
  },
  {
    "country": "CA",
    "name": "Richibucto",
    "lat": "46.68073",
    "lng": "-64.88044"
  },
  {
    "country": "CA",
    "name": "Richmond",
    "lat": "45.66677",
    "lng": "-72.1491"
  },
  {
    "country": "CA",
    "name": "Richmond",
    "lat": "49.17003",
    "lng": "-123.13683"
  },
  {
    "country": "CA",
    "name": "Richmond Hill",
    "lat": "43.87111",
    "lng": "-79.43725"
  },
  {
    "country": "CA",
    "name": "Rideau Park",
    "lat": "53.47899",
    "lng": "-113.5047"
  },
  {
    "country": "CA",
    "name": "Rigaud",
    "lat": "45.47927",
    "lng": "-74.30238"
  },
  {
    "country": "CA",
    "name": "Rimbey",
    "lat": "52.6334",
    "lng": "-114.23532"
  },
  {
    "country": "CA",
    "name": "Rivers",
    "lat": "50.03081",
    "lng": "-100.24029"
  },
  {
    "country": "CA",
    "name": "Rivière-Rouge",
    "lat": "46.41679",
    "lng": "-74.86596"
  },
  {
    "country": "CA",
    "name": "Roberval",
    "lat": "48.5168",
    "lng": "-72.23244"
  },
  {
    "country": "CA",
    "name": "Roblin",
    "lat": "51.22999",
    "lng": "-101.3565"
  },
  {
    "country": "CA",
    "name": "Rock Forest",
    "lat": "45.35699",
    "lng": "-71.99676"
  },
  {
    "country": "CA",
    "name": "Rocky Mountain House",
    "lat": "52.36683",
    "lng": "-114.9188"
  },
  {
    "country": "CA",
    "name": "Rosemère",
    "lat": "45.63338",
    "lng": "-73.79919"
  },
  {
    "country": "CA",
    "name": "Rosetown",
    "lat": "51.5501",
    "lng": "-108.00136"
  },
  {
    "country": "CA",
    "name": "Rossland",
    "lat": "49.08313",
    "lng": "-117.80224"
  },
  {
    "country": "CA",
    "name": "Rosthern",
    "lat": "52.66679",
    "lng": "-106.33446"
  },
  {
    "country": "CA",
    "name": "Rougemont",
    "lat": "45.43338",
    "lng": "-73.04914"
  },
  {
    "country": "CA",
    "name": "Rouyn-Noranda",
    "lat": "48.23656",
    "lng": "-79.02311"
  },
  {
    "country": "CA",
    "name": "Sackville",
    "lat": "45.91875",
    "lng": "-64.38455"
  },
  {
    "country": "CA",
    "name": "Saguenay",
    "lat": "48.41675",
    "lng": "-71.06573"
  },
  {
    "country": "CA",
    "name": "Saint-Adolphe-d'Howard",
    "lat": "45.96679",
    "lng": "-74.33253"
  },
  {
    "country": "CA",
    "name": "Saint-Ambroise",
    "lat": "48.55009",
    "lng": "-71.33238"
  },
  {
    "country": "CA",
    "name": "Saint-André-Avellin",
    "lat": "45.7168",
    "lng": "-75.06599"
  },
  {
    "country": "CA",
    "name": "Saint Andrews",
    "lat": "45.0737",
    "lng": "-67.05312"
  },
  {
    "country": "CA",
    "name": "Saint-Augustin",
    "lat": "51.22602",
    "lng": "-58.65017"
  },
  {
    "country": "CA",
    "name": "Saint-Basile-le-Grand",
    "lat": "45.53338",
    "lng": "-73.28246"
  },
  {
    "country": "CA",
    "name": "Saint-Bruno",
    "lat": "48.46679",
    "lng": "-71.6491"
  },
  {
    "country": "CA",
    "name": "Saint-Bruno-de-Guigues",
    "lat": "47.46685",
    "lng": "-79.43296"
  },
  {
    "country": "CA",
    "name": "Saint-Bruno-de-Montarville",
    "lat": "45.53341",
    "lng": "-73.34916"
  },
  {
    "country": "CA",
    "name": "Saint-Césaire",
    "lat": "45.41678",
    "lng": "-72.99914"
  },
  {
    "country": "CA",
    "name": "Saint-Colomban",
    "lat": "45.73338",
    "lng": "-74.13251"
  },
  {
    "country": "CA",
    "name": "Saint-Côme--Linière",
    "lat": "46.06677",
    "lng": "-70.51573"
  },
  {
    "country": "CA",
    "name": "Saint-Constant",
    "lat": "45.36678",
    "lng": "-73.56588"
  },
  {
    "country": "CA",
    "name": "Saint-Cyrille-de-Wendover",
    "lat": "45.93336",
    "lng": "-72.43241"
  },
  {
    "country": "CA",
    "name": "Saint-Damase",
    "lat": "45.53341",
    "lng": "-72.99914"
  },
  {
    "country": "CA",
    "name": "Saint-Denis-sur-Richelieu",
    "lat": "45.78338",
    "lng": "-73.14915"
  },
  {
    "country": "CA",
    "name": "Sainte-Adèle",
    "lat": "45.95008",
    "lng": "-74.13251"
  },
  {
    "country": "CA",
    "name": "Sainte-Agathe-des-Monts",
    "lat": "46.05009",
    "lng": "-74.28252"
  },
  {
    "country": "CA",
    "name": "Sainte-Anne-de-Bellevue",
    "lat": "45.40618",
    "lng": "-73.9456"
  },
  {
    "country": "CA",
    "name": "Sainte-Anne-des-Monts",
    "lat": "49.12402",
    "lng": "-66.49243"
  },
  {
    "country": "CA",
    "name": "Sainte-Anne-des-Plaines",
    "lat": "45.76468",
    "lng": "-73.81156"
  },
  {
    "country": "CA",
    "name": "Sainte-Béatrix",
    "lat": "46.20007",
    "lng": "-73.61587"
  },
  {
    "country": "CA",
    "name": "Sainte-Catherine",
    "lat": "45.40008",
    "lng": "-73.58248"
  },
  {
    "country": "CA",
    "name": "Sainte-Catherine",
    "lat": "46.31836",
    "lng": "-72.56632"
  },
  {
    "country": "CA",
    "name": "Saint-Édouard",
    "lat": "45.23338",
    "lng": "-73.51588"
  },
  {
    "country": "CA",
    "name": "Sainte-Julie",
    "lat": "45.58338",
    "lng": "-73.33246"
  },
  {
    "country": "CA",
    "name": "Sainte-Julienne",
    "lat": "45.96677",
    "lng": "-73.71587"
  },
  {
    "country": "CA",
    "name": "Sainte-Marthe-sur-le-Lac",
    "lat": "45.53338",
    "lng": "-73.9325"
  },
  {
    "country": "CA",
    "name": "Sainte-Martine",
    "lat": "45.25008",
    "lng": "-73.79919"
  },
  {
    "country": "CA",
    "name": "Sainte-Sophie",
    "lat": "45.81678",
    "lng": "-73.89919"
  },
  {
    "country": "CA",
    "name": "Sainte-Thècle",
    "lat": "46.81676",
    "lng": "-72.49911"
  },
  {
    "country": "CA",
    "name": "Sainte-Thérèse",
    "lat": "45.63922",
    "lng": "-73.82757"
  },
  {
    "country": "CA",
    "name": "Saint-Eustache",
    "lat": "45.565",
    "lng": "-73.90554"
  },
  {
    "country": "CA",
    "name": "Saint-Félicien",
    "lat": "48.65007",
    "lng": "-72.44906"
  },
  {
    "country": "CA",
    "name": "Saint-Félix-de-Valois",
    "lat": "46.16977",
    "lng": "-73.42525"
  },
  {
    "country": "CA",
    "name": "Saint-Gabriel",
    "lat": "46.30007",
    "lng": "-73.38245"
  },
  {
    "country": "CA",
    "name": "Saint-Gédéon",
    "lat": "48.50009",
    "lng": "-71.76581"
  },
  {
    "country": "CA",
    "name": "Saint-Germain-de-Grantham",
    "lat": "45.83337",
    "lng": "-72.56582"
  },
  {
    "country": "CA",
    "name": "Saint-Hippolyte",
    "lat": "45.93338",
    "lng": "-74.0159"
  },
  {
    "country": "CA",
    "name": "Saint-Hyacinthe",
    "lat": "45.63076",
    "lng": "-72.95699"
  },
  {
    "country": "CA",
    "name": "Saint-Jacques",
    "lat": "45.95007",
    "lng": "-73.56586"
  },
  {
    "country": "CA",
    "name": "Saint-Jacques-le-Mineur",
    "lat": "45.28338",
    "lng": "-73.41587"
  },
  {
    "country": "CA",
    "name": "Saint-Jean-sur-Richelieu",
    "lat": "45.30713",
    "lng": "-73.26259"
  },
  {
    "country": "CA",
    "name": "Saint-Jérôme",
    "lat": "45.78036",
    "lng": "-74.00365"
  },
  {
    "country": "CA",
    "name": "Saint John",
    "lat": "45.27271",
    "lng": "-66.06766"
  },
  {
    "country": "CA",
    "name": "Saint-Joseph-de-Coleraine",
    "lat": "45.96677",
    "lng": "-71.36577"
  },
  {
    "country": "CA",
    "name": "Saint-Joseph-du-Lac",
    "lat": "45.53338",
    "lng": "-73.9992"
  },
  {
    "country": "CA",
    "name": "Saint-Laurent",
    "lat": "45.50008",
    "lng": "-73.66585"
  },
  {
    "country": "CA",
    "name": "Saint-Lazare",
    "lat": "45.40008",
    "lng": "-74.13256"
  },
  {
    "country": "CA",
    "name": "Saint-Léonard",
    "lat": "45.58773",
    "lng": "-73.59501"
  },
  {
    "country": "CA",
    "name": "Saint-Lin-Laurentides",
    "lat": "45.85008",
    "lng": "-73.76588"
  },
  {
    "country": "CA",
    "name": "Saint-Marc-des-Carrières",
    "lat": "46.68335",
    "lng": "-72.0491"
  },
  {
    "country": "CA",
    "name": "Saint-Mathieu",
    "lat": "45.31678",
    "lng": "-73.51587"
  },
  {
    "country": "CA",
    "name": "Saint-Michel-des-Saints",
    "lat": "46.68338",
    "lng": "-73.91589"
  },
  {
    "country": "CA",
    "name": "Saint-Nazaire",
    "lat": "48.58944",
    "lng": "-71.55247"
  },
  {
    "country": "CA",
    "name": "Saint-Philippe-de-La Prairie",
    "lat": "45.35723",
    "lng": "-73.47706"
  },
  {
    "country": "CA",
    "name": "Saint-Pie",
    "lat": "45.50277",
    "lng": "-72.9089"
  },
  {
    "country": "CA",
    "name": "Saint-Pie-V",
    "lat": "46.00351",
    "lng": "-72.74689"
  },
  {
    "country": "CA",
    "name": "Saint-Pierre-les-Becquets",
    "lat": "46.50005",
    "lng": "-72.1991"
  },
  {
    "country": "CA",
    "name": "Saint-Polycarpe",
    "lat": "45.30009",
    "lng": "-74.29924"
  },
  {
    "country": "CA",
    "name": "Saint-Raymond",
    "lat": "45.46698",
    "lng": "-73.60948"
  },
  {
    "country": "CA",
    "name": "Saint-Rémi",
    "lat": "45.26678",
    "lng": "-73.61588"
  },
  {
    "country": "CA",
    "name": "Saint-Rémi-de-Tingwick",
    "lat": "45.86677",
    "lng": "-71.81581"
  },
  {
    "country": "CA",
    "name": "Saint-Sauveur",
    "lat": "45.88686",
    "lng": "-74.17943"
  },
  {
    "country": "CA",
    "name": "Saint-Thomas",
    "lat": "46.01677",
    "lng": "-73.34915"
  },
  {
    "country": "CA",
    "name": "Saint-Tite",
    "lat": "46.73336",
    "lng": "-72.56581"
  },
  {
    "country": "CA",
    "name": "Saint-Zotique",
    "lat": "45.25009",
    "lng": "-74.24924"
  },
  {
    "country": "CA",
    "name": "Salaberry-de-Valleyfield",
    "lat": "45.25008",
    "lng": "-74.13253"
  },
  {
    "country": "CA",
    "name": "Salisbury",
    "lat": "46.03905",
    "lng": "-65.04628"
  },
  {
    "country": "CA",
    "name": "Salmo",
    "lat": "49.19986",
    "lng": "-117.2689"
  },
  {
    "country": "CA",
    "name": "Salmon Arm",
    "lat": "50.6998",
    "lng": "-119.30237"
  },
  {
    "country": "CA",
    "name": "Sarnia",
    "lat": "42.97866",
    "lng": "-82.40407"
  },
  {
    "country": "CA",
    "name": "Saskatoon",
    "lat": "52.13238",
    "lng": "-106.66892"
  },
  {
    "country": "CA",
    "name": "Sault Ste. Marie",
    "lat": "46.51677",
    "lng": "-84.33325"
  },
  {
    "country": "CA",
    "name": "Sechelt",
    "lat": "49.47512",
    "lng": "-123.75903"
  },
  {
    "country": "CA",
    "name": "Selkirk",
    "lat": "50.1436",
    "lng": "-96.88452"
  },
  {
    "country": "CA",
    "name": "Senneterre",
    "lat": "48.39302",
    "lng": "-77.23951"
  },
  {
    "country": "CA",
    "name": "Sept-Îles",
    "lat": "50.20011",
    "lng": "-66.38208"
  },
  {
    "country": "CA",
    "name": "Sexsmith",
    "lat": "55.34998",
    "lng": "-118.78602"
  },
  {
    "country": "CA",
    "name": "Shaunavon",
    "lat": "49.65005",
    "lng": "-108.4181"
  },
  {
    "country": "CA",
    "name": "Shawinigan",
    "lat": "46.56675",
    "lng": "-72.74913"
  },
  {
    "country": "CA",
    "name": "Shawville",
    "lat": "45.60011",
    "lng": "-76.4827"
  },
  {
    "country": "CA",
    "name": "Shediac",
    "lat": "46.21981",
    "lng": "-64.54107"
  },
  {
    "country": "CA",
    "name": "Shelburne",
    "lat": "43.76325",
    "lng": "-65.32355"
  },
  {
    "country": "CA",
    "name": "Shelburne",
    "lat": "44.0787",
    "lng": "-80.20408"
  },
  {
    "country": "CA",
    "name": "Shellbrook",
    "lat": "53.21679",
    "lng": "-106.40109"
  },
  {
    "country": "CA",
    "name": "Sherbrooke",
    "lat": "45.40008",
    "lng": "-71.89908"
  },
  {
    "country": "CA",
    "name": "Sherwood Park",
    "lat": "53.51684",
    "lng": "-113.3187"
  },
  {
    "country": "CA",
    "name": "Sicamous",
    "lat": "50.83312",
    "lng": "-118.98565"
  },
  {
    "country": "CA",
    "name": "Simcoe",
    "lat": "42.8334",
    "lng": "-80.29967"
  },
  {
    "country": "CA",
    "name": "Slave Lake",
    "lat": "55.28344",
    "lng": "-114.76896"
  },
  {
    "country": "CA",
    "name": "Smithers",
    "lat": "54.78036",
    "lng": "-127.17428"
  },
  {
    "country": "CA",
    "name": "Smiths Falls",
    "lat": "44.90452",
    "lng": "-76.02333"
  },
  {
    "country": "CA",
    "name": "Smoky Lake",
    "lat": "54.11687",
    "lng": "-112.46863"
  },
  {
    "country": "CA",
    "name": "Sooke",
    "lat": "48.37463",
    "lng": "-123.72762"
  },
  {
    "country": "CA",
    "name": "Souris",
    "lat": "46.3501",
    "lng": "-62.24862"
  },
  {
    "country": "CA",
    "name": "Souris",
    "lat": "49.6172",
    "lng": "-100.2612"
  },
  {
    "country": "CA",
    "name": "South Huron",
    "lat": "43.31679",
    "lng": "-81.51647"
  },
  {
    "country": "CA",
    "name": "South River",
    "lat": "45.8334",
    "lng": "-79.38293"
  },
  {
    "country": "CA",
    "name": "Sparwood",
    "lat": "49.73332",
    "lng": "-114.88532"
  },
  {
    "country": "CA",
    "name": "Spirit River",
    "lat": "55.78327",
    "lng": "-118.83607"
  },
  {
    "country": "CA",
    "name": "Springhill",
    "lat": "45.65015",
    "lng": "-64.04873"
  },
  {
    "country": "CA",
    "name": "Spruce Grove",
    "lat": "53.53344",
    "lng": "-113.91874"
  },
  {
    "country": "CA",
    "name": "St. Albert",
    "lat": "53.63344",
    "lng": "-113.63533"
  },
  {
    "country": "CA",
    "name": "St. Catharines",
    "lat": "43.17126",
    "lng": "-79.24267"
  },
  {
    "country": "CA",
    "name": "Steinbach",
    "lat": "49.52579",
    "lng": "-96.68451"
  },
  {
    "country": "CA",
    "name": "Stephenville",
    "lat": "48.55001",
    "lng": "-58.5818"
  },
  {
    "country": "CA",
    "name": "Stephenville Crossing",
    "lat": "48.50001",
    "lng": "-58.4318"
  },
  {
    "country": "CA",
    "name": "Stettler",
    "lat": "52.31683",
    "lng": "-112.71861"
  },
  {
    "country": "CA",
    "name": "Stonewall",
    "lat": "50.13441",
    "lng": "-97.32676"
  },
  {
    "country": "CA",
    "name": "Stony Plain",
    "lat": "53.53343",
    "lng": "-114.00205"
  },
  {
    "country": "CA",
    "name": "Stratford",
    "lat": "43.36679",
    "lng": "-80.94972"
  },
  {
    "country": "CA",
    "name": "Strathmore",
    "lat": "51.05011",
    "lng": "-113.38523"
  },
  {
    "country": "CA",
    "name": "St. Thomas",
    "lat": "42.77361",
    "lng": "-81.18038"
  },
  {
    "country": "CA",
    "name": "Summerland",
    "lat": "49.59977",
    "lng": "-119.66911"
  },
  {
    "country": "CA",
    "name": "Summerside",
    "lat": "46.39593",
    "lng": "-63.78762"
  },
  {
    "country": "CA",
    "name": "Sundre",
    "lat": "51.8001",
    "lng": "-114.63532"
  },
  {
    "country": "CA",
    "name": "Surrey",
    "lat": "49.10635",
    "lng": "-122.82509"
  },
  {
    "country": "CA",
    "name": "Sussex",
    "lat": "45.72266",
    "lng": "-65.50663"
  },
  {
    "country": "CA",
    "name": "Sutton",
    "lat": "45.10008",
    "lng": "-72.61582"
  },
  {
    "country": "CA",
    "name": "Swan Hills",
    "lat": "54.71681",
    "lng": "-115.40226"
  },
  {
    "country": "CA",
    "name": "Swan River",
    "lat": "52.1058",
    "lng": "-101.26759"
  },
  {
    "country": "CA",
    "name": "Swift Current",
    "lat": "50.28337",
    "lng": "-107.80135"
  },
  {
    "country": "CA",
    "name": "Sylvan Lake",
    "lat": "52.311",
    "lng": "-114.08375"
  },
  {
    "country": "CA",
    "name": "Taber",
    "lat": "49.78703",
    "lng": "-112.14603"
  },
  {
    "country": "CA",
    "name": "Témiscaming",
    "lat": "46.72122",
    "lng": "-79.09712"
  },
  {
    "country": "CA",
    "name": "Temiskaming Shores",
    "lat": "47.49376",
    "lng": "-79.71529"
  },
  {
    "country": "CA",
    "name": "Terrace",
    "lat": "54.51634",
    "lng": "-128.60345"
  },
  {
    "country": "CA",
    "name": "Terrebonne",
    "lat": "45.70004",
    "lng": "-73.64732"
  },
  {
    "country": "CA",
    "name": "The Pas",
    "lat": "53.82509",
    "lng": "-101.25413"
  },
  {
    "country": "CA",
    "name": "Thessalon",
    "lat": "46.25006",
    "lng": "-83.5666"
  },
  {
    "country": "CA",
    "name": "Thompson",
    "lat": "55.7435",
    "lng": "-97.85579"
  },
  {
    "country": "CA",
    "name": "Thorold",
    "lat": "43.11682",
    "lng": "-79.19958"
  },
  {
    "country": "CA",
    "name": "Three Hills",
    "lat": "51.70012",
    "lng": "-113.26863"
  },
  {
    "country": "CA",
    "name": "Thunder Bay",
    "lat": "48.38202",
    "lng": "-89.25018"
  },
  {
    "country": "CA",
    "name": "Thurso",
    "lat": "45.6001",
    "lng": "-75.24931"
  },
  {
    "country": "CA",
    "name": "Timmins",
    "lat": "48.46686",
    "lng": "-81.33312"
  },
  {
    "country": "CA",
    "name": "Tisdale",
    "lat": "52.85002",
    "lng": "-104.05096"
  },
  {
    "country": "CA",
    "name": "Tobermory",
    "lat": "45.25007",
    "lng": "-81.66647"
  },
  {
    "country": "CA",
    "name": "Tofield",
    "lat": "53.36684",
    "lng": "-112.66862"
  },
  {
    "country": "CA",
    "name": "Torbay",
    "lat": "47.66659",
    "lng": "-52.73135"
  },
  {
    "country": "CA",
    "name": "Toronto",
    "lat": "43.70011",
    "lng": "-79.4163"
  },
  {
    "country": "CA",
    "name": "Trail",
    "lat": "49.09983",
    "lng": "-117.70223"
  },
  {
    "country": "CA",
    "name": "Trois-Rivières",
    "lat": "46.34515",
    "lng": "-72.5477"
  },
  {
    "country": "CA",
    "name": "Truro",
    "lat": "45.36685",
    "lng": "-63.26538"
  },
  {
    "country": "CA",
    "name": "Tumbler Ridge",
    "lat": "55.13027",
    "lng": "-120.99415"
  },
  {
    "country": "CA",
    "name": "Two Hills",
    "lat": "53.71686",
    "lng": "-111.75181"
  },
  {
    "country": "CA",
    "name": "Ucluelet",
    "lat": "48.94153",
    "lng": "-125.54635"
  },
  {
    "country": "CA",
    "name": "Unity",
    "lat": "52.45014",
    "lng": "-109.16816"
  },
  {
    "country": "CA",
    "name": "Uxbridge",
    "lat": "44.10012",
    "lng": "-79.11628"
  },
  {
    "country": "CA",
    "name": "Valcourt",
    "lat": "45.50008",
    "lng": "-72.31581"
  },
  {
    "country": "CA",
    "name": "Val-David",
    "lat": "46.03338",
    "lng": "-74.21592"
  },
  {
    "country": "CA",
    "name": "Val-des-Monts",
    "lat": "45.6501",
    "lng": "-75.66604"
  },
  {
    "country": "CA",
    "name": "Val-d'Or",
    "lat": "48.0974",
    "lng": "-77.79737"
  },
  {
    "country": "CA",
    "name": "Valleyview",
    "lat": "55.06673",
    "lng": "-117.28585"
  },
  {
    "country": "CA",
    "name": "Val-Morin",
    "lat": "46.00008",
    "lng": "-74.18251"
  },
  {
    "country": "CA",
    "name": "Vancouver",
    "lat": "49.24966",
    "lng": "-123.11934"
  },
  {
    "country": "CA",
    "name": "Vanderhoof",
    "lat": "54.01657",
    "lng": "-124.01982"
  },
  {
    "country": "CA",
    "name": "Varennes",
    "lat": "45.68338",
    "lng": "-73.43246"
  },
  {
    "country": "CA",
    "name": "Vaudreuil-Dorion",
    "lat": "45.40008",
    "lng": "-74.03251"
  },
  {
    "country": "CA",
    "name": "Vaughan",
    "lat": "43.8361",
    "lng": "-79.49827"
  },
  {
    "country": "CA",
    "name": "Vegreville",
    "lat": "53.50015",
    "lng": "-112.05182"
  },
  {
    "country": "CA",
    "name": "Venise-en-Québec",
    "lat": "45.08338",
    "lng": "-73.13245"
  },
  {
    "country": "CA",
    "name": "Verchères",
    "lat": "45.78338",
    "lng": "-73.34916"
  },
  {
    "country": "CA",
    "name": "Vermilion",
    "lat": "53.35409",
    "lng": "-110.85849"
  },
  {
    "country": "CA",
    "name": "Vernon",
    "lat": "50.26729",
    "lng": "-119.27337"
  },
  {
    "country": "CA",
    "name": "Victoria",
    "lat": "48.43294",
    "lng": "-123.3693"
  },
  {
    "country": "CA",
    "name": "Victoriaville",
    "lat": "46.05007",
    "lng": "-71.96579"
  },
  {
    "country": "CA",
    "name": "Viking",
    "lat": "53.10014",
    "lng": "-111.76844"
  },
  {
    "country": "CA",
    "name": "Ville-Marie",
    "lat": "47.33345",
    "lng": "-79.43297"
  },
  {
    "country": "CA",
    "name": "Virden",
    "lat": "49.8508",
    "lng": "-100.93262"
  },
  {
    "country": "CA",
    "name": "Vulcan",
    "lat": "50.40008",
    "lng": "-113.25189"
  },
  {
    "country": "CA",
    "name": "Wabana",
    "lat": "47.63319",
    "lng": "-52.94806"
  },
  {
    "country": "CA",
    "name": "Wadena",
    "lat": "51.94999",
    "lng": "-103.80102"
  },
  {
    "country": "CA",
    "name": "Wainwright",
    "lat": "52.83482",
    "lng": "-110.85342"
  },
  {
    "country": "CA",
    "name": "Wakefield",
    "lat": "45.6668",
    "lng": "-75.83265"
  },
  {
    "country": "CA",
    "name": "Walpole Island",
    "lat": "42.6152",
    "lng": "-82.51398"
  },
  {
    "country": "CA",
    "name": "Warman",
    "lat": "52.31679",
    "lng": "-106.56791"
  },
  {
    "country": "CA",
    "name": "Warwick",
    "lat": "45.95007",
    "lng": "-71.9824"
  },
  {
    "country": "CA",
    "name": "Wasaga Beach",
    "lat": "44.5168",
    "lng": "-80.01637"
  },
  {
    "country": "CA",
    "name": "Waswanipi",
    "lat": "49.73346",
    "lng": "-76.16604"
  },
  {
    "country": "CA",
    "name": "Waterloo",
    "lat": "45.35008",
    "lng": "-72.51582"
  },
  {
    "country": "CA",
    "name": "Waterloo",
    "lat": "43.4668",
    "lng": "-80.51639"
  },
  {
    "country": "CA",
    "name": "Watrous",
    "lat": "51.66677",
    "lng": "-105.46788"
  },
  {
    "country": "CA",
    "name": "Watson Lake",
    "lat": "60.06349",
    "lng": "-128.70893"
  },
  {
    "country": "CA",
    "name": "Welland",
    "lat": "42.98342",
    "lng": "-79.24958"
  },
  {
    "country": "CA",
    "name": "Wembley",
    "lat": "55.14995",
    "lng": "-119.13602"
  },
  {
    "country": "CA",
    "name": "West End",
    "lat": "49.28333",
    "lng": "-123.13333"
  },
  {
    "country": "CA",
    "name": "Westlock",
    "lat": "54.15016",
    "lng": "-113.86876"
  },
  {
    "country": "CA",
    "name": "Westmount",
    "lat": "45.48341",
    "lng": "-73.59918"
  },
  {
    "country": "CA",
    "name": "Wetaskiwin",
    "lat": "52.96683",
    "lng": "-113.36869"
  },
  {
    "country": "CA",
    "name": "Weyburn",
    "lat": "49.66675",
    "lng": "-103.85109"
  },
  {
    "country": "CA",
    "name": "Whistler",
    "lat": "50.1164",
    "lng": "-122.96946"
  },
  {
    "country": "CA",
    "name": "White City",
    "lat": "50.43338",
    "lng": "-104.36778"
  },
  {
    "country": "CA",
    "name": "Whitecourt",
    "lat": "54.15015",
    "lng": "-115.68548"
  },
  {
    "country": "CA",
    "name": "Whitehorse",
    "lat": "60.71611",
    "lng": "-135.05375"
  },
  {
    "country": "CA",
    "name": "White Rock",
    "lat": "49.01636",
    "lng": "-122.8026"
  },
  {
    "country": "CA",
    "name": "Wilkie",
    "lat": "52.41683",
    "lng": "-108.70142"
  },
  {
    "country": "CA",
    "name": "Williams Lake",
    "lat": "52.14153",
    "lng": "-122.14451"
  },
  {
    "country": "CA",
    "name": "Windsor",
    "lat": "44.98345",
    "lng": "-64.13204"
  },
  {
    "country": "CA",
    "name": "Windsor",
    "lat": "45.56678",
    "lng": "-71.99909"
  },
  {
    "country": "CA",
    "name": "Windsor",
    "lat": "42.30008",
    "lng": "-83.01654"
  },
  {
    "country": "CA",
    "name": "Wingham",
    "lat": "43.88793",
    "lng": "-81.31145"
  },
  {
    "country": "CA",
    "name": "Winkler",
    "lat": "49.1817",
    "lng": "-97.94104"
  },
  {
    "country": "CA",
    "name": "Winnipeg",
    "lat": "49.8844",
    "lng": "-97.14704"
  },
  {
    "country": "CA",
    "name": "Wolfville",
    "lat": "45.08345",
    "lng": "-64.36546"
  },
  {
    "country": "CA",
    "name": "Woodstock",
    "lat": "43.13339",
    "lng": "-80.7497"
  },
  {
    "country": "CA",
    "name": "Wynyard",
    "lat": "51.76674",
    "lng": "-104.18436"
  },
  {
    "country": "CA",
    "name": "Yamachiche",
    "lat": "46.26676",
    "lng": "-72.83243"
  },
  {
    "country": "CA",
    "name": "Yarmouth",
    "lat": "43.83345",
    "lng": "-66.11557"
  },
  {
    "country": "CA",
    "name": "Yellowknife",
    "lat": "62.45411",
    "lng": "-114.37248"
  },
  {
    "country": "CA",
    "name": "Yorkton",
    "lat": "51.2167",
    "lng": "-102.46766"
  },
  {
    "country": "CA",
    "name": "Beauceville",
    "lat": "46.21785",
    "lng": "-70.77873"
  },
  {
    "country": "CA",
    "name": "Halifax",
    "lat": "44.64533",
    "lng": "-63.57239"
  },
  {
    "country": "CA",
    "name": "St. John's",
    "lat": "47.56494",
    "lng": "-52.70931"
  },
  {
    "country": "CA",
    "name": "Beaupré",
    "lat": "47.04428",
    "lng": "-70.89529"
  },
  {
    "country": "CA",
    "name": "Château-Richer",
    "lat": "46.96031",
    "lng": "-71.03219"
  },
  {
    "country": "CA",
    "name": "Québec",
    "lat": "46.81228",
    "lng": "-71.21454"
  },
  {
    "country": "CA",
    "name": "L'Ange-Gardien",
    "lat": "46.91976",
    "lng": "-71.08253"
  },
  {
    "country": "CA",
    "name": "Lévis",
    "lat": "46.80326",
    "lng": "-71.17793"
  },
  {
    "country": "CA",
    "name": "Montmagny",
    "lat": "46.98043",
    "lng": "-70.55493"
  },
  {
    "country": "CA",
    "name": "Neuville",
    "lat": "46.69823",
    "lng": "-71.58275"
  },
  {
    "country": "CA",
    "name": "Portneuf",
    "lat": "46.69058",
    "lng": "-71.89011"
  },
  {
    "country": "CA",
    "name": "Rimouski",
    "lat": "48.44879",
    "lng": "-68.52396"
  },
  {
    "country": "CA",
    "name": "Rivière-du-Loup",
    "lat": "47.82699",
    "lng": "-69.54243"
  },
  {
    "country": "CA",
    "name": "Sydney",
    "lat": "46.1351",
    "lng": "-60.1831"
  },
  {
    "country": "CA",
    "name": "Tofino",
    "lat": "49.15314",
    "lng": "-125.90744"
  },
  {
    "country": "CA",
    "name": "L'Ancienne-Lorette",
    "lat": "46.79392",
    "lng": "-71.35191"
  },
  {
    "country": "CA",
    "name": "Edmundston",
    "lat": "47.3737",
    "lng": "-68.32512"
  },
  {
    "country": "CA",
    "name": "St-Jean-Port-Joli",
    "lat": "47.21418",
    "lng": "-70.26969"
  },
  {
    "country": "CA",
    "name": "Saint-Georges",
    "lat": "46.11353",
    "lng": "-70.66526"
  },
  {
    "country": "CA",
    "name": "Sainte Catherine de la Jacques Cartier",
    "lat": "46.85244",
    "lng": "-71.62056"
  },
  {
    "country": "CA",
    "name": "Baie-Saint-Paul",
    "lat": "47.44109",
    "lng": "-70.49858"
  },
  {
    "country": "CA",
    "name": "Carleton-sur-Mer",
    "lat": "48.10749",
    "lng": "-66.128"
  },
  {
    "country": "CA",
    "name": "Cacouna",
    "lat": "47.91657",
    "lng": "-69.50054"
  },
  {
    "country": "CA",
    "name": "Campbellton",
    "lat": "48.00751",
    "lng": "-66.67272"
  },
  {
    "country": "CA",
    "name": "Bathurst",
    "lat": "47.61814",
    "lng": "-65.65112"
  },
  {
    "country": "CA",
    "name": "Matane",
    "lat": "48.82857",
    "lng": "-67.52197"
  },
  {
    "country": "CA",
    "name": "Paris",
    "lat": "43.2",
    "lng": "-80.38333"
  },
  {
    "country": "CA",
    "name": "Amqui",
    "lat": "48.46382",
    "lng": "-67.43134"
  },
  {
    "country": "CA",
    "name": "Dawson City",
    "lat": "64.06013",
    "lng": "-139.43328"
  },
  {
    "country": "CA",
    "name": "Chandler",
    "lat": "48.34935",
    "lng": "-64.67926"
  },
  {
    "country": "CA",
    "name": "Bonaventure",
    "lat": "48.04573",
    "lng": "-65.49259"
  },
  {
    "country": "CA",
    "name": "New-Richmond",
    "lat": "48.16059",
    "lng": "-65.85823"
  },
  {
    "country": "CA",
    "name": "Thetford-Mines",
    "lat": "46.09371",
    "lng": "-71.30539"
  },
  {
    "country": "CA",
    "name": "New Carlisle",
    "lat": "48.00956",
    "lng": "-65.33621"
  },
  {
    "country": "CA",
    "name": "Cabano",
    "lat": "47.68065",
    "lng": "-68.8781"
  },
  {
    "country": "CA",
    "name": "Sacré-Coeur",
    "lat": "48.2297",
    "lng": "-69.80061"
  },
  {
    "country": "CA",
    "name": "Forestville",
    "lat": "48.73808",
    "lng": "-69.08478"
  },
  {
    "country": "CA",
    "name": "Mont-Joli",
    "lat": "48.58388",
    "lng": "-68.19214"
  },
  {
    "country": "CA",
    "name": "Lillooet",
    "lat": "50.6856",
    "lng": "-121.942"
  },
  {
    "country": "CA",
    "name": "La Malbaie",
    "lat": "47.654",
    "lng": "-70.15268"
  },
  {
    "country": "CA",
    "name": "Sainte-Marie",
    "lat": "46.43401",
    "lng": "-71.01168"
  },
  {
    "country": "CA",
    "name": "Plessisville",
    "lat": "46.21856",
    "lng": "-71.76201"
  },
  {
    "country": "CA",
    "name": "Maliotenam",
    "lat": "50.21119",
    "lng": "-66.18164"
  },
  {
    "country": "CA",
    "name": "Scarborough",
    "lat": "43.77223",
    "lng": "-79.25666"
  },
  {
    "country": "CA",
    "name": "Les Escoumins",
    "lat": "48.35191",
    "lng": "-69.40724"
  },
  {
    "country": "CA",
    "name": "Fossambault-sur-lac",
    "lat": "46.87662",
    "lng": "-71.61541"
  },
  {
    "country": "CA",
    "name": "Cole Harbour",
    "lat": "44.67244",
    "lng": "-63.47506"
  },
  {
    "country": "CA",
    "name": "Okanagan",
    "lat": "50.36386",
    "lng": "-119.34997"
  },
  {
    "country": "CA",
    "name": "West Kelowna",
    "lat": "49.8625",
    "lng": "-119.58333"
  },
  {
    "country": "CA",
    "name": "Tracadie-Sheila",
    "lat": "47.51444",
    "lng": "-64.91806"
  },
  {
    "country": "CA",
    "name": "Sydney Mines",
    "lat": "46.23669",
    "lng": "-60.21767"
  },
  {
    "country": "CA",
    "name": "Jonquière",
    "lat": "48.41648",
    "lng": "-71.24884"
  },
  {
    "country": "CA",
    "name": "Cap-Santé",
    "lat": "46.67159",
    "lng": "-71.78812"
  },
  {
    "country": "CA",
    "name": "Saint-Augustin-de-Desmaures",
    "lat": "46.74064",
    "lng": "-71.45131"
  },
  {
    "country": "CA",
    "name": "Donnacona",
    "lat": "46.68042",
    "lng": "-71.7239"
  },
  {
    "country": "CA",
    "name": "La Pocatière",
    "lat": "47.36733",
    "lng": "-70.03484"
  },
  {
    "country": "CA",
    "name": "Saint-Joseph-de-Beauce",
    "lat": "46.3",
    "lng": "-70.86667"
  },
  {
    "country": "CA",
    "name": "Metabetchouan-Lac-a-la-Croix",
    "lat": "48.41",
    "lng": "-71.78"
  },
  {
    "country": "CA",
    "name": "Ladner",
    "lat": "49.08938",
    "lng": "-123.08241"
  },
  {
    "country": "CA",
    "name": "Walnut Grove",
    "lat": "49.16473",
    "lng": "-122.64042"
  },
  {
    "country": "CA",
    "name": "Aldergrove",
    "lat": "49.05801",
    "lng": "-122.47087"
  },
  {
    "country": "CA",
    "name": "Saint-Léonard",
    "lat": "47.16317",
    "lng": "-67.9246"
  },
  {
    "country": "CA",
    "name": "Harrison Brook",
    "lat": "47.21304",
    "lng": "-67.92847"
  },
  {
    "country": "CA",
    "name": "Omemee",
    "lat": "44.29897",
    "lng": "-78.55989"
  },
  {
    "country": "CA",
    "name": "East York",
    "lat": "43.69053",
    "lng": "-79.32794"
  },
  {
    "country": "CA",
    "name": "Napanee Downtown",
    "lat": "44.24832",
    "lng": "-76.95069"
  },
  {
    "country": "CA",
    "name": "Skatepark",
    "lat": "44.25122",
    "lng": "-76.94424"
  },
  {
    "country": "CA",
    "name": "Breakeyville",
    "lat": "46.68037",
    "lng": "-71.22327"
  },
  {
    "country": "CA",
    "name": "Saint-Antoine-de-Tilly",
    "lat": "46.66346",
    "lng": "-71.57335"
  },
  {
    "country": "CA",
    "name": "Ancaster",
    "lat": "43.21806",
    "lng": "-79.98716"
  },
  {
    "country": "CA",
    "name": "Shannon",
    "lat": "46.88026",
    "lng": "-71.51464"
  },
  {
    "country": "CA",
    "name": "Saint-Henri",
    "lat": "46.69314",
    "lng": "-71.06927"
  },
  {
    "country": "CA",
    "name": "Pohénégamook",
    "lat": "47.46315",
    "lng": "-69.22666"
  },
  {
    "country": "CA",
    "name": "Pont-Rouge",
    "lat": "46.75468",
    "lng": "-71.69566"
  },
  {
    "country": "CA",
    "name": "Princeville",
    "lat": "46.17163",
    "lng": "-71.87462"
  },
  {
    "country": "CA",
    "name": "West Vancouver",
    "lat": "49.36672",
    "lng": "-123.16652"
  },
  {
    "country": "CA",
    "name": "Saint-Siméon",
    "lat": "47.84431",
    "lng": "-69.87837"
  },
  {
    "country": "CA",
    "name": "Willowdale",
    "lat": "43.76672",
    "lng": "-79.39909"
  },
  {
    "country": "CA",
    "name": "Florenceville-Bristol",
    "lat": "46.44353",
    "lng": "-67.61536"
  },
  {
    "country": "CA",
    "name": "Saint-Pascal",
    "lat": "47.51813",
    "lng": "-69.80301"
  },
  {
    "country": "CA",
    "name": "Vallée-Jonction",
    "lat": "46.37441",
    "lng": "-70.91881"
  },
  {
    "country": "CA",
    "name": "Saint-Antonin",
    "lat": "47.7607",
    "lng": "-69.47745"
  },
  {
    "country": "CA",
    "name": "Lower Sackville",
    "lat": "44.77599",
    "lng": "-63.67865"
  },
  {
    "country": "CA",
    "name": "le Plateau",
    "lat": "45.43514",
    "lng": "-75.7803"
  },
  {
    "country": "CA",
    "name": "Wild Rose",
    "lat": "53.4708",
    "lng": "-113.38119"
  },
  {
    "country": "CA",
    "name": "Silver Berry",
    "lat": "53.45787",
    "lng": "-113.3817"
  },
  {
    "country": "CA",
    "name": "Laurel",
    "lat": "53.44667",
    "lng": "-113.38197"
  },
  {
    "country": "CA",
    "name": "Tamarack",
    "lat": "53.46441",
    "lng": "-113.36235"
  },
  {
    "country": "CA",
    "name": "Larkspur",
    "lat": "53.47942",
    "lng": "-113.38142"
  },
  {
    "country": "CA",
    "name": "Hérouxville",
    "lat": "46.66617",
    "lng": "-72.62512"
  },
  {
    "country": "CA",
    "name": "Saint-Norbert",
    "lat": "46.16949",
    "lng": "-73.31494"
  },
  {
    "country": "CA",
    "name": "Sainte-Élisabeth",
    "lat": "46.09502",
    "lng": "-73.35176"
  },
  {
    "country": "CA",
    "name": "Shippagan",
    "lat": "47.74424",
    "lng": "-64.70804"
  },
  {
    "country": "CA",
    "name": "Fogo Island",
    "lat": "49.71649",
    "lng": "-54.16981"
  },
  {
    "country": "CA",
    "name": "Behchoko",
    "lat": "62.8025",
    "lng": "-116.04639"
  },
  {
    "country": "CA",
    "name": "Wendover",
    "lat": "45.57275",
    "lng": "-75.12757"
  },
  {
    "country": "CA",
    "name": "La Haute-Saint-Charles",
    "lat": "46.89028",
    "lng": "-71.37222"
  },
  {
    "country": "CC",
    "name": "West Island",
    "lat": "-12.15681",
    "lng": "96.82251"
  },
  {
    "country": "CD",
    "name": "Yangambi",
    "lat": "0.76755",
    "lng": "24.43973"
  },
  {
    "country": "CD",
    "name": "Watsa",
    "lat": "3.03716",
    "lng": "29.53551"
  },
  {
    "country": "CD",
    "name": "Wamba",
    "lat": "2.14838",
    "lng": "27.99466"
  },
  {
    "country": "CD",
    "name": "Uvira",
    "lat": "-3.39534",
    "lng": "29.13779"
  },
  {
    "country": "CD",
    "name": "Tshikapa",
    "lat": "-6.41621",
    "lng": "20.79995"
  },
  {
    "country": "CD",
    "name": "Sake",
    "lat": "-1.57386",
    "lng": "29.04339"
  },
  {
    "country": "CD",
    "name": "Mwene-Ditu",
    "lat": "-7.00906",
    "lng": "23.45278"
  },
  {
    "country": "CD",
    "name": "Mweka",
    "lat": "-4.85187",
    "lng": "21.5595"
  },
  {
    "country": "CD",
    "name": "Mbuji-Mayi",
    "lat": "-6.13603",
    "lng": "23.58979"
  },
  {
    "country": "CD",
    "name": "Lusambo",
    "lat": "-4.97503",
    "lng": "23.44391"
  },
  {
    "country": "CD",
    "name": "Luebo",
    "lat": "-5.35218",
    "lng": "21.42192"
  },
  {
    "country": "CD",
    "name": "Lubao",
    "lat": "-5.38771",
    "lng": "25.74885"
  },
  {
    "country": "CD",
    "name": "Lodja",
    "lat": "-3.52105",
    "lng": "23.6005"
  },
  {
    "country": "CD",
    "name": "Lisala",
    "lat": "2.15127",
    "lng": "21.51672"
  },
  {
    "country": "CD",
    "name": "Kongolo",
    "lat": "-5.38532",
    "lng": "27.00029"
  },
  {
    "country": "CD",
    "name": "Kisangani",
    "lat": "0.51528",
    "lng": "25.19099"
  },
  {
    "country": "CD",
    "name": "Kindu",
    "lat": "-2.94373",
    "lng": "25.92237"
  },
  {
    "country": "CD",
    "name": "Kasongo",
    "lat": "-4.42741",
    "lng": "26.66656"
  },
  {
    "country": "CD",
    "name": "Kananga",
    "lat": "-5.89624",
    "lng": "22.41659"
  },
  {
    "country": "CD",
    "name": "Kampene",
    "lat": "-3.59678",
    "lng": "26.66715"
  },
  {
    "country": "CD",
    "name": "Kamina",
    "lat": "-8.73508",
    "lng": "24.99798"
  },
  {
    "country": "CD",
    "name": "Kalemie",
    "lat": "-5.94749",
    "lng": "29.19471"
  },
  {
    "country": "CD",
    "name": "Kabinda",
    "lat": "-6.13791",
    "lng": "24.48179"
  },
  {
    "country": "CD",
    "name": "Kabare",
    "lat": "-2.49682",
    "lng": "28.79081"
  },
  {
    "country": "CD",
    "name": "Kabalo",
    "lat": "-6.05255",
    "lng": "26.9143"
  },
  {
    "country": "CD",
    "name": "Isiro",
    "lat": "2.77391",
    "lng": "27.61603"
  },
  {
    "country": "CD",
    "name": "Ilebo",
    "lat": "-4.33111",
    "lng": "20.58638"
  },
  {
    "country": "CD",
    "name": "Goma",
    "lat": "-1.67409",
    "lng": "29.22845"
  },
  {
    "country": "CD",
    "name": "Gbadolite",
    "lat": "4.279",
    "lng": "21.00284"
  },
  {
    "country": "CD",
    "name": "Gandajika",
    "lat": "-6.74504",
    "lng": "23.95328"
  },
  {
    "country": "CD",
    "name": "Demba",
    "lat": "-5.49573",
    "lng": "22.26962"
  },
  {
    "country": "CD",
    "name": "Butembo",
    "lat": "0.14164",
    "lng": "29.29117"
  },
  {
    "country": "CD",
    "name": "Buta",
    "lat": "2.78582",
    "lng": "24.72997"
  },
  {
    "country": "CD",
    "name": "Businga",
    "lat": "3.33863",
    "lng": "20.88577"
  },
  {
    "country": "CD",
    "name": "Bunia",
    "lat": "1.55941",
    "lng": "30.25224"
  },
  {
    "country": "CD",
    "name": "Bumba",
    "lat": "2.18771",
    "lng": "22.46827"
  },
  {
    "country": "CD",
    "name": "Bukavu",
    "lat": "-2.49077",
    "lng": "28.84281"
  },
  {
    "country": "CD",
    "name": "Bukama",
    "lat": "-9.20443",
    "lng": "25.85475"
  },
  {
    "country": "CD",
    "name": "Bongandanga",
    "lat": "1.50695",
    "lng": "21.0726"
  },
  {
    "country": "CD",
    "name": "Bondo",
    "lat": "3.81461",
    "lng": "23.68665"
  },
  {
    "country": "CD",
    "name": "Boende",
    "lat": "-0.28163",
    "lng": "20.88053"
  },
  {
    "country": "CD",
    "name": "Beni",
    "lat": "0.49113",
    "lng": "29.47306"
  },
  {
    "country": "CD",
    "name": "Basoko",
    "lat": "1.23909",
    "lng": "23.61598"
  },
  {
    "country": "CD",
    "name": "Aketi",
    "lat": "2.73877",
    "lng": "23.78326"
  },
  {
    "country": "CD",
    "name": "Lubumbashi",
    "lat": "-11.66089",
    "lng": "27.47938"
  },
  {
    "country": "CD",
    "name": "Likasi",
    "lat": "-10.98303",
    "lng": "26.7384"
  },
  {
    "country": "CD",
    "name": "Kolwezi",
    "lat": "-10.71484",
    "lng": "25.46674"
  },
  {
    "country": "CD",
    "name": "Kipushi",
    "lat": "-11.76097",
    "lng": "27.25135"
  },
  {
    "country": "CD",
    "name": "Kambove",
    "lat": "-10.87352",
    "lng": "26.59746"
  },
  {
    "country": "CD",
    "name": "Tshela",
    "lat": "-4.99707",
    "lng": "12.9484"
  },
  {
    "country": "CD",
    "name": "Nioki",
    "lat": "-2.72037",
    "lng": "17.69001"
  },
  {
    "country": "CD",
    "name": "Mushie",
    "lat": "-3.01728",
    "lng": "16.92238"
  },
  {
    "country": "CD",
    "name": "Moanda",
    "lat": "-5.92753",
    "lng": "12.37148"
  },
  {
    "country": "CD",
    "name": "Mbanza-Ngungu",
    "lat": "-5.25837",
    "lng": "14.85838"
  },
  {
    "country": "CD",
    "name": "Mbandaka",
    "lat": "0.04865",
    "lng": "18.26034"
  },
  {
    "country": "CD",
    "name": "Matadi",
    "lat": "-5.83861",
    "lng": "13.46306"
  },
  {
    "country": "CD",
    "name": "Mangai",
    "lat": "-4.02328",
    "lng": "19.53385"
  },
  {
    "country": "CD",
    "name": "Lukolela",
    "lat": "-1.06046",
    "lng": "17.1821"
  },
  {
    "country": "CD",
    "name": "Libenge",
    "lat": "3.65332",
    "lng": "18.63566"
  },
  {
    "country": "CD",
    "name": "Kinshasa",
    "lat": "-4.32758",
    "lng": "15.31357"
  },
  {
    "country": "CD",
    "name": "Kikwit",
    "lat": "-5.04098",
    "lng": "18.81619"
  },
  {
    "country": "CD",
    "name": "Kasongo-Lunda",
    "lat": "-6.47833",
    "lng": "16.81735"
  },
  {
    "country": "CD",
    "name": "Kasangulu",
    "lat": "-4.5833",
    "lng": "15.16554"
  },
  {
    "country": "CD",
    "name": "Inongo",
    "lat": "-1.9275",
    "lng": "18.2881"
  },
  {
    "country": "CD",
    "name": "Gemena",
    "lat": "3.25651",
    "lng": "19.77234"
  },
  {
    "country": "CD",
    "name": "Bulungu",
    "lat": "-4.54437",
    "lng": "18.60364"
  },
  {
    "country": "CD",
    "name": "Bosobolo",
    "lat": "4.1898",
    "lng": "19.8833"
  },
  {
    "country": "CD",
    "name": "Boma",
    "lat": "-5.85098",
    "lng": "13.05364"
  },
  {
    "country": "CD",
    "name": "Bolobo",
    "lat": "-2.158",
    "lng": "16.23249"
  },
  {
    "country": "CD",
    "name": "Bandundu",
    "lat": "-3.31687",
    "lng": "17.38063"
  },
  {
    "country": "CD",
    "name": "Masina",
    "lat": "-4.38361",
    "lng": "15.39139"
  },
  {
    "country": "CF",
    "name": "Zemio",
    "lat": "5.03144",
    "lng": "25.13614"
  },
  {
    "country": "CF",
    "name": "Ouango",
    "lat": "4.31325",
    "lng": "22.55524"
  },
  {
    "country": "CF",
    "name": "Ouadda",
    "lat": "8.07771",
    "lng": "22.40075"
  },
  {
    "country": "CF",
    "name": "Obo",
    "lat": "5.39586",
    "lng": "26.49211"
  },
  {
    "country": "CF",
    "name": "Ndélé",
    "lat": "8.41091",
    "lng": "20.64728"
  },
  {
    "country": "CF",
    "name": "Mobaye",
    "lat": "4.31902",
    "lng": "21.17861"
  },
  {
    "country": "CF",
    "name": "Kembé",
    "lat": "4.62275",
    "lng": "21.88645"
  },
  {
    "country": "CF",
    "name": "Ippy",
    "lat": "6.26793",
    "lng": "21.22468"
  },
  {
    "country": "CF",
    "name": "Gambo",
    "lat": "4.64816",
    "lng": "22.26331"
  },
  {
    "country": "CF",
    "name": "Bria",
    "lat": "6.54233",
    "lng": "21.98633"
  },
  {
    "country": "CF",
    "name": "Birao",
    "lat": "10.28488",
    "lng": "22.78818"
  },
  {
    "country": "CF",
    "name": "Bangassou",
    "lat": "4.83895",
    "lng": "23.11739"
  },
  {
    "country": "CF",
    "name": "Bangassou",
    "lat": "4.74132",
    "lng": "22.81838"
  },
  {
    "country": "CF",
    "name": "Bambari",
    "lat": "5.76795",
    "lng": "20.67565"
  },
  {
    "country": "CF",
    "name": "Alindao",
    "lat": "5.02667",
    "lng": "21.20876"
  },
  {
    "country": "CF",
    "name": "Sibut",
    "lat": "5.71801",
    "lng": "19.07389"
  },
  {
    "country": "CF",
    "name": "Paoua",
    "lat": "7.24269",
    "lng": "16.44059"
  },
  {
    "country": "CF",
    "name": "Nola",
    "lat": "3.52494",
    "lng": "16.04583"
  },
  {
    "country": "CF",
    "name": "Mongoumba",
    "lat": "3.64153",
    "lng": "18.59364"
  },
  {
    "country": "CF",
    "name": "Mbaïki",
    "lat": "3.86781",
    "lng": "17.98923"
  },
  {
    "country": "CF",
    "name": "Kouango",
    "lat": "4.99337",
    "lng": "19.96186"
  },
  {
    "country": "CF",
    "name": "Kaga Bandoro",
    "lat": "6.98961",
    "lng": "19.18744"
  },
  {
    "country": "CF",
    "name": "Kabo",
    "lat": "7.69937",
    "lng": "18.62903"
  },
  {
    "country": "CF",
    "name": "Gamboula",
    "lat": "4.11775",
    "lng": "15.13926"
  },
  {
    "country": "CF",
    "name": "Damara",
    "lat": "4.96075",
    "lng": "18.7035"
  },
  {
    "country": "CF",
    "name": "Carnot",
    "lat": "4.94273",
    "lng": "15.87735"
  },
  {
    "country": "CF",
    "name": "Bozoum",
    "lat": "6.31933",
    "lng": "16.37992"
  },
  {
    "country": "CF",
    "name": "Bouca",
    "lat": "6.50734",
    "lng": "18.2767"
  },
  {
    "country": "CF",
    "name": "Bouar",
    "lat": "5.93404",
    "lng": "15.59599"
  },
  {
    "country": "CF",
    "name": "Bossangoa",
    "lat": "6.49263",
    "lng": "17.45518"
  },
  {
    "country": "CF",
    "name": "Boda",
    "lat": "4.31887",
    "lng": "17.46953"
  },
  {
    "country": "CF",
    "name": "Boali",
    "lat": "4.80048",
    "lng": "18.12747"
  },
  {
    "country": "CF",
    "name": "Bimbo",
    "lat": "4.25671",
    "lng": "18.41583"
  },
  {
    "country": "CF",
    "name": "Berbérati",
    "lat": "4.26116",
    "lng": "15.79216"
  },
  {
    "country": "CF",
    "name": "Batangafo",
    "lat": "7.30082",
    "lng": "18.2833"
  },
  {
    "country": "CF",
    "name": "Baoro",
    "lat": "5.66667",
    "lng": "15.96667"
  },
  {
    "country": "CF",
    "name": "Bangui",
    "lat": "4.36122",
    "lng": "18.55496"
  },
  {
    "country": "CG",
    "name": "Sibiti",
    "lat": "-3.68192",
    "lng": "13.34985"
  },
  {
    "country": "CG",
    "name": "Sémbé",
    "lat": "1.64806",
    "lng": "14.58056"
  },
  {
    "country": "CG",
    "name": "Pointe-Noire",
    "lat": "-4.77609",
    "lng": "11.86352"
  },
  {
    "country": "CG",
    "name": "Owando",
    "lat": "-0.48193",
    "lng": "15.89988"
  },
  {
    "country": "CG",
    "name": "Ouésso",
    "lat": "1.61361",
    "lng": "16.05167"
  },
  {
    "country": "CG",
    "name": "Mossendjo",
    "lat": "-2.94968",
    "lng": "12.70423"
  },
  {
    "country": "CG",
    "name": "Makoua",
    "lat": "0.00694",
    "lng": "15.63333"
  },
  {
    "country": "CG",
    "name": "Madingou",
    "lat": "-4.15361",
    "lng": "13.55"
  },
  {
    "country": "CG",
    "name": "Dolisie",
    "lat": "-4.19834",
    "lng": "12.66664"
  },
  {
    "country": "CG",
    "name": "Loango",
    "lat": "-4.65194",
    "lng": "11.8125"
  },
  {
    "country": "CG",
    "name": "Loandjili",
    "lat": "-4.75611",
    "lng": "11.85778"
  },
  {
    "country": "CG",
    "name": "Kinkala",
    "lat": "-4.36139",
    "lng": "14.76444"
  },
  {
    "country": "CG",
    "name": "Kayes",
    "lat": "-4.20493",
    "lng": "13.28608"
  },
  {
    "country": "CG",
    "name": "Impfondo",
    "lat": "1.61804",
    "lng": "18.05981"
  },
  {
    "country": "CG",
    "name": "Gamboma",
    "lat": "-1.87639",
    "lng": "15.86444"
  },
  {
    "country": "CG",
    "name": "Ewo",
    "lat": "-0.8725",
    "lng": "14.82056"
  },
  {
    "country": "CG",
    "name": "Djambala",
    "lat": "-2.54472",
    "lng": "14.75333"
  },
  {
    "country": "CG",
    "name": "Brazzaville",
    "lat": "-4.26613",
    "lng": "15.28318"
  },
  {
    "country": "CG",
    "name": "Nkayi",
    "lat": "-4.18396",
    "lng": "13.2859"
  },
  {
    "country": "CH",
    "name": "Zwingen",
    "lat": "47.43825",
    "lng": "7.53027"
  },
  {
    "country": "CH",
    "name": "Zweisimmen",
    "lat": "46.55539",
    "lng": "7.37302"
  },
  {
    "country": "CH",
    "name": "Zuzwil",
    "lat": "47.47452",
    "lng": "9.11196"
  },
  {
    "country": "CH",
    "name": "Bad Zurzach",
    "lat": "47.58764",
    "lng": "8.29365"
  },
  {
    "country": "CH",
    "name": "Zürich",
    "lat": "47.36667",
    "lng": "8.55"
  },
  {
    "country": "CH",
    "name": "Zuoz",
    "lat": "46.60206",
    "lng": "9.95965"
  },
  {
    "country": "CH",
    "name": "Zunzgen",
    "lat": "47.44925",
    "lng": "7.80789"
  },
  {
    "country": "CH",
    "name": "Zumikon",
    "lat": "47.33158",
    "lng": "8.62271"
  },
  {
    "country": "CH",
    "name": "Zug",
    "lat": "47.17242",
    "lng": "8.51745"
  },
  {
    "country": "CH",
    "name": "Zuchwil",
    "lat": "47.20173",
    "lng": "7.56649"
  },
  {
    "country": "CH",
    "name": "Zollikon",
    "lat": "47.34019",
    "lng": "8.57407"
  },
  {
    "country": "CH",
    "name": "Zollikofen",
    "lat": "46.99905",
    "lng": "7.45809"
  },
  {
    "country": "CH",
    "name": "Zofingen",
    "lat": "47.28779",
    "lng": "7.94586"
  },
  {
    "country": "CH",
    "name": "Zizers",
    "lat": "46.93575",
    "lng": "9.56491"
  },
  {
    "country": "CH",
    "name": "Zernez",
    "lat": "46.69862",
    "lng": "10.09268"
  },
  {
    "country": "CH",
    "name": "Zermatt",
    "lat": "46.01998",
    "lng": "7.74863"
  },
  {
    "country": "CH",
    "name": "Zell",
    "lat": "47.13673",
    "lng": "7.92495"
  },
  {
    "country": "CH",
    "name": "Zäziwil",
    "lat": "46.90196",
    "lng": "7.66185"
  },
  {
    "country": "CH",
    "name": "Yvonand",
    "lat": "46.80034",
    "lng": "6.74249"
  },
  {
    "country": "CH",
    "name": "Yverdon-les-Bains",
    "lat": "46.77852",
    "lng": "6.64115"
  },
  {
    "country": "CH",
    "name": "Wyssachen",
    "lat": "47.07851",
    "lng": "7.82922"
  },
  {
    "country": "CH",
    "name": "Wynigen",
    "lat": "47.10586",
    "lng": "7.66681"
  },
  {
    "country": "CH",
    "name": "Wynau",
    "lat": "47.2557",
    "lng": "7.81626"
  },
  {
    "country": "CH",
    "name": "Würenlos",
    "lat": "47.44205",
    "lng": "8.36261"
  },
  {
    "country": "CH",
    "name": "Würenlingen",
    "lat": "47.53356",
    "lng": "8.25666"
  },
  {
    "country": "CH",
    "name": "Worben",
    "lat": "47.10279",
    "lng": "7.29518"
  },
  {
    "country": "CH",
    "name": "Worb",
    "lat": "46.92984",
    "lng": "7.56306"
  },
  {
    "country": "CH",
    "name": "Wollerau",
    "lat": "47.19478",
    "lng": "8.71903"
  },
  {
    "country": "CH",
    "name": "Wolhusen",
    "lat": "47.05983",
    "lng": "8.07389"
  },
  {
    "country": "CH",
    "name": "Wolfwil",
    "lat": "47.26871",
    "lng": "7.79652"
  },
  {
    "country": "CH",
    "name": "Wölflinswil",
    "lat": "47.4607",
    "lng": "7.99835"
  },
  {
    "country": "CH",
    "name": "Wolfenschiessen",
    "lat": "46.90322",
    "lng": "8.39423"
  },
  {
    "country": "CH",
    "name": "Wohlen",
    "lat": "47.35066",
    "lng": "8.27517"
  },
  {
    "country": "CH",
    "name": "Wohlen",
    "lat": "46.97118",
    "lng": "7.35685"
  },
  {
    "country": "CH",
    "name": "Wittnau",
    "lat": "47.48139",
    "lng": "7.97577"
  },
  {
    "country": "CH",
    "name": "Wittenbach",
    "lat": "47.46108",
    "lng": "9.38601"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 7) / Witikon",
    "lat": "47.35751",
    "lng": "8.59105"
  },
  {
    "country": "CH",
    "name": "Winterthur",
    "lat": "47.50564",
    "lng": "8.72413"
  },
  {
    "country": "CH",
    "name": "Windisch",
    "lat": "47.47899",
    "lng": "8.21842"
  },
  {
    "country": "CH",
    "name": "Wimmis",
    "lat": "46.67587",
    "lng": "7.63972"
  },
  {
    "country": "CH",
    "name": "Willisau",
    "lat": "47.12183",
    "lng": "7.99418"
  },
  {
    "country": "CH",
    "name": "Wildhaus",
    "lat": "47.20583",
    "lng": "9.35402"
  },
  {
    "country": "CH",
    "name": "Wilderswil",
    "lat": "46.66369",
    "lng": "7.86175"
  },
  {
    "country": "CH",
    "name": "Wilchingen",
    "lat": "47.66745",
    "lng": "8.46774"
  },
  {
    "country": "CH",
    "name": "Wila",
    "lat": "47.41928",
    "lng": "8.84524"
  },
  {
    "country": "CH",
    "name": "Wil",
    "lat": "47.46152",
    "lng": "9.04552"
  },
  {
    "country": "CH",
    "name": "Wikon",
    "lat": "47.26339",
    "lng": "7.96801"
  },
  {
    "country": "CH",
    "name": "Wigoltingen",
    "lat": "47.5977",
    "lng": "9.03141"
  },
  {
    "country": "CH",
    "name": "Wiesendangen / Wiesendangen (Dorf)",
    "lat": "47.5217",
    "lng": "8.78967"
  },
  {
    "country": "CH",
    "name": "Wiedlisbach",
    "lat": "47.25194",
    "lng": "7.6461"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 3) / Alt-Wiedikon",
    "lat": "47.36201",
    "lng": "8.51497"
  },
  {
    "country": "CH",
    "name": "Wetzikon",
    "lat": "47.3264",
    "lng": "8.79779"
  },
  {
    "country": "CH",
    "name": "Wettingen",
    "lat": "47.47049",
    "lng": "8.31636"
  },
  {
    "country": "CH",
    "name": "Werthenstein",
    "lat": "47.05578",
    "lng": "8.10182"
  },
  {
    "country": "CH",
    "name": "Welschenrohr",
    "lat": "47.28052",
    "lng": "7.52664"
  },
  {
    "country": "CH",
    "name": "Weisslingen",
    "lat": "47.43063",
    "lng": "8.76787"
  },
  {
    "country": "CH",
    "name": "Weiningen",
    "lat": "47.42022",
    "lng": "8.43644"
  },
  {
    "country": "CH",
    "name": "Weinfelden",
    "lat": "47.56667",
    "lng": "9.1"
  },
  {
    "country": "CH",
    "name": "Weggis",
    "lat": "47.03208",
    "lng": "8.43219"
  },
  {
    "country": "CH",
    "name": "Wegenstetten",
    "lat": "47.49797",
    "lng": "7.93141"
  },
  {
    "country": "CH",
    "name": "Weesen",
    "lat": "47.13447",
    "lng": "9.09644"
  },
  {
    "country": "CH",
    "name": "Wauwil",
    "lat": "47.18457",
    "lng": "8.021"
  },
  {
    "country": "CH",
    "name": "Wattwil",
    "lat": "47.29955",
    "lng": "9.08657"
  },
  {
    "country": "CH",
    "name": "Wattenwil",
    "lat": "46.76973",
    "lng": "7.50835"
  },
  {
    "country": "CH",
    "name": "Wängi",
    "lat": "47.49654",
    "lng": "8.95325"
  },
  {
    "country": "CH",
    "name": "Wangen an der Aare",
    "lat": "47.23208",
    "lng": "7.65253"
  },
  {
    "country": "CH",
    "name": "Wangen",
    "lat": "47.34365",
    "lng": "7.86982"
  },
  {
    "country": "CH",
    "name": "Walzenhausen",
    "lat": "47.44867",
    "lng": "9.60495"
  },
  {
    "country": "CH",
    "name": "Waltenschwil",
    "lat": "47.33339",
    "lng": "8.29791"
  },
  {
    "country": "CH",
    "name": "Wallisellen",
    "lat": "47.41499",
    "lng": "8.59672"
  },
  {
    "country": "CH",
    "name": "Walenstadt",
    "lat": "47.12411",
    "lng": "9.31194"
  },
  {
    "country": "CH",
    "name": "Walkringen",
    "lat": "46.94856",
    "lng": "7.6204"
  },
  {
    "country": "CH",
    "name": "Waldstatt",
    "lat": "47.35627",
    "lng": "9.28345"
  },
  {
    "country": "CH",
    "name": "Waldkirch",
    "lat": "47.46859",
    "lng": "9.28665"
  },
  {
    "country": "CH",
    "name": "Waldenburg",
    "lat": "47.38333",
    "lng": "7.75"
  },
  {
    "country": "CH",
    "name": "Wald",
    "lat": "47.27595",
    "lng": "8.91405"
  },
  {
    "country": "CH",
    "name": "Walchwil",
    "lat": "47.10169",
    "lng": "8.51693"
  },
  {
    "country": "CH",
    "name": "Wahlen",
    "lat": "47.40226",
    "lng": "7.51511"
  },
  {
    "country": "CH",
    "name": "Wagenhausen",
    "lat": "47.66003",
    "lng": "8.84782"
  },
  {
    "country": "CH",
    "name": "Wädenswil",
    "lat": "47.22683",
    "lng": "8.6687"
  },
  {
    "country": "CH",
    "name": "Vuadens",
    "lat": "46.61545",
    "lng": "7.01732"
  },
  {
    "country": "CH",
    "name": "Vouvry",
    "lat": "46.33746",
    "lng": "6.8895"
  },
  {
    "country": "CH",
    "name": "Vorderthal",
    "lat": "47.12172",
    "lng": "8.90225"
  },
  {
    "country": "CH",
    "name": "Vordemwald",
    "lat": "47.27585",
    "lng": "7.90114"
  },
  {
    "country": "CH",
    "name": "Volketswil / Volketswil (Dorf)",
    "lat": "47.39016",
    "lng": "8.69085"
  },
  {
    "country": "CH",
    "name": "Vitznau",
    "lat": "47.01014",
    "lng": "8.4842"
  },
  {
    "country": "CH",
    "name": "Visperterminen",
    "lat": "46.25899",
    "lng": "7.90192"
  },
  {
    "country": "CH",
    "name": "Visp",
    "lat": "46.2937",
    "lng": "7.88149"
  },
  {
    "country": "CH",
    "name": "Vionnaz",
    "lat": "46.31101",
    "lng": "6.90062"
  },
  {
    "country": "CH",
    "name": "Villnachern",
    "lat": "47.47098",
    "lng": "8.15975"
  },
  {
    "country": "CH",
    "name": "Villmergen",
    "lat": "47.35009",
    "lng": "8.24762"
  },
  {
    "country": "CH",
    "name": "Villigen",
    "lat": "47.52682",
    "lng": "8.21486"
  },
  {
    "country": "CH",
    "name": "Villeneuve",
    "lat": "46.39869",
    "lng": "6.92654"
  },
  {
    "country": "CH",
    "name": "Villaz-Saint-Pierre",
    "lat": "46.72074",
    "lng": "6.95638"
  },
  {
    "country": "CH",
    "name": "Villars-sur-Ollon",
    "lat": "46.29832",
    "lng": "7.05631"
  },
  {
    "country": "CH",
    "name": "Villars-sur-Glâne",
    "lat": "46.79054",
    "lng": "7.11717"
  },
  {
    "country": "CH",
    "name": "Viganello",
    "lat": "46.01342",
    "lng": "8.96879"
  },
  {
    "country": "CH",
    "name": "Vicques",
    "lat": "47.35",
    "lng": "7.41342"
  },
  {
    "country": "CH",
    "name": "Veyrier",
    "lat": "46.16699",
    "lng": "6.18436"
  },
  {
    "country": "CH",
    "name": "Vex",
    "lat": "46.21239",
    "lng": "7.39826"
  },
  {
    "country": "CH",
    "name": "Vevey",
    "lat": "46.46299",
    "lng": "6.84345"
  },
  {
    "country": "CH",
    "name": "Vétroz",
    "lat": "46.22171",
    "lng": "7.27858"
  },
  {
    "country": "CH",
    "name": "Versoix",
    "lat": "46.28382",
    "lng": "6.16214"
  },
  {
    "country": "CH",
    "name": "Verscio",
    "lat": "46.18482",
    "lng": "8.73224"
  },
  {
    "country": "CH",
    "name": "Vernier",
    "lat": "46.21702",
    "lng": "6.08497"
  },
  {
    "country": "CH",
    "name": "Vernayaz",
    "lat": "46.13667",
    "lng": "7.03906"
  },
  {
    "country": "CH",
    "name": "Verbier",
    "lat": "46.1002",
    "lng": "7.22651"
  },
  {
    "country": "CH",
    "name": "Veltheim (Kreis 5)",
    "lat": "47.51419",
    "lng": "8.717"
  },
  {
    "country": "CH",
    "name": "Veltheim",
    "lat": "47.43796",
    "lng": "8.14722"
  },
  {
    "country": "CH",
    "name": "Vechigen",
    "lat": "46.94616",
    "lng": "7.56065"
  },
  {
    "country": "CH",
    "name": "Varen",
    "lat": "46.3186",
    "lng": "7.60743"
  },
  {
    "country": "CH",
    "name": "Vandœuvres",
    "lat": "46.22179",
    "lng": "6.20285"
  },
  {
    "country": "CH",
    "name": "Vals Platz",
    "lat": "46.61647",
    "lng": "9.18025"
  },
  {
    "country": "CH",
    "name": "Vallorbe",
    "lat": "46.71256",
    "lng": "6.37894"
  },
  {
    "country": "CH",
    "name": "Uzwil",
    "lat": "47.43653",
    "lng": "9.13422"
  },
  {
    "country": "CH",
    "name": "Uznach",
    "lat": "47.22421",
    "lng": "8.98263"
  },
  {
    "country": "CH",
    "name": "Utzenstorf",
    "lat": "47.13248",
    "lng": "7.55355"
  },
  {
    "country": "CH",
    "name": "Uttwil",
    "lat": "47.5844",
    "lng": "9.34101"
  },
  {
    "country": "CH",
    "name": "Uttigen",
    "lat": "46.79435",
    "lng": "7.57789"
  },
  {
    "country": "CH",
    "name": "Uster",
    "lat": "47.34713",
    "lng": "8.72091"
  },
  {
    "country": "CH",
    "name": "Urtenen",
    "lat": "47.02667",
    "lng": "7.50081"
  },
  {
    "country": "CH",
    "name": "Urnäsch",
    "lat": "47.31669",
    "lng": "9.2795"
  },
  {
    "country": "CH",
    "name": "Wetzikon / Unter-Wetzikon",
    "lat": "47.31637",
    "lng": "8.79369"
  },
  {
    "country": "CH",
    "name": "Untervaz",
    "lat": "46.9275",
    "lng": "9.53422"
  },
  {
    "country": "CH",
    "name": "Untersiggenthal",
    "lat": "47.50213",
    "lng": "8.25554"
  },
  {
    "country": "CH",
    "name": "Unterseen",
    "lat": "46.6853",
    "lng": "7.84722"
  },
  {
    "country": "CH",
    "name": "Unterlunkhofen",
    "lat": "47.3212",
    "lng": "8.38102"
  },
  {
    "country": "CH",
    "name": "Unterkulm",
    "lat": "47.30998",
    "lng": "8.11371"
  },
  {
    "country": "CH",
    "name": "Illnau / Unter-Illnau",
    "lat": "47.40787",
    "lng": "8.72607"
  },
  {
    "country": "CH",
    "name": "Unteriberg",
    "lat": "47.06258",
    "lng": "8.8052"
  },
  {
    "country": "CH",
    "name": "Unterengstringen",
    "lat": "47.41396",
    "lng": "8.44761"
  },
  {
    "country": "CH",
    "name": "Ehrendingen",
    "lat": "47.5025",
    "lng": "8.34729"
  },
  {
    "country": "CH",
    "name": "Unterägeri",
    "lat": "47.13645",
    "lng": "8.5853"
  },
  {
    "country": "CH",
    "name": "Uitikon",
    "lat": "47.36911",
    "lng": "8.45699"
  },
  {
    "country": "CH",
    "name": "Uhwiesen",
    "lat": "47.67074",
    "lng": "8.63542"
  },
  {
    "country": "CH",
    "name": "Uetikon",
    "lat": "47.26441",
    "lng": "8.67925"
  },
  {
    "country": "CH",
    "name": "Uetendorf",
    "lat": "46.77392",
    "lng": "7.57251"
  },
  {
    "country": "CH",
    "name": "Uerkheim",
    "lat": "47.30353",
    "lng": "8.0232"
  },
  {
    "country": "CH",
    "name": "Uerikon",
    "lat": "47.23672",
    "lng": "8.7573"
  },
  {
    "country": "CH",
    "name": "Ueberstorf",
    "lat": "46.86587",
    "lng": "7.30998"
  },
  {
    "country": "CH",
    "name": "Udligenswil",
    "lat": "47.09005",
    "lng": "8.40335"
  },
  {
    "country": "CH",
    "name": "Turtmann",
    "lat": "46.30028",
    "lng": "7.702"
  },
  {
    "country": "CH",
    "name": "Turgi",
    "lat": "47.49201",
    "lng": "8.25412"
  },
  {
    "country": "CH",
    "name": "Turbenthal",
    "lat": "47.43633",
    "lng": "8.84629"
  },
  {
    "country": "CH",
    "name": "Tuggen",
    "lat": "47.20291",
    "lng": "8.94896"
  },
  {
    "country": "CH",
    "name": "Trun",
    "lat": "46.74292",
    "lng": "8.98716"
  },
  {
    "country": "CH",
    "name": "Trubschachen",
    "lat": "46.92228",
    "lng": "7.8452"
  },
  {
    "country": "CH",
    "name": "Trub",
    "lat": "46.94168",
    "lng": "7.87996"
  },
  {
    "country": "CH",
    "name": "Troistorrents",
    "lat": "46.2289",
    "lng": "6.91589"
  },
  {
    "country": "CH",
    "name": "Trogen",
    "lat": "47.40782",
    "lng": "9.46498"
  },
  {
    "country": "CH",
    "name": "Trimmis",
    "lat": "46.90075",
    "lng": "9.5612"
  },
  {
    "country": "CH",
    "name": "Trimbach",
    "lat": "47.36561",
    "lng": "7.8868"
  },
  {
    "country": "CH",
    "name": "Triengen",
    "lat": "47.23573",
    "lng": "8.07652"
  },
  {
    "country": "CH",
    "name": "Treyvaux",
    "lat": "46.72796",
    "lng": "7.13769"
  },
  {
    "country": "CH",
    "name": "Trélex",
    "lat": "46.41538",
    "lng": "6.20813"
  },
  {
    "country": "CH",
    "name": "Travers",
    "lat": "46.94018",
    "lng": "6.67595"
  },
  {
    "country": "CH",
    "name": "Tramelan",
    "lat": "47.22298",
    "lng": "7.10287"
  },
  {
    "country": "CH",
    "name": "Trachselwald",
    "lat": "47.01699",
    "lng": "7.73639"
  },
  {
    "country": "CH",
    "name": "Töss (Kreis 4)",
    "lat": "47.4789",
    "lng": "8.70215"
  },
  {
    "country": "CH",
    "name": "Toffen",
    "lat": "46.86031",
    "lng": "7.49216"
  },
  {
    "country": "CH",
    "name": "Tiefencastel",
    "lat": "46.66014",
    "lng": "9.57883"
  },
  {
    "country": "CH",
    "name": "Thusis",
    "lat": "46.69724",
    "lng": "9.43938"
  },
  {
    "country": "CH",
    "name": "Thundorf",
    "lat": "47.54594",
    "lng": "8.96358"
  },
  {
    "country": "CH",
    "name": "Thun",
    "lat": "46.75118",
    "lng": "7.62166"
  },
  {
    "country": "CH",
    "name": "Thierachern",
    "lat": "46.75319",
    "lng": "7.57442"
  },
  {
    "country": "CH",
    "name": "Therwil",
    "lat": "47.49941",
    "lng": "7.55669"
  },
  {
    "country": "CH",
    "name": "Thayngen",
    "lat": "47.74717",
    "lng": "8.70724"
  },
  {
    "country": "CH",
    "name": "Thalwil",
    "lat": "47.29175",
    "lng": "8.56351"
  },
  {
    "country": "CH",
    "name": "Teufenthal",
    "lat": "47.32896",
    "lng": "8.11777"
  },
  {
    "country": "CH",
    "name": "Teufen",
    "lat": "47.3908",
    "lng": "9.38644"
  },
  {
    "country": "CH",
    "name": "Tesserete",
    "lat": "46.06813",
    "lng": "8.96501"
  },
  {
    "country": "CH",
    "name": "Tegerfelden",
    "lat": "47.55809",
    "lng": "8.28914"
  },
  {
    "country": "CH",
    "name": "Tavannes",
    "lat": "47.22079",
    "lng": "7.19759"
  },
  {
    "country": "CH",
    "name": "Täuffelen",
    "lat": "47.0663",
    "lng": "7.19883"
  },
  {
    "country": "CH",
    "name": "Tann",
    "lat": "47.26898",
    "lng": "8.85024"
  },
  {
    "country": "CH",
    "name": "Tanay",
    "lat": "46.34503",
    "lng": "6.83041"
  },
  {
    "country": "CH",
    "name": "Tamins",
    "lat": "46.82964",
    "lng": "9.40648"
  },
  {
    "country": "CH",
    "name": "Tägerwilen",
    "lat": "47.65698",
    "lng": "9.13999"
  },
  {
    "country": "CH",
    "name": "Tafers",
    "lat": "46.81483",
    "lng": "7.21852"
  },
  {
    "country": "CH",
    "name": "Sursee",
    "lat": "47.17088",
    "lng": "8.11113"
  },
  {
    "country": "CH",
    "name": "Sumiswald",
    "lat": "47.02747",
    "lng": "7.74526"
  },
  {
    "country": "CH",
    "name": "Sulz",
    "lat": "47.53602",
    "lng": "8.09628"
  },
  {
    "country": "CH",
    "name": "Sulgen",
    "lat": "47.53967",
    "lng": "9.18585"
  },
  {
    "country": "CH",
    "name": "Suhr",
    "lat": "47.37172",
    "lng": "8.07967"
  },
  {
    "country": "CH",
    "name": "Subingen",
    "lat": "47.19852",
    "lng": "7.61949"
  },
  {
    "country": "CH",
    "name": "Strengelbach",
    "lat": "47.27917",
    "lng": "7.92895"
  },
  {
    "country": "CH",
    "name": "Stettlen",
    "lat": "46.95835",
    "lng": "7.52508"
  },
  {
    "country": "CH",
    "name": "Stettfurt",
    "lat": "47.52588",
    "lng": "8.95317"
  },
  {
    "country": "CH",
    "name": "Steinhausen",
    "lat": "47.1951",
    "lng": "8.48581"
  },
  {
    "country": "CH",
    "name": "Steinen",
    "lat": "47.04975",
    "lng": "8.61214"
  },
  {
    "country": "CH",
    "name": "Stein am Rhein",
    "lat": "47.65933",
    "lng": "8.85964"
  },
  {
    "country": "CH",
    "name": "Stein",
    "lat": "47.54403",
    "lng": "7.95256"
  },
  {
    "country": "CH",
    "name": "Steffisburg",
    "lat": "46.77807",
    "lng": "7.63249"
  },
  {
    "country": "CH",
    "name": "Steckborn",
    "lat": "47.66667",
    "lng": "8.98333"
  },
  {
    "country": "CH",
    "name": "Staufen",
    "lat": "47.38197",
    "lng": "8.16681"
  },
  {
    "country": "CH",
    "name": "Stansstad",
    "lat": "46.9768",
    "lng": "8.33553"
  },
  {
    "country": "CH",
    "name": "Stans",
    "lat": "46.95805",
    "lng": "8.36609"
  },
  {
    "country": "CH",
    "name": "Stalden",
    "lat": "46.23341",
    "lng": "7.87273"
  },
  {
    "country": "CH",
    "name": "Staffelbach",
    "lat": "47.28395",
    "lng": "8.04208"
  },
  {
    "country": "CH",
    "name": "Stäfa",
    "lat": "47.24254",
    "lng": "8.72342"
  },
  {
    "country": "CH",
    "name": "Stabio",
    "lat": "45.84846",
    "lng": "8.93642"
  },
  {
    "country": "CH",
    "name": "Spreitenbach",
    "lat": "47.42285",
    "lng": "8.36792"
  },
  {
    "country": "CH",
    "name": "Spiez",
    "lat": "46.68473",
    "lng": "7.69111"
  },
  {
    "country": "CH",
    "name": "Speicher",
    "lat": "47.4109",
    "lng": "9.44335"
  },
  {
    "country": "CH",
    "name": "Sottens",
    "lat": "46.65521",
    "lng": "6.74197"
  },
  {
    "country": "CH",
    "name": "Sorengo",
    "lat": "45.99766",
    "lng": "8.93783"
  },
  {
    "country": "CH",
    "name": "Solothurn",
    "lat": "47.20791",
    "lng": "7.53714"
  },
  {
    "country": "CH",
    "name": "Sissach",
    "lat": "47.46408",
    "lng": "7.80888"
  },
  {
    "country": "CH",
    "name": "Sirnach",
    "lat": "47.46222",
    "lng": "8.99763"
  },
  {
    "country": "CH",
    "name": "Sitten",
    "lat": "46.22739",
    "lng": "7.35559"
  },
  {
    "country": "CH",
    "name": "Sins",
    "lat": "47.19296",
    "lng": "8.39384"
  },
  {
    "country": "CH",
    "name": "Silvaplana",
    "lat": "46.4581",
    "lng": "9.79514"
  },
  {
    "country": "CH",
    "name": "Silenen",
    "lat": "46.7891",
    "lng": "8.67325"
  },
  {
    "country": "CH",
    "name": "Sigriswil",
    "lat": "46.71656",
    "lng": "7.71335"
  },
  {
    "country": "CH",
    "name": "Signau",
    "lat": "46.91944",
    "lng": "7.72418"
  },
  {
    "country": "CH",
    "name": "Sierre",
    "lat": "46.29192",
    "lng": "7.53559"
  },
  {
    "country": "CH",
    "name": "Siebnen",
    "lat": "47.17449",
    "lng": "8.89781"
  },
  {
    "country": "CH",
    "name": "Sevelen",
    "lat": "47.12213",
    "lng": "9.48601"
  },
  {
    "country": "CH",
    "name": "Seuzach / Seuzach (Dorf)",
    "lat": "47.53545",
    "lng": "8.73728"
  },
  {
    "country": "CH",
    "name": "Seon",
    "lat": "47.34848",
    "lng": "8.16072"
  },
  {
    "country": "CH",
    "name": "Sennwald",
    "lat": "47.26063",
    "lng": "9.50268"
  },
  {
    "country": "CH",
    "name": "Sempach",
    "lat": "47.13577",
    "lng": "8.19149"
  },
  {
    "country": "CH",
    "name": "Sementina",
    "lat": "46.18363",
    "lng": "8.99162"
  },
  {
    "country": "CH",
    "name": "Selzach",
    "lat": "47.20531",
    "lng": "7.45521"
  },
  {
    "country": "CH",
    "name": "Seltisberg",
    "lat": "47.46249",
    "lng": "7.72039"
  },
  {
    "country": "CH",
    "name": "Seftigen",
    "lat": "46.78765",
    "lng": "7.53937"
  },
  {
    "country": "CH",
    "name": "Seengen",
    "lat": "47.32503",
    "lng": "8.20724"
  },
  {
    "country": "CH",
    "name": "Seedorf",
    "lat": "47.03445",
    "lng": "7.31249"
  },
  {
    "country": "CH",
    "name": "Seedorf",
    "lat": "46.88199",
    "lng": "8.61611"
  },
  {
    "country": "CH",
    "name": "Seeberg",
    "lat": "47.15585",
    "lng": "7.66567"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 11) / Seebach",
    "lat": "47.42181",
    "lng": "8.54779"
  },
  {
    "country": "CH",
    "name": "Scuol",
    "lat": "46.79671",
    "lng": "10.29804"
  },
  {
    "country": "CH",
    "name": "Schwyz",
    "lat": "47.02076",
    "lng": "8.65414"
  },
  {
    "country": "CH",
    "name": "Schwellbrunn",
    "lat": "47.35255",
    "lng": "9.24894"
  },
  {
    "country": "CH",
    "name": "Schwarzenberg",
    "lat": "47.01705",
    "lng": "8.17261"
  },
  {
    "country": "CH",
    "name": "Schwanden",
    "lat": "46.99541",
    "lng": "9.0701"
  },
  {
    "country": "CH",
    "name": "Schwaderloch",
    "lat": "47.58541",
    "lng": "8.14455"
  },
  {
    "country": "CH",
    "name": "Schüpfheim",
    "lat": "46.95161",
    "lng": "8.01723"
  },
  {
    "country": "CH",
    "name": "Schüpfen",
    "lat": "47.03661",
    "lng": "7.37723"
  },
  {
    "country": "CH",
    "name": "Schübelbach",
    "lat": "47.17326",
    "lng": "8.92811"
  },
  {
    "country": "CH",
    "name": "Schötz",
    "lat": "47.16896",
    "lng": "7.9887"
  },
  {
    "country": "CH",
    "name": "Schönenwerd",
    "lat": "47.3691",
    "lng": "8.00167"
  },
  {
    "country": "CH",
    "name": "Schönenbuch",
    "lat": "47.53853",
    "lng": "7.50572"
  },
  {
    "country": "CH",
    "name": "Schöftland",
    "lat": "47.3059",
    "lng": "8.05119"
  },
  {
    "country": "CH",
    "name": "Schmitten",
    "lat": "46.8575",
    "lng": "7.25031"
  },
  {
    "country": "CH",
    "name": "Schmerikon",
    "lat": "47.22538",
    "lng": "8.94836"
  },
  {
    "country": "CH",
    "name": "Schlieren",
    "lat": "47.39668",
    "lng": "8.44763"
  },
  {
    "country": "CH",
    "name": "Schleitheim",
    "lat": "47.74818",
    "lng": "8.48213"
  },
  {
    "country": "CH",
    "name": "Schinznach Dorf",
    "lat": "47.4465",
    "lng": "8.14089"
  },
  {
    "country": "CH",
    "name": "Schinznach Bad",
    "lat": "47.44992",
    "lng": "8.16833"
  },
  {
    "country": "CH",
    "name": "Schindellegi",
    "lat": "47.1746",
    "lng": "8.71345"
  },
  {
    "country": "CH",
    "name": "Schiers",
    "lat": "46.96973",
    "lng": "9.6872"
  },
  {
    "country": "CH",
    "name": "Schenkon",
    "lat": "47.17765",
    "lng": "8.13204"
  },
  {
    "country": "CH",
    "name": "Schattdorf",
    "lat": "46.8655",
    "lng": "8.65465"
  },
  {
    "country": "CH",
    "name": "Scharans",
    "lat": "46.71814",
    "lng": "9.45903"
  },
  {
    "country": "CH",
    "name": "Schänis",
    "lat": "47.15995",
    "lng": "9.04549"
  },
  {
    "country": "CH",
    "name": "Schafisheim",
    "lat": "47.37664",
    "lng": "8.14263"
  },
  {
    "country": "CH",
    "name": "Schaffhausen",
    "lat": "47.69732",
    "lng": "8.63493"
  },
  {
    "country": "CH",
    "name": "Saxon",
    "lat": "46.14937",
    "lng": "7.17514"
  },
  {
    "country": "CH",
    "name": "Savigny",
    "lat": "46.53844",
    "lng": "6.73222"
  },
  {
    "country": "CH",
    "name": "Savièse",
    "lat": "46.25115",
    "lng": "7.34558"
  },
  {
    "country": "CH",
    "name": "Sattel",
    "lat": "47.08246",
    "lng": "8.63565"
  },
  {
    "country": "CH",
    "name": "Satigny",
    "lat": "46.21462",
    "lng": "6.03553"
  },
  {
    "country": "CH",
    "name": "Sarnen",
    "lat": "46.89611",
    "lng": "8.24531"
  },
  {
    "country": "CH",
    "name": "Sarmenstorf",
    "lat": "47.31109",
    "lng": "8.2495"
  },
  {
    "country": "CH",
    "name": "Sargans",
    "lat": "47.04896",
    "lng": "9.44103"
  },
  {
    "country": "CH",
    "name": "Santa Maria in Calanca",
    "lat": "46.26285",
    "lng": "9.14485"
  },
  {
    "country": "CH",
    "name": "Sankt Stephan",
    "lat": "46.50827",
    "lng": "7.39559"
  },
  {
    "country": "CH",
    "name": "Sankt Peterzell",
    "lat": "47.31782",
    "lng": "9.17599"
  },
  {
    "country": "CH",
    "name": "Sankt Niklaus",
    "lat": "46.17717",
    "lng": "7.80349"
  },
  {
    "country": "CH",
    "name": "St. Moritz",
    "lat": "46.49937",
    "lng": "9.84327"
  },
  {
    "country": "CH",
    "name": "Sankt Margrethen",
    "lat": "47.45253",
    "lng": "9.63741"
  },
  {
    "country": "CH",
    "name": "Sankt Gallenkappel",
    "lat": "47.24368",
    "lng": "8.96438"
  },
  {
    "country": "CH",
    "name": "Sankt Gallen",
    "lat": "47.42391",
    "lng": "9.37477"
  },
  {
    "country": "CH",
    "name": "Sankt Antoni",
    "lat": "46.82207",
    "lng": "7.26091"
  },
  {
    "country": "CH",
    "name": "Samedan",
    "lat": "46.53399",
    "lng": "9.87276"
  },
  {
    "country": "CH",
    "name": "Salvan",
    "lat": "46.1189",
    "lng": "7.02078"
  },
  {
    "country": "CH",
    "name": "Salmsach",
    "lat": "47.55433",
    "lng": "9.37229"
  },
  {
    "country": "CH",
    "name": "Salgesch",
    "lat": "46.31155",
    "lng": "7.5712"
  },
  {
    "country": "CH",
    "name": "Sâles",
    "lat": "46.63473",
    "lng": "6.97336"
  },
  {
    "country": "CH",
    "name": "Saint-Prex",
    "lat": "46.47963",
    "lng": "6.45992"
  },
  {
    "country": "CH",
    "name": "Saint-Maurice",
    "lat": "46.21826",
    "lng": "7.0032"
  },
  {
    "country": "CH",
    "name": "Saint-Livres",
    "lat": "46.50794",
    "lng": "6.38753"
  },
  {
    "country": "CH",
    "name": "Saint-Léonard",
    "lat": "46.25152",
    "lng": "7.41714"
  },
  {
    "country": "CH",
    "name": "Saint-Imier",
    "lat": "47.15284",
    "lng": "6.99692"
  },
  {
    "country": "CH",
    "name": "Sainte-Croix",
    "lat": "46.82203",
    "lng": "6.50283"
  },
  {
    "country": "CH",
    "name": "Saint-Cergue",
    "lat": "46.4459",
    "lng": "6.15737"
  },
  {
    "country": "CH",
    "name": "Saint-Blaise",
    "lat": "47.01511",
    "lng": "6.98832"
  },
  {
    "country": "CH",
    "name": "Saint-Aubin-Sauges",
    "lat": "46.89419",
    "lng": "6.77251"
  },
  {
    "country": "CH",
    "name": "Saillon",
    "lat": "46.17035",
    "lng": "7.18771"
  },
  {
    "country": "CH",
    "name": "Saignelégier",
    "lat": "47.25619",
    "lng": "6.99648"
  },
  {
    "country": "CH",
    "name": "Safenwil",
    "lat": "47.32163",
    "lng": "7.98254"
  },
  {
    "country": "CH",
    "name": "Sachseln",
    "lat": "46.86718",
    "lng": "8.23344"
  },
  {
    "country": "CH",
    "name": "Saas-Grund",
    "lat": "46.12281",
    "lng": "7.93651"
  },
  {
    "country": "CH",
    "name": "Saas-Fee",
    "lat": "46.10805",
    "lng": "7.92741"
  },
  {
    "country": "CH",
    "name": "Saanen",
    "lat": "46.48945",
    "lng": "7.26003"
  },
  {
    "country": "CH",
    "name": "Rüti",
    "lat": "47.25603",
    "lng": "8.85552"
  },
  {
    "country": "CH",
    "name": "Rüthi",
    "lat": "47.2948",
    "lng": "9.53857"
  },
  {
    "country": "CH",
    "name": "Ruswil",
    "lat": "47.08425",
    "lng": "8.12645"
  },
  {
    "country": "CH",
    "name": "Russikon",
    "lat": "47.39669",
    "lng": "8.77515"
  },
  {
    "country": "CH",
    "name": "Rüschlikon",
    "lat": "47.30688",
    "lng": "8.55135"
  },
  {
    "country": "CH",
    "name": "Rüschegg",
    "lat": "46.77977",
    "lng": "7.39167"
  },
  {
    "country": "CH",
    "name": "Rupperswil",
    "lat": "47.40131",
    "lng": "8.12877"
  },
  {
    "country": "CH",
    "name": "Rümlang",
    "lat": "47.45041",
    "lng": "8.52993"
  },
  {
    "country": "CH",
    "name": "Rüeggisberg",
    "lat": "46.82216",
    "lng": "7.4389"
  },
  {
    "country": "CH",
    "name": "Rue",
    "lat": "46.61916",
    "lng": "6.82225"
  },
  {
    "country": "CH",
    "name": "Rudolfstetten",
    "lat": "47.37101",
    "lng": "8.38083"
  },
  {
    "country": "CH",
    "name": "Rüderswil",
    "lat": "46.98374",
    "lng": "7.72167"
  },
  {
    "country": "CH",
    "name": "Rubigen",
    "lat": "46.89868",
    "lng": "7.5446"
  },
  {
    "country": "CH",
    "name": "Rotkreuz",
    "lat": "47.14283",
    "lng": "8.4314"
  },
  {
    "country": "CH",
    "name": "Rothrist",
    "lat": "47.30508",
    "lng": "7.89196"
  },
  {
    "country": "CH",
    "name": "Rothenthurm",
    "lat": "47.1042",
    "lng": "8.67585"
  },
  {
    "country": "CH",
    "name": "Röschenz",
    "lat": "47.42366",
    "lng": "7.48024"
  },
  {
    "country": "CH",
    "name": "Rorschach",
    "lat": "47.478",
    "lng": "9.4903"
  },
  {
    "country": "CH",
    "name": "Rorbas",
    "lat": "47.53092",
    "lng": "8.57555"
  },
  {
    "country": "CH",
    "name": "Root",
    "lat": "47.11458",
    "lng": "8.39021"
  },
  {
    "country": "CH",
    "name": "Romont",
    "lat": "46.69652",
    "lng": "6.91898"
  },
  {
    "country": "CH",
    "name": "Römerswil",
    "lat": "47.16881",
    "lng": "8.24528"
  },
  {
    "country": "CH",
    "name": "Romanshorn",
    "lat": "47.56586",
    "lng": "9.37869"
  },
  {
    "country": "CH",
    "name": "Romanel-sur-Lausanne",
    "lat": "46.56403",
    "lng": "6.60538"
  },
  {
    "country": "CH",
    "name": "Rolle",
    "lat": "46.4582",
    "lng": "6.33499"
  },
  {
    "country": "CH",
    "name": "Rohrbach",
    "lat": "47.13521",
    "lng": "7.81334"
  },
  {
    "country": "CH",
    "name": "Rohr",
    "lat": "47.41029",
    "lng": "7.95333"
  },
  {
    "country": "CH",
    "name": "Roggwil",
    "lat": "47.49981",
    "lng": "9.3958"
  },
  {
    "country": "CH",
    "name": "Roggwil",
    "lat": "47.24119",
    "lng": "7.82141"
  },
  {
    "country": "CH",
    "name": "Rodersdorf",
    "lat": "47.48082",
    "lng": "7.45767"
  },
  {
    "country": "CH",
    "name": "Riva San Vitale",
    "lat": "45.90123",
    "lng": "8.97167"
  },
  {
    "country": "CH",
    "name": "Ringgenberg",
    "lat": "46.70114",
    "lng": "7.89445"
  },
  {
    "country": "CH",
    "name": "Effretikon / Rikon",
    "lat": "47.43099",
    "lng": "8.68624"
  },
  {
    "country": "CH",
    "name": "Riggisberg",
    "lat": "46.81028",
    "lng": "7.48014"
  },
  {
    "country": "CH",
    "name": "Riedholz",
    "lat": "47.23158",
    "lng": "7.56829"
  },
  {
    "country": "CH",
    "name": "Riddes",
    "lat": "46.17276",
    "lng": "7.2236"
  },
  {
    "country": "CH",
    "name": "Rickenbach bei Wil",
    "lat": "47.44856",
    "lng": "9.04902"
  },
  {
    "country": "CH",
    "name": "Richterswil",
    "lat": "47.20622",
    "lng": "8.69686"
  },
  {
    "country": "CH",
    "name": "Riaz",
    "lat": "46.64224",
    "lng": "7.06183"
  },
  {
    "country": "CH",
    "name": "Rheinfelden",
    "lat": "47.55437",
    "lng": "7.79403"
  },
  {
    "country": "CH",
    "name": "Rheineck",
    "lat": "47.4663",
    "lng": "9.59028"
  },
  {
    "country": "CH",
    "name": "Rhäzüns",
    "lat": "46.79891",
    "lng": "9.39764"
  },
  {
    "country": "CH",
    "name": "Renens",
    "lat": "46.53989",
    "lng": "6.5881"
  },
  {
    "country": "CH",
    "name": "Reinach",
    "lat": "47.25732",
    "lng": "8.18091"
  },
  {
    "country": "CH",
    "name": "Reigoldswil",
    "lat": "47.39824",
    "lng": "7.68718"
  },
  {
    "country": "CH",
    "name": "Reiden",
    "lat": "47.24719",
    "lng": "7.97135"
  },
  {
    "country": "CH",
    "name": "Reichenburg",
    "lat": "47.17097",
    "lng": "8.97704"
  },
  {
    "country": "CH",
    "name": "Rehetobel",
    "lat": "47.42611",
    "lng": "9.483"
  },
  {
    "country": "CH",
    "name": "Regensdorf",
    "lat": "47.4341",
    "lng": "8.46874"
  },
  {
    "country": "CH",
    "name": "Reconvilier",
    "lat": "47.23431",
    "lng": "7.22239"
  },
  {
    "country": "CH",
    "name": "Rechthalten",
    "lat": "46.76766",
    "lng": "7.24028"
  },
  {
    "country": "CH",
    "name": "Rebstein",
    "lat": "47.39812",
    "lng": "9.58503"
  },
  {
    "country": "CH",
    "name": "Elsau-Räterschen / Räterschen",
    "lat": "47.49927",
    "lng": "8.796"
  },
  {
    "country": "CH",
    "name": "Raron",
    "lat": "46.31196",
    "lng": "7.80029"
  },
  {
    "country": "CH",
    "name": "Rapperswil",
    "lat": "47.22557",
    "lng": "8.82228"
  },
  {
    "country": "CH",
    "name": "Randogne",
    "lat": "46.30952",
    "lng": "7.50058"
  },
  {
    "country": "CH",
    "name": "Ramsen",
    "lat": "47.70797",
    "lng": "8.80949"
  },
  {
    "country": "CH",
    "name": "Rafz",
    "lat": "47.60438",
    "lng": "8.54305"
  },
  {
    "country": "CH",
    "name": "Radelfingen",
    "lat": "47.02146",
    "lng": "7.27178"
  },
  {
    "country": "CH",
    "name": "Quarten",
    "lat": "47.107",
    "lng": "9.24199"
  },
  {
    "country": "CH",
    "name": "Pura",
    "lat": "45.98647",
    "lng": "8.86877"
  },
  {
    "country": "CH",
    "name": "Pully",
    "lat": "46.51027",
    "lng": "6.66183"
  },
  {
    "country": "CH",
    "name": "Puidoux",
    "lat": "46.50093",
    "lng": "6.78249"
  },
  {
    "country": "CH",
    "name": "Promontogno",
    "lat": "46.33939",
    "lng": "9.55759"
  },
  {
    "country": "CH",
    "name": "Prilly",
    "lat": "46.53698",
    "lng": "6.60456"
  },
  {
    "country": "CH",
    "name": "Pregassona",
    "lat": "46.02021",
    "lng": "8.97429"
  },
  {
    "country": "CH",
    "name": "Pratteln",
    "lat": "47.52071",
    "lng": "7.69356"
  },
  {
    "country": "CH",
    "name": "Praroman",
    "lat": "46.75145",
    "lng": "7.17778"
  },
  {
    "country": "CH",
    "name": "Prangins",
    "lat": "46.39518",
    "lng": "6.2496"
  },
  {
    "country": "CH",
    "name": "Poschiavo",
    "lat": "46.32441",
    "lng": "10.05823"
  },
  {
    "country": "CH",
    "name": "Porrentruy",
    "lat": "47.41728",
    "lng": "7.07573"
  },
  {
    "country": "CH",
    "name": "Pontresina",
    "lat": "46.4955",
    "lng": "9.90126"
  },
  {
    "country": "CH",
    "name": "La Punt Chamues-ch",
    "lat": "46.57887",
    "lng": "9.92015"
  },
  {
    "country": "CH",
    "name": "Plan-les-Ouates",
    "lat": "46.16789",
    "lng": "6.11664"
  },
  {
    "country": "CH",
    "name": "Plaffeien",
    "lat": "46.74198",
    "lng": "7.28666"
  },
  {
    "country": "CH",
    "name": "Pieterlen",
    "lat": "47.17501",
    "lng": "7.33791"
  },
  {
    "country": "CH",
    "name": "Pfyn",
    "lat": "47.59693",
    "lng": "8.9542"
  },
  {
    "country": "CH",
    "name": "Pfungen",
    "lat": "47.51394",
    "lng": "8.6423"
  },
  {
    "country": "CH",
    "name": "Pfaffhausen",
    "lat": "47.36476",
    "lng": "8.62375"
  },
  {
    "country": "CH",
    "name": "Pfeffingen",
    "lat": "47.45984",
    "lng": "7.58975"
  },
  {
    "country": "CH",
    "name": "Pfaffnau",
    "lat": "47.22772",
    "lng": "7.89719"
  },
  {
    "country": "CH",
    "name": "Pfäffikon",
    "lat": "47.36453",
    "lng": "8.79202"
  },
  {
    "country": "CH",
    "name": "Pfäffikon",
    "lat": "47.20109",
    "lng": "8.77816"
  },
  {
    "country": "CH",
    "name": "Peseux",
    "lat": "46.98704",
    "lng": "6.88903"
  },
  {
    "country": "CH",
    "name": "Péry",
    "lat": "47.19398",
    "lng": "7.24913"
  },
  {
    "country": "CH",
    "name": "Perroy",
    "lat": "46.4669",
    "lng": "6.35349"
  },
  {
    "country": "CH",
    "name": "Penthalaz",
    "lat": "46.61077",
    "lng": "6.52519"
  },
  {
    "country": "CH",
    "name": "Payerne",
    "lat": "46.82192",
    "lng": "6.93817"
  },
  {
    "country": "CH",
    "name": "Paudex",
    "lat": "46.50548",
    "lng": "6.66819"
  },
  {
    "country": "CH",
    "name": "Pampigny",
    "lat": "46.58093",
    "lng": "6.42941"
  },
  {
    "country": "CH",
    "name": "Palézieux",
    "lat": "46.54191",
    "lng": "6.83989"
  },
  {
    "country": "CH",
    "name": "Pailly",
    "lat": "46.70123",
    "lng": "6.6754"
  },
  {
    "country": "CH",
    "name": "Ottenbach",
    "lat": "47.28228",
    "lng": "8.40432"
  },
  {
    "country": "CH",
    "name": "Othmarsingen",
    "lat": "47.40125",
    "lng": "8.21383"
  },
  {
    "country": "CH",
    "name": "Otelfingen",
    "lat": "47.46053",
    "lng": "8.39141"
  },
  {
    "country": "CH",
    "name": "Ostermundigen",
    "lat": "46.95694",
    "lng": "7.49019"
  },
  {
    "country": "CH",
    "name": "Orvin",
    "lat": "47.16068",
    "lng": "7.21368"
  },
  {
    "country": "CH",
    "name": "Orsières",
    "lat": "46.02903",
    "lng": "7.14437"
  },
  {
    "country": "CH",
    "name": "Orpund",
    "lat": "47.13891",
    "lng": "7.30775"
  },
  {
    "country": "CH",
    "name": "Oron-la-Ville",
    "lat": "46.57094",
    "lng": "6.82557"
  },
  {
    "country": "CH",
    "name": "Ormalingen",
    "lat": "47.46936",
    "lng": "7.87248"
  },
  {
    "country": "CH",
    "name": "Orbe",
    "lat": "46.72504",
    "lng": "6.53069"
  },
  {
    "country": "CH",
    "name": "Opfikon",
    "lat": "47.43169",
    "lng": "8.57588"
  },
  {
    "country": "CH",
    "name": "Onex",
    "lat": "46.18396",
    "lng": "6.10237"
  },
  {
    "country": "CH",
    "name": "Olten",
    "lat": "47.34999",
    "lng": "7.90329"
  },
  {
    "country": "CH",
    "name": "Ollon",
    "lat": "46.29524",
    "lng": "6.99314"
  },
  {
    "country": "CH",
    "name": "Oftringen",
    "lat": "47.31382",
    "lng": "7.92533"
  },
  {
    "country": "CH",
    "name": "Oetwil",
    "lat": "47.27049",
    "lng": "8.72023"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 11) / Oerlikon",
    "lat": "47.40823",
    "lng": "8.54258"
  },
  {
    "country": "CH",
    "name": "Oensingen",
    "lat": "47.28764",
    "lng": "7.71612"
  },
  {
    "country": "CH",
    "name": "Obfelden",
    "lat": "47.26413",
    "lng": "8.4215"
  },
  {
    "country": "CH",
    "name": "Oberwil",
    "lat": "47.51407",
    "lng": "7.55786"
  },
  {
    "country": "CH",
    "name": "Wetzikon / Ober-Wetzikon",
    "lat": "47.32514",
    "lng": "8.80005"
  },
  {
    "country": "CH",
    "name": "Oberuzwil",
    "lat": "47.43076",
    "lng": "9.12724"
  },
  {
    "country": "CH",
    "name": "Urdorf",
    "lat": "47.38507",
    "lng": "8.42581"
  },
  {
    "country": "CH",
    "name": "Obersiggenthal",
    "lat": "47.4875",
    "lng": "8.29652"
  },
  {
    "country": "CH",
    "name": "Oberschrot",
    "lat": "46.74126",
    "lng": "7.28149"
  },
  {
    "country": "CH",
    "name": "Oberrüti",
    "lat": "47.16673",
    "lng": "8.39441"
  },
  {
    "country": "CH",
    "name": "Oberriet",
    "lat": "47.32088",
    "lng": "9.56808"
  },
  {
    "country": "CH",
    "name": "Oberrieden",
    "lat": "47.27444",
    "lng": "8.57838"
  },
  {
    "country": "CH",
    "name": "Oberlunkhofen",
    "lat": "47.31244",
    "lng": "8.39242"
  },
  {
    "country": "CH",
    "name": "Oberkirch",
    "lat": "47.15642",
    "lng": "8.11567"
  },
  {
    "country": "CH",
    "name": "Oberhelfenschwil",
    "lat": "47.35673",
    "lng": "9.11076"
  },
  {
    "country": "CH",
    "name": "Obergösgen",
    "lat": "47.36538",
    "lng": "7.95173"
  },
  {
    "country": "CH",
    "name": "Oberglatt",
    "lat": "47.47576",
    "lng": "8.51896"
  },
  {
    "country": "CH",
    "name": "Oberentfelden",
    "lat": "47.35639",
    "lng": "8.04594"
  },
  {
    "country": "CH",
    "name": "Oberengstringen",
    "lat": "47.40841",
    "lng": "8.46515"
  },
  {
    "country": "CH",
    "name": "Endingen",
    "lat": "47.53742",
    "lng": "8.29036"
  },
  {
    "country": "CH",
    "name": "Oberegg",
    "lat": "47.42531",
    "lng": "9.55134"
  },
  {
    "country": "CH",
    "name": "Oberdorf",
    "lat": "47.39353",
    "lng": "7.75169"
  },
  {
    "country": "CH",
    "name": "Oberdiessbach",
    "lat": "46.84117",
    "lng": "7.6173"
  },
  {
    "country": "CH",
    "name": "Oberburg",
    "lat": "47.03665",
    "lng": "7.62745"
  },
  {
    "country": "CH",
    "name": "Oberbuchsiten",
    "lat": "47.31334",
    "lng": "7.76836"
  },
  {
    "country": "CH",
    "name": "Oberbipp",
    "lat": "47.2607",
    "lng": "7.66359"
  },
  {
    "country": "CH",
    "name": "Nyon",
    "lat": "46.38318",
    "lng": "6.23955"
  },
  {
    "country": "CH",
    "name": "Nürensdorf",
    "lat": "47.44814",
    "lng": "8.64908"
  },
  {
    "country": "CH",
    "name": "Nunningen",
    "lat": "47.3941",
    "lng": "7.61951"
  },
  {
    "country": "CH",
    "name": "Novazzano",
    "lat": "45.84073",
    "lng": "8.98236"
  },
  {
    "country": "CH",
    "name": "Nottwil",
    "lat": "47.13469",
    "lng": "8.13774"
  },
  {
    "country": "CH",
    "name": "Wichtrach",
    "lat": "46.8501",
    "lng": "7.57748"
  },
  {
    "country": "CH",
    "name": "Niederurnen",
    "lat": "47.12598",
    "lng": "9.05428"
  },
  {
    "country": "CH",
    "name": "Niederrohrdorf",
    "lat": "47.42409",
    "lng": "8.30404"
  },
  {
    "country": "CH",
    "name": "Niederlenz",
    "lat": "47.40079",
    "lng": "8.1764"
  },
  {
    "country": "CH",
    "name": "Niederhelfenschwil",
    "lat": "47.47487",
    "lng": "9.18543"
  },
  {
    "country": "CH",
    "name": "Niedergösgen",
    "lat": "47.37157",
    "lng": "7.98837"
  },
  {
    "country": "CH",
    "name": "Erlinsbach",
    "lat": "47.39753",
    "lng": "8.00797"
  },
  {
    "country": "CH",
    "name": "Niederbüren",
    "lat": "47.46547",
    "lng": "9.20568"
  },
  {
    "country": "CH",
    "name": "Niederbipp",
    "lat": "47.27175",
    "lng": "7.69583"
  },
  {
    "country": "CH",
    "name": "Nidau",
    "lat": "47.12545",
    "lng": "7.24033"
  },
  {
    "country": "CH",
    "name": "Neunkirch",
    "lat": "47.69012",
    "lng": "8.49981"
  },
  {
    "country": "CH",
    "name": "Neuhausen",
    "lat": "47.68579",
    "lng": "8.61474"
  },
  {
    "country": "CH",
    "name": "Neuenkirch",
    "lat": "47.09989",
    "lng": "8.20416"
  },
  {
    "country": "CH",
    "name": "Neuenhof",
    "lat": "47.44985",
    "lng": "8.32682"
  },
  {
    "country": "CH",
    "name": "Neudorf",
    "lat": "47.17699",
    "lng": "8.20911"
  },
  {
    "country": "CH",
    "name": "Neuchâtel",
    "lat": "46.99179",
    "lng": "6.931"
  },
  {
    "country": "CH",
    "name": "Netstal",
    "lat": "47.06337",
    "lng": "9.05734"
  },
  {
    "country": "CH",
    "name": "Neftenbach / Dorf Neftenbach",
    "lat": "47.52764",
    "lng": "8.6649"
  },
  {
    "country": "CH",
    "name": "Nebikon",
    "lat": "47.19185",
    "lng": "7.97769"
  },
  {
    "country": "CH",
    "name": "Naters",
    "lat": "46.32536",
    "lng": "7.98912"
  },
  {
    "country": "CH",
    "name": "Nänikon",
    "lat": "47.36975",
    "lng": "8.68894"
  },
  {
    "country": "CH",
    "name": "Näfels",
    "lat": "47.09775",
    "lng": "9.06361"
  },
  {
    "country": "CH",
    "name": "Muttenz",
    "lat": "47.52271",
    "lng": "7.64511"
  },
  {
    "country": "CH",
    "name": "Murten/Morat",
    "lat": "46.92827",
    "lng": "7.11715"
  },
  {
    "country": "CH",
    "name": "Muri",
    "lat": "47.27428",
    "lng": "8.33854"
  },
  {
    "country": "CH",
    "name": "Muri",
    "lat": "46.93122",
    "lng": "7.48658"
  },
  {
    "country": "CH",
    "name": "Murgenthal",
    "lat": "47.27145",
    "lng": "7.83935"
  },
  {
    "country": "CH",
    "name": "Muotathal",
    "lat": "46.97676",
    "lng": "8.76499"
  },
  {
    "country": "CH",
    "name": "Muolen",
    "lat": "47.52102",
    "lng": "9.32484"
  },
  {
    "country": "CH",
    "name": "Müntschemier",
    "lat": "46.99548",
    "lng": "7.14626"
  },
  {
    "country": "CH",
    "name": "Münsterlingen",
    "lat": "47.63197",
    "lng": "9.23271"
  },
  {
    "country": "CH",
    "name": "Münsingen",
    "lat": "46.87298",
    "lng": "7.561"
  },
  {
    "country": "CH",
    "name": "Münchwilen",
    "lat": "47.47719",
    "lng": "8.99677"
  },
  {
    "country": "CH",
    "name": "Münchenstein",
    "lat": "47.51848",
    "lng": "7.60966"
  },
  {
    "country": "CH",
    "name": "Münchenbuchsee",
    "lat": "47.02175",
    "lng": "7.45036"
  },
  {
    "country": "CH",
    "name": "Mumpf",
    "lat": "47.54563",
    "lng": "7.92123"
  },
  {
    "country": "CH",
    "name": "Müllheim",
    "lat": "47.60195",
    "lng": "9.00357"
  },
  {
    "country": "CH",
    "name": "Mühlethurnen",
    "lat": "46.81345",
    "lng": "7.50881"
  },
  {
    "country": "CH",
    "name": "Mühleberg",
    "lat": "46.95466",
    "lng": "7.26102"
  },
  {
    "country": "CH",
    "name": "Muhen",
    "lat": "47.33578",
    "lng": "8.05536"
  },
  {
    "country": "CH",
    "name": "Moutier",
    "lat": "47.27818",
    "lng": "7.36951"
  },
  {
    "country": "CH",
    "name": "Moudon",
    "lat": "46.66758",
    "lng": "6.79781"
  },
  {
    "country": "CH",
    "name": "Mosnang",
    "lat": "47.36252",
    "lng": "9.04296"
  },
  {
    "country": "CH",
    "name": "Mörschwil",
    "lat": "47.47097",
    "lng": "9.42278"
  },
  {
    "country": "CH",
    "name": "Morges",
    "lat": "46.51127",
    "lng": "6.49854"
  },
  {
    "country": "CH",
    "name": "Morbio Inferiore",
    "lat": "45.84915",
    "lng": "9.01907"
  },
  {
    "country": "CH",
    "name": "Montreux",
    "lat": "46.43301",
    "lng": "6.91143"
  },
  {
    "country": "CH",
    "name": "Monthey",
    "lat": "46.25451",
    "lng": "6.95406"
  },
  {
    "country": "CH",
    "name": "Monte Carasso",
    "lat": "46.18649",
    "lng": "8.99892"
  },
  {
    "country": "CH",
    "name": "Montana",
    "lat": "46.31338",
    "lng": "7.48839"
  },
  {
    "country": "CH",
    "name": "Montagny",
    "lat": "46.79289",
    "lng": "6.61222"
  },
  {
    "country": "CH",
    "name": "Montagnola",
    "lat": "45.98323",
    "lng": "8.91786"
  },
  {
    "country": "CH",
    "name": "Mönchaltorf",
    "lat": "47.30958",
    "lng": "8.72029"
  },
  {
    "country": "CH",
    "name": "Mollis",
    "lat": "47.08878",
    "lng": "9.07242"
  },
  {
    "country": "CH",
    "name": "Mollens",
    "lat": "46.5776",
    "lng": "6.3632"
  },
  {
    "country": "CH",
    "name": "Möhlin",
    "lat": "47.55915",
    "lng": "7.84329"
  },
  {
    "country": "CH",
    "name": "Mogelsberg",
    "lat": "47.36222",
    "lng": "9.13541"
  },
  {
    "country": "CH",
    "name": "Minusio",
    "lat": "46.17769",
    "lng": "8.81473"
  },
  {
    "country": "CH",
    "name": "Mézières",
    "lat": "46.67958",
    "lng": "6.9263"
  },
  {
    "country": "CH",
    "name": "Meyrin",
    "lat": "46.23424",
    "lng": "6.08025"
  },
  {
    "country": "CH",
    "name": "Mettmenstetten",
    "lat": "47.24529",
    "lng": "8.46347"
  },
  {
    "country": "CH",
    "name": "Messen",
    "lat": "47.09155",
    "lng": "7.44528"
  },
  {
    "country": "CH",
    "name": "Mesocco",
    "lat": "46.3939",
    "lng": "9.23333"
  },
  {
    "country": "CH",
    "name": "Merenschwand",
    "lat": "47.25944",
    "lng": "8.37633"
  },
  {
    "country": "CH",
    "name": "Menznau",
    "lat": "47.08364",
    "lng": "8.03971"
  },
  {
    "country": "CH",
    "name": "Menzingen",
    "lat": "47.17764",
    "lng": "8.59215"
  },
  {
    "country": "CH",
    "name": "Menziken",
    "lat": "47.23965",
    "lng": "8.18996"
  },
  {
    "country": "CH",
    "name": "Mendrisio",
    "lat": "45.87019",
    "lng": "8.9816"
  },
  {
    "country": "CH",
    "name": "Mellingen",
    "lat": "47.41903",
    "lng": "8.27331"
  },
  {
    "country": "CH",
    "name": "Melide",
    "lat": "45.95455",
    "lng": "8.94725"
  },
  {
    "country": "CH",
    "name": "Melchnau",
    "lat": "47.18213",
    "lng": "7.85128"
  },
  {
    "country": "CH",
    "name": "Melano",
    "lat": "45.92202",
    "lng": "8.98435"
  },
  {
    "country": "CH",
    "name": "Meisterschwanden",
    "lat": "47.29489",
    "lng": "8.22867"
  },
  {
    "country": "CH",
    "name": "Meiringen",
    "lat": "46.72709",
    "lng": "8.1872"
  },
  {
    "country": "CH",
    "name": "Meinisberg",
    "lat": "47.15965",
    "lng": "7.34801"
  },
  {
    "country": "CH",
    "name": "Meilen",
    "lat": "47.27232",
    "lng": "8.64617"
  },
  {
    "country": "CH",
    "name": "Meierskappel",
    "lat": "47.1247",
    "lng": "8.44274"
  },
  {
    "country": "CH",
    "name": "Meggen",
    "lat": "47.04691",
    "lng": "8.37467"
  },
  {
    "country": "CH",
    "name": "Mauensee",
    "lat": "47.16703",
    "lng": "8.06793"
  },
  {
    "country": "CH",
    "name": "Matzingen",
    "lat": "47.51957",
    "lng": "8.93365"
  },
  {
    "country": "CH",
    "name": "Matzendorf",
    "lat": "47.30374",
    "lng": "7.6282"
  },
  {
    "country": "CH",
    "name": "Matten",
    "lat": "46.67833",
    "lng": "7.86889"
  },
  {
    "country": "CH",
    "name": "Massagno",
    "lat": "46.01257",
    "lng": "8.94354"
  },
  {
    "country": "CH",
    "name": "Martigny-Ville",
    "lat": "46.10276",
    "lng": "7.07245"
  },
  {
    "country": "CH",
    "name": "Martigny-Combe",
    "lat": "46.07817",
    "lng": "7.05099"
  },
  {
    "country": "CH",
    "name": "Marthalen",
    "lat": "47.62913",
    "lng": "8.65326"
  },
  {
    "country": "CH",
    "name": "Märstetten-Dorf",
    "lat": "47.59252",
    "lng": "9.06851"
  },
  {
    "country": "CH",
    "name": "Marsens",
    "lat": "46.65644",
    "lng": "7.05948"
  },
  {
    "country": "CH",
    "name": "Marly",
    "lat": "46.77611",
    "lng": "7.16459"
  },
  {
    "country": "CH",
    "name": "Männedorf",
    "lat": "47.25686",
    "lng": "8.69893"
  },
  {
    "country": "CH",
    "name": "Malvaglia",
    "lat": "46.40588",
    "lng": "8.9819"
  },
  {
    "country": "CH",
    "name": "Malters",
    "lat": "47.03628",
    "lng": "8.18193"
  },
  {
    "country": "CH",
    "name": "Malleray",
    "lat": "47.23839",
    "lng": "7.27286"
  },
  {
    "country": "CH",
    "name": "Malans",
    "lat": "46.98096",
    "lng": "9.57527"
  },
  {
    "country": "CH",
    "name": "Maienfeld",
    "lat": "47.00472",
    "lng": "9.53115"
  },
  {
    "country": "CH",
    "name": "Magden",
    "lat": "47.52868",
    "lng": "7.81128"
  },
  {
    "country": "CH",
    "name": "Magadino",
    "lat": "46.14892",
    "lng": "8.8561"
  },
  {
    "country": "CH",
    "name": "Madiswil",
    "lat": "47.16463",
    "lng": "7.79858"
  },
  {
    "country": "CH",
    "name": "Lyssach",
    "lat": "47.06445",
    "lng": "7.58228"
  },
  {
    "country": "CH",
    "name": "Lyss",
    "lat": "47.0741",
    "lng": "7.30655"
  },
  {
    "country": "CH",
    "name": "Luzern",
    "lat": "47.05048",
    "lng": "8.30635"
  },
  {
    "country": "CH",
    "name": "Luzein",
    "lat": "46.91957",
    "lng": "9.7608"
  },
  {
    "country": "CH",
    "name": "Lützelflüh",
    "lat": "47.00757",
    "lng": "7.69165"
  },
  {
    "country": "CH",
    "name": "Lutry",
    "lat": "46.50241",
    "lng": "6.68647"
  },
  {
    "country": "CH",
    "name": "Lütisburg",
    "lat": "47.39451",
    "lng": "9.08312"
  },
  {
    "country": "CH",
    "name": "Luthern",
    "lat": "47.05753",
    "lng": "7.91692"
  },
  {
    "country": "CH",
    "name": "Luterbach",
    "lat": "47.21426",
    "lng": "7.58463"
  },
  {
    "country": "CH",
    "name": "Lungern",
    "lat": "46.78578",
    "lng": "8.15984"
  },
  {
    "country": "CH",
    "name": "Lumino",
    "lat": "46.2302",
    "lng": "9.0642"
  },
  {
    "country": "CH",
    "name": "Lugano",
    "lat": "46.01008",
    "lng": "8.96004"
  },
  {
    "country": "CH",
    "name": "Luchsingen",
    "lat": "46.9664",
    "lng": "9.03715"
  },
  {
    "country": "CH",
    "name": "Lucens",
    "lat": "46.70854",
    "lng": "6.83931"
  },
  {
    "country": "CH",
    "name": "Lotzwil",
    "lat": "47.19135",
    "lng": "7.79102"
  },
  {
    "country": "CH",
    "name": "Lostorf",
    "lat": "47.38372",
    "lng": "7.94655"
  },
  {
    "country": "CH",
    "name": "Losone",
    "lat": "46.16866",
    "lng": "8.75928"
  },
  {
    "country": "CH",
    "name": "Lodrino",
    "lat": "46.30016",
    "lng": "8.97986"
  },
  {
    "country": "CH",
    "name": "Locarno",
    "lat": "46.17086",
    "lng": "8.79953"
  },
  {
    "country": "CH",
    "name": "Littau",
    "lat": "47.05",
    "lng": "8.26274"
  },
  {
    "country": "CH",
    "name": "Linthal",
    "lat": "46.92127",
    "lng": "8.99799"
  },
  {
    "country": "CH",
    "name": "Linden",
    "lat": "46.8469",
    "lng": "7.67831"
  },
  {
    "country": "CH",
    "name": "Ligornetto",
    "lat": "45.86161",
    "lng": "8.95166"
  },
  {
    "country": "CH",
    "name": "Liestal",
    "lat": "47.48455",
    "lng": "7.73446"
  },
  {
    "country": "CH",
    "name": "Liesberg",
    "lat": "47.40398",
    "lng": "7.42787"
  },
  {
    "country": "CH",
    "name": "Lichtensteig",
    "lat": "47.32381",
    "lng": "9.08758"
  },
  {
    "country": "CH",
    "name": "Leytron",
    "lat": "46.1866",
    "lng": "7.2078"
  },
  {
    "country": "CH",
    "name": "Leysin",
    "lat": "46.34183",
    "lng": "7.01151"
  },
  {
    "country": "CH",
    "name": "Le Vaud",
    "lat": "46.47753",
    "lng": "6.23603"
  },
  {
    "country": "CH",
    "name": "Leuzigen",
    "lat": "47.17458",
    "lng": "7.45775"
  },
  {
    "country": "CH",
    "name": "Leukerbad",
    "lat": "46.37943",
    "lng": "7.62687"
  },
  {
    "country": "CH",
    "name": "Leuk",
    "lat": "46.31736",
    "lng": "7.63412"
  },
  {
    "country": "CH",
    "name": "Les Ponts-de-Martel",
    "lat": "46.99735",
    "lng": "6.73059"
  },
  {
    "country": "CH",
    "name": "Les Geneveys-sur-Coffrane",
    "lat": "47.01528",
    "lng": "6.8513"
  },
  {
    "country": "CH",
    "name": "Les Breuleux",
    "lat": "47.21099",
    "lng": "7.00792"
  },
  {
    "country": "CH",
    "name": "Les Brenets",
    "lat": "47.06774",
    "lng": "6.70478"
  },
  {
    "country": "CH",
    "name": "Les Bois",
    "lat": "47.17715",
    "lng": "6.90498"
  },
  {
    "country": "CH",
    "name": "Lenzerheide",
    "lat": "46.72215",
    "lng": "9.55905"
  },
  {
    "country": "CH",
    "name": "Lenzburg",
    "lat": "47.38853",
    "lng": "8.17503"
  },
  {
    "country": "CH",
    "name": "Lens",
    "lat": "46.28298",
    "lng": "7.44976"
  },
  {
    "country": "CH",
    "name": "Le Noirmont",
    "lat": "47.22464",
    "lng": "6.95784"
  },
  {
    "country": "CH",
    "name": "Lenk",
    "lat": "46.45826",
    "lng": "7.44298"
  },
  {
    "country": "CH",
    "name": "Lengnau",
    "lat": "47.18155",
    "lng": "7.36814"
  },
  {
    "country": "CH",
    "name": "Le Mont-sur-Lausanne",
    "lat": "46.55815",
    "lng": "6.63145"
  },
  {
    "country": "CH",
    "name": "Le Locle",
    "lat": "47.05619",
    "lng": "6.74913"
  },
  {
    "country": "CH",
    "name": "Le Landeron",
    "lat": "47.05702",
    "lng": "7.07052"
  },
  {
    "country": "CH",
    "name": "Leibstadt",
    "lat": "47.5879",
    "lng": "8.17611"
  },
  {
    "country": "CH",
    "name": "Le Chenit",
    "lat": "46.60688",
    "lng": "6.23062"
  },
  {
    "country": "CH",
    "name": "Lavertezzo",
    "lat": "46.25893",
    "lng": "8.83756"
  },
  {
    "country": "CH",
    "name": "Lauterbrunnen",
    "lat": "46.59307",
    "lng": "7.90938"
  },
  {
    "country": "CH",
    "name": "Lausen",
    "lat": "47.47139",
    "lng": "7.7603"
  },
  {
    "country": "CH",
    "name": "Lausanne",
    "lat": "46.516",
    "lng": "6.63282"
  },
  {
    "country": "CH",
    "name": "Lauperswil",
    "lat": "46.96564",
    "lng": "7.74214"
  },
  {
    "country": "CH",
    "name": "Laupersdorf",
    "lat": "47.3126",
    "lng": "7.65465"
  },
  {
    "country": "CH",
    "name": "Laupen",
    "lat": "46.90214",
    "lng": "7.23973"
  },
  {
    "country": "CH",
    "name": "Laufenburg",
    "lat": "47.55985",
    "lng": "8.06225"
  },
  {
    "country": "CH",
    "name": "Laufen",
    "lat": "47.42193",
    "lng": "7.49946"
  },
  {
    "country": "CH",
    "name": "Läufelfingen",
    "lat": "47.39457",
    "lng": "7.85578"
  },
  {
    "country": "CH",
    "name": "La Tour-de-Trême",
    "lat": "46.61061",
    "lng": "7.06496"
  },
  {
    "country": "CH",
    "name": "La Tour-de-Peilz",
    "lat": "46.45312",
    "lng": "6.85856"
  },
  {
    "country": "CH",
    "name": "La Sarraz",
    "lat": "46.65863",
    "lng": "6.51077"
  },
  {
    "country": "CH",
    "name": "La Roche",
    "lat": "46.6962",
    "lng": "7.13721"
  },
  {
    "country": "CH",
    "name": "Langrickenbach",
    "lat": "47.59353",
    "lng": "9.24727"
  },
  {
    "country": "CH",
    "name": "Langnau / Langnau (Dorf)",
    "lat": "47.28643",
    "lng": "8.53627"
  },
  {
    "country": "CH",
    "name": "Langnau",
    "lat": "46.93936",
    "lng": "7.78738"
  },
  {
    "country": "CH",
    "name": "Langenthal",
    "lat": "47.21526",
    "lng": "7.79607"
  },
  {
    "country": "CH",
    "name": "Langenbruck",
    "lat": "47.34917",
    "lng": "7.76802"
  },
  {
    "country": "CH",
    "name": "La Neuveville",
    "lat": "47.06592",
    "lng": "7.09717"
  },
  {
    "country": "CH",
    "name": "Landquart",
    "lat": "46.95",
    "lng": "9.56667"
  },
  {
    "country": "CH",
    "name": "St-Légier-La Chiésaz",
    "lat": "46.47227",
    "lng": "6.87366"
  },
  {
    "country": "CH",
    "name": "Lachen",
    "lat": "47.19224",
    "lng": "8.85324"
  },
  {
    "country": "CH",
    "name": "La Chaux-de-Fonds",
    "lat": "47.09993",
    "lng": "6.82586"
  },
  {
    "country": "CH",
    "name": "L'Abbaye",
    "lat": "46.64966",
    "lng": "6.31907"
  },
  {
    "country": "CH",
    "name": "Laax",
    "lat": "46.80452",
    "lng": "9.25787"
  },
  {
    "country": "CH",
    "name": "Küttigen",
    "lat": "47.41484",
    "lng": "8.04979"
  },
  {
    "country": "CH",
    "name": "Küssnacht",
    "lat": "47.08557",
    "lng": "8.44206"
  },
  {
    "country": "CH",
    "name": "Küsnacht",
    "lat": "47.31805",
    "lng": "8.58401"
  },
  {
    "country": "CH",
    "name": "Künten",
    "lat": "47.38887",
    "lng": "8.33045"
  },
  {
    "country": "CH",
    "name": "Krummenau",
    "lat": "47.24755",
    "lng": "9.17064"
  },
  {
    "country": "CH",
    "name": "Kriens",
    "lat": "47.0311",
    "lng": "8.28547"
  },
  {
    "country": "CH",
    "name": "Kriegstetten",
    "lat": "47.17449",
    "lng": "7.59799"
  },
  {
    "country": "CH",
    "name": "Kreuzlingen",
    "lat": "47.65051",
    "lng": "9.17504"
  },
  {
    "country": "CH",
    "name": "Krauchthal",
    "lat": "47.00964",
    "lng": "7.5664"
  },
  {
    "country": "CH",
    "name": "Koppigen",
    "lat": "47.13125",
    "lng": "7.60525"
  },
  {
    "country": "CH",
    "name": "Konolfingen",
    "lat": "46.87909",
    "lng": "7.62013"
  },
  {
    "country": "CH",
    "name": "Köniz",
    "lat": "46.92436",
    "lng": "7.41457"
  },
  {
    "country": "CH",
    "name": "Kölliken",
    "lat": "47.33337",
    "lng": "8.02237"
  },
  {
    "country": "CH",
    "name": "Kollbrunn",
    "lat": "47.45793",
    "lng": "8.78295"
  },
  {
    "country": "CH",
    "name": "Koblenz",
    "lat": "47.60972",
    "lng": "8.2375"
  },
  {
    "country": "CH",
    "name": "Knutwil",
    "lat": "47.19953",
    "lng": "8.07315"
  },
  {
    "country": "CH",
    "name": "Knonau",
    "lat": "47.2235",
    "lng": "8.46197"
  },
  {
    "country": "CH",
    "name": "Kloten",
    "lat": "47.45152",
    "lng": "8.58491"
  },
  {
    "country": "CH",
    "name": "Klosters Serneus",
    "lat": "46.88918",
    "lng": "9.83826"
  },
  {
    "country": "CH",
    "name": "Klingnau",
    "lat": "47.58361",
    "lng": "8.2488"
  },
  {
    "country": "CH",
    "name": "Kleinlützel",
    "lat": "47.42518",
    "lng": "7.41607"
  },
  {
    "country": "CH",
    "name": "Kirchlindach",
    "lat": "46.99965",
    "lng": "7.41735"
  },
  {
    "country": "CH",
    "name": "Kirchberg",
    "lat": "47.41159",
    "lng": "9.0402"
  },
  {
    "country": "CH",
    "name": "Kirchberg",
    "lat": "47.08538",
    "lng": "7.58288"
  },
  {
    "country": "CH",
    "name": "Killwangen",
    "lat": "47.43223",
    "lng": "8.35097"
  },
  {
    "country": "CH",
    "name": "Kilchberg",
    "lat": "47.32438",
    "lng": "8.54548"
  },
  {
    "country": "CH",
    "name": "Kerzers",
    "lat": "46.97586",
    "lng": "7.1957"
  },
  {
    "country": "CH",
    "name": "Kerns",
    "lat": "46.90121",
    "lng": "8.27514"
  },
  {
    "country": "CH",
    "name": "Kehrsatz",
    "lat": "46.91035",
    "lng": "7.47096"
  },
  {
    "country": "CH",
    "name": "Kappelen",
    "lat": "47.06015",
    "lng": "7.2686"
  },
  {
    "country": "CH",
    "name": "Kandersteg",
    "lat": "46.49467",
    "lng": "7.67326"
  },
  {
    "country": "CH",
    "name": "Kaltbrunn",
    "lat": "47.21367",
    "lng": "9.0259"
  },
  {
    "country": "CH",
    "name": "Kallnach",
    "lat": "47.02032",
    "lng": "7.23545"
  },
  {
    "country": "CH",
    "name": "Kaisten",
    "lat": "47.5416",
    "lng": "8.04337"
  },
  {
    "country": "CH",
    "name": "Kaiseraugst",
    "lat": "47.53966",
    "lng": "7.72605"
  },
  {
    "country": "CH",
    "name": "Jussy",
    "lat": "46.2359",
    "lng": "6.26701"
  },
  {
    "country": "CH",
    "name": "Jonschwil",
    "lat": "47.42402",
    "lng": "9.08689"
  },
  {
    "country": "CH",
    "name": "Jonen",
    "lat": "47.2975",
    "lng": "8.39282"
  },
  {
    "country": "CH",
    "name": "Jona",
    "lat": "47.22983",
    "lng": "8.83884"
  },
  {
    "country": "CH",
    "name": "Jenaz",
    "lat": "46.92892",
    "lng": "9.71275"
  },
  {
    "country": "CH",
    "name": "Jegenstorf",
    "lat": "47.04802",
    "lng": "7.50787"
  },
  {
    "country": "CH",
    "name": "Pfäffikon / Irgenhausen",
    "lat": "47.3624",
    "lng": "8.79265"
  },
  {
    "country": "CH",
    "name": "Inwil",
    "lat": "47.1253",
    "lng": "8.34885"
  },
  {
    "country": "CH",
    "name": "Interlaken",
    "lat": "46.68387",
    "lng": "7.86638"
  },
  {
    "country": "CH",
    "name": "Ins",
    "lat": "47.00584",
    "lng": "7.10609"
  },
  {
    "country": "CH",
    "name": "Ingenbohl",
    "lat": "46.9988",
    "lng": "8.61529"
  },
  {
    "country": "CH",
    "name": "Illnau",
    "lat": "47.4113",
    "lng": "8.72125"
  },
  {
    "country": "CH",
    "name": "Ilanz",
    "lat": "46.77413",
    "lng": "9.20461"
  },
  {
    "country": "CH",
    "name": "Igis",
    "lat": "46.94531",
    "lng": "9.57218"
  },
  {
    "country": "CH",
    "name": "Ibach",
    "lat": "47.01105",
    "lng": "8.64538"
  },
  {
    "country": "CH",
    "name": "Hüttwilen",
    "lat": "47.60674",
    "lng": "8.87343"
  },
  {
    "country": "CH",
    "name": "Huttwil",
    "lat": "47.11502",
    "lng": "7.86209"
  },
  {
    "country": "CH",
    "name": "Hünenberg",
    "lat": "47.17536",
    "lng": "8.42497"
  },
  {
    "country": "CH",
    "name": "Horw",
    "lat": "47.01692",
    "lng": "8.30956"
  },
  {
    "country": "CH",
    "name": "Horn",
    "lat": "47.49425",
    "lng": "9.46246"
  },
  {
    "country": "CH",
    "name": "Horgen",
    "lat": "47.25983",
    "lng": "8.59778"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 10) / Höngg",
    "lat": "47.40313",
    "lng": "8.4971"
  },
  {
    "country": "CH",
    "name": "Homburg",
    "lat": "47.63469",
    "lng": "9.00756"
  },
  {
    "country": "CH",
    "name": "Hombrechtikon",
    "lat": "47.25298",
    "lng": "8.77212"
  },
  {
    "country": "CH",
    "name": "Hölstein",
    "lat": "47.4229",
    "lng": "7.77041"
  },
  {
    "country": "CH",
    "name": "Hohenrain",
    "lat": "47.18083",
    "lng": "8.31802"
  },
  {
    "country": "CH",
    "name": "Hochwald",
    "lat": "47.45389",
    "lng": "7.64459"
  },
  {
    "country": "CH",
    "name": "Hochdorf",
    "lat": "47.16841",
    "lng": "8.29179"
  },
  {
    "country": "CH",
    "name": "Hitzkirch",
    "lat": "47.22403",
    "lng": "8.26425"
  },
  {
    "country": "CH",
    "name": "Hittnau / Hittnau (Dorf)",
    "lat": "47.36334",
    "lng": "8.82418"
  },
  {
    "country": "CH",
    "name": "Hinwil",
    "lat": "47.29426",
    "lng": "8.84393"
  },
  {
    "country": "CH",
    "name": "Hinterrhein",
    "lat": "46.53333",
    "lng": "9.2"
  },
  {
    "country": "CH",
    "name": "Hindelbank",
    "lat": "47.0427",
    "lng": "7.54143"
  },
  {
    "country": "CH",
    "name": "Himmelried",
    "lat": "47.42136",
    "lng": "7.59985"
  },
  {
    "country": "CH",
    "name": "Hilterfingen",
    "lat": "46.73521",
    "lng": "7.66185"
  },
  {
    "country": "CH",
    "name": "Hildisrieden",
    "lat": "47.15068",
    "lng": "8.22582"
  },
  {
    "country": "CH",
    "name": "Hettlingen",
    "lat": "47.5461",
    "lng": "8.70532"
  },
  {
    "country": "CH",
    "name": "Herzogenbuchsee",
    "lat": "47.18795",
    "lng": "7.7062"
  },
  {
    "country": "CH",
    "name": "Herrliberg",
    "lat": "47.29064",
    "lng": "8.61464"
  },
  {
    "country": "CH",
    "name": "Hermiswil",
    "lat": "46.83125",
    "lng": "7.47775"
  },
  {
    "country": "CH",
    "name": "Herisau",
    "lat": "47.38615",
    "lng": "9.27916"
  },
  {
    "country": "CH",
    "name": "Hergiswil",
    "lat": "46.98429",
    "lng": "8.30944"
  },
  {
    "country": "CH",
    "name": "Hérémence",
    "lat": "46.18032",
    "lng": "7.40477"
  },
  {
    "country": "CH",
    "name": "Henggart",
    "lat": "47.56272",
    "lng": "8.68215"
  },
  {
    "country": "CH",
    "name": "Heitenried",
    "lat": "46.82762",
    "lng": "7.29944"
  },
  {
    "country": "CH",
    "name": "Heimiswil",
    "lat": "47.06755",
    "lng": "7.66665"
  },
  {
    "country": "CH",
    "name": "Heimberg",
    "lat": "46.79482",
    "lng": "7.60433"
  },
  {
    "country": "CH",
    "name": "Heiden",
    "lat": "47.44255",
    "lng": "9.53293"
  },
  {
    "country": "CH",
    "name": "Oberwinterthur (Kreis 2) / Hegi",
    "lat": "47.50716",
    "lng": "8.77057"
  },
  {
    "country": "CH",
    "name": "Hausen am Albis / Hausen (Dorf)",
    "lat": "47.24496",
    "lng": "8.53299"
  },
  {
    "country": "CH",
    "name": "Haslen",
    "lat": "47.36931",
    "lng": "9.36752"
  },
  {
    "country": "CH",
    "name": "Hasle",
    "lat": "46.97787",
    "lng": "8.05326"
  },
  {
    "country": "CH",
    "name": "Hallau",
    "lat": "47.69648",
    "lng": "8.45827"
  },
  {
    "country": "CH",
    "name": "Hägglingen",
    "lat": "47.38851",
    "lng": "8.25285"
  },
  {
    "country": "CH",
    "name": "Häggenschwil",
    "lat": "47.49462",
    "lng": "9.34487"
  },
  {
    "country": "CH",
    "name": "Hägendorf",
    "lat": "47.33497",
    "lng": "7.84133"
  },
  {
    "country": "CH",
    "name": "Güttingen",
    "lat": "47.60349",
    "lng": "9.28742"
  },
  {
    "country": "CH",
    "name": "Gunzwil",
    "lat": "47.21072",
    "lng": "8.17932"
  },
  {
    "country": "CH",
    "name": "Gunzgen",
    "lat": "47.31375",
    "lng": "7.83102"
  },
  {
    "country": "CH",
    "name": "Guggisberg",
    "lat": "46.76756",
    "lng": "7.32946"
  },
  {
    "country": "CH",
    "name": "Gstaad",
    "lat": "46.47215",
    "lng": "7.28685"
  },
  {
    "country": "CH",
    "name": "Gryon",
    "lat": "46.27377",
    "lng": "7.05975"
  },
  {
    "country": "CH",
    "name": "Gruyères",
    "lat": "46.58338",
    "lng": "7.08207"
  },
  {
    "country": "CH",
    "name": "Grüsch",
    "lat": "46.97965",
    "lng": "9.64639"
  },
  {
    "country": "CH",
    "name": "Grosswangen",
    "lat": "47.1331",
    "lng": "8.05041"
  },
  {
    "country": "CH",
    "name": "Andelfingen",
    "lat": "47.59447",
    "lng": "8.67826"
  },
  {
    "country": "CH",
    "name": "Grossaffoltern",
    "lat": "47.06534",
    "lng": "7.35689"
  },
  {
    "country": "CH",
    "name": "Grône",
    "lat": "46.25288",
    "lng": "7.45947"
  },
  {
    "country": "CH",
    "name": "Grolley",
    "lat": "46.8336",
    "lng": "7.07116"
  },
  {
    "country": "CH",
    "name": "Grindelwald",
    "lat": "46.62396",
    "lng": "8.03601"
  },
  {
    "country": "CH",
    "name": "Grimisuat",
    "lat": "46.25938",
    "lng": "7.38408"
  },
  {
    "country": "CH",
    "name": "Grenchen",
    "lat": "47.1921",
    "lng": "7.39586"
  },
  {
    "country": "CH",
    "name": "Grellingen",
    "lat": "47.44231",
    "lng": "7.58906"
  },
  {
    "country": "CH",
    "name": "Greifensee",
    "lat": "47.36717",
    "lng": "8.68115"
  },
  {
    "country": "CH",
    "name": "Gravesano",
    "lat": "46.04208",
    "lng": "8.91832"
  },
  {
    "country": "CH",
    "name": "Gränichen",
    "lat": "47.3593",
    "lng": "8.10243"
  },
  {
    "country": "CH",
    "name": "Grandson",
    "lat": "46.80946",
    "lng": "6.646"
  },
  {
    "country": "CH",
    "name": "Grand-Savagnier",
    "lat": "47.05101",
    "lng": "6.95489"
  },
  {
    "country": "CH",
    "name": "Le Grand-Saconnex",
    "lat": "46.23188",
    "lng": "6.12091"
  },
  {
    "country": "CH",
    "name": "Grancy",
    "lat": "46.59214",
    "lng": "6.46391"
  },
  {
    "country": "CH",
    "name": "Grächen",
    "lat": "46.19529",
    "lng": "7.83745"
  },
  {
    "country": "CH",
    "name": "Grabs",
    "lat": "47.18248",
    "lng": "9.44395"
  },
  {
    "country": "CH",
    "name": "Gottlieben",
    "lat": "47.6638",
    "lng": "9.13371"
  },
  {
    "country": "CH",
    "name": "Gossau",
    "lat": "47.41551",
    "lng": "9.25482"
  },
  {
    "country": "CH",
    "name": "Gossau",
    "lat": "47.3051",
    "lng": "8.75831"
  },
  {
    "country": "CH",
    "name": "Gorgier",
    "lat": "46.90143",
    "lng": "6.77985"
  },
  {
    "country": "CH",
    "name": "Gordola",
    "lat": "46.18256",
    "lng": "8.86657"
  },
  {
    "country": "CH",
    "name": "Gontenschwil",
    "lat": "47.27166",
    "lng": "8.14396"
  },
  {
    "country": "CH",
    "name": "Gonten",
    "lat": "47.32725",
    "lng": "9.34705"
  },
  {
    "country": "CH",
    "name": "Gommiswald",
    "lat": "47.23128",
    "lng": "9.02355"
  },
  {
    "country": "CH",
    "name": "Goldingen",
    "lat": "47.26477",
    "lng": "8.96167"
  },
  {
    "country": "CH",
    "name": "Goldau",
    "lat": "47.04761",
    "lng": "8.54616"
  },
  {
    "country": "CH",
    "name": "Goldach",
    "lat": "47.47401",
    "lng": "9.46711"
  },
  {
    "country": "CH",
    "name": "Glovelier",
    "lat": "47.33534",
    "lng": "7.20556"
  },
  {
    "country": "CH",
    "name": "Glattfelden",
    "lat": "47.55871",
    "lng": "8.50167"
  },
  {
    "country": "CH",
    "name": "Glattbrugg",
    "lat": "47.4313",
    "lng": "8.56272"
  },
  {
    "country": "CH",
    "name": "Glarus",
    "lat": "47.04057",
    "lng": "9.06804"
  },
  {
    "country": "CH",
    "name": "Gland",
    "lat": "46.42082",
    "lng": "6.2701"
  },
  {
    "country": "CH",
    "name": "Giubiasco",
    "lat": "46.17246",
    "lng": "9.00793"
  },
  {
    "country": "CH",
    "name": "Giswil",
    "lat": "46.83333",
    "lng": "8.18065"
  },
  {
    "country": "CH",
    "name": "Gipf-Oberfrick",
    "lat": "47.49875",
    "lng": "8.00497"
  },
  {
    "country": "CH",
    "name": "Gimel",
    "lat": "46.50945",
    "lng": "6.30736"
  },
  {
    "country": "CH",
    "name": "Giffers",
    "lat": "46.7623",
    "lng": "7.20845"
  },
  {
    "country": "CH",
    "name": "Geuensee",
    "lat": "47.1997",
    "lng": "8.10689"
  },
  {
    "country": "CH",
    "name": "Gersau",
    "lat": "46.99419",
    "lng": "8.525"
  },
  {
    "country": "CH",
    "name": "Gerlafingen",
    "lat": "47.17087",
    "lng": "7.57249"
  },
  {
    "country": "CH",
    "name": "Genolier",
    "lat": "46.43537",
    "lng": "6.21809"
  },
  {
    "country": "CH",
    "name": "Genève",
    "lat": "46.20222",
    "lng": "6.14569"
  },
  {
    "country": "CH",
    "name": "Gelterkinden",
    "lat": "47.46497",
    "lng": "7.85174"
  },
  {
    "country": "CH",
    "name": "Gebenstorf",
    "lat": "47.48136",
    "lng": "8.23949"
  },
  {
    "country": "CH",
    "name": "Ganterschwil",
    "lat": "47.38103",
    "lng": "9.09239"
  },
  {
    "country": "CH",
    "name": "Gams",
    "lat": "47.20429",
    "lng": "9.44172"
  },
  {
    "country": "CH",
    "name": "Gampel",
    "lat": "46.31599",
    "lng": "7.7421"
  },
  {
    "country": "CH",
    "name": "Gais",
    "lat": "47.3615",
    "lng": "9.45356"
  },
  {
    "country": "CH",
    "name": "Gachnang",
    "lat": "47.53935",
    "lng": "8.85311"
  },
  {
    "country": "CH",
    "name": "Fully",
    "lat": "46.13851",
    "lng": "7.11468"
  },
  {
    "country": "CH",
    "name": "Füllinsdorf",
    "lat": "47.50688",
    "lng": "7.73129"
  },
  {
    "country": "CH",
    "name": "Fulenbach",
    "lat": "47.27103",
    "lng": "7.83136"
  },
  {
    "country": "CH",
    "name": "Frutigen",
    "lat": "46.58723",
    "lng": "7.64945"
  },
  {
    "country": "CH",
    "name": "Froideville",
    "lat": "46.60123",
    "lng": "6.68085"
  },
  {
    "country": "CH",
    "name": "Frick",
    "lat": "47.51169",
    "lng": "8.02471"
  },
  {
    "country": "CH",
    "name": "Fribourg",
    "lat": "46.80237",
    "lng": "7.15128"
  },
  {
    "country": "CH",
    "name": "Frenkendorf",
    "lat": "47.50686",
    "lng": "7.71648"
  },
  {
    "country": "CH",
    "name": "Freienbach",
    "lat": "47.20534",
    "lng": "8.75842"
  },
  {
    "country": "CH",
    "name": "Frauenkappelen",
    "lat": "46.95425",
    "lng": "7.33835"
  },
  {
    "country": "CH",
    "name": "Frauenfeld",
    "lat": "47.55776",
    "lng": "8.89893"
  },
  {
    "country": "CH",
    "name": "Fraubrunnen",
    "lat": "47.0862",
    "lng": "7.52727"
  },
  {
    "country": "CH",
    "name": "Founex",
    "lat": "46.33277",
    "lng": "6.19243"
  },
  {
    "country": "CH",
    "name": "Fontenais",
    "lat": "47.40292",
    "lng": "7.08108"
  },
  {
    "country": "CH",
    "name": "Fontainemelon",
    "lat": "47.05495",
    "lng": "6.8868"
  },
  {
    "country": "CH",
    "name": "Flurlingen",
    "lat": "47.6839",
    "lng": "8.62995"
  },
  {
    "country": "CH",
    "name": "Flums",
    "lat": "47.09058",
    "lng": "9.34301"
  },
  {
    "country": "CH",
    "name": "Flühli",
    "lat": "46.88391",
    "lng": "8.01558"
  },
  {
    "country": "CH",
    "name": "Flüelen",
    "lat": "46.90478",
    "lng": "8.62396"
  },
  {
    "country": "CH",
    "name": "Flims",
    "lat": "46.83705",
    "lng": "9.28458"
  },
  {
    "country": "CH",
    "name": "Fleurier",
    "lat": "46.90224",
    "lng": "6.58253"
  },
  {
    "country": "CH",
    "name": "Flawil",
    "lat": "47.41301",
    "lng": "9.18324"
  },
  {
    "country": "CH",
    "name": "Flamatt",
    "lat": "46.88994",
    "lng": "7.32204"
  },
  {
    "country": "CH",
    "name": "Fischingen",
    "lat": "47.41422",
    "lng": "8.96862"
  },
  {
    "country": "CH",
    "name": "Fiesch",
    "lat": "46.39981",
    "lng": "8.13533"
  },
  {
    "country": "CH",
    "name": "Feusisberg",
    "lat": "47.18707",
    "lng": "8.74724"
  },
  {
    "country": "CH",
    "name": "Feuerthalen",
    "lat": "47.69054",
    "lng": "8.64357"
  },
  {
    "country": "CH",
    "name": "Ferenbalm",
    "lat": "46.9488",
    "lng": "7.21124"
  },
  {
    "country": "CH",
    "name": "Felsberg",
    "lat": "46.84566",
    "lng": "9.47588"
  },
  {
    "country": "CH",
    "name": "Feldmeilen",
    "lat": "47.27873",
    "lng": "8.62165"
  },
  {
    "country": "CH",
    "name": "Fehraltorf",
    "lat": "47.38775",
    "lng": "8.75149"
  },
  {
    "country": "CH",
    "name": "Fällanden",
    "lat": "47.37169",
    "lng": "8.63869"
  },
  {
    "country": "CH",
    "name": "Faido",
    "lat": "46.477",
    "lng": "8.80125"
  },
  {
    "country": "CH",
    "name": "Evolène",
    "lat": "46.11422",
    "lng": "7.49407"
  },
  {
    "country": "CH",
    "name": "Evionnaz",
    "lat": "46.18096",
    "lng": "7.02232"
  },
  {
    "country": "CH",
    "name": "Evilard",
    "lat": "47.15046",
    "lng": "7.23895"
  },
  {
    "country": "CH",
    "name": "Ettiswil",
    "lat": "47.15031",
    "lng": "8.01759"
  },
  {
    "country": "CH",
    "name": "Ettingen",
    "lat": "47.48225",
    "lng": "7.54654"
  },
  {
    "country": "CH",
    "name": "Estavayer-le-Lac",
    "lat": "46.84876",
    "lng": "6.8465"
  },
  {
    "country": "CH",
    "name": "Escholzmatt",
    "lat": "46.9135",
    "lng": "7.93426"
  },
  {
    "country": "CH",
    "name": "Eschlikon",
    "lat": "47.46361",
    "lng": "8.96381"
  },
  {
    "country": "CH",
    "name": "Eschenz",
    "lat": "47.64793",
    "lng": "8.87472"
  },
  {
    "country": "CH",
    "name": "Eschenbach",
    "lat": "47.23981",
    "lng": "8.92156"
  },
  {
    "country": "CH",
    "name": "Erstfeld",
    "lat": "46.81885",
    "lng": "8.65052"
  },
  {
    "country": "CH",
    "name": "Ersigen",
    "lat": "47.09368",
    "lng": "7.59507"
  },
  {
    "country": "CH",
    "name": "Ermatingen",
    "lat": "47.67057",
    "lng": "9.08573"
  },
  {
    "country": "CH",
    "name": "Erlenbach im Simmental",
    "lat": "46.66021",
    "lng": "7.55445"
  },
  {
    "country": "CH",
    "name": "Erlenbach",
    "lat": "47.30298",
    "lng": "8.59743"
  },
  {
    "country": "CH",
    "name": "Erlen",
    "lat": "47.54814",
    "lng": "9.23415"
  },
  {
    "country": "CH",
    "name": "Erlach",
    "lat": "47.0422",
    "lng": "7.09728"
  },
  {
    "country": "CH",
    "name": "Eriswil",
    "lat": "47.07816",
    "lng": "7.85149"
  },
  {
    "country": "CH",
    "name": "Ependes",
    "lat": "46.75368",
    "lng": "7.14609"
  },
  {
    "country": "CH",
    "name": "Epalinges",
    "lat": "46.54896",
    "lng": "6.66831"
  },
  {
    "country": "CH",
    "name": "Entlebuch",
    "lat": "46.99559",
    "lng": "8.06354"
  },
  {
    "country": "CH",
    "name": "Ennetbürgen",
    "lat": "46.98423",
    "lng": "8.41003"
  },
  {
    "country": "CH",
    "name": "Ennenda",
    "lat": "47.03363",
    "lng": "9.07888"
  },
  {
    "country": "CH",
    "name": "Engelberg",
    "lat": "46.82107",
    "lng": "8.40133"
  },
  {
    "country": "CH",
    "name": "Emmetten",
    "lat": "46.95658",
    "lng": "8.51467"
  },
  {
    "country": "CH",
    "name": "Emmen",
    "lat": "47.07819",
    "lng": "8.27331"
  },
  {
    "country": "CH",
    "name": "Embrach",
    "lat": "47.50561",
    "lng": "8.59406"
  },
  {
    "country": "CH",
    "name": "Elgg",
    "lat": "47.49715",
    "lng": "8.86523"
  },
  {
    "country": "CH",
    "name": "Einsiedeln",
    "lat": "47.12849",
    "lng": "8.74735"
  },
  {
    "country": "CH",
    "name": "Eiken",
    "lat": "47.53361",
    "lng": "7.98801"
  },
  {
    "country": "CH",
    "name": "Eichberg",
    "lat": "47.34374",
    "lng": "9.5314"
  },
  {
    "country": "CH",
    "name": "Eich",
    "lat": "47.15116",
    "lng": "8.16695"
  },
  {
    "country": "CH",
    "name": "Egnach",
    "lat": "47.54268",
    "lng": "9.38048"
  },
  {
    "country": "CH",
    "name": "Egliswil",
    "lat": "47.34922",
    "lng": "8.18553"
  },
  {
    "country": "CH",
    "name": "Eggiwil",
    "lat": "46.87575",
    "lng": "7.79567"
  },
  {
    "country": "CH",
    "name": "Eggersriet",
    "lat": "47.44202",
    "lng": "9.46901"
  },
  {
    "country": "CH",
    "name": "Egg",
    "lat": "47.29976",
    "lng": "8.69032"
  },
  {
    "country": "CH",
    "name": "Egerkingen",
    "lat": "47.31957",
    "lng": "7.78424"
  },
  {
    "country": "CH",
    "name": "Effretikon",
    "lat": "47.42575",
    "lng": "8.69094"
  },
  {
    "country": "CH",
    "name": "Ecublens",
    "lat": "46.60735",
    "lng": "6.80895"
  },
  {
    "country": "CH",
    "name": "Echallens",
    "lat": "46.6413",
    "lng": "6.63317"
  },
  {
    "country": "CH",
    "name": "Ebnat-Kappel",
    "lat": "47.26195",
    "lng": "9.12473"
  },
  {
    "country": "CH",
    "name": "Ebikon",
    "lat": "47.07937",
    "lng": "8.34041"
  },
  {
    "country": "CH",
    "name": "Dürrenroth",
    "lat": "47.08953",
    "lng": "7.7917"
  },
  {
    "country": "CH",
    "name": "Dürrenäsch",
    "lat": "47.32094",
    "lng": "8.15874"
  },
  {
    "country": "CH",
    "name": "Dürnten",
    "lat": "47.27856",
    "lng": "8.84156"
  },
  {
    "country": "CH",
    "name": "Düdingen",
    "lat": "46.84916",
    "lng": "7.1915"
  },
  {
    "country": "CH",
    "name": "Dübendorf",
    "lat": "47.39724",
    "lng": "8.61872"
  },
  {
    "country": "CH",
    "name": "Dottikon",
    "lat": "47.38437",
    "lng": "8.23981"
  },
  {
    "country": "CH",
    "name": "Dornach",
    "lat": "47.48038",
    "lng": "7.61644"
  },
  {
    "country": "CH",
    "name": "Domdidier",
    "lat": "46.86716",
    "lng": "7.01337"
  },
  {
    "country": "CH",
    "name": "Dombresson",
    "lat": "47.07192",
    "lng": "6.9592"
  },
  {
    "country": "CH",
    "name": "Domat",
    "lat": "46.83483",
    "lng": "9.45075"
  },
  {
    "country": "CH",
    "name": "Disentis",
    "lat": "46.70341",
    "lng": "8.8509"
  },
  {
    "country": "CH",
    "name": "Dietlikon / Dietlikon (Dorf)",
    "lat": "47.41827",
    "lng": "8.6188"
  },
  {
    "country": "CH",
    "name": "Dietikon",
    "lat": "47.40165",
    "lng": "8.40015"
  },
  {
    "country": "CH",
    "name": "Diessenhofen",
    "lat": "47.68908",
    "lng": "8.74958"
  },
  {
    "country": "CH",
    "name": "Diepoldsau",
    "lat": "47.386",
    "lng": "9.65558"
  },
  {
    "country": "CH",
    "name": "Diemtigen",
    "lat": "46.64928",
    "lng": "7.56477"
  },
  {
    "country": "CH",
    "name": "Dielsdorf",
    "lat": "47.48146",
    "lng": "8.4585"
  },
  {
    "country": "CH",
    "name": "Diegten",
    "lat": "47.4138",
    "lng": "7.81085"
  },
  {
    "country": "CH",
    "name": "Derendingen",
    "lat": "47.1985",
    "lng": "7.58844"
  },
  {
    "country": "CH",
    "name": "Densbüren",
    "lat": "47.4526",
    "lng": "8.0533"
  },
  {
    "country": "CH",
    "name": "Delémont",
    "lat": "47.36493",
    "lng": "7.34453"
  },
  {
    "country": "CH",
    "name": "Deitingen",
    "lat": "47.21515",
    "lng": "7.6188"
  },
  {
    "country": "CH",
    "name": "Degersheim",
    "lat": "47.37429",
    "lng": "9.20019"
  },
  {
    "country": "CH",
    "name": "Davos",
    "lat": "46.80429",
    "lng": "9.83723"
  },
  {
    "country": "CH",
    "name": "Därligen",
    "lat": "46.66175",
    "lng": "7.80808"
  },
  {
    "country": "CH",
    "name": "Dardagny",
    "lat": "46.19564",
    "lng": "5.99497"
  },
  {
    "country": "CH",
    "name": "Dallenwil",
    "lat": "46.9242",
    "lng": "8.38785"
  },
  {
    "country": "CH",
    "name": "Dagmersellen",
    "lat": "47.21405",
    "lng": "7.98519"
  },
  {
    "country": "CH",
    "name": "Dachsen",
    "lat": "47.66515",
    "lng": "8.6179"
  },
  {
    "country": "CH",
    "name": "Cully",
    "lat": "46.48892",
    "lng": "6.72945"
  },
  {
    "country": "CH",
    "name": "Cugy",
    "lat": "46.81479",
    "lng": "6.88888"
  },
  {
    "country": "CH",
    "name": "Cugnasco",
    "lat": "46.17473",
    "lng": "8.91684"
  },
  {
    "country": "CH",
    "name": "Crissier",
    "lat": "46.54586",
    "lng": "6.57567"
  },
  {
    "country": "CH",
    "name": "Couvet",
    "lat": "46.92525",
    "lng": "6.6327"
  },
  {
    "country": "CH",
    "name": "Courtételle",
    "lat": "47.34074",
    "lng": "7.31827"
  },
  {
    "country": "CH",
    "name": "Courtelary",
    "lat": "47.17822",
    "lng": "7.07236"
  },
  {
    "country": "CH",
    "name": "Court",
    "lat": "47.23956",
    "lng": "7.33655"
  },
  {
    "country": "CH",
    "name": "Courroux",
    "lat": "47.36069",
    "lng": "7.37371"
  },
  {
    "country": "CH",
    "name": "Courrendlin",
    "lat": "47.33853",
    "lng": "7.37243"
  },
  {
    "country": "CH",
    "name": "Courgevaux",
    "lat": "46.90648",
    "lng": "7.11215"
  },
  {
    "country": "CH",
    "name": "Courgenay",
    "lat": "47.40483",
    "lng": "7.12522"
  },
  {
    "country": "CH",
    "name": "Courfaivre",
    "lat": "47.33461",
    "lng": "7.28186"
  },
  {
    "country": "CH",
    "name": "Cossonay",
    "lat": "46.61443",
    "lng": "6.50631"
  },
  {
    "country": "CH",
    "name": "Cortaillod",
    "lat": "46.94306",
    "lng": "6.8444"
  },
  {
    "country": "CH",
    "name": "Corsier",
    "lat": "46.26297",
    "lng": "6.22461"
  },
  {
    "country": "CH",
    "name": "Cornaux",
    "lat": "47.0396",
    "lng": "7.01872"
  },
  {
    "country": "CH",
    "name": "Corminboeuf",
    "lat": "46.81029",
    "lng": "7.10535"
  },
  {
    "country": "CH",
    "name": "Corgémont",
    "lat": "47.19457",
    "lng": "7.14517"
  },
  {
    "country": "CH",
    "name": "Coppet",
    "lat": "46.31682",
    "lng": "6.19114"
  },
  {
    "country": "CH",
    "name": "Conthey",
    "lat": "46.2237",
    "lng": "7.30283"
  },
  {
    "country": "CH",
    "name": "Confignon",
    "lat": "46.17341",
    "lng": "6.08437"
  },
  {
    "country": "CH",
    "name": "Comano",
    "lat": "46.03635",
    "lng": "8.95526"
  },
  {
    "country": "CH",
    "name": "Colombier",
    "lat": "46.55709",
    "lng": "6.47284"
  },
  {
    "country": "CH",
    "name": "Collombey",
    "lat": "46.27385",
    "lng": "6.94789"
  },
  {
    "country": "CH",
    "name": "Claro",
    "lat": "46.25763",
    "lng": "9.02252"
  },
  {
    "country": "CH",
    "name": "Churwalden",
    "lat": "46.78143",
    "lng": "9.54377"
  },
  {
    "country": "CH",
    "name": "Chur",
    "lat": "46.84986",
    "lng": "9.53287"
  },
  {
    "country": "CH",
    "name": "Chippis",
    "lat": "46.2802",
    "lng": "7.53962"
  },
  {
    "country": "CH",
    "name": "Chiasso",
    "lat": "45.83203",
    "lng": "9.03119"
  },
  {
    "country": "CH",
    "name": "Chézard-Saint-Martin",
    "lat": "47.06629",
    "lng": "6.93332"
  },
  {
    "country": "CH",
    "name": "Chexbres",
    "lat": "46.48208",
    "lng": "6.77805"
  },
  {
    "country": "CH",
    "name": "Cheseaux",
    "lat": "46.58624",
    "lng": "6.60587"
  },
  {
    "country": "CH",
    "name": "Chermignon-d’en Haut",
    "lat": "46.28844",
    "lng": "7.47487"
  },
  {
    "country": "CH",
    "name": "Chêne-Bourg",
    "lat": "46.19534",
    "lng": "6.19406"
  },
  {
    "country": "CH",
    "name": "Chavornay",
    "lat": "46.70244",
    "lng": "6.5694"
  },
  {
    "country": "CH",
    "name": "Chavannes",
    "lat": "46.53005",
    "lng": "6.57068"
  },
  {
    "country": "CH",
    "name": "Châtel-Saint-Denis",
    "lat": "46.52691",
    "lng": "6.90083"
  },
  {
    "country": "CH",
    "name": "Château-d'Oex",
    "lat": "46.47455",
    "lng": "7.13155"
  },
  {
    "country": "CH",
    "name": "Charrat",
    "lat": "46.1249",
    "lng": "7.13138"
  },
  {
    "country": "CH",
    "name": "Charmey",
    "lat": "46.61957",
    "lng": "7.16486"
  },
  {
    "country": "CH",
    "name": "Chardonne",
    "lat": "46.47676",
    "lng": "6.8268"
  },
  {
    "country": "CH",
    "name": "Chancy",
    "lat": "46.15003",
    "lng": "5.97153"
  },
  {
    "country": "CH",
    "name": "Champéry",
    "lat": "46.17543",
    "lng": "6.86903"
  },
  {
    "country": "CH",
    "name": "Chamoson",
    "lat": "46.20275",
    "lng": "7.22319"
  },
  {
    "country": "CH",
    "name": "Cham",
    "lat": "47.18213",
    "lng": "8.46358"
  },
  {
    "country": "CH",
    "name": "Chalais",
    "lat": "46.26758",
    "lng": "7.51145"
  },
  {
    "country": "CH",
    "name": "Cevio",
    "lat": "46.31479",
    "lng": "8.60332"
  },
  {
    "country": "CH",
    "name": "Cernier",
    "lat": "47.05878",
    "lng": "6.9004"
  },
  {
    "country": "CH",
    "name": "Celerina",
    "lat": "46.51217",
    "lng": "9.85794"
  },
  {
    "country": "CH",
    "name": "Cazis",
    "lat": "46.7194",
    "lng": "9.43271"
  },
  {
    "country": "CH",
    "name": "Caux",
    "lat": "46.43241",
    "lng": "6.93855"
  },
  {
    "country": "CH",
    "name": "Cauco",
    "lat": "46.33541",
    "lng": "9.12129"
  },
  {
    "country": "CH",
    "name": "Castel San Pietro",
    "lat": "45.86211",
    "lng": "9.00843"
  },
  {
    "country": "CH",
    "name": "Caslano",
    "lat": "45.97364",
    "lng": "8.87739"
  },
  {
    "country": "CH",
    "name": "Carouge",
    "lat": "46.18096",
    "lng": "6.13921"
  },
  {
    "country": "CH",
    "name": "Canobbio",
    "lat": "46.03592",
    "lng": "8.96605"
  },
  {
    "country": "CH",
    "name": "Camorino",
    "lat": "46.16483",
    "lng": "9.00547"
  },
  {
    "country": "CH",
    "name": "Cadro",
    "lat": "46.04595",
    "lng": "8.98725"
  },
  {
    "country": "CH",
    "name": "Cadenazzo",
    "lat": "46.15172",
    "lng": "8.94719"
  },
  {
    "country": "CH",
    "name": "Cadempino",
    "lat": "46.03672",
    "lng": "8.93403"
  },
  {
    "country": "CH",
    "name": "Buus",
    "lat": "47.50635",
    "lng": "7.86414"
  },
  {
    "country": "CH",
    "name": "Buttwil",
    "lat": "47.26828",
    "lng": "8.31064"
  },
  {
    "country": "CH",
    "name": "Buttisholz",
    "lat": "47.11442",
    "lng": "8.09425"
  },
  {
    "country": "CH",
    "name": "Bütschwil",
    "lat": "47.36022",
    "lng": "9.07213"
  },
  {
    "country": "CH",
    "name": "Bussigny",
    "lat": "46.5511",
    "lng": "6.55597"
  },
  {
    "country": "CH",
    "name": "Büsserach",
    "lat": "47.39415",
    "lng": "7.54117"
  },
  {
    "country": "CH",
    "name": "Buseno",
    "lat": "46.27381",
    "lng": "9.10735"
  },
  {
    "country": "CH",
    "name": "Büron",
    "lat": "47.21192",
    "lng": "8.0942"
  },
  {
    "country": "CH",
    "name": "Bürglen",
    "lat": "47.54921",
    "lng": "9.1495"
  },
  {
    "country": "CH",
    "name": "Bürglen",
    "lat": "46.87565",
    "lng": "8.66539"
  },
  {
    "country": "CH",
    "name": "Burgistein",
    "lat": "46.78464",
    "lng": "7.49988"
  },
  {
    "country": "CH",
    "name": "Burgdorf",
    "lat": "47.05901",
    "lng": "7.62786"
  },
  {
    "country": "CH",
    "name": "Buochs",
    "lat": "46.97398",
    "lng": "8.42279"
  },
  {
    "country": "CH",
    "name": "Bulle",
    "lat": "46.61797",
    "lng": "7.0569"
  },
  {
    "country": "CH",
    "name": "Bülach",
    "lat": "47.52197",
    "lng": "8.54049"
  },
  {
    "country": "CH",
    "name": "Bühler",
    "lat": "47.37348",
    "lng": "9.42507"
  },
  {
    "country": "CH",
    "name": "Buchs",
    "lat": "47.39358",
    "lng": "8.08233"
  },
  {
    "country": "CH",
    "name": "Buchs",
    "lat": "47.16743",
    "lng": "9.47794"
  },
  {
    "country": "CH",
    "name": "Buchrain",
    "lat": "47.09625",
    "lng": "8.34729"
  },
  {
    "country": "CH",
    "name": "Buchholterberg",
    "lat": "46.81351",
    "lng": "7.67463"
  },
  {
    "country": "CH",
    "name": "Bubikon",
    "lat": "47.26698",
    "lng": "8.8179"
  },
  {
    "country": "CH",
    "name": "Bubendorf",
    "lat": "47.44586",
    "lng": "7.73759"
  },
  {
    "country": "CH",
    "name": "Brüttisellen",
    "lat": "47.42173",
    "lng": "8.63263"
  },
  {
    "country": "CH",
    "name": "Brütten",
    "lat": "47.47318",
    "lng": "8.67569"
  },
  {
    "country": "CH",
    "name": "Brusio",
    "lat": "46.25953",
    "lng": "10.12385"
  },
  {
    "country": "CH",
    "name": "Brugg",
    "lat": "47.48096",
    "lng": "8.20869"
  },
  {
    "country": "CH",
    "name": "Brügg",
    "lat": "47.1237",
    "lng": "7.27887"
  },
  {
    "country": "CH",
    "name": "Bronschhofen",
    "lat": "47.47835",
    "lng": "9.03454"
  },
  {
    "country": "CH",
    "name": "Broc",
    "lat": "46.60513",
    "lng": "7.09891"
  },
  {
    "country": "CH",
    "name": "Brittnau",
    "lat": "47.25954",
    "lng": "7.94689"
  },
  {
    "country": "CH",
    "name": "Brissago",
    "lat": "46.12013",
    "lng": "8.71181"
  },
  {
    "country": "CH",
    "name": "Brislach",
    "lat": "47.41763",
    "lng": "7.5434"
  },
  {
    "country": "CH",
    "name": "Brig",
    "lat": "46.31667",
    "lng": "7.98333"
  },
  {
    "country": "CH",
    "name": "Brienz",
    "lat": "46.7545",
    "lng": "8.03847"
  },
  {
    "country": "CH",
    "name": "Bremgarten",
    "lat": "47.35109",
    "lng": "8.34214"
  },
  {
    "country": "CH",
    "name": "Breitenbach",
    "lat": "47.40668",
    "lng": "7.54554"
  },
  {
    "country": "CH",
    "name": "Breíl",
    "lat": "46.76986",
    "lng": "9.06036"
  },
  {
    "country": "CH",
    "name": "Bowil",
    "lat": "46.89304",
    "lng": "7.69757"
  },
  {
    "country": "CH",
    "name": "Boudry",
    "lat": "46.94991",
    "lng": "6.83757"
  },
  {
    "country": "CH",
    "name": "Bottmingen",
    "lat": "47.52343",
    "lng": "7.57211"
  },
  {
    "country": "CH",
    "name": "Bottighofen",
    "lat": "47.63643",
    "lng": "9.20882"
  },
  {
    "country": "CH",
    "name": "Bottens",
    "lat": "46.61596",
    "lng": "6.66149"
  },
  {
    "country": "CH",
    "name": "Bösingen",
    "lat": "46.89229",
    "lng": "7.2277"
  },
  {
    "country": "CH",
    "name": "Bonstetten",
    "lat": "47.31505",
    "lng": "8.46836"
  },
  {
    "country": "CH",
    "name": "Boniswil",
    "lat": "47.31725",
    "lng": "8.18963"
  },
  {
    "country": "CH",
    "name": "Bönigen",
    "lat": "46.68736",
    "lng": "7.8935"
  },
  {
    "country": "CH",
    "name": "Boncourt",
    "lat": "47.49493",
    "lng": "7.01297"
  },
  {
    "country": "CH",
    "name": "Bonaduz",
    "lat": "46.81103",
    "lng": "9.39821"
  },
  {
    "country": "CH",
    "name": "Boltigen",
    "lat": "46.62847",
    "lng": "7.39054"
  },
  {
    "country": "CH",
    "name": "Bolligen",
    "lat": "46.9751",
    "lng": "7.49697"
  },
  {
    "country": "CH",
    "name": "Bodio",
    "lat": "46.37808",
    "lng": "8.90991"
  },
  {
    "country": "CH",
    "name": "Blumenstein",
    "lat": "46.7421",
    "lng": "7.52136"
  },
  {
    "country": "CH",
    "name": "Blonay",
    "lat": "46.46778",
    "lng": "6.89615"
  },
  {
    "country": "CH",
    "name": "Birsfelden",
    "lat": "47.5529",
    "lng": "7.62322"
  },
  {
    "country": "CH",
    "name": "Birr",
    "lat": "47.43432",
    "lng": "8.20891"
  },
  {
    "country": "CH",
    "name": "Birmenstorf",
    "lat": "47.46152",
    "lng": "8.24816"
  },
  {
    "country": "CH",
    "name": "Birmensdorf",
    "lat": "47.35515",
    "lng": "8.44256"
  },
  {
    "country": "CH",
    "name": "Bioggio",
    "lat": "46.01357",
    "lng": "8.91103"
  },
  {
    "country": "CH",
    "name": "Binningen",
    "lat": "47.54021",
    "lng": "7.56932"
  },
  {
    "country": "CH",
    "name": "Bilten",
    "lat": "47.14995",
    "lng": "9.02551"
  },
  {
    "country": "CH",
    "name": "Biglen",
    "lat": "46.92629",
    "lng": "7.62508"
  },
  {
    "country": "CH",
    "name": "Bière",
    "lat": "46.53761",
    "lng": "6.33362"
  },
  {
    "country": "CH",
    "name": "Biel/Bienne",
    "lat": "47.13713",
    "lng": "7.24608"
  },
  {
    "country": "CH",
    "name": "Biberist",
    "lat": "47.18009",
    "lng": "7.56246"
  },
  {
    "country": "CH",
    "name": "Biasca",
    "lat": "46.35972",
    "lng": "8.96965"
  },
  {
    "country": "CH",
    "name": "Bex",
    "lat": "46.24965",
    "lng": "7.0098"
  },
  {
    "country": "CH",
    "name": "Bévilard",
    "lat": "47.23711",
    "lng": "7.28325"
  },
  {
    "country": "CH",
    "name": "Bevaix",
    "lat": "46.92958",
    "lng": "6.8147"
  },
  {
    "country": "CH",
    "name": "Bettlach",
    "lat": "47.20062",
    "lng": "7.42405"
  },
  {
    "country": "CH",
    "name": "Bettingen",
    "lat": "47.57039",
    "lng": "7.66425"
  },
  {
    "country": "CH",
    "name": "Beromünster",
    "lat": "47.20612",
    "lng": "8.19265"
  },
  {
    "country": "CH",
    "name": "Bernex",
    "lat": "46.1765",
    "lng": "6.07544"
  },
  {
    "country": "CH",
    "name": "Bern",
    "lat": "46.94809",
    "lng": "7.44744"
  },
  {
    "country": "CH",
    "name": "Beringen",
    "lat": "47.69763",
    "lng": "8.57431"
  },
  {
    "country": "CH",
    "name": "Berikon",
    "lat": "47.35155",
    "lng": "8.37232"
  },
  {
    "country": "CH",
    "name": "Berg",
    "lat": "47.57879",
    "lng": "9.16635"
  },
  {
    "country": "CH",
    "name": "Benken",
    "lat": "47.19942",
    "lng": "9.00735"
  },
  {
    "country": "CH",
    "name": "Belp",
    "lat": "46.89129",
    "lng": "7.49825"
  },
  {
    "country": "CH",
    "name": "Belmont-sur-Lausanne",
    "lat": "46.51891",
    "lng": "6.67636"
  },
  {
    "country": "CH",
    "name": "Bellmund",
    "lat": "47.10852",
    "lng": "7.24608"
  },
  {
    "country": "CH",
    "name": "Bellinzona",
    "lat": "46.19278",
    "lng": "9.01703"
  },
  {
    "country": "CH",
    "name": "Bellevue",
    "lat": "46.25739",
    "lng": "6.15475"
  },
  {
    "country": "CH",
    "name": "Belfaux",
    "lat": "46.82171",
    "lng": "7.10674"
  },
  {
    "country": "CH",
    "name": "Begnins",
    "lat": "46.44152",
    "lng": "6.24762"
  },
  {
    "country": "CH",
    "name": "Beckenried",
    "lat": "46.96653",
    "lng": "8.47575"
  },
  {
    "country": "CH",
    "name": "Beatenberg",
    "lat": "46.69896",
    "lng": "7.79428"
  },
  {
    "country": "CH",
    "name": "Bavois",
    "lat": "46.68403",
    "lng": "6.5671"
  },
  {
    "country": "CH",
    "name": "Bauma",
    "lat": "47.36745",
    "lng": "8.87905"
  },
  {
    "country": "CH",
    "name": "Bauen",
    "lat": "46.93559",
    "lng": "8.57836"
  },
  {
    "country": "CH",
    "name": "Bätterkinden",
    "lat": "47.13164",
    "lng": "7.53817"
  },
  {
    "country": "CH",
    "name": "Bassersdorf",
    "lat": "47.44342",
    "lng": "8.62851"
  },
  {
    "country": "CH",
    "name": "Basse-Nendaz",
    "lat": "46.18993",
    "lng": "7.31209"
  },
  {
    "country": "CH",
    "name": "Bassecourt",
    "lat": "47.33808",
    "lng": "7.24373"
  },
  {
    "country": "CH",
    "name": "Basel",
    "lat": "47.55839",
    "lng": "7.57327"
  },
  {
    "country": "CH",
    "name": "Bäriswil",
    "lat": "47.01947",
    "lng": "7.52709"
  },
  {
    "country": "CH",
    "name": "Bäretswil",
    "lat": "47.33709",
    "lng": "8.85645"
  },
  {
    "country": "CH",
    "name": "Baltschieder",
    "lat": "46.30888",
    "lng": "7.8657"
  },
  {
    "country": "CH",
    "name": "Balsthal",
    "lat": "47.31613",
    "lng": "7.69318"
  },
  {
    "country": "CH",
    "name": "Ballwil",
    "lat": "47.15371",
    "lng": "8.32233"
  },
  {
    "country": "CH",
    "name": "Ballens",
    "lat": "46.55485",
    "lng": "6.3731"
  },
  {
    "country": "CH",
    "name": "Balgach",
    "lat": "47.40556",
    "lng": "9.60702"
  },
  {
    "country": "CH",
    "name": "Balerna",
    "lat": "45.84638",
    "lng": "9.00724"
  },
  {
    "country": "CH",
    "name": "Bagnes",
    "lat": "46.08333",
    "lng": "7.21667"
  },
  {
    "country": "CH",
    "name": "Bad Ragaz",
    "lat": "47.00601",
    "lng": "9.50266"
  },
  {
    "country": "CH",
    "name": "Baden",
    "lat": "47.47333",
    "lng": "8.30592"
  },
  {
    "country": "CH",
    "name": "Bachenbülach",
    "lat": "47.50317",
    "lng": "8.54556"
  },
  {
    "country": "CH",
    "name": "Bäch",
    "lat": "47.20388",
    "lng": "8.73224"
  },
  {
    "country": "CH",
    "name": "Baar",
    "lat": "47.19625",
    "lng": "8.52954"
  },
  {
    "country": "CH",
    "name": "Ayent",
    "lat": "46.28249",
    "lng": "7.41028"
  },
  {
    "country": "CH",
    "name": "Avry-sur-Matran",
    "lat": "46.78753",
    "lng": "7.06735"
  },
  {
    "country": "CH",
    "name": "Avenches",
    "lat": "46.88004",
    "lng": "7.04071"
  },
  {
    "country": "CH",
    "name": "Auw",
    "lat": "47.21082",
    "lng": "8.36583"
  },
  {
    "country": "CH",
    "name": "Auvernier",
    "lat": "46.97545",
    "lng": "6.87903"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 4) / Aussersihl",
    "lat": "47.37752",
    "lng": "8.52127"
  },
  {
    "country": "CH",
    "name": "Aubonne",
    "lat": "46.49514",
    "lng": "6.39155"
  },
  {
    "country": "CH",
    "name": "Au",
    "lat": "47.43093",
    "lng": "9.63448"
  },
  {
    "country": "CH",
    "name": "Au",
    "lat": "47.24185",
    "lng": "8.64406"
  },
  {
    "country": "CH",
    "name": "Attiswil",
    "lat": "47.24673",
    "lng": "7.61353"
  },
  {
    "country": "CH",
    "name": "Attinghausen",
    "lat": "46.86255",
    "lng": "8.63036"
  },
  {
    "country": "CH",
    "name": "Attalens",
    "lat": "46.50555",
    "lng": "6.85039"
  },
  {
    "country": "CH",
    "name": "Ascona",
    "lat": "46.15451",
    "lng": "8.77327"
  },
  {
    "country": "CH",
    "name": "Arzo",
    "lat": "45.87606",
    "lng": "8.94103"
  },
  {
    "country": "CH",
    "name": "Arzier",
    "lat": "46.45962",
    "lng": "6.20813"
  },
  {
    "country": "CH",
    "name": "Arvigo",
    "lat": "46.30211",
    "lng": "9.113"
  },
  {
    "country": "CH",
    "name": "Arth",
    "lat": "47.06337",
    "lng": "8.52349"
  },
  {
    "country": "CH",
    "name": "Arosa",
    "lat": "46.77793",
    "lng": "9.67621"
  },
  {
    "country": "CH",
    "name": "Arlesheim",
    "lat": "47.49412",
    "lng": "7.61979"
  },
  {
    "country": "CH",
    "name": "Aristau",
    "lat": "47.28692",
    "lng": "8.36356"
  },
  {
    "country": "CH",
    "name": "Arisdorf",
    "lat": "47.51323",
    "lng": "7.76515"
  },
  {
    "country": "CH",
    "name": "Ardon",
    "lat": "46.20951",
    "lng": "7.26012"
  },
  {
    "country": "CH",
    "name": "Arch",
    "lat": "47.16533",
    "lng": "7.43139"
  },
  {
    "country": "CH",
    "name": "Arbon",
    "lat": "47.51667",
    "lng": "9.43333"
  },
  {
    "country": "CH",
    "name": "Apples",
    "lat": "46.55237",
    "lng": "6.42889"
  },
  {
    "country": "CH",
    "name": "Appenzell",
    "lat": "47.33103",
    "lng": "9.40996"
  },
  {
    "country": "CH",
    "name": "Anières",
    "lat": "46.27673",
    "lng": "6.22204"
  },
  {
    "country": "CH",
    "name": "Andwil",
    "lat": "47.43855",
    "lng": "9.27436"
  },
  {
    "country": "CH",
    "name": "Andermatt",
    "lat": "46.63565",
    "lng": "8.59388"
  },
  {
    "country": "CH",
    "name": "Amriswil",
    "lat": "47.54699",
    "lng": "9.29586"
  },
  {
    "country": "CH",
    "name": "Amden",
    "lat": "47.14888",
    "lng": "9.14233"
  },
  {
    "country": "CH",
    "name": "Altstätten",
    "lat": "47.37766",
    "lng": "9.54746"
  },
  {
    "country": "CH",
    "name": "Altnau",
    "lat": "47.61052",
    "lng": "9.2616"
  },
  {
    "country": "CH",
    "name": "Altishofen",
    "lat": "47.19916",
    "lng": "7.96964"
  },
  {
    "country": "CH",
    "name": "Alterswil",
    "lat": "46.79587",
    "lng": "7.25877"
  },
  {
    "country": "CH",
    "name": "Altendorf",
    "lat": "47.18994",
    "lng": "8.83823"
  },
  {
    "country": "CH",
    "name": "Altdorf",
    "lat": "46.88042",
    "lng": "8.64441"
  },
  {
    "country": "CH",
    "name": "Alpnach",
    "lat": "46.94227",
    "lng": "8.2718"
  },
  {
    "country": "CH",
    "name": "Allschwil",
    "lat": "47.55074",
    "lng": "7.53599"
  },
  {
    "country": "CH",
    "name": "Alle",
    "lat": "47.42542",
    "lng": "7.13018"
  },
  {
    "country": "CH",
    "name": "Airolo",
    "lat": "46.52855",
    "lng": "8.61189"
  },
  {
    "country": "CH",
    "name": "Aigle",
    "lat": "46.3181",
    "lng": "6.96457"
  },
  {
    "country": "CH",
    "name": "Agno",
    "lat": "45.99863",
    "lng": "8.9003"
  },
  {
    "country": "CH",
    "name": "Affoltern am Albis",
    "lat": "47.27743",
    "lng": "8.45128"
  },
  {
    "country": "CH",
    "name": "Affeltrangen",
    "lat": "47.52581",
    "lng": "9.03307"
  },
  {
    "country": "CH",
    "name": "Aeschi b. Spiez",
    "lat": "46.65848",
    "lng": "7.6965"
  },
  {
    "country": "CH",
    "name": "Aesch",
    "lat": "47.47104",
    "lng": "7.5973"
  },
  {
    "country": "CH",
    "name": "Adliswil",
    "lat": "47.30997",
    "lng": "8.52462"
  },
  {
    "country": "CH",
    "name": "Adligenswil",
    "lat": "47.06521",
    "lng": "8.36124"
  },
  {
    "country": "CH",
    "name": "Adelboden",
    "lat": "46.49142",
    "lng": "7.56031"
  },
  {
    "country": "CH",
    "name": "Acquarossa",
    "lat": "46.45473",
    "lng": "8.94261"
  },
  {
    "country": "CH",
    "name": "Aarwangen",
    "lat": "47.23845",
    "lng": "7.76854"
  },
  {
    "country": "CH",
    "name": "Aarburg",
    "lat": "47.32067",
    "lng": "7.89986"
  },
  {
    "country": "CH",
    "name": "Aarberg",
    "lat": "47.04439",
    "lng": "7.27578"
  },
  {
    "country": "CH",
    "name": "Aarau",
    "lat": "47.39254",
    "lng": "8.04422"
  },
  {
    "country": "CH",
    "name": "Aadorf",
    "lat": "47.49204",
    "lng": "8.90099"
  },
  {
    "country": "CH",
    "name": "Riehen",
    "lat": "47.57884",
    "lng": "7.64683"
  },
  {
    "country": "CH",
    "name": "Chêne-Bougeries",
    "lat": "46.19843",
    "lng": "6.18642"
  },
  {
    "country": "CH",
    "name": "Meinier",
    "lat": "46.24706",
    "lng": "6.23423"
  },
  {
    "country": "CH",
    "name": "Puplinge",
    "lat": "46.21043",
    "lng": "6.23114"
  },
  {
    "country": "CH",
    "name": "Thônex",
    "lat": "46.18815",
    "lng": "6.19904"
  },
  {
    "country": "CH",
    "name": "Wettswil / Wettswil (Dorf)",
    "lat": "47.34152",
    "lng": "8.47149"
  },
  {
    "country": "CH",
    "name": "Sellenbüren",
    "lat": "47.34361",
    "lng": "8.48301"
  },
  {
    "country": "CH",
    "name": "Itingen",
    "lat": "47.46651",
    "lng": "7.78502"
  },
  {
    "country": "CH",
    "name": "Ecublens",
    "lat": "46.52899",
    "lng": "6.56261"
  },
  {
    "country": "CH",
    "name": "Affoltern / Hasenbüel",
    "lat": "47.27324",
    "lng": "8.45218"
  },
  {
    "country": "CH",
    "name": "Affoltern / Oberdorf",
    "lat": "47.27852",
    "lng": "8.45651"
  },
  {
    "country": "CH",
    "name": "Affoltern / Unterdorf",
    "lat": "47.28277",
    "lng": "8.45409"
  },
  {
    "country": "CH",
    "name": "Affoltern / Sonnenberg",
    "lat": "47.28055",
    "lng": "8.46008"
  },
  {
    "country": "CH",
    "name": "Schachen",
    "lat": "47.32419",
    "lng": "8.47251"
  },
  {
    "country": "CH",
    "name": "Hedingen",
    "lat": "47.29794",
    "lng": "8.44833"
  },
  {
    "country": "CH",
    "name": "Obfelden / Oberlunnern",
    "lat": "47.26197",
    "lng": "8.41588"
  },
  {
    "country": "CH",
    "name": "Obfelden / Toussen",
    "lat": "47.26574",
    "lng": "8.43013"
  },
  {
    "country": "CH",
    "name": "Wettswil / Ausser-Dorf",
    "lat": "47.33197",
    "lng": "8.47732"
  },
  {
    "country": "CH",
    "name": "Kleinandelfingen",
    "lat": "47.60058",
    "lng": "8.68362"
  },
  {
    "country": "CH",
    "name": "Bülach / Soligänter",
    "lat": "47.52632",
    "lng": "8.54106"
  },
  {
    "country": "CH",
    "name": "Bülach / Gstückt",
    "lat": "47.52337",
    "lng": "8.54879"
  },
  {
    "country": "CH",
    "name": "Bülach / Seematt",
    "lat": "47.51716",
    "lng": "8.54651"
  },
  {
    "country": "CH",
    "name": "Dietlikon / Eichwiesen",
    "lat": "47.4191",
    "lng": "8.62078"
  },
  {
    "country": "CH",
    "name": "Embrach / Embrach (Dorfkern)",
    "lat": "47.504",
    "lng": "8.59477"
  },
  {
    "country": "CH",
    "name": "Embrach / Kellersacker",
    "lat": "47.51455",
    "lng": "8.59146"
  },
  {
    "country": "CH",
    "name": "Freienstein",
    "lat": "47.53307",
    "lng": "8.58455"
  },
  {
    "country": "CH",
    "name": "Hochfelden",
    "lat": "47.52262",
    "lng": "8.51564"
  },
  {
    "country": "CH",
    "name": "Höri",
    "lat": "47.50799",
    "lng": "8.51203"
  },
  {
    "country": "CH",
    "name": "Kloten / Kloten (Zentrum)",
    "lat": "47.45134",
    "lng": "8.58683"
  },
  {
    "country": "CH",
    "name": "Kloten / Freienberg (Chanzler-Chlini Chaseren)",
    "lat": "47.46584",
    "lng": "8.58145"
  },
  {
    "country": "CH",
    "name": "Kloten / Horainli",
    "lat": "47.45399",
    "lng": "8.58306"
  },
  {
    "country": "CH",
    "name": "Kloten / Geissberg",
    "lat": "47.45424",
    "lng": "8.59066"
  },
  {
    "country": "CH",
    "name": "Kloten / Hostrass",
    "lat": "47.45255",
    "lng": "8.59464"
  },
  {
    "country": "CH",
    "name": "Kloten / Holberg",
    "lat": "47.44642",
    "lng": "8.57661"
  },
  {
    "country": "CH",
    "name": "Kloten / Balsberg",
    "lat": "47.44233",
    "lng": "8.57496"
  },
  {
    "country": "CH",
    "name": "Kloten / Spitz",
    "lat": "47.44455",
    "lng": "8.58724"
  },
  {
    "country": "CH",
    "name": "Kloten / Rütlen",
    "lat": "47.44726",
    "lng": "8.58808"
  },
  {
    "country": "CH",
    "name": "Birchwil",
    "lat": "47.45431",
    "lng": "8.63477"
  },
  {
    "country": "CH",
    "name": "Glattbrugg / Wydacker/Bettacker/Lättenwiesen",
    "lat": "47.42908",
    "lng": "8.56657"
  },
  {
    "country": "CH",
    "name": "Grossacker/Opfikon",
    "lat": "47.42696",
    "lng": "8.57886"
  },
  {
    "country": "CH",
    "name": "Glattbrugg / Rohr/Platten-Balsberg",
    "lat": "47.43721",
    "lng": "8.56642"
  },
  {
    "country": "CH",
    "name": "Wallisellen / Wallisellen-West",
    "lat": "47.41906",
    "lng": "8.58586"
  },
  {
    "country": "CH",
    "name": "Wallisellen / Wallisellen-Ost",
    "lat": "47.41446",
    "lng": "8.59727"
  },
  {
    "country": "CH",
    "name": "Wallisellen / Rieden",
    "lat": "47.41738",
    "lng": "8.60028"
  },
  {
    "country": "CH",
    "name": "Dällikon / Dällikon (Dorf)",
    "lat": "47.43983",
    "lng": "8.43813"
  },
  {
    "country": "CH",
    "name": "Neerach",
    "lat": "47.51096",
    "lng": "8.47099"
  },
  {
    "country": "CH",
    "name": "Niederglatt / Niederglatt (Dorfkern)",
    "lat": "47.49065",
    "lng": "8.50048"
  },
  {
    "country": "CH",
    "name": "Niederhasli",
    "lat": "47.48012",
    "lng": "8.48576"
  },
  {
    "country": "CH",
    "name": "Oberglatt / Oberglatt (Dorfkern)",
    "lat": "47.47596",
    "lng": "8.51929"
  },
  {
    "country": "CH",
    "name": "Oberglatt / Bahnhofquartier",
    "lat": "47.47143",
    "lng": "8.51289"
  },
  {
    "country": "CH",
    "name": "Hofstetten",
    "lat": "47.47778",
    "lng": "8.50646"
  },
  {
    "country": "CH",
    "name": "Sonnhalde",
    "lat": "47.45329",
    "lng": "8.46091"
  },
  {
    "country": "CH",
    "name": "Regensdorf / Hofacher-Geeren",
    "lat": "47.43525",
    "lng": "8.4624"
  },
  {
    "country": "CH",
    "name": "Regensdorf / Feldblumen-Riedthofstrasse",
    "lat": "47.43618",
    "lng": "8.46659"
  },
  {
    "country": "CH",
    "name": "Regensdorf / Obstgarten",
    "lat": "47.42772",
    "lng": "8.46566"
  },
  {
    "country": "CH",
    "name": "Rümlang / Rümlang (Dorfkern)",
    "lat": "47.4494",
    "lng": "8.53255"
  },
  {
    "country": "CH",
    "name": "Tann / Tann (Dorfkern)",
    "lat": "47.26494",
    "lng": "8.85048"
  },
  {
    "country": "CH",
    "name": "Grüt",
    "lat": "47.31151",
    "lng": "8.78339"
  },
  {
    "country": "CH",
    "name": "Binzikon",
    "lat": "47.27632",
    "lng": "8.75851"
  },
  {
    "country": "CH",
    "name": "Hadlikon",
    "lat": "47.2875",
    "lng": "8.85719"
  },
  {
    "country": "CH",
    "name": "Rüti / Westlicher Dorfteil",
    "lat": "47.25548",
    "lng": "8.8449"
  },
  {
    "country": "CH",
    "name": "Rüti / Dorfzentrum, Südl. Teil",
    "lat": "47.25368",
    "lng": "8.85654"
  },
  {
    "country": "CH",
    "name": "Rüti / Oberdorf",
    "lat": "47.25894",
    "lng": "8.86512"
  },
  {
    "country": "CH",
    "name": "Wetzikon / Robenhausen",
    "lat": "47.33089",
    "lng": "8.78762"
  },
  {
    "country": "CH",
    "name": "Wetzikon / Kempten",
    "lat": "47.33319",
    "lng": "8.80982"
  },
  {
    "country": "CH",
    "name": "Adliswil / Adliswil (Stadtkern)",
    "lat": "47.31128",
    "lng": "8.52675"
  },
  {
    "country": "CH",
    "name": "Adliswil / Oberleimbach",
    "lat": "47.3202",
    "lng": "8.51508"
  },
  {
    "country": "CH",
    "name": "Adliswil / Sood",
    "lat": "47.3187",
    "lng": "8.52425"
  },
  {
    "country": "CH",
    "name": "Adliswil / Hündli-Zopf",
    "lat": "47.31637",
    "lng": "8.51888"
  },
  {
    "country": "CH",
    "name": "Adliswil / Sonnenberg",
    "lat": "47.30958",
    "lng": "8.52055"
  },
  {
    "country": "CH",
    "name": "Adliswil / Tal",
    "lat": "47.31142",
    "lng": "8.53446"
  },
  {
    "country": "CH",
    "name": "Hirzel",
    "lat": "47.21743",
    "lng": "8.60794"
  },
  {
    "country": "CH",
    "name": "Horgen / Horgen (Dorfkern)",
    "lat": "47.25604",
    "lng": "8.60159"
  },
  {
    "country": "CH",
    "name": "Horgen / Allmend",
    "lat": "47.24729",
    "lng": "8.6066"
  },
  {
    "country": "CH",
    "name": "Horgen / Scheller-Stockerstrasse",
    "lat": "47.26584",
    "lng": "8.5876"
  },
  {
    "country": "CH",
    "name": "Horgen / Oberdorf",
    "lat": "47.25837",
    "lng": "8.59013"
  },
  {
    "country": "CH",
    "name": "Kilchberg / Bächler-Stocken",
    "lat": "47.32728",
    "lng": "8.53957"
  },
  {
    "country": "CH",
    "name": "Kilchberg / Kilchberg (Dorfkern)",
    "lat": "47.32012",
    "lng": "8.54306"
  },
  {
    "country": "CH",
    "name": "Langnau / Vitaquartier",
    "lat": "47.29377",
    "lng": "8.53758"
  },
  {
    "country": "CH",
    "name": "Mühlehalde",
    "lat": "47.28306",
    "lng": "8.53386"
  },
  {
    "country": "CH",
    "name": "Oberrieden / Mitte",
    "lat": "47.27242",
    "lng": "8.58021"
  },
  {
    "country": "CH",
    "name": "Oberrieden / Berg",
    "lat": "47.27628",
    "lng": "8.57257"
  },
  {
    "country": "CH",
    "name": "Richterswil / Dorfkern",
    "lat": "47.20715",
    "lng": "8.70607"
  },
  {
    "country": "CH",
    "name": "Richterswil / Richterswil (Dorfkern)",
    "lat": "47.20323",
    "lng": "8.70516"
  },
  {
    "country": "CH",
    "name": "Richterswil / Burghalde",
    "lat": "47.20973",
    "lng": "8.69133"
  },
  {
    "country": "CH",
    "name": "Thalwil / Dorfkern",
    "lat": "47.29047",
    "lng": "8.56633"
  },
  {
    "country": "CH",
    "name": "Thalwil / Berg",
    "lat": "47.29178",
    "lng": "8.55602"
  },
  {
    "country": "CH",
    "name": "Thalwil / Nord",
    "lat": "47.29748",
    "lng": "8.55634"
  },
  {
    "country": "CH",
    "name": "Thalwil / Süd",
    "lat": "47.28495",
    "lng": "8.56954"
  },
  {
    "country": "CH",
    "name": "Gattikon",
    "lat": "47.28439",
    "lng": "8.5483"
  },
  {
    "country": "CH",
    "name": "Wädenswil / Dorf (Wädenswil)",
    "lat": "47.22923",
    "lng": "8.6722"
  },
  {
    "country": "CH",
    "name": "Au / Unter-Dorf",
    "lat": "47.2473",
    "lng": "8.6327"
  },
  {
    "country": "CH",
    "name": "Au / Mittel-Dorf",
    "lat": "47.24303",
    "lng": "8.64591"
  },
  {
    "country": "CH",
    "name": "Wädenswil / Hangenmoos",
    "lat": "47.23367",
    "lng": "8.65251"
  },
  {
    "country": "CH",
    "name": "Wädenswil / Büelen",
    "lat": "47.23395",
    "lng": "8.66346"
  },
  {
    "country": "CH",
    "name": "Wädenswil / Untermosen-Fuhr",
    "lat": "47.22772",
    "lng": "8.66303"
  },
  {
    "country": "CH",
    "name": "Wädenswil / Leihof-Mühlebach",
    "lat": "47.22364",
    "lng": "8.67149"
  },
  {
    "country": "CH",
    "name": "Wädenswil / Eichweid",
    "lat": "47.21847",
    "lng": "8.6744"
  },
  {
    "country": "CH",
    "name": "Wädenswil / Boller-Giessen",
    "lat": "47.22115",
    "lng": "8.68385"
  },
  {
    "country": "CH",
    "name": "Erlenbach / rechts des Dorfbachs oberhalb Bahnlinie",
    "lat": "47.30658",
    "lng": "8.60271"
  },
  {
    "country": "CH",
    "name": "Erlenbach / links des Dorfbachs oberhalb Bahnlinie",
    "lat": "47.2995",
    "lng": "8.60188"
  },
  {
    "country": "CH",
    "name": "Küsnacht / Dorf",
    "lat": "47.31783",
    "lng": "8.58303"
  },
  {
    "country": "CH",
    "name": "Küsnacht / Goldbach",
    "lat": "47.32729",
    "lng": "8.58077"
  },
  {
    "country": "CH",
    "name": "Küsnacht / Itschnach",
    "lat": "47.32714",
    "lng": "8.60068"
  },
  {
    "country": "CH",
    "name": "Küsnacht / Schiedhalden",
    "lat": "47.32112",
    "lng": "8.58881"
  },
  {
    "country": "CH",
    "name": "Küsnacht / Heslibach",
    "lat": "47.31307",
    "lng": "8.58849"
  },
  {
    "country": "CH",
    "name": "Männedorf / Dorfkern",
    "lat": "47.25612",
    "lng": "8.69161"
  },
  {
    "country": "CH",
    "name": "Männedorf / Ausserfeld",
    "lat": "47.24636",
    "lng": "8.70608"
  },
  {
    "country": "CH",
    "name": "Dorf",
    "lat": "47.239",
    "lng": "8.73567"
  },
  {
    "country": "CH",
    "name": "Uetikon / Grossdorf",
    "lat": "47.26654",
    "lng": "8.67765"
  },
  {
    "country": "CH",
    "name": "Zollikerberg",
    "lat": "47.3451",
    "lng": "8.60088"
  },
  {
    "country": "CH",
    "name": "Effretikon / Watt",
    "lat": "47.42797",
    "lng": "8.69822"
  },
  {
    "country": "CH",
    "name": "Effretikon / Rappenhalde-Bannhalde",
    "lat": "47.42388",
    "lng": "8.69653"
  },
  {
    "country": "CH",
    "name": "Tagelswangen",
    "lat": "47.4307",
    "lng": "8.67284"
  },
  {
    "country": "CH",
    "name": "Pfäffikon / Pfäffikon (Dorfkern)",
    "lat": "47.36943",
    "lng": "8.78309"
  },
  {
    "country": "CH",
    "name": "Dübendorf / Vogelquartier",
    "lat": "47.39502",
    "lng": "8.61184"
  },
  {
    "country": "CH",
    "name": "Dübendorf / Wasserfurren",
    "lat": "47.39352",
    "lng": "8.6085"
  },
  {
    "country": "CH",
    "name": "Dübendorf / Sonnenberg",
    "lat": "47.39469",
    "lng": "8.63162"
  },
  {
    "country": "CH",
    "name": "Dübendorf / Kunklerstrasse",
    "lat": "47.40109",
    "lng": "8.62724"
  },
  {
    "country": "CH",
    "name": "Hinteregg",
    "lat": "47.30736",
    "lng": "8.68339"
  },
  {
    "country": "CH",
    "name": "Esslingen",
    "lat": "47.28325",
    "lng": "8.71038"
  },
  {
    "country": "CH",
    "name": "Benglen",
    "lat": "47.36077",
    "lng": "8.63687"
  },
  {
    "country": "CH",
    "name": "Greifensee / Müllerwis / Seilerwis",
    "lat": "47.37042",
    "lng": "8.68151"
  },
  {
    "country": "CH",
    "name": "Greifensee / Pfisterhölzli",
    "lat": "47.3643",
    "lng": "8.68979"
  },
  {
    "country": "CH",
    "name": "Aesch",
    "lat": "47.3297",
    "lng": "8.6541"
  },
  {
    "country": "CH",
    "name": "Binz",
    "lat": "47.35635",
    "lng": "8.62657"
  },
  {
    "country": "CH",
    "name": "Mönchaltorf / Dorf",
    "lat": "47.30401",
    "lng": "8.72211"
  },
  {
    "country": "CH",
    "name": "Schwerzenbach / Chimli",
    "lat": "47.38592",
    "lng": "8.65888"
  },
  {
    "country": "CH",
    "name": "Schwerzenbach / Blatten",
    "lat": "47.38308",
    "lng": "8.64954"
  },
  {
    "country": "CH",
    "name": "Uster / Kirch-Uster",
    "lat": "47.34579",
    "lng": "8.71839"
  },
  {
    "country": "CH",
    "name": "Uster / Nieder-Uster",
    "lat": "47.34743",
    "lng": "8.70088"
  },
  {
    "country": "CH",
    "name": "Uster / Gschwader",
    "lat": "47.36016",
    "lng": "8.7139"
  },
  {
    "country": "CH",
    "name": "Uster / Ober-Uster",
    "lat": "47.34874",
    "lng": "8.73319"
  },
  {
    "country": "CH",
    "name": "Uster / Nossikon",
    "lat": "47.34088",
    "lng": "8.72555"
  },
  {
    "country": "CH",
    "name": "Nänikon / Nänikon (Dorfkern)",
    "lat": "47.37099",
    "lng": "8.69254"
  },
  {
    "country": "CH",
    "name": "Kindhausen / Kindhausen (Dorf)",
    "lat": "47.40644",
    "lng": "8.68296"
  },
  {
    "country": "CH",
    "name": "Hegnau / Sunnebüel-Eich",
    "lat": "47.39246",
    "lng": "8.6791"
  },
  {
    "country": "CH",
    "name": "Hegnau / Dammboden-Grindel",
    "lat": "47.38713",
    "lng": "8.66657"
  },
  {
    "country": "CH",
    "name": "Gutenswil",
    "lat": "47.38387",
    "lng": "8.71763"
  },
  {
    "country": "CH",
    "name": "Wangen",
    "lat": "47.41182",
    "lng": "8.64516"
  },
  {
    "country": "CH",
    "name": "Elgg / Städtchen und Umgebung",
    "lat": "47.49265",
    "lng": "8.8668"
  },
  {
    "country": "CH",
    "name": "Seuzach Dorf / Breite-Weid",
    "lat": "47.53345",
    "lng": "8.73415"
  },
  {
    "country": "CH",
    "name": "Stadt Winterthur (Kreis 1) / Altstadt",
    "lat": "47.49951",
    "lng": "8.72872"
  },
  {
    "country": "CH",
    "name": "Stadt Winterthur (Kreis 1) / Lind",
    "lat": "47.50571",
    "lng": "8.73372"
  },
  {
    "country": "CH",
    "name": "Stadt Winterthur (Kreis 1) / Heiligberg",
    "lat": "47.49409",
    "lng": "8.72334"
  },
  {
    "country": "CH",
    "name": "Stadt Winterthur (Kreis 1) / Tössfeld",
    "lat": "47.4934",
    "lng": "8.71512"
  },
  {
    "country": "CH",
    "name": "Stadt Winterthur (Kreis 1) / Brühlberg",
    "lat": "47.49764",
    "lng": "8.71272"
  },
  {
    "country": "CH",
    "name": "Stadt Winterthur (Kreis 1) / Neuwiesen",
    "lat": "47.50207",
    "lng": "8.71625"
  },
  {
    "country": "CH",
    "name": "Oberwinterthur (Kreis 2) / Talacker",
    "lat": "47.50596",
    "lng": "8.7515"
  },
  {
    "country": "CH",
    "name": "Oberwinterthur (Kreis 2) / Guggenbühl",
    "lat": "47.51339",
    "lng": "8.75998"
  },
  {
    "country": "CH",
    "name": "Oberwinterthur (Kreis 2) / Zinzikon",
    "lat": "47.5195",
    "lng": "8.7564"
  },
  {
    "country": "CH",
    "name": "Seen (Kreis 3) / Waser",
    "lat": "47.48913",
    "lng": "8.76034"
  },
  {
    "country": "CH",
    "name": "Seen (Kreis 3) / Büelwiesen",
    "lat": "47.48446",
    "lng": "8.76517"
  },
  {
    "country": "CH",
    "name": "Seen (Kreis 3) / Waldegg",
    "lat": "47.48393",
    "lng": "8.75586"
  },
  {
    "country": "CH",
    "name": "Seen (Kreis 3) / Ganzenbühl",
    "lat": "47.481",
    "lng": "8.76249"
  },
  {
    "country": "CH",
    "name": "Seen (Kreis 3) / Oberseen",
    "lat": "47.48205",
    "lng": "8.77289"
  },
  {
    "country": "CH",
    "name": "Töss (Kreis 4) / Vorder-Dättnau",
    "lat": "47.48135",
    "lng": "8.69855"
  },
  {
    "country": "CH",
    "name": "Töss (Kreis 4) / Schlosstal",
    "lat": "47.49279",
    "lng": "8.70223"
  },
  {
    "country": "CH",
    "name": "Töss (Kreis 4) / Eichliacker",
    "lat": "47.48727",
    "lng": "8.7074"
  },
  {
    "country": "CH",
    "name": "Veltheim (Kreis 5) / Rosenberg",
    "lat": "47.51386",
    "lng": "8.71583"
  },
  {
    "country": "CH",
    "name": "Veltheim (Kreis 5) / Blumenau",
    "lat": "47.50618",
    "lng": "8.71563"
  },
  {
    "country": "CH",
    "name": "Wülflingen (Kreis 6) / Oberfeld",
    "lat": "47.49873",
    "lng": "8.69897"
  },
  {
    "country": "CH",
    "name": "Wülflingen (Kreis 6) / Lindenplatz",
    "lat": "47.51098",
    "lng": "8.6929"
  },
  {
    "country": "CH",
    "name": "Wülflingen (Kreis 6) / Niederfeld",
    "lat": "47.50904",
    "lng": "8.67968"
  },
  {
    "country": "CH",
    "name": "Wülflingen (Kreis 6) / Härti",
    "lat": "47.51262",
    "lng": "8.684"
  },
  {
    "country": "CH",
    "name": "Mattenbach (Kreis 7) / Deutweg",
    "lat": "47.49419",
    "lng": "8.73948"
  },
  {
    "country": "CH",
    "name": "Mattenbach (Kreis 7) / Gutschick",
    "lat": "47.49104",
    "lng": "8.75258"
  },
  {
    "country": "CH",
    "name": "Mattenbach (Kreis 7) / Endliker",
    "lat": "47.48821",
    "lng": "8.74938"
  },
  {
    "country": "CH",
    "name": "Kollbrunn / Kollbrunn (Dorfkern)",
    "lat": "47.45748",
    "lng": "8.77413"
  },
  {
    "country": "CH",
    "name": "Dietikon / Vorstadt",
    "lat": "47.40819",
    "lng": "8.39719"
  },
  {
    "country": "CH",
    "name": "Dietikon / Almend",
    "lat": "47.40477",
    "lng": "8.39168"
  },
  {
    "country": "CH",
    "name": "Dietikon / Oberdorf",
    "lat": "47.40065",
    "lng": "8.39416"
  },
  {
    "country": "CH",
    "name": "Dietikon / Kreuzacker",
    "lat": "47.39919",
    "lng": "8.40146"
  },
  {
    "country": "CH",
    "name": "Dietikon / Guggenbühl",
    "lat": "47.40009",
    "lng": "8.40818"
  },
  {
    "country": "CH",
    "name": "Dietikon / Hofacker",
    "lat": "47.39718",
    "lng": "8.41609"
  },
  {
    "country": "CH",
    "name": "Dietikon / Schönenwerd",
    "lat": "47.39706",
    "lng": "8.42576"
  },
  {
    "country": "CH",
    "name": "Oberengstringen / Zentrum",
    "lat": "47.40711",
    "lng": "8.46276"
  },
  {
    "country": "CH",
    "name": "Oberengstringen / Sonnenberg",
    "lat": "47.41211",
    "lng": "8.46055"
  },
  {
    "country": "CH",
    "name": "Oberengstringen / Rauchacher",
    "lat": "47.40919",
    "lng": "8.45627"
  },
  {
    "country": "CH",
    "name": "Schlieren / Zentrum",
    "lat": "47.39779",
    "lng": "8.4477"
  },
  {
    "country": "CH",
    "name": "Schlieren / Engstingerquartier",
    "lat": "47.40338",
    "lng": "8.44352"
  },
  {
    "country": "CH",
    "name": "Schlieren / Spital",
    "lat": "47.39489",
    "lng": "8.43027"
  },
  {
    "country": "CH",
    "name": "Schlieren / Freiestrasse",
    "lat": "47.39598",
    "lng": "8.44202"
  },
  {
    "country": "CH",
    "name": "Schlieren / Kamp",
    "lat": "47.39358",
    "lng": "8.44453"
  },
  {
    "country": "CH",
    "name": "Schlieren / Boden",
    "lat": "47.39721",
    "lng": "8.45734"
  },
  {
    "country": "CH",
    "name": "Urdorf / Bodenfeld",
    "lat": "47.3892",
    "lng": "8.42265"
  },
  {
    "country": "CH",
    "name": "Urdorf / Moos",
    "lat": "47.38977",
    "lng": "8.42886"
  },
  {
    "country": "CH",
    "name": "Urdorf / Oberurdorf",
    "lat": "47.38072",
    "lng": "8.42343"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 12) / Auzelg",
    "lat": "47.41511",
    "lng": "8.57014"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 11) / Schwandenholz",
    "lat": "47.42476",
    "lng": "8.52125"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 2) / Mittel-Leimbach",
    "lat": "47.32538",
    "lng": "8.51391"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 2) / Unter-Leimbach",
    "lat": "47.33362",
    "lng": "8.51433"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 10) / Wipkingen",
    "lat": "47.39503",
    "lng": "8.52529"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 10) / Rütihof",
    "lat": "47.41444",
    "lng": "8.47928"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 1) / Rathaus",
    "lat": "47.37161",
    "lng": "8.54501"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 11) / Affoltern",
    "lat": "47.41814",
    "lng": "8.5122"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 12) / Saatlen",
    "lat": "47.41127",
    "lng": "8.5648"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 12) / Schwamendingen-Mitte",
    "lat": "47.4063",
    "lng": "8.57242"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 12) / Hirzenbach",
    "lat": "47.40187",
    "lng": "8.58633"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 1) / Lindenhof",
    "lat": "47.37188",
    "lng": "8.54036"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 1) / City",
    "lat": "47.37269",
    "lng": "8.53576"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 2) / Wollishofen",
    "lat": "47.3401",
    "lng": "8.53134"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 2) / Enge",
    "lat": "47.3605",
    "lng": "8.53127"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 3) / Friesenberg",
    "lat": "47.36372",
    "lng": "8.50417"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 3) / Sihlfeld",
    "lat": "47.37382",
    "lng": "8.51164"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 4) / Werd",
    "lat": "47.37178",
    "lng": "8.52584"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 4) / Langstrasse",
    "lat": "47.37767",
    "lng": "8.52854"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 4) / Hard",
    "lat": "47.38311",
    "lng": "8.50942"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 5) / Gewerbeschule",
    "lat": "47.38481",
    "lng": "8.53011"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 5) / Escher-Wyss",
    "lat": "47.39052",
    "lng": "8.51292"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 6) / Unterstrass",
    "lat": "47.3953",
    "lng": "8.53721"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 6) / Oberstrass",
    "lat": "47.38917",
    "lng": "8.5504"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 7) / Fluntern",
    "lat": "47.38013",
    "lng": "8.56133"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 7) / Hottingen",
    "lat": "47.37011",
    "lng": "8.56306"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 7) / Hirslanden",
    "lat": "47.3624",
    "lng": "8.56755"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 8) / Seefeld",
    "lat": "47.35462",
    "lng": "8.55537"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 8) / Mühlebach",
    "lat": "47.35727",
    "lng": "8.55744"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 8) / Weinegg",
    "lat": "47.3525",
    "lng": "8.57011"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 9) / Albisrieden",
    "lat": "47.37398",
    "lng": "8.49007"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 9) / Altstetten",
    "lat": "47.38946",
    "lng": "8.48533"
  },
  {
    "country": "CH",
    "name": "Schwerzenbach",
    "lat": "47.38213",
    "lng": "8.65727"
  },
  {
    "country": "CH",
    "name": "Steinmaur",
    "lat": "47.4971",
    "lng": "8.45216"
  },
  {
    "country": "CH",
    "name": "Hegnau",
    "lat": "47.39227",
    "lng": "8.66988"
  },
  {
    "country": "CH",
    "name": "Gockhausen",
    "lat": "47.38098",
    "lng": "8.59978"
  },
  {
    "country": "CH",
    "name": "Stadt Winterthur (Kreis 1)",
    "lat": "47.49494",
    "lng": "8.71954"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 5)",
    "lat": "47.38767",
    "lng": "8.52152"
  },
  {
    "country": "CH",
    "name": "Dänikon",
    "lat": "47.44674",
    "lng": "8.40648"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 12)",
    "lat": "47.40372",
    "lng": "8.57608"
  },
  {
    "country": "CH",
    "name": "Wülflingen (Kreis 6)",
    "lat": "47.51036",
    "lng": "8.68333"
  },
  {
    "country": "CH",
    "name": "Sulz",
    "lat": "47.53954",
    "lng": "8.78887"
  },
  {
    "country": "CH",
    "name": "Seglingen",
    "lat": "47.57244",
    "lng": "8.52093"
  },
  {
    "country": "CH",
    "name": "Niederglatt",
    "lat": "47.49066",
    "lng": "8.49987"
  },
  {
    "country": "CH",
    "name": "Ebmatingen",
    "lat": "47.34987",
    "lng": "8.64013"
  },
  {
    "country": "CH",
    "name": "Seen (Kreis 3)",
    "lat": "47.47646",
    "lng": "8.76996"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 3)",
    "lat": "47.35785",
    "lng": "8.50296"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 11)",
    "lat": "47.42326",
    "lng": "8.52166"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 9)",
    "lat": "47.38245",
    "lng": "8.47993"
  },
  {
    "country": "CH",
    "name": "Oberwinterthur (Kreis 2)",
    "lat": "47.51692",
    "lng": "8.76863"
  },
  {
    "country": "CH",
    "name": "Geroldswil",
    "lat": "47.42213",
    "lng": "8.41085"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 10)",
    "lat": "47.40773",
    "lng": "8.5005"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 2)",
    "lat": "47.33756",
    "lng": "8.5211"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 8)",
    "lat": "47.3548",
    "lng": "8.56097"
  },
  {
    "country": "CH",
    "name": "Wolfhausen",
    "lat": "47.25619",
    "lng": "8.7991"
  },
  {
    "country": "CH",
    "name": "Seuzach Dorf",
    "lat": "47.5356",
    "lng": "8.73209"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 1)",
    "lat": "47.37055",
    "lng": "8.54177"
  },
  {
    "country": "CH",
    "name": "Mattenbach (Kreis 7)",
    "lat": "47.48705",
    "lng": "8.74681"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 7)",
    "lat": "47.37328",
    "lng": "8.58038"
  },
  {
    "country": "CH",
    "name": "Obermeilen",
    "lat": "47.26574",
    "lng": "8.65567"
  },
  {
    "country": "CH",
    "name": "Zürich (Kreis 6)",
    "lat": "47.39223",
    "lng": "8.54381"
  },
  {
    "country": "CH",
    "name": "Elsau-Räterschen",
    "lat": "47.50238",
    "lng": "8.79874"
  },
  {
    "country": "CH",
    "name": "Thalwil / See",
    "lat": "47.29409",
    "lng": "8.56929"
  },
  {
    "country": "CH",
    "name": "Thal",
    "lat": "47.46677",
    "lng": "9.56643"
  },
  {
    "country": "CH",
    "name": "Préverenges",
    "lat": "46.51854",
    "lng": "6.52682"
  },
  {
    "country": "CH",
    "name": "Langnau am Albis",
    "lat": "47.28885",
    "lng": "8.5411"
  },
  {
    "country": "CH",
    "name": "Langendorf",
    "lat": "47.21974",
    "lng": "7.51469"
  },
  {
    "country": "CH",
    "name": "Troinex",
    "lat": "46.16313",
    "lng": "6.14745"
  },
  {
    "country": "CH",
    "name": "Lancy",
    "lat": "46.18981",
    "lng": "6.11441"
  },
  {
    "country": "CH",
    "name": "Muralto",
    "lat": "46.17323",
    "lng": "8.80219"
  },
  {
    "country": "CH",
    "name": "Münchenwiler",
    "lat": "46.91334",
    "lng": "7.12556"
  },
  {
    "country": "CH",
    "name": "Stetten",
    "lat": "47.74025",
    "lng": "8.66298"
  },
  {
    "country": "CH",
    "name": "Löhningen",
    "lat": "47.70121",
    "lng": "8.55236"
  },
  {
    "country": "CH",
    "name": "Lauffohr (Brugg)",
    "lat": "47.50154",
    "lng": "8.23122"
  },
  {
    "country": "CH",
    "name": "Jongny",
    "lat": "46.47883",
    "lng": "6.84114"
  },
  {
    "country": "CH",
    "name": "Haag (Rheintal)",
    "lat": "47.20989",
    "lng": "9.48931"
  },
  {
    "country": "CH",
    "name": "Givisiez",
    "lat": "46.81201",
    "lng": "7.12639"
  },
  {
    "country": "CH",
    "name": "Aire-la-Ville",
    "lat": "46.19057",
    "lng": "6.04287"
  },
  {
    "country": "CH",
    "name": "Hausen",
    "lat": "47.46396",
    "lng": "8.20988"
  },
  {
    "country": "CH",
    "name": "Veyras",
    "lat": "46.30212",
    "lng": "7.53619"
  },
  {
    "country": "CH",
    "name": "Känerkinden",
    "lat": "47.41188",
    "lng": "7.83716"
  },
  {
    "country": "CH",
    "name": "Oberurnen",
    "lat": "47.11412",
    "lng": "9.05866"
  },
  {
    "country": "CH",
    "name": "Saint Saphorin",
    "lat": "46.47329",
    "lng": "6.79601"
  },
  {
    "country": "CH",
    "name": "Cuarnens",
    "lat": "46.62545",
    "lng": "6.43713"
  },
  {
    "country": "CH",
    "name": "Les Avanchets",
    "lat": "46.22168",
    "lng": "6.10814"
  },
  {
    "country": "CH",
    "name": "Biberstein",
    "lat": "47.41641",
    "lng": "8.08508"
  },
  {
    "country": "CH",
    "name": "Braggio",
    "lat": "46.30277",
    "lng": "9.1238"
  },
  {
    "country": "CH",
    "name": "Saint-George",
    "lat": "46.51428",
    "lng": "6.2598"
  },
  {
    "country": "CH",
    "name": "Saubraz",
    "lat": "46.51606",
    "lng": "6.33018"
  },
  {
    "country": "CH",
    "name": "Berolle",
    "lat": "46.55798",
    "lng": "6.33551"
  },
  {
    "country": "CH",
    "name": "Mauraz",
    "lat": "46.60558",
    "lng": "6.42074"
  },
  {
    "country": "CH",
    "name": "Chavannes-le-Veyron",
    "lat": "46.607",
    "lng": "6.45086"
  },
  {
    "country": "CH",
    "name": "La Chaux",
    "lat": "46.61714",
    "lng": "6.47223"
  },
  {
    "country": "CH",
    "name": "Chevilly",
    "lat": "46.64272",
    "lng": "6.47661"
  },
  {
    "country": "CH",
    "name": "Moiry",
    "lat": "46.64914",
    "lng": "6.45335"
  },
  {
    "country": "CH",
    "name": "Ferreyres",
    "lat": "46.65804",
    "lng": "6.4852"
  },
  {
    "country": "CH",
    "name": "Orny",
    "lat": "46.66758",
    "lng": "6.52639"
  },
  {
    "country": "CH",
    "name": "Pompaples",
    "lat": "46.66699",
    "lng": "6.50966"
  },
  {
    "country": "CH",
    "name": "Penthéréaz",
    "lat": "46.68171",
    "lng": "6.6039"
  },
  {
    "country": "CH",
    "name": "Vuarrens",
    "lat": "46.68578",
    "lng": "6.64793"
  },
  {
    "country": "CH",
    "name": "Rueyres",
    "lat": "46.69337",
    "lng": "6.69213"
  },
  {
    "country": "CH",
    "name": "Bas-Vully",
    "lat": "46.96194",
    "lng": "7.11251"
  },
  {
    "country": "CH",
    "name": "Marin-Epagnier",
    "lat": "47.01017",
    "lng": "6.99941"
  },
  {
    "country": "CH",
    "name": "Tägertschi",
    "lat": "46.87548",
    "lng": "7.58529"
  },
  {
    "country": "CH",
    "name": "Oberrohrdorf",
    "lat": "47.41833",
    "lng": "8.31983"
  },
  {
    "country": "CH",
    "name": "Kirchleerau",
    "lat": "47.27579",
    "lng": "8.06581"
  },
  {
    "country": "CH",
    "name": "Matran",
    "lat": "46.78593",
    "lng": "7.09768"
  },
  {
    "country": "CH",
    "name": "Blécherette",
    "lat": "46.53932",
    "lng": "6.62227"
  },
  {
    "country": "CH",
    "name": "Oberhof",
    "lat": "47.44874",
    "lng": "8.00273"
  },
  {
    "country": "CH",
    "name": "Tenniken",
    "lat": "47.43712",
    "lng": "7.81149"
  },
  {
    "country": "CH",
    "name": "Gansingen",
    "lat": "47.5429",
    "lng": "8.13516"
  },
  {
    "country": "CH",
    "name": "Vuisternens-devant-Romont",
    "lat": "46.65312",
    "lng": "6.92958"
  },
  {
    "country": "CH",
    "name": "Wettswil",
    "lat": "47.33725",
    "lng": "8.47527"
  },
  {
    "country": "CH",
    "name": "Oberkulm",
    "lat": "47.29908",
    "lng": "8.12242"
  },
  {
    "country": "CH",
    "name": "Savosa",
    "lat": "46.01902",
    "lng": "8.94236"
  },
  {
    "country": "CH",
    "name": "Aeugst am Albis",
    "lat": "47.26703",
    "lng": "8.48539"
  },
  {
    "country": "CH",
    "name": "Pont-la-Ville",
    "lat": "46.69793",
    "lng": "7.11094"
  },
  {
    "country": "CH",
    "name": "Servion",
    "lat": "46.57096",
    "lng": "6.77835"
  },
  {
    "country": "CH",
    "name": "Chéserex",
    "lat": "46.39935",
    "lng": "6.17524"
  },
  {
    "country": "CH",
    "name": "Hohentannen",
    "lat": "47.50862",
    "lng": "9.225"
  },
  {
    "country": "CH",
    "name": "Valeyres-sous-Montagny",
    "lat": "46.79859",
    "lng": "6.61094"
  },
  {
    "country": "CH",
    "name": "Bedigliora",
    "lat": "46.00252",
    "lng": "8.84052"
  },
  {
    "country": "CH",
    "name": "Uebeschi",
    "lat": "46.73774",
    "lng": "7.5558"
  },
  {
    "country": "CH",
    "name": "Kleinbösingen",
    "lat": "46.89404",
    "lng": "7.20531"
  },
  {
    "country": "CH",
    "name": "Niedermuhlern",
    "lat": "46.85846",
    "lng": "7.46663"
  },
  {
    "country": "CH",
    "name": "Cheseaux-Noréaz",
    "lat": "46.78184",
    "lng": "6.67029"
  },
  {
    "country": "CH",
    "name": "Rochefort",
    "lat": "46.97768",
    "lng": "6.80835"
  },
  {
    "country": "CH",
    "name": "Corcelles-le-Jorat",
    "lat": "46.60647",
    "lng": "6.74273"
  },
  {
    "country": "CH",
    "name": "Rüegsau",
    "lat": "47.02483",
    "lng": "7.67395"
  },
  {
    "country": "CH",
    "name": "Auswil",
    "lat": "47.13632",
    "lng": "7.83226"
  },
  {
    "country": "CH",
    "name": "Rümligen",
    "lat": "46.82975",
    "lng": "7.49542"
  },
  {
    "country": "CH",
    "name": "Donat",
    "lat": "46.62843",
    "lng": "9.4297"
  },
  {
    "country": "CH",
    "name": "Surpierre",
    "lat": "46.74612",
    "lng": "6.85929"
  },
  {
    "country": "CH",
    "name": "Oberhünigen",
    "lat": "46.88049",
    "lng": "7.65696"
  },
  {
    "country": "CH",
    "name": "Les Clées",
    "lat": "46.7321",
    "lng": "6.46266"
  },
  {
    "country": "CH",
    "name": "Busswil bei Melchnau",
    "lat": "47.18583",
    "lng": "7.83194"
  },
  {
    "country": "CH",
    "name": "Walliswil bei Niederbipp",
    "lat": "47.23625",
    "lng": "7.68991"
  },
  {
    "country": "CH",
    "name": "Rüti bei Lyssach",
    "lat": "47.05684",
    "lng": "7.57679"
  },
  {
    "country": "CI",
    "name": "Zuénoula",
    "lat": "7.43027",
    "lng": "-6.05054"
  },
  {
    "country": "CI",
    "name": "Zoukougbeu",
    "lat": "6.76229",
    "lng": "-6.8638"
  },
  {
    "country": "CI",
    "name": "Zouan-Hounien",
    "lat": "6.91937",
    "lng": "-8.2065"
  },
  {
    "country": "CI",
    "name": "Yamoussoukro",
    "lat": "6.82055",
    "lng": "-5.27674"
  },
  {
    "country": "CI",
    "name": "Yakassé-Attobrou",
    "lat": "6.18174",
    "lng": "-3.65111"
  },
  {
    "country": "CI",
    "name": "Ouaninou",
    "lat": "8.2379",
    "lng": "-7.86638"
  },
  {
    "country": "CI",
    "name": "Vavoua",
    "lat": "7.38194",
    "lng": "-6.47778"
  },
  {
    "country": "CI",
    "name": "Transua",
    "lat": "7.55004",
    "lng": "-3.01431"
  },
  {
    "country": "CI",
    "name": "Toumodi",
    "lat": "6.55799",
    "lng": "-5.01769"
  },
  {
    "country": "CI",
    "name": "Toulépleu Gueré",
    "lat": "6.57395",
    "lng": "-8.42592"
  },
  {
    "country": "CI",
    "name": "Toulépleu",
    "lat": "6.57974",
    "lng": "-8.41091"
  },
  {
    "country": "CI",
    "name": "Touba",
    "lat": "8.28333",
    "lng": "-7.68333"
  },
  {
    "country": "CI",
    "name": "Tengréla",
    "lat": "10.48115",
    "lng": "-6.40694"
  },
  {
    "country": "CI",
    "name": "Tiébissou",
    "lat": "7.15772",
    "lng": "-5.2248"
  },
  {
    "country": "CI",
    "name": "Tiassalé",
    "lat": "5.89839",
    "lng": "-4.82293"
  },
  {
    "country": "CI",
    "name": "Téhini",
    "lat": "9.60542",
    "lng": "-3.65804"
  },
  {
    "country": "CI",
    "name": "Tanda",
    "lat": "7.80335",
    "lng": "-3.16832"
  },
  {
    "country": "CI",
    "name": "Taï",
    "lat": "5.87366",
    "lng": "-7.45519"
  },
  {
    "country": "CI",
    "name": "Tabou",
    "lat": "4.42295",
    "lng": "-7.3528"
  },
  {
    "country": "CI",
    "name": "Sipilou",
    "lat": "7.8645",
    "lng": "-8.10143"
  },
  {
    "country": "CI",
    "name": "Sinfra",
    "lat": "6.62103",
    "lng": "-5.91144"
  },
  {
    "country": "CI",
    "name": "Sinématiali",
    "lat": "9.5841",
    "lng": "-5.38476"
  },
  {
    "country": "CI",
    "name": "Sikensi",
    "lat": "5.66829",
    "lng": "-4.57371"
  },
  {
    "country": "CI",
    "name": "Séguélon",
    "lat": "9.35694",
    "lng": "-7.12083"
  },
  {
    "country": "CI",
    "name": "Sassandra",
    "lat": "4.95384",
    "lng": "-6.08531"
  },
  {
    "country": "CI",
    "name": "San-Pédro",
    "lat": "4.74851",
    "lng": "-6.6363"
  },
  {
    "country": "CI",
    "name": "Sandégué",
    "lat": "7.95376",
    "lng": "-3.58012"
  },
  {
    "country": "CI",
    "name": "Samatiguila",
    "lat": "9.81952",
    "lng": "-7.56085"
  },
  {
    "country": "CI",
    "name": "Sakassou",
    "lat": "7.45462",
    "lng": "-5.29263"
  },
  {
    "country": "CI",
    "name": "Prikro",
    "lat": "7.64705",
    "lng": "-3.99626"
  },
  {
    "country": "CI",
    "name": "Oumé",
    "lat": "6.38309",
    "lng": "-5.41759"
  },
  {
    "country": "CI",
    "name": "Ouangolodougou",
    "lat": "9.96837",
    "lng": "-5.14882"
  },
  {
    "country": "CI",
    "name": "Odienné",
    "lat": "9.50511",
    "lng": "-7.56433"
  },
  {
    "country": "CI",
    "name": "Niakaramandougou",
    "lat": "8.65759",
    "lng": "-5.29109"
  },
  {
    "country": "CI",
    "name": "Nassian",
    "lat": "8.45275",
    "lng": "-3.47152"
  },
  {
    "country": "CI",
    "name": "M’Bengué",
    "lat": "10.00244",
    "lng": "-5.90037"
  },
  {
    "country": "CI",
    "name": "M’Batto",
    "lat": "6.47197",
    "lng": "-4.35781"
  },
  {
    "country": "CI",
    "name": "M’Bahiakro",
    "lat": "7.45728",
    "lng": "-4.33993"
  },
  {
    "country": "CI",
    "name": "Mankono",
    "lat": "8.05861",
    "lng": "-6.18972"
  },
  {
    "country": "CI",
    "name": "Minignan",
    "lat": "9.99744",
    "lng": "-7.83593"
  },
  {
    "country": "CI",
    "name": "Man",
    "lat": "7.41251",
    "lng": "-7.55383"
  },
  {
    "country": "CI",
    "name": "Madinani",
    "lat": "9.61083",
    "lng": "-6.94215"
  },
  {
    "country": "CI",
    "name": "Lakota",
    "lat": "5.84752",
    "lng": "-5.682"
  },
  {
    "country": "CI",
    "name": "Kouto",
    "lat": "9.89029",
    "lng": "-6.40921"
  },
  {
    "country": "CI",
    "name": "Kounahiri",
    "lat": "7.79089",
    "lng": "-5.83477"
  },
  {
    "country": "CI",
    "name": "Koun-Fao",
    "lat": "7.48764",
    "lng": "-3.25249"
  },
  {
    "country": "CI",
    "name": "Kouibly",
    "lat": "7.25597",
    "lng": "-7.23508"
  },
  {
    "country": "CI",
    "name": "Koro",
    "lat": "8.55505",
    "lng": "-7.46348"
  },
  {
    "country": "CI",
    "name": "Korhogo",
    "lat": "9.45803",
    "lng": "-5.62961"
  },
  {
    "country": "CI",
    "name": "Kong",
    "lat": "9.14943",
    "lng": "-4.60982"
  },
  {
    "country": "CI",
    "name": "Kouassi-Kouassikro",
    "lat": "7.34141",
    "lng": "-4.67709"
  },
  {
    "country": "CI",
    "name": "Katiola",
    "lat": "8.13728",
    "lng": "-5.10095"
  },
  {
    "country": "CI",
    "name": "Kaniasso",
    "lat": "9.81471",
    "lng": "-7.5125"
  },
  {
    "country": "CI",
    "name": "Kani",
    "lat": "8.47807",
    "lng": "-6.60509"
  },
  {
    "country": "CI",
    "name": "Jacqueville",
    "lat": "5.20515",
    "lng": "-4.4146"
  },
  {
    "country": "CI",
    "name": "Issia",
    "lat": "6.49224",
    "lng": "-6.58558"
  },
  {
    "country": "CI",
    "name": "Guitry",
    "lat": "5.51952",
    "lng": "-5.24038"
  },
  {
    "country": "CI",
    "name": "Guiglo",
    "lat": "6.54368",
    "lng": "-7.4935"
  },
  {
    "country": "CI",
    "name": "Guibéroua",
    "lat": "6.23869",
    "lng": "-6.17147"
  },
  {
    "country": "CI",
    "name": "Guéyo",
    "lat": "5.6882",
    "lng": "-6.0712"
  },
  {
    "country": "CI",
    "name": "Grand-Lahou",
    "lat": "5.25068",
    "lng": "-5.00333"
  },
  {
    "country": "CI",
    "name": "Grand-Bassam",
    "lat": "5.2118",
    "lng": "-3.73884"
  },
  {
    "country": "CI",
    "name": "Affery",
    "lat": "6.32035",
    "lng": "-3.95235"
  },
  {
    "country": "CI",
    "name": "Gbéléban",
    "lat": "9.58461",
    "lng": "-8.13183"
  },
  {
    "country": "CI",
    "name": "Gagnoa",
    "lat": "6.13193",
    "lng": "-5.9506"
  },
  {
    "country": "CI",
    "name": "Fresco",
    "lat": "5.08226",
    "lng": "-5.56938"
  },
  {
    "country": "CI",
    "name": "Ferkessédougou",
    "lat": "9.5928",
    "lng": "-5.19449"
  },
  {
    "country": "CI",
    "name": "Facobly",
    "lat": "7.3883",
    "lng": "-7.37644"
  },
  {
    "country": "CI",
    "name": "Dianra",
    "lat": "8.94333",
    "lng": "-6.2549"
  },
  {
    "country": "CI",
    "name": "Duekoué",
    "lat": "6.74202",
    "lng": "-7.34918"
  },
  {
    "country": "CI",
    "name": "Divo",
    "lat": "5.83739",
    "lng": "-5.35723"
  },
  {
    "country": "CI",
    "name": "Dimbokro",
    "lat": "6.64678",
    "lng": "-4.70519"
  },
  {
    "country": "CI",
    "name": "Dikodougou",
    "lat": "9.06757",
    "lng": "-5.77222"
  },
  {
    "country": "CI",
    "name": "Djékanou",
    "lat": "6.48389",
    "lng": "-5.11553"
  },
  {
    "country": "CI",
    "name": "Didiévi",
    "lat": "7.12866",
    "lng": "-4.89804"
  },
  {
    "country": "CI",
    "name": "Daoukro",
    "lat": "7.0591",
    "lng": "-3.9631"
  },
  {
    "country": "CI",
    "name": "Danané",
    "lat": "7.25957",
    "lng": "-8.15498"
  },
  {
    "country": "CI",
    "name": "Daloa",
    "lat": "6.87735",
    "lng": "-6.45022"
  },
  {
    "country": "CI",
    "name": "Dabou",
    "lat": "5.32556",
    "lng": "-4.37685"
  },
  {
    "country": "CI",
    "name": "Dabakala",
    "lat": "8.36321",
    "lng": "-4.42863"
  },
  {
    "country": "CI",
    "name": "Buyo",
    "lat": "6.27534",
    "lng": "-6.99704"
  },
  {
    "country": "CI",
    "name": "Boundiali",
    "lat": "9.52167",
    "lng": "-6.48694"
  },
  {
    "country": "CI",
    "name": "Bouna",
    "lat": "9.26927",
    "lng": "-2.9951"
  },
  {
    "country": "CI",
    "name": "Bouaké",
    "lat": "7.69385",
    "lng": "-5.03031"
  },
  {
    "country": "CI",
    "name": "Bouaflé",
    "lat": "6.99041",
    "lng": "-5.7442"
  },
  {
    "country": "CI",
    "name": "Botro",
    "lat": "7.85249",
    "lng": "-5.31063"
  },
  {
    "country": "CI",
    "name": "Bonoua",
    "lat": "5.27247",
    "lng": "-3.59625"
  },
  {
    "country": "CI",
    "name": "Bongouanou",
    "lat": "6.65175",
    "lng": "-4.20406"
  },
  {
    "country": "CI",
    "name": "Bondoukou",
    "lat": "8.0402",
    "lng": "-2.80003"
  },
  {
    "country": "CI",
    "name": "Bocanda",
    "lat": "7.06264",
    "lng": "-4.49948"
  },
  {
    "country": "CI",
    "name": "Bloléquin",
    "lat": "6.56913",
    "lng": "-8.00253"
  },
  {
    "country": "CI",
    "name": "Bingerville",
    "lat": "5.35581",
    "lng": "-3.88537"
  },
  {
    "country": "CI",
    "name": "Biankouma",
    "lat": "7.73909",
    "lng": "-7.61377"
  },
  {
    "country": "CI",
    "name": "Béttié",
    "lat": "6.07568",
    "lng": "-3.40846"
  },
  {
    "country": "CI",
    "name": "Béoumi",
    "lat": "7.67395",
    "lng": "-5.58085"
  },
  {
    "country": "CI",
    "name": "Bangolo",
    "lat": "7.01232",
    "lng": "-7.48639"
  },
  {
    "country": "CI",
    "name": "Ayamé",
    "lat": "5.6052",
    "lng": "-3.15709"
  },
  {
    "country": "CI",
    "name": "Attiégouakro",
    "lat": "6.77402",
    "lng": "-5.11411"
  },
  {
    "country": "CI",
    "name": "Arrah",
    "lat": "6.67342",
    "lng": "-3.96938"
  },
  {
    "country": "CI",
    "name": "Anyama",
    "lat": "5.49462",
    "lng": "-4.05183"
  },
  {
    "country": "CI",
    "name": "Alépé",
    "lat": "5.5004",
    "lng": "-3.66308"
  },
  {
    "country": "CI",
    "name": "Akoupé",
    "lat": "6.38423",
    "lng": "-3.88759"
  },
  {
    "country": "CI",
    "name": "Agnibilékrou",
    "lat": "7.13113",
    "lng": "-3.20415"
  },
  {
    "country": "CI",
    "name": "Agboville",
    "lat": "5.92801",
    "lng": "-4.21319"
  },
  {
    "country": "CI",
    "name": "Adzopé",
    "lat": "6.10694",
    "lng": "-3.86194"
  },
  {
    "country": "CI",
    "name": "Adiaké",
    "lat": "5.28634",
    "lng": "-3.30403"
  },
  {
    "country": "CI",
    "name": "Aboisso",
    "lat": "5.46779",
    "lng": "-3.20711"
  },
  {
    "country": "CI",
    "name": "Abobo",
    "lat": "5.41613",
    "lng": "-4.0159"
  },
  {
    "country": "CI",
    "name": "Abidjan",
    "lat": "5.30966",
    "lng": "-4.01266"
  },
  {
    "country": "CI",
    "name": "Abengourou",
    "lat": "6.72972",
    "lng": "-3.49639"
  },
  {
    "country": "CI",
    "name": "Séguéla",
    "lat": "7.96111",
    "lng": "-6.67306"
  },
  {
    "country": "CI",
    "name": "Soubré",
    "lat": "5.78377",
    "lng": "-6.59388"
  },
  {
    "country": "CI",
    "name": "Tiapoum",
    "lat": "5.13622",
    "lng": "-3.02308"
  },
  {
    "country": "CI",
    "name": "Taabo",
    "lat": "6.1998",
    "lng": "-5.10884"
  },
  {
    "country": "CK",
    "name": "Avarua",
    "lat": "-21.2075",
    "lng": "-159.77545"
  },
  {
    "country": "CL",
    "name": "Yumbel",
    "lat": "-37.0982",
    "lng": "-72.56084"
  },
  {
    "country": "CL",
    "name": "Viña del Mar",
    "lat": "-33.02457",
    "lng": "-71.55183"
  },
  {
    "country": "CL",
    "name": "Villarrica",
    "lat": "-39.28569",
    "lng": "-72.2279"
  },
  {
    "country": "CL",
    "name": "Villa Alemana",
    "lat": "-33.04222",
    "lng": "-71.37333"
  },
  {
    "country": "CL",
    "name": "Vilcún",
    "lat": "-38.66875",
    "lng": "-72.22565"
  },
  {
    "country": "CL",
    "name": "Vicuña",
    "lat": "-30.03541",
    "lng": "-70.71274"
  },
  {
    "country": "CL",
    "name": "Victoria",
    "lat": "-38.23291",
    "lng": "-72.33292"
  },
  {
    "country": "CL",
    "name": "Valparaíso",
    "lat": "-33.036",
    "lng": "-71.62963"
  },
  {
    "country": "CL",
    "name": "Vallenar",
    "lat": "-28.57617",
    "lng": "-70.75938"
  },
  {
    "country": "CL",
    "name": "Valdivia",
    "lat": "-39.81422",
    "lng": "-73.24589"
  },
  {
    "country": "CL",
    "name": "Traiguén",
    "lat": "-38.2496",
    "lng": "-72.67027"
  },
  {
    "country": "CL",
    "name": "Tomé",
    "lat": "-36.61756",
    "lng": "-72.95593"
  },
  {
    "country": "CL",
    "name": "Tocopilla",
    "lat": "-22.09198",
    "lng": "-70.19792"
  },
  {
    "country": "CL",
    "name": "Teno",
    "lat": "-34.87055",
    "lng": "-71.16219"
  },
  {
    "country": "CL",
    "name": "Temuco",
    "lat": "-38.73965",
    "lng": "-72.59842"
  },
  {
    "country": "CL",
    "name": "Taltal",
    "lat": "-25.40713",
    "lng": "-70.48554"
  },
  {
    "country": "CL",
    "name": "Talcahuano",
    "lat": "-36.72494",
    "lng": "-73.11684"
  },
  {
    "country": "CL",
    "name": "Talca",
    "lat": "-35.4264",
    "lng": "-71.65542"
  },
  {
    "country": "CL",
    "name": "Talagante",
    "lat": "-33.66386",
    "lng": "-70.92734"
  },
  {
    "country": "CL",
    "name": "San Vicente de Tagua Tagua",
    "lat": "-34.43859",
    "lng": "-71.07751"
  },
  {
    "country": "CL",
    "name": "San Vicente",
    "lat": "-34.43333",
    "lng": "-71.08333"
  },
  {
    "country": "CL",
    "name": "Santiago",
    "lat": "-33.45694",
    "lng": "-70.64827"
  },
  {
    "country": "CL",
    "name": "Santa Cruz",
    "lat": "-34.63881",
    "lng": "-71.36576"
  },
  {
    "country": "CL",
    "name": "San Pedro de Atacama",
    "lat": "-22.9111",
    "lng": "-68.20113"
  },
  {
    "country": "CL",
    "name": "San Javier",
    "lat": "-35.5952",
    "lng": "-71.72924"
  },
  {
    "country": "CL",
    "name": "San Felipe",
    "lat": "-32.74976",
    "lng": "-70.72584"
  },
  {
    "country": "CL",
    "name": "San Clemente",
    "lat": "-35.53777",
    "lng": "-71.487"
  },
  {
    "country": "CL",
    "name": "San Carlos",
    "lat": "-36.42477",
    "lng": "-71.958"
  },
  {
    "country": "CL",
    "name": "San Bernardo",
    "lat": "-33.59217",
    "lng": "-70.6996"
  },
  {
    "country": "CL",
    "name": "San Antonio",
    "lat": "-33.59473",
    "lng": "-71.60746"
  },
  {
    "country": "CL",
    "name": "Salamanca",
    "lat": "-31.77922",
    "lng": "-70.96389"
  },
  {
    "country": "CL",
    "name": "Río Bueno",
    "lat": "-40.33494",
    "lng": "-72.95564"
  },
  {
    "country": "CL",
    "name": "Rengo",
    "lat": "-34.40639",
    "lng": "-70.85834"
  },
  {
    "country": "CL",
    "name": "Rauco",
    "lat": "-34.92546",
    "lng": "-71.31722"
  },
  {
    "country": "CL",
    "name": "Rancagua",
    "lat": "-34.17083",
    "lng": "-70.74444"
  },
  {
    "country": "CL",
    "name": "Quilpué",
    "lat": "-33.04752",
    "lng": "-71.44249"
  },
  {
    "country": "CL",
    "name": "Quillota",
    "lat": "-32.88341",
    "lng": "-71.24882"
  },
  {
    "country": "CL",
    "name": "Puyehue",
    "lat": "-40.65944",
    "lng": "-72.60172"
  },
  {
    "country": "CL",
    "name": "Putre",
    "lat": "-18.19821",
    "lng": "-69.56071"
  },
  {
    "country": "CL",
    "name": "Purranque",
    "lat": "-40.91305",
    "lng": "-73.15913"
  },
  {
    "country": "CL",
    "name": "Punta Arenas",
    "lat": "-53.15483",
    "lng": "-70.91129"
  },
  {
    "country": "CL",
    "name": "Puerto Williams",
    "lat": "-54.93355",
    "lng": "-67.60963"
  },
  {
    "country": "CL",
    "name": "Puerto Varas",
    "lat": "-41.31946",
    "lng": "-72.98538"
  },
  {
    "country": "CL",
    "name": "Quellón",
    "lat": "-43.11819",
    "lng": "-73.61661"
  },
  {
    "country": "CL",
    "name": "Puerto Natales",
    "lat": "-51.72987",
    "lng": "-72.50603"
  },
  {
    "country": "CL",
    "name": "Puerto Montt",
    "lat": "-41.4693",
    "lng": "-72.94237"
  },
  {
    "country": "CL",
    "name": "Puerto Cisnes",
    "lat": "-44.74736",
    "lng": "-72.69695"
  },
  {
    "country": "CL",
    "name": "Puerto Aysén",
    "lat": "-45.40303",
    "lng": "-72.69184"
  },
  {
    "country": "CL",
    "name": "Puente Alto",
    "lat": "-33.61169",
    "lng": "-70.57577"
  },
  {
    "country": "CL",
    "name": "Pucón",
    "lat": "-39.28223",
    "lng": "-71.95427"
  },
  {
    "country": "CL",
    "name": "Providencia",
    "lat": "-33.43107",
    "lng": "-70.60454"
  },
  {
    "country": "CL",
    "name": "Pozo Almonte",
    "lat": "-20.25585",
    "lng": "-69.7863"
  },
  {
    "country": "CL",
    "name": "Porvenir",
    "lat": "-53.296",
    "lng": "-70.36629"
  },
  {
    "country": "CL",
    "name": "Pitrufquén",
    "lat": "-38.98635",
    "lng": "-72.63721"
  },
  {
    "country": "CL",
    "name": "Pica",
    "lat": "-20.49128",
    "lng": "-69.33118"
  },
  {
    "country": "CL",
    "name": "Penco",
    "lat": "-36.74075",
    "lng": "-72.99528"
  },
  {
    "country": "CL",
    "name": "Peñaflor",
    "lat": "-33.60627",
    "lng": "-70.87649"
  },
  {
    "country": "CL",
    "name": "Parral",
    "lat": "-36.14311",
    "lng": "-71.82605"
  },
  {
    "country": "CL",
    "name": "Panguipulli",
    "lat": "-39.64355",
    "lng": "-72.33269"
  },
  {
    "country": "CL",
    "name": "Palena",
    "lat": "-43.61876",
    "lng": "-71.80434"
  },
  {
    "country": "CL",
    "name": "Paine",
    "lat": "-33.80796",
    "lng": "-70.74109"
  },
  {
    "country": "CL",
    "name": "Ovalle",
    "lat": "-30.60106",
    "lng": "-71.19901"
  },
  {
    "country": "CL",
    "name": "Osorno",
    "lat": "-40.57395",
    "lng": "-73.13348"
  },
  {
    "country": "CL",
    "name": "Nueva Imperial",
    "lat": "-38.74451",
    "lng": "-72.95025"
  },
  {
    "country": "CL",
    "name": "Nacimiento",
    "lat": "-37.50253",
    "lng": "-72.67307"
  },
  {
    "country": "CL",
    "name": "Mulchén",
    "lat": "-37.71893",
    "lng": "-72.24099"
  },
  {
    "country": "CL",
    "name": "Monte Patria",
    "lat": "-30.69496",
    "lng": "-70.9577"
  },
  {
    "country": "CL",
    "name": "Molina",
    "lat": "-35.11428",
    "lng": "-71.28232"
  },
  {
    "country": "CL",
    "name": "Melipilla",
    "lat": "-33.68909",
    "lng": "-71.21528"
  },
  {
    "country": "CL",
    "name": "Machalí",
    "lat": "-34.18082",
    "lng": "-70.64933"
  },
  {
    "country": "CL",
    "name": "Lota",
    "lat": "-37.08994",
    "lng": "-73.1577"
  },
  {
    "country": "CL",
    "name": "Los Ángeles",
    "lat": "-37.46973",
    "lng": "-72.35366"
  },
  {
    "country": "CL",
    "name": "Los Andes",
    "lat": "-32.83369",
    "lng": "-70.59827"
  },
  {
    "country": "CL",
    "name": "Longaví",
    "lat": "-35.96496",
    "lng": "-71.6836"
  },
  {
    "country": "CL",
    "name": "Loncoche",
    "lat": "-39.36708",
    "lng": "-72.63087"
  },
  {
    "country": "CL",
    "name": "Llaillay",
    "lat": "-32.84043",
    "lng": "-70.95623"
  },
  {
    "country": "CL",
    "name": "Linares",
    "lat": "-35.84667",
    "lng": "-71.59308"
  },
  {
    "country": "CL",
    "name": "Limache",
    "lat": "-33.01667",
    "lng": "-71.26667"
  },
  {
    "country": "CL",
    "name": "Lebu",
    "lat": "-37.60825",
    "lng": "-73.65356"
  },
  {
    "country": "CL",
    "name": "Lautaro",
    "lat": "-38.53066",
    "lng": "-72.43652"
  },
  {
    "country": "CL",
    "name": "La Unión",
    "lat": "-40.29313",
    "lng": "-73.08167"
  },
  {
    "country": "CL",
    "name": "La Serena",
    "lat": "-29.90453",
    "lng": "-71.24894"
  },
  {
    "country": "CL",
    "name": "Lampa",
    "lat": "-33.2863",
    "lng": "-70.87561"
  },
  {
    "country": "CL",
    "name": "La Ligua",
    "lat": "-32.45242",
    "lng": "-71.23106"
  },
  {
    "country": "CL",
    "name": "Laja",
    "lat": "-37.28415",
    "lng": "-72.71105"
  },
  {
    "country": "CL",
    "name": "La Ensenada",
    "lat": "-41.20746",
    "lng": "-72.5384"
  },
  {
    "country": "CL",
    "name": "Iquique",
    "lat": "-20.21326",
    "lng": "-70.15027"
  },
  {
    "country": "CL",
    "name": "Illapel",
    "lat": "-31.63349",
    "lng": "-71.16967"
  },
  {
    "country": "CL",
    "name": "Hacienda La Calera",
    "lat": "-32.78333",
    "lng": "-71.21667"
  },
  {
    "country": "CL",
    "name": "Graneros",
    "lat": "-34.06863",
    "lng": "-70.72747"
  },
  {
    "country": "CL",
    "name": "Futaleufú",
    "lat": "-43.18492",
    "lng": "-71.86722"
  },
  {
    "country": "CL",
    "name": "Frutillar",
    "lat": "-41.12676",
    "lng": "-73.04372"
  },
  {
    "country": "CL",
    "name": "Freire",
    "lat": "-38.95252",
    "lng": "-72.62653"
  },
  {
    "country": "CL",
    "name": "El Tabo",
    "lat": "-33.45",
    "lng": "-71.66667"
  },
  {
    "country": "CL",
    "name": "El Monte",
    "lat": "-33.67969",
    "lng": "-70.98482"
  },
  {
    "country": "CL",
    "name": "Diego de Almagro",
    "lat": "-26.36667",
    "lng": "-70.05"
  },
  {
    "country": "CL",
    "name": "Curicó",
    "lat": "-34.98279",
    "lng": "-71.23943"
  },
  {
    "country": "CL",
    "name": "Curanilahue",
    "lat": "-37.47793",
    "lng": "-73.34495"
  },
  {
    "country": "CL",
    "name": "Corral",
    "lat": "-39.8873",
    "lng": "-73.43101"
  },
  {
    "country": "CL",
    "name": "Coronel",
    "lat": "-37.03386",
    "lng": "-73.14019"
  },
  {
    "country": "CL",
    "name": "Coquimbo",
    "lat": "-29.95332",
    "lng": "-71.33947"
  },
  {
    "country": "CL",
    "name": "Copiapó",
    "lat": "-27.36679",
    "lng": "-70.3314"
  },
  {
    "country": "CL",
    "name": "Constitución",
    "lat": "-35.33321",
    "lng": "-72.41156"
  },
  {
    "country": "CL",
    "name": "Concepción",
    "lat": "-36.82699",
    "lng": "-73.04977"
  },
  {
    "country": "CL",
    "name": "Collipulli",
    "lat": "-37.95453",
    "lng": "-72.43438"
  },
  {
    "country": "CL",
    "name": "Colina",
    "lat": "-33.20443",
    "lng": "-70.67474"
  },
  {
    "country": "CL",
    "name": "Colbún",
    "lat": "-35.69494",
    "lng": "-71.40568"
  },
  {
    "country": "CL",
    "name": "Coihueco",
    "lat": "-36.62785",
    "lng": "-71.83068"
  },
  {
    "country": "CL",
    "name": "Coyhaique",
    "lat": "-45.57524",
    "lng": "-72.06619"
  },
  {
    "country": "CL",
    "name": "Cochrane",
    "lat": "-47.2557",
    "lng": "-72.5695"
  },
  {
    "country": "CL",
    "name": "Chonchi",
    "lat": "-42.62387",
    "lng": "-73.775"
  },
  {
    "country": "CL",
    "name": "Chimbarongo",
    "lat": "-34.71247",
    "lng": "-71.0434"
  },
  {
    "country": "CL",
    "name": "Chillán",
    "lat": "-36.60664",
    "lng": "-72.10344"
  },
  {
    "country": "CL",
    "name": "Chile Chico",
    "lat": "-46.541",
    "lng": "-71.72375"
  },
  {
    "country": "CL",
    "name": "Chiguayante",
    "lat": "-36.9256",
    "lng": "-73.02841"
  },
  {
    "country": "CL",
    "name": "Chicureo Abajo",
    "lat": "-33.28379",
    "lng": "-70.65333"
  },
  {
    "country": "CL",
    "name": "Chañaral",
    "lat": "-26.34298",
    "lng": "-70.61648"
  },
  {
    "country": "CL",
    "name": "Chaitén",
    "lat": "-42.91596",
    "lng": "-72.70632"
  },
  {
    "country": "CL",
    "name": "Cauquenes",
    "lat": "-35.9671",
    "lng": "-72.32248"
  },
  {
    "country": "CL",
    "name": "Castro",
    "lat": "-42.4721",
    "lng": "-73.77319"
  },
  {
    "country": "CL",
    "name": "Cartagena",
    "lat": "-33.55384",
    "lng": "-71.60761"
  },
  {
    "country": "CL",
    "name": "Carahue",
    "lat": "-38.71122",
    "lng": "-73.16101"
  },
  {
    "country": "CL",
    "name": "Cañete",
    "lat": "-37.80128",
    "lng": "-73.39616"
  },
  {
    "country": "CL",
    "name": "Cámeron",
    "lat": "-53.63988",
    "lng": "-69.64693"
  },
  {
    "country": "CL",
    "name": "Calbuco",
    "lat": "-41.77338",
    "lng": "-73.13049"
  },
  {
    "country": "CL",
    "name": "Calama",
    "lat": "-22.45667",
    "lng": "-68.92371"
  },
  {
    "country": "CL",
    "name": "Cabrero",
    "lat": "-37.03394",
    "lng": "-72.40468"
  },
  {
    "country": "CL",
    "name": "Bulnes",
    "lat": "-36.74232",
    "lng": "-72.29854"
  },
  {
    "country": "CL",
    "name": "Buin",
    "lat": "-33.73257",
    "lng": "-70.74281"
  },
  {
    "country": "CL",
    "name": "Arica",
    "lat": "-18.4746",
    "lng": "-70.29792"
  },
  {
    "country": "CL",
    "name": "Arauco",
    "lat": "-37.2463",
    "lng": "-73.31752"
  },
  {
    "country": "CL",
    "name": "Antofagasta",
    "lat": "-23.65236",
    "lng": "-70.3954"
  },
  {
    "country": "CL",
    "name": "Angol",
    "lat": "-37.79519",
    "lng": "-72.71636"
  },
  {
    "country": "CL",
    "name": "Ancud",
    "lat": "-41.8707",
    "lng": "-73.81622"
  },
  {
    "country": "CL",
    "name": "Puerto Chacabuco",
    "lat": "-45.46667",
    "lng": "-72.81667"
  },
  {
    "country": "CL",
    "name": "La Junta",
    "lat": "-43.97434",
    "lng": "-72.40554"
  },
  {
    "country": "CL",
    "name": "Hanga Roa",
    "lat": "-27.15474",
    "lng": "-109.43241"
  },
  {
    "country": "CL",
    "name": "Las Gaviotas",
    "lat": "-39.86653",
    "lng": "-73.18834"
  },
  {
    "country": "CL",
    "name": "Las Animas",
    "lat": "-39.80867",
    "lng": "-73.21821"
  },
  {
    "country": "CL",
    "name": "La Pintana",
    "lat": "-33.58331",
    "lng": "-70.63419"
  },
  {
    "country": "CL",
    "name": "Lo Prado",
    "lat": "-33.4443",
    "lng": "-70.72552"
  },
  {
    "country": "CL",
    "name": "Villa Presidente Frei, Ñuñoa, Santiago, Chile",
    "lat": "-33.46069",
    "lng": "-70.58024"
  },
  {
    "country": "CL",
    "name": "Vallenar",
    "lat": "-28.51576",
    "lng": "-70.25551"
  },
  {
    "country": "CM",
    "name": "Yoko",
    "lat": "5.53333",
    "lng": "12.31667"
  },
  {
    "country": "CM",
    "name": "Yokadouma",
    "lat": "3.51667",
    "lng": "15.05"
  },
  {
    "country": "CM",
    "name": "Yaoundé",
    "lat": "3.86667",
    "lng": "11.51667"
  },
  {
    "country": "CM",
    "name": "Yagoua",
    "lat": "10.34107",
    "lng": "15.23288"
  },
  {
    "country": "CM",
    "name": "Yabassi",
    "lat": "4.45697",
    "lng": "9.96822"
  },
  {
    "country": "CM",
    "name": "Wum",
    "lat": "6.38333",
    "lng": "10.06667"
  },
  {
    "country": "CM",
    "name": "Tonga",
    "lat": "4.96667",
    "lng": "10.7"
  },
  {
    "country": "CM",
    "name": "Tiko",
    "lat": "4.075",
    "lng": "9.36005"
  },
  {
    "country": "CM",
    "name": "Tignère",
    "lat": "7.36667",
    "lng": "12.65"
  },
  {
    "country": "CM",
    "name": "Tibati",
    "lat": "6.46504",
    "lng": "12.62843"
  },
  {
    "country": "CM",
    "name": "Tcholliré",
    "lat": "8.4022",
    "lng": "14.1698"
  },
  {
    "country": "CM",
    "name": "Sangmélima",
    "lat": "2.93333",
    "lng": "11.98333"
  },
  {
    "country": "CM",
    "name": "Saa",
    "lat": "4.36667",
    "lng": "11.45"
  },
  {
    "country": "CM",
    "name": "Rey Bouba",
    "lat": "8.6724",
    "lng": "14.1786"
  },
  {
    "country": "CM",
    "name": "Poli",
    "lat": "8.4756",
    "lng": "13.24097"
  },
  {
    "country": "CM",
    "name": "Pitoa",
    "lat": "9.3839",
    "lng": "13.50231"
  },
  {
    "country": "CM",
    "name": "Penja",
    "lat": "4.63911",
    "lng": "9.67987"
  },
  {
    "country": "CM",
    "name": "Ombésa",
    "lat": "4.6",
    "lng": "11.25"
  },
  {
    "country": "CM",
    "name": "Okola",
    "lat": "4.01667",
    "lng": "11.38333"
  },
  {
    "country": "CM",
    "name": "Okoa",
    "lat": "3.98333",
    "lng": "11.6"
  },
  {
    "country": "CM",
    "name": "Obala",
    "lat": "4.16667",
    "lng": "11.53333"
  },
  {
    "country": "CM",
    "name": "Ntui",
    "lat": "4.45",
    "lng": "11.63333"
  },
  {
    "country": "CM",
    "name": "Nkoteng",
    "lat": "4.51667",
    "lng": "12.03333"
  },
  {
    "country": "CM",
    "name": "Nkongsamba",
    "lat": "4.9547",
    "lng": "9.9404"
  },
  {
    "country": "CM",
    "name": "Njinikom",
    "lat": "6.23333",
    "lng": "10.28333"
  },
  {
    "country": "CM",
    "name": "Nguti",
    "lat": "5.3299",
    "lng": "9.4185"
  },
  {
    "country": "CM",
    "name": "Ngoro",
    "lat": "4.95",
    "lng": "11.38333"
  },
  {
    "country": "CM",
    "name": "Ngomedzap",
    "lat": "3.25",
    "lng": "11.2"
  },
  {
    "country": "CM",
    "name": "Ngaoundéré",
    "lat": "7.32765",
    "lng": "13.58472"
  },
  {
    "country": "CM",
    "name": "Ngambé",
    "lat": "4.23343",
    "lng": "10.61532"
  },
  {
    "country": "CM",
    "name": "Ndikiniméki",
    "lat": "4.76667",
    "lng": "10.83333"
  },
  {
    "country": "CM",
    "name": "Ndelele",
    "lat": "4.04065",
    "lng": "14.92501"
  },
  {
    "country": "CM",
    "name": "Nanga Eboko",
    "lat": "4.68333",
    "lng": "12.36667"
  },
  {
    "country": "CM",
    "name": "Mvangué",
    "lat": "2.96667",
    "lng": "11.51667"
  },
  {
    "country": "CM",
    "name": "Muyuka",
    "lat": "4.2898",
    "lng": "9.4103"
  },
  {
    "country": "CM",
    "name": "Mutengene",
    "lat": "4.0913",
    "lng": "9.3144"
  },
  {
    "country": "CM",
    "name": "Mundemba",
    "lat": "4.9479",
    "lng": "8.8724"
  },
  {
    "country": "CM",
    "name": "Mouanko",
    "lat": "3.63972",
    "lng": "9.77694"
  },
  {
    "country": "CM",
    "name": "Mora",
    "lat": "11.04611",
    "lng": "14.14011"
  },
  {
    "country": "CM",
    "name": "Mokolo",
    "lat": "10.74244",
    "lng": "13.80227"
  },
  {
    "country": "CM",
    "name": "Mme-Bafumen",
    "lat": "6.33333",
    "lng": "10.23333"
  },
  {
    "country": "CM",
    "name": "Minta",
    "lat": "4.58333",
    "lng": "12.8"
  },
  {
    "country": "CM",
    "name": "Mindif",
    "lat": "10.39757",
    "lng": "14.43626"
  },
  {
    "country": "CM",
    "name": "Melong",
    "lat": "5.12181",
    "lng": "9.96143"
  },
  {
    "country": "CM",
    "name": "Meïganga",
    "lat": "6.51667",
    "lng": "14.3"
  },
  {
    "country": "CM",
    "name": "Mbouda",
    "lat": "5.62611",
    "lng": "10.25421"
  },
  {
    "country": "CM",
    "name": "Mbengwi",
    "lat": "6.01667",
    "lng": "10"
  },
  {
    "country": "CM",
    "name": "Mbankomo",
    "lat": "3.78333",
    "lng": "11.38333"
  },
  {
    "country": "CM",
    "name": "Mbanga",
    "lat": "4.5016",
    "lng": "9.5671"
  },
  {
    "country": "CM",
    "name": "Mbang",
    "lat": "4.58333",
    "lng": "13.33333"
  },
  {
    "country": "CM",
    "name": "Mbandjok",
    "lat": "4.45",
    "lng": "11.9"
  },
  {
    "country": "CM",
    "name": "Mbalmayo",
    "lat": "3.51667",
    "lng": "11.5"
  },
  {
    "country": "CM",
    "name": "Maroua",
    "lat": "10.59095",
    "lng": "14.31593"
  },
  {
    "country": "CM",
    "name": "Manjo",
    "lat": "4.8428",
    "lng": "9.8217"
  },
  {
    "country": "CM",
    "name": "Mamfe",
    "lat": "5.75132",
    "lng": "9.3137"
  },
  {
    "country": "CM",
    "name": "Makary",
    "lat": "12.57535",
    "lng": "14.45483"
  },
  {
    "country": "CM",
    "name": "Loum",
    "lat": "4.7182",
    "lng": "9.7351"
  },
  {
    "country": "CM",
    "name": "Lolodorf",
    "lat": "3.23333",
    "lng": "10.73333"
  },
  {
    "country": "CM",
    "name": "Limbe",
    "lat": "4.02356",
    "lng": "9.20607"
  },
  {
    "country": "CM",
    "name": "Lagdo",
    "lat": "9.05828",
    "lng": "13.66605"
  },
  {
    "country": "CM",
    "name": "Kumbo",
    "lat": "6.2",
    "lng": "10.66667"
  },
  {
    "country": "CM",
    "name": "Kumba",
    "lat": "4.6363",
    "lng": "9.4469"
  },
  {
    "country": "CM",
    "name": "Kribi",
    "lat": "2.93725",
    "lng": "9.90765"
  },
  {
    "country": "CM",
    "name": "Koza",
    "lat": "10.86846",
    "lng": "13.88205"
  },
  {
    "country": "CM",
    "name": "Kousséri",
    "lat": "12.07689",
    "lng": "15.03063"
  },
  {
    "country": "CM",
    "name": "Kontcha",
    "lat": "7.96667",
    "lng": "12.23333"
  },
  {
    "country": "CM",
    "name": "Bankim",
    "lat": "6.08303",
    "lng": "11.4905"
  },
  {
    "country": "CM",
    "name": "Kaélé",
    "lat": "10.10917",
    "lng": "14.45083"
  },
  {
    "country": "CM",
    "name": "Jakiri",
    "lat": "6.1",
    "lng": "10.65"
  },
  {
    "country": "CM",
    "name": "Guider",
    "lat": "9.9333",
    "lng": "13.94671"
  },
  {
    "country": "CM",
    "name": "Garoua Boulaï",
    "lat": "5.88333",
    "lng": "14.55"
  },
  {
    "country": "CM",
    "name": "Garoua",
    "lat": "9.30143",
    "lng": "13.39771"
  },
  {
    "country": "CM",
    "name": "Fundong",
    "lat": "6.25",
    "lng": "10.26667"
  },
  {
    "country": "CM",
    "name": "Foumbot",
    "lat": "5.50803",
    "lng": "10.6325"
  },
  {
    "country": "CM",
    "name": "Foumban",
    "lat": "5.72662",
    "lng": "10.89865"
  },
  {
    "country": "CM",
    "name": "Fontem",
    "lat": "5.4685",
    "lng": "9.8818"
  },
  {
    "country": "CM",
    "name": "Évodoula",
    "lat": "4.08333",
    "lng": "11.2"
  },
  {
    "country": "CM",
    "name": "Essé",
    "lat": "4.1",
    "lng": "11.9"
  },
  {
    "country": "CM",
    "name": "Eséka",
    "lat": "3.65",
    "lng": "10.76667"
  },
  {
    "country": "CM",
    "name": "Edéa",
    "lat": "3.8",
    "lng": "10.13333"
  },
  {
    "country": "CM",
    "name": "Ébolowa",
    "lat": "2.9",
    "lng": "11.15"
  },
  {
    "country": "CM",
    "name": "Dschang",
    "lat": "5.44397",
    "lng": "10.05332"
  },
  {
    "country": "CM",
    "name": "Doumé",
    "lat": "4.23333",
    "lng": "13.45"
  },
  {
    "country": "CM",
    "name": "Douala",
    "lat": "4.04827",
    "lng": "9.70428"
  },
  {
    "country": "CM",
    "name": "Djohong",
    "lat": "6.83333",
    "lng": "14.7"
  },
  {
    "country": "CM",
    "name": "Dizangué",
    "lat": "3.76667",
    "lng": "9.98333"
  },
  {
    "country": "CM",
    "name": "Dimako",
    "lat": "4.38333",
    "lng": "13.56667"
  },
  {
    "country": "CM",
    "name": "Dibombari",
    "lat": "4.1787",
    "lng": "9.6561"
  },
  {
    "country": "CM",
    "name": "Diang",
    "lat": "4.25",
    "lng": "10.01667"
  },
  {
    "country": "CM",
    "name": "Buea",
    "lat": "4.15342",
    "lng": "9.24231"
  },
  {
    "country": "CM",
    "name": "Bonabéri",
    "lat": "4.07142",
    "lng": "9.68177"
  },
  {
    "country": "CM",
    "name": "Bogo",
    "lat": "10.7336",
    "lng": "14.60928"
  },
  {
    "country": "CM",
    "name": "Bétaré Oya",
    "lat": "5.6",
    "lng": "14.08333"
  },
  {
    "country": "CM",
    "name": "Bertoua",
    "lat": "4.57728",
    "lng": "13.68459"
  },
  {
    "country": "CM",
    "name": "Belo",
    "lat": "6.13333",
    "lng": "10.25"
  },
  {
    "country": "CM",
    "name": "Bélel",
    "lat": "7.05",
    "lng": "14.43333"
  },
  {
    "country": "CM",
    "name": "Bélabo",
    "lat": "4.93333",
    "lng": "13.3"
  },
  {
    "country": "CM",
    "name": "Bekondo",
    "lat": "4.6819",
    "lng": "9.3214"
  },
  {
    "country": "CM",
    "name": "Bazou",
    "lat": "5.06001",
    "lng": "10.46751"
  },
  {
    "country": "CM",
    "name": "Batouri",
    "lat": "4.43333",
    "lng": "14.36667"
  },
  {
    "country": "CM",
    "name": "Batibo",
    "lat": "5.8358",
    "lng": "9.8553"
  },
  {
    "country": "CM",
    "name": "Banyo",
    "lat": "6.75",
    "lng": "11.81667"
  },
  {
    "country": "CM",
    "name": "Bansoa",
    "lat": "5.44836",
    "lng": "10.31355"
  },
  {
    "country": "CM",
    "name": "Ngou",
    "lat": "5.19685",
    "lng": "10.38595"
  },
  {
    "country": "CM",
    "name": "Bangangté",
    "lat": "5.14079",
    "lng": "10.52535"
  },
  {
    "country": "CM",
    "name": "Bandjoun",
    "lat": "5.37568",
    "lng": "10.41326"
  },
  {
    "country": "CM",
    "name": "Bana",
    "lat": "5.14655",
    "lng": "10.27545"
  },
  {
    "country": "CM",
    "name": "Bamusso",
    "lat": "4.4591",
    "lng": "8.9027"
  },
  {
    "country": "CM",
    "name": "Bamendjou",
    "lat": "5.38988",
    "lng": "10.33014"
  },
  {
    "country": "CM",
    "name": "Bamenda",
    "lat": "5.9597",
    "lng": "10.14597"
  },
  {
    "country": "CM",
    "name": "Bali",
    "lat": "5.88737",
    "lng": "10.01176"
  },
  {
    "country": "CM",
    "name": "Bafoussam",
    "lat": "5.47775",
    "lng": "10.41759"
  },
  {
    "country": "CM",
    "name": "Bafia",
    "lat": "4.75",
    "lng": "11.23333"
  },
  {
    "country": "CM",
    "name": "Bafang",
    "lat": "5.15705",
    "lng": "10.1771"
  },
  {
    "country": "CM",
    "name": "Babanki",
    "lat": "6.11667",
    "lng": "10.25"
  },
  {
    "country": "CM",
    "name": "Ambam",
    "lat": "2.38333",
    "lng": "11.28333"
  },
  {
    "country": "CM",
    "name": "Akonolinga",
    "lat": "3.76667",
    "lng": "12.25"
  },
  {
    "country": "CM",
    "name": "Akono",
    "lat": "3.5",
    "lng": "11.33333"
  },
  {
    "country": "CM",
    "name": "Akom II",
    "lat": "2.78333",
    "lng": "10.56667"
  },
  {
    "country": "CM",
    "name": "Abong Mbang",
    "lat": "3.98333",
    "lng": "13.18333"
  },
  {
    "country": "CM",
    "name": "Idenao",
    "lat": "4.2475",
    "lng": "9.00472"
  },
  {
    "country": "CM",
    "name": "Ndom",
    "lat": "4.4978",
    "lng": "9.5628"
  },
  {
    "country": "CM",
    "name": "Somié",
    "lat": "6.45843",
    "lng": "11.43299"
  },
  {
    "country": "CN",
    "name": "Zongga",
    "lat": "29",
    "lng": "85.25"
  },
  {
    "country": "CN",
    "name": "Zito",
    "lat": "30.73893",
    "lng": "95.83613"
  },
  {
    "country": "CN",
    "name": "Zhowagoin",
    "lat": "28.6591",
    "lng": "97.45065"
  },
  {
    "country": "CN",
    "name": "Zhedao",
    "lat": "24.81934",
    "lng": "98.27627"
  },
  {
    "country": "CN",
    "name": "Zhangfeng",
    "lat": "24.22085",
    "lng": "97.78683"
  },
  {
    "country": "CN",
    "name": "Zhamog",
    "lat": "29.86653",
    "lng": "95.75903"
  },
  {
    "country": "CN",
    "name": "Zhadong",
    "lat": "29.65",
    "lng": "84.16667"
  },
  {
    "country": "CN",
    "name": "Zepu",
    "lat": "38.18867",
    "lng": "77.27075"
  },
  {
    "country": "CN",
    "name": "Zangguy",
    "lat": "37.28333",
    "lng": "78.76667"
  },
  {
    "country": "CN",
    "name": "Zaindainxoi",
    "lat": "31.85",
    "lng": "93.66667"
  },
  {
    "country": "CN",
    "name": "Yuhu",
    "lat": "26.10679",
    "lng": "99.98292"
  },
  {
    "country": "CN",
    "name": "Yopurga",
    "lat": "39.23938",
    "lng": "76.76432"
  },
  {
    "country": "CN",
    "name": "Yanduo",
    "lat": "30.65722",
    "lng": "97.5731"
  },
  {
    "country": "CN",
    "name": "Xireg",
    "lat": "36.91866",
    "lng": "98.44463"
  },
  {
    "country": "CN",
    "name": "Xinyuan",
    "lat": "37.3",
    "lng": "99"
  },
  {
    "country": "CN",
    "name": "Rikaze",
    "lat": "29.25",
    "lng": "88.88333"
  },
  {
    "country": "CN",
    "name": "Xêgar",
    "lat": "28.63333",
    "lng": "87.08333"
  },
  {
    "country": "CN",
    "name": "Xarsingma",
    "lat": "27.49402",
    "lng": "88.95296"
  },
  {
    "country": "CN",
    "name": "Xangda",
    "lat": "32.20551",
    "lng": "96.47809"
  },
  {
    "country": "CN",
    "name": "Wangda",
    "lat": "29.67445",
    "lng": "97.83736"
  },
  {
    "country": "CN",
    "name": "Tungdor",
    "lat": "29.2",
    "lng": "94.08333"
  },
  {
    "country": "CN",
    "name": "Toding",
    "lat": "31.48056",
    "lng": "79.79803"
  },
  {
    "country": "CN",
    "name": "Tengyue",
    "lat": "24.99492",
    "lng": "98.51276"
  },
  {
    "country": "CN",
    "name": "Jiuquan",
    "lat": "39.74318",
    "lng": "98.51736"
  },
  {
    "country": "CN",
    "name": "Songmai",
    "lat": "28.71471",
    "lng": "99.28633"
  },
  {
    "country": "CN",
    "name": "Shule",
    "lat": "39.40231",
    "lng": "76.0508"
  },
  {
    "country": "CN",
    "name": "Shiquanhe",
    "lat": "32.50124",
    "lng": "80.09758"
  },
  {
    "country": "CN",
    "name": "Shimen",
    "lat": "25.89479",
    "lng": "99.42936"
  },
  {
    "country": "CN",
    "name": "Dianyang",
    "lat": "24.70261",
    "lng": "99.15919"
  },
  {
    "country": "CN",
    "name": "Shengping",
    "lat": "28.48563",
    "lng": "98.91139"
  },
  {
    "country": "CN",
    "name": "Shangpa",
    "lat": "26.91948",
    "lng": "98.95158"
  },
  {
    "country": "CN",
    "name": "Shache",
    "lat": "38.41667",
    "lng": "77.24056"
  },
  {
    "country": "CN",
    "name": "Segong",
    "lat": "32.21667",
    "lng": "92.11667"
  },
  {
    "country": "CN",
    "name": "Sajia",
    "lat": "28.91667",
    "lng": "88.05"
  },
  {
    "country": "CN",
    "name": "Rutog",
    "lat": "33.41844",
    "lng": "79.63919"
  },
  {
    "country": "CN",
    "name": "Ruoqiang",
    "lat": "39.02003",
    "lng": "88.16465"
  },
  {
    "country": "CN",
    "name": "Racaka",
    "lat": "31.4",
    "lng": "96.51667"
  },
  {
    "country": "CN",
    "name": "Quxar",
    "lat": "29.1",
    "lng": "87.65"
  },
  {
    "country": "CN",
    "name": "Qümong",
    "lat": "32.97771",
    "lng": "98.09795"
  },
  {
    "country": "CN",
    "name": "Qira",
    "lat": "37.02847",
    "lng": "80.80287"
  },
  {
    "country": "CN",
    "name": "Qiemo",
    "lat": "38.13407",
    "lng": "85.52977"
  },
  {
    "country": "CN",
    "name": "Qiangqinxue",
    "lat": "29.26667",
    "lng": "89.9"
  },
  {
    "country": "CN",
    "name": "Qamdo",
    "lat": "31.1304",
    "lng": "97.17982"
  },
  {
    "country": "CN",
    "name": "Jiajuedibu",
    "lat": "30.93333",
    "lng": "88.63333"
  },
  {
    "country": "CN",
    "name": "Qagan Us",
    "lat": "36.39719",
    "lng": "98.01222"
  },
  {
    "country": "CN",
    "name": "Pubu",
    "lat": "31.39625",
    "lng": "90.00958"
  },
  {
    "country": "CN",
    "name": "Guma",
    "lat": "37.6168",
    "lng": "78.28087"
  },
  {
    "country": "CN",
    "name": "Pingyuan",
    "lat": "24.73642",
    "lng": "97.91358"
  },
  {
    "country": "CN",
    "name": "Kequ",
    "lat": "33.96865",
    "lng": "99.90097"
  },
  {
    "country": "CN",
    "name": "Pagnag",
    "lat": "32.26986",
    "lng": "91.68101"
  },
  {
    "country": "CN",
    "name": "Luobuqiongzi",
    "lat": "29.16667",
    "lng": "89.25"
  },
  {
    "country": "CN",
    "name": "Ngamring",
    "lat": "29.23333",
    "lng": "87.16667"
  },
  {
    "country": "CN",
    "name": "Geji",
    "lat": "32.39545",
    "lng": "81.13972"
  },
  {
    "country": "CN",
    "name": "Nangxian",
    "lat": "29.04701",
    "lng": "93.08795"
  },
  {
    "country": "CN",
    "name": "Namling",
    "lat": "29.68527",
    "lng": "89.09556"
  },
  {
    "country": "CN",
    "name": "Nagqu",
    "lat": "31.47678",
    "lng": "92.05729"
  },
  {
    "country": "CN",
    "name": "Karakax",
    "lat": "37.27225",
    "lng": "79.73728"
  },
  {
    "country": "CN",
    "name": "Niya",
    "lat": "37.06553",
    "lng": "82.68933"
  },
  {
    "country": "CN",
    "name": "Mengsuo",
    "lat": "22.60199",
    "lng": "99.55137"
  },
  {
    "country": "CN",
    "name": "Mengmeng",
    "lat": "23.46502",
    "lng": "99.80206"
  },
  {
    "country": "CN",
    "name": "Menglang",
    "lat": "22.56214",
    "lng": "99.91029"
  },
  {
    "country": "CN",
    "name": "Mengdong",
    "lat": "23.16152",
    "lng": "99.20226"
  },
  {
    "country": "CN",
    "name": "Motuo",
    "lat": "29.31329",
    "lng": "95.30741"
  },
  {
    "country": "CN",
    "name": "Maindong",
    "lat": "31.33333",
    "lng": "85.41667"
  },
  {
    "country": "CN",
    "name": "Machali",
    "lat": "34.93333",
    "lng": "98.23333"
  },
  {
    "country": "CN",
    "name": "Luzhang",
    "lat": "25.97309",
    "lng": "98.82345"
  },
  {
    "country": "CN",
    "name": "Luring",
    "lat": "32.26667",
    "lng": "84.2"
  },
  {
    "country": "CN",
    "name": "Lop",
    "lat": "37.07403",
    "lng": "80.18231"
  },
  {
    "country": "CN",
    "name": "Longshan",
    "lat": "24.60089",
    "lng": "98.70418"
  },
  {
    "country": "CN",
    "name": "Lhasa",
    "lat": "29.65",
    "lng": "91.1"
  },
  {
    "country": "CN",
    "name": "Laojunmiao",
    "lat": "39.83333",
    "lng": "97.73333"
  },
  {
    "country": "CN",
    "name": "Laojie",
    "lat": "25.44829",
    "lng": "99.5561"
  },
  {
    "country": "CN",
    "name": "Kashgar",
    "lat": "39.47066",
    "lng": "75.98951"
  },
  {
    "country": "CN",
    "name": "Kangmar",
    "lat": "28.55953",
    "lng": "89.68009"
  },
  {
    "country": "CN",
    "name": "Jomda",
    "lat": "31.4962",
    "lng": "98.21171"
  },
  {
    "country": "CN",
    "name": "Jinta",
    "lat": "39.98333",
    "lng": "98.86667"
  },
  {
    "country": "CN",
    "name": "Jinhua",
    "lat": "26.538",
    "lng": "99.91715"
  },
  {
    "country": "CN",
    "name": "Jinding",
    "lat": "26.43903",
    "lng": "99.44061"
  },
  {
    "country": "CN",
    "name": "Jiayuguan",
    "lat": "39.81121",
    "lng": "98.28618"
  },
  {
    "country": "CN",
    "name": "Jiashi",
    "lat": "39.49554",
    "lng": "76.74282"
  },
  {
    "country": "CN",
    "name": "Hotan",
    "lat": "37.1075",
    "lng": "79.93548"
  },
  {
    "country": "CN",
    "name": "Hongwansi",
    "lat": "38.83514",
    "lng": "99.59865"
  },
  {
    "country": "CN",
    "name": "Gyigang",
    "lat": "28.66667",
    "lng": "97.51667"
  },
  {
    "country": "CN",
    "name": "Jiangzi",
    "lat": "28.92026",
    "lng": "89.59956"
  },
  {
    "country": "CN",
    "name": "Gyangkar",
    "lat": "28.4",
    "lng": "87.8"
  },
  {
    "country": "CN",
    "name": "Gyamotang",
    "lat": "31.53333",
    "lng": "95.43333"
  },
  {
    "country": "CN",
    "name": "Golmud",
    "lat": "36.40672",
    "lng": "94.90061"
  },
  {
    "country": "CN",
    "name": "Gengqing",
    "lat": "31.81649",
    "lng": "98.59579"
  },
  {
    "country": "CN",
    "name": "Gengma",
    "lat": "23.52325",
    "lng": "99.3786"
  },
  {
    "country": "CN",
    "name": "Jiding",
    "lat": "29.36667",
    "lng": "88.25"
  },
  {
    "country": "CN",
    "name": "Gartog",
    "lat": "29.68451",
    "lng": "98.59473"
  },
  {
    "country": "CN",
    "name": "Gaotai Chengguanzhen",
    "lat": "39.34456",
    "lng": "99.80015"
  },
  {
    "country": "CN",
    "name": "Kambaxoi",
    "lat": "28.3",
    "lng": "88.53333"
  },
  {
    "country": "CN",
    "name": "Nansan",
    "lat": "23.79575",
    "lng": "98.80397"
  },
  {
    "country": "CN",
    "name": "Fengshan",
    "lat": "24.58333",
    "lng": "99.9"
  },
  {
    "country": "CN",
    "name": "Domartang",
    "lat": "30.93902",
    "lng": "94.68908"
  },
  {
    "country": "CN",
    "name": "Dêqên",
    "lat": "29.96178",
    "lng": "90.71875"
  },
  {
    "country": "CN",
    "name": "Delingha",
    "lat": "37.376",
    "lng": "97.37457"
  },
  {
    "country": "CN",
    "name": "Dedang",
    "lat": "24.0118",
    "lng": "99.23964"
  },
  {
    "country": "CN",
    "name": "Dartang",
    "lat": "31.93333",
    "lng": "94"
  },
  {
    "country": "CN",
    "name": "Dangchengwan",
    "lat": "39.50011",
    "lng": "95.04081"
  },
  {
    "country": "CN",
    "name": "Chongdui",
    "lat": "28.15",
    "lng": "85.96667"
  },
  {
    "country": "CN",
    "name": "Coka",
    "lat": "30.9054",
    "lng": "94.6695"
  },
  {
    "country": "CN",
    "name": "Cikai",
    "lat": "27.76344",
    "lng": "98.71105"
  },
  {
    "country": "CN",
    "name": "Youdian",
    "lat": "24.82894",
    "lng": "99.59232"
  },
  {
    "country": "CN",
    "name": "Burang",
    "lat": "30.29559",
    "lng": "81.17511"
  },
  {
    "country": "CN",
    "name": "Molo",
    "lat": "30.86004",
    "lng": "98.27297"
  },
  {
    "country": "CN",
    "name": "Baohe",
    "lat": "27.19582",
    "lng": "99.32483"
  },
  {
    "country": "CN",
    "name": "Baima",
    "lat": "30.05752",
    "lng": "96.91852"
  },
  {
    "country": "CN",
    "name": "Zhaosu",
    "lat": "43.12278",
    "lng": "81.07583"
  },
  {
    "country": "CN",
    "name": "Yumen",
    "lat": "40.28333",
    "lng": "97.2"
  },
  {
    "country": "CN",
    "name": "Yuli",
    "lat": "41.33662",
    "lng": "86.25675"
  },
  {
    "country": "CN",
    "name": "Yuanquan",
    "lat": "40.5",
    "lng": "95.8"
  },
  {
    "country": "CN",
    "name": "Yiwu",
    "lat": "43.24918",
    "lng": "94.6943"
  },
  {
    "country": "CN",
    "name": "Yining",
    "lat": "43.97799",
    "lng": "81.51804"
  },
  {
    "country": "CN",
    "name": "Yanqi",
    "lat": "42.06204",
    "lng": "86.56632"
  },
  {
    "country": "CN",
    "name": "Xinyuan",
    "lat": "43.42649",
    "lng": "83.24959"
  },
  {
    "country": "CN",
    "name": "Xinhe",
    "lat": "41.55028",
    "lng": "82.61667"
  },
  {
    "country": "CN",
    "name": "Xayar",
    "lat": "41.23",
    "lng": "82.80583"
  },
  {
    "country": "CN",
    "name": "Wushi",
    "lat": "41.15167",
    "lng": "79.225"
  },
  {
    "country": "CN",
    "name": "Wujiaqu",
    "lat": "44.16963",
    "lng": "87.53497"
  },
  {
    "country": "CN",
    "name": "Wensu",
    "lat": "41.27196",
    "lng": "80.24085"
  },
  {
    "country": "CN",
    "name": "Ürümqi",
    "lat": "43.80096",
    "lng": "87.60046"
  },
  {
    "country": "CN",
    "name": "Urho",
    "lat": "46.11651",
    "lng": "85.67769"
  },
  {
    "country": "CN",
    "name": "Turpan",
    "lat": "42.94769",
    "lng": "89.17886"
  },
  {
    "country": "CN",
    "name": "Toli",
    "lat": "45.93859",
    "lng": "83.60056"
  },
  {
    "country": "CN",
    "name": "Toksun",
    "lat": "42.79359",
    "lng": "88.64163"
  },
  {
    "country": "CN",
    "name": "Tekes",
    "lat": "43.21669",
    "lng": "81.83973"
  },
  {
    "country": "CN",
    "name": "Tacheng",
    "lat": "46.74535",
    "lng": "82.95847"
  },
  {
    "country": "CN",
    "name": "Shihezi",
    "lat": "44.3023",
    "lng": "86.03694"
  },
  {
    "country": "CN",
    "name": "Shanshan",
    "lat": "42.8675",
    "lng": "90.20463"
  },
  {
    "country": "CN",
    "name": "Qitai",
    "lat": "44.02788",
    "lng": "89.5798"
  },
  {
    "country": "CN",
    "name": "Qinghe",
    "lat": "46.66725",
    "lng": "90.37864"
  },
  {
    "country": "CN",
    "name": "Qapqal",
    "lat": "43.80194",
    "lng": "81.08722"
  },
  {
    "country": "CN",
    "name": "Nilka",
    "lat": "43.78894",
    "lng": "82.49599"
  },
  {
    "country": "CN",
    "name": "Mori",
    "lat": "43.82442",
    "lng": "90.19476"
  },
  {
    "country": "CN",
    "name": "Luntai",
    "lat": "41.77389",
    "lng": "84.24417"
  },
  {
    "country": "CN",
    "name": "Kuytun",
    "lat": "44.42707",
    "lng": "84.90069"
  },
  {
    "country": "CN",
    "name": "Kuqa",
    "lat": "41.72778",
    "lng": "82.93639"
  },
  {
    "country": "CN",
    "name": "Korla",
    "lat": "41.76055",
    "lng": "86.15231"
  },
  {
    "country": "CN",
    "name": "Karamay",
    "lat": "45.58473",
    "lng": "84.88724"
  },
  {
    "country": "CN",
    "name": "Kalpin",
    "lat": "40.52755",
    "lng": "79.06577"
  },
  {
    "country": "CN",
    "name": "Jimsar",
    "lat": "43.98333",
    "lng": "89.06667"
  },
  {
    "country": "CN",
    "name": "Yili",
    "lat": "43.9",
    "lng": "81.35"
  },
  {
    "country": "CN",
    "name": "Khutubi",
    "lat": "44.19035",
    "lng": "86.88521"
  },
  {
    "country": "CN",
    "name": "Hoxut",
    "lat": "42.25861",
    "lng": "86.85778"
  },
  {
    "country": "CN",
    "name": "Hoxtolgay",
    "lat": "46.51872",
    "lng": "86.00214"
  },
  {
    "country": "CN",
    "name": "Hejing",
    "lat": "42.31639",
    "lng": "86.38278"
  },
  {
    "country": "CN",
    "name": "Hami",
    "lat": "42.83393",
    "lng": "93.50601"
  },
  {
    "country": "CN",
    "name": "Tokkuztara",
    "lat": "43.46667",
    "lng": "82.14889"
  },
  {
    "country": "CN",
    "name": "Bofeng",
    "lat": "44.15874",
    "lng": "87.97418"
  },
  {
    "country": "CN",
    "name": "Emin",
    "lat": "46.52574",
    "lng": "83.63325"
  },
  {
    "country": "CN",
    "name": "Dushanzi",
    "lat": "44.33333",
    "lng": "84.85"
  },
  {
    "country": "CN",
    "name": "Dabancheng",
    "lat": "43.35833",
    "lng": "88.32004"
  },
  {
    "country": "CN",
    "name": "Changji",
    "lat": "44.00782",
    "lng": "87.30461"
  },
  {
    "country": "CN",
    "name": "Bohu",
    "lat": "41.98434",
    "lng": "86.62198"
  },
  {
    "country": "CN",
    "name": "Barkol",
    "lat": "43.59881",
    "lng": "93.00862"
  },
  {
    "country": "CN",
    "name": "Baijiantan",
    "lat": "45.68928",
    "lng": "85.12441"
  },
  {
    "country": "CN",
    "name": "Baicheng",
    "lat": "41.77389",
    "lng": "81.86889"
  },
  {
    "country": "CN",
    "name": "Aykol",
    "lat": "40.95759",
    "lng": "80.13574"
  },
  {
    "country": "CN",
    "name": "Awat",
    "lat": "40.63837",
    "lng": "80.37965"
  },
  {
    "country": "CN",
    "name": "Aral",
    "lat": "40.54184",
    "lng": "81.26566"
  },
  {
    "country": "CN",
    "name": "Altay",
    "lat": "47.84864",
    "lng": "88.13361"
  },
  {
    "country": "CN",
    "name": "Aksu",
    "lat": "41.18418",
    "lng": "80.27921"
  },
  {
    "country": "CN",
    "name": "Akqi",
    "lat": "40.94152",
    "lng": "78.44379"
  },
  {
    "country": "CN",
    "name": "Shuimogou",
    "lat": "43.82856",
    "lng": "87.6382"
  },
  {
    "country": "CN",
    "name": "Sishilichengzi",
    "lat": "41.96194",
    "lng": "86.47667"
  },
  {
    "country": "CN",
    "name": "Topterek",
    "lat": "47.43403",
    "lng": "85.87113"
  },
  {
    "country": "CN",
    "name": "Xindu",
    "lat": "33.33987",
    "lng": "120.14594"
  },
  {
    "country": "CN",
    "name": "Beigang",
    "lat": "31.79735",
    "lng": "119.87857"
  },
  {
    "country": "CN",
    "name": "Youyupu",
    "lat": "27.5517",
    "lng": "109.135"
  },
  {
    "country": "CN",
    "name": "Zhujiachang",
    "lat": "27.3575",
    "lng": "108.93833"
  },
  {
    "country": "CN",
    "name": "Xujiaba",
    "lat": "27.88472",
    "lng": "108.11361"
  },
  {
    "country": "CN",
    "name": "Qinglong",
    "lat": "28.26291",
    "lng": "108.11234"
  },
  {
    "country": "CN",
    "name": "Sanchahe",
    "lat": "28.49528",
    "lng": "106.42833"
  },
  {
    "country": "CN",
    "name": "Guandou",
    "lat": "31.37829",
    "lng": "118.39759"
  },
  {
    "country": "CN",
    "name": "Yushan",
    "lat": "31.67265",
    "lng": "118.48456"
  },
  {
    "country": "CN",
    "name": "Xianshui",
    "lat": "30.99145",
    "lng": "101.12701"
  },
  {
    "country": "CN",
    "name": "Lintan Chengguanzhen",
    "lat": "34.68885",
    "lng": "103.35242"
  },
  {
    "country": "CN",
    "name": "Mengjin Chengguanzhen",
    "lat": "34.8269",
    "lng": "112.43129"
  },
  {
    "country": "CN",
    "name": "Liaoyang",
    "lat": "37.07977",
    "lng": "113.33986"
  },
  {
    "country": "CN",
    "name": "Zunyi",
    "lat": "27.68667",
    "lng": "106.90722"
  },
  {
    "country": "CN",
    "name": "Zuitou",
    "lat": "34.06219",
    "lng": "107.31266"
  },
  {
    "country": "CN",
    "name": "Zuitai",
    "lat": "33.33083",
    "lng": "105.60467"
  },
  {
    "country": "CN",
    "name": "Zoucheng",
    "lat": "35.40056",
    "lng": "116.96556"
  },
  {
    "country": "CN",
    "name": "Zongyang",
    "lat": "30.69889",
    "lng": "117.20417"
  },
  {
    "country": "CN",
    "name": "Nyinma",
    "lat": "34.00065",
    "lng": "102.07127"
  },
  {
    "country": "CN",
    "name": "Ziyang Chengguanzhen",
    "lat": "32.51917",
    "lng": "108.53232"
  },
  {
    "country": "CN",
    "name": "Yanjiang",
    "lat": "30.12108",
    "lng": "104.64811"
  },
  {
    "country": "CN",
    "name": "Tangdong",
    "lat": "26.00188",
    "lng": "113.25379"
  },
  {
    "country": "CN",
    "name": "Wenchang",
    "lat": "31.63625",
    "lng": "105.15502"
  },
  {
    "country": "CN",
    "name": "Zitong",
    "lat": "30.1782",
    "lng": "105.82991"
  },
  {
    "country": "CN",
    "name": "Ziketan",
    "lat": "35.58621",
    "lng": "99.9879"
  },
  {
    "country": "CN",
    "name": "Zigong",
    "lat": "29.34162",
    "lng": "104.77689"
  },
  {
    "country": "CN",
    "name": "Zhuzhoujiang Miaozuxiang",
    "lat": "26.67528",
    "lng": "110.07194"
  },
  {
    "country": "CN",
    "name": "Zhuzhou",
    "lat": "27.83333",
    "lng": "113.15"
  },
  {
    "country": "CN",
    "name": "Zhuyang",
    "lat": "30.73674",
    "lng": "107.20115"
  },
  {
    "country": "CN",
    "name": "Zhuxi Chengguanzhen",
    "lat": "32.32569",
    "lng": "109.72337"
  },
  {
    "country": "CN",
    "name": "Zhushan Chengguanzhen",
    "lat": "32.22179",
    "lng": "110.23614"
  },
  {
    "country": "CN",
    "name": "Jiahe Chengguanzhen",
    "lat": "25.55936",
    "lng": "112.36352"
  },
  {
    "country": "CN",
    "name": "Zhuqi",
    "lat": "26.1486",
    "lng": "119.10216"
  },
  {
    "country": "CN",
    "name": "Zhuoyang",
    "lat": "26.63003",
    "lng": "119.0215"
  },
  {
    "country": "CN",
    "name": "Zhumadian",
    "lat": "32.97944",
    "lng": "114.02944"
  },
  {
    "country": "CN",
    "name": "Jiangpu",
    "lat": "32.06149",
    "lng": "118.62399"
  },
  {
    "country": "CN",
    "name": "Zhujiajiao",
    "lat": "31.10757",
    "lng": "121.05696"
  },
  {
    "country": "CN",
    "name": "Shangqiu",
    "lat": "34.45",
    "lng": "115.65"
  },
  {
    "country": "CN",
    "name": "Zhuji",
    "lat": "29.71877",
    "lng": "120.24233"
  },
  {
    "country": "CN",
    "name": "Zhouqu Chengguanzhen",
    "lat": "33.78417",
    "lng": "104.36278"
  },
  {
    "country": "CN",
    "name": "Zhushi",
    "lat": "27.08778",
    "lng": "110.67694"
  },
  {
    "country": "CN",
    "name": "Mizhou",
    "lat": "35.99472",
    "lng": "119.3975"
  },
  {
    "country": "CN",
    "name": "Zhuangtou",
    "lat": "39.65778",
    "lng": "117.29167"
  },
  {
    "country": "CN",
    "name": "Zhuanghe",
    "lat": "39.70083",
    "lng": "122.99111"
  },
  {
    "country": "CN",
    "name": "Zhouzhuang",
    "lat": "31.11788",
    "lng": "120.84427"
  },
  {
    "country": "CN",
    "name": "Zhoukou",
    "lat": "33.63333",
    "lng": "114.63333"
  },
  {
    "country": "CN",
    "name": "Zhoukou",
    "lat": "31.03473",
    "lng": "106.40113"
  },
  {
    "country": "CN",
    "name": "Zhoucun",
    "lat": "36.81667",
    "lng": "117.81667"
  },
  {
    "country": "CN",
    "name": "Yuxi",
    "lat": "24.355",
    "lng": "102.54222"
  },
  {
    "country": "CN",
    "name": "Zhongzhou",
    "lat": "30.29402",
    "lng": "108.03296"
  },
  {
    "country": "CN",
    "name": "Zhongzhai",
    "lat": "27.19528",
    "lng": "109.26861"
  },
  {
    "country": "CN",
    "name": "Ningxiang",
    "lat": "37.34",
    "lng": "111.20523"
  },
  {
    "country": "CN",
    "name": "Zhongxinqiao",
    "lat": "39.03794",
    "lng": "117.56062"
  },
  {
    "country": "CN",
    "name": "Zhongxing",
    "lat": "33.70389",
    "lng": "118.67917"
  },
  {
    "country": "CN",
    "name": "Zhongxin",
    "lat": "26.61667",
    "lng": "101.27154"
  },
  {
    "country": "CN",
    "name": "Zhongwei",
    "lat": "37.51129",
    "lng": "105.19067"
  },
  {
    "country": "CN",
    "name": "Zhongshu",
    "lat": "25.0273",
    "lng": "103.66298"
  },
  {
    "country": "CN",
    "name": "Zhongshu",
    "lat": "24.51667",
    "lng": "103.76667"
  },
  {
    "country": "CN",
    "name": "Zhongshan",
    "lat": "24.53333",
    "lng": "111.3"
  },
  {
    "country": "CN",
    "name": "Jinzhong",
    "lat": "26.37595",
    "lng": "103.30639"
  },
  {
    "country": "CN",
    "name": "Ning’an",
    "lat": "37.49753",
    "lng": "105.6765"
  },
  {
    "country": "CN",
    "name": "Zhongmu Chengguanzhen",
    "lat": "34.71145",
    "lng": "113.96559"
  },
  {
    "country": "CN",
    "name": "Kaijiang",
    "lat": "31.03959",
    "lng": "104.67448"
  },
  {
    "country": "CN",
    "name": "Zhonghe",
    "lat": "28.45049",
    "lng": "108.98901"
  },
  {
    "country": "CN",
    "name": "Zhongfang",
    "lat": "27.41139",
    "lng": "109.93194"
  },
  {
    "country": "CN",
    "name": "Zhongfang",
    "lat": "26.60083",
    "lng": "119.42583"
  },
  {
    "country": "CN",
    "name": "Zhongduo",
    "lat": "28.8466",
    "lng": "108.76416"
  },
  {
    "country": "CN",
    "name": "Zhongdeng",
    "lat": "39.59056",
    "lng": "117.35306"
  },
  {
    "country": "CN",
    "name": "Zhongchao",
    "lat": "26.1375",
    "lng": "109.22"
  },
  {
    "country": "CN",
    "name": "Zhongba",
    "lat": "31.77819",
    "lng": "104.73932"
  },
  {
    "country": "CN",
    "name": "Zhong’an",
    "lat": "25.66667",
    "lng": "104.23333"
  },
  {
    "country": "CN",
    "name": "Zhijin",
    "lat": "26.6668",
    "lng": "105.768"
  },
  {
    "country": "CN",
    "name": "Zhijiang",
    "lat": "27.45814",
    "lng": "109.6592"
  },
  {
    "country": "CN",
    "name": "Zhifang",
    "lat": "30.35",
    "lng": "114.31667"
  },
  {
    "country": "CN",
    "name": "Zhicheng",
    "lat": "31.00751",
    "lng": "119.90851"
  },
  {
    "country": "CN",
    "name": "Zhicheng",
    "lat": "30.29556",
    "lng": "111.50472"
  },
  {
    "country": "CN",
    "name": "Zhenzhou",
    "lat": "32.28034",
    "lng": "119.16999"
  },
  {
    "country": "CN",
    "name": "Zhenyuan Chengguanzhen",
    "lat": "35.6775",
    "lng": "107.19639"
  },
  {
    "country": "CN",
    "name": "Wufeng",
    "lat": "27.45",
    "lng": "104.83333"
  },
  {
    "country": "CN",
    "name": "Zhenping Chengguanzhen",
    "lat": "33.03314",
    "lng": "112.23321"
  },
  {
    "country": "CN",
    "name": "Zhenjiang",
    "lat": "32.21086",
    "lng": "119.45508"
  },
  {
    "country": "CN",
    "name": "Zhaobaoshan",
    "lat": "29.9695",
    "lng": "121.68753"
  },
  {
    "country": "CN",
    "name": "Zhenhai",
    "lat": "24.25823",
    "lng": "118.09049"
  },
  {
    "country": "CN",
    "name": "Zhengzhou",
    "lat": "34.75778",
    "lng": "113.64861"
  },
  {
    "country": "CN",
    "name": "Zhenyang",
    "lat": "32.60361",
    "lng": "114.38306"
  },
  {
    "country": "CN",
    "name": "Zhecheng Chengguanzhen",
    "lat": "34.1046",
    "lng": "115.3176"
  },
  {
    "country": "CN",
    "name": "Zhaxi",
    "lat": "27.85081",
    "lng": "104.96874"
  },
  {
    "country": "CN",
    "name": "Qianyou",
    "lat": "33.6775",
    "lng": "109.12333"
  },
  {
    "country": "CN",
    "name": "Zhaozhen",
    "lat": "30.8563",
    "lng": "104.43606"
  },
  {
    "country": "CN",
    "name": "Xinghua",
    "lat": "32.93917",
    "lng": "119.83417"
  },
  {
    "country": "CN",
    "name": "Zhaotong",
    "lat": "27.31667",
    "lng": "103.71667"
  },
  {
    "country": "CN",
    "name": "Zhaoren",
    "lat": "35.20667",
    "lng": "107.79139"
  },
  {
    "country": "CN",
    "name": "Zhaoqing",
    "lat": "23.05116",
    "lng": "112.45972"
  },
  {
    "country": "CN",
    "name": "Zhaoping",
    "lat": "24.17244",
    "lng": "110.78703"
  },
  {
    "country": "CN",
    "name": "Zhaoguli",
    "lat": "39.16673",
    "lng": "117.24191"
  },
  {
    "country": "CN",
    "name": "Zhaogezhuang",
    "lat": "39.78444",
    "lng": "117.19583"
  },
  {
    "country": "CN",
    "name": "Zhaogezhuang",
    "lat": "39.76538",
    "lng": "118.41191"
  },
  {
    "country": "CN",
    "name": "Chaoge",
    "lat": "35.605",
    "lng": "114.18861"
  },
  {
    "country": "CN",
    "name": "Zhaoyuan",
    "lat": "37.36497",
    "lng": "120.40997"
  },
  {
    "country": "CN",
    "name": "Xiping",
    "lat": "25.59784",
    "lng": "103.79613"
  },
  {
    "country": "CN",
    "name": "Zhanjiang",
    "lat": "21.28145",
    "lng": "110.34271"
  },
  {
    "country": "CN",
    "name": "Danzhu",
    "lat": "36.1245",
    "lng": "112.86101"
  },
  {
    "country": "CN",
    "name": "Zhangzhou",
    "lat": "24.51333",
    "lng": "117.65556"
  },
  {
    "country": "CN",
    "name": "Zhangye",
    "lat": "38.93417",
    "lng": "100.45167"
  },
  {
    "country": "CN",
    "name": "Zhangwan",
    "lat": "26.71139",
    "lng": "119.59194"
  },
  {
    "country": "CN",
    "name": "Zhangjiapan",
    "lat": "37.60157",
    "lng": "108.79702"
  },
  {
    "country": "CN",
    "name": "Zhangjiachuan",
    "lat": "34.98756",
    "lng": "106.20902"
  },
  {
    "country": "CN",
    "name": "Zhangguizhuang",
    "lat": "39.0902",
    "lng": "117.30719"
  },
  {
    "country": "CN",
    "name": "Zhanggu",
    "lat": "30.86875",
    "lng": "101.88848"
  },
  {
    "country": "CN",
    "name": "Zibo",
    "lat": "36.79056",
    "lng": "118.06333"
  },
  {
    "country": "CN",
    "name": "Anyang",
    "lat": "36.096",
    "lng": "114.38278"
  },
  {
    "country": "CN",
    "name": "Zhangcheng",
    "lat": "25.84676",
    "lng": "118.93692"
  },
  {
    "country": "CN",
    "name": "Zhaishi Miaozu Dongzuxiang",
    "lat": "26.50083",
    "lng": "110.04444"
  },
  {
    "country": "CN",
    "name": "Zengjia",
    "lat": "32.61957",
    "lng": "106.10118"
  },
  {
    "country": "CN",
    "name": "Zaozhuang",
    "lat": "34.86472",
    "lng": "117.55417"
  },
  {
    "country": "CN",
    "name": "Zaoyang",
    "lat": "32.12722",
    "lng": "112.75417"
  },
  {
    "country": "CN",
    "name": "Zaojiacheng",
    "lat": "39.27706",
    "lng": "117.43574"
  },
  {
    "country": "CN",
    "name": "Zagunao",
    "lat": "31.44618",
    "lng": "103.17662"
  },
  {
    "country": "CN",
    "name": "Yuzhong Chengguanzhen",
    "lat": "35.84278",
    "lng": "104.1125"
  },
  {
    "country": "CN",
    "name": "Yuyue",
    "lat": "30.0182",
    "lng": "113.96325"
  },
  {
    "country": "CN",
    "name": "Yuyao",
    "lat": "30.05",
    "lng": "121.14944"
  },
  {
    "country": "CN",
    "name": "Xiushui",
    "lat": "38.10379",
    "lng": "113.38865"
  },
  {
    "country": "CN",
    "name": "Yingchuan",
    "lat": "34.16278",
    "lng": "113.46389"
  },
  {
    "country": "CN",
    "name": "Yuxia",
    "lat": "34.06153",
    "lng": "108.62905"
  },
  {
    "country": "CN",
    "name": "Yuxi",
    "lat": "28.889",
    "lng": "107.594"
  },
  {
    "country": "CN",
    "name": "Yutian",
    "lat": "39.87861",
    "lng": "117.73917"
  },
  {
    "country": "CN",
    "name": "Jicheng",
    "lat": "37.06359",
    "lng": "112.95769"
  },
  {
    "country": "CN",
    "name": "Kunshan",
    "lat": "31.37762",
    "lng": "120.95431"
  },
  {
    "country": "CN",
    "name": "Yushan",
    "lat": "26.90863",
    "lng": "118.56713"
  },
  {
    "country": "CN",
    "name": "Yuping",
    "lat": "22.97693",
    "lng": "103.71085"
  },
  {
    "country": "CN",
    "name": "Yunyang",
    "lat": "33.44743",
    "lng": "112.71422"
  },
  {
    "country": "CN",
    "name": "Junyang",
    "lat": "28.41667",
    "lng": "115.36667"
  },
  {
    "country": "CN",
    "name": "Yunxian Chengguanzhen",
    "lat": "32.83129",
    "lng": "110.80875"
  },
  {
    "country": "CN",
    "name": "Aihua",
    "lat": "24.41667",
    "lng": "100.1"
  },
  {
    "country": "CN",
    "name": "Yunxixian Chengguanzhen",
    "lat": "32.98276",
    "lng": "110.42306"
  },
  {
    "country": "CN",
    "name": "Yunxi",
    "lat": "31.2264",
    "lng": "105.38614"
  },
  {
    "country": "CN",
    "name": "Yunxi",
    "lat": "29.47328",
    "lng": "113.2458"
  },
  {
    "country": "CN",
    "name": "Yunmeng Chengguanzhen",
    "lat": "31.06251",
    "lng": "113.76545"
  },
  {
    "country": "CN",
    "name": "Yunling",
    "lat": "23.95384",
    "lng": "117.33603"
  },
  {
    "country": "CN",
    "name": "Jinghong",
    "lat": "21.99102",
    "lng": "100.73409"
  },
  {
    "country": "CN",
    "name": "Pizhou",
    "lat": "34.31139",
    "lng": "117.95028"
  },
  {
    "country": "CN",
    "name": "Yunhe",
    "lat": "26.52497",
    "lng": "100.1978"
  },
  {
    "country": "CN",
    "name": "Yunfu",
    "lat": "22.92833",
    "lng": "112.03954"
  },
  {
    "country": "CN",
    "name": "Yuncheng",
    "lat": "35.59833",
    "lng": "115.93472"
  },
  {
    "country": "CN",
    "name": "Yuncheng",
    "lat": "35.02306",
    "lng": "110.99278"
  },
  {
    "country": "CN",
    "name": "Yulinshi",
    "lat": "38.29181",
    "lng": "109.73753"
  },
  {
    "country": "CN",
    "name": "Yulin",
    "lat": "22.63333",
    "lng": "110.15"
  },
  {
    "country": "CN",
    "name": "Yujin",
    "lat": "29.20909",
    "lng": "103.94556"
  },
  {
    "country": "CN",
    "name": "Wulingyuan",
    "lat": "29.34936",
    "lng": "110.54407"
  },
  {
    "country": "CN",
    "name": "Yuguzhuang",
    "lat": "39.64",
    "lng": "117.35889"
  },
  {
    "country": "CN",
    "name": "Yueyang",
    "lat": "36.2896",
    "lng": "111.91454"
  },
  {
    "country": "CN",
    "name": "Yuecheng",
    "lat": "28.64157",
    "lng": "102.5087"
  },
  {
    "country": "CN",
    "name": "Jiulong",
    "lat": "30.53622",
    "lng": "106.43713"
  },
  {
    "country": "CN",
    "name": "Yudong",
    "lat": "29.385",
    "lng": "106.51944"
  },
  {
    "country": "CN",
    "name": "Yuci",
    "lat": "37.68028",
    "lng": "112.73194"
  },
  {
    "country": "CN",
    "name": "Yucheng",
    "lat": "34.92889",
    "lng": "116.46528"
  },
  {
    "country": "CN",
    "name": "Yuanshan",
    "lat": "24.36959",
    "lng": "114.48962"
  },
  {
    "country": "CN",
    "name": "Yuanping",
    "lat": "38.71528",
    "lng": "112.7575"
  },
  {
    "country": "CN",
    "name": "Yuanmou",
    "lat": "25.70589",
    "lng": "101.86875"
  },
  {
    "country": "CN",
    "name": "Yuanling",
    "lat": "28.44861",
    "lng": "110.40222"
  },
  {
    "country": "CN",
    "name": "Qianjiang",
    "lat": "30.421",
    "lng": "112.8919"
  },
  {
    "country": "CN",
    "name": "Yuanjiazhuang",
    "lat": "33.52319",
    "lng": "107.983"
  },
  {
    "country": "CN",
    "name": "Heyuan",
    "lat": "23.73333",
    "lng": "114.68333"
  },
  {
    "country": "CN",
    "name": "Yuanba",
    "lat": "32.32563",
    "lng": "105.96178"
  },
  {
    "country": "CN",
    "name": "Youxian Chengguanzhen",
    "lat": "26.99168",
    "lng": "113.36062"
  },
  {
    "country": "CN",
    "name": "Youxi Chengguanzhen",
    "lat": "26.17361",
    "lng": "118.17889"
  },
  {
    "country": "CN",
    "name": "Youguzhuang",
    "lat": "39.90583",
    "lng": "117.24611"
  },
  {
    "country": "CN",
    "name": "Yongxing Chengguanzhen",
    "lat": "26.12408",
    "lng": "113.12852"
  },
  {
    "country": "CN",
    "name": "Yongqing",
    "lat": "34.74806",
    "lng": "106.12694"
  },
  {
    "country": "CN",
    "name": "Yongning",
    "lat": "28.52449",
    "lng": "114.36576"
  },
  {
    "country": "CN",
    "name": "Yongning",
    "lat": "24.68",
    "lng": "118.69"
  },
  {
    "country": "CN",
    "name": "Yonghe",
    "lat": "39.07528",
    "lng": "117.47556"
  },
  {
    "country": "CN",
    "name": "Zhihe",
    "lat": "36.77996",
    "lng": "110.63956"
  },
  {
    "country": "CN",
    "name": "Yongfu",
    "lat": "25.00402",
    "lng": "109.98185"
  },
  {
    "country": "CN",
    "name": "Yongfeng",
    "lat": "27.42829",
    "lng": "112.18338"
  },
  {
    "country": "CN",
    "name": "Yongding",
    "lat": "26.04122",
    "lng": "101.68642"
  },
  {
    "country": "CN",
    "name": "Yongding",
    "lat": "25.1986",
    "lng": "102.46189"
  },
  {
    "country": "CN",
    "name": "Yongdeng Chengguanzhen",
    "lat": "36.73361",
    "lng": "103.25931"
  },
  {
    "country": "CN",
    "name": "Taocheng",
    "lat": "25.3123",
    "lng": "118.30056"
  },
  {
    "country": "CN",
    "name": "Yongchang Chengguanzhen",
    "lat": "38.27053",
    "lng": "102.02017"
  },
  {
    "country": "CN",
    "name": "Yongchuan",
    "lat": "29.35376",
    "lng": "105.89392"
  },
  {
    "country": "CN",
    "name": "Yongbei",
    "lat": "26.64623",
    "lng": "100.78073"
  },
  {
    "country": "CN",
    "name": "Yong’an",
    "lat": "31.02056",
    "lng": "109.45871"
  },
  {
    "country": "CN",
    "name": "Yong’an",
    "lat": "25.98",
    "lng": "117.36417"
  },
  {
    "country": "CN",
    "name": "Yizhang Chengguanzhen",
    "lat": "25.38323",
    "lng": "112.97897"
  },
  {
    "country": "CN",
    "name": "Yiyang Chengguanzhen",
    "lat": "34.51083",
    "lng": "112.16222"
  },
  {
    "country": "CN",
    "name": "Yitiaoshan",
    "lat": "37.1533",
    "lng": "104.062"
  },
  {
    "country": "CN",
    "name": "Yisuhe",
    "lat": "27.76544",
    "lng": "112.92683"
  },
  {
    "country": "CN",
    "name": "Yishui",
    "lat": "35.78472",
    "lng": "118.62806"
  },
  {
    "country": "CN",
    "name": "Yishi",
    "lat": "35.16497",
    "lng": "110.74598"
  },
  {
    "country": "CN",
    "name": "Yishan",
    "lat": "34.29944",
    "lng": "119.25417"
  },
  {
    "country": "CN",
    "name": "Yisa",
    "lat": "23.33231",
    "lng": "102.44711"
  },
  {
    "country": "CN",
    "name": "Yinying",
    "lat": "37.93694",
    "lng": "113.5575"
  },
  {
    "country": "CN",
    "name": "Yinliu",
    "lat": "39.9825",
    "lng": "117.39639"
  },
  {
    "country": "CN",
    "name": "Eling",
    "lat": "28.00045",
    "lng": "108.40093"
  },
  {
    "country": "CN",
    "name": "Yining",
    "lat": "29.03614",
    "lng": "114.56362"
  },
  {
    "country": "CN",
    "name": "Zhongxiang",
    "lat": "31.16611",
    "lng": "112.58306"
  },
  {
    "country": "CN",
    "name": "Yingxian",
    "lat": "39.55912",
    "lng": "113.18554"
  },
  {
    "country": "CN",
    "name": "Yingshang Chengguanzhen",
    "lat": "32.62945",
    "lng": "116.27013"
  },
  {
    "country": "CN",
    "name": "Yinggen",
    "lat": "19.03833",
    "lng": "109.84"
  },
  {
    "country": "CN",
    "name": "Yingdu",
    "lat": "24.97167",
    "lng": "118.24417"
  },
  {
    "country": "CN",
    "name": "Yingcheng",
    "lat": "24.16588",
    "lng": "113.41267"
  },
  {
    "country": "CN",
    "name": "Chengzhong",
    "lat": "30.94454",
    "lng": "113.55284"
  },
  {
    "country": "CN",
    "name": "Yinchuan",
    "lat": "38.46806",
    "lng": "106.27306"
  },
  {
    "country": "CN",
    "name": "Yima",
    "lat": "34.73806",
    "lng": "111.88389"
  },
  {
    "country": "CN",
    "name": "Yijing",
    "lat": "37.83556",
    "lng": "113.60194"
  },
  {
    "country": "CN",
    "name": "Yigou",
    "lat": "35.81139",
    "lng": "114.31667"
  },
  {
    "country": "CN",
    "name": "Qingzhou",
    "lat": "36.69667",
    "lng": "118.47972"
  },
  {
    "country": "CN",
    "name": "Yichun",
    "lat": "27.83333",
    "lng": "114.4"
  },
  {
    "country": "CN",
    "name": "Yichuan Chengguanzhen",
    "lat": "34.41972",
    "lng": "112.41917"
  },
  {
    "country": "CN",
    "name": "Tangxing",
    "lat": "35.74521",
    "lng": "111.69872"
  },
  {
    "country": "CN",
    "name": "Yicheng",
    "lat": "31.70472",
    "lng": "112.25611"
  },
  {
    "country": "CN",
    "name": "Yicheng",
    "lat": "31.36059",
    "lng": "119.82016"
  },
  {
    "country": "CN",
    "name": "Yichang",
    "lat": "30.71444",
    "lng": "111.28472"
  },
  {
    "country": "CN",
    "name": "Yibin",
    "lat": "28.76667",
    "lng": "104.62383"
  },
  {
    "country": "CN",
    "name": "Yezhou",
    "lat": "30.60369",
    "lng": "109.72333"
  },
  {
    "country": "CN",
    "name": "Kunyang",
    "lat": "33.62",
    "lng": "113.345"
  },
  {
    "country": "CN",
    "name": "Yatunpu",
    "lat": "26.155",
    "lng": "109.62667"
  },
  {
    "country": "CN",
    "name": "Yatou",
    "lat": "37.1566",
    "lng": "122.43762"
  },
  {
    "country": "CN",
    "name": "Yashan",
    "lat": "22.1975",
    "lng": "109.94194"
  },
  {
    "country": "CN",
    "name": "Yaozhou",
    "lat": "34.90528",
    "lng": "108.97"
  },
  {
    "country": "CN",
    "name": "Yaoshi",
    "lat": "27.63944",
    "lng": "109.53028"
  },
  {
    "country": "CN",
    "name": "Yaoshi",
    "lat": "26.29306",
    "lng": "110.78917"
  },
  {
    "country": "CN",
    "name": "Yaohua",
    "lat": "32.12152",
    "lng": "118.8717"
  },
  {
    "country": "CN",
    "name": "Yaodu",
    "lat": "30.1",
    "lng": "117.01667"
  },
  {
    "country": "CN",
    "name": "Yanzhou",
    "lat": "35.55278",
    "lng": "116.82861"
  },
  {
    "country": "CN",
    "name": "Yantian",
    "lat": "26.85333",
    "lng": "119.8575"
  },
  {
    "country": "CN",
    "name": "Yantan",
    "lat": "29.27396",
    "lng": "104.8738"
  },
  {
    "country": "CN",
    "name": "Yantai",
    "lat": "37.47649",
    "lng": "121.44081"
  },
  {
    "country": "CN",
    "name": "Yansi",
    "lat": "29.82365",
    "lng": "118.33792"
  },
  {
    "country": "CN",
    "name": "Yanmen",
    "lat": "27.855",
    "lng": "109.74028"
  },
  {
    "country": "CN",
    "name": "Anling",
    "lat": "34.1089",
    "lng": "114.16983"
  },
  {
    "country": "CN",
    "name": "Yanling",
    "lat": "29.53065",
    "lng": "104.66108"
  },
  {
    "country": "CN",
    "name": "Yanliang",
    "lat": "34.65918",
    "lng": "109.22921"
  },
  {
    "country": "CN",
    "name": "Yankou",
    "lat": "30.35115",
    "lng": "106.28669"
  },
  {
    "country": "CN",
    "name": "Yanjing",
    "lat": "27.42699",
    "lng": "101.50968"
  },
  {
    "country": "CN",
    "name": "Yanjin Chengguanzhen",
    "lat": "35.14083",
    "lng": "114.18778"
  },
  {
    "country": "CN",
    "name": "Yanjing",
    "lat": "28.08228",
    "lng": "104.19497"
  },
  {
    "country": "CN",
    "name": "Yangzhou",
    "lat": "32.39722",
    "lng": "119.43583"
  },
  {
    "country": "CN",
    "name": "Yangzhong",
    "lat": "26.70556",
    "lng": "119.37444"
  },
  {
    "country": "CN",
    "name": "Yangxin",
    "lat": "37.64472",
    "lng": "117.57667"
  },
  {
    "country": "CN",
    "name": "Yuanyang Chengguanzhen",
    "lat": "35.05222",
    "lng": "113.96389"
  },
  {
    "country": "CN",
    "name": "Yangtou",
    "lat": "27.68944",
    "lng": "109.41389"
  },
  {
    "country": "CN",
    "name": "Yangshuo",
    "lat": "24.78081",
    "lng": "110.48967"
  },
  {
    "country": "CN",
    "name": "Zhangjiagang",
    "lat": "31.865",
    "lng": "120.53889"
  },
  {
    "country": "CN",
    "name": "Yangquan",
    "lat": "37.8575",
    "lng": "113.56333"
  },
  {
    "country": "CN",
    "name": "Yangpu",
    "lat": "31.26193",
    "lng": "121.51904"
  },
  {
    "country": "CN",
    "name": "Yangliuqing",
    "lat": "39.1375",
    "lng": "116.99972"
  },
  {
    "country": "CN",
    "name": "Yangling",
    "lat": "34.27173",
    "lng": "108.07891"
  },
  {
    "country": "CN",
    "name": "Yangjinzhuang",
    "lat": "39.885",
    "lng": "117.39806"
  },
  {
    "country": "CN",
    "name": "Yangjiapo",
    "lat": "39.29417",
    "lng": "117.8875"
  },
  {
    "country": "CN",
    "name": "Yanghou",
    "lat": "26.64083",
    "lng": "118.50806"
  },
  {
    "country": "CN",
    "name": "Yanghe",
    "lat": "38.27852",
    "lng": "106.24776"
  },
  {
    "country": "CN",
    "name": "Yanggu",
    "lat": "36.11056",
    "lng": "115.77528"
  },
  {
    "country": "CN",
    "name": "Yangezhuang",
    "lat": "39.99639",
    "lng": "117.69028"
  },
  {
    "country": "CN",
    "name": "Yangcun",
    "lat": "39.36389",
    "lng": "117.06028"
  },
  {
    "country": "CN",
    "name": "Yangcheng",
    "lat": "35.4922",
    "lng": "112.40428"
  },
  {
    "country": "CN",
    "name": "Huamachi",
    "lat": "37.7852",
    "lng": "107.40322"
  },
  {
    "country": "CN",
    "name": "Yancheng",
    "lat": "36.79944",
    "lng": "116.74389"
  },
  {
    "country": "CN",
    "name": "Yancheng Chengguanzhen",
    "lat": "33.58472",
    "lng": "113.98667"
  },
  {
    "country": "CN",
    "name": "Yancheng",
    "lat": "33.3575",
    "lng": "120.1573"
  },
  {
    "country": "CN",
    "name": "Yakou",
    "lat": "24.67194",
    "lng": "118.63722"
  },
  {
    "country": "CN",
    "name": "Yacha",
    "lat": "19.23056",
    "lng": "109.4475"
  },
  {
    "country": "CN",
    "name": "Yucheng",
    "lat": "29.98521",
    "lng": "102.999"
  },
  {
    "country": "CN",
    "name": "Tongshan",
    "lat": "34.18045",
    "lng": "117.15707"
  },
  {
    "country": "CN",
    "name": "Xuyong",
    "lat": "28.16992",
    "lng": "105.43452"
  },
  {
    "country": "CN",
    "name": "Xuyang",
    "lat": "29.45941",
    "lng": "104.41947"
  },
  {
    "country": "CN",
    "name": "Xucheng",
    "lat": "20.32917",
    "lng": "110.16712"
  },
  {
    "country": "CN",
    "name": "Shangrao",
    "lat": "28.45179",
    "lng": "117.94287"
  },
  {
    "country": "CN",
    "name": "Xunyi Chengguanzhen",
    "lat": "35.11732",
    "lng": "108.31275"
  },
  {
    "country": "CN",
    "name": "Xun Xian Chengguanzhen",
    "lat": "35.66473",
    "lng": "114.53458"
  },
  {
    "country": "CN",
    "name": "Xunchang",
    "lat": "28.45433",
    "lng": "104.71498"
  },
  {
    "country": "CN",
    "name": "Xujiang",
    "lat": "26.83945",
    "lng": "116.32011"
  },
  {
    "country": "CN",
    "name": "Xuhui",
    "lat": "31.19594",
    "lng": "121.44709"
  },
  {
    "country": "CN",
    "name": "Funan Chengguanzhen",
    "lat": "32.63678",
    "lng": "115.61494"
  },
  {
    "country": "CN",
    "name": "Xuefeng",
    "lat": "26.35722",
    "lng": "117.19778"
  },
  {
    "country": "CN",
    "name": "Xuchang",
    "lat": "34.03189",
    "lng": "113.86299"
  },
  {
    "country": "CN",
    "name": "Zhushan",
    "lat": "29.99452",
    "lng": "109.47907"
  },
  {
    "country": "CN",
    "name": "Xuanzhou",
    "lat": "30.9525",
    "lng": "118.75528"
  },
  {
    "country": "CN",
    "name": "Xiyan",
    "lat": "26.61639",
    "lng": "110.47361"
  },
  {
    "country": "CN",
    "name": "Leping",
    "lat": "37.61469",
    "lng": "113.66499"
  },
  {
    "country": "CN",
    "name": "Xixiang",
    "lat": "35.16278",
    "lng": "112.865"
  },
  {
    "country": "CN",
    "name": "Xixiang",
    "lat": "32.98703",
    "lng": "107.764"
  },
  {
    "country": "CN",
    "name": "Longquan",
    "lat": "36.69525",
    "lng": "110.95564"
  },
  {
    "country": "CN",
    "name": "Xi Xian Chengguanzhen",
    "lat": "32.34361",
    "lng": "114.72944"
  },
  {
    "country": "CN",
    "name": "Zijin",
    "lat": "33.28917",
    "lng": "111.47444"
  },
  {
    "country": "CN",
    "name": "Xixi",
    "lat": "27.69375",
    "lng": "110.95333"
  },
  {
    "country": "CN",
    "name": "Xiuying",
    "lat": "20.00073",
    "lng": "110.29359"
  },
  {
    "country": "CN",
    "name": "Xiuwu Chengguanzhen",
    "lat": "35.23111",
    "lng": "113.43806"
  },
  {
    "country": "CN",
    "name": "Xiushan",
    "lat": "24.10999",
    "lng": "102.76153"
  },
  {
    "country": "CN",
    "name": "Xiulin",
    "lat": "29.71667",
    "lng": "112.4"
  },
  {
    "country": "CN",
    "name": "Xiugu",
    "lat": "27.91132",
    "lng": "116.77637"
  },
  {
    "country": "CN",
    "name": "Xitangtuo",
    "lat": "39.3224",
    "lng": "117.48821"
  },
  {
    "country": "CN",
    "name": "Xishan",
    "lat": "25.68528",
    "lng": "108.96389"
  },
  {
    "country": "CN",
    "name": "Xisa",
    "lat": "23.45",
    "lng": "104.70775"
  },
  {
    "country": "CN",
    "name": "Baicheng",
    "lat": "33.38639",
    "lng": "114.01583"
  },
  {
    "country": "CN",
    "name": "Xiongzhou",
    "lat": "25.11667",
    "lng": "114.3"
  },
  {
    "country": "CN",
    "name": "Guixi",
    "lat": "28.28857",
    "lng": "117.21329"
  },
  {
    "country": "CN",
    "name": "Xiongshan",
    "lat": "27.36439",
    "lng": "118.85711"
  },
  {
    "country": "CN",
    "name": "Xinzhou",
    "lat": "38.40917",
    "lng": "112.73333"
  },
  {
    "country": "CN",
    "name": "Xinzhou",
    "lat": "30.86667",
    "lng": "114.8"
  },
  {
    "country": "CN",
    "name": "Xinzhou",
    "lat": "24.87234",
    "lng": "105.35117"
  },
  {
    "country": "CN",
    "name": "Xinzhi",
    "lat": "36.49889",
    "lng": "111.70472"
  },
  {
    "country": "CN",
    "name": "Xinhualu",
    "lat": "34.39633",
    "lng": "113.72466"
  },
  {
    "country": "CN",
    "name": "Xinzheng",
    "lat": "31.27491",
    "lng": "106.28714"
  },
  {
    "country": "CN",
    "name": "Xinzhan",
    "lat": "28.38833",
    "lng": "106.85667"
  },
  {
    "country": "CN",
    "name": "Xinyu",
    "lat": "27.83906",
    "lng": "114.84591"
  },
  {
    "country": "CN",
    "name": "Xinyu",
    "lat": "27.80429",
    "lng": "114.93335"
  },
  {
    "country": "CN",
    "name": "Hancheng",
    "lat": "32.51861",
    "lng": "112.35222"
  },
  {
    "country": "CN",
    "name": "Xinyang",
    "lat": "32.12278",
    "lng": "114.06556"
  },
  {
    "country": "CN",
    "name": "Xincheng",
    "lat": "22.70155",
    "lng": "112.22464"
  },
  {
    "country": "CN",
    "name": "Xinxiang",
    "lat": "35.19033",
    "lng": "113.80151"
  },
  {
    "country": "CN",
    "name": "Xinji",
    "lat": "31.6232",
    "lng": "114.874"
  },
  {
    "country": "CN",
    "name": "Longquan",
    "lat": "25.90139",
    "lng": "112.21167"
  },
  {
    "country": "CN",
    "name": "Xintai",
    "lat": "35.90056",
    "lng": "117.75194"
  },
  {
    "country": "CN",
    "name": "Xinshiba",
    "lat": "28.97091",
    "lng": "102.77126"
  },
  {
    "country": "CN",
    "name": "Xinshi",
    "lat": "31.04704",
    "lng": "113.14098"
  },
  {
    "country": "CN",
    "name": "Xinshan",
    "lat": "25.13732",
    "lng": "115.3872"
  },
  {
    "country": "CN",
    "name": "Xinpu",
    "lat": "34.59972",
    "lng": "119.15944"
  },
  {
    "country": "CN",
    "name": "Xinning",
    "lat": "22.6708",
    "lng": "107.88912"
  },
  {
    "country": "CN",
    "name": "Xinmian",
    "lat": "29.23992",
    "lng": "102.37208"
  },
  {
    "country": "CN",
    "name": "Xinling",
    "lat": "31.0253",
    "lng": "110.31816"
  },
  {
    "country": "CN",
    "name": "Xinli",
    "lat": "39.08472",
    "lng": "117.33556"
  },
  {
    "country": "CN",
    "name": "Xinkaikou",
    "lat": "39.67889",
    "lng": "117.19028"
  },
  {
    "country": "CN",
    "name": "Xinjing",
    "lat": "23.20252",
    "lng": "106.38207"
  },
  {
    "country": "CN",
    "name": "Longxing",
    "lat": "35.61297",
    "lng": "111.21925"
  },
  {
    "country": "CN",
    "name": "Xinji",
    "lat": "37.90278",
    "lng": "115.20361"
  },
  {
    "country": "CN",
    "name": "Xining",
    "lat": "36.62554",
    "lng": "101.75739"
  },
  {
    "country": "CN",
    "name": "Xinhuang",
    "lat": "27.37359",
    "lng": "109.13376"
  },
  {
    "country": "CN",
    "name": "Shangmei",
    "lat": "27.74278",
    "lng": "111.29556"
  },
  {
    "country": "CN",
    "name": "Xinhua",
    "lat": "26.88838",
    "lng": "102.93324"
  },
  {
    "country": "CN",
    "name": "Xinhua",
    "lat": "23.6431",
    "lng": "105.65317"
  },
  {
    "country": "CN",
    "name": "Suohe",
    "lat": "34.78722",
    "lng": "113.35806"
  },
  {
    "country": "CN",
    "name": "Weifen",
    "lat": "38.48064",
    "lng": "111.16664"
  },
  {
    "country": "CN",
    "name": "Zhongcheng",
    "lat": "28.30954",
    "lng": "105.23075"
  },
  {
    "country": "CN",
    "name": "Xingtai",
    "lat": "37.06306",
    "lng": "114.49417"
  },
  {
    "country": "CN",
    "name": "Xingguo",
    "lat": "34.85861",
    "lng": "105.66861"
  },
  {
    "country": "CN",
    "name": "Xingguo",
    "lat": "29.92253",
    "lng": "115.30208"
  },
  {
    "country": "CN",
    "name": "Ankang",
    "lat": "32.68",
    "lng": "109.01722"
  },
  {
    "country": "CN",
    "name": "Xing’an",
    "lat": "25.61964",
    "lng": "110.64248"
  },
  {
    "country": "CN",
    "name": "Xindu",
    "lat": "30.82236",
    "lng": "104.15742"
  },
  {
    "country": "CN",
    "name": "Xindou",
    "lat": "31.39648",
    "lng": "100.67847"
  },
  {
    "country": "CN",
    "name": "Xindian",
    "lat": "36.7975",
    "lng": "118.29444"
  },
  {
    "country": "CN",
    "name": "Xindian",
    "lat": "26.12238",
    "lng": "119.30153"
  },
  {
    "country": "CN",
    "name": "Xindian",
    "lat": "24.61006",
    "lng": "118.24068"
  },
  {
    "country": "CN",
    "name": "Xindi",
    "lat": "29.81667",
    "lng": "113.46667"
  },
  {
    "country": "CN",
    "name": "Feicheng",
    "lat": "36.24861",
    "lng": "116.76583"
  },
  {
    "country": "CN",
    "name": "Xincheng",
    "lat": "35.3",
    "lng": "111.66417"
  },
  {
    "country": "CN",
    "name": "Xincheng",
    "lat": "28.01512",
    "lng": "102.84233"
  },
  {
    "country": "CN",
    "name": "Chengdong",
    "lat": "26.57861",
    "lng": "118.73861"
  },
  {
    "country": "CN",
    "name": "Xincheng Chengguanzhen",
    "lat": "24.08613",
    "lng": "108.65261"
  },
  {
    "country": "CN",
    "name": "Xincai",
    "lat": "32.74389",
    "lng": "114.97611"
  },
  {
    "country": "CN",
    "name": "Xin’anjiang",
    "lat": "29.47478",
    "lng": "119.27148"
  },
  {
    "country": "CN",
    "name": "Xin’an Chengguanzhen",
    "lat": "34.7175",
    "lng": "112.13556"
  },
  {
    "country": "CN",
    "name": "Xin’an",
    "lat": "32.43799",
    "lng": "118.40888"
  },
  {
    "country": "CN",
    "name": "Xinan",
    "lat": "26.72",
    "lng": "119.85556"
  },
  {
    "country": "CN",
    "name": "Sanshui",
    "lat": "23.15486",
    "lng": "112.89161"
  },
  {
    "country": "CN",
    "name": "Xinli",
    "lat": "39.84417",
    "lng": "108.73472"
  },
  {
    "country": "CN",
    "name": "Ximei",
    "lat": "24.98773",
    "lng": "118.3858"
  },
  {
    "country": "CN",
    "name": "Xiling",
    "lat": "26.81444",
    "lng": "119.04722"
  },
  {
    "country": "CN",
    "name": "Xihuachi",
    "lat": "35.81639",
    "lng": "108.0125"
  },
  {
    "country": "CN",
    "name": "Wacheng",
    "lat": "33.78333",
    "lng": "114.51667"
  },
  {
    "country": "CN",
    "name": "Xihe",
    "lat": "31.68635",
    "lng": "113.46585"
  },
  {
    "country": "CN",
    "name": "Xigang",
    "lat": "38.55258",
    "lng": "106.34805"
  },
  {
    "country": "CN",
    "name": "Nanjie",
    "lat": "35.73556",
    "lng": "107.63528"
  },
  {
    "country": "CN",
    "name": "Xiedian",
    "lat": "35.42816",
    "lng": "110.81181"
  },
  {
    "country": "CN",
    "name": "Xidu",
    "lat": "26.95629",
    "lng": "112.36829"
  },
  {
    "country": "CN",
    "name": "Xiditou",
    "lat": "39.25375",
    "lng": "117.34814"
  },
  {
    "country": "CN",
    "name": "Xichang",
    "lat": "27.89642",
    "lng": "102.26341"
  },
  {
    "country": "CN",
    "name": "Xibu",
    "lat": "23.69906",
    "lng": "117.42511"
  },
  {
    "country": "CN",
    "name": "Xibing",
    "lat": "26.98139",
    "lng": "119.72472"
  },
  {
    "country": "CN",
    "name": "Xiazhuang",
    "lat": "34.91611",
    "lng": "118.63889"
  },
  {
    "country": "CN",
    "name": "Xiazhen",
    "lat": "34.80222",
    "lng": "117.11167"
  },
  {
    "country": "CN",
    "name": "Xiayi Chengguanzhen",
    "lat": "34.2368",
    "lng": "116.11608"
  },
  {
    "country": "CN",
    "name": "Yaofeng",
    "lat": "35.13861",
    "lng": "111.21222"
  },
  {
    "country": "CN",
    "name": "Xiawuqi",
    "lat": "39.61361",
    "lng": "117.05333"
  },
  {
    "country": "CN",
    "name": "Haining",
    "lat": "30.53629",
    "lng": "120.68638"
  },
  {
    "country": "CN",
    "name": "Zijinglu",
    "lat": "34.76",
    "lng": "112.97139"
  },
  {
    "country": "CN",
    "name": "Xiaoxita",
    "lat": "30.77135",
    "lng": "111.32146"
  },
  {
    "country": "CN",
    "name": "Xiaoxi",
    "lat": "24.35249",
    "lng": "117.29071"
  },
  {
    "country": "CN",
    "name": "Xiaoweizhai",
    "lat": "26.19028",
    "lng": "107.5125"
  },
  {
    "country": "CN",
    "name": "Xiaoshan",
    "lat": "30.16746",
    "lng": "120.25883"
  },
  {
    "country": "CN",
    "name": "Xiaoshajiang",
    "lat": "27.52139",
    "lng": "110.74806"
  },
  {
    "country": "CN",
    "name": "Xiaolongmen",
    "lat": "27.80194",
    "lng": "110.16056"
  },
  {
    "country": "CN",
    "name": "Xiaolingwei",
    "lat": "32.03244",
    "lng": "118.854"
  },
  {
    "country": "CN",
    "name": "Xiaojiang",
    "lat": "22.27296",
    "lng": "109.55184"
  },
  {
    "country": "CN",
    "name": "Xiaohenglong",
    "lat": "27.605",
    "lng": "110.51694"
  },
  {
    "country": "CN",
    "name": "Xiaogan",
    "lat": "30.92689",
    "lng": "113.92221"
  },
  {
    "country": "CN",
    "name": "Xiaodongzhuang",
    "lat": "39.06029",
    "lng": "117.41544"
  },
  {
    "country": "CN",
    "name": "Xiaodian",
    "lat": "39.25412",
    "lng": "117.22747"
  },
  {
    "country": "CN",
    "name": "Xiaodian",
    "lat": "37.73639",
    "lng": "112.55639"
  },
  {
    "country": "CN",
    "name": "Xianyang",
    "lat": "34.33778",
    "lng": "108.70261"
  },
  {
    "country": "CN",
    "name": "Xianxi",
    "lat": "26.33472",
    "lng": "109.64306"
  },
  {
    "country": "CN",
    "name": "Xiantao",
    "lat": "30.3708",
    "lng": "113.44294"
  },
  {
    "country": "CN",
    "name": "Xiantan",
    "lat": "28.81859",
    "lng": "106.1927"
  },
  {
    "country": "CN",
    "name": "Xianshuigu",
    "lat": "38.985",
    "lng": "117.38278"
  },
  {
    "country": "CN",
    "name": "Xianrenwan",
    "lat": "27.75444",
    "lng": "110.32972"
  },
  {
    "country": "CN",
    "name": "Xiannü",
    "lat": "32.42806",
    "lng": "119.56048"
  },
  {
    "country": "CN",
    "name": "Xianning",
    "lat": "29.84347",
    "lng": "114.32201"
  },
  {
    "country": "CN",
    "name": "Xianju",
    "lat": "28.8547",
    "lng": "120.73168"
  },
  {
    "country": "CN",
    "name": "Xiangzhou",
    "lat": "23.97282",
    "lng": "109.66678"
  },
  {
    "country": "CN",
    "name": "Zhuhai",
    "lat": "22.27694",
    "lng": "113.56778"
  },
  {
    "country": "CN",
    "name": "Xiangcheng",
    "lat": "25.46687",
    "lng": "100.56248"
  },
  {
    "country": "CN",
    "name": "Guhan",
    "lat": "36.53547",
    "lng": "113.02528"
  },
  {
    "country": "CN",
    "name": "Wenxing",
    "lat": "28.68208",
    "lng": "112.87864"
  },
  {
    "country": "CN",
    "name": "Xiangxiang",
    "lat": "27.73333",
    "lng": "112.53333"
  },
  {
    "country": "CN",
    "name": "Xiangtan",
    "lat": "27.85",
    "lng": "112.9"
  },
  {
    "country": "CN",
    "name": "Menghai",
    "lat": "21.95322",
    "lng": "100.38409"
  },
  {
    "country": "CN",
    "name": "Changning",
    "lat": "35.97983",
    "lng": "110.82211"
  },
  {
    "country": "CN",
    "name": "Xiangkou",
    "lat": "29.3305",
    "lng": "107.737"
  },
  {
    "country": "CN",
    "name": "Xianghu",
    "lat": "25.8",
    "lng": "116"
  },
  {
    "country": "CN",
    "name": "Zhangwan",
    "lat": "32.08326",
    "lng": "112.16667"
  },
  {
    "country": "CN",
    "name": "Xiangyang",
    "lat": "32.0422",
    "lng": "112.14479"
  },
  {
    "country": "CN",
    "name": "Xiangdong",
    "lat": "27.65207",
    "lng": "113.72406"
  },
  {
    "country": "CN",
    "name": "Xiangcheng Chengguanzhen",
    "lat": "33.84703",
    "lng": "113.4778"
  },
  {
    "country": "CN",
    "name": "Xiancun",
    "lat": "26.93861",
    "lng": "119.36028"
  },
  {
    "country": "CN",
    "name": "Xi’an",
    "lat": "34.25833",
    "lng": "108.92861"
  },
  {
    "country": "CN",
    "name": "Xiamen",
    "lat": "24.47979",
    "lng": "118.08187"
  },
  {
    "country": "CN",
    "name": "Xialiang",
    "lat": "32.07673",
    "lng": "106.77151"
  },
  {
    "country": "CN",
    "name": "Nancheng",
    "lat": "36.94861",
    "lng": "115.99778"
  },
  {
    "country": "CN",
    "name": "Xiajiang",
    "lat": "25.75556",
    "lng": "108.69194"
  },
  {
    "country": "CN",
    "name": "Xiahu",
    "lat": "26.61056",
    "lng": "119.94833"
  },
  {
    "country": "CN",
    "name": "Xiacang",
    "lat": "39.78639",
    "lng": "117.41667"
  },
  {
    "country": "CN",
    "name": "Xiabaishi",
    "lat": "26.81528",
    "lng": "119.67917"
  },
  {
    "country": "CN",
    "name": "Wuzhou",
    "lat": "23.48333",
    "lng": "111.31667"
  },
  {
    "country": "CN",
    "name": "Wuzhong",
    "lat": "37.9867",
    "lng": "106.201"
  },
  {
    "country": "CN",
    "name": "Wuzhen",
    "lat": "30.74536",
    "lng": "120.4851"
  },
  {
    "country": "CN",
    "name": "Yancheng",
    "lat": "38.91538",
    "lng": "111.86928"
  },
  {
    "country": "CN",
    "name": "Wuyun",
    "lat": "28.65388",
    "lng": "120.06693"
  },
  {
    "country": "CN",
    "name": "Wuyuan",
    "lat": "30.51539",
    "lng": "120.94856"
  },
  {
    "country": "CN",
    "name": "Ziyang",
    "lat": "29.24972",
    "lng": "117.85472"
  },
  {
    "country": "CN",
    "name": "Wuyu",
    "lat": "24.33551",
    "lng": "118.14489"
  },
  {
    "country": "CN",
    "name": "Wuquan",
    "lat": "33.44408",
    "lng": "113.5709"
  },
  {
    "country": "CN",
    "name": "Wuyang",
    "lat": "31.9925",
    "lng": "116.24722"
  },
  {
    "country": "CN",
    "name": "Wujin",
    "lat": "30.41131",
    "lng": "103.81302"
  },
  {
    "country": "CN",
    "name": "Wuyang",
    "lat": "26.74278",
    "lng": "110.32833"
  },
  {
    "country": "CN",
    "name": "Wuxue",
    "lat": "29.85058",
    "lng": "115.5525"
  },
  {
    "country": "CN",
    "name": "Wuxuan",
    "lat": "23.62466",
    "lng": "109.65201"
  },
  {
    "country": "CN",
    "name": "Fengzhou",
    "lat": "36.84278",
    "lng": "112.85417"
  },
  {
    "country": "CN",
    "name": "Wushan",
    "lat": "31.07971",
    "lng": "109.87588"
  },
  {
    "country": "CN",
    "name": "Wuxi",
    "lat": "31.56887",
    "lng": "120.28857"
  },
  {
    "country": "CN",
    "name": "Tongxiang",
    "lat": "30.63287",
    "lng": "120.56081"
  },
  {
    "country": "CN",
    "name": "Taicheng",
    "lat": "38.73102",
    "lng": "113.228"
  },
  {
    "country": "CN",
    "name": "Wuqi",
    "lat": "36.92631",
    "lng": "108.17171"
  },
  {
    "country": "CN",
    "name": "Dongyang",
    "lat": "29.26778",
    "lng": "120.22528"
  },
  {
    "country": "CN",
    "name": "Chengxiang",
    "lat": "23.16096",
    "lng": "108.27759"
  },
  {
    "country": "CN",
    "name": "Huaibin Chengguanzhen",
    "lat": "32.46397",
    "lng": "115.40812"
  },
  {
    "country": "CN",
    "name": "Changde",
    "lat": "29.04638",
    "lng": "111.6783"
  },
  {
    "country": "CN",
    "name": "Wujiashan",
    "lat": "30.61702",
    "lng": "114.13166"
  },
  {
    "country": "CN",
    "name": "Wuhu",
    "lat": "31.33728",
    "lng": "118.37351"
  },
  {
    "country": "CN",
    "name": "Wuhe Chengguanzhen",
    "lat": "33.1386",
    "lng": "117.86582"
  },
  {
    "country": "CN",
    "name": "Wuhan",
    "lat": "30.58333",
    "lng": "114.26667"
  },
  {
    "country": "CN",
    "name": "Wuhai",
    "lat": "39.68442",
    "lng": "106.81583"
  },
  {
    "country": "CN",
    "name": "Yakou",
    "lat": "33.29649",
    "lng": "113.52351"
  },
  {
    "country": "CN",
    "name": "Wufeng",
    "lat": "30.2",
    "lng": "110.69081"
  },
  {
    "country": "CN",
    "name": "Wuda",
    "lat": "39.49944",
    "lng": "106.71167"
  },
  {
    "country": "CN",
    "name": "Laocheng",
    "lat": "37.14278",
    "lng": "115.88833"
  },
  {
    "country": "CN",
    "name": "Wucheng",
    "lat": "31.2837",
    "lng": "117.90193"
  },
  {
    "country": "CN",
    "name": "Wucheng",
    "lat": "29.60077",
    "lng": "118.17495"
  },
  {
    "country": "CN",
    "name": "Wenzhou",
    "lat": "27.99942",
    "lng": "120.66682"
  },
  {
    "country": "CN",
    "name": "Wenquan",
    "lat": "34.93528",
    "lng": "113.07333"
  },
  {
    "country": "CN",
    "name": "Wenxian Chengguanzhen",
    "lat": "32.94712",
    "lng": "104.68139"
  },
  {
    "country": "CN",
    "name": "Tongcheng",
    "lat": "35.35468",
    "lng": "111.21608"
  },
  {
    "country": "CN",
    "name": "Fengcheng",
    "lat": "37.43278",
    "lng": "112.02333"
  },
  {
    "country": "CN",
    "name": "Wenshui",
    "lat": "28.45056",
    "lng": "106.52667"
  },
  {
    "country": "CN",
    "name": "Wenshang",
    "lat": "35.7275",
    "lng": "116.49611"
  },
  {
    "country": "CN",
    "name": "Wenquan",
    "lat": "30.84928",
    "lng": "115.6991"
  },
  {
    "country": "CN",
    "name": "Wenping",
    "lat": "27.19306",
    "lng": "103.5273"
  },
  {
    "country": "CN",
    "name": "Wenling",
    "lat": "28.37524",
    "lng": "121.38416"
  },
  {
    "country": "CN",
    "name": "Wenlin",
    "lat": "29.99814",
    "lng": "104.13992"
  },
  {
    "country": "CN",
    "name": "Wenfeng",
    "lat": "27.19899",
    "lng": "115.11963"
  },
  {
    "country": "CN",
    "name": "Tianfu",
    "lat": "37.19723",
    "lng": "122.05228"
  },
  {
    "country": "CN",
    "name": "Wenchang",
    "lat": "19.6157",
    "lng": "110.74894"
  },
  {
    "country": "CN",
    "name": "Weizhou",
    "lat": "31.49267",
    "lng": "103.58491"
  },
  {
    "country": "CN",
    "name": "Weiyuan",
    "lat": "36.85316",
    "lng": "101.99169"
  },
  {
    "country": "CN",
    "name": "Qingyuan",
    "lat": "35.13674",
    "lng": "104.2221"
  },
  {
    "country": "CN",
    "name": "Weiyuan",
    "lat": "23.46831",
    "lng": "100.68354"
  },
  {
    "country": "CN",
    "name": "Mingzhou",
    "lat": "36.9761",
    "lng": "115.25663"
  },
  {
    "country": "CN",
    "name": "Weitang",
    "lat": "30.85021",
    "lng": "120.91138"
  },
  {
    "country": "CN",
    "name": "Weishi Chengguanzhen",
    "lat": "34.41361",
    "lng": "114.18722"
  },
  {
    "country": "CN",
    "name": "Chang’an",
    "lat": "34.15111",
    "lng": "108.945"
  },
  {
    "country": "CN",
    "name": "Weinan",
    "lat": "34.50355",
    "lng": "109.50891"
  },
  {
    "country": "CN",
    "name": "Weihai",
    "lat": "37.50914",
    "lng": "122.11356"
  },
  {
    "country": "CN",
    "name": "Weifang",
    "lat": "36.71",
    "lng": "119.10194"
  },
  {
    "country": "CN",
    "name": "Wanzhi",
    "lat": "31.14687",
    "lng": "118.56708"
  },
  {
    "country": "CN",
    "name": "Wanxian",
    "lat": "30.81544",
    "lng": "108.37089"
  },
  {
    "country": "CN",
    "name": "Wantouqiao",
    "lat": "26.84111",
    "lng": "110.61944"
  },
  {
    "country": "CN",
    "name": "Wansheng",
    "lat": "28.9629",
    "lng": "106.92844"
  },
  {
    "country": "CN",
    "name": "Wanshan",
    "lat": "27.5232",
    "lng": "109.206"
  },
  {
    "country": "CN",
    "name": "Wanning",
    "lat": "18.79931",
    "lng": "110.3841"
  },
  {
    "country": "CN",
    "name": "Wangqinzhuang",
    "lat": "39.22942",
    "lng": "117.08968"
  },
  {
    "country": "CN",
    "name": "Leiyang",
    "lat": "30.12043",
    "lng": "116.68292"
  },
  {
    "country": "CN",
    "name": "Yinzhu",
    "lat": "35.87861",
    "lng": "119.97528"
  },
  {
    "country": "CN",
    "name": "Wangbuzhuang",
    "lat": "39.6775",
    "lng": "117.42861"
  },
  {
    "country": "CN",
    "name": "Anping",
    "lat": "27.86639",
    "lng": "110.11611"
  },
  {
    "country": "CN",
    "name": "Wafangdian",
    "lat": "39.61833",
    "lng": "122.00806"
  },
  {
    "country": "CN",
    "name": "Ulan",
    "lat": "39.09374",
    "lng": "107.98022"
  },
  {
    "country": "CN",
    "name": "Tuzhai",
    "lat": "24.98301",
    "lng": "118.83194"
  },
  {
    "country": "CN",
    "name": "Tuokou",
    "lat": "27.12472",
    "lng": "109.62472"
  },
  {
    "country": "CN",
    "name": "Tuojiang",
    "lat": "27.95472",
    "lng": "109.56798"
  },
  {
    "country": "CN",
    "name": "Tuojiang",
    "lat": "25.18667",
    "lng": "111.57167"
  },
  {
    "country": "CN",
    "name": "Tuodian",
    "lat": "24.66667",
    "lng": "101.63333"
  },
  {
    "country": "CN",
    "name": "Huangshan",
    "lat": "29.71139",
    "lng": "118.3125"
  },
  {
    "country": "CN",
    "name": "Linjiang",
    "lat": "36.3275",
    "lng": "112.88194"
  },
  {
    "country": "CN",
    "name": "Tuncheng",
    "lat": "19.36333",
    "lng": "110.09778"
  },
  {
    "country": "CN",
    "name": "Tubu",
    "lat": "29.04532",
    "lng": "115.81267"
  },
  {
    "country": "CN",
    "name": "Tuanfeng",
    "lat": "30.71361",
    "lng": "114.91613"
  },
  {
    "country": "CN",
    "name": "Touying",
    "lat": "39.96389",
    "lng": "117.21833"
  },
  {
    "country": "CN",
    "name": "Loushanguan",
    "lat": "28.1368",
    "lng": "106.822"
  },
  {
    "country": "CN",
    "name": "Tongzhou",
    "lat": "39.90395",
    "lng": "116.66183"
  },
  {
    "country": "CN",
    "name": "Tongyang",
    "lat": "29.67054",
    "lng": "114.59694"
  },
  {
    "country": "CN",
    "name": "Tongxu Chengguanzhen",
    "lat": "34.47722",
    "lng": "114.45833"
  },
  {
    "country": "CN",
    "name": "Yuhai",
    "lat": "36.98129",
    "lng": "105.90606"
  },
  {
    "country": "CN",
    "name": "Pingxiang",
    "lat": "35.2079",
    "lng": "105.25058"
  },
  {
    "country": "CN",
    "name": "Tongwan",
    "lat": "27.58111",
    "lng": "110.27722"
  },
  {
    "country": "CN",
    "name": "Fuding",
    "lat": "27.32734",
    "lng": "120.21399"
  },
  {
    "country": "CN",
    "name": "Tongren",
    "lat": "27.71722",
    "lng": "109.18528"
  },
  {
    "country": "CN",
    "name": "Tongquan",
    "lat": "25.4",
    "lng": "103.56667"
  },
  {
    "country": "CN",
    "name": "Wusong",
    "lat": "30.95",
    "lng": "117.78333"
  },
  {
    "country": "CN",
    "name": "Tongle",
    "lat": "24.84757",
    "lng": "106.5764"
  },
  {
    "country": "CN",
    "name": "Tonggu",
    "lat": "26.57222",
    "lng": "109.30944"
  },
  {
    "country": "CN",
    "name": "Tongchuan",
    "lat": "31.09407",
    "lng": "105.08731"
  },
  {
    "country": "CN",
    "name": "Tongcheng",
    "lat": "31.03911",
    "lng": "116.97367"
  },
  {
    "country": "CN",
    "name": "Tongbai Chengguanzhen",
    "lat": "32.36417",
    "lng": "113.39639"
  },
  {
    "country": "CN",
    "name": "Tingjiang",
    "lat": "26.07401",
    "lng": "119.50574"
  },
  {
    "country": "CN",
    "name": "Tingdong",
    "lat": "25.82444",
    "lng": "108.6125"
  },
  {
    "country": "CN",
    "name": "Tianzhou",
    "lat": "23.77861",
    "lng": "106.89718"
  },
  {
    "country": "CN",
    "name": "Tiantang",
    "lat": "30.85",
    "lng": "116.35"
  },
  {
    "country": "CN",
    "name": "Tiantai Chengguanzhen",
    "lat": "29.13633",
    "lng": "121.02958"
  },
  {
    "country": "CN",
    "name": "Qincheng",
    "lat": "34.58028",
    "lng": "105.72722"
  },
  {
    "country": "CN",
    "name": "Tianshui",
    "lat": "34.57952",
    "lng": "105.74238"
  },
  {
    "country": "CN",
    "name": "Tianpeng",
    "lat": "30.98664",
    "lng": "103.93933"
  },
  {
    "country": "CN",
    "name": "Tianjin",
    "lat": "39.14222",
    "lng": "117.17667"
  },
  {
    "country": "CN",
    "name": "Wuxue Shi",
    "lat": "29.91525",
    "lng": "115.41432"
  },
  {
    "country": "CN",
    "name": "Tiandiba",
    "lat": "27.70178",
    "lng": "103.24806"
  },
  {
    "country": "CN",
    "name": "Tiandeng",
    "lat": "23.12658",
    "lng": "107.09369"
  },
  {
    "country": "CN",
    "name": "Tianchi",
    "lat": "30.28112",
    "lng": "105.02346"
  },
  {
    "country": "CN",
    "name": "Tiancheng",
    "lat": "29.54022",
    "lng": "114.04155"
  },
  {
    "country": "CN",
    "name": "Tianchang",
    "lat": "32.68497",
    "lng": "119.00932"
  },
  {
    "country": "CN",
    "name": "Chengtangcun",
    "lat": "35.08357",
    "lng": "117.19071"
  },
  {
    "country": "CN",
    "name": "Tengzhou",
    "lat": "23.38806",
    "lng": "110.89116"
  },
  {
    "country": "CN",
    "name": "Temuli",
    "lat": "27.70795",
    "lng": "102.80768"
  },
  {
    "country": "CN",
    "name": "Taozhuang",
    "lat": "34.85",
    "lng": "117.33333"
  },
  {
    "country": "CN",
    "name": "Taozhou",
    "lat": "30.90641",
    "lng": "119.40865"
  },
  {
    "country": "CN",
    "name": "Zhangjiang",
    "lat": "28.91103",
    "lng": "111.4799"
  },
  {
    "country": "CN",
    "name": "Taoyang",
    "lat": "35.40135",
    "lng": "103.85325"
  },
  {
    "country": "CN",
    "name": "Taohuajiang",
    "lat": "28.52361",
    "lng": "112.12528"
  },
  {
    "country": "CN",
    "name": "Taohong",
    "lat": "27.10107",
    "lng": "110.99486"
  },
  {
    "country": "CN",
    "name": "Taocheng",
    "lat": "22.87936",
    "lng": "107.15648"
  },
  {
    "country": "CN",
    "name": "Tanwan",
    "lat": "27.96639",
    "lng": "110.15028"
  },
  {
    "country": "CN",
    "name": "Tantou",
    "lat": "26.03033",
    "lng": "119.59739"
  },
  {
    "country": "CN",
    "name": "Tangzhai",
    "lat": "34.43278",
    "lng": "116.59111"
  },
  {
    "country": "CN",
    "name": "Tangyang Chengguanzhen",
    "lat": "35.91446",
    "lng": "114.35514"
  },
  {
    "country": "CN",
    "name": "Tangshan",
    "lat": "39.63333",
    "lng": "118.18333"
  },
  {
    "country": "CN",
    "name": "Tangping",
    "lat": "22.03177",
    "lng": "111.93537"
  },
  {
    "country": "CN",
    "name": "Tangkou",
    "lat": "26.95417",
    "lng": "119.01278"
  },
  {
    "country": "CN",
    "name": "Tangjiazhuang",
    "lat": "39.74326",
    "lng": "118.45099"
  },
  {
    "country": "CN",
    "name": "Tangjiafang",
    "lat": "26.84",
    "lng": "110.36472"
  },
  {
    "country": "CN",
    "name": "Binhe",
    "lat": "32.68833",
    "lng": "112.8275"
  },
  {
    "country": "CN",
    "name": "Tanggu",
    "lat": "39.02111",
    "lng": "117.64694"
  },
  {
    "country": "CN",
    "name": "Tangdukou",
    "lat": "26.96589",
    "lng": "111.24138"
  },
  {
    "country": "CN",
    "name": "Tancheng",
    "lat": "34.6152",
    "lng": "118.338"
  },
  {
    "country": "CN",
    "name": "Tancheng",
    "lat": "25.50808",
    "lng": "119.80722"
  },
  {
    "country": "CN",
    "name": "Guanghe Chengguanzhen",
    "lat": "35.48153",
    "lng": "103.57604"
  },
  {
    "country": "CN",
    "name": "Taizhou",
    "lat": "32.49069",
    "lng": "119.90812"
  },
  {
    "country": "CN",
    "name": "Taiyuan",
    "lat": "37.86944",
    "lng": "112.56028"
  },
  {
    "country": "CN",
    "name": "Taixing",
    "lat": "32.16667",
    "lng": "120.01361"
  },
  {
    "country": "CN",
    "name": "Taiping",
    "lat": "28.14083",
    "lng": "106.03771"
  },
  {
    "country": "CN",
    "name": "Taikang Chengguanzhen",
    "lat": "34.06667",
    "lng": "114.86667"
  },
  {
    "country": "CN",
    "name": "Jinxi",
    "lat": "30.43226",
    "lng": "116.29217"
  },
  {
    "country": "CN",
    "name": "Taihe Chengguanzhen",
    "lat": "33.16552",
    "lng": "115.64886"
  },
  {
    "country": "CN",
    "name": "Taihe",
    "lat": "30.87123",
    "lng": "105.38454"
  },
  {
    "country": "CN",
    "name": "Mingxing",
    "lat": "37.42639",
    "lng": "112.54417"
  },
  {
    "country": "CN",
    "name": "Taishan",
    "lat": "22.25135",
    "lng": "112.7799"
  },
  {
    "country": "CN",
    "name": "Chengxiang",
    "lat": "31.44778",
    "lng": "121.09389"
  },
  {
    "country": "CN",
    "name": "Tai’an",
    "lat": "36.18528",
    "lng": "117.12"
  },
  {
    "country": "CN",
    "name": "Suzhou",
    "lat": "33.63611",
    "lng": "116.97889"
  },
  {
    "country": "CN",
    "name": "Fuyu",
    "lat": "30.15",
    "lng": "116.11667"
  },
  {
    "country": "CN",
    "name": "Suozhen",
    "lat": "36.95389",
    "lng": "118.10472"
  },
  {
    "country": "CN",
    "name": "Suonan",
    "lat": "35.66653",
    "lng": "103.39792"
  },
  {
    "country": "CN",
    "name": "Suizhou",
    "lat": "31.71111",
    "lng": "113.36306"
  },
  {
    "country": "CN",
    "name": "Sui Xian Chengguanzhen",
    "lat": "34.44797",
    "lng": "115.04439"
  },
  {
    "country": "CN",
    "name": "Suixi",
    "lat": "33.89067",
    "lng": "116.77473"
  },
  {
    "country": "CN",
    "name": "Suicheng",
    "lat": "21.37951",
    "lng": "110.25052"
  },
  {
    "country": "CN",
    "name": "Suishan",
    "lat": "29.60831",
    "lng": "103.48603"
  },
  {
    "country": "CN",
    "name": "Quyang",
    "lat": "33.14472",
    "lng": "113.99028"
  },
  {
    "country": "CN",
    "name": "Suicheng",
    "lat": "33.8963",
    "lng": "117.93307"
  },
  {
    "country": "CN",
    "name": "Suining",
    "lat": "30.50802",
    "lng": "105.57332"
  },
  {
    "country": "CN",
    "name": "Suicheng",
    "lat": "26.83779",
    "lng": "116.83592"
  },
  {
    "country": "CN",
    "name": "Sui’an",
    "lat": "24.08698",
    "lng": "117.60912"
  },
  {
    "country": "CN",
    "name": "Songyuan",
    "lat": "27.62167",
    "lng": "119.05917"
  },
  {
    "country": "CN",
    "name": "Songyuan",
    "lat": "27.5273",
    "lng": "118.77657"
  },
  {
    "country": "CN",
    "name": "Songyang",
    "lat": "25.32511",
    "lng": "103.02981"
  },
  {
    "country": "CN",
    "name": "Song Xian Chengguanzhen",
    "lat": "34.13472",
    "lng": "112.0825"
  },
  {
    "country": "CN",
    "name": "Songkan",
    "lat": "28.54972",
    "lng": "106.85972"
  },
  {
    "country": "CN",
    "name": "Songjiang",
    "lat": "31.03595",
    "lng": "121.2146"
  },
  {
    "country": "CN",
    "name": "Songbai",
    "lat": "31.75685",
    "lng": "110.67252"
  },
  {
    "country": "CN",
    "name": "Siyang",
    "lat": "27.2116",
    "lng": "108.745"
  },
  {
    "country": "CN",
    "name": "Siyang",
    "lat": "22.16841",
    "lng": "107.94309"
  },
  {
    "country": "CN",
    "name": "Sicheng",
    "lat": "33.48936",
    "lng": "117.85679"
  },
  {
    "country": "CN",
    "name": "Sishui",
    "lat": "35.64889",
    "lng": "117.27583"
  },
  {
    "country": "CN",
    "name": "Simenqian",
    "lat": "27.48722",
    "lng": "110.88611"
  },
  {
    "country": "CN",
    "name": "Simao",
    "lat": "22.78863",
    "lng": "100.97481"
  },
  {
    "country": "CN",
    "name": "Sigaozhuang",
    "lat": "39.46778",
    "lng": "117.25028"
  },
  {
    "country": "CN",
    "name": "Si’en",
    "lat": "24.84198",
    "lng": "108.27162"
  },
  {
    "country": "CN",
    "name": "Sicheng",
    "lat": "24.4054",
    "lng": "106.58154"
  },
  {
    "country": "CN",
    "name": "Shucheng",
    "lat": "34.12128",
    "lng": "118.78078"
  },
  {
    "country": "CN",
    "name": "Shuozhou",
    "lat": "39.31583",
    "lng": "112.4225"
  },
  {
    "country": "CN",
    "name": "Shuitou",
    "lat": "36.97306",
    "lng": "111.2091"
  },
  {
    "country": "CN",
    "name": "Shuidatian",
    "lat": "27.85222",
    "lng": "109.60472"
  },
  {
    "country": "CN",
    "name": "Shuikou",
    "lat": "26.3836",
    "lng": "118.73027"
  },
  {
    "country": "CN",
    "name": "Laixi",
    "lat": "36.85917",
    "lng": "120.52694"
  },
  {
    "country": "CN",
    "name": "Shuidong",
    "lat": "21.5134",
    "lng": "111.00184"
  },
  {
    "country": "CN",
    "name": "Shuiche",
    "lat": "27.68694",
    "lng": "110.99972"
  },
  {
    "country": "CN",
    "name": "Shuibian",
    "lat": "27.60805",
    "lng": "115.32636"
  },
  {
    "country": "CN",
    "name": "Shucheng Chengguanzhen",
    "lat": "31.47448",
    "lng": "116.95207"
  },
  {
    "country": "CN",
    "name": "Shuangzhong",
    "lat": "29.74296",
    "lng": "116.22426"
  },
  {
    "country": "CN",
    "name": "Shuangxi",
    "lat": "28.86295",
    "lng": "115.35194"
  },
  {
    "country": "CN",
    "name": "Shuangxi",
    "lat": "27.22833",
    "lng": "109.85583"
  },
  {
    "country": "CN",
    "name": "Shuangxi",
    "lat": "27.02248",
    "lng": "119.0414"
  },
  {
    "country": "CN",
    "name": "Shuangshu",
    "lat": "39.56389",
    "lng": "117.02444"
  },
  {
    "country": "CN",
    "name": "Shuangshipu",
    "lat": "33.91705",
    "lng": "106.52466"
  },
  {
    "country": "CN",
    "name": "Longbo",
    "lat": "25.92922",
    "lng": "111.6222"
  },
  {
    "country": "CN",
    "name": "Dongsheng",
    "lat": "30.57383",
    "lng": "103.92127"
  },
  {
    "country": "CN",
    "name": "Shuangjiang",
    "lat": "30.9424",
    "lng": "108.68129"
  },
  {
    "country": "CN",
    "name": "Shuangjiang",
    "lat": "26.15467",
    "lng": "109.7138"
  },
  {
    "country": "CN",
    "name": "Shuangjiang",
    "lat": "24.17261",
    "lng": "102.40049"
  },
  {
    "country": "CN",
    "name": "Shuanggang",
    "lat": "39.04395",
    "lng": "117.31014"
  },
  {
    "country": "CN",
    "name": "Shuangcheng",
    "lat": "27.24",
    "lng": "119.89444"
  },
  {
    "country": "CN",
    "name": "Chaoyang",
    "lat": "37.90801",
    "lng": "113.15044"
  },
  {
    "country": "CN",
    "name": "Shouchun",
    "lat": "32.58162",
    "lng": "116.79291"
  },
  {
    "country": "CN",
    "name": "Shoushan",
    "lat": "26.96444",
    "lng": "119.16167"
  },
  {
    "country": "CN",
    "name": "Shouguang",
    "lat": "36.88",
    "lng": "118.7375"
  },
  {
    "country": "CN",
    "name": "Shizuishan",
    "lat": "39.23333",
    "lng": "106.76944"
  },
  {
    "country": "CN",
    "name": "Shizilu",
    "lat": "35.17111",
    "lng": "118.82889"
  },
  {
    "country": "CN",
    "name": "Shiyan",
    "lat": "32.6475",
    "lng": "110.77806"
  },
  {
    "country": "CN",
    "name": "Shijiang",
    "lat": "27.08194",
    "lng": "110.79333"
  },
  {
    "country": "CN",
    "name": "Shiwan",
    "lat": "23.00107",
    "lng": "113.077"
  },
  {
    "country": "CN",
    "name": "Shitanjing",
    "lat": "39.23417",
    "lng": "106.34389"
  },
  {
    "country": "CN",
    "name": "Qili",
    "lat": "30.19906",
    "lng": "117.47799"
  },
  {
    "country": "CN",
    "name": "Shishi",
    "lat": "24.74038",
    "lng": "118.62906"
  },
  {
    "country": "CN",
    "name": "Shiqiao",
    "lat": "22.9464",
    "lng": "113.35769"
  },
  {
    "country": "CN",
    "name": "Shiqian",
    "lat": "27.5225",
    "lng": "108.22806"
  },
  {
    "country": "CN",
    "name": "Shiqi",
    "lat": "22.51682",
    "lng": "113.38521"
  },
  {
    "country": "CN",
    "name": "Yilong",
    "lat": "23.69137",
    "lng": "102.48701"
  },
  {
    "country": "CN",
    "name": "Shinan",
    "lat": "22.7439",
    "lng": "109.87428"
  },
  {
    "country": "CN",
    "name": "Chujiang",
    "lat": "29.5771",
    "lng": "111.363"
  },
  {
    "country": "CN",
    "name": "Shima",
    "lat": "24.44647",
    "lng": "117.81216"
  },
  {
    "country": "CN",
    "name": "Lingquan",
    "lat": "36.99949",
    "lng": "110.844"
  },
  {
    "country": "CN",
    "name": "Shilong",
    "lat": "23.11444",
    "lng": "113.84722"
  },
  {
    "country": "CN",
    "name": "Shilu",
    "lat": "19.25984",
    "lng": "109.04884"
  },
  {
    "country": "CN",
    "name": "Tongchuanshi",
    "lat": "35.07474",
    "lng": "109.08495"
  },
  {
    "country": "CN",
    "name": "Shilaorencun",
    "lat": "36.09723",
    "lng": "120.4891"
  },
  {
    "country": "CN",
    "name": "Shijing",
    "lat": "24.61956",
    "lng": "118.42437"
  },
  {
    "country": "CN",
    "name": "Shijiazhuang",
    "lat": "38.04139",
    "lng": "114.47861"
  },
  {
    "country": "CN",
    "name": "Shijiaochang",
    "lat": "28.92444",
    "lng": "106.75611"
  },
  {
    "country": "CN",
    "name": "Shijiao",
    "lat": "23.86949",
    "lng": "113.5284"
  },
  {
    "country": "CN",
    "name": "Gaolan Chengguanzhen",
    "lat": "36.33467",
    "lng": "103.94556"
  },
  {
    "country": "CN",
    "name": "Xincheng",
    "lat": "35.875",
    "lng": "111.43528"
  },
  {
    "country": "CN",
    "name": "Shicheng",
    "lat": "27.10671",
    "lng": "119.33499"
  },
  {
    "country": "CN",
    "name": "Shedian",
    "lat": "33.06128",
    "lng": "112.94259"
  },
  {
    "country": "CN",
    "name": "Shenzhen",
    "lat": "22.54554",
    "lng": "114.0683"
  },
  {
    "country": "CN",
    "name": "Yanta",
    "lat": "36.24111",
    "lng": "115.66722"
  },
  {
    "country": "CN",
    "name": "Dongcheng",
    "lat": "33.41235",
    "lng": "115.08091"
  },
  {
    "country": "CN",
    "name": "Shenjiamen",
    "lat": "29.95763",
    "lng": "122.29802"
  },
  {
    "country": "CN",
    "name": "Shanhu",
    "lat": "29.59583",
    "lng": "120.81667"
  },
  {
    "country": "CN",
    "name": "Shengrenjian",
    "lat": "34.84422",
    "lng": "111.19131"
  },
  {
    "country": "CN",
    "name": "Longquan",
    "lat": "39.08446",
    "lng": "112.19119"
  },
  {
    "country": "CN",
    "name": "Shazikou",
    "lat": "36.115",
    "lng": "120.53722"
  },
  {
    "country": "CN",
    "name": "Shayang",
    "lat": "30.70937",
    "lng": "112.58849"
  },
  {
    "country": "CN",
    "name": "Shawan",
    "lat": "29.41117",
    "lng": "103.54327"
  },
  {
    "country": "CN",
    "name": "Shashi",
    "lat": "30.30722",
    "lng": "112.24472"
  },
  {
    "country": "CN",
    "name": "Shaping",
    "lat": "29.23082",
    "lng": "103.26587"
  },
  {
    "country": "CN",
    "name": "Shaping",
    "lat": "22.77019",
    "lng": "112.95776"
  },
  {
    "country": "CN",
    "name": "Shaoxing",
    "lat": "30.00237",
    "lng": "120.57864"
  },
  {
    "country": "CN",
    "name": "Shaowu",
    "lat": "27.34089",
    "lng": "117.4831"
  },
  {
    "country": "CN",
    "name": "Shaoguan",
    "lat": "24.8",
    "lng": "113.58333"
  },
  {
    "country": "CN",
    "name": "Shanyang",
    "lat": "26.67019",
    "lng": "119.20509"
  },
  {
    "country": "CN",
    "name": "Shancheng",
    "lat": "34.79528",
    "lng": "116.08167"
  },
  {
    "country": "CN",
    "name": "Shanwei",
    "lat": "22.78199",
    "lng": "115.3475"
  },
  {
    "country": "CN",
    "name": "Shantou",
    "lat": "23.36814",
    "lng": "116.71479"
  },
  {
    "country": "CN",
    "name": "Shanting",
    "lat": "35.07528",
    "lng": "117.45778"
  },
  {
    "country": "CN",
    "name": "Shanmen",
    "lat": "27.225",
    "lng": "110.69278"
  },
  {
    "country": "CN",
    "name": "Shanhe",
    "lat": "35.48436",
    "lng": "108.36398"
  },
  {
    "country": "CN",
    "name": "Shangtang",
    "lat": "28.15541",
    "lng": "120.6882"
  },
  {
    "country": "CN",
    "name": "Xincheng",
    "lat": "33.54194",
    "lng": "114.59833"
  },
  {
    "country": "CN",
    "name": "Shangpai",
    "lat": "31.74565",
    "lng": "117.16109"
  },
  {
    "country": "CN",
    "name": "Shangli",
    "lat": "27.8771",
    "lng": "113.792"
  },
  {
    "country": "CN",
    "name": "Jiyuanlu",
    "lat": "34.8225",
    "lng": "113.26722"
  },
  {
    "country": "CN",
    "name": "Shangjie",
    "lat": "25.67106",
    "lng": "99.98025"
  },
  {
    "country": "CN",
    "name": "Linjiang",
    "lat": "25.05167",
    "lng": "116.4203"
  },
  {
    "country": "CN",
    "name": "Shanghai",
    "lat": "31.22222",
    "lng": "121.45806"
  },
  {
    "country": "CN",
    "name": "Shangcheng Chengguanzhen",
    "lat": "31.79528",
    "lng": "115.40111"
  },
  {
    "country": "CN",
    "name": "Shangcang",
    "lat": "39.89944",
    "lng": "117.38806"
  },
  {
    "country": "CN",
    "name": "Chongyang",
    "lat": "33.25922",
    "lng": "114.24204"
  },
  {
    "country": "CN",
    "name": "Qingquan",
    "lat": "38.79312",
    "lng": "101.08868"
  },
  {
    "country": "CN",
    "name": "Shancheng",
    "lat": "26.90053",
    "lng": "117.16312"
  },
  {
    "country": "CN",
    "name": "Shancheng",
    "lat": "24.49155",
    "lng": "117.34568"
  },
  {
    "country": "CN",
    "name": "Shaliuhe",
    "lat": "37.326",
    "lng": "100.13439"
  },
  {
    "country": "CN",
    "name": "Shajiang",
    "lat": "26.7825",
    "lng": "119.96694"
  },
  {
    "country": "CN",
    "name": "Shahe",
    "lat": "39.14165",
    "lng": "100.17836"
  },
  {
    "country": "CN",
    "name": "Shahejie",
    "lat": "29.60794",
    "lng": "115.8872"
  },
  {
    "country": "CN",
    "name": "Shahecheng",
    "lat": "36.93833",
    "lng": "114.50583"
  },
  {
    "country": "CN",
    "name": "Sailaitang",
    "lat": "32.93519",
    "lng": "100.73757"
  },
  {
    "country": "CN",
    "name": "Seke",
    "lat": "32.27146",
    "lng": "100.33316"
  },
  {
    "country": "CN",
    "name": "Sanyuan Chengguanzhen",
    "lat": "34.61472",
    "lng": "108.92833"
  },
  {
    "country": "CN",
    "name": "Sanya",
    "lat": "18.24306",
    "lng": "109.505"
  },
  {
    "country": "CN",
    "name": "Sanshan",
    "lat": "31.22319",
    "lng": "118.22448"
  },
  {
    "country": "CN",
    "name": "Sanming",
    "lat": "26.24861",
    "lng": "117.61861"
  },
  {
    "country": "CN",
    "name": "Sanmao",
    "lat": "32.23931",
    "lng": "119.81536"
  },
  {
    "country": "CN",
    "name": "Sanjiaocheng",
    "lat": "36.89083",
    "lng": "100.99972"
  },
  {
    "country": "CN",
    "name": "Sanjiang",
    "lat": "26.6749",
    "lng": "109.196"
  },
  {
    "country": "CN",
    "name": "Sanjiang",
    "lat": "24.72063",
    "lng": "112.29442"
  },
  {
    "country": "CN",
    "name": "Sangzi",
    "lat": "39.90556",
    "lng": "117.15722"
  },
  {
    "country": "CN",
    "name": "Sangyuan",
    "lat": "37.6256",
    "lng": "116.38259"
  },
  {
    "country": "CN",
    "name": "Sangmu",
    "lat": "28.21528",
    "lng": "106.26889"
  },
  {
    "country": "CN",
    "name": "Sanchakou",
    "lat": "39.78444",
    "lng": "117.31861"
  },
  {
    "country": "CN",
    "name": "Changsha",
    "lat": "22.38124",
    "lng": "112.68492"
  },
  {
    "country": "CN",
    "name": "Ruyang Chengguanzhen",
    "lat": "34.15028",
    "lng": "112.45833"
  },
  {
    "country": "CN",
    "name": "Ruoshui",
    "lat": "27.00194",
    "lng": "109.96667"
  },
  {
    "country": "CN",
    "name": "Rende",
    "lat": "25.55821",
    "lng": "103.27604"
  },
  {
    "country": "CN",
    "name": "Runing",
    "lat": "33.00111",
    "lng": "114.35417"
  },
  {
    "country": "CN",
    "name": "Rulong",
    "lat": "30.94116",
    "lng": "100.31087"
  },
  {
    "country": "CN",
    "name": "Rulin",
    "lat": "26.34704",
    "lng": "110.26627"
  },
  {
    "country": "CN",
    "name": "Guwei",
    "lat": "34.71034",
    "lng": "110.6571"
  },
  {
    "country": "CN",
    "name": "Rucheng",
    "lat": "32.38833",
    "lng": "120.55528"
  },
  {
    "country": "CN",
    "name": "Rucheng Chengguanzhen",
    "lat": "25.53641",
    "lng": "113.71547"
  },
  {
    "country": "CN",
    "name": "Rongwo",
    "lat": "35.51483",
    "lng": "102.016"
  },
  {
    "country": "CN",
    "name": "Rongshui",
    "lat": "25.06667",
    "lng": "109.25"
  },
  {
    "country": "CN",
    "name": "Rongmei",
    "lat": "29.89333",
    "lng": "110.02611"
  },
  {
    "country": "CN",
    "name": "Rongjiawan",
    "lat": "29.15",
    "lng": "113.10243"
  },
  {
    "country": "CN",
    "name": "Rongjiang",
    "lat": "25.66247",
    "lng": "114.75034"
  },
  {
    "country": "CN",
    "name": "Rongcheng",
    "lat": "30.64281",
    "lng": "117.83515"
  },
  {
    "country": "CN",
    "name": "Fuqing",
    "lat": "25.725",
    "lng": "119.37944"
  },
  {
    "country": "CN",
    "name": "Jieyang",
    "lat": "23.5418",
    "lng": "116.36581"
  },
  {
    "country": "CN",
    "name": "Rongcheng",
    "lat": "22.85842",
    "lng": "110.54643"
  },
  {
    "country": "CN",
    "name": "Rizhao",
    "lat": "35.4275",
    "lng": "119.45528"
  },
  {
    "country": "CN",
    "name": "Rifeng",
    "lat": "27.29728",
    "lng": "116.91107"
  },
  {
    "country": "CN",
    "name": "Renqiu",
    "lat": "38.69889",
    "lng": "116.09361"
  },
  {
    "country": "CN",
    "name": "Renhua",
    "lat": "25.09125",
    "lng": "113.74446"
  },
  {
    "country": "CN",
    "name": "Renhe",
    "lat": "26.49926",
    "lng": "101.73861"
  },
  {
    "country": "CN",
    "name": "Renfengzhuang",
    "lat": "39.31139",
    "lng": "117.66222"
  },
  {
    "country": "CN",
    "name": "Quzhou",
    "lat": "28.95944",
    "lng": "118.86861"
  },
  {
    "country": "CN",
    "name": "Quyang",
    "lat": "26.57507",
    "lng": "109.63808"
  },
  {
    "country": "CN",
    "name": "Lechang",
    "lat": "35.64201",
    "lng": "111.46722"
  },
  {
    "country": "CN",
    "name": "Qujing",
    "lat": "25.48333",
    "lng": "103.78333"
  },
  {
    "country": "CN",
    "name": "Qujiang",
    "lat": "30.84206",
    "lng": "106.96785"
  },
  {
    "country": "CN",
    "name": "Qufu",
    "lat": "35.59667",
    "lng": "116.99111"
  },
  {
    "country": "CN",
    "name": "Panlong",
    "lat": "32.80222",
    "lng": "114.01917"
  },
  {
    "country": "CN",
    "name": "Quanzhou",
    "lat": "25.94459",
    "lng": "111.03639"
  },
  {
    "country": "CN",
    "name": "Quanzhou",
    "lat": "24.91389",
    "lng": "118.58583"
  },
  {
    "country": "CN",
    "name": "Chengxiang",
    "lat": "24.74636",
    "lng": "114.52491"
  },
  {
    "country": "CN",
    "name": "Quanjiang",
    "lat": "26.30955",
    "lng": "114.51292"
  },
  {
    "country": "CN",
    "name": "Wuxi",
    "lat": "26.5844",
    "lng": "111.859"
  },
  {
    "country": "CN",
    "name": "Zhaoyu",
    "lat": "37.35528",
    "lng": "112.31667"
  },
  {
    "country": "CN",
    "name": "Qi Xian Chengguanzhen",
    "lat": "34.55",
    "lng": "114.78333"
  },
  {
    "country": "CN",
    "name": "Zhuangyuan",
    "lat": "37.30553",
    "lng": "120.82747"
  },
  {
    "country": "CN",
    "name": "Qiongshan",
    "lat": "20.00583",
    "lng": "110.35417"
  },
  {
    "country": "CN",
    "name": "Qiongxi",
    "lat": "32.79272",
    "lng": "102.54293"
  },
  {
    "country": "CN",
    "name": "Qionghu",
    "lat": "28.84061",
    "lng": "112.37399"
  },
  {
    "country": "CN",
    "name": "Qinzhou",
    "lat": "21.97296",
    "lng": "108.62612"
  },
  {
    "country": "CN",
    "name": "Qinhe",
    "lat": "36.50139",
    "lng": "112.32472"
  },
  {
    "country": "CN",
    "name": "Tanbei",
    "lat": "35.08806",
    "lng": "112.93944"
  },
  {
    "country": "CN",
    "name": "Dingchang",
    "lat": "36.76306",
    "lng": "112.68722"
  },
  {
    "country": "CN",
    "name": "Qinting",
    "lat": "27.12412",
    "lng": "113.94902"
  },
  {
    "country": "CN",
    "name": "Longgang",
    "lat": "35.68941",
    "lng": "112.15798"
  },
  {
    "country": "CN",
    "name": "Qinnan",
    "lat": "33.25306",
    "lng": "119.91333"
  },
  {
    "country": "CN",
    "name": "Qinhuangdao",
    "lat": "39.93167",
    "lng": "119.58833"
  },
  {
    "country": "CN",
    "name": "Qingyuan",
    "lat": "37.61748",
    "lng": "112.32583"
  },
  {
    "country": "CN",
    "name": "Jinjiang",
    "lat": "24.81978",
    "lng": "118.57415"
  },
  {
    "country": "CN",
    "name": "Qinglang",
    "lat": "27.12472",
    "lng": "108.73278"
  },
  {
    "country": "CN",
    "name": "Qingxi",
    "lat": "26.43114",
    "lng": "110.35489"
  },
  {
    "country": "CN",
    "name": "Chengguan",
    "lat": "39.90722",
    "lng": "111.67333"
  },
  {
    "country": "CN",
    "name": "Qingquan",
    "lat": "30.45113",
    "lng": "115.25593"
  },
  {
    "country": "CN",
    "name": "Qingkou",
    "lat": "34.84828",
    "lng": "119.10835"
  },
  {
    "country": "CN",
    "name": "Qingjiangqiao",
    "lat": "26.60444",
    "lng": "110.98528"
  },
  {
    "country": "CN",
    "name": "Huai'an",
    "lat": "33.58861",
    "lng": "119.01917"
  },
  {
    "country": "CN",
    "name": "Qinghua",
    "lat": "35.165",
    "lng": "113.06167"
  },
  {
    "country": "CN",
    "name": "Qingguang",
    "lat": "39.19883",
    "lng": "117.03314"
  },
  {
    "country": "CN",
    "name": "Qingfu",
    "lat": "28.43701",
    "lng": "104.51622"
  },
  {
    "country": "CN",
    "name": "Qingfeng Chengguanzhen",
    "lat": "35.90361",
    "lng": "115.10528"
  },
  {
    "country": "CN",
    "name": "Qingdao",
    "lat": "36.06488",
    "lng": "120.38042"
  },
  {
    "country": "CN",
    "name": "Qingyuan",
    "lat": "23.7",
    "lng": "113.03333"
  },
  {
    "country": "CN",
    "name": "Qincheng",
    "lat": "27.2127",
    "lng": "116.53008"
  },
  {
    "country": "CN",
    "name": "Qimeng",
    "lat": "26.48472",
    "lng": "108.99944"
  },
  {
    "country": "CN",
    "name": "Qishan",
    "lat": "29.84431",
    "lng": "117.71937"
  },
  {
    "country": "CN",
    "name": "Qilidian",
    "lat": "32.18206",
    "lng": "119.40084"
  },
  {
    "country": "CN",
    "name": "Qidu",
    "lat": "26.76528",
    "lng": "119.54722"
  },
  {
    "country": "CN",
    "name": "Hongqiao",
    "lat": "26.76837",
    "lng": "112.10814"
  },
  {
    "country": "CN",
    "name": "Qibu",
    "lat": "26.5075",
    "lng": "119.545"
  },
  {
    "country": "CN",
    "name": "Qiaozhuang",
    "lat": "32.59026",
    "lng": "105.23343"
  },
  {
    "country": "CN",
    "name": "Qiaoxu",
    "lat": "22.95616",
    "lng": "109.76072"
  },
  {
    "country": "CN",
    "name": "Qiaowa",
    "lat": "27.93079",
    "lng": "101.27781"
  },
  {
    "country": "CN",
    "name": "Qiaotou",
    "lat": "36.935",
    "lng": "101.67361"
  },
  {
    "country": "CN",
    "name": "Qiaojiang",
    "lat": "27.93722",
    "lng": "110.67639"
  },
  {
    "country": "CN",
    "name": "Qiaogu",
    "lat": "39.3125",
    "lng": "117.72472"
  },
  {
    "country": "CN",
    "name": "Qianqiu",
    "lat": "34.7423",
    "lng": "111.872"
  },
  {
    "country": "CN",
    "name": "Qianling",
    "lat": "28.71187",
    "lng": "109.64597"
  },
  {
    "country": "CN",
    "name": "Qiancheng",
    "lat": "27.18501",
    "lng": "109.76543"
  },
  {
    "country": "CN",
    "name": "Qabqa",
    "lat": "36.28139",
    "lng": "100.61306"
  },
  {
    "country": "CN",
    "name": "Puzi",
    "lat": "26.98639",
    "lng": "109.77639"
  },
  {
    "country": "CN",
    "name": "Puyang Chengguanzhen",
    "lat": "35.70506",
    "lng": "115.01409"
  },
  {
    "country": "CN",
    "name": "Puyang",
    "lat": "29.45679",
    "lng": "119.88872"
  },
  {
    "country": "CN",
    "name": "Pucheng",
    "lat": "36.41361",
    "lng": "111.095"
  },
  {
    "country": "CN",
    "name": "Puting",
    "lat": "29.33129",
    "lng": "115.75746"
  },
  {
    "country": "CN",
    "name": "Putian",
    "lat": "25.43944",
    "lng": "119.01028"
  },
  {
    "country": "CN",
    "name": "Puqi",
    "lat": "29.71667",
    "lng": "113.88333"
  },
  {
    "country": "CN",
    "name": "Pumiao",
    "lat": "22.75867",
    "lng": "108.48111"
  },
  {
    "country": "CN",
    "name": "Pulandian",
    "lat": "39.39528",
    "lng": "121.96694"
  },
  {
    "country": "CN",
    "name": "Pukou",
    "lat": "26.52222",
    "lng": "109.55583"
  },
  {
    "country": "CN",
    "name": "Puji",
    "lat": "32.23908",
    "lng": "106.45478"
  },
  {
    "country": "CN",
    "name": "Puji",
    "lat": "27.38019",
    "lng": "102.54126"
  },
  {
    "country": "CN",
    "name": "Puhechang",
    "lat": "28.9525",
    "lng": "106.83111"
  },
  {
    "country": "CN",
    "name": "Pucheng Chengguanzhen",
    "lat": "34.95611",
    "lng": "109.58406"
  },
  {
    "country": "CN",
    "name": "Poyang",
    "lat": "28.99242",
    "lng": "116.66754"
  },
  {
    "country": "CN",
    "name": "Potou",
    "lat": "21.26841",
    "lng": "110.43545"
  },
  {
    "country": "CN",
    "name": "Pitong",
    "lat": "30.80993",
    "lng": "103.88253"
  },
  {
    "country": "CN",
    "name": "Pisha",
    "lat": "27.07057",
    "lng": "102.75771"
  },
  {
    "country": "CN",
    "name": "Guhuai",
    "lat": "32.9586",
    "lng": "114.6255"
  },
  {
    "country": "CN",
    "name": "Pingyin",
    "lat": "36.28306",
    "lng": "116.44528"
  },
  {
    "country": "CN",
    "name": "Pingyi",
    "lat": "35.50056",
    "lng": "117.63083"
  },
  {
    "country": "CN",
    "name": "Gutao",
    "lat": "37.2025",
    "lng": "112.17806"
  },
  {
    "country": "CN",
    "name": "Pingxiang",
    "lat": "27.61672",
    "lng": "113.85353"
  },
  {
    "country": "CN",
    "name": "Qingyang",
    "lat": "36.20712",
    "lng": "113.41721"
  },
  {
    "country": "CN",
    "name": "Pingshan",
    "lat": "25.51985",
    "lng": "102.47581"
  },
  {
    "country": "CN",
    "name": "Pingshan",
    "lat": "22.99376",
    "lng": "114.71311"
  },
  {
    "country": "CN",
    "name": "Pingqiao",
    "lat": "32.09583",
    "lng": "114.12028"
  },
  {
    "country": "CN",
    "name": "Pingnan",
    "lat": "23.54218",
    "lng": "110.38946"
  },
  {
    "country": "CN",
    "name": "Pingma",
    "lat": "23.63743",
    "lng": "107.1014"
  },
  {
    "country": "CN",
    "name": "Pingluo Chengguanzhen",
    "lat": "38.90377",
    "lng": "106.54128"
  },
  {
    "country": "CN",
    "name": "Pingliang",
    "lat": "35.53917",
    "lng": "106.68611"
  },
  {
    "country": "CN",
    "name": "Pingle",
    "lat": "24.64522",
    "lng": "110.64306"
  },
  {
    "country": "CN",
    "name": "Hanchang",
    "lat": "28.7",
    "lng": "113.58333"
  },
  {
    "country": "CN",
    "name": "Pingjiang",
    "lat": "25.97056",
    "lng": "108.39528"
  },
  {
    "country": "CN",
    "name": "Pingdu",
    "lat": "36.78444",
    "lng": "119.94639"
  },
  {
    "country": "CN",
    "name": "Pingdu",
    "lat": "27.3863",
    "lng": "114.61018"
  },
  {
    "country": "CN",
    "name": "Pingdingshan",
    "lat": "33.73847",
    "lng": "113.30119"
  },
  {
    "country": "CN",
    "name": "Guanshan",
    "lat": "37.8081",
    "lng": "113.597"
  },
  {
    "country": "CN",
    "name": "Pingchuan",
    "lat": "25.09453",
    "lng": "116.09601"
  },
  {
    "country": "CN",
    "name": "Xinguan",
    "lat": "39.45527",
    "lng": "111.53001"
  },
  {
    "country": "CN",
    "name": "Longcheng",
    "lat": "29.89688",
    "lng": "116.55546"
  },
  {
    "country": "CN",
    "name": "Baiyang",
    "lat": "35.8511",
    "lng": "106.639"
  },
  {
    "country": "CN",
    "name": "Penguanzhuang",
    "lat": "39.48417",
    "lng": "117.81333"
  },
  {
    "country": "CN",
    "name": "Penglai",
    "lat": "30.58217",
    "lng": "105.25141"
  },
  {
    "country": "CN",
    "name": "Pengcheng",
    "lat": "36.43111",
    "lng": "114.17"
  },
  {
    "country": "CN",
    "name": "Peicheng",
    "lat": "34.73611",
    "lng": "116.92472"
  },
  {
    "country": "CN",
    "name": "Panzhuang",
    "lat": "39.33943",
    "lng": "117.4682"
  },
  {
    "country": "CN",
    "name": "Dadukou",
    "lat": "26.5479",
    "lng": "101.70539"
  },
  {
    "country": "CN",
    "name": "Panlian",
    "lat": "26.88778",
    "lng": "102.10836"
  },
  {
    "country": "CN",
    "name": "Panggezhuang",
    "lat": "39.80472",
    "lng": "117.16611"
  },
  {
    "country": "CN",
    "name": "Pandu",
    "lat": "26.23639",
    "lng": "119.45026"
  },
  {
    "country": "CN",
    "name": "Oljoq",
    "lat": "38.17979",
    "lng": "107.47506"
  },
  {
    "country": "CN",
    "name": "Nuojiang",
    "lat": "31.91562",
    "lng": "107.24273"
  },
  {
    "country": "CN",
    "name": "Guang’an",
    "lat": "30.47413",
    "lng": "106.63696"
  },
  {
    "country": "CN",
    "name": "Niushan",
    "lat": "34.52352",
    "lng": "118.76495"
  },
  {
    "country": "CN",
    "name": "Niujiapai",
    "lat": "39.52222",
    "lng": "117.28944"
  },
  {
    "country": "CN",
    "name": "Niudaokou",
    "lat": "39.78611",
    "lng": "117.25222"
  },
  {
    "country": "CN",
    "name": "Ningzhou",
    "lat": "24.1877",
    "lng": "102.917"
  },
  {
    "country": "CN",
    "name": "Shunling",
    "lat": "25.59167",
    "lng": "111.93028"
  },
  {
    "country": "CN",
    "name": "Ningyang",
    "lat": "35.76417",
    "lng": "116.79139"
  },
  {
    "country": "CN",
    "name": "Yutan",
    "lat": "28.25831",
    "lng": "112.56048"
  },
  {
    "country": "CN",
    "name": "Xinning",
    "lat": "35.49506",
    "lng": "107.92038"
  },
  {
    "country": "CN",
    "name": "Fenghuang",
    "lat": "38.9978",
    "lng": "112.29779"
  },
  {
    "country": "CN",
    "name": "Hanyuan",
    "lat": "32.834",
    "lng": "106.25035"
  },
  {
    "country": "CN",
    "name": "Ningling Chengguanzhen",
    "lat": "34.45",
    "lng": "115.31667"
  },
  {
    "country": "CN",
    "name": "Ningjin",
    "lat": "36.9863",
    "lng": "122.502"
  },
  {
    "country": "CN",
    "name": "Ningjin",
    "lat": "37.64985",
    "lng": "116.79328"
  },
  {
    "country": "CN",
    "name": "Ninghe",
    "lat": "39.46194",
    "lng": "117.7625"
  },
  {
    "country": "CN",
    "name": "Ninghai",
    "lat": "37.38422",
    "lng": "121.60859"
  },
  {
    "country": "CN",
    "name": "Ninghai",
    "lat": "29.28917",
    "lng": "121.42472"
  },
  {
    "country": "CN",
    "name": "Ning’er",
    "lat": "23.04053",
    "lng": "101.03683"
  },
  {
    "country": "CN",
    "name": "Ningchegu",
    "lat": "39.15889",
    "lng": "117.6625"
  },
  {
    "country": "CN",
    "name": "Ningbo",
    "lat": "29.87819",
    "lng": "121.54945"
  },
  {
    "country": "CN",
    "name": "Niangxi",
    "lat": "27.30856",
    "lng": "111.43186"
  },
  {
    "country": "CN",
    "name": "Neixiang Chengguanzhen",
    "lat": "33.04667",
    "lng": "111.84361"
  },
  {
    "country": "CN",
    "name": "Neijiang",
    "lat": "29.58354",
    "lng": "105.06216"
  },
  {
    "country": "CN",
    "name": "Neihuang Chengguanzhen",
    "lat": "35.95083",
    "lng": "114.90222"
  },
  {
    "country": "CN",
    "name": "Napo Chengxiangzhen",
    "lat": "23.47944",
    "lng": "105.79157"
  },
  {
    "country": "CN",
    "name": "Nanzhou",
    "lat": "29.35955",
    "lng": "112.40243"
  },
  {
    "country": "CN",
    "name": "Nanzhao Chengguanzhen",
    "lat": "33.49249",
    "lng": "112.42723"
  },
  {
    "country": "CN",
    "name": "Nanzhao",
    "lat": "23.7199",
    "lng": "117.17103"
  },
  {
    "country": "CN",
    "name": "Nanzhang Chengguanzhen",
    "lat": "31.78394",
    "lng": "111.82752"
  },
  {
    "country": "CN",
    "name": "Nanyang",
    "lat": "32.99472",
    "lng": "112.53278"
  },
  {
    "country": "CN",
    "name": "Nanxun",
    "lat": "30.86902",
    "lng": "120.41994"
  },
  {
    "country": "CN",
    "name": "Nanxi",
    "lat": "28.84209",
    "lng": "104.97958"
  },
  {
    "country": "CN",
    "name": "Nantong",
    "lat": "32.03028",
    "lng": "120.87472"
  },
  {
    "country": "CN",
    "name": "Nansha",
    "lat": "23.18037",
    "lng": "102.8333"
  },
  {
    "country": "CN",
    "name": "Nanrenfu",
    "lat": "39.64611",
    "lng": "117.19167"
  },
  {
    "country": "CN",
    "name": "Pucheng",
    "lat": "27.92333",
    "lng": "118.53333"
  },
  {
    "country": "CN",
    "name": "Yongle",
    "lat": "33.26465",
    "lng": "104.23278"
  },
  {
    "country": "CN",
    "name": "Nanping",
    "lat": "26.645",
    "lng": "118.17361"
  },
  {
    "country": "CN",
    "name": "Nanpi",
    "lat": "38.03333",
    "lng": "116.7"
  },
  {
    "country": "CN",
    "name": "Nanning",
    "lat": "22.81667",
    "lng": "108.31667"
  },
  {
    "country": "CN",
    "name": "Nanmuping",
    "lat": "27.31111",
    "lng": "109.67861"
  },
  {
    "country": "CN",
    "name": "Nanmaizhu",
    "lat": "39.5025",
    "lng": "117.74472"
  },
  {
    "country": "CN",
    "name": "Nanma",
    "lat": "36.18478",
    "lng": "118.15486"
  },
  {
    "country": "CN",
    "name": "Nanlong",
    "lat": "31.35333",
    "lng": "106.06309"
  },
  {
    "country": "CN",
    "name": "Jishan",
    "lat": "30.92149",
    "lng": "118.33017"
  },
  {
    "country": "CN",
    "name": "Nanle Chengguanzhen",
    "lat": "36.07616",
    "lng": "115.19905"
  },
  {
    "country": "CN",
    "name": "Nankang",
    "lat": "29.44654",
    "lng": "116.04068"
  },
  {
    "country": "CN",
    "name": "Nanjing",
    "lat": "32.06167",
    "lng": "118.77778"
  },
  {
    "country": "CN",
    "name": "Nanjie",
    "lat": "23.63414",
    "lng": "112.43478"
  },
  {
    "country": "CN",
    "name": "Nanjiang",
    "lat": "32.35389",
    "lng": "106.83238"
  },
  {
    "country": "CN",
    "name": "Nanjian",
    "lat": "25.04801",
    "lng": "100.53224"
  },
  {
    "country": "CN",
    "name": "Guantao",
    "lat": "36.54099",
    "lng": "115.28293"
  },
  {
    "country": "CN",
    "name": "Nangong",
    "lat": "37.35806",
    "lng": "115.37444"
  },
  {
    "country": "CN",
    "name": "Nanfeng",
    "lat": "23.72695",
    "lng": "111.79723"
  },
  {
    "country": "CN",
    "name": "Duji",
    "lat": "33.99765",
    "lng": "116.8284"
  },
  {
    "country": "CN",
    "name": "Nandu",
    "lat": "22.8525",
    "lng": "110.82333"
  },
  {
    "country": "CN",
    "name": "Nanding",
    "lat": "36.74833",
    "lng": "118.05583"
  },
  {
    "country": "CN",
    "name": "Nandan Chengguanzhen",
    "lat": "25.01036",
    "lng": "107.55712"
  },
  {
    "country": "CN",
    "name": "Nancun",
    "lat": "35.4635",
    "lng": "112.796"
  },
  {
    "country": "CN",
    "name": "Nanchong",
    "lat": "30.79508",
    "lng": "106.08473"
  },
  {
    "country": "CN",
    "name": "Nanchangshan",
    "lat": "37.91522",
    "lng": "120.73247"
  },
  {
    "country": "CN",
    "name": "Nanchang",
    "lat": "28.68396",
    "lng": "115.85306"
  },
  {
    "country": "CN",
    "name": "Nancang",
    "lat": "39.20409",
    "lng": "117.13625"
  },
  {
    "country": "CN",
    "name": "Nancaicun",
    "lat": "39.47528",
    "lng": "117.01611"
  },
  {
    "country": "CN",
    "name": "Nanbin",
    "lat": "29.9994",
    "lng": "108.10913"
  },
  {
    "country": "CN",
    "name": "Nan’an",
    "lat": "25.39977",
    "lng": "114.36218"
  },
  {
    "country": "CN",
    "name": "Gaoyao",
    "lat": "23.02432",
    "lng": "112.44555"
  },
  {
    "country": "CN",
    "name": "Nada",
    "lat": "19.52257",
    "lng": "109.5786"
  },
  {
    "country": "CN",
    "name": "Muxi",
    "lat": "28.95964",
    "lng": "103.90086"
  },
  {
    "country": "CN",
    "name": "Mucheng",
    "lat": "35.09556",
    "lng": "113.39"
  },
  {
    "country": "CN",
    "name": "Miyang",
    "lat": "24.40417",
    "lng": "103.44278"
  },
  {
    "country": "CN",
    "name": "Qingping",
    "lat": "34.53656",
    "lng": "113.37526"
  },
  {
    "country": "CN",
    "name": "Chengjiao Chengguanzhen",
    "lat": "34.43583",
    "lng": "104.03056"
  },
  {
    "country": "CN",
    "name": "Minquan Chengguanzhen",
    "lat": "34.66449",
    "lng": "115.13299"
  },
  {
    "country": "CN",
    "name": "Sanlei",
    "lat": "38.62639",
    "lng": "103.08833"
  },
  {
    "country": "CN",
    "name": "Hongshui",
    "lat": "38.42457",
    "lng": "100.7926"
  },
  {
    "country": "CN",
    "name": "Minjian",
    "lat": "28.84622",
    "lng": "103.54575"
  },
  {
    "country": "CN",
    "name": "Mingshui",
    "lat": "36.71667",
    "lng": "117.5"
  },
  {
    "country": "CN",
    "name": "Mingguang",
    "lat": "32.78017",
    "lng": "117.96378"
  },
  {
    "country": "CN",
    "name": "Minggang",
    "lat": "32.45861",
    "lng": "114.04861"
  },
  {
    "country": "CN",
    "name": "Mingfeng",
    "lat": "31.06167",
    "lng": "111.64278"
  },
  {
    "country": "CN",
    "name": "Min’an",
    "lat": "29.4595",
    "lng": "109.437"
  },
  {
    "country": "CN",
    "name": "Min’an",
    "lat": "26.04962",
    "lng": "119.49964"
  },
  {
    "country": "CN",
    "name": "Miluo Chengguanzhen",
    "lat": "28.8107",
    "lng": "113.06616"
  },
  {
    "country": "CN",
    "name": "Micheng",
    "lat": "25.32037",
    "lng": "100.49931"
  },
  {
    "country": "CN",
    "name": "Jiannan",
    "lat": "31.34355",
    "lng": "104.19588"
  },
  {
    "country": "CN",
    "name": "Mianyang",
    "lat": "31.46784",
    "lng": "104.68168"
  },
  {
    "country": "CN",
    "name": "Mianyang",
    "lat": "33.15703",
    "lng": "106.69445"
  },
  {
    "country": "CN",
    "name": "Chengxiang",
    "lat": "28.55262",
    "lng": "102.1682"
  },
  {
    "country": "CN",
    "name": "Mianchi Chengguanzhen",
    "lat": "34.75417",
    "lng": "111.75944"
  },
  {
    "country": "CN",
    "name": "Mentougou",
    "lat": "39.93819",
    "lng": "116.09307"
  },
  {
    "country": "CN",
    "name": "Wenlan",
    "lat": "23.36002",
    "lng": "103.43684"
  },
  {
    "country": "CN",
    "name": "Mengyin",
    "lat": "35.70694",
    "lng": "117.92639"
  },
  {
    "country": "CN",
    "name": "Huichang",
    "lat": "34.90376",
    "lng": "112.78426"
  },
  {
    "country": "CN",
    "name": "Mengshan",
    "lat": "24.21405",
    "lng": "110.51775"
  },
  {
    "country": "CN",
    "name": "Mengquan",
    "lat": "39.82528",
    "lng": "117.47667"
  },
  {
    "country": "CN",
    "name": "Menglie",
    "lat": "22.55967",
    "lng": "101.8679"
  },
  {
    "country": "CN",
    "name": "Mengla",
    "lat": "21.46859",
    "lng": "101.55069"
  },
  {
    "country": "CN",
    "name": "Mengcheng Chengguanzhen",
    "lat": "33.26611",
    "lng": "116.56605"
  },
  {
    "country": "CN",
    "name": "Meizhou",
    "lat": "24.28859",
    "lng": "116.11768"
  },
  {
    "country": "CN",
    "name": "Meixing",
    "lat": "30.99907",
    "lng": "102.36019"
  },
  {
    "country": "CN",
    "name": "Meishan",
    "lat": "31.72913",
    "lng": "115.91241"
  },
  {
    "country": "CN",
    "name": "Wuchuan",
    "lat": "21.45713",
    "lng": "110.76591"
  },
  {
    "country": "CN",
    "name": "Meilin",
    "lat": "25.87308",
    "lng": "115.0108"
  },
  {
    "country": "CN",
    "name": "Meijiang",
    "lat": "26.47583",
    "lng": "116.015"
  },
  {
    "country": "CN",
    "name": "Meicheng",
    "lat": "30.63449",
    "lng": "116.5798"
  },
  {
    "country": "CN",
    "name": "Meicheng",
    "lat": "26.21528",
    "lng": "118.86111"
  },
  {
    "country": "CN",
    "name": "Meichang",
    "lat": "39.36611",
    "lng": "117.18056"
  },
  {
    "country": "CN",
    "name": "Mazhuang",
    "lat": "39.20947",
    "lng": "117.13311"
  },
  {
    "country": "CN",
    "name": "Mazhang",
    "lat": "21.27574",
    "lng": "110.32212"
  },
  {
    "country": "CN",
    "name": "Xinmatou",
    "lat": "36.81802",
    "lng": "115.17047"
  },
  {
    "country": "CN",
    "name": "Matou",
    "lat": "23.35534",
    "lng": "107.5564"
  },
  {
    "country": "CN",
    "name": "Maoping",
    "lat": "30.82972",
    "lng": "110.97778"
  },
  {
    "country": "CN",
    "name": "Maoping",
    "lat": "26.73694",
    "lng": "109.22111"
  },
  {
    "country": "CN",
    "name": "Maoping",
    "lat": "26.51972",
    "lng": "110.41194"
  },
  {
    "country": "CN",
    "name": "Maoming",
    "lat": "21.65",
    "lng": "110.9"
  },
  {
    "country": "CN",
    "name": "Haimen",
    "lat": "31.89619",
    "lng": "121.17274"
  },
  {
    "country": "CN",
    "name": "Malin",
    "lat": "26.455",
    "lng": "110.64167"
  },
  {
    "country": "CN",
    "name": "Mali",
    "lat": "23.12621",
    "lng": "104.7409"
  },
  {
    "country": "CN",
    "name": "Majie",
    "lat": "25.0319",
    "lng": "102.638"
  },
  {
    "country": "CN",
    "name": "Majiadian",
    "lat": "39.65778",
    "lng": "117.26611"
  },
  {
    "country": "CN",
    "name": "Zhijiang",
    "lat": "30.42139",
    "lng": "111.75333"
  },
  {
    "country": "CN",
    "name": "Magitang",
    "lat": "35.93859",
    "lng": "102.02968"
  },
  {
    "country": "CN",
    "name": "Macheng",
    "lat": "31.18013",
    "lng": "115.02213"
  },
  {
    "country": "CN",
    "name": "Maba",
    "lat": "24.68413",
    "lng": "113.59839"
  },
  {
    "country": "CN",
    "name": "Ma’an",
    "lat": "26.9775",
    "lng": "110.72111"
  },
  {
    "country": "CN",
    "name": "Ma’anshan",
    "lat": "31.68579",
    "lng": "118.51008"
  },
  {
    "country": "CN",
    "name": "Luzhou",
    "lat": "28.8903",
    "lng": "105.42575"
  },
  {
    "country": "CN",
    "name": "Luzhai",
    "lat": "24.49754",
    "lng": "109.73315"
  },
  {
    "country": "CN",
    "name": "Luyuan",
    "lat": "34.53596",
    "lng": "109.08508"
  },
  {
    "country": "CN",
    "name": "Xiguan",
    "lat": "33.86667",
    "lng": "115.46667"
  },
  {
    "country": "CN",
    "name": "Luyang",
    "lat": "27.62389",
    "lng": "110.09889"
  },
  {
    "country": "CN",
    "name": "Luxu",
    "lat": "23.22117",
    "lng": "108.80299"
  },
  {
    "country": "CN",
    "name": "Luxia",
    "lat": "26.93",
    "lng": "118.80722"
  },
  {
    "country": "CN",
    "name": "Luxi",
    "lat": "27.63618",
    "lng": "114.03529"
  },
  {
    "country": "CN",
    "name": "Luwan",
    "lat": "31.20908",
    "lng": "121.46335"
  },
  {
    "country": "CN",
    "name": "Lüshun",
    "lat": "38.8",
    "lng": "121.26667"
  },
  {
    "country": "CN",
    "name": "Lushi Chengguanzhen",
    "lat": "34.04861",
    "lng": "111.03278"
  },
  {
    "country": "CN",
    "name": "Lushar",
    "lat": "36.48416",
    "lng": "101.56328"
  },
  {
    "country": "CN",
    "name": "Luyang",
    "lat": "33.73564",
    "lng": "112.90508"
  },
  {
    "country": "CN",
    "name": "Luqiao",
    "lat": "29.93246",
    "lng": "102.23163"
  },
  {
    "country": "CN",
    "name": "Luqiao",
    "lat": "28.58023",
    "lng": "121.37491"
  },
  {
    "country": "CN",
    "name": "Luoyang",
    "lat": "34.68361",
    "lng": "112.45361"
  },
  {
    "country": "CN",
    "name": "Luoyang",
    "lat": "27.56139",
    "lng": "119.71139"
  },
  {
    "country": "CN",
    "name": "Luoyang",
    "lat": "24.95938",
    "lng": "118.683"
  },
  {
    "country": "CN",
    "name": "Luoyang",
    "lat": "23.16244",
    "lng": "114.27342"
  },
  {
    "country": "CN",
    "name": "Luoxiong",
    "lat": "24.88558",
    "lng": "104.29225"
  },
  {
    "country": "CN",
    "name": "Luoshan Chengguanzhen",
    "lat": "32.20318",
    "lng": "114.50942"
  },
  {
    "country": "CN",
    "name": "Luorong",
    "lat": "24.40583",
    "lng": "109.60861"
  },
  {
    "country": "CN",
    "name": "Luoqiao",
    "lat": "26.47265",
    "lng": "119.00392"
  },
  {
    "country": "CN",
    "name": "Luoning Chengguanzhen",
    "lat": "34.38778",
    "lng": "111.65583"
  },
  {
    "country": "CN",
    "name": "Luojiu",
    "lat": "27.51583",
    "lng": "109.80889"
  },
  {
    "country": "CN",
    "name": "Luojiang",
    "lat": "31.30497",
    "lng": "104.50484"
  },
  {
    "country": "CN",
    "name": "Luohe",
    "lat": "33.56394",
    "lng": "114.04272"
  },
  {
    "country": "CN",
    "name": "Luocheng",
    "lat": "22.76953",
    "lng": "111.56882"
  },
  {
    "country": "CN",
    "name": "Luocheng",
    "lat": "30.98021",
    "lng": "104.28081"
  },
  {
    "country": "CN",
    "name": "Luocheng",
    "lat": "29.38481",
    "lng": "104.02862"
  },
  {
    "country": "CN",
    "name": "Luocheng",
    "lat": "25.03231",
    "lng": "118.79495"
  },
  {
    "country": "CN",
    "name": "Lufu",
    "lat": "24.7602",
    "lng": "103.26647"
  },
  {
    "country": "CN",
    "name": "Lukou",
    "lat": "27.70292",
    "lng": "113.15202"
  },
  {
    "country": "CN",
    "name": "Lucheng",
    "lat": "31.23357",
    "lng": "117.28057"
  },
  {
    "country": "CN",
    "name": "Luhua",
    "lat": "32.06708",
    "lng": "102.98786"
  },
  {
    "country": "CN",
    "name": "Lufeng",
    "lat": "27.90944",
    "lng": "110.58583"
  },
  {
    "country": "CN",
    "name": "Lüeyang Chengguanzhen",
    "lat": "33.33205",
    "lng": "106.15496"
  },
  {
    "country": "CN",
    "name": "Daxing",
    "lat": "22.96916",
    "lng": "102.40611"
  },
  {
    "country": "CN",
    "name": "Luhua",
    "lat": "36.33139",
    "lng": "113.22444"
  },
  {
    "country": "CN",
    "name": "Lucheng",
    "lat": "31.76324",
    "lng": "120.04588"
  },
  {
    "country": "CN",
    "name": "Kangding",
    "lat": "30.00222",
    "lng": "101.9569"
  },
  {
    "country": "CN",
    "name": "Wenquan",
    "lat": "22.32528",
    "lng": "110.25556"
  },
  {
    "country": "CN",
    "name": "Lubu",
    "lat": "23.17233",
    "lng": "112.28298"
  },
  {
    "country": "CN",
    "name": "Luanzhou",
    "lat": "39.75",
    "lng": "118.73333"
  },
  {
    "country": "CN",
    "name": "Luanchuan Chengguanzhen",
    "lat": "33.7808",
    "lng": "111.613"
  },
  {
    "country": "CN",
    "name": "Luancheng",
    "lat": "37.87917",
    "lng": "114.65167"
  },
  {
    "country": "CN",
    "name": "Lu’an",
    "lat": "31.73561",
    "lng": "116.51688"
  },
  {
    "country": "CN",
    "name": "Loufan",
    "lat": "38.0918",
    "lng": "111.80721"
  },
  {
    "country": "CN",
    "name": "Loudi",
    "lat": "27.73444",
    "lng": "111.99444"
  },
  {
    "country": "CN",
    "name": "Longzhou",
    "lat": "22.39967",
    "lng": "106.78967"
  },
  {
    "country": "CN",
    "name": "Longyan",
    "lat": "25.10722",
    "lng": "117.0225"
  },
  {
    "country": "CN",
    "name": "Longxu",
    "lat": "23.41667",
    "lng": "111.23333"
  },
  {
    "country": "CN",
    "name": "Longxian Chengguanzhen",
    "lat": "34.90734",
    "lng": "106.84965"
  },
  {
    "country": "CN",
    "name": "Longtou’an",
    "lat": "27.67028",
    "lng": "110.33611"
  },
  {
    "country": "CN",
    "name": "Longtan",
    "lat": "27.41139",
    "lng": "110.53639"
  },
  {
    "country": "CN",
    "name": "Longsheng",
    "lat": "25.79361",
    "lng": "110.00917"
  },
  {
    "country": "CN",
    "name": "Longquan",
    "lat": "30.5613",
    "lng": "104.26893"
  },
  {
    "country": "CN",
    "name": "Longquan",
    "lat": "24.67193",
    "lng": "102.1613"
  },
  {
    "country": "CN",
    "name": "Longnan",
    "lat": "24.9",
    "lng": "114.78333"
  },
  {
    "country": "CN",
    "name": "Longmen",
    "lat": "24.95972",
    "lng": "118.08889"
  },
  {
    "country": "CN",
    "name": "Longlisuo",
    "lat": "26.41417",
    "lng": "109.10222"
  },
  {
    "country": "CN",
    "name": "Longgang",
    "lat": "37.65181",
    "lng": "120.33063"
  },
  {
    "country": "CN",
    "name": "Longjin",
    "lat": "26.18197",
    "lng": "116.81464"
  },
  {
    "country": "CN",
    "name": "Longde Chengguanzhen",
    "lat": "35.6125",
    "lng": "106.11667"
  },
  {
    "country": "CN",
    "name": "Longchuan",
    "lat": "25.16152",
    "lng": "101.29418"
  },
  {
    "country": "CN",
    "name": "Longcheng",
    "lat": "34.18448",
    "lng": "116.95077"
  },
  {
    "country": "CN",
    "name": "Longcheng",
    "lat": "24.89827",
    "lng": "102.79965"
  },
  {
    "country": "CN",
    "name": "Long’an",
    "lat": "32.40934",
    "lng": "104.52868"
  },
  {
    "country": "CN",
    "name": "Long’an Chengxiangzhen",
    "lat": "23.20712",
    "lng": "107.6509"
  },
  {
    "country": "CN",
    "name": "Lizhuangzi",
    "lat": "39.00417",
    "lng": "117.52556"
  },
  {
    "country": "CN",
    "name": "Liyuan",
    "lat": "29.39537",
    "lng": "110.15591"
  },
  {
    "country": "CN",
    "name": "Liyang",
    "lat": "31.71772",
    "lng": "118.35731"
  },
  {
    "country": "CN",
    "name": "Licheng",
    "lat": "31.42813",
    "lng": "119.48353"
  },
  {
    "country": "CN",
    "name": "Lixiqiao",
    "lat": "26.79472",
    "lng": "110.41806"
  },
  {
    "country": "CN",
    "name": "Lixin Chengguanzhen",
    "lat": "33.14328",
    "lng": "116.22718"
  },
  {
    "country": "CN",
    "name": "Liyang",
    "lat": "29.6518",
    "lng": "111.752"
  },
  {
    "country": "CN",
    "name": "Liuzikou",
    "lat": "39.87028",
    "lng": "117.34667"
  },
  {
    "country": "CN",
    "name": "Guankou",
    "lat": "28.15861",
    "lng": "113.62709"
  },
  {
    "country": "CN",
    "name": "Liuwudian",
    "lat": "24.55552",
    "lng": "118.19558"
  },
  {
    "country": "CN",
    "name": "Puning",
    "lat": "23.31072",
    "lng": "116.16869"
  },
  {
    "country": "CN",
    "name": "Liupai",
    "lat": "25.04",
    "lng": "107.17315"
  },
  {
    "country": "CN",
    "name": "Liulin",
    "lat": "37.45333",
    "lng": "110.90189"
  },
  {
    "country": "CN",
    "name": "Liukuaizhuang",
    "lat": "39.24789",
    "lng": "117.33941"
  },
  {
    "country": "CN",
    "name": "Liujiaxia",
    "lat": "35.934",
    "lng": "103.31831"
  },
  {
    "country": "CN",
    "name": "Liuduzhai",
    "lat": "27.36611",
    "lng": "110.935"
  },
  {
    "country": "CN",
    "name": "Liucheng",
    "lat": "30.7",
    "lng": "103.83771"
  },
  {
    "country": "CN",
    "name": "Liuba",
    "lat": "33.61861",
    "lng": "106.91889"
  },
  {
    "country": "CN",
    "name": "Liu’anzhuang",
    "lat": "39.23868",
    "lng": "117.19819"
  },
  {
    "country": "CN",
    "name": "Lishui",
    "lat": "28.46042",
    "lng": "119.91029"
  },
  {
    "country": "CN",
    "name": "Lishi",
    "lat": "37.51556",
    "lng": "111.13417"
  },
  {
    "country": "CN",
    "name": "Lishi",
    "lat": "24.80459",
    "lng": "115.03325"
  },
  {
    "country": "CN",
    "name": "Lintong",
    "lat": "34.37803",
    "lng": "109.20892"
  },
  {
    "country": "CN",
    "name": "Lishan",
    "lat": "31.85764",
    "lng": "113.29505"
  },
  {
    "country": "CN",
    "name": "Liquan Chengguanzhen",
    "lat": "34.48111",
    "lng": "108.42361"
  },
  {
    "country": "CN",
    "name": "Liuzhou",
    "lat": "24.31258",
    "lng": "109.38916"
  },
  {
    "country": "CN",
    "name": "Linyi",
    "lat": "35.06306",
    "lng": "118.34278"
  },
  {
    "country": "CN",
    "name": "Chang’an",
    "lat": "29.4718",
    "lng": "113.444"
  },
  {
    "country": "CN",
    "name": "Linquan",
    "lat": "37.97965",
    "lng": "111.02059"
  },
  {
    "country": "CN",
    "name": "Kaiyuan",
    "lat": "36.06813",
    "lng": "113.82209"
  },
  {
    "country": "CN",
    "name": "Linxia Chengguanzhen",
    "lat": "35.60028",
    "lng": "103.20639"
  },
  {
    "country": "CN",
    "name": "Linxi",
    "lat": "39.71183",
    "lng": "118.44954"
  },
  {
    "country": "CN",
    "name": "Linwu Chengguanzhen",
    "lat": "25.23247",
    "lng": "112.53981"
  },
  {
    "country": "CN",
    "name": "Lintingkou",
    "lat": "39.63028",
    "lng": "117.50028"
  },
  {
    "country": "CN",
    "name": "Linshui",
    "lat": "36.42472",
    "lng": "114.20472"
  },
  {
    "country": "CN",
    "name": "Ruzhou",
    "lat": "34.16167",
    "lng": "112.82972"
  },
  {
    "country": "CN",
    "name": "Linquan Chengguanzhen",
    "lat": "33.08506",
    "lng": "115.29023"
  },
  {
    "country": "CN",
    "name": "Linqu",
    "lat": "36.51556",
    "lng": "118.53972"
  },
  {
    "country": "CN",
    "name": "Linqiong",
    "lat": "30.41587",
    "lng": "103.46089"
  },
  {
    "country": "CN",
    "name": "Qingnian",
    "lat": "36.84032",
    "lng": "115.71183"
  },
  {
    "country": "CN",
    "name": "Linping",
    "lat": "30.4225",
    "lng": "120.29722"
  },
  {
    "country": "CN",
    "name": "Linli",
    "lat": "29.45",
    "lng": "111.65"
  },
  {
    "country": "CN",
    "name": "Linkou",
    "lat": "26.24806",
    "lng": "109.86361"
  },
  {
    "country": "CN",
    "name": "Linhai",
    "lat": "28.85535",
    "lng": "121.1447"
  },
  {
    "country": "CN",
    "name": "Lingcheng",
    "lat": "37.33133",
    "lng": "116.56953"
  },
  {
    "country": "CN",
    "name": "Xiayang",
    "lat": "26.48885",
    "lng": "113.76796"
  },
  {
    "country": "CN",
    "name": "Lingxi",
    "lat": "29.005",
    "lng": "109.84472"
  },
  {
    "country": "CN",
    "name": "Dongta",
    "lat": "38.0814",
    "lng": "106.34444"
  },
  {
    "country": "CN",
    "name": "Cuifeng",
    "lat": "36.84517",
    "lng": "111.78172"
  },
  {
    "country": "CN",
    "name": "Wuling",
    "lat": "39.46799",
    "lng": "114.14843"
  },
  {
    "country": "CN",
    "name": "Lingjiang",
    "lat": "31.7346",
    "lng": "105.93162"
  },
  {
    "country": "CN",
    "name": "Chongwen",
    "lat": "35.77491",
    "lng": "113.25079"
  },
  {
    "country": "CN",
    "name": "Lingcheng",
    "lat": "33.53766",
    "lng": "117.53357"
  },
  {
    "country": "CN",
    "name": "Lingcheng",
    "lat": "22.70722",
    "lng": "110.34917"
  },
  {
    "country": "CN",
    "name": "Lingcheng",
    "lat": "22.42317",
    "lng": "109.29303"
  },
  {
    "country": "CN",
    "name": "Lincheng",
    "lat": "19.90778",
    "lng": "109.68583"
  },
  {
    "country": "CN",
    "name": "Linfen",
    "lat": "36.08889",
    "lng": "111.51889"
  },
  {
    "country": "CN",
    "name": "Lincheng",
    "lat": "26.86932",
    "lng": "109.66336"
  },
  {
    "country": "CN",
    "name": "Lin’an",
    "lat": "30.23583",
    "lng": "119.71806"
  },
  {
    "country": "CN",
    "name": "Xishan",
    "lat": "27.66667",
    "lng": "113.5"
  },
  {
    "country": "CN",
    "name": "Lijiang",
    "lat": "23.5711",
    "lng": "102.00417"
  },
  {
    "country": "CN",
    "name": "Lichuan",
    "lat": "30.3",
    "lng": "108.85"
  },
  {
    "country": "CN",
    "name": "Lihou",
    "lat": "36.50289",
    "lng": "113.36945"
  },
  {
    "country": "CN",
    "name": "Licheng",
    "lat": "24.50649",
    "lng": "110.38919"
  },
  {
    "country": "CN",
    "name": "Licheng",
    "lat": "23.29549",
    "lng": "113.82465"
  },
  {
    "country": "CN",
    "name": "Liaogao",
    "lat": "28.17",
    "lng": "109.195"
  },
  {
    "country": "CN",
    "name": "Liaocheng",
    "lat": "36.45596",
    "lng": "115.97766"
  },
  {
    "country": "CN",
    "name": "Lianzhou",
    "lat": "24.78186",
    "lng": "112.3712"
  },
  {
    "country": "CN",
    "name": "Lianzhou",
    "lat": "21.66621",
    "lng": "109.20116"
  },
  {
    "country": "CN",
    "name": "Lianran",
    "lat": "24.92271",
    "lng": "102.48496"
  },
  {
    "country": "CN",
    "name": "Lianhe",
    "lat": "24.57298",
    "lng": "118.34171"
  },
  {
    "country": "CN",
    "name": "Wuwei",
    "lat": "37.92672",
    "lng": "102.63202"
  },
  {
    "country": "CN",
    "name": "Liangyaping",
    "lat": "27.71833",
    "lng": "110.67083"
  },
  {
    "country": "CN",
    "name": "Liangxiang",
    "lat": "39.73598",
    "lng": "116.13295"
  },
  {
    "country": "CN",
    "name": "Xincheng",
    "lat": "39.98677",
    "lng": "112.46135"
  },
  {
    "country": "CN",
    "name": "Liangdang Chengguanzhen",
    "lat": "33.90972",
    "lng": "106.30222"
  },
  {
    "country": "CN",
    "name": "Liangcunchang",
    "lat": "28.40667",
    "lng": "106.42444"
  },
  {
    "country": "CN",
    "name": "Lianfeng",
    "lat": "25.70441",
    "lng": "116.72162"
  },
  {
    "country": "CN",
    "name": "Liancheng",
    "lat": "24.05192",
    "lng": "105.07497"
  },
  {
    "country": "CN",
    "name": "Lianjiang",
    "lat": "21.64673",
    "lng": "110.28172"
  },
  {
    "country": "CN",
    "name": "Leshan",
    "lat": "29.56227",
    "lng": "103.76386"
  },
  {
    "country": "CN",
    "name": "Leping",
    "lat": "28.96667",
    "lng": "117.11667"
  },
  {
    "country": "CN",
    "name": "Lengshuitan",
    "lat": "26.4111",
    "lng": "111.59559"
  },
  {
    "country": "CN",
    "name": "Lengshuijiang",
    "lat": "27.68806",
    "lng": "111.42944"
  },
  {
    "country": "CN",
    "name": "Leli",
    "lat": "24.35405",
    "lng": "106.2437"
  },
  {
    "country": "CN",
    "name": "Leiyang",
    "lat": "26.40238",
    "lng": "112.85908"
  },
  {
    "country": "CN",
    "name": "Lecheng",
    "lat": "25.128",
    "lng": "113.35041"
  },
  {
    "country": "CN",
    "name": "Laohekou",
    "lat": "32.38583",
    "lng": "111.66778"
  },
  {
    "country": "CN",
    "name": "Lanzhou",
    "lat": "36.05701",
    "lng": "103.83987"
  },
  {
    "country": "CN",
    "name": "Lanxi",
    "lat": "29.21588",
    "lng": "119.47156"
  },
  {
    "country": "CN",
    "name": "Lianyuan",
    "lat": "27.68833",
    "lng": "111.66417"
  },
  {
    "country": "CN",
    "name": "Lantian",
    "lat": "27.025",
    "lng": "109.29472"
  },
  {
    "country": "CN",
    "name": "Tafeng",
    "lat": "25.35407",
    "lng": "112.18987"
  },
  {
    "country": "CN",
    "name": "Lanli",
    "lat": "27.88694",
    "lng": "109.91861"
  },
  {
    "country": "CN",
    "name": "Languan",
    "lat": "34.15754",
    "lng": "109.31415"
  },
  {
    "country": "CN",
    "name": "Langfang",
    "lat": "39.50972",
    "lng": "116.69472"
  },
  {
    "country": "CN",
    "name": "Langao Chengguanzhen",
    "lat": "32.30028",
    "lng": "108.89306"
  },
  {
    "country": "CN",
    "name": "Lankao Chengguanzhen",
    "lat": "34.83294",
    "lng": "114.80718"
  },
  {
    "country": "CN",
    "name": "Laizhou",
    "lat": "37.18073",
    "lng": "119.94217"
  },
  {
    "country": "CN",
    "name": "Laiyang",
    "lat": "36.97583",
    "lng": "120.71361"
  },
  {
    "country": "CN",
    "name": "Laiwu",
    "lat": "36.19278",
    "lng": "117.65694"
  },
  {
    "country": "CN",
    "name": "Xiangfeng",
    "lat": "29.50761",
    "lng": "109.40266"
  },
  {
    "country": "CN",
    "name": "Laibin",
    "lat": "23.7",
    "lng": "109.26667"
  },
  {
    "country": "CN",
    "name": "Labuleng",
    "lat": "35.20125",
    "lng": "102.52117"
  },
  {
    "country": "CN",
    "name": "Labu",
    "lat": "24.25985",
    "lng": "109.33415"
  },
  {
    "country": "CN",
    "name": "Kunyang",
    "lat": "27.66583",
    "lng": "120.56583"
  },
  {
    "country": "CN",
    "name": "Kunyang",
    "lat": "24.66753",
    "lng": "102.5919"
  },
  {
    "country": "CN",
    "name": "Kunming",
    "lat": "25.03889",
    "lng": "102.71833"
  },
  {
    "country": "CN",
    "name": "Kuangyuan",
    "lat": "24.91379",
    "lng": "103.14789"
  },
  {
    "country": "CN",
    "name": "Kou’an",
    "lat": "32.3082",
    "lng": "119.87568"
  },
  {
    "country": "CN",
    "name": "Kengyuan",
    "lat": "26.33964",
    "lng": "119.76476"
  },
  {
    "country": "CN",
    "name": "Lanyi",
    "lat": "38.71983",
    "lng": "111.59783"
  },
  {
    "country": "CN",
    "name": "Fucheng",
    "lat": "35.3725",
    "lng": "103.70556"
  },
  {
    "country": "CN",
    "name": "Kangle",
    "lat": "28.09557",
    "lng": "114.45007"
  },
  {
    "country": "CN",
    "name": "Kaiyuan",
    "lat": "23.69767",
    "lng": "103.30372"
  },
  {
    "country": "CN",
    "name": "Kaiping",
    "lat": "39.67798",
    "lng": "118.25217"
  },
  {
    "country": "CN",
    "name": "Xinning",
    "lat": "31.08515",
    "lng": "107.86508"
  },
  {
    "country": "CN",
    "name": "Kaihua Chengguanzhen",
    "lat": "29.14586",
    "lng": "118.40903"
  },
  {
    "country": "CN",
    "name": "Kaihua",
    "lat": "23.3695",
    "lng": "104.27721"
  },
  {
    "country": "CN",
    "name": "Kaifeng",
    "lat": "34.7986",
    "lng": "114.30742"
  },
  {
    "country": "CN",
    "name": "Juye",
    "lat": "35.39472",
    "lng": "116.08833"
  },
  {
    "country": "CN",
    "name": "Junxi",
    "lat": "25.69795",
    "lng": "117.84541"
  },
  {
    "country": "CN",
    "name": "Junlian",
    "lat": "28.17106",
    "lng": "104.51162"
  },
  {
    "country": "CN",
    "name": "Juegang",
    "lat": "32.31737",
    "lng": "121.18552"
  },
  {
    "country": "CN",
    "name": "Juanshui",
    "lat": "29.30307",
    "lng": "113.88676"
  },
  {
    "country": "CN",
    "name": "Juancheng",
    "lat": "35.56157",
    "lng": "115.50134"
  },
  {
    "country": "CN",
    "name": "Liulin",
    "lat": "34.58972",
    "lng": "103.50417"
  },
  {
    "country": "CN",
    "name": "Jiyuan",
    "lat": "35.09",
    "lng": "112.58"
  },
  {
    "country": "CN",
    "name": "Jichang",
    "lat": "36.10111",
    "lng": "110.67333"
  },
  {
    "country": "CN",
    "name": "Chengjiao",
    "lat": "35.40495",
    "lng": "114.06043"
  },
  {
    "country": "CN",
    "name": "Huayuan",
    "lat": "33.4688",
    "lng": "114.87314"
  },
  {
    "country": "CN",
    "name": "Ningshan Chengguanzhen",
    "lat": "33.33153",
    "lng": "108.30685"
  },
  {
    "country": "CN",
    "name": "Yangjiaping",
    "lat": "29.50512",
    "lng": "106.50135"
  },
  {
    "country": "CN",
    "name": "Lianzhu",
    "lat": "23.40844",
    "lng": "101.71028"
  },
  {
    "country": "CN",
    "name": "Jiujiang",
    "lat": "29.70475",
    "lng": "116.00206"
  },
  {
    "country": "CN",
    "name": "Jiuchenggong",
    "lat": "34.67868",
    "lng": "107.78758"
  },
  {
    "country": "CN",
    "name": "Jishui",
    "lat": "33.73333",
    "lng": "115.4"
  },
  {
    "country": "CN",
    "name": "Qianzhou",
    "lat": "28.31925",
    "lng": "109.73346"
  },
  {
    "country": "CN",
    "name": "Jifeng",
    "lat": "35.61347",
    "lng": "110.95854"
  },
  {
    "country": "CN",
    "name": "Jinzhou",
    "lat": "39.1",
    "lng": "121.71667"
  },
  {
    "country": "CN",
    "name": "Jinyuan",
    "lat": "37.72694",
    "lng": "112.47083"
  },
  {
    "country": "CN",
    "name": "Jinxiu",
    "lat": "24.13721",
    "lng": "110.18009"
  },
  {
    "country": "CN",
    "name": "Jinxiang",
    "lat": "27.43265",
    "lng": "120.60625"
  },
  {
    "country": "CN",
    "name": "Jinshiqiao",
    "lat": "27.58425",
    "lng": "110.93634"
  },
  {
    "country": "CN",
    "name": "Jinshi",
    "lat": "29.60487",
    "lng": "111.87012"
  },
  {
    "country": "CN",
    "name": "Jinshi",
    "lat": "26.41796",
    "lng": "110.80017"
  },
  {
    "country": "CN",
    "name": "Jinshan",
    "lat": "25.11508",
    "lng": "102.09833"
  },
  {
    "country": "CN",
    "name": "Jinsha",
    "lat": "32.08982",
    "lng": "121.07355"
  },
  {
    "country": "CN",
    "name": "Jinping",
    "lat": "35.31435",
    "lng": "107.02923"
  },
  {
    "country": "CN",
    "name": "Jinping",
    "lat": "24.43374",
    "lng": "100.81989"
  },
  {
    "country": "CN",
    "name": "Jinping",
    "lat": "24.03054",
    "lng": "104.22702"
  },
  {
    "country": "CN",
    "name": "Jinhe",
    "lat": "22.76667",
    "lng": "103.25"
  },
  {
    "country": "CN",
    "name": "Jinjing",
    "lat": "24.575",
    "lng": "118.59722"
  },
  {
    "country": "CN",
    "name": "Jinjiang",
    "lat": "19.72878",
    "lng": "110.00851"
  },
  {
    "country": "CN",
    "name": "Jinji",
    "lat": "23.22806",
    "lng": "110.82611"
  },
  {
    "country": "CN",
    "name": "Jining",
    "lat": "35.405",
    "lng": "116.58139"
  },
  {
    "country": "CN",
    "name": "Jinhua",
    "lat": "29.10678",
    "lng": "119.64421"
  },
  {
    "country": "CN",
    "name": "Jinhe",
    "lat": "27.71694",
    "lng": "109.60472"
  },
  {
    "country": "CN",
    "name": "Jingzhou",
    "lat": "30.35028",
    "lng": "112.19028"
  },
  {
    "country": "CN",
    "name": "Wulan",
    "lat": "36.56541",
    "lng": "104.68401"
  },
  {
    "country": "CN",
    "name": "Xiangshui",
    "lat": "35.47695",
    "lng": "106.33112"
  },
  {
    "country": "CN",
    "name": "Jingyang",
    "lat": "32.51667",
    "lng": "107.88333"
  },
  {
    "country": "CN",
    "name": "Jingyang",
    "lat": "30.29194",
    "lng": "118.5425"
  },
  {
    "country": "CN",
    "name": "Yancheng",
    "lat": "29.65068",
    "lng": "104.06723"
  },
  {
    "country": "CN",
    "name": "Tianchang",
    "lat": "37.99806",
    "lng": "114.01556"
  },
  {
    "country": "CN",
    "name": "Xiluodu",
    "lat": "28.24425",
    "lng": "103.63849"
  },
  {
    "country": "CN",
    "name": "Jingzhou",
    "lat": "37.68868",
    "lng": "116.25958"
  },
  {
    "country": "CN",
    "name": "Jingchuan",
    "lat": "30.68916",
    "lng": "118.40431"
  },
  {
    "country": "CN",
    "name": "Jingping",
    "lat": "39.52",
    "lng": "112.28389"
  },
  {
    "country": "CN",
    "name": "Jingning Chengguanzhen",
    "lat": "35.52036",
    "lng": "105.72301"
  },
  {
    "country": "CN",
    "name": "Jingmen",
    "lat": "31.03361",
    "lng": "112.20472"
  },
  {
    "country": "CN",
    "name": "Jingling",
    "lat": "30.65",
    "lng": "113.1"
  },
  {
    "country": "CN",
    "name": "Echeng",
    "lat": "38.37444",
    "lng": "111.97167"
  },
  {
    "country": "CN",
    "name": "Jingjiang",
    "lat": "32.01417",
    "lng": "120.2625"
  },
  {
    "country": "CN",
    "name": "Jinghai",
    "lat": "38.93373",
    "lng": "116.92699"
  },
  {
    "country": "CN",
    "name": "Jinggan",
    "lat": "34.53",
    "lng": "108.83417"
  },
  {
    "country": "CN",
    "name": "Jingdezhen",
    "lat": "29.2947",
    "lng": "117.20789"
  },
  {
    "country": "CN",
    "name": "Jingchuan Chengguanzhen",
    "lat": "35.33194",
    "lng": "107.36111"
  },
  {
    "country": "CN",
    "name": "Zhangping",
    "lat": "25.29972",
    "lng": "117.415"
  },
  {
    "country": "CN",
    "name": "Jing’an",
    "lat": "22.21072",
    "lng": "113.29218"
  },
  {
    "country": "CN",
    "name": "Jin’e",
    "lat": "29.34313",
    "lng": "105.28443"
  },
  {
    "country": "CN",
    "name": "Jinchang",
    "lat": "38.50062",
    "lng": "102.19379"
  },
  {
    "country": "CN",
    "name": "Jinchuan",
    "lat": "31.47551",
    "lng": "102.05884"
  },
  {
    "country": "CN",
    "name": "Jinchuan",
    "lat": "27.76036",
    "lng": "115.3885"
  },
  {
    "country": "CN",
    "name": "Jincheng",
    "lat": "35.50222",
    "lng": "112.83278"
  },
  {
    "country": "CN",
    "name": "Jincheng",
    "lat": "30.99712",
    "lng": "105.88191"
  },
  {
    "country": "CN",
    "name": "Jincheng",
    "lat": "28.26648",
    "lng": "103.56838"
  },
  {
    "country": "CN",
    "name": "Jincheng",
    "lat": "25.50147",
    "lng": "102.40058"
  },
  {
    "country": "CN",
    "name": "Jinbi",
    "lat": "25.70855",
    "lng": "101.33679"
  },
  {
    "country": "CN",
    "name": "Jinan",
    "lat": "36.66833",
    "lng": "116.99722"
  },
  {
    "country": "CN",
    "name": "Jin’an",
    "lat": "32.63941",
    "lng": "103.59683"
  },
  {
    "country": "CN",
    "name": "Jimo",
    "lat": "36.38972",
    "lng": "120.46222"
  },
  {
    "country": "CN",
    "name": "Daqinglu",
    "lat": "34.89927",
    "lng": "112.58314"
  },
  {
    "country": "CN",
    "name": "Jijiang",
    "lat": "29.28993",
    "lng": "106.25001"
  },
  {
    "country": "CN",
    "name": "Jiexiu",
    "lat": "37.02444",
    "lng": "111.9125"
  },
  {
    "country": "CN",
    "name": "Jieshou",
    "lat": "33.26338",
    "lng": "115.36108"
  },
  {
    "country": "CN",
    "name": "Jieshi",
    "lat": "22.81027",
    "lng": "115.83058"
  },
  {
    "country": "CN",
    "name": "Jiekou",
    "lat": "23.54992",
    "lng": "113.58099"
  },
  {
    "country": "CN",
    "name": "Jiehu",
    "lat": "35.54278",
    "lng": "118.455"
  },
  {
    "country": "CN",
    "name": "Jiazi",
    "lat": "22.87932",
    "lng": "116.07318"
  },
  {
    "country": "CN",
    "name": "Jiaxing",
    "lat": "30.7522",
    "lng": "120.75"
  },
  {
    "country": "CN",
    "name": "Jiaxiang",
    "lat": "35.39606",
    "lng": "116.348"
  },
  {
    "country": "CN",
    "name": "Jiaxian",
    "lat": "33.96833",
    "lng": "113.20806"
  },
  {
    "country": "CN",
    "name": "Jiaozuo",
    "lat": "35.23972",
    "lng": "113.23306"
  },
  {
    "country": "CN",
    "name": "Jiaocheng",
    "lat": "24.65732",
    "lng": "116.16709"
  },
  {
    "country": "CN",
    "name": "Jiaokui",
    "lat": "27.59414",
    "lng": "104.00478"
  },
  {
    "country": "CN",
    "name": "Tianning",
    "lat": "37.54722",
    "lng": "112.16053"
  },
  {
    "country": "CN",
    "name": "Jiaozhou",
    "lat": "36.28389",
    "lng": "120.00333"
  },
  {
    "country": "CN",
    "name": "Ningde",
    "lat": "26.66167",
    "lng": "119.52278"
  },
  {
    "country": "CN",
    "name": "Jiancheng",
    "lat": "30.39097",
    "lng": "104.54912"
  },
  {
    "country": "CN",
    "name": "Lin’an",
    "lat": "23.60255",
    "lng": "102.83092"
  },
  {
    "country": "CN",
    "name": "Jian’ou",
    "lat": "27.04694",
    "lng": "118.32528"
  },
  {
    "country": "CN",
    "name": "Tongzilin",
    "lat": "26.70039",
    "lng": "101.85134"
  },
  {
    "country": "CN",
    "name": "Jianjun",
    "lat": "34.69139",
    "lng": "108.13972"
  },
  {
    "country": "CN",
    "name": "Jianjiang",
    "lat": "26.54972",
    "lng": "119.755"
  },
  {
    "country": "CN",
    "name": "Xiaopu",
    "lat": "25.23917",
    "lng": "111.31664"
  },
  {
    "country": "CN",
    "name": "Jiangyan",
    "lat": "32.50611",
    "lng": "120.14278"
  },
  {
    "country": "CN",
    "name": "Gujiang",
    "lat": "35.49399",
    "lng": "111.55334"
  },
  {
    "country": "CN",
    "name": "Jiangwakou",
    "lat": "39.5225",
    "lng": "117.7025"
  },
  {
    "country": "CN",
    "name": "Jianguang",
    "lat": "28.19377",
    "lng": "115.7836"
  },
  {
    "country": "CN",
    "name": "Jiangshi",
    "lat": "27.12333",
    "lng": "109.73778"
  },
  {
    "country": "CN",
    "name": "Jiangna",
    "lat": "23.6092",
    "lng": "104.37312"
  },
  {
    "country": "CN",
    "name": "Jiangmen",
    "lat": "22.58333",
    "lng": "113.08333"
  },
  {
    "country": "CN",
    "name": "Jiangkou",
    "lat": "31.56506",
    "lng": "107.09736"
  },
  {
    "country": "CN",
    "name": "Jiangkouxu",
    "lat": "27.69417",
    "lng": "109.73583"
  },
  {
    "country": "CN",
    "name": "Jiangkou",
    "lat": "25.48694",
    "lng": "119.19834"
  },
  {
    "country": "CN",
    "name": "Jiangkou",
    "lat": "23.43916",
    "lng": "111.4974"
  },
  {
    "country": "CN",
    "name": "Jiangfang",
    "lat": "26.50158",
    "lng": "110.3464"
  },
  {
    "country": "CN",
    "name": "Gangdong",
    "lat": "27.91694",
    "lng": "110.83417"
  },
  {
    "country": "CN",
    "name": "Yangjiang",
    "lat": "21.85563",
    "lng": "111.96272"
  },
  {
    "country": "CN",
    "name": "Jiang’an Qu",
    "lat": "30.6089",
    "lng": "114.30683"
  },
  {
    "country": "CN",
    "name": "Jiang’an",
    "lat": "28.73335",
    "lng": "105.0683"
  },
  {
    "country": "CN",
    "name": "Jianchang",
    "lat": "27.55831",
    "lng": "116.63978"
  },
  {
    "country": "CN",
    "name": "Ji’an",
    "lat": "27.11716",
    "lng": "114.97927"
  },
  {
    "country": "CN",
    "name": "Jiamaying",
    "lat": "37.20806",
    "lng": "115.95"
  },
  {
    "country": "CN",
    "name": "Guangyuan",
    "lat": "32.44201",
    "lng": "105.823"
  },
  {
    "country": "CN",
    "name": "Yancheng",
    "lat": "29.74357",
    "lng": "103.56679"
  },
  {
    "country": "CN",
    "name": "Qionghai",
    "lat": "19.2425",
    "lng": "110.46417"
  },
  {
    "country": "CN",
    "name": "Jiading",
    "lat": "25.4295",
    "lng": "114.92804"
  },
  {
    "country": "CN",
    "name": "Huzhou",
    "lat": "30.8703",
    "lng": "120.0933"
  },
  {
    "country": "CN",
    "name": "Ganting",
    "lat": "34.10241",
    "lng": "108.61406"
  },
  {
    "country": "CN",
    "name": "Hutang",
    "lat": "31.53429",
    "lng": "119.49"
  },
  {
    "country": "CN",
    "name": "Xushan",
    "lat": "30.1764",
    "lng": "121.2457"
  },
  {
    "country": "CN",
    "name": "Huozhuangzi",
    "lat": "39.29148",
    "lng": "117.31358"
  },
  {
    "country": "CN",
    "name": "Huotong",
    "lat": "26.84972",
    "lng": "119.41806"
  },
  {
    "country": "CN",
    "name": "Huoqiu Chengguanzhen",
    "lat": "32.35473",
    "lng": "116.2939"
  },
  {
    "country": "CN",
    "name": "Huomachong",
    "lat": "27.88333",
    "lng": "110.23"
  },
  {
    "country": "CN",
    "name": "Huolu",
    "lat": "38.08056",
    "lng": "114.29611"
  },
  {
    "country": "CN",
    "name": "Huojia Chengguanzhen",
    "lat": "35.26556",
    "lng": "113.65056"
  },
  {
    "country": "CN",
    "name": "Huogezhuang",
    "lat": "39.74389",
    "lng": "117.3675"
  },
  {
    "country": "CN",
    "name": "Yong’an",
    "lat": "39.69571",
    "lng": "113.68708"
  },
  {
    "country": "CN",
    "name": "Humen",
    "lat": "22.81899",
    "lng": "113.67306"
  },
  {
    "country": "CN",
    "name": "Huliao",
    "lat": "24.35764",
    "lng": "116.68663"
  },
  {
    "country": "CN",
    "name": "Huizhou",
    "lat": "23.11147",
    "lng": "114.41523"
  },
  {
    "country": "CN",
    "name": "Chengguan",
    "lat": "35.45861",
    "lng": "113.79778"
  },
  {
    "country": "CN",
    "name": "Huixian Chengguanzhen",
    "lat": "33.76833",
    "lng": "106.08083"
  },
  {
    "country": "CN",
    "name": "Huishi",
    "lat": "35.69196",
    "lng": "105.04858"
  },
  {
    "country": "CN",
    "name": "Huilong",
    "lat": "31.81111",
    "lng": "121.655"
  },
  {
    "country": "CN",
    "name": "Huili Chengguanzhen",
    "lat": "26.66256",
    "lng": "102.24392"
  },
  {
    "country": "CN",
    "name": "Huidong",
    "lat": "26.63745",
    "lng": "102.57568"
  },
  {
    "country": "CN",
    "name": "Huicheng",
    "lat": "29.86925",
    "lng": "118.43364"
  },
  {
    "country": "CN",
    "name": "Huicheng",
    "lat": "23.03845",
    "lng": "116.28988"
  },
  {
    "country": "CN",
    "name": "Xinhui",
    "lat": "22.456",
    "lng": "113.0482"
  },
  {
    "country": "CN",
    "name": "Longquan",
    "lat": "36.11736",
    "lng": "113.18571"
  },
  {
    "country": "CN",
    "name": "Huazhou",
    "lat": "21.63333",
    "lng": "110.58333"
  },
  {
    "country": "CN",
    "name": "Huazangsi",
    "lat": "36.97653",
    "lng": "103.13522"
  },
  {
    "country": "CN",
    "name": "Huayuan",
    "lat": "31.31422",
    "lng": "114.01775"
  },
  {
    "country": "CN",
    "name": "Huayuan",
    "lat": "28.58815",
    "lng": "109.47578"
  },
  {
    "country": "CN",
    "name": "Huayuan",
    "lat": "26.91361",
    "lng": "110.53583"
  },
  {
    "country": "CN",
    "name": "Shuanghejiedao",
    "lat": "30.37448",
    "lng": "106.77266"
  },
  {
    "country": "CN",
    "name": "Huayin",
    "lat": "34.56528",
    "lng": "110.06639"
  },
  {
    "country": "CN",
    "name": "Huayang",
    "lat": "30.07087",
    "lng": "118.59032"
  },
  {
    "country": "CN",
    "name": "Huazhou",
    "lat": "34.51523",
    "lng": "109.75759"
  },
  {
    "country": "CN",
    "name": "Huarong",
    "lat": "30.53333",
    "lng": "114.73333"
  },
  {
    "country": "CN",
    "name": "Huarong Chengguanzhen",
    "lat": "29.51889",
    "lng": "112.54837"
  },
  {
    "country": "CN",
    "name": "Huaqiu",
    "lat": "28.11665",
    "lng": "106.60225"
  },
  {
    "country": "CN",
    "name": "Huaqiao",
    "lat": "27.70806",
    "lng": "110.14194"
  },
  {
    "country": "CN",
    "name": "Huantuo",
    "lat": "39.22634",
    "lng": "117.3239"
  },
  {
    "country": "CN",
    "name": "Huangzhuang",
    "lat": "39.48167",
    "lng": "117.51361"
  },
  {
    "country": "CN",
    "name": "Huangzhuang",
    "lat": "39.34284",
    "lng": "117.05515"
  },
  {
    "country": "CN",
    "name": "Huangzhuang",
    "lat": "39.31472",
    "lng": "117.05333"
  },
  {
    "country": "CN",
    "name": "Huangzhou",
    "lat": "30.45",
    "lng": "114.8"
  },
  {
    "country": "CN",
    "name": "Huangzhai",
    "lat": "38.07514",
    "lng": "112.65946"
  },
  {
    "country": "CN",
    "name": "Huangyuan Chengguanzhen",
    "lat": "36.68749",
    "lng": "101.27084"
  },
  {
    "country": "CN",
    "name": "Huangyan",
    "lat": "28.6501",
    "lng": "121.26591"
  },
  {
    "country": "CN",
    "name": "Huangxikou",
    "lat": "27.71889",
    "lng": "110.385"
  },
  {
    "country": "CN",
    "name": "Donglai",
    "lat": "37.64707",
    "lng": "120.5227"
  },
  {
    "country": "CN",
    "name": "Huangtukuang",
    "lat": "26.91528",
    "lng": "110.40778"
  },
  {
    "country": "CN",
    "name": "Huangshi",
    "lat": "30.24706",
    "lng": "115.04814"
  },
  {
    "country": "CN",
    "name": "Huangshan",
    "lat": "26.82634",
    "lng": "100.21906"
  },
  {
    "country": "CN",
    "name": "Huangqiao",
    "lat": "27.02194",
    "lng": "110.84056"
  },
  {
    "country": "CN",
    "name": "Dasha",
    "lat": "23.11037",
    "lng": "113.4418"
  },
  {
    "country": "CN",
    "name": "Huangpi",
    "lat": "30.88453",
    "lng": "114.37789"
  },
  {
    "country": "CN",
    "name": "Huangmei",
    "lat": "30.19235",
    "lng": "116.02496"
  },
  {
    "country": "CN",
    "name": "Huangmaoyuan",
    "lat": "27.40417",
    "lng": "110.47472"
  },
  {
    "country": "CN",
    "name": "Huanglong",
    "lat": "26.54139",
    "lng": "110.93444"
  },
  {
    "country": "CN",
    "name": "Huangjinjing",
    "lat": "27.58563",
    "lng": "110.89133"
  },
  {
    "country": "CN",
    "name": "Huanggang",
    "lat": "23.67704",
    "lng": "116.99961"
  },
  {
    "country": "CN",
    "name": "Daxing",
    "lat": "39.74025",
    "lng": "116.32693"
  },
  {
    "country": "CN",
    "name": "Dingcheng",
    "lat": "32.12722",
    "lng": "115.03944"
  },
  {
    "country": "CN",
    "name": "Huangcaotuo",
    "lat": "39.1794",
    "lng": "117.32156"
  },
  {
    "country": "CN",
    "name": "Hong’an Chengguanzhen",
    "lat": "31.36208",
    "lng": "114.63689"
  },
  {
    "country": "CN",
    "name": "Huanfeng",
    "lat": "31.71667",
    "lng": "118.1"
  },
  {
    "country": "CN",
    "name": "Huaiyuan Chengguanzhen",
    "lat": "32.95893",
    "lng": "117.16566"
  },
  {
    "country": "CN",
    "name": "Huaiyang Chengguanzhen",
    "lat": "33.73333",
    "lng": "114.88333"
  },
  {
    "country": "CN",
    "name": "Yunzhong",
    "lat": "39.82707",
    "lng": "113.09622"
  },
  {
    "country": "CN",
    "name": "Huainan",
    "lat": "32.62639",
    "lng": "116.99694"
  },
  {
    "country": "CN",
    "name": "Yanshi Chengguanzhen",
    "lat": "34.71601",
    "lng": "112.79568"
  },
  {
    "country": "CN",
    "name": "Huaicheng",
    "lat": "23.91952",
    "lng": "112.17629"
  },
  {
    "country": "CN",
    "name": "Huaihua",
    "lat": "27.56337",
    "lng": "110.00404"
  },
  {
    "country": "CN",
    "name": "Huaidian",
    "lat": "33.43333",
    "lng": "115.03333"
  },
  {
    "country": "CN",
    "name": "Huaibei",
    "lat": "33.97444",
    "lng": "116.79167"
  },
  {
    "country": "CN",
    "name": "Huai’an",
    "lat": "33.50389",
    "lng": "119.14417"
  },
  {
    "country": "CN",
    "name": "Huagai",
    "lat": "31.54633",
    "lng": "104.55532"
  },
  {
    "country": "CN",
    "name": "Huafeng",
    "lat": "25.00167",
    "lng": "117.5275"
  },
  {
    "country": "CN",
    "name": "Houxiang",
    "lat": "39.51278",
    "lng": "117.11583"
  },
  {
    "country": "CN",
    "name": "Xintian",
    "lat": "35.61358",
    "lng": "111.3566"
  },
  {
    "country": "CN",
    "name": "Hongzhou",
    "lat": "26.12583",
    "lng": "109.40889"
  },
  {
    "country": "CN",
    "name": "Hongyang",
    "lat": "26.52861",
    "lng": "119.4625"
  },
  {
    "country": "CN",
    "name": "Dahuaishu",
    "lat": "36.26556",
    "lng": "111.67528"
  },
  {
    "country": "CN",
    "name": "Hongsipu",
    "lat": "37.39917",
    "lng": "106.06028"
  },
  {
    "country": "CN",
    "name": "Hongkou",
    "lat": "31.25",
    "lng": "121.48917"
  },
  {
    "country": "CN",
    "name": "Donghe",
    "lat": "32.23341",
    "lng": "106.30126"
  },
  {
    "country": "CN",
    "name": "Hongjiang",
    "lat": "27.11",
    "lng": "109.99556"
  },
  {
    "country": "CN",
    "name": "Hezuo",
    "lat": "34.98556",
    "lng": "102.90944"
  },
  {
    "country": "CN",
    "name": "Hezheng Chengguanzhen",
    "lat": "35.42999",
    "lng": "103.35725"
  },
  {
    "country": "CN",
    "name": "Hezhang",
    "lat": "27.12222",
    "lng": "104.72389"
  },
  {
    "country": "CN",
    "name": "Heze",
    "lat": "35.23929",
    "lng": "115.47358"
  },
  {
    "country": "CN",
    "name": "Heyin",
    "lat": "36.04408",
    "lng": "101.42874"
  },
  {
    "country": "CN",
    "name": "Hechuan",
    "lat": "29.99228",
    "lng": "106.26461"
  },
  {
    "country": "CN",
    "name": "Hexiangqiao",
    "lat": "27.22028",
    "lng": "110.96333"
  },
  {
    "country": "CN",
    "name": "Hetang",
    "lat": "26.66276",
    "lng": "119.11062"
  },
  {
    "country": "CN",
    "name": "Yixing",
    "lat": "37.3376",
    "lng": "113.53926"
  },
  {
    "country": "CN",
    "name": "Jianshe",
    "lat": "34.2175",
    "lng": "113.76889"
  },
  {
    "country": "CN",
    "name": "Yiyang",
    "lat": "28.58917",
    "lng": "112.32833"
  },
  {
    "country": "CN",
    "name": "Wenbi",
    "lat": "39.3874",
    "lng": "111.19115"
  },
  {
    "country": "CN",
    "name": "Hepo",
    "lat": "23.43077",
    "lng": "115.82991"
  },
  {
    "country": "CN",
    "name": "Hepingyizu",
    "lat": "29.24693",
    "lng": "103.08249"
  },
  {
    "country": "CN",
    "name": "Heping",
    "lat": "28.5579",
    "lng": "108.49"
  },
  {
    "country": "CN",
    "name": "Hengzhou",
    "lat": "22.68862",
    "lng": "109.26589"
  },
  {
    "country": "CN",
    "name": "Hengyang",
    "lat": "26.88946",
    "lng": "112.61888"
  },
  {
    "country": "CN",
    "name": "Hengshui",
    "lat": "37.73222",
    "lng": "115.70111"
  },
  {
    "country": "CN",
    "name": "Hengshui",
    "lat": "25.7",
    "lng": "114.31667"
  },
  {
    "country": "CN",
    "name": "Kaiyun",
    "lat": "27.21351",
    "lng": "112.85599"
  },
  {
    "country": "CN",
    "name": "Hengdong Chengguanzhen",
    "lat": "27.08333",
    "lng": "112.95"
  },
  {
    "country": "CN",
    "name": "Hengbanqiao",
    "lat": "27.17167",
    "lng": "110.86528"
  },
  {
    "country": "CN",
    "name": "Helixi",
    "lat": "30.62841",
    "lng": "118.98124"
  },
  {
    "country": "CN",
    "name": "Helie",
    "lat": "31.5214",
    "lng": "120.28961"
  },
  {
    "country": "CN",
    "name": "Hekou",
    "lat": "28.31585",
    "lng": "117.70843"
  },
  {
    "country": "CN",
    "name": "Hekou",
    "lat": "22.53851",
    "lng": "104.01109"
  },
  {
    "country": "CN",
    "name": "Hejiang",
    "lat": "28.81161",
    "lng": "105.83359"
  },
  {
    "country": "CN",
    "name": "Heilangkou",
    "lat": "39.61278",
    "lng": "117.40167"
  },
  {
    "country": "CN",
    "name": "Hefei",
    "lat": "31.86389",
    "lng": "117.28083"
  },
  {
    "country": "CN",
    "name": "Hede",
    "lat": "33.7722",
    "lng": "120.26176"
  },
  {
    "country": "CN",
    "name": "Hecun",
    "lat": "36.53333",
    "lng": "114.11111"
  },
  {
    "country": "CN",
    "name": "Hechuan",
    "lat": "26.93613",
    "lng": "114.22778"
  },
  {
    "country": "CN",
    "name": "Hecheng",
    "lat": "28.13939",
    "lng": "120.28799"
  },
  {
    "country": "CN",
    "name": "Hebi",
    "lat": "35.89917",
    "lng": "114.1925"
  },
  {
    "country": "CN",
    "name": "Hebeitun",
    "lat": "39.57472",
    "lng": "117.11333"
  },
  {
    "country": "CN",
    "name": "Haoxue",
    "lat": "30.04761",
    "lng": "112.46759"
  },
  {
    "country": "CN",
    "name": "Hanzhong",
    "lat": "33.07507",
    "lng": "107.02214"
  },
  {
    "country": "CN",
    "name": "Hanyuan",
    "lat": "34.01083",
    "lng": "105.29194"
  },
  {
    "country": "CN",
    "name": "Hanyin Chengguanzhen",
    "lat": "32.89139",
    "lng": "108.50472"
  },
  {
    "country": "CN",
    "name": "Chengyang",
    "lat": "27.08917",
    "lng": "119.64528"
  },
  {
    "country": "CN",
    "name": "Hanting",
    "lat": "36.77083",
    "lng": "119.21083"
  },
  {
    "country": "CN",
    "name": "Hanshou",
    "lat": "28.90583",
    "lng": "111.95611"
  },
  {
    "country": "CN",
    "name": "Hanjiashu",
    "lat": "39.1875",
    "lng": "117.07306"
  },
  {
    "country": "CN",
    "name": "Hanjia",
    "lat": "29.29524",
    "lng": "108.16132"
  },
  {
    "country": "CN",
    "name": "Hanji",
    "lat": "35.49544",
    "lng": "102.9926"
  },
  {
    "country": "CN",
    "name": "Hangzhou",
    "lat": "30.29365",
    "lng": "120.16142"
  },
  {
    "country": "CN",
    "name": "Hangu",
    "lat": "39.24889",
    "lng": "117.78917"
  },
  {
    "country": "CN",
    "name": "Hangou",
    "lat": "39.29083",
    "lng": "117.09"
  },
  {
    "country": "CN",
    "name": "Hangchuan",
    "lat": "27.51947",
    "lng": "117.33491"
  },
  {
    "country": "CN",
    "name": "Hanfeng",
    "lat": "31.16946",
    "lng": "108.4031"
  },
  {
    "country": "CN",
    "name": "Changzhi",
    "lat": "36.18389",
    "lng": "113.10528"
  },
  {
    "country": "CN",
    "name": "Handian",
    "lat": "36.04583",
    "lng": "113.04417"
  },
  {
    "country": "CN",
    "name": "Handan",
    "lat": "36.60056",
    "lng": "114.46778"
  },
  {
    "country": "CN",
    "name": "Hanchuan",
    "lat": "30.65",
    "lng": "113.76667"
  },
  {
    "country": "CN",
    "name": "Hancheng",
    "lat": "35.46028",
    "lng": "110.42917"
  },
  {
    "country": "CN",
    "name": "Haizhou",
    "lat": "34.58167",
    "lng": "119.12889"
  },
  {
    "country": "CN",
    "name": "Sanhe",
    "lat": "36.5641",
    "lng": "105.639"
  },
  {
    "country": "CN",
    "name": "Haiyang",
    "lat": "29.78612",
    "lng": "118.17698"
  },
  {
    "country": "CN",
    "name": "Haishiwan",
    "lat": "36.34628",
    "lng": "102.85799"
  },
  {
    "country": "CN",
    "name": "Jiaojiang",
    "lat": "28.69844",
    "lng": "121.47331"
  },
  {
    "country": "CN",
    "name": "Haimen",
    "lat": "23.19346",
    "lng": "116.61219"
  },
  {
    "country": "CN",
    "name": "Haikou",
    "lat": "24.77985",
    "lng": "102.57548"
  },
  {
    "country": "CN",
    "name": "Haikou",
    "lat": "20.04583",
    "lng": "110.34167"
  },
  {
    "country": "CN",
    "name": "Haicheng",
    "lat": "22.97533",
    "lng": "115.33179"
  },
  {
    "country": "CN",
    "name": "Haidian",
    "lat": "39.99064",
    "lng": "116.28868"
  },
  {
    "country": "CN",
    "name": "Hai’an",
    "lat": "32.54361",
    "lng": "120.45"
  },
  {
    "country": "CN",
    "name": "Guzhen Chengguanzhen",
    "lat": "33.31056",
    "lng": "117.31056"
  },
  {
    "country": "CN",
    "name": "Guyong",
    "lat": "26.73083",
    "lng": "117.46833"
  },
  {
    "country": "CN",
    "name": "Guyi",
    "lat": "25.77778",
    "lng": "109.60028"
  },
  {
    "country": "CN",
    "name": "Guye",
    "lat": "39.73054",
    "lng": "118.44085"
  },
  {
    "country": "CN",
    "name": "Guyang",
    "lat": "28.61385",
    "lng": "109.93253"
  },
  {
    "country": "CN",
    "name": "Gushi Chengguanzhen",
    "lat": "32.16208",
    "lng": "115.66989"
  },
  {
    "country": "CN",
    "name": "Guozhen",
    "lat": "34.36591",
    "lng": "107.35904"
  },
  {
    "country": "CN",
    "name": "Guoyang Chengguanzhen",
    "lat": "33.5055",
    "lng": "116.2308"
  },
  {
    "country": "CN",
    "name": "Lingbao Chengguanzhen",
    "lat": "34.51972",
    "lng": "110.86444"
  },
  {
    "country": "CN",
    "name": "Guofuchang",
    "lat": "28.85",
    "lng": "106.60139"
  },
  {
    "country": "CN",
    "name": "Gunan",
    "lat": "29.0231",
    "lng": "106.648"
  },
  {
    "country": "CN",
    "name": "Gulin",
    "lat": "28.04223",
    "lng": "105.81038"
  },
  {
    "country": "CN",
    "name": "Guli",
    "lat": "28.88162",
    "lng": "120.03308"
  },
  {
    "country": "CN",
    "name": "Gulaobei",
    "lat": "30.51941",
    "lng": "111.42664"
  },
  {
    "country": "CN",
    "name": "Gulang",
    "lat": "37.46657",
    "lng": "102.89428"
  },
  {
    "country": "CN",
    "name": "Guiyang",
    "lat": "26.58333",
    "lng": "106.71667"
  },
  {
    "country": "CN",
    "name": "Guiyang Chengguanzhen",
    "lat": "25.73333",
    "lng": "112.74589"
  },
  {
    "country": "CN",
    "name": "Guixi",
    "lat": "30.33355",
    "lng": "107.34545"
  },
  {
    "country": "CN",
    "name": "Guishan",
    "lat": "24.05027",
    "lng": "102.00018"
  },
  {
    "country": "CN",
    "name": "Guiren",
    "lat": "33.66972",
    "lng": "118.18889"
  },
  {
    "country": "CN",
    "name": "Guiping",
    "lat": "23.39336",
    "lng": "110.07437"
  },
  {
    "country": "CN",
    "name": "Guilin",
    "lat": "25.28194",
    "lng": "110.28639"
  },
  {
    "country": "CN",
    "name": "Guidong Chengguanzhen",
    "lat": "26.07903",
    "lng": "113.94062"
  },
  {
    "country": "CN",
    "name": "Guigang",
    "lat": "23.09639",
    "lng": "109.60917"
  },
  {
    "country": "CN",
    "name": "Gufeng",
    "lat": "26.90833",
    "lng": "118.98194"
  },
  {
    "country": "CN",
    "name": "Gucheng Chengguanzhen",
    "lat": "32.26604",
    "lng": "111.63476"
  },
  {
    "country": "CN",
    "name": "Guancheng",
    "lat": "36.48031",
    "lng": "115.4351"
  },
  {
    "country": "CN",
    "name": "Guantou",
    "lat": "26.13515",
    "lng": "119.55718"
  },
  {
    "country": "CN",
    "name": "Guangzhou",
    "lat": "23.11667",
    "lng": "113.25"
  },
  {
    "country": "CN",
    "name": "Guanyang",
    "lat": "25.49523",
    "lng": "111.13487"
  },
  {
    "country": "CN",
    "name": "Guangshui",
    "lat": "31.6199",
    "lng": "113.9978"
  },
  {
    "country": "CN",
    "name": "Zishui",
    "lat": "32.00773",
    "lng": "114.90108"
  },
  {
    "country": "CN",
    "name": "Guangrao",
    "lat": "37.05286",
    "lng": "118.3991"
  },
  {
    "country": "CN",
    "name": "Guangming",
    "lat": "28.3102",
    "lng": "102.41189"
  },
  {
    "country": "CN",
    "name": "Huquan",
    "lat": "39.79538",
    "lng": "114.18303"
  },
  {
    "country": "CN",
    "name": "Guandu",
    "lat": "28.56833",
    "lng": "106.10255"
  },
  {
    "country": "CN",
    "name": "Gongjing",
    "lat": "29.34748",
    "lng": "104.71157"
  },
  {
    "country": "CN",
    "name": "Gongjiang",
    "lat": "25.95735",
    "lng": "115.41002"
  },
  {
    "country": "CN",
    "name": "Gonghe",
    "lat": "25.25575",
    "lng": "101.51857"
  },
  {
    "country": "CN",
    "name": "Gongcheng",
    "lat": "24.83333",
    "lng": "110.81667"
  },
  {
    "country": "CN",
    "name": "Gejiu",
    "lat": "23.36085",
    "lng": "103.15372"
  },
  {
    "country": "CN",
    "name": "Gedong",
    "lat": "37.89311",
    "lng": "111.25544"
  },
  {
    "country": "CN",
    "name": "Gecheng",
    "lat": "31.94856",
    "lng": "108.66073"
  },
  {
    "country": "CN",
    "name": "Ganzi",
    "lat": "31.62744",
    "lng": "99.99413"
  },
  {
    "country": "CN",
    "name": "Gaozhuang",
    "lat": "39.26917",
    "lng": "117.97556"
  },
  {
    "country": "CN",
    "name": "Gaozhou",
    "lat": "21.93924",
    "lng": "110.84607"
  },
  {
    "country": "CN",
    "name": "Gaozeng",
    "lat": "25.80167",
    "lng": "108.9375"
  },
  {
    "country": "CN",
    "name": "Gaoyou",
    "lat": "32.78933",
    "lng": "119.44182"
  },
  {
    "country": "CN",
    "name": "Gaotangling",
    "lat": "28.36667",
    "lng": "112.81667"
  },
  {
    "country": "CN",
    "name": "Gaoyi",
    "lat": "26.95944",
    "lng": "110.01556"
  },
  {
    "country": "CN",
    "name": "Gaoqiao",
    "lat": "26.63361",
    "lng": "110.9"
  },
  {
    "country": "CN",
    "name": "Gaoping",
    "lat": "30.77576",
    "lng": "106.10294"
  },
  {
    "country": "CN",
    "name": "Gaoniang",
    "lat": "26.8425",
    "lng": "109.17889"
  },
  {
    "country": "CN",
    "name": "Gaomi",
    "lat": "36.38333",
    "lng": "119.75278"
  },
  {
    "country": "CN",
    "name": "Gaoleshan",
    "lat": "29.67825",
    "lng": "109.14453"
  },
  {
    "country": "CN",
    "name": "Gaojingzhuang",
    "lat": "39.41611",
    "lng": "117.63"
  },
  {
    "country": "CN",
    "name": "Gaohe",
    "lat": "30.74173",
    "lng": "116.84259"
  },
  {
    "country": "CN",
    "name": "Gaogou",
    "lat": "34.0175",
    "lng": "119.18861"
  },
  {
    "country": "CN",
    "name": "Gaocun",
    "lat": "27.87731",
    "lng": "109.78476"
  },
  {
    "country": "CN",
    "name": "Gaocheng",
    "lat": "29.98814",
    "lng": "100.2694"
  },
  {
    "country": "CN",
    "name": "Ganzhou",
    "lat": "25.84664",
    "lng": "114.9326"
  },
  {
    "country": "CN",
    "name": "Gantang",
    "lat": "30.29694",
    "lng": "118.13056"
  },
  {
    "country": "CN",
    "name": "Gantang",
    "lat": "26.92",
    "lng": "119.63333"
  },
  {
    "country": "CN",
    "name": "Gantang",
    "lat": "26.79833",
    "lng": "118.93611"
  },
  {
    "country": "CN",
    "name": "Lingchuan",
    "lat": "25.40951",
    "lng": "110.32278"
  },
  {
    "country": "CN",
    "name": "Ganshui",
    "lat": "28.74222",
    "lng": "106.71111"
  },
  {
    "country": "CN",
    "name": "Gangu Chengguanzhen",
    "lat": "34.73564",
    "lng": "105.32632"
  },
  {
    "country": "CN",
    "name": "Gabasumdo",
    "lat": "35.2589",
    "lng": "100.54994"
  },
  {
    "country": "CN",
    "name": "Fuzhuang",
    "lat": "39.26611",
    "lng": "117.93444"
  },
  {
    "country": "CN",
    "name": "Fuzhou",
    "lat": "26.06139",
    "lng": "119.30611"
  },
  {
    "country": "CN",
    "name": "Fuyang",
    "lat": "32.9",
    "lng": "115.81667"
  },
  {
    "country": "CN",
    "name": "Fuyang",
    "lat": "30.05333",
    "lng": "119.95194"
  },
  {
    "country": "CN",
    "name": "Fuyang",
    "lat": "24.83441",
    "lng": "111.25802"
  },
  {
    "country": "CN",
    "name": "Qingyang",
    "lat": "37.49583",
    "lng": "121.25806"
  },
  {
    "country": "CN",
    "name": "Tiantan",
    "lat": "35.96611",
    "lng": "111.84167"
  },
  {
    "country": "CN",
    "name": "Furong",
    "lat": "26.45",
    "lng": "114.76667"
  },
  {
    "country": "CN",
    "name": "Fuling",
    "lat": "29.706",
    "lng": "107.39575"
  },
  {
    "country": "CN",
    "name": "Fuliang",
    "lat": "29.37639",
    "lng": "117.24667"
  },
  {
    "country": "CN",
    "name": "Fushi",
    "lat": "29.18382",
    "lng": "105.00114"
  },
  {
    "country": "CN",
    "name": "Fuji",
    "lat": "29.14819",
    "lng": "105.37391"
  },
  {
    "country": "CN",
    "name": "Fugou Chengguanzhen",
    "lat": "34.06667",
    "lng": "114.38333"
  },
  {
    "country": "CN",
    "name": "Fufeng",
    "lat": "34.36051",
    "lng": "107.87348"
  },
  {
    "country": "CN",
    "name": "Fucheng",
    "lat": "37.86913",
    "lng": "116.15058"
  },
  {
    "country": "CN",
    "name": "Fubao",
    "lat": "28.76905",
    "lng": "106.07667"
  },
  {
    "country": "CN",
    "name": "Foshan",
    "lat": "23.02677",
    "lng": "113.13148"
  },
  {
    "country": "CN",
    "name": "Fenyi",
    "lat": "27.81117",
    "lng": "114.66805"
  },
  {
    "country": "CN",
    "name": "Yong’an",
    "lat": "36.65762",
    "lng": "111.56643"
  },
  {
    "country": "CN",
    "name": "Fengzhou",
    "lat": "24.95762",
    "lng": "118.53365"
  },
  {
    "country": "CN",
    "name": "Fengyi",
    "lat": "31.68412",
    "lng": "103.85382"
  },
  {
    "country": "CN",
    "name": "Fengyi",
    "lat": "28.5537",
    "lng": "107.439"
  },
  {
    "country": "CN",
    "name": "Fengyang Fuchengzhen",
    "lat": "32.87969",
    "lng": "117.54465"
  },
  {
    "country": "CN",
    "name": "Fengxian",
    "lat": "34.70388",
    "lng": "116.58717"
  },
  {
    "country": "CN",
    "name": "Fengtai",
    "lat": "39.55806",
    "lng": "117.74917"
  },
  {
    "country": "CN",
    "name": "Fengtai",
    "lat": "39.84757",
    "lng": "116.27227"
  },
  {
    "country": "CN",
    "name": "Fengtai Chengguanzhen",
    "lat": "32.70825",
    "lng": "116.72956"
  },
  {
    "country": "CN",
    "name": "Fengshan",
    "lat": "30.88712",
    "lng": "115.42091"
  },
  {
    "country": "CN",
    "name": "Fengshan",
    "lat": "26.48556",
    "lng": "119.54917"
  },
  {
    "country": "CN",
    "name": "Fengcheng",
    "lat": "24.57117",
    "lng": "107.04243"
  },
  {
    "country": "CN",
    "name": "Fengrun",
    "lat": "39.83333",
    "lng": "118.11667"
  },
  {
    "country": "CN",
    "name": "Fengqiu Chengguanzhen",
    "lat": "35.02917",
    "lng": "114.41306"
  },
  {
    "country": "CN",
    "name": "Fengpu",
    "lat": "26.68276",
    "lng": "118.76006"
  },
  {
    "country": "CN",
    "name": "Fengming",
    "lat": "34.44139",
    "lng": "107.61778"
  },
  {
    "country": "CN",
    "name": "Fenglu",
    "lat": "24.67652",
    "lng": "102.91129"
  },
  {
    "country": "CN",
    "name": "Fengkou",
    "lat": "30.08268",
    "lng": "113.33346"
  },
  {
    "country": "CN",
    "name": "Fenggang",
    "lat": "27.54566",
    "lng": "116.21456"
  },
  {
    "country": "CN",
    "name": "Shuangzhu",
    "lat": "26.63114",
    "lng": "118.6457"
  },
  {
    "country": "CN",
    "name": "Fengchuan",
    "lat": "28.7",
    "lng": "115.38333"
  },
  {
    "country": "CN",
    "name": "Fengcheng",
    "lat": "26.19722",
    "lng": "119.53917"
  },
  {
    "country": "CN",
    "name": "Fengcheng",
    "lat": "25.05697",
    "lng": "118.1829"
  },
  {
    "country": "CN",
    "name": "Fengcheng",
    "lat": "24.72365",
    "lng": "116.72429"
  },
  {
    "country": "CN",
    "name": "Feicheng",
    "lat": "35.26056",
    "lng": "117.9675"
  },
  {
    "country": "CN",
    "name": "Feiluan",
    "lat": "26.5625",
    "lng": "119.5975"
  },
  {
    "country": "CN",
    "name": "Fanshi",
    "lat": "39.18992",
    "lng": "113.26401"
  },
  {
    "country": "CN",
    "name": "Fanzhuang",
    "lat": "39.19361",
    "lng": "117.335"
  },
  {
    "country": "CN",
    "name": "Fangxian Chengguanzhen",
    "lat": "32.055",
    "lng": "110.73417"
  },
  {
    "country": "CN",
    "name": "Fangting",
    "lat": "31.12766",
    "lng": "104.16649"
  },
  {
    "country": "CN",
    "name": "Fangshan",
    "lat": "39.68699",
    "lng": "115.99658"
  },
  {
    "country": "CN",
    "name": "Fangjiazhuang",
    "lat": "39.72972",
    "lng": "117.42056"
  },
  {
    "country": "CN",
    "name": "Fangcheng Chengguanzhen",
    "lat": "33.25322",
    "lng": "113.0012"
  },
  {
    "country": "CN",
    "name": "Fanyang",
    "lat": "31.08471",
    "lng": "118.19425"
  },
  {
    "country": "CN",
    "name": "Ezhou",
    "lat": "30.4",
    "lng": "114.83333"
  },
  {
    "country": "CN",
    "name": "Erwangzhuang",
    "lat": "39.39167",
    "lng": "117.35389"
  },
  {
    "country": "CN",
    "name": "Erqu",
    "lat": "34.15278",
    "lng": "108.20639"
  },
  {
    "country": "CN",
    "name": "Dawu Chengguanzhen",
    "lat": "31.60965",
    "lng": "114.11806"
  },
  {
    "country": "CN",
    "name": "Enshi",
    "lat": "30.3",
    "lng": "109.48333"
  },
  {
    "country": "CN",
    "name": "Enle",
    "lat": "23.96049",
    "lng": "101.08265"
  },
  {
    "country": "CN",
    "name": "Enjiang",
    "lat": "27.32177",
    "lng": "115.42925"
  },
  {
    "country": "CN",
    "name": "Encheng",
    "lat": "22.18659",
    "lng": "112.30424"
  },
  {
    "country": "CN",
    "name": "Ehen Hudag",
    "lat": "39.21074",
    "lng": "101.66898"
  },
  {
    "country": "CN",
    "name": "Duyun",
    "lat": "26.26667",
    "lng": "107.51667"
  },
  {
    "country": "CN",
    "name": "Duru",
    "lat": "28.5255",
    "lng": "107.887"
  },
  {
    "country": "CN",
    "name": "Duobao",
    "lat": "30.67",
    "lng": "112.68952"
  },
  {
    "country": "CN",
    "name": "Dunhou",
    "lat": "27.05",
    "lng": "114.9"
  },
  {
    "country": "CN",
    "name": "Doucun",
    "lat": "34.74809",
    "lng": "109.17968"
  },
  {
    "country": "CN",
    "name": "Ducheng",
    "lat": "23.24212",
    "lng": "111.5284"
  },
  {
    "country": "CN",
    "name": "Duchang",
    "lat": "29.266",
    "lng": "116.18631"
  },
  {
    "country": "CN",
    "name": "Douhudi",
    "lat": "30.06056",
    "lng": "112.22417"
  },
  {
    "country": "CN",
    "name": "Xinyi",
    "lat": "22.37303",
    "lng": "110.94746"
  },
  {
    "country": "CN",
    "name": "Dongzhaogezhuang",
    "lat": "39.94889",
    "lng": "117.37"
  },
  {
    "country": "CN",
    "name": "Dongyuan",
    "lat": "24.91738",
    "lng": "118.75236"
  },
  {
    "country": "CN",
    "name": "Donglan",
    "lat": "24.55018",
    "lng": "107.38289"
  },
  {
    "country": "CN",
    "name": "Shengli",
    "lat": "37.46271",
    "lng": "118.49165"
  },
  {
    "country": "CN",
    "name": "Dongxi",
    "lat": "32.06577",
    "lng": "106.24843"
  },
  {
    "country": "CN",
    "name": "Dongxi",
    "lat": "28.76139",
    "lng": "106.66111"
  },
  {
    "country": "CN",
    "name": "Dongtai",
    "lat": "32.85231",
    "lng": "120.30947"
  },
  {
    "country": "CN",
    "name": "Dongtazhuang",
    "lat": "39.89389",
    "lng": "117.33722"
  },
  {
    "country": "CN",
    "name": "Dongsheng",
    "lat": "39.81609",
    "lng": "109.97763"
  },
  {
    "country": "CN",
    "name": "Dongshan",
    "lat": "31.95568",
    "lng": "118.83269"
  },
  {
    "country": "CN",
    "name": "Dongshan Dongzuxiang",
    "lat": "26.595",
    "lng": "109.89667"
  },
  {
    "country": "CN",
    "name": "Dongshan",
    "lat": "25.79389",
    "lng": "114.54256"
  },
  {
    "country": "CN",
    "name": "Dongping",
    "lat": "28.38017",
    "lng": "111.20586"
  },
  {
    "country": "CN",
    "name": "Dongnigu",
    "lat": "39.01655",
    "lng": "117.44396"
  },
  {
    "country": "CN",
    "name": "Dongming Chengguanzhen",
    "lat": "35.29145",
    "lng": "115.09019"
  },
  {
    "country": "CN",
    "name": "Dongmen",
    "lat": "24.79198",
    "lng": "108.9"
  },
  {
    "country": "CN",
    "name": "Dongling",
    "lat": "24.98271",
    "lng": "118.8979"
  },
  {
    "country": "CN",
    "name": "Dongkou",
    "lat": "27.05272",
    "lng": "110.5361"
  },
  {
    "country": "CN",
    "name": "Dongkan",
    "lat": "33.99972",
    "lng": "119.83083"
  },
  {
    "country": "CN",
    "name": "Dongjituo",
    "lat": "39.42194",
    "lng": "117.57417"
  },
  {
    "country": "CN",
    "name": "Donghuang",
    "lat": "28.33297",
    "lng": "106.21557"
  },
  {
    "country": "CN",
    "name": "Donghua",
    "lat": "35.2152",
    "lng": "106.653"
  },
  {
    "country": "CN",
    "name": "Donghai",
    "lat": "22.94593",
    "lng": "115.64204"
  },
  {
    "country": "CN",
    "name": "Dongguang",
    "lat": "37.88509",
    "lng": "116.53283"
  },
  {
    "country": "CN",
    "name": "Dongguan",
    "lat": "39.01732",
    "lng": "111.12674"
  },
  {
    "country": "CN",
    "name": "Dongguan",
    "lat": "23.01797",
    "lng": "113.74866"
  },
  {
    "country": "CN",
    "name": "Dong’erying",
    "lat": "39.9575",
    "lng": "117.27917"
  },
  {
    "country": "CN",
    "name": "Dongdu",
    "lat": "35.85",
    "lng": "117.7"
  },
  {
    "country": "CN",
    "name": "Dongditou",
    "lat": "39.26641",
    "lng": "117.37273"
  },
  {
    "country": "CN",
    "name": "Dongdai",
    "lat": "26.24366",
    "lng": "119.61566"
  },
  {
    "country": "CN",
    "name": "Dongcun",
    "lat": "38.29442",
    "lng": "111.70352"
  },
  {
    "country": "CN",
    "name": "Dongcun",
    "lat": "36.77667",
    "lng": "121.15972"
  },
  {
    "country": "CN",
    "name": "Dongchuan",
    "lat": "25.47655",
    "lng": "101.28468"
  },
  {
    "country": "CN",
    "name": "Dongchong",
    "lat": "26.54001",
    "lng": "119.83257"
  },
  {
    "country": "CN",
    "name": "Dingzhou",
    "lat": "38.51306",
    "lng": "114.99556"
  },
  {
    "country": "CN",
    "name": "Jinchang",
    "lat": "38.49808",
    "lng": "112.9236"
  },
  {
    "country": "CN",
    "name": "Dingxi",
    "lat": "35.57088",
    "lng": "104.62303"
  },
  {
    "country": "CN",
    "name": "Dingtao",
    "lat": "35.07436",
    "lng": "115.56582"
  },
  {
    "country": "CN",
    "name": "Dingping",
    "lat": "30.33862",
    "lng": "106.927"
  },
  {
    "country": "CN",
    "name": "Dinghai",
    "lat": "26.28022",
    "lng": "119.78964"
  },
  {
    "country": "CN",
    "name": "Dingcheng",
    "lat": "32.51609",
    "lng": "117.65952"
  },
  {
    "country": "CN",
    "name": "Dingbian",
    "lat": "37.59266",
    "lng": "107.59428"
  },
  {
    "country": "CN",
    "name": "Dingcheng",
    "lat": "19.67914",
    "lng": "110.36231"
  },
  {
    "country": "CN",
    "name": "Dianbu",
    "lat": "31.87308",
    "lng": "117.45803"
  },
  {
    "country": "CN",
    "name": "Dezhou",
    "lat": "37.45127",
    "lng": "116.31046"
  },
  {
    "country": "CN",
    "name": "Dezhou",
    "lat": "27.40809",
    "lng": "102.18001"
  },
  {
    "country": "CN",
    "name": "Deyang",
    "lat": "31.13019",
    "lng": "104.38198"
  },
  {
    "country": "CN",
    "name": "Deqing",
    "lat": "30.54485",
    "lng": "119.9599"
  },
  {
    "country": "CN",
    "name": "Decheng",
    "lat": "23.14263",
    "lng": "111.77737"
  },
  {
    "country": "CN",
    "name": "Dengzhou",
    "lat": "37.80822",
    "lng": "120.75908"
  },
  {
    "country": "CN",
    "name": "Huazhou",
    "lat": "32.68222",
    "lng": "112.08194"
  },
  {
    "country": "CN",
    "name": "Dengjiapu",
    "lat": "26.90444",
    "lng": "110.92"
  },
  {
    "country": "CN",
    "name": "Songyang",
    "lat": "34.45528",
    "lng": "113.02806"
  },
  {
    "country": "CN",
    "name": "Debao Chengguanzhen",
    "lat": "23.38471",
    "lng": "106.57352"
  },
  {
    "country": "CN",
    "name": "Dazuo",
    "lat": "24.88616",
    "lng": "118.96433"
  },
  {
    "country": "CN",
    "name": "Dazhongzhuang",
    "lat": "39.68083",
    "lng": "117.56417"
  },
  {
    "country": "CN",
    "name": "Dazhong",
    "lat": "33.19973",
    "lng": "120.4578"
  },
  {
    "country": "CN",
    "name": "Dazhe",
    "lat": "24.57556",
    "lng": "115.89184"
  },
  {
    "country": "CN",
    "name": "Zhangjiajie",
    "lat": "29.12944",
    "lng": "110.47833"
  },
  {
    "country": "CN",
    "name": "Daying",
    "lat": "34.72177",
    "lng": "111.10295"
  },
  {
    "country": "CN",
    "name": "Daye",
    "lat": "30.08333",
    "lng": "114.95"
  },
  {
    "country": "CN",
    "name": "Dayanggezhuang",
    "lat": "39.81889",
    "lng": "117.42361"
  },
  {
    "country": "CN",
    "name": "Lijiang",
    "lat": "26.86879",
    "lng": "100.22072"
  },
  {
    "country": "CN",
    "name": "Daxing",
    "lat": "27.26369",
    "lng": "100.86387"
  },
  {
    "country": "CN",
    "name": "Dazhou",
    "lat": "31.21592",
    "lng": "107.50092"
  },
  {
    "country": "CN",
    "name": "Dawukou",
    "lat": "39.04194",
    "lng": "106.39583"
  },
  {
    "country": "CN",
    "name": "Dawu",
    "lat": "34.46623",
    "lng": "100.22993"
  },
  {
    "country": "CN",
    "name": "Dawangtai",
    "lat": "39.27504",
    "lng": "117.48502"
  },
  {
    "country": "CN",
    "name": "Datong",
    "lat": "32.62082",
    "lng": "117.06319"
  },
  {
    "country": "CN",
    "name": "Datianzhuang",
    "lat": "39.2725",
    "lng": "117.75361"
  },
  {
    "country": "CN",
    "name": "Datangzhuang",
    "lat": "39.39944",
    "lng": "117.43417"
  },
  {
    "country": "CN",
    "name": "Dasi",
    "lat": "39.01821",
    "lng": "117.23768"
  },
  {
    "country": "CN",
    "name": "Dashentang",
    "lat": "39.21722",
    "lng": "117.9525"
  },
  {
    "country": "CN",
    "name": "Darong",
    "lat": "25.785",
    "lng": "108.864"
  },
  {
    "country": "CN",
    "name": "Darenzhuang",
    "lat": "39.03889",
    "lng": "117.25194"
  },
  {
    "country": "CN",
    "name": "Fenghua",
    "lat": "29.65628",
    "lng": "121.4064"
  },
  {
    "country": "CN",
    "name": "Daqiao",
    "lat": "26.615",
    "lng": "118.90639"
  },
  {
    "country": "CN",
    "name": "Dabaozi",
    "lat": "26.69556",
    "lng": "109.44778"
  },
  {
    "country": "CN",
    "name": "Daokou",
    "lat": "35.56389",
    "lng": "114.50583"
  },
  {
    "country": "CN",
    "name": "Daojiang",
    "lat": "25.49603",
    "lng": "111.55146"
  },
  {
    "country": "CN",
    "name": "Danyang",
    "lat": "26.35102",
    "lng": "119.4803"
  },
  {
    "country": "CN",
    "name": "Danshui",
    "lat": "22.7984",
    "lng": "114.46716"
  },
  {
    "country": "CN",
    "name": "Danjiangkou",
    "lat": "32.54278",
    "lng": "111.50861"
  },
  {
    "country": "CN",
    "name": "Xinshui",
    "lat": "36.47839",
    "lng": "110.75522"
  },
  {
    "country": "CN",
    "name": "Gushu",
    "lat": "31.56055",
    "lng": "118.48147"
  },
  {
    "country": "CN",
    "name": "Dangcheng",
    "lat": "34.42787",
    "lng": "116.37657"
  },
  {
    "country": "CN",
    "name": "Dangchang Chengguanzhen",
    "lat": "34.04462",
    "lng": "104.39464"
  },
  {
    "country": "CN",
    "name": "Danfeng",
    "lat": "24.83054",
    "lng": "104.0082"
  },
  {
    "country": "CN",
    "name": "Xincheng",
    "lat": "33.63333",
    "lng": "115.18333"
  },
  {
    "country": "CN",
    "name": "Danxi",
    "lat": "29.47472",
    "lng": "121.86556"
  },
  {
    "country": "CN",
    "name": "Daming",
    "lat": "36.28608",
    "lng": "115.14356"
  },
  {
    "country": "CN",
    "name": "Daliang",
    "lat": "39.53944",
    "lng": "117.095"
  },
  {
    "country": "CN",
    "name": "Daliang",
    "lat": "22.84067",
    "lng": "113.2503"
  },
  {
    "country": "CN",
    "name": "Dalian",
    "lat": "38.91222",
    "lng": "121.60222"
  },
  {
    "country": "CN",
    "name": "Dali",
    "lat": "34.79586",
    "lng": "109.93895"
  },
  {
    "country": "CN",
    "name": "Dali",
    "lat": "25.58474",
    "lng": "100.21229"
  },
  {
    "country": "CN",
    "name": "Dakoutun",
    "lat": "39.58333",
    "lng": "117.22889"
  },
  {
    "country": "CN",
    "name": "Dajie",
    "lat": "24.29623",
    "lng": "102.75064"
  },
  {
    "country": "CN",
    "name": "Dajianchang",
    "lat": "39.47778",
    "lng": "117.08306"
  },
  {
    "country": "CN",
    "name": "Daiyue",
    "lat": "39.52038",
    "lng": "112.81684"
  },
  {
    "country": "CN",
    "name": "Shangguan",
    "lat": "39.06901",
    "lng": "112.92913"
  },
  {
    "country": "CN",
    "name": "Daixi",
    "lat": "26.8125",
    "lng": "119.11417"
  },
  {
    "country": "CN",
    "name": "Daishan",
    "lat": "30.24589",
    "lng": "122.19895"
  },
  {
    "country": "CN",
    "name": "Dahuangpu",
    "lat": "39.44111",
    "lng": "117.27778"
  },
  {
    "country": "CN",
    "name": "Dahua",
    "lat": "23.76798",
    "lng": "107.9841"
  },
  {
    "country": "CN",
    "name": "Ziyuan",
    "lat": "26.03667",
    "lng": "110.64056"
  },
  {
    "country": "CN",
    "name": "Dazhasi",
    "lat": "33.57795",
    "lng": "102.96412"
  },
  {
    "country": "CN",
    "name": "Dafeng",
    "lat": "23.43422",
    "lng": "108.59825"
  },
  {
    "country": "CN",
    "name": "Dadunqiu",
    "lat": "39.40611",
    "lng": "117.03306"
  },
  {
    "country": "CN",
    "name": "Xinshancun",
    "lat": "29.486",
    "lng": "106.47861"
  },
  {
    "country": "CN",
    "name": "Xinxing",
    "lat": "39.86694",
    "lng": "124.12304"
  },
  {
    "country": "CN",
    "name": "Dadeng",
    "lat": "24.54386",
    "lng": "118.32753"
  },
  {
    "country": "CN",
    "name": "Dabu",
    "lat": "24.66739",
    "lng": "109.23547"
  },
  {
    "country": "CN",
    "name": "Dabizhuang",
    "lat": "39.19306",
    "lng": "117.25583"
  },
  {
    "country": "CN",
    "name": "Dabao’anzhen",
    "lat": "39.89944",
    "lng": "117.47639"
  },
  {
    "country": "CN",
    "name": "Dabaizhuang",
    "lat": "39.44472",
    "lng": "117.38028"
  },
  {
    "country": "CN",
    "name": "Dabachang",
    "lat": "27.7425",
    "lng": "108.34333"
  },
  {
    "country": "CN",
    "name": "Cuntan",
    "lat": "29.60248",
    "lng": "106.57055"
  },
  {
    "country": "CN",
    "name": "Cuijiang",
    "lat": "26.26321",
    "lng": "116.64991"
  },
  {
    "country": "CN",
    "name": "Cuijiamatou",
    "lat": "39.07472",
    "lng": "117.30056"
  },
  {
    "country": "CN",
    "name": "Cuihuangkou",
    "lat": "39.52583",
    "lng": "117.18056"
  },
  {
    "country": "CN",
    "name": "Cuihua",
    "lat": "27.73766",
    "lng": "103.85738"
  },
  {
    "country": "CN",
    "name": "Cili",
    "lat": "29.42444",
    "lng": "111.12013"
  },
  {
    "country": "CN",
    "name": "Chuzhou",
    "lat": "32.32194",
    "lng": "118.29778"
  },
  {
    "country": "CN",
    "name": "Chunxi",
    "lat": "31.32769",
    "lng": "118.87489"
  },
  {
    "country": "CN",
    "name": "Chunhua",
    "lat": "34.79889",
    "lng": "108.575"
  },
  {
    "country": "CN",
    "name": "Yangchun",
    "lat": "22.16667",
    "lng": "111.78333"
  },
  {
    "country": "CN",
    "name": "Chumi",
    "lat": "28.23361",
    "lng": "106.83278"
  },
  {
    "country": "CN",
    "name": "Chuimatan",
    "lat": "35.7181",
    "lng": "102.87407"
  },
  {
    "country": "CN",
    "name": "Zhiqing Songduo",
    "lat": "33.43333",
    "lng": "101.43333"
  },
  {
    "country": "CN",
    "name": "Yiwu",
    "lat": "29.31506",
    "lng": "120.07676"
  },
  {
    "country": "CN",
    "name": "Chongru",
    "lat": "26.95111",
    "lng": "119.92528"
  },
  {
    "country": "CN",
    "name": "Chongqing",
    "lat": "29.56278",
    "lng": "106.55278"
  },
  {
    "country": "CN",
    "name": "Chonglong",
    "lat": "29.78062",
    "lng": "104.85224"
  },
  {
    "country": "CN",
    "name": "Chizhou",
    "lat": "30.66134",
    "lng": "117.47783"
  },
  {
    "country": "CN",
    "name": "Chixi",
    "lat": "26.91111",
    "lng": "119.48306"
  },
  {
    "country": "CN",
    "name": "Chikan",
    "lat": "21.27116",
    "lng": "110.35906"
  },
  {
    "country": "CN",
    "name": "Chitu",
    "lat": "39.20333",
    "lng": "117.40278"
  },
  {
    "country": "CN",
    "name": "Chicheng",
    "lat": "30.77936",
    "lng": "105.71214"
  },
  {
    "country": "CN",
    "name": "Chenzhou",
    "lat": "25.8",
    "lng": "113.03333"
  },
  {
    "country": "CN",
    "name": "Chenying",
    "lat": "28.6929",
    "lng": "117.06732"
  },
  {
    "country": "CN",
    "name": "Chenyang",
    "lat": "28.01581",
    "lng": "110.17298"
  },
  {
    "country": "CN",
    "name": "Chengzhong",
    "lat": "22.16824",
    "lng": "107.0073"
  },
  {
    "country": "CN",
    "name": "Chengyang",
    "lat": "36.31167",
    "lng": "120.37583"
  },
  {
    "country": "CN",
    "name": "Chengyang",
    "lat": "35.57944",
    "lng": "118.83278"
  },
  {
    "country": "CN",
    "name": "Chengxian Chengguanzhen",
    "lat": "33.74775",
    "lng": "105.73294"
  },
  {
    "country": "CN",
    "name": "Chengwu",
    "lat": "34.95407",
    "lng": "115.88419"
  },
  {
    "country": "CN",
    "name": "Chengtougu",
    "lat": "39.14",
    "lng": "117.77889"
  },
  {
    "country": "CN",
    "name": "Langchi",
    "lat": "31.07952",
    "lng": "106.56514"
  },
  {
    "country": "CN",
    "name": "Jiangyin",
    "lat": "31.91102",
    "lng": "120.26302"
  },
  {
    "country": "CN",
    "name": "Chengjiang",
    "lat": "26.80171",
    "lng": "114.89978"
  },
  {
    "country": "CN",
    "name": "Chengdu",
    "lat": "30.66667",
    "lng": "104.06667"
  },
  {
    "country": "CN",
    "name": "Chenghua",
    "lat": "23.46132",
    "lng": "116.77007"
  },
  {
    "country": "CN",
    "name": "Chatian",
    "lat": "27.80222",
    "lng": "109.37361"
  },
  {
    "country": "CN",
    "name": "Chaozhou",
    "lat": "23.65396",
    "lng": "116.62262"
  },
  {
    "country": "CN",
    "name": "Chaotian",
    "lat": "32.64462",
    "lng": "105.88501"
  },
  {
    "country": "CN",
    "name": "Chaohu",
    "lat": "31.6",
    "lng": "117.86667"
  },
  {
    "country": "CN",
    "name": "Changzhou",
    "lat": "31.77359",
    "lng": "119.95401"
  },
  {
    "country": "CN",
    "name": "Changzhi",
    "lat": "35.20889",
    "lng": "111.73861"
  },
  {
    "country": "CN",
    "name": "Puxi",
    "lat": "35.19583",
    "lng": "114.685"
  },
  {
    "country": "CN",
    "name": "Changyuan",
    "lat": "29.40499",
    "lng": "105.58827"
  },
  {
    "country": "CN",
    "name": "Kuiju",
    "lat": "36.85361",
    "lng": "119.39083"
  },
  {
    "country": "CN",
    "name": "Changtun",
    "lat": "39.44333",
    "lng": "117.07056"
  },
  {
    "country": "CN",
    "name": "Wu’an",
    "lat": "24.60387",
    "lng": "117.74539"
  },
  {
    "country": "CN",
    "name": "Changsha",
    "lat": "28.68778",
    "lng": "105.98972"
  },
  {
    "country": "CN",
    "name": "Changsha",
    "lat": "28.19874",
    "lng": "112.97087"
  },
  {
    "country": "CN",
    "name": "Changqing",
    "lat": "36.5575",
    "lng": "116.72722"
  },
  {
    "country": "CN",
    "name": "Changqiao",
    "lat": "26.82139",
    "lng": "118.84361"
  },
  {
    "country": "CN",
    "name": "Changpu",
    "lat": "26.57584",
    "lng": "110.10785"
  },
  {
    "country": "CN",
    "name": "Changning",
    "lat": "31.21739",
    "lng": "121.42105"
  },
  {
    "country": "CN",
    "name": "Changning",
    "lat": "28.57773",
    "lng": "104.92087"
  },
  {
    "country": "CN",
    "name": "Yiyang",
    "lat": "26.38893",
    "lng": "112.37925"
  },
  {
    "country": "CN",
    "name": "Changning",
    "lat": "24.95568",
    "lng": "115.64236"
  },
  {
    "country": "CN",
    "name": "Changli",
    "lat": "39.70417",
    "lng": "119.15056"
  },
  {
    "country": "CN",
    "name": "Changleng",
    "lat": "28.7",
    "lng": "115.81667"
  },
  {
    "country": "CN",
    "name": "Changchi",
    "lat": "32.16377",
    "lng": "106.65814"
  },
  {
    "country": "CN",
    "name": "Rong’an",
    "lat": "25.23333",
    "lng": "109.38333"
  },
  {
    "country": "CN",
    "name": "Chaling Chengguanzhen",
    "lat": "26.79097",
    "lng": "113.53975"
  },
  {
    "country": "CN",
    "name": "Chaicun",
    "lat": "37.93278",
    "lng": "112.47639"
  },
  {
    "country": "CN",
    "name": "Chadian",
    "lat": "39.22472",
    "lng": "117.74889"
  },
  {
    "country": "CN",
    "name": "Chadian",
    "lat": "27.58194",
    "lng": "109.13278"
  },
  {
    "country": "CN",
    "name": "Chabaihu",
    "lat": "39.46556",
    "lng": "117.14833"
  },
  {
    "country": "CN",
    "name": "Caohe",
    "lat": "30.2297",
    "lng": "115.43346"
  },
  {
    "country": "CN",
    "name": "Weining",
    "lat": "26.85",
    "lng": "104.23333"
  },
  {
    "country": "CN",
    "name": "Cangzhou",
    "lat": "38.31667",
    "lng": "116.86667"
  },
  {
    "country": "CN",
    "name": "Caiyuan",
    "lat": "30.72361",
    "lng": "122.45139"
  },
  {
    "country": "CN",
    "name": "Caijiapu",
    "lat": "39.17306",
    "lng": "117.81056"
  },
  {
    "country": "CN",
    "name": "Caijia",
    "lat": "28.90889",
    "lng": "106.3404"
  },
  {
    "country": "CN",
    "name": "Caidian",
    "lat": "30.58333",
    "lng": "114.03333"
  },
  {
    "country": "CN",
    "name": "Buhe",
    "lat": "30.28757",
    "lng": "112.22979"
  },
  {
    "country": "CN",
    "name": "Bozhou",
    "lat": "33.87722",
    "lng": "115.77028"
  },
  {
    "country": "CN",
    "name": "Bozhou",
    "lat": "27.37889",
    "lng": "109.27778"
  },
  {
    "country": "CN",
    "name": "Boyang",
    "lat": "26.21167",
    "lng": "109.52056"
  },
  {
    "country": "CN",
    "name": "Botou",
    "lat": "38.06667",
    "lng": "116.5666"
  },
  {
    "country": "CN",
    "name": "Boshan",
    "lat": "36.48333",
    "lng": "117.83333"
  },
  {
    "country": "CN",
    "name": "Baise City",
    "lat": "23.89972",
    "lng": "106.61333"
  },
  {
    "country": "CN",
    "name": "Bobai",
    "lat": "22.27085",
    "lng": "109.97433"
  },
  {
    "country": "CN",
    "name": "Biyong",
    "lat": "27.18722",
    "lng": "109.51"
  },
  {
    "country": "CN",
    "name": "Bishui",
    "lat": "32.71786",
    "lng": "113.31167"
  },
  {
    "country": "CN",
    "name": "Biyang",
    "lat": "29.92885",
    "lng": "117.94638"
  },
  {
    "country": "CN",
    "name": "Bicheng",
    "lat": "29.59491",
    "lng": "106.22476"
  },
  {
    "country": "CN",
    "name": "Binzhou",
    "lat": "37.36667",
    "lng": "118.01667"
  },
  {
    "country": "CN",
    "name": "Bijie",
    "lat": "27.30193",
    "lng": "105.28627"
  },
  {
    "country": "CN",
    "name": "Biaokou",
    "lat": "39.32527",
    "lng": "117.55378"
  },
  {
    "country": "CN",
    "name": "Bianzhuang",
    "lat": "34.84861",
    "lng": "118.04472"
  },
  {
    "country": "CN",
    "name": "Bengbu",
    "lat": "32.94083",
    "lng": "117.36083"
  },
  {
    "country": "CN",
    "name": "Benchu",
    "lat": "26.77111",
    "lng": "109.29056"
  },
  {
    "country": "CN",
    "name": "Bencheng",
    "lat": "39.5",
    "lng": "118.7"
  },
  {
    "country": "CN",
    "name": "Beiwenquan",
    "lat": "29.83366",
    "lng": "106.41935"
  },
  {
    "country": "CN",
    "name": "Beitan",
    "lat": "39.75806",
    "lng": "117.44556"
  },
  {
    "country": "CN",
    "name": "Beilun",
    "lat": "29.91917",
    "lng": "121.83778"
  },
  {
    "country": "CN",
    "name": "Beilizigu",
    "lat": "39.49139",
    "lng": "117.465"
  },
  {
    "country": "CN",
    "name": "Beijing",
    "lat": "39.9075",
    "lng": "116.39723"
  },
  {
    "country": "CN",
    "name": "Beihuaidian",
    "lat": "39.25854",
    "lng": "117.56378"
  },
  {
    "country": "CN",
    "name": "Beihai",
    "lat": "21.48333",
    "lng": "109.1"
  },
  {
    "country": "CN",
    "name": "Beidao",
    "lat": "34.56861",
    "lng": "105.89333"
  },
  {
    "country": "CN",
    "name": "Beidaihehaibin",
    "lat": "39.82222",
    "lng": "119.51806"
  },
  {
    "country": "CN",
    "name": "Beicang",
    "lat": "39.2357",
    "lng": "117.12262"
  },
  {
    "country": "CN",
    "name": "Beicaicun",
    "lat": "39.48722",
    "lng": "117.02556"
  },
  {
    "country": "CN",
    "name": "Beibei",
    "lat": "29.82739",
    "lng": "106.43645"
  },
  {
    "country": "CN",
    "name": "Bazhou",
    "lat": "31.8557",
    "lng": "106.772"
  },
  {
    "country": "CN",
    "name": "Bayan Hot",
    "lat": "38.83861",
    "lng": "105.66861"
  },
  {
    "country": "CN",
    "name": "Basuo",
    "lat": "19.0939",
    "lng": "108.65456"
  },
  {
    "country": "CN",
    "name": "Bashan",
    "lat": "27.76823",
    "lng": "116.05017"
  },
  {
    "country": "CN",
    "name": "Barkam",
    "lat": "31.90059",
    "lng": "102.22092"
  },
  {
    "country": "CN",
    "name": "Baoyou",
    "lat": "18.74932",
    "lng": "109.17172"
  },
  {
    "country": "CN",
    "name": "Baoying",
    "lat": "33.22917",
    "lng": "119.30917"
  },
  {
    "country": "CN",
    "name": "Muping",
    "lat": "30.37045",
    "lng": "102.81223"
  },
  {
    "country": "CN",
    "name": "Baocheng",
    "lat": "18.64028",
    "lng": "109.69944"
  },
  {
    "country": "CN",
    "name": "Baoshan",
    "lat": "31.40845",
    "lng": "121.48956"
  },
  {
    "country": "CN",
    "name": "Langzhong",
    "lat": "31.55037",
    "lng": "105.99381"
  },
  {
    "country": "CN",
    "name": "Baokang Chengguanzhen",
    "lat": "31.87806",
    "lng": "111.25639"
  },
  {
    "country": "CN",
    "name": "Baofeng Chengguanzhen",
    "lat": "33.87028",
    "lng": "113.06528"
  },
  {
    "country": "CN",
    "name": "Baoding",
    "lat": "38.85111",
    "lng": "115.49028"
  },
  {
    "country": "CN",
    "name": "Bao’an",
    "lat": "36.82899",
    "lng": "108.75814"
  },
  {
    "country": "CN",
    "name": "Bangjun",
    "lat": "39.99111",
    "lng": "117.26278"
  },
  {
    "country": "CN",
    "name": "Bangdong",
    "lat": "26.97556",
    "lng": "109.18583"
  },
  {
    "country": "CN",
    "name": "Bamencheng",
    "lat": "39.57778",
    "lng": "117.60528"
  },
  {
    "country": "CN",
    "name": "Bama",
    "lat": "24.17054",
    "lng": "107.24892"
  },
  {
    "country": "CN",
    "name": "Baiyun",
    "lat": "26.03648",
    "lng": "118.90622"
  },
  {
    "country": "CN",
    "name": "Baiyin",
    "lat": "36.54696",
    "lng": "104.17023"
  },
  {
    "country": "CN",
    "name": "Baiyashi",
    "lat": "26.38883",
    "lng": "111.26213"
  },
  {
    "country": "CN",
    "name": "Baixi",
    "lat": "28.6997",
    "lng": "104.54917"
  },
  {
    "country": "CN",
    "name": "Baishi",
    "lat": "26.97361",
    "lng": "109.44333"
  },
  {
    "country": "CN",
    "name": "Baishan",
    "lat": "23.71353",
    "lng": "108.17093"
  },
  {
    "country": "CN",
    "name": "Baisha",
    "lat": "26.52222",
    "lng": "110.93111"
  },
  {
    "country": "CN",
    "name": "Baijian",
    "lat": "39.99417",
    "lng": "117.20861"
  },
  {
    "country": "CN",
    "name": "Baihe",
    "lat": "22.1343",
    "lng": "107.232"
  },
  {
    "country": "CN",
    "name": "Shangyu",
    "lat": "30.01556",
    "lng": "120.87111"
  },
  {
    "country": "CN",
    "name": "Bahuang",
    "lat": "27.71806",
    "lng": "109.01889"
  },
  {
    "country": "CN",
    "name": "Badu",
    "lat": "26.81028",
    "lng": "119.56417"
  },
  {
    "country": "CN",
    "name": "Badaogu",
    "lat": "39.47333",
    "lng": "117.32972"
  },
  {
    "country": "CN",
    "name": "Bada",
    "lat": "24.59297",
    "lng": "105.09324"
  },
  {
    "country": "CN",
    "name": "Bachuan",
    "lat": "29.84863",
    "lng": "106.05046"
  },
  {
    "country": "CN",
    "name": "Babu",
    "lat": "24.41667",
    "lng": "111.51667"
  },
  {
    "country": "CN",
    "name": "Qilian",
    "lat": "38.18056",
    "lng": "100.24028"
  },
  {
    "country": "CN",
    "name": "Aoyang",
    "lat": "28.23896",
    "lng": "114.92081"
  },
  {
    "country": "CN",
    "name": "Aoyang",
    "lat": "27.45889",
    "lng": "119.50139"
  },
  {
    "country": "CN",
    "name": "Aoxi",
    "lat": "27.42589",
    "lng": "115.83643"
  },
  {
    "country": "CN",
    "name": "Aoshi",
    "lat": "26.40167",
    "lng": "109.07111"
  },
  {
    "country": "CN",
    "name": "Fucheng",
    "lat": "36.14684",
    "lng": "112.23351"
  },
  {
    "country": "CN",
    "name": "Anyang",
    "lat": "23.93796",
    "lng": "108.09765"
  },
  {
    "country": "CN",
    "name": "Anxiang",
    "lat": "29.4",
    "lng": "112.15"
  },
  {
    "country": "CN",
    "name": "Anshun",
    "lat": "26.25",
    "lng": "105.93333"
  },
  {
    "country": "CN",
    "name": "Anren Chengguanzhen",
    "lat": "26.71413",
    "lng": "113.26726"
  },
  {
    "country": "CN",
    "name": "Anqiu",
    "lat": "36.43417",
    "lng": "119.1925"
  },
  {
    "country": "CN",
    "name": "Anqing",
    "lat": "30.51365",
    "lng": "117.04723"
  },
  {
    "country": "CN",
    "name": "Mabai",
    "lat": "23.01279",
    "lng": "104.45081"
  },
  {
    "country": "CN",
    "name": "Anlu",
    "lat": "31.2575",
    "lng": "113.67833"
  },
  {
    "country": "CN",
    "name": "Anju",
    "lat": "30.34956",
    "lng": "105.45594"
  },
  {
    "country": "CN",
    "name": "Anjiang",
    "lat": "27.31944",
    "lng": "110.10306"
  },
  {
    "country": "CN",
    "name": "Naxi",
    "lat": "28.77422",
    "lng": "105.36488"
  },
  {
    "country": "CN",
    "name": "Andongwei",
    "lat": "35.1294",
    "lng": "119.276"
  },
  {
    "country": "CN",
    "name": "Anbu",
    "lat": "23.44895",
    "lng": "116.68092"
  },
  {
    "country": "CN",
    "name": "Aba",
    "lat": "32.90594",
    "lng": "101.70625"
  },
  {
    "country": "CN",
    "name": "Langxia",
    "lat": "30.16778",
    "lng": "121.075"
  },
  {
    "country": "CN",
    "name": "Jiangyou",
    "lat": "31.76667",
    "lng": "104.71667"
  },
  {
    "country": "CN",
    "name": "Suzhou",
    "lat": "31.30408",
    "lng": "120.59538"
  },
  {
    "country": "CN",
    "name": "Zhoushan",
    "lat": "29.98869",
    "lng": "122.20488"
  },
  {
    "country": "CN",
    "name": "Huaihelu",
    "lat": "34.71638",
    "lng": "113.64138"
  },
  {
    "country": "CN",
    "name": "Zhongzhan",
    "lat": "35.24139",
    "lng": "113.16028"
  },
  {
    "country": "CN",
    "name": "Mudu",
    "lat": "31.25597",
    "lng": "120.51857"
  },
  {
    "country": "CN",
    "name": "Songling",
    "lat": "31.1933",
    "lng": "120.71758"
  },
  {
    "country": "CN",
    "name": "Fulilu",
    "lat": "36.10168",
    "lng": "103.61573"
  },
  {
    "country": "CN",
    "name": "Xiliguantun",
    "lat": "37.07833",
    "lng": "115.94139"
  },
  {
    "country": "CN",
    "name": "Runsong",
    "lat": "26.87",
    "lng": "109.097"
  },
  {
    "country": "CN",
    "name": "Dundong",
    "lat": "26.0119",
    "lng": "109.141"
  },
  {
    "country": "CN",
    "name": "Gaowu",
    "lat": "25.5625",
    "lng": "108.908"
  },
  {
    "country": "CN",
    "name": "Pingjiang",
    "lat": "25.8114",
    "lng": "108.662"
  },
  {
    "country": "CN",
    "name": "Longzhouwan",
    "lat": "29.37861",
    "lng": "106.54"
  },
  {
    "country": "CN",
    "name": "Nanping",
    "lat": "29.54111",
    "lng": "106.58778"
  },
  {
    "country": "CN",
    "name": "Dianjun",
    "lat": "30.70154",
    "lng": "111.25991"
  },
  {
    "country": "CN",
    "name": "Zhongyuanlu",
    "lat": "35.76847",
    "lng": "115.06133"
  },
  {
    "country": "CN",
    "name": "Yangying",
    "lat": "35.81805",
    "lng": "115.94807"
  },
  {
    "country": "CN",
    "name": "Chang’an",
    "lat": "22.80648",
    "lng": "113.80278"
  },
  {
    "country": "CN",
    "name": "Nanhai",
    "lat": "21.47251",
    "lng": "111.02684"
  },
  {
    "country": "CN",
    "name": "Zhize",
    "lat": "21.7554",
    "lng": "111.61433"
  },
  {
    "country": "CN",
    "name": "Dongcheng",
    "lat": "21.882",
    "lng": "112.01022"
  },
  {
    "country": "CN",
    "name": "Xiasi",
    "lat": "32.28998",
    "lng": "105.51326"
  },
  {
    "country": "CN",
    "name": "Zhongshan",
    "lat": "21.31992",
    "lng": "110.5723"
  },
  {
    "country": "CN",
    "name": "Chongshan",
    "lat": "18.78229",
    "lng": "109.5013"
  },
  {
    "country": "CN",
    "name": "Duohu",
    "lat": "29.0937",
    "lng": "119.68511"
  },
  {
    "country": "CN",
    "name": "Luogang",
    "lat": "23.17789",
    "lng": "113.50104"
  },
  {
    "country": "CN",
    "name": "Dadonghai",
    "lat": "18.22056",
    "lng": "109.51028"
  },
  {
    "country": "CN",
    "name": "Lianghu",
    "lat": "29.99152",
    "lng": "120.89845"
  },
  {
    "country": "CN",
    "name": "Lingcheng",
    "lat": "35.534",
    "lng": "116.918"
  },
  {
    "country": "CN",
    "name": "Zhoucheng",
    "lat": "35.91222",
    "lng": "116.31167"
  },
  {
    "country": "CN",
    "name": "Xunzhong",
    "lat": "25.49431",
    "lng": "118.23885"
  },
  {
    "country": "CN",
    "name": "Keren",
    "lat": "24.58057",
    "lng": "118.66209"
  },
  {
    "country": "CN",
    "name": "Wubu",
    "lat": "24.59589",
    "lng": "118.55359"
  },
  {
    "country": "CN",
    "name": "Tatou",
    "lat": "24.61378",
    "lng": "118.52585"
  },
  {
    "country": "CN",
    "name": "Yinglin",
    "lat": "24.63222",
    "lng": "118.58056"
  },
  {
    "country": "CN",
    "name": "Maping",
    "lat": "24.68722",
    "lng": "118.55278"
  },
  {
    "country": "CN",
    "name": "Neikeng",
    "lat": "24.78544",
    "lng": "118.46037"
  },
  {
    "country": "CN",
    "name": "Baiqi",
    "lat": "24.88244",
    "lng": "118.70869"
  },
  {
    "country": "CN",
    "name": "Shanxia",
    "lat": "24.93802",
    "lng": "118.8817"
  },
  {
    "country": "CN",
    "name": "Xiangyun",
    "lat": "24.97111",
    "lng": "118.16028"
  },
  {
    "country": "CN",
    "name": "Jingfeng",
    "lat": "24.97441",
    "lng": "118.96486"
  },
  {
    "country": "CN",
    "name": "Dalianwan",
    "lat": "39.02861",
    "lng": "121.695"
  },
  {
    "country": "CN",
    "name": "Wuyishan",
    "lat": "27.75995",
    "lng": "118.03066"
  },
  {
    "country": "CN",
    "name": "Xiaping",
    "lat": "26.73139",
    "lng": "114.27028"
  },
  {
    "country": "CN",
    "name": "Xingsha",
    "lat": "28.23972",
    "lng": "113.08778"
  },
  {
    "country": "CN",
    "name": "Heshan",
    "lat": "28.5825",
    "lng": "112.35028"
  },
  {
    "country": "CN",
    "name": "Liulinzhou",
    "lat": "29.45639",
    "lng": "113.01028"
  },
  {
    "country": "CN",
    "name": "Yueyang",
    "lat": "29.37455",
    "lng": "113.09481"
  },
  {
    "country": "CN",
    "name": "Baisha",
    "lat": "28.21971",
    "lng": "110.21695"
  },
  {
    "country": "CN",
    "name": "Bojia",
    "lat": "26.46722",
    "lng": "111.96806"
  },
  {
    "country": "CN",
    "name": "Dengying",
    "lat": "36.13889",
    "lng": "120.57417"
  },
  {
    "country": "CN",
    "name": "Kutao",
    "lat": "36.145",
    "lng": "120.48778"
  },
  {
    "country": "CN",
    "name": "Beizhai",
    "lat": "36.21972",
    "lng": "120.52889"
  },
  {
    "country": "CN",
    "name": "Qingshancun",
    "lat": "36.15415",
    "lng": "120.6824"
  },
  {
    "country": "CN",
    "name": "Xinzhuang",
    "lat": "39.0249",
    "lng": "117.34377"
  },
  {
    "country": "CN",
    "name": "Weiwangzhuang",
    "lat": "39.025",
    "lng": "117.44083"
  },
  {
    "country": "CN",
    "name": "Goutou",
    "lat": "39.805",
    "lng": "117.19917"
  },
  {
    "country": "CN",
    "name": "Meipu",
    "lat": "26.2112",
    "lng": "118.89561"
  },
  {
    "country": "CN",
    "name": "Rong’an",
    "lat": "26.12472",
    "lng": "119.12139"
  },
  {
    "country": "CN",
    "name": "Shangjie",
    "lat": "26.08679",
    "lng": "119.18494"
  },
  {
    "country": "CN",
    "name": "Kuai’an",
    "lat": "26.03417",
    "lng": "119.41639"
  },
  {
    "country": "CN",
    "name": "Chengmen",
    "lat": "25.99339",
    "lng": "119.36136"
  },
  {
    "country": "CN",
    "name": "Hongtang",
    "lat": "26.07056",
    "lng": "119.23083"
  },
  {
    "country": "CN",
    "name": "Huai’an",
    "lat": "26.09899",
    "lng": "119.22171"
  },
  {
    "country": "CN",
    "name": "Donghu",
    "lat": "26.23453",
    "lng": "119.5143"
  },
  {
    "country": "CN",
    "name": "Houyu",
    "lat": "26.05958",
    "lng": "119.53502"
  },
  {
    "country": "CN",
    "name": "Jitou",
    "lat": "26.47681",
    "lng": "119.60517"
  },
  {
    "country": "CN",
    "name": "Beishan",
    "lat": "26.43755",
    "lng": "119.63278"
  },
  {
    "country": "CN",
    "name": "Huangtian",
    "lat": "26.43851",
    "lng": "118.62398"
  },
  {
    "country": "CN",
    "name": "Dingtou",
    "lat": "26.83977",
    "lng": "119.66111"
  },
  {
    "country": "CN",
    "name": "Ouyang",
    "lat": "26.4191",
    "lng": "109.216"
  },
  {
    "country": "CN",
    "name": "Dengyuantai",
    "lat": "26.68806",
    "lng": "110.54222"
  },
  {
    "country": "CN",
    "name": "Dazhai",
    "lat": "25.8098",
    "lng": "110.15"
  },
  {
    "country": "CN",
    "name": "Yanta",
    "lat": "34.20636",
    "lng": "108.9524"
  },
  {
    "country": "CN",
    "name": "Yunxing",
    "lat": "39.9991",
    "lng": "112.69787"
  },
  {
    "country": "CN",
    "name": "Zunhua",
    "lat": "40.17917",
    "lng": "117.95861"
  },
  {
    "country": "CN",
    "name": "Zhuozishan",
    "lat": "40.89917",
    "lng": "112.56028"
  },
  {
    "country": "CN",
    "name": "Zhuolu",
    "lat": "40.36944",
    "lng": "115.21611"
  },
  {
    "country": "CN",
    "name": "Zhenlai",
    "lat": "45.84955",
    "lng": "123.2973"
  },
  {
    "country": "CN",
    "name": "Zhengjiatun",
    "lat": "43.50639",
    "lng": "123.50639"
  },
  {
    "country": "CN",
    "name": "Zhaozhou",
    "lat": "45.68333",
    "lng": "125.31667"
  },
  {
    "country": "CN",
    "name": "Zhaoyuan",
    "lat": "45.5",
    "lng": "125.13333"
  },
  {
    "country": "CN",
    "name": "Zhaodong",
    "lat": "46.06771",
    "lng": "125.98263"
  },
  {
    "country": "CN",
    "name": "Zhangjiakou",
    "lat": "40.81",
    "lng": "114.87944"
  },
  {
    "country": "CN",
    "name": "Zhangbei",
    "lat": "41.1525",
    "lng": "114.70778"
  },
  {
    "country": "CN",
    "name": "Zhalantun",
    "lat": "48.00945",
    "lng": "122.73651"
  },
  {
    "country": "CN",
    "name": "Yushu",
    "lat": "44.8",
    "lng": "126.53333"
  },
  {
    "country": "CN",
    "name": "Yuelai",
    "lat": "47.02325",
    "lng": "130.71296"
  },
  {
    "country": "CN",
    "name": "Youhao",
    "lat": "47.85306",
    "lng": "128.83565"
  },
  {
    "country": "CN",
    "name": "Yitong",
    "lat": "43.32628",
    "lng": "125.29726"
  },
  {
    "country": "CN",
    "name": "Yingshouyingzi",
    "lat": "40.55147",
    "lng": "117.66155"
  },
  {
    "country": "CN",
    "name": "Yingkou",
    "lat": "40.66482",
    "lng": "122.22833"
  },
  {
    "country": "CN",
    "name": "Yilan",
    "lat": "46.31618",
    "lng": "129.55455"
  },
  {
    "country": "CN",
    "name": "Yichun",
    "lat": "47.72143",
    "lng": "128.87529"
  },
  {
    "country": "CN",
    "name": "Yi’an",
    "lat": "47.889",
    "lng": "125.30392"
  },
  {
    "country": "CN",
    "name": "Yebaishou",
    "lat": "41.3975",
    "lng": "119.64083"
  },
  {
    "country": "CN",
    "name": "Yantongshan",
    "lat": "43.29194",
    "lng": "126.00944"
  },
  {
    "country": "CN",
    "name": "Yanshou",
    "lat": "45.45324",
    "lng": "128.32678"
  },
  {
    "country": "CN",
    "name": "Yanqing",
    "lat": "40.46093",
    "lng": "115.9715"
  },
  {
    "country": "CN",
    "name": "Yanji",
    "lat": "42.9075",
    "lng": "129.50778"
  },
  {
    "country": "CN",
    "name": "Longquan",
    "lat": "40.3638",
    "lng": "113.66616"
  },
  {
    "country": "CN",
    "name": "Yakeshi",
    "lat": "49.28333",
    "lng": "120.73333"
  },
  {
    "country": "CN",
    "name": "Zhangjiakou Shi Xuanhua Qu",
    "lat": "40.61028",
    "lng": "115.04472"
  },
  {
    "country": "CN",
    "name": "Xiwanzi",
    "lat": "40.97139",
    "lng": "115.2725"
  },
  {
    "country": "CN",
    "name": "Xiuyan",
    "lat": "40.29278",
    "lng": "123.27444"
  },
  {
    "country": "CN",
    "name": "Xiping",
    "lat": "40.03952",
    "lng": "113.60455"
  },
  {
    "country": "CN",
    "name": "Xinrong",
    "lat": "40.2579",
    "lng": "113.136"
  },
  {
    "country": "CN",
    "name": "Xinqing",
    "lat": "48.28701",
    "lng": "129.52337"
  },
  {
    "country": "CN",
    "name": "Xinmin",
    "lat": "41.99083",
    "lng": "122.82528"
  },
  {
    "country": "CN",
    "name": "Xinlin",
    "lat": "51.7",
    "lng": "124.33333"
  },
  {
    "country": "CN",
    "name": "Xinhui",
    "lat": "42.28389",
    "lng": "119.89833"
  },
  {
    "country": "CN",
    "name": "Xinglongshan",
    "lat": "43.95611",
    "lng": "125.46611"
  },
  {
    "country": "CN",
    "name": "Xinglong",
    "lat": "40.42028",
    "lng": "117.5075"
  },
  {
    "country": "CN",
    "name": "Xinghe Chengguanzhen",
    "lat": "40.87556",
    "lng": "113.88389"
  },
  {
    "country": "CN",
    "name": "Xingcheng",
    "lat": "40.61667",
    "lng": "120.71667"
  },
  {
    "country": "CN",
    "name": "Xin Bulag",
    "lat": "42.2375",
    "lng": "113.83639"
  },
  {
    "country": "CN",
    "name": "Xilin Hot",
    "lat": "43.96667",
    "lng": "116.03333"
  },
  {
    "country": "CN",
    "name": "Xilin",
    "lat": "47.47606",
    "lng": "129.30369"
  },
  {
    "country": "CN",
    "name": "Xifeng",
    "lat": "42.73722",
    "lng": "124.72222"
  },
  {
    "country": "CN",
    "name": "Xicheng",
    "lat": "40.11056",
    "lng": "114.15889"
  },
  {
    "country": "CN",
    "name": "Xiaoshi",
    "lat": "41.29711",
    "lng": "124.12092"
  },
  {
    "country": "CN",
    "name": "Chengzhen",
    "lat": "40.47972",
    "lng": "115.26778"
  },
  {
    "country": "CN",
    "name": "Xamba",
    "lat": "40.88472",
    "lng": "107.14"
  },
  {
    "country": "CN",
    "name": "Wumahe",
    "lat": "47.72348",
    "lng": "128.79277"
  },
  {
    "country": "CN",
    "name": "Wudan",
    "lat": "42.93444",
    "lng": "119.02389"
  },
  {
    "country": "CN",
    "name": "Wuchang",
    "lat": "44.91428",
    "lng": "127.15001"
  },
  {
    "country": "CN",
    "name": "Weichang",
    "lat": "41.94472",
    "lng": "117.74806"
  },
  {
    "country": "CN",
    "name": "Wangqing",
    "lat": "43.32179",
    "lng": "129.76342"
  },
  {
    "country": "CN",
    "name": "Hepingjie",
    "lat": "42.05972",
    "lng": "126.91583"
  },
  {
    "country": "CN",
    "name": "Wangkui",
    "lat": "46.83283",
    "lng": "126.47768"
  },
  {
    "country": "CN",
    "name": "Uliastai",
    "lat": "45.55",
    "lng": "116.83333"
  },
  {
    "country": "CN",
    "name": "Ulan Hua",
    "lat": "41.51306",
    "lng": "111.69639"
  },
  {
    "country": "CN",
    "name": "Ulanhot",
    "lat": "46.08333",
    "lng": "122.08333"
  },
  {
    "country": "CN",
    "name": "Tuquan",
    "lat": "45.40304",
    "lng": "121.60462"
  },
  {
    "country": "CN",
    "name": "Tumen",
    "lat": "42.96611",
    "lng": "129.8425"
  },
  {
    "country": "CN",
    "name": "Tongliao",
    "lat": "43.6125",
    "lng": "122.26528"
  },
  {
    "country": "CN",
    "name": "Tonghua",
    "lat": "41.71972",
    "lng": "125.92639"
  },
  {
    "country": "CN",
    "name": "Tonghe",
    "lat": "45.9761",
    "lng": "128.74289"
  },
  {
    "country": "CN",
    "name": "Togrog Ul",
    "lat": "40.7867",
    "lng": "113.205"
  },
  {
    "country": "CN",
    "name": "Tieling",
    "lat": "42.29306",
    "lng": "123.84139"
  },
  {
    "country": "CN",
    "name": "Tieli",
    "lat": "46.98043",
    "lng": "128.04497"
  },
  {
    "country": "CN",
    "name": "Yuquan",
    "lat": "40.44259",
    "lng": "113.97442"
  },
  {
    "country": "CN",
    "name": "Tianyi",
    "lat": "41.56667",
    "lng": "119.33333"
  },
  {
    "country": "CN",
    "name": "Tianshan",
    "lat": "43.88737",
    "lng": "120.09336"
  },
  {
    "country": "CN",
    "name": "Guangming",
    "lat": "45.33333",
    "lng": "122.78333"
  },
  {
    "country": "CN",
    "name": "Tangyuan",
    "lat": "46.72642",
    "lng": "129.89966"
  },
  {
    "country": "CN",
    "name": "Tailai",
    "lat": "46.38909",
    "lng": "123.41371"
  },
  {
    "country": "CN",
    "name": "Taikang",
    "lat": "46.86135",
    "lng": "124.442"
  },
  {
    "country": "CN",
    "name": "Tahe",
    "lat": "52.33333",
    "lng": "124.73333"
  },
  {
    "country": "CN",
    "name": "Sunwu",
    "lat": "49.41749",
    "lng": "127.3155"
  },
  {
    "country": "CN",
    "name": "Sunjia Buzi",
    "lat": "42.01707",
    "lng": "126.58513"
  },
  {
    "country": "CN",
    "name": "Sujiatun",
    "lat": "41.65917",
    "lng": "123.33917"
  },
  {
    "country": "CN",
    "name": "Suizhong",
    "lat": "40.32916",
    "lng": "120.33653"
  },
  {
    "country": "CN",
    "name": "Suileng",
    "lat": "47.24805",
    "lng": "127.09535"
  },
  {
    "country": "CN",
    "name": "Suihua",
    "lat": "46.63954",
    "lng": "126.99508"
  },
  {
    "country": "CN",
    "name": "Suifenhe",
    "lat": "44.39982",
    "lng": "131.14775"
  },
  {
    "country": "CN",
    "name": "Songjianghe",
    "lat": "42.1859",
    "lng": "127.47895"
  },
  {
    "country": "CN",
    "name": "Siping",
    "lat": "43.16143",
    "lng": "124.37785"
  },
  {
    "country": "CN",
    "name": "Shunyi",
    "lat": "40.12175",
    "lng": "116.64783"
  },
  {
    "country": "CN",
    "name": "Shulinzhao",
    "lat": "40.39278",
    "lng": "110.02694"
  },
  {
    "country": "CN",
    "name": "Shulan",
    "lat": "44.41667",
    "lng": "126.95"
  },
  {
    "country": "CN",
    "name": "Shuangyashan",
    "lat": "46.63611",
    "lng": "131.15389"
  },
  {
    "country": "CN",
    "name": "Shuangyang",
    "lat": "43.52417",
    "lng": "125.67361"
  },
  {
    "country": "CN",
    "name": "Shuangtashan",
    "lat": "40.94778",
    "lng": "117.79472"
  },
  {
    "country": "CN",
    "name": "Shuangcheng",
    "lat": "45.35",
    "lng": "126.28333"
  },
  {
    "country": "CN",
    "name": "Shiguai",
    "lat": "40.70583",
    "lng": "110.28556"
  },
  {
    "country": "CN",
    "name": "Shenyang",
    "lat": "41.79222",
    "lng": "123.43278"
  },
  {
    "country": "CN",
    "name": "Shanhecun",
    "lat": "45.71131",
    "lng": "128.58029"
  },
  {
    "country": "CN",
    "name": "Shanhaiguan",
    "lat": "40.0025",
    "lng": "119.74889"
  },
  {
    "country": "CN",
    "name": "Shangzhi",
    "lat": "45.21406",
    "lng": "127.97426"
  },
  {
    "country": "CN",
    "name": "Qitai",
    "lat": "41.54944",
    "lng": "113.53389"
  },
  {
    "country": "CN",
    "name": "Shacheng",
    "lat": "40.39139",
    "lng": "115.51139"
  },
  {
    "country": "CN",
    "name": "Sanchazi",
    "lat": "42.08167",
    "lng": "126.60028"
  },
  {
    "country": "CN",
    "name": "Sanchahe",
    "lat": "44.96306",
    "lng": "126.01532"
  },
  {
    "country": "CN",
    "name": "Salaqi",
    "lat": "40.54139",
    "lng": "110.51083"
  },
  {
    "country": "CN",
    "name": "Saihan Tal",
    "lat": "42.73583",
    "lng": "112.65139"
  },
  {
    "country": "CN",
    "name": "Fendou",
    "lat": "46.64142",
    "lng": "124.86283"
  },
  {
    "country": "CN",
    "name": "Taihecun",
    "lat": "45.76347",
    "lng": "130.85048"
  },
  {
    "country": "CN",
    "name": "Qiqihar",
    "lat": "47.34088",
    "lng": "123.96045"
  },
  {
    "country": "CN",
    "name": "Qinglong",
    "lat": "40.40556",
    "lng": "118.94389"
  },
  {
    "country": "CN",
    "name": "Qinggang",
    "lat": "46.68469",
    "lng": "126.10595"
  },
  {
    "country": "CN",
    "name": "Qing’an",
    "lat": "46.87759",
    "lng": "127.50054"
  },
  {
    "country": "CN",
    "name": "Songyuan",
    "lat": "45.12902",
    "lng": "124.82769"
  },
  {
    "country": "CN",
    "name": "Qian’an",
    "lat": "44.99324",
    "lng": "124.05811"
  },
  {
    "country": "CN",
    "name": "Qasq",
    "lat": "40.71222",
    "lng": "111.12889"
  },
  {
    "country": "CN",
    "name": "Ming’antu",
    "lat": "42.30278",
    "lng": "114.99333"
  },
  {
    "country": "CN",
    "name": "Pingzhuang",
    "lat": "42.03722",
    "lng": "119.28889"
  },
  {
    "country": "CN",
    "name": "Pingquan",
    "lat": "41.0025",
    "lng": "118.68417"
  },
  {
    "country": "CN",
    "name": "Pingdingbu",
    "lat": "41.66528",
    "lng": "115.69778"
  },
  {
    "country": "CN",
    "name": "Panshi",
    "lat": "42.94222",
    "lng": "126.05611"
  },
  {
    "country": "CN",
    "name": "Panshan",
    "lat": "41.18806",
    "lng": "122.04944"
  },
  {
    "country": "CN",
    "name": "Nong’an",
    "lat": "44.38198",
    "lng": "125.16847"
  },
  {
    "country": "CN",
    "name": "Nirji",
    "lat": "48.48333",
    "lng": "124.48333"
  },
  {
    "country": "CN",
    "name": "Ning’an",
    "lat": "44.34395",
    "lng": "129.46556"
  },
  {
    "country": "CN",
    "name": "Nianzishan",
    "lat": "47.51667",
    "lng": "122.88333"
  },
  {
    "country": "CN",
    "name": "Nenjiang",
    "lat": "49.17414",
    "lng": "125.21774"
  },
  {
    "country": "CN",
    "name": "Nehe",
    "lat": "48.48333",
    "lng": "124.83333"
  },
  {
    "country": "CN",
    "name": "Nantai",
    "lat": "40.9241",
    "lng": "122.80437"
  },
  {
    "country": "CN",
    "name": "Nanpiao",
    "lat": "41.09822",
    "lng": "120.74792"
  },
  {
    "country": "CN",
    "name": "Nanhaoqian",
    "lat": "41.06806",
    "lng": "113.96028"
  },
  {
    "country": "CN",
    "name": "Lianhe",
    "lat": "47.13333",
    "lng": "129.27426"
  },
  {
    "country": "CN",
    "name": "Naji",
    "lat": "48.12217",
    "lng": "123.45904"
  },
  {
    "country": "CN",
    "name": "Mulan",
    "lat": "45.94715",
    "lng": "128.03706"
  },
  {
    "country": "CN",
    "name": "Mujiayingzi",
    "lat": "42.11667",
    "lng": "118.78333"
  },
  {
    "country": "CN",
    "name": "Mudanjiang",
    "lat": "44.58333",
    "lng": "129.6"
  },
  {
    "country": "CN",
    "name": "Mishan",
    "lat": "45.55",
    "lng": "131.88333"
  },
  {
    "country": "CN",
    "name": "Mingyue",
    "lat": "43.10694",
    "lng": "128.92167"
  },
  {
    "country": "CN",
    "name": "Mingshui",
    "lat": "47.1815",
    "lng": "125.90027"
  },
  {
    "country": "CN",
    "name": "Meixi",
    "lat": "47.6317",
    "lng": "129.13064"
  },
  {
    "country": "CN",
    "name": "Meilisi",
    "lat": "47.31499",
    "lng": "123.75442"
  },
  {
    "country": "CN",
    "name": "Meihekou",
    "lat": "42.52722",
    "lng": "125.67528"
  },
  {
    "country": "CN",
    "name": "Mashan",
    "lat": "45.20508",
    "lng": "130.52614"
  },
  {
    "country": "CN",
    "name": "Manzhouli",
    "lat": "49.6",
    "lng": "117.43333"
  },
  {
    "country": "CN",
    "name": "Mandalt",
    "lat": "43.84028",
    "lng": "113.71556"
  },
  {
    "country": "CN",
    "name": "Lubei",
    "lat": "44.60866",
    "lng": "120.9556"
  },
  {
    "country": "CN",
    "name": "Luanping",
    "lat": "40.91667",
    "lng": "117.28333"
  },
  {
    "country": "CN",
    "name": "Longjing",
    "lat": "42.77139",
    "lng": "129.42333"
  },
  {
    "country": "CN",
    "name": "Longjiang",
    "lat": "47.33072",
    "lng": "123.17816"
  },
  {
    "country": "CN",
    "name": "Longhua",
    "lat": "41.31167",
    "lng": "117.725"
  },
  {
    "country": "CN",
    "name": "Longfeng",
    "lat": "46.53168",
    "lng": "125.1038"
  },
  {
    "country": "CN",
    "name": "Liuhe",
    "lat": "42.24007",
    "lng": "125.71717"
  },
  {
    "country": "CN",
    "name": "Lishu",
    "lat": "45.08978",
    "lng": "130.69136"
  },
  {
    "country": "CN",
    "name": "Lishu",
    "lat": "43.30472",
    "lng": "124.32778"
  },
  {
    "country": "CN",
    "name": "Linxi",
    "lat": "43.51667",
    "lng": "118.03333"
  },
  {
    "country": "CN",
    "name": "Linkou",
    "lat": "45.28606",
    "lng": "130.26151"
  },
  {
    "country": "CN",
    "name": "Linjiang",
    "lat": "41.80694",
    "lng": "126.90778"
  },
  {
    "country": "CN",
    "name": "Lingyuan",
    "lat": "41.24",
    "lng": "119.40111"
  },
  {
    "country": "CN",
    "name": "Lingdong",
    "lat": "46.56694",
    "lng": "131.14528"
  },
  {
    "country": "CN",
    "name": "Lindong",
    "lat": "43.98333",
    "lng": "119.18333"
  },
  {
    "country": "CN",
    "name": "Lindian",
    "lat": "47.18258",
    "lng": "124.86773"
  },
  {
    "country": "CN",
    "name": "Liaozhong",
    "lat": "41.50611",
    "lng": "122.72417"
  },
  {
    "country": "CN",
    "name": "Liaoyuan",
    "lat": "42.90361",
    "lng": "125.13583"
  },
  {
    "country": "CN",
    "name": "Liaoyang",
    "lat": "41.27194",
    "lng": "123.17306"
  },
  {
    "country": "CN",
    "name": "Daihai",
    "lat": "40.52111",
    "lng": "112.49306"
  },
  {
    "country": "CN",
    "name": "Biancheng",
    "lat": "40.67852",
    "lng": "122.36233"
  },
  {
    "country": "CN",
    "name": "Lanxi",
    "lat": "46.25785",
    "lng": "126.28269"
  },
  {
    "country": "CN",
    "name": "Langxiang",
    "lat": "46.94985",
    "lng": "128.86849"
  },
  {
    "country": "CN",
    "name": "Langtoucun",
    "lat": "40.04068",
    "lng": "124.33525"
  },
  {
    "country": "CN",
    "name": "E’erguna",
    "lat": "50.22362",
    "lng": "120.17092"
  },
  {
    "country": "CN",
    "name": "Kuandian",
    "lat": "40.72861",
    "lng": "124.78472"
  },
  {
    "country": "CN",
    "name": "Kuancheng",
    "lat": "40.60556",
    "lng": "118.4825"
  },
  {
    "country": "CN",
    "name": "Kuaidamao",
    "lat": "41.65532",
    "lng": "125.74225"
  },
  {
    "country": "CN",
    "name": "Kouquan",
    "lat": "39.9982",
    "lng": "113.145"
  },
  {
    "country": "CN",
    "name": "Kouqian",
    "lat": "43.63914",
    "lng": "126.45784"
  },
  {
    "country": "CN",
    "name": "Kongjiazhuang",
    "lat": "40.7525",
    "lng": "114.72611"
  },
  {
    "country": "CN",
    "name": "Kangping",
    "lat": "42.73917",
    "lng": "123.34944"
  },
  {
    "country": "CN",
    "name": "Kangbao",
    "lat": "41.84639",
    "lng": "114.61389"
  },
  {
    "country": "CN",
    "name": "Kaiyuan",
    "lat": "42.53306",
    "lng": "124.04028"
  },
  {
    "country": "CN",
    "name": "Kaitong",
    "lat": "44.81351",
    "lng": "123.15"
  },
  {
    "country": "CN",
    "name": "Kailu",
    "lat": "43.58333",
    "lng": "121.2"
  },
  {
    "country": "CN",
    "name": "Jixi",
    "lat": "45.30109",
    "lng": "130.95718"
  },
  {
    "country": "CN",
    "name": "Jiutai",
    "lat": "44.1525",
    "lng": "125.83278"
  },
  {
    "country": "CN",
    "name": "Jiupu",
    "lat": "41.06667",
    "lng": "122.95"
  },
  {
    "country": "CN",
    "name": "Jishu",
    "lat": "44.31667",
    "lng": "126.8"
  },
  {
    "country": "CN",
    "name": "Jinzhou",
    "lat": "41.10778",
    "lng": "121.14167"
  },
  {
    "country": "CN",
    "name": "Lianshan",
    "lat": "40.76432",
    "lng": "120.85327"
  },
  {
    "country": "CN",
    "name": "Fendou",
    "lat": "47.40955",
    "lng": "129.42822"
  },
  {
    "country": "CN",
    "name": "Jinshan",
    "lat": "41.91667",
    "lng": "118.66667"
  },
  {
    "country": "CN",
    "name": "Jining",
    "lat": "41.0275",
    "lng": "113.10583"
  },
  {
    "country": "CN",
    "name": "Jingyu",
    "lat": "42.37267",
    "lng": "126.80115"
  },
  {
    "country": "CN",
    "name": "Jingpeng",
    "lat": "43.25",
    "lng": "117.51667"
  },
  {
    "country": "CN",
    "name": "Jilin",
    "lat": "43.85083",
    "lng": "126.56028"
  },
  {
    "country": "CN",
    "name": "Jidong",
    "lat": "45.21667",
    "lng": "131.08333"
  },
  {
    "country": "CN",
    "name": "Minzhu",
    "lat": "43.72145",
    "lng": "127.33401"
  },
  {
    "country": "CN",
    "name": "Ji’an",
    "lat": "41.12349",
    "lng": "126.17631"
  },
  {
    "country": "CN",
    "name": "Jiamusi",
    "lat": "46.79927",
    "lng": "130.31633"
  },
  {
    "country": "CN",
    "name": "Jalai Nur",
    "lat": "49.45",
    "lng": "117.7"
  },
  {
    "country": "CN",
    "name": "Jiagedaqi",
    "lat": "50.41667",
    "lng": "124.11667"
  },
  {
    "country": "CN",
    "name": "Inder",
    "lat": "46.7",
    "lng": "122.93333"
  },
  {
    "country": "CN",
    "name": "Hushitai",
    "lat": "41.94175",
    "lng": "123.50266"
  },
  {
    "country": "CN",
    "name": "Kulun",
    "lat": "42.73056",
    "lng": "121.77556"
  },
  {
    "country": "CN",
    "name": "Hunchun",
    "lat": "42.8675",
    "lng": "130.35806"
  },
  {
    "country": "CN",
    "name": "Khuma",
    "lat": "51.71667",
    "lng": "126.63333"
  },
  {
    "country": "CN",
    "name": "Huludao",
    "lat": "40.75243",
    "lng": "120.83552"
  },
  {
    "country": "CN",
    "name": "Hulan Ergi",
    "lat": "47.20417",
    "lng": "123.63333"
  },
  {
    "country": "CN",
    "name": "Hulan",
    "lat": "45.98333",
    "lng": "126.6"
  },
  {
    "country": "CN",
    "name": "Huinan",
    "lat": "42.6225",
    "lng": "126.26139"
  },
  {
    "country": "CN",
    "name": "Huanren",
    "lat": "41.26472",
    "lng": "125.36667"
  },
  {
    "country": "CN",
    "name": "Huangnihe",
    "lat": "43.55833",
    "lng": "128.02389"
  },
  {
    "country": "CN",
    "name": "Huanan",
    "lat": "46.2207",
    "lng": "130.525"
  },
  {
    "country": "CN",
    "name": "Huadian",
    "lat": "42.96333",
    "lng": "126.74778"
  },
  {
    "country": "CN",
    "name": "Changshun",
    "lat": "41.89139",
    "lng": "113.99222"
  },
  {
    "country": "CN",
    "name": "Hongshan",
    "lat": "47.9758",
    "lng": "129.02199"
  },
  {
    "country": "CN",
    "name": "Honggang",
    "lat": "46.40124",
    "lng": "124.88322"
  },
  {
    "country": "CN",
    "name": "Hohhot",
    "lat": "40.81056",
    "lng": "111.65222"
  },
  {
    "country": "CN",
    "name": "Hoh Ereg",
    "lat": "41.09556",
    "lng": "111.44083"
  },
  {
    "country": "CN",
    "name": "Hobor",
    "lat": "41.27154",
    "lng": "112.62663"
  },
  {
    "country": "CN",
    "name": "Fendou",
    "lat": "45.21235",
    "lng": "130.90254"
  },
  {
    "country": "CN",
    "name": "Helong",
    "lat": "42.53974",
    "lng": "128.99722"
  },
  {
    "country": "CN",
    "name": "Heishan",
    "lat": "41.68917",
    "lng": "122.11278"
  },
  {
    "country": "CN",
    "name": "Heihe",
    "lat": "50.24413",
    "lng": "127.49016"
  },
  {
    "country": "CN",
    "name": "Hegang",
    "lat": "47.35118",
    "lng": "130.30012"
  },
  {
    "country": "CN",
    "name": "Harbin",
    "lat": "45.75",
    "lng": "126.65"
  },
  {
    "country": "CN",
    "name": "Haliut",
    "lat": "41.55611",
    "lng": "108.51972"
  },
  {
    "country": "CN",
    "name": "Hailun",
    "lat": "47.4565",
    "lng": "126.95368"
  },
  {
    "country": "CN",
    "name": "Hailin",
    "lat": "44.57149",
    "lng": "129.38539"
  },
  {
    "country": "CN",
    "name": "Hailar",
    "lat": "49.2",
    "lng": "119.7"
  },
  {
    "country": "CN",
    "name": "Haicheng",
    "lat": "40.85158",
    "lng": "122.74754"
  },
  {
    "country": "CN",
    "name": "Jinshan",
    "lat": "41.03349",
    "lng": "110.05205"
  },
  {
    "country": "CN",
    "name": "Gongzhuling",
    "lat": "43.50075",
    "lng": "124.81979"
  },
  {
    "country": "CN",
    "name": "Gongchangling",
    "lat": "41.11667",
    "lng": "123.45"
  },
  {
    "country": "CN",
    "name": "Genhe",
    "lat": "50.78333",
    "lng": "121.51667"
  },
  {
    "country": "CN",
    "name": "Gannan",
    "lat": "47.91472",
    "lng": "123.50306"
  },
  {
    "country": "CN",
    "name": "Gaizhou",
    "lat": "40.39417",
    "lng": "122.36861"
  },
  {
    "country": "CN",
    "name": "Fuyuan",
    "lat": "48.36306",
    "lng": "134.28917"
  },
  {
    "country": "CN",
    "name": "Fuyu",
    "lat": "47.79756",
    "lng": "124.45731"
  },
  {
    "country": "CN",
    "name": "Fuyu",
    "lat": "45.18333",
    "lng": "124.81667"
  },
  {
    "country": "CN",
    "name": "Fuxin",
    "lat": "42.01556",
    "lng": "121.65889"
  },
  {
    "country": "CN",
    "name": "Fusong",
    "lat": "42.32505",
    "lng": "127.27265"
  },
  {
    "country": "CN",
    "name": "Fushun",
    "lat": "41.88669",
    "lng": "123.94363"
  },
  {
    "country": "CN",
    "name": "Fuli",
    "lat": "46.72167",
    "lng": "131.13944"
  },
  {
    "country": "CN",
    "name": "Fujin",
    "lat": "47.26",
    "lng": "132.03222"
  },
  {
    "country": "CN",
    "name": "Beichengqu",
    "lat": "40.43944",
    "lng": "113.15361"
  },
  {
    "country": "CN",
    "name": "Fengxiang",
    "lat": "47.57549",
    "lng": "130.82306"
  },
  {
    "country": "CN",
    "name": "Fengcheng",
    "lat": "40.45361",
    "lng": "124.07167"
  },
  {
    "country": "CN",
    "name": "Fangzheng",
    "lat": "45.83881",
    "lng": "128.82757"
  },
  {
    "country": "CN",
    "name": "Erenhot",
    "lat": "43.6475",
    "lng": "111.97667"
  },
  {
    "country": "CN",
    "name": "Erdaojiang",
    "lat": "41.77639",
    "lng": "126.03194"
  },
  {
    "country": "CN",
    "name": "Duolun",
    "lat": "42.18712",
    "lng": "116.48909"
  },
  {
    "country": "CN",
    "name": "Dunhua",
    "lat": "43.3725",
    "lng": "128.2425"
  },
  {
    "country": "CN",
    "name": "Dongning",
    "lat": "44.06219",
    "lng": "131.12075"
  },
  {
    "country": "CN",
    "name": "Dongling",
    "lat": "41.81444",
    "lng": "123.57583"
  },
  {
    "country": "CN",
    "name": "Dongfeng",
    "lat": "42.64031",
    "lng": "125.51176"
  },
  {
    "country": "CN",
    "name": "Dongxing",
    "lat": "45.36088",
    "lng": "130.78679"
  },
  {
    "country": "CN",
    "name": "Dehui",
    "lat": "44.53333",
    "lng": "125.7"
  },
  {
    "country": "CN",
    "name": "Dawa",
    "lat": "40.99373",
    "lng": "122.06804"
  },
  {
    "country": "CN",
    "name": "Datong",
    "lat": "46.03376",
    "lng": "124.81064"
  },
  {
    "country": "CN",
    "name": "Datong",
    "lat": "40.09361",
    "lng": "113.29139"
  },
  {
    "country": "CN",
    "name": "Dashitou",
    "lat": "43.30667",
    "lng": "128.51139"
  },
  {
    "country": "CN",
    "name": "Dashiqiao",
    "lat": "40.63732",
    "lng": "122.50251"
  },
  {
    "country": "CN",
    "name": "Daqin Tal",
    "lat": "42.88719",
    "lng": "120.67466"
  },
  {
    "country": "CN",
    "name": "Daqing",
    "lat": "46.58333",
    "lng": "125"
  },
  {
    "country": "CN",
    "name": "Dandong",
    "lat": "40.12917",
    "lng": "124.39472"
  },
  {
    "country": "CN",
    "name": "Linghai",
    "lat": "41.16528",
    "lng": "121.36667"
  },
  {
    "country": "CN",
    "name": "Dalain Hob",
    "lat": "41.96528",
    "lng": "101.06389"
  },
  {
    "country": "CN",
    "name": "Dalai",
    "lat": "45.5",
    "lng": "124.3"
  },
  {
    "country": "CN",
    "name": "Dailing",
    "lat": "47.02389",
    "lng": "129.01904"
  },
  {
    "country": "CN",
    "name": "Dage",
    "lat": "41.19889",
    "lng": "116.64417"
  },
  {
    "country": "CN",
    "name": "Daban",
    "lat": "43.53333",
    "lng": "118.66667"
  },
  {
    "country": "CN",
    "name": "Shuguang",
    "lat": "47.72411",
    "lng": "128.67399"
  },
  {
    "country": "CN",
    "name": "Chifeng",
    "lat": "42.26833",
    "lng": "118.96361"
  },
  {
    "country": "CN",
    "name": "Chicheng",
    "lat": "40.86667",
    "lng": "115.83333"
  },
  {
    "country": "CN",
    "name": "Chengzihe",
    "lat": "45.33333",
    "lng": "131.06667"
  },
  {
    "country": "CN",
    "name": "Chengde",
    "lat": "40.9519",
    "lng": "117.95883"
  },
  {
    "country": "CN",
    "name": "Chaoyang",
    "lat": "42.66223",
    "lng": "126.0263"
  },
  {
    "country": "CN",
    "name": "Chaoyang",
    "lat": "41.57028",
    "lng": "120.45861"
  },
  {
    "country": "CN",
    "name": "Changtu",
    "lat": "42.77884",
    "lng": "124.09545"
  },
  {
    "country": "CN",
    "name": "Changping",
    "lat": "40.21612",
    "lng": "116.23471"
  },
  {
    "country": "CN",
    "name": "Changling",
    "lat": "44.26532",
    "lng": "124.00045"
  },
  {
    "country": "CN",
    "name": "Changchun",
    "lat": "43.88",
    "lng": "125.32278"
  },
  {
    "country": "CN",
    "name": "Changbai",
    "lat": "41.41673",
    "lng": "128.19053"
  },
  {
    "country": "CN",
    "name": "Chaihe",
    "lat": "44.7598",
    "lng": "129.67826"
  },
  {
    "country": "CN",
    "name": "Chaigoubu",
    "lat": "40.66778",
    "lng": "114.41139"
  },
  {
    "country": "CN",
    "name": "Boli",
    "lat": "45.75279",
    "lng": "130.57211"
  },
  {
    "country": "CN",
    "name": "Binzhou",
    "lat": "45.75281",
    "lng": "127.47986"
  },
  {
    "country": "CN",
    "name": "Benxi",
    "lat": "41.28861",
    "lng": "123.765"
  },
  {
    "country": "CN",
    "name": "Beipiao",
    "lat": "41.79194",
    "lng": "120.77917"
  },
  {
    "country": "CN",
    "name": "Bei’an",
    "lat": "48.26667",
    "lng": "126.6"
  },
  {
    "country": "CN",
    "name": "Bayan Tuohai",
    "lat": "49.13333",
    "lng": "119.73333"
  },
  {
    "country": "CN",
    "name": "Baiyin Chagan",
    "lat": "41.45333",
    "lng": "113.18333"
  },
  {
    "country": "CN",
    "name": "Bayan Huxu",
    "lat": "45.15",
    "lng": "121.4"
  },
  {
    "country": "CN",
    "name": "Bayan Hure",
    "lat": "49.5",
    "lng": "119.51667"
  },
  {
    "country": "CN",
    "name": "Bayan Gol",
    "lat": "40.3",
    "lng": "106.98333"
  },
  {
    "country": "CN",
    "name": "Bayan",
    "lat": "46.07556",
    "lng": "127.3984"
  },
  {
    "country": "CN",
    "name": "Baotou",
    "lat": "40.65222",
    "lng": "109.82222"
  },
  {
    "country": "CN",
    "name": "Baoshan",
    "lat": "46.55861",
    "lng": "131.42444"
  },
  {
    "country": "CN",
    "name": "Baoqing",
    "lat": "46.33167",
    "lng": "132.21111"
  },
  {
    "country": "CN",
    "name": "Baokang",
    "lat": "44.11972",
    "lng": "123.30472"
  },
  {
    "country": "CN",
    "name": "Baochang",
    "lat": "41.88444",
    "lng": "115.27889"
  },
  {
    "country": "CN",
    "name": "Bamiantong",
    "lat": "44.91738",
    "lng": "130.52"
  },
  {
    "country": "CN",
    "name": "Baishishan",
    "lat": "43.58333",
    "lng": "127.56667"
  },
  {
    "country": "CN",
    "name": "Baiquan",
    "lat": "47.60605",
    "lng": "126.08481"
  },
  {
    "country": "CN",
    "name": "Baiquan",
    "lat": "42.88538",
    "lng": "124.95827"
  },
  {
    "country": "CN",
    "name": "Bailingmiao",
    "lat": "41.69194",
    "lng": "110.43556"
  },
  {
    "country": "CN",
    "name": "Baicheng",
    "lat": "45.60746",
    "lng": "122.82076"
  },
  {
    "country": "CN",
    "name": "Xiqu",
    "lat": "26.60566",
    "lng": "101.59828"
  },
  {
    "country": "CN",
    "name": "Baishan",
    "lat": "41.93853",
    "lng": "126.41965"
  },
  {
    "country": "CN",
    "name": "Wenquan",
    "lat": "47.18333",
    "lng": "119.96667"
  },
  {
    "country": "CN",
    "name": "Anshan",
    "lat": "41.12361",
    "lng": "122.99"
  },
  {
    "country": "CN",
    "name": "Xinxing",
    "lat": "47.15467",
    "lng": "123.80987"
  },
  {
    "country": "CN",
    "name": "Anda",
    "lat": "46.40202",
    "lng": "125.31454"
  },
  {
    "country": "CN",
    "name": "Amgalang",
    "lat": "48.25",
    "lng": "118.2"
  },
  {
    "country": "CN",
    "name": "Oroqen Zizhiqi",
    "lat": "50.56667",
    "lng": "123.71667"
  },
  {
    "country": "CN",
    "name": "Acheng",
    "lat": "45.54545",
    "lng": "126.97703"
  },
  {
    "country": "CN",
    "name": "Songling",
    "lat": "40.29303",
    "lng": "118.26908"
  },
  {
    "country": "CN",
    "name": "Bayinbaolige",
    "lat": "41.09139",
    "lng": "107.06639"
  },
  {
    "country": "CN",
    "name": "Ulashan",
    "lat": "40.665",
    "lng": "108.74472"
  },
  {
    "country": "CN",
    "name": "Mositai",
    "lat": "45.53538",
    "lng": "119.66698"
  },
  {
    "country": "CN",
    "name": "Hanbin",
    "lat": "32.88972",
    "lng": "108.90444"
  },
  {
    "country": "CN",
    "name": "Xiling",
    "lat": "30.71606",
    "lng": "111.2839"
  },
  {
    "country": "CN",
    "name": "E’zhou",
    "lat": "30.39607",
    "lng": "114.88655"
  },
  {
    "country": "CN",
    "name": "Hong’an",
    "lat": "47.20554",
    "lng": "123.62524"
  },
  {
    "country": "CN",
    "name": "Jinniu",
    "lat": "25.80062",
    "lng": "100.57435"
  },
  {
    "country": "CN",
    "name": "Nanzhao",
    "lat": "25.22222",
    "lng": "100.30344"
  },
  {
    "country": "CN",
    "name": "Jiantang",
    "lat": "27.82244",
    "lng": "99.76929"
  },
  {
    "country": "CN",
    "name": "Nayun",
    "lat": "22.33196",
    "lng": "99.56132"
  },
  {
    "country": "CN",
    "name": "Dingcheng",
    "lat": "29.01937",
    "lng": "111.67976"
  },
  {
    "country": "CN",
    "name": "Liangshi",
    "lat": "27.20636",
    "lng": "111.73714"
  },
  {
    "country": "CN",
    "name": "Yunji",
    "lat": "26.6932",
    "lng": "112.66748"
  },
  {
    "country": "CN",
    "name": "Jianghai",
    "lat": "22.57518",
    "lng": "113.11904"
  },
  {
    "country": "CN",
    "name": "Lianjiang",
    "lat": "22.59018",
    "lng": "113.07642"
  },
  {
    "country": "CN",
    "name": "Leicheng",
    "lat": "20.91558",
    "lng": "110.08371"
  },
  {
    "country": "CN",
    "name": "Dongzhen",
    "lat": "22.37971",
    "lng": "110.93885"
  },
  {
    "country": "CN",
    "name": "Luozhou",
    "lat": "21.60589",
    "lng": "110.27705"
  },
  {
    "country": "CN",
    "name": "Hexi",
    "lat": "21.68651",
    "lng": "110.63417"
  },
  {
    "country": "CN",
    "name": "Taihe",
    "lat": "23.73535",
    "lng": "112.97782"
  },
  {
    "country": "CN",
    "name": "Xiangjiaba",
    "lat": "28.63266",
    "lng": "104.40416"
  },
  {
    "country": "CN",
    "name": "Zhongcheng",
    "lat": "28.59103",
    "lng": "103.93958"
  },
  {
    "country": "CN",
    "name": "Shiqiao",
    "lat": "27.98195",
    "lng": "120.55917"
  },
  {
    "country": "CN",
    "name": "Yushan",
    "lat": "31.67748",
    "lng": "120.80134"
  },
  {
    "country": "CN",
    "name": "Jincheng",
    "lat": "31.74422",
    "lng": "119.57416"
  },
  {
    "country": "CN",
    "name": "Yongyang",
    "lat": "31.65811",
    "lng": "119.02772"
  },
  {
    "country": "CN",
    "name": "Shilin",
    "lat": "24.81878",
    "lng": "103.33237"
  },
  {
    "country": "CN",
    "name": "Huohua",
    "lat": "30.759",
    "lng": "106.05936"
  },
  {
    "country": "CN",
    "name": "Xinan",
    "lat": "23.15445",
    "lng": "112.89344"
  },
  {
    "country": "CN",
    "name": "Shunde",
    "lat": "22.80087",
    "lng": "113.29208"
  },
  {
    "country": "CN",
    "name": "Xinfa",
    "lat": "28.83071",
    "lng": "104.32077"
  },
  {
    "country": "CN",
    "name": "Panzhihua",
    "lat": "26.58509",
    "lng": "101.71276"
  },
  {
    "country": "CN",
    "name": "Haikuotiankong",
    "lat": "22.52881",
    "lng": "113.9399"
  },
  {
    "country": "CN",
    "name": "Xilinji",
    "lat": "52.99063",
    "lng": "123.23522"
  },
  {
    "country": "CN",
    "name": "Gufu",
    "lat": "31.36208",
    "lng": "110.72918"
  },
  {
    "country": "CN",
    "name": "Hongmiao",
    "lat": "32.22483",
    "lng": "118.91975"
  },
  {
    "country": "CN",
    "name": "Shirong",
    "lat": "29.35092",
    "lng": "102.65248"
  },
  {
    "country": "CN",
    "name": "Nanwai",
    "lat": "31.20474",
    "lng": "107.50363"
  },
  {
    "country": "CN",
    "name": "Xiwai",
    "lat": "31.21682",
    "lng": "107.47525"
  },
  {
    "country": "CN",
    "name": "Xia’er",
    "lat": "29.00594",
    "lng": "101.51439"
  },
  {
    "country": "CN",
    "name": "Zhongshan",
    "lat": "22.52306",
    "lng": "113.37912"
  },
  {
    "country": "CN",
    "name": "Chengnan",
    "lat": "23.27217",
    "lng": "116.60502"
  },
  {
    "country": "CN",
    "name": "Yongchang",
    "lat": "31.66574",
    "lng": "104.43726"
  },
  {
    "country": "CN",
    "name": "Jinjiazhuang",
    "lat": "31.72012",
    "lng": "118.48953"
  },
  {
    "country": "CN",
    "name": "Jinghu",
    "lat": "31.34758",
    "lng": "118.36829"
  },
  {
    "country": "CN",
    "name": "Yijiang",
    "lat": "31.31546",
    "lng": "118.36053"
  },
  {
    "country": "CN",
    "name": "Weicheng",
    "lat": "34.3314",
    "lng": "108.71691"
  },
  {
    "country": "CN",
    "name": "Qindu",
    "lat": "34.34186",
    "lng": "108.70824"
  },
  {
    "country": "CN",
    "name": "Weiyang",
    "lat": "34.2906",
    "lng": "108.93554"
  },
  {
    "country": "CN",
    "name": "Xincheng",
    "lat": "34.26321",
    "lng": "108.94954"
  },
  {
    "country": "CN",
    "name": "Beilin",
    "lat": "34.22846",
    "lng": "108.91566"
  },
  {
    "country": "CN",
    "name": "Tongchuan",
    "lat": "34.8988",
    "lng": "108.95056"
  },
  {
    "country": "CN",
    "name": "Lianhu",
    "lat": "34.25848",
    "lng": "108.92421"
  },
  {
    "country": "CN",
    "name": "Wuhu",
    "lat": "31.1463",
    "lng": "118.56465"
  },
  {
    "country": "CN",
    "name": "Pan’an",
    "lat": "29.05368",
    "lng": "120.43758"
  },
  {
    "country": "CN",
    "name": "Longgang",
    "lat": "40.72146",
    "lng": "120.92558"
  },
  {
    "country": "CN",
    "name": "Changshu City",
    "lat": "31.64615",
    "lng": "120.74221"
  },
  {
    "country": "CN",
    "name": "Shixing",
    "lat": "24.94824",
    "lng": "114.06572"
  },
  {
    "country": "CN",
    "name": "Jiashan",
    "lat": "30.84918",
    "lng": "120.92583"
  },
  {
    "country": "CN",
    "name": "Fenghuang",
    "lat": "27.93557",
    "lng": "109.59961"
  },
  {
    "country": "CN",
    "name": "Dehang",
    "lat": "28.3071",
    "lng": "109.79668"
  },
  {
    "country": "CN",
    "name": "Zhaoxian",
    "lat": "28.70618",
    "lng": "115.73617"
  },
  {
    "country": "CN",
    "name": "Dianga",
    "lat": "34.06363",
    "lng": "103.21358"
  },
  {
    "country": "CN",
    "name": "Shoushan",
    "lat": "34.27771",
    "lng": "107.74619"
  },
  {
    "country": "CN",
    "name": "Fengxiang Chengguanzhen",
    "lat": "34.52301",
    "lng": "107.39127"
  },
  {
    "country": "CN",
    "name": "Zhongshan Donglu",
    "lat": "34.37964",
    "lng": "107.14638"
  },
  {
    "country": "CN",
    "name": "Jinling",
    "lat": "34.36925",
    "lng": "107.14997"
  },
  {
    "country": "CN",
    "name": "Mangqu",
    "lat": "35.5857",
    "lng": "100.75237"
  },
  {
    "country": "CN",
    "name": "Qianyang Chengguanzhen",
    "lat": "34.64209",
    "lng": "107.13019"
  },
  {
    "country": "CN",
    "name": "Saga",
    "lat": "29.32367",
    "lng": "85.22601"
  },
  {
    "country": "CN",
    "name": "Zhu Cheng City",
    "lat": "35.99502",
    "lng": "119.40259"
  },
  {
    "country": "CN",
    "name": "Nanzheng Chengguanzhen",
    "lat": "33.00452",
    "lng": "106.93466"
  },
  {
    "country": "CN",
    "name": "Yelin",
    "lat": "18.52099",
    "lng": "110.0397"
  },
  {
    "country": "CN",
    "name": "Yuanzhou",
    "lat": "27.79846",
    "lng": "114.37608"
  },
  {
    "country": "CN",
    "name": "Xiayang",
    "lat": "31.14967",
    "lng": "121.11588"
  },
  {
    "country": "CN",
    "name": "Xinchenglu",
    "lat": "31.38864",
    "lng": "121.26305"
  },
  {
    "country": "CN",
    "name": "Fangsong",
    "lat": "31.03285",
    "lng": "121.18943"
  },
  {
    "country": "CN",
    "name": "Biru",
    "lat": "31.48319",
    "lng": "93.67741"
  },
  {
    "country": "CN",
    "name": "Biruxong",
    "lat": "31.401",
    "lng": "93.601"
  },
  {
    "country": "CN",
    "name": "Moluo",
    "lat": "30.80392",
    "lng": "98.10038"
  },
  {
    "country": "CN",
    "name": "Qianquan",
    "lat": "30.87126",
    "lng": "114.37258"
  },
  {
    "country": "CN",
    "name": "Shangri-La",
    "lat": "27.82511",
    "lng": "99.70779"
  },
  {
    "country": "CN",
    "name": "Jishi",
    "lat": "35.84613",
    "lng": "102.48171"
  },
  {
    "country": "CN",
    "name": "Dingqing",
    "lat": "31.41153",
    "lng": "95.58418"
  },
  {
    "country": "CN",
    "name": "Konggar",
    "lat": "29.29389",
    "lng": "90.98708"
  },
  {
    "country": "CN",
    "name": "Laxi",
    "lat": "31.92125",
    "lng": "94.04757"
  },
  {
    "country": "CN",
    "name": "Mainling",
    "lat": "29.21767",
    "lng": "94.21325"
  },
  {
    "country": "CN",
    "name": "Nagqu",
    "lat": "31.403",
    "lng": "92.003"
  },
  {
    "country": "CN",
    "name": "Renwu",
    "lat": "29.605",
    "lng": "89.005"
  },
  {
    "country": "CN",
    "name": "Samdo",
    "lat": "31.2143",
    "lng": "96.5994"
  },
  {
    "country": "CN",
    "name": "Xuejiawan",
    "lat": "39.86678",
    "lng": "111.2208"
  },
  {
    "country": "CN",
    "name": "Galutu",
    "lat": "38.60086",
    "lng": "108.84742"
  },
  {
    "country": "CN",
    "name": "Aletengxire",
    "lat": "39.57993",
    "lng": "109.75821"
  },
  {
    "country": "CN",
    "name": "Dabagou",
    "lat": "46.06946",
    "lng": "121.91632"
  },
  {
    "country": "CN",
    "name": "Liuxiang",
    "lat": "37.87143",
    "lng": "112.56054"
  },
  {
    "country": "CN",
    "name": "Julun",
    "lat": "37.9074",
    "lng": "112.55774"
  },
  {
    "country": "CN",
    "name": "Qianfeng",
    "lat": "37.84942",
    "lng": "112.52081"
  },
  {
    "country": "CN",
    "name": "Dongqu",
    "lat": "37.92021",
    "lng": "112.20018"
  },
  {
    "country": "CN",
    "name": "Bala Ga’er Gaole",
    "lat": "44.59149",
    "lng": "117.6237"
  },
  {
    "country": "CN",
    "name": "Bieligutai",
    "lat": "44.0303",
    "lng": "114.98036"
  },
  {
    "country": "CN",
    "name": "Tianjiao",
    "lat": "39.82553",
    "lng": "109.99953"
  },
  {
    "country": "CN",
    "name": "Heping",
    "lat": "46.08626",
    "lng": "122.07708"
  },
  {
    "country": "CN",
    "name": "Shangdu",
    "lat": "42.25005",
    "lng": "116.00798"
  },
  {
    "country": "CN",
    "name": "Wenquan",
    "lat": "47.1756",
    "lng": "119.94809"
  },
  {
    "country": "CN",
    "name": "Tongyangdao",
    "lat": "41.77031",
    "lng": "109.96987"
  },
  {
    "country": "CN",
    "name": "Bayinsai",
    "lat": "39.50022",
    "lng": "106.72021"
  },
  {
    "country": "CN",
    "name": "Xingong",
    "lat": "49.29031",
    "lng": "120.70609"
  },
  {
    "country": "CN",
    "name": "Xiritala",
    "lat": "43.93889",
    "lng": "116.07021"
  },
  {
    "country": "CN",
    "name": "Xinghua",
    "lat": "48.01449",
    "lng": "122.69839"
  },
  {
    "country": "CN",
    "name": "Xarlung",
    "lat": "29.9",
    "lng": "93.3"
  },
  {
    "country": "CN",
    "name": "Xoixar",
    "lat": "27.903",
    "lng": "91.903"
  },
  {
    "country": "CN",
    "name": "Naidong",
    "lat": "29.24301",
    "lng": "91.77239"
  },
  {
    "country": "CN",
    "name": "Dongjie",
    "lat": "26.08823",
    "lng": "119.29449"
  },
  {
    "country": "CN",
    "name": "Shaoyang",
    "lat": "32.92958",
    "lng": "119.83576"
  },
  {
    "country": "CN",
    "name": "Guyang",
    "lat": "32.13538",
    "lng": "119.44209"
  },
  {
    "country": "CN",
    "name": "Zhengdonglu",
    "lat": "32.19278",
    "lng": "119.4705"
  },
  {
    "country": "CN",
    "name": "Shouxihu",
    "lat": "32.42089",
    "lng": "119.40435"
  },
  {
    "country": "CN",
    "name": "Hanshang",
    "lat": "32.37744",
    "lng": "119.39302"
  },
  {
    "country": "CN",
    "name": "Wenhe",
    "lat": "32.39523",
    "lng": "119.42688"
  },
  {
    "country": "CN",
    "name": "Wulaocun",
    "lat": "32.03437",
    "lng": "118.79575"
  },
  {
    "country": "CN",
    "name": "Qinhong",
    "lat": "32.01135",
    "lng": "118.79655"
  },
  {
    "country": "CN",
    "name": "Binhu",
    "lat": "32.03008",
    "lng": "118.75768"
  },
  {
    "country": "CN",
    "name": "Meiyuan Xincun",
    "lat": "32.05421",
    "lng": "118.79275"
  },
  {
    "country": "CN",
    "name": "Xiongzhou",
    "lat": "32.34359",
    "lng": "118.84986"
  },
  {
    "country": "CN",
    "name": "Jizhou",
    "lat": "27.14409",
    "lng": "114.99596"
  },
  {
    "country": "CN",
    "name": "Gulou",
    "lat": "26.08653",
    "lng": "119.29798"
  },
  {
    "country": "CN",
    "name": "Nanchansi",
    "lat": "31.56242",
    "lng": "120.30021"
  },
  {
    "country": "CN",
    "name": "Beidajie",
    "lat": "31.58528",
    "lng": "120.29004"
  },
  {
    "country": "CN",
    "name": "Chong’ansi",
    "lat": "31.57987",
    "lng": "120.29518"
  },
  {
    "country": "CN",
    "name": "Songlong",
    "lat": "31.1624",
    "lng": "120.6384"
  },
  {
    "country": "CN",
    "name": "Yuanhe",
    "lat": "31.39929",
    "lng": "120.61445"
  },
  {
    "country": "CN",
    "name": "Shishan",
    "lat": "31.29883",
    "lng": "120.56516"
  },
  {
    "country": "CN",
    "name": "Shuangta",
    "lat": "31.30408",
    "lng": "120.62968"
  },
  {
    "country": "CN",
    "name": "Pingjianglu",
    "lat": "31.31469",
    "lng": "120.62978"
  },
  {
    "country": "CN",
    "name": "Shilu",
    "lat": "31.31169",
    "lng": "120.59409"
  },
  {
    "country": "CN",
    "name": "Xiangcheng",
    "lat": "31.93667",
    "lng": "111.91778"
  },
  {
    "country": "CN",
    "name": "Ordos",
    "lat": "39.6086",
    "lng": "109.78157"
  },
  {
    "country": "CN",
    "name": "Lanjiang",
    "lat": "29.21511",
    "lng": "119.46121"
  },
  {
    "country": "CN",
    "name": "Chengzhong",
    "lat": "29.10644",
    "lng": "119.64855"
  },
  {
    "country": "CN",
    "name": "Jiefanglu",
    "lat": "31.70886",
    "lng": "118.50905"
  },
  {
    "country": "CN",
    "name": "Ningnan",
    "lat": "31.98504",
    "lng": "118.78147"
  },
  {
    "country": "CN",
    "name": "Chengbei",
    "lat": "40.22303",
    "lng": "116.24584"
  },
  {
    "country": "CN",
    "name": "Longshan",
    "lat": "40.32015",
    "lng": "116.62909"
  },
  {
    "country": "CN",
    "name": "Dayu",
    "lat": "39.9375",
    "lng": "116.09669"
  },
  {
    "country": "CN",
    "name": "Lugu",
    "lat": "39.89672",
    "lng": "116.22037"
  },
  {
    "country": "CN",
    "name": "Jingshan",
    "lat": "39.92528",
    "lng": "116.40411"
  },
  {
    "country": "CN",
    "name": "Jinrongjie",
    "lat": "39.91222",
    "lng": "116.35615"
  },
  {
    "country": "CN",
    "name": "Chaowai",
    "lat": "39.91812",
    "lng": "116.43242"
  },
  {
    "country": "CN",
    "name": "Gongchen",
    "lat": "39.72796",
    "lng": "116.13756"
  },
  {
    "country": "CN",
    "name": "Beiyuan",
    "lat": "39.90362",
    "lng": "116.64667"
  },
  {
    "country": "CN",
    "name": "Shengli",
    "lat": "40.11818",
    "lng": "116.64295"
  },
  {
    "country": "CN",
    "name": "Xingfeng",
    "lat": "39.72965",
    "lng": "116.33661"
  },
  {
    "country": "CN",
    "name": "Binhe",
    "lat": "40.13347",
    "lng": "117.10852"
  },
  {
    "country": "CN",
    "name": "Gulou",
    "lat": "40.36997",
    "lng": "116.83352"
  },
  {
    "country": "CN",
    "name": "Huayang",
    "lat": "31.95165",
    "lng": "119.16284"
  },
  {
    "country": "CN",
    "name": "Yunyang",
    "lat": "31.99563",
    "lng": "119.56463"
  },
  {
    "country": "CN",
    "name": "Hehai",
    "lat": "31.82921",
    "lng": "119.9778"
  },
  {
    "country": "CN",
    "name": "Sanjiang",
    "lat": "31.34813",
    "lng": "118.36132"
  },
  {
    "country": "CN",
    "name": "Dongcheng",
    "lat": "28.89381",
    "lng": "120.04024"
  },
  {
    "country": "CN",
    "name": "Chengxiang",
    "lat": "31.3986",
    "lng": "109.62284"
  },
  {
    "country": "CN",
    "name": "Fuying",
    "lat": "28.8626",
    "lng": "120.7193"
  },
  {
    "country": "CN",
    "name": "Dongcheng",
    "lat": "28.6473",
    "lng": "121.27106"
  },
  {
    "country": "CN",
    "name": "Lubei",
    "lat": "28.58633",
    "lng": "121.36998"
  },
  {
    "country": "CN",
    "name": "Taizhou",
    "lat": "28.66266",
    "lng": "121.43312"
  },
  {
    "country": "CN",
    "name": "Gucheng",
    "lat": "28.84856",
    "lng": "121.1161"
  },
  {
    "country": "CN",
    "name": "Taiping",
    "lat": "28.36877",
    "lng": "121.36171"
  },
  {
    "country": "CN",
    "name": "Zhugang",
    "lat": "28.13832",
    "lng": "121.22621"
  },
  {
    "country": "CN",
    "name": "Chenjiaba",
    "lat": "30.81386",
    "lng": "108.37326"
  },
  {
    "country": "CN",
    "name": "Sanhe",
    "lat": "29.86864",
    "lng": "107.73027"
  },
  {
    "country": "CN",
    "name": "Qianjiang",
    "lat": "29.53284",
    "lng": "108.77478"
  },
  {
    "country": "CN",
    "name": "Hutang",
    "lat": "31.71581",
    "lng": "119.94458"
  },
  {
    "country": "CN",
    "name": "Changhongjie",
    "lat": "39.13727",
    "lng": "117.14748"
  },
  {
    "country": "CN",
    "name": "Wanghailou",
    "lat": "39.15954",
    "lng": "117.20338"
  },
  {
    "country": "CN",
    "name": "Xiyuzhuang",
    "lat": "39.16631",
    "lng": "117.15679"
  },
  {
    "country": "CN",
    "name": "Dawangzhuang",
    "lat": "39.12703",
    "lng": "117.21618"
  },
  {
    "country": "CN",
    "name": "Dayingmen",
    "lat": "39.10734",
    "lng": "117.20958"
  },
  {
    "country": "CN",
    "name": "Xiaobailou",
    "lat": "39.11766",
    "lng": "117.20565"
  },
  {
    "country": "CN",
    "name": "Guoyuan Xincun",
    "lat": "39.22187",
    "lng": "117.13018"
  },
  {
    "country": "CN",
    "name": "Wuma",
    "lat": "28.01731",
    "lng": "120.66595"
  },
  {
    "country": "CN",
    "name": "Lizhi",
    "lat": "29.70317",
    "lng": "107.39521"
  },
  {
    "country": "CN",
    "name": "Fengcheng",
    "lat": "29.82811",
    "lng": "107.06379"
  },
  {
    "country": "CN",
    "name": "Shuangfengqiao",
    "lat": "29.71859",
    "lng": "106.62712"
  },
  {
    "country": "CN",
    "name": "Nanjin",
    "lat": "29.98497",
    "lng": "106.26529"
  },
  {
    "country": "CN",
    "name": "Shuanglu",
    "lat": "29.48543",
    "lng": "105.7629"
  },
  {
    "country": "CN",
    "name": "Tangxiang",
    "lat": "29.70226",
    "lng": "105.72363"
  },
  {
    "country": "CN",
    "name": "Zhongshanlu",
    "lat": "29.35695",
    "lng": "105.90435"
  },
  {
    "country": "CN",
    "name": "Huancuilou",
    "lat": "37.50041",
    "lng": "122.11398"
  },
  {
    "country": "CN",
    "name": "Wenhua",
    "lat": "37.39106",
    "lng": "121.58959"
  },
  {
    "country": "CN",
    "name": "Huanghai",
    "lat": "37.4887",
    "lng": "121.44038"
  },
  {
    "country": "CN",
    "name": "Xiangyang",
    "lat": "37.53157",
    "lng": "121.39388"
  },
  {
    "country": "CN",
    "name": "Jimai",
    "lat": "33.75155",
    "lng": "99.64821"
  },
  {
    "country": "CN",
    "name": "Youganning",
    "lat": "34.73564",
    "lng": "101.61141"
  },
  {
    "country": "CN",
    "name": "Wenshan City",
    "lat": "23.36306",
    "lng": "104.25047"
  },
  {
    "country": "CN",
    "name": "Nanhang",
    "lat": "47.31469",
    "lng": "123.94796"
  },
  {
    "country": "CN",
    "name": "Bukui",
    "lat": "47.35503",
    "lng": "123.95172"
  },
  {
    "country": "CN",
    "name": "Longhua",
    "lat": "47.33847",
    "lng": "123.97919"
  },
  {
    "country": "CN",
    "name": "Dong’an",
    "lat": "46.59405",
    "lng": "125.07878"
  },
  {
    "country": "CN",
    "name": "Dayou",
    "lat": "46.63616",
    "lng": "126.98753"
  },
  {
    "country": "CN",
    "name": "Xiaoduchuan",
    "lat": "30.29113",
    "lng": "109.47616"
  },
  {
    "country": "CN",
    "name": "Xuri",
    "lat": "47.72685",
    "lng": "128.89994"
  },
  {
    "country": "CN",
    "name": "Youyi",
    "lat": "46.80485",
    "lng": "130.31922"
  },
  {
    "country": "CN",
    "name": "Qiaonan",
    "lat": "46.80361",
    "lng": "130.35805"
  },
  {
    "country": "CN",
    "name": "Zhanqian",
    "lat": "46.80011",
    "lng": "130.37547"
  },
  {
    "country": "CN",
    "name": "Jianguo",
    "lat": "46.8177",
    "lng": "130.39615"
  },
  {
    "country": "CN",
    "name": "Xing’an",
    "lat": "47.2463",
    "lng": "130.22038"
  },
  {
    "country": "CN",
    "name": "Tiexi",
    "lat": "47.31187",
    "lng": "130.28027"
  },
  {
    "country": "CN",
    "name": "Hongqi",
    "lat": "47.318",
    "lng": "130.2679"
  },
  {
    "country": "CN",
    "name": "Guangming",
    "lat": "47.33972",
    "lng": "130.28679"
  },
  {
    "country": "CN",
    "name": "Dongshan",
    "lat": "47.34277",
    "lng": "130.31222"
  },
  {
    "country": "CN",
    "name": "Gounan",
    "lat": "47.35941",
    "lng": "130.29747"
  },
  {
    "country": "CN",
    "name": "Beishan",
    "lat": "45.8162",
    "lng": "130.92833"
  },
  {
    "country": "CN",
    "name": "Hongjunlu",
    "lat": "45.30347",
    "lng": "130.97596"
  },
  {
    "country": "CN",
    "name": "Xiangyang",
    "lat": "44.58799",
    "lng": "129.57977"
  },
  {
    "country": "CN",
    "name": "Xianfeng",
    "lat": "44.57503",
    "lng": "129.60255"
  },
  {
    "country": "CN",
    "name": "Xin’an",
    "lat": "44.58033",
    "lng": "129.62572"
  },
  {
    "country": "CN",
    "name": "Yangming",
    "lat": "44.59629",
    "lng": "129.62081"
  },
  {
    "country": "CN",
    "name": "Zhonghualu",
    "lat": "35.60525",
    "lng": "104.59668"
  },
  {
    "country": "CN",
    "name": "Liupanshui",
    "lat": "26.59444",
    "lng": "104.83333"
  },
  {
    "country": "CN",
    "name": "Qinjiang",
    "lat": "26.32994",
    "lng": "116.33467"
  },
  {
    "country": "CN",
    "name": "Huichang",
    "lat": "25.60074",
    "lng": "115.77796"
  },
  {
    "country": "CN",
    "name": "Xuri",
    "lat": "28.43511",
    "lng": "117.91979"
  },
  {
    "country": "CN",
    "name": "Huanggang",
    "lat": "30.45143",
    "lng": "114.87035"
  },
  {
    "country": "CN",
    "name": "Yanqiao",
    "lat": "31.68918",
    "lng": "120.278"
  },
  {
    "country": "CN",
    "name": "Meixian",
    "lat": "24.28382",
    "lng": "116.06953"
  },
  {
    "country": "CN",
    "name": "Beijinglu",
    "lat": "31.32268",
    "lng": "118.38505"
  },
  {
    "country": "CN",
    "name": "Chengqu",
    "lat": "36.9106",
    "lng": "121.52504"
  },
  {
    "country": "CN",
    "name": "Louqiao",
    "lat": "28.01061",
    "lng": "120.63218"
  },
  {
    "country": "CN",
    "name": "Shazhou",
    "lat": "40.13799",
    "lng": "94.66227"
  },
  {
    "country": "CN",
    "name": "Chaoyang",
    "lat": "48.88638",
    "lng": "130.40323"
  },
  {
    "country": "CN",
    "name": "Dongcheng",
    "lat": "29.15201",
    "lng": "107.10335"
  },
  {
    "country": "CN",
    "name": "Bianjiang",
    "lat": "49.5578",
    "lng": "128.47307"
  },
  {
    "country": "CN",
    "name": "Dongtundu",
    "lat": "28.18371",
    "lng": "113.03209"
  },
  {
    "country": "CN",
    "name": "Furong Beilu",
    "lat": "28.23707",
    "lng": "112.98076"
  },
  {
    "country": "CN",
    "name": "Guitang",
    "lat": "28.13996",
    "lng": "113.04246"
  },
  {
    "country": "CN",
    "name": "Qingyuan",
    "lat": "28.1172",
    "lng": "112.99846"
  },
  {
    "country": "CN",
    "name": "Wangyue",
    "lat": "28.2359",
    "lng": "112.917"
  },
  {
    "country": "CN",
    "name": "Damatou",
    "lat": "28.61751",
    "lng": "112.33695"
  },
  {
    "country": "CN",
    "name": "Hongliuwan",
    "lat": "39.63187",
    "lng": "94.33694"
  },
  {
    "country": "CN",
    "name": "Mingren",
    "lat": "45.59316",
    "lng": "122.81879"
  },
  {
    "country": "CN",
    "name": "Meilu",
    "lat": "21.43412",
    "lng": "110.77555"
  },
  {
    "country": "CN",
    "name": "Nan’an",
    "lat": "23.03136",
    "lng": "112.45108"
  },
  {
    "country": "CN",
    "name": "Xing’an",
    "lat": "50.2477",
    "lng": "127.49323"
  },
  {
    "country": "CN",
    "name": "Yinla",
    "lat": "29.5773",
    "lng": "94.48301"
  },
  {
    "country": "CN",
    "name": "Mugala",
    "lat": "36.8576",
    "lng": "81.66844"
  },
  {
    "country": "CN",
    "name": "Ailan Mubage",
    "lat": "43.90845",
    "lng": "81.33299"
  },
  {
    "country": "CN",
    "name": "Nanjie",
    "lat": "38.95462",
    "lng": "100.47237"
  },
  {
    "country": "CN",
    "name": "Xinjia",
    "lat": "37.6574",
    "lng": "120.485"
  },
  {
    "country": "CN",
    "name": "Nierong",
    "lat": "32.11309",
    "lng": "92.29572"
  },
  {
    "country": "CN",
    "name": "Xingning",
    "lat": "24.1483",
    "lng": "115.72272"
  },
  {
    "country": "CN",
    "name": "Anning Xilu",
    "lat": "36.1035",
    "lng": "103.71928"
  },
  {
    "country": "CN",
    "name": "Zhangyelu",
    "lat": "36.05752",
    "lng": "103.82269"
  },
  {
    "country": "CN",
    "name": "Xihu",
    "lat": "36.06735",
    "lng": "103.77654"
  },
  {
    "country": "CN",
    "name": "Dongdajie",
    "lat": "37.92686",
    "lng": "102.6343"
  },
  {
    "country": "CN",
    "name": "Renminlu",
    "lat": "36.5512",
    "lng": "104.16952"
  },
  {
    "country": "CN",
    "name": "Xingpinglu",
    "lat": "36.72752",
    "lng": "104.81379"
  },
  {
    "country": "CN",
    "name": "Guangzhoulu",
    "lat": "38.49915",
    "lng": "102.16809"
  },
  {
    "country": "CN",
    "name": "Binhe",
    "lat": "37.51084",
    "lng": "105.18445"
  },
  {
    "country": "CN",
    "name": "Shengli",
    "lat": "37.98425",
    "lng": "106.19659"
  },
  {
    "country": "CN",
    "name": "Beijie",
    "lat": "39.22264",
    "lng": "106.76579"
  },
  {
    "country": "CN",
    "name": "Sangpi",
    "lat": "28.93391",
    "lng": "99.79991"
  },
  {
    "country": "CN",
    "name": "Tantang",
    "lat": "23.13684",
    "lng": "109.41314"
  },
  {
    "country": "CN",
    "name": "Nanchangshan",
    "lat": "37.93049",
    "lng": "120.72908"
  },
  {
    "country": "CN",
    "name": "Tianmen",
    "lat": "30.65888",
    "lng": "113.15369"
  },
  {
    "country": "CN",
    "name": "Changjianglu Jiedao",
    "lat": "35.966",
    "lng": "120.17317"
  },
  {
    "country": "CN",
    "name": "Dongping",
    "lat": "36.499",
    "lng": "117.996"
  },
  {
    "country": "CN",
    "name": "Jianshelu",
    "lat": "34.7534",
    "lng": "113.606"
  },
  {
    "country": "CN",
    "name": "Ganhechen",
    "lat": "33.5582",
    "lng": "114.02"
  },
  {
    "country": "CN",
    "name": "Dizhuang",
    "lat": "33.56452",
    "lng": "114.06965"
  },
  {
    "country": "CN",
    "name": "Gangba",
    "lat": "28.2166",
    "lng": "88.4743"
  },
  {
    "country": "CN",
    "name": "Jibenggang",
    "lat": "29.6583",
    "lng": "91.1276"
  },
  {
    "country": "CN",
    "name": "Alatan'molezhen",
    "lat": "48.66426",
    "lng": "116.81122"
  },
  {
    "country": "CN",
    "name": "Yulong",
    "lat": "33.38324",
    "lng": "120.13058"
  },
  {
    "country": "CN",
    "name": "Nu’erbage",
    "lat": "37.1134",
    "lng": "79.91034"
  },
  {
    "country": "CN",
    "name": "Rizhao",
    "lat": "35.39579",
    "lng": "119.53217"
  },
  {
    "country": "CN",
    "name": "Xicheng",
    "lat": "35.24616",
    "lng": "115.43336"
  },
  {
    "country": "CN",
    "name": "Puyang",
    "lat": "35.76318",
    "lng": "115.01721"
  },
  {
    "country": "CN",
    "name": "Fan Xian Chengguanzhen",
    "lat": "35.85813",
    "lng": "115.50056"
  },
  {
    "country": "CN",
    "name": "Gulou",
    "lat": "36.44414",
    "lng": "115.96418"
  },
  {
    "country": "CN",
    "name": "Gumudi",
    "lat": "43.95486",
    "lng": "87.67309"
  },
  {
    "country": "CN",
    "name": "Huoche Xizhan",
    "lat": "43.87141",
    "lng": "87.42018"
  },
  {
    "country": "CN",
    "name": "Xingfulu",
    "lat": "43.78246",
    "lng": "87.63682"
  },
  {
    "country": "CN",
    "name": "Yangzi Jianglu",
    "lat": "43.77332",
    "lng": "87.58879"
  },
  {
    "country": "CN",
    "name": "Beijinglu",
    "lat": "43.83445",
    "lng": "87.57652"
  },
  {
    "country": "CN",
    "name": "Hekou",
    "lat": "37.88464",
    "lng": "118.52664"
  },
  {
    "country": "CN",
    "name": "Xinhu",
    "lat": "37.44642",
    "lng": "116.29727"
  },
  {
    "country": "CN",
    "name": "Baluntai",
    "lat": "42.66699",
    "lng": "86.32198"
  },
  {
    "country": "CN",
    "name": "Chengguan",
    "lat": "35.30935",
    "lng": "115.11881"
  },
  {
    "country": "CN",
    "name": "Guangrao",
    "lat": "37.25969",
    "lng": "118.46345"
  },
  {
    "country": "CN",
    "name": "Beidaihe",
    "lat": "39.83227",
    "lng": "119.48439"
  },
  {
    "country": "CN",
    "name": "Yanji",
    "lat": "33.9653",
    "lng": "116.451"
  },
  {
    "country": "CN",
    "name": "Changyuan County",
    "lat": "35.2125",
    "lng": "114.735"
  },
  {
    "country": "CN",
    "name": "Xuzhou",
    "lat": "34.20442",
    "lng": "117.28386"
  },
  {
    "country": "CN",
    "name": "Lianyungang",
    "lat": "34.59845",
    "lng": "119.21556"
  },
  {
    "country": "CN",
    "name": "Baoji",
    "lat": "34.36775",
    "lng": "107.23705"
  },
  {
    "country": "CN",
    "name": "Renhuai",
    "lat": "27.7914",
    "lng": "106.40104"
  },
  {
    "country": "CN",
    "name": "Huocheng",
    "lat": "44.05305",
    "lng": "80.87173"
  },
  {
    "country": "CN",
    "name": "Haimen",
    "lat": "28.68074",
    "lng": "121.42408"
  },
  {
    "country": "CN",
    "name": "Longnan",
    "lat": "33.39791",
    "lng": "104.91703"
  },
  {
    "country": "CN",
    "name": "Bayan Nur",
    "lat": "40.74143",
    "lng": "107.38599"
  },
  {
    "country": "CO",
    "name": "Zipaquirá",
    "lat": "5.02208",
    "lng": "-74.00481"
  },
  {
    "country": "CO",
    "name": "Zipacón",
    "lat": "4.75881",
    "lng": "-74.38017"
  },
  {
    "country": "CO",
    "name": "Zetaquira",
    "lat": "5.28215",
    "lng": "-73.16896"
  },
  {
    "country": "CO",
    "name": "Zarzal",
    "lat": "4.39462",
    "lng": "-76.0715"
  },
  {
    "country": "CO",
    "name": "Zaragoza",
    "lat": "7.48971",
    "lng": "-74.86919"
  },
  {
    "country": "CO",
    "name": "Zapatoca",
    "lat": "6.81532",
    "lng": "-73.26768"
  },
  {
    "country": "CO",
    "name": "Zambrano",
    "lat": "9.7474",
    "lng": "-74.81572"
  },
  {
    "country": "CO",
    "name": "Yuto",
    "lat": "5.53168",
    "lng": "-76.63512"
  },
  {
    "country": "CO",
    "name": "Yumbo",
    "lat": "3.58234",
    "lng": "-76.49146"
  },
  {
    "country": "CO",
    "name": "Yotoco",
    "lat": "3.86048",
    "lng": "-76.38364"
  },
  {
    "country": "CO",
    "name": "Yopal",
    "lat": "5.33775",
    "lng": "-72.39586"
  },
  {
    "country": "CO",
    "name": "Yondó",
    "lat": "7.00621",
    "lng": "-73.90972"
  },
  {
    "country": "CO",
    "name": "Yolombó",
    "lat": "6.59841",
    "lng": "-75.0114"
  },
  {
    "country": "CO",
    "name": "Yarumal",
    "lat": "6.96321",
    "lng": "-75.41738"
  },
  {
    "country": "CO",
    "name": "Yalí",
    "lat": "6.67457",
    "lng": "-74.8343"
  },
  {
    "country": "CO",
    "name": "Yaguará",
    "lat": "2.66355",
    "lng": "-75.51753"
  },
  {
    "country": "CO",
    "name": "Yacuanquer",
    "lat": "1.11577",
    "lng": "-77.40169"
  },
  {
    "country": "CO",
    "name": "Yacopí",
    "lat": "5.45948",
    "lng": "-74.33823"
  },
  {
    "country": "CO",
    "name": "Viterbo",
    "lat": "5.06242",
    "lng": "-75.87159"
  },
  {
    "country": "CO",
    "name": "Vistahermosa",
    "lat": "3.12428",
    "lng": "-73.75156"
  },
  {
    "country": "CO",
    "name": "Viracachá",
    "lat": "5.43637",
    "lng": "-73.29606"
  },
  {
    "country": "CO",
    "name": "Viotá",
    "lat": "4.43713",
    "lng": "-74.52157"
  },
  {
    "country": "CO",
    "name": "Villeta",
    "lat": "5.00886",
    "lng": "-74.47226"
  },
  {
    "country": "CO",
    "name": "Villavieja",
    "lat": "3.22052",
    "lng": "-75.21864"
  },
  {
    "country": "CO",
    "name": "Villavicencio",
    "lat": "4.142",
    "lng": "-73.62664"
  },
  {
    "country": "CO",
    "name": "Villarrica",
    "lat": "3.93502",
    "lng": "-74.60036"
  },
  {
    "country": "CO",
    "name": "Villa Rica",
    "lat": "3.17484",
    "lng": "-76.46197"
  },
  {
    "country": "CO",
    "name": "Villa del Rosario",
    "lat": "7.83389",
    "lng": "-72.47417"
  },
  {
    "country": "CO",
    "name": "Villapinzón",
    "lat": "5.21617",
    "lng": "-73.5949"
  },
  {
    "country": "CO",
    "name": "Villanueva",
    "lat": "10.60768",
    "lng": "-72.97901"
  },
  {
    "country": "CO",
    "name": "Villanueva",
    "lat": "10.44361",
    "lng": "-75.27306"
  },
  {
    "country": "CO",
    "name": "Villanueva",
    "lat": "6.67169",
    "lng": "-73.17421"
  },
  {
    "country": "CO",
    "name": "Villanueva",
    "lat": "5.28333",
    "lng": "-71.96667"
  },
  {
    "country": "CO",
    "name": "Villamaría",
    "lat": "5.04565",
    "lng": "-75.51474"
  },
  {
    "country": "CO",
    "name": "Villahermosa",
    "lat": "5.03067",
    "lng": "-75.11607"
  },
  {
    "country": "CO",
    "name": "Villagómez",
    "lat": "5.27372",
    "lng": "-74.19614"
  },
  {
    "country": "CO",
    "name": "Villagarzón",
    "lat": "1.0375",
    "lng": "-76.62667"
  },
  {
    "country": "CO",
    "name": "Villa de Leyva",
    "lat": "5.63413",
    "lng": "-73.52438"
  },
  {
    "country": "CO",
    "name": "Villa Caro",
    "lat": "7.91427",
    "lng": "-72.97144"
  },
  {
    "country": "CO",
    "name": "Vijes",
    "lat": "3.69934",
    "lng": "-76.4423"
  },
  {
    "country": "CO",
    "name": "Vigía del Fuerte",
    "lat": "6.58933",
    "lng": "-76.89599"
  },
  {
    "country": "CO",
    "name": "La Victoria",
    "lat": "5.52583",
    "lng": "-74.23611"
  },
  {
    "country": "CO",
    "name": "Victoria",
    "lat": "5.31648",
    "lng": "-74.91101"
  },
  {
    "country": "CO",
    "name": "Vianí",
    "lat": "4.87384",
    "lng": "-74.56244"
  },
  {
    "country": "CO",
    "name": "Vetas",
    "lat": "7.30911",
    "lng": "-72.87122"
  },
  {
    "country": "CO",
    "name": "Versalles",
    "lat": "4.57544",
    "lng": "-76.19814"
  },
  {
    "country": "CO",
    "name": "Vergara",
    "lat": "5.11841",
    "lng": "-74.34549"
  },
  {
    "country": "CO",
    "name": "Ventaquemada",
    "lat": "5.36753",
    "lng": "-73.52075"
  },
  {
    "country": "CO",
    "name": "Venecia",
    "lat": "5.96278",
    "lng": "-75.73806"
  },
  {
    "country": "CO",
    "name": "Venecia",
    "lat": "4.08808",
    "lng": "-74.47746"
  },
  {
    "country": "CO",
    "name": "Venadillo",
    "lat": "4.71929",
    "lng": "-74.92918"
  },
  {
    "country": "CO",
    "name": "Vélez",
    "lat": "6.01335",
    "lng": "-73.67352"
  },
  {
    "country": "CO",
    "name": "Valparaíso",
    "lat": "5.615",
    "lng": "-75.62422"
  },
  {
    "country": "CO",
    "name": "Valparaíso",
    "lat": "1.19403",
    "lng": "-75.70746"
  },
  {
    "country": "CO",
    "name": "Valledupar",
    "lat": "10.46314",
    "lng": "-73.25322"
  },
  {
    "country": "CO",
    "name": "Valle de San Juan",
    "lat": "4.19869",
    "lng": "-75.11733"
  },
  {
    "country": "CO",
    "name": "Valle de San José",
    "lat": "6.4475",
    "lng": "-73.14361"
  },
  {
    "country": "CO",
    "name": "Valencia",
    "lat": "8.25801",
    "lng": "-76.14928"
  },
  {
    "country": "CO",
    "name": "Valdivia",
    "lat": "7.29382",
    "lng": "-75.3919"
  },
  {
    "country": "CO",
    "name": "Útica",
    "lat": "5.18727",
    "lng": "-74.48105"
  },
  {
    "country": "CO",
    "name": "Usiacurí",
    "lat": "10.74313",
    "lng": "-74.97604"
  },
  {
    "country": "CO",
    "name": "Urumita",
    "lat": "10.55894",
    "lng": "-73.01232"
  },
  {
    "country": "CO",
    "name": "Urrao",
    "lat": "6.31696",
    "lng": "-76.1342"
  },
  {
    "country": "CO",
    "name": "Uribia",
    "lat": "11.71505",
    "lng": "-72.26592"
  },
  {
    "country": "CO",
    "name": "Uribe",
    "lat": "3.2409",
    "lng": "-74.35497"
  },
  {
    "country": "CO",
    "name": "San José de Uré",
    "lat": "7.78637",
    "lng": "-75.5337"
  },
  {
    "country": "CO",
    "name": "Uramita",
    "lat": "6.89944",
    "lng": "-76.17417"
  },
  {
    "country": "CO",
    "name": "Unguía",
    "lat": "8.04364",
    "lng": "-77.09137"
  },
  {
    "country": "CO",
    "name": "Une",
    "lat": "4.40306",
    "lng": "-74.02528"
  },
  {
    "country": "CO",
    "name": "Úmbita",
    "lat": "5.22041",
    "lng": "-73.45695"
  },
  {
    "country": "CO",
    "name": "Ulloa",
    "lat": "4.70444",
    "lng": "-75.74028"
  },
  {
    "country": "CO",
    "name": "Villa de San Diego de Ubaté",
    "lat": "5.30933",
    "lng": "-73.81575"
  },
  {
    "country": "CO",
    "name": "Ubaque",
    "lat": "4.48667",
    "lng": "-73.93748"
  },
  {
    "country": "CO",
    "name": "Ubalá",
    "lat": "4.74778",
    "lng": "-72.53694"
  },
  {
    "country": "CO",
    "name": "Tutazá",
    "lat": "6.03228",
    "lng": "-72.85639"
  },
  {
    "country": "CO",
    "name": "Tuta",
    "lat": "5.68966",
    "lng": "-73.22779"
  },
  {
    "country": "CO",
    "name": "Turmequé",
    "lat": "5.3236",
    "lng": "-73.49067"
  },
  {
    "country": "CO",
    "name": "Turbo",
    "lat": "8.09263",
    "lng": "-76.72822"
  },
  {
    "country": "CO",
    "name": "Turbaná",
    "lat": "10.27169",
    "lng": "-75.44222"
  },
  {
    "country": "CO",
    "name": "Turbaco",
    "lat": "10.32944",
    "lng": "-75.41137"
  },
  {
    "country": "CO",
    "name": "Túquerres",
    "lat": "1.08647",
    "lng": "-77.61858"
  },
  {
    "country": "CO",
    "name": "Tununguá",
    "lat": "5.72967",
    "lng": "-73.94137"
  },
  {
    "country": "CO",
    "name": "Tunja",
    "lat": "5.53528",
    "lng": "-73.36778"
  },
  {
    "country": "CO",
    "name": "Tumaco",
    "lat": "1.79112",
    "lng": "-78.79275"
  },
  {
    "country": "CO",
    "name": "Tuluá",
    "lat": "4.08466",
    "lng": "-76.19536"
  },
  {
    "country": "CO",
    "name": "Tuchín",
    "lat": "9.18662",
    "lng": "-75.55473"
  },
  {
    "country": "CO",
    "name": "Tubará",
    "lat": "10.87562",
    "lng": "-74.97873"
  },
  {
    "country": "CO",
    "name": "Trujillo",
    "lat": "4.21217",
    "lng": "-76.31945"
  },
  {
    "country": "CO",
    "name": "Trinidad",
    "lat": "5.40849",
    "lng": "-71.66196"
  },
  {
    "country": "CO",
    "name": "Tres Esquinas",
    "lat": "3.86512",
    "lng": "-74.70906"
  },
  {
    "country": "CO",
    "name": "Totoró",
    "lat": "2.51111",
    "lng": "-76.40178"
  },
  {
    "country": "CO",
    "name": "Tota",
    "lat": "5.55833",
    "lng": "-72.98757"
  },
  {
    "country": "CO",
    "name": "Toro",
    "lat": "4.61167",
    "lng": "-76.08139"
  },
  {
    "country": "CO",
    "name": "Toribío",
    "lat": "2.95481",
    "lng": "-76.26839"
  },
  {
    "country": "CO",
    "name": "Topaipí",
    "lat": "5.33457",
    "lng": "-74.30292"
  },
  {
    "country": "CO",
    "name": "Tópaga",
    "lat": "5.75979",
    "lng": "-72.82583"
  },
  {
    "country": "CO",
    "name": "Tona",
    "lat": "7.20221",
    "lng": "-72.96502"
  },
  {
    "country": "CO",
    "name": "Tolú Viejo",
    "lat": "9.45082",
    "lng": "-75.43864"
  },
  {
    "country": "CO",
    "name": "Santiago de Tolú",
    "lat": "9.52392",
    "lng": "-75.58139"
  },
  {
    "country": "CO",
    "name": "Toledo",
    "lat": "7.30984",
    "lng": "-72.48295"
  },
  {
    "country": "CO",
    "name": "Toledo",
    "lat": "7.01306",
    "lng": "-75.69528"
  },
  {
    "country": "CO",
    "name": "Togüí",
    "lat": "5.93462",
    "lng": "-73.51297"
  },
  {
    "country": "CO",
    "name": "Tocancipá",
    "lat": "4.96531",
    "lng": "-73.91301"
  },
  {
    "country": "CO",
    "name": "Tocaima",
    "lat": "4.4582",
    "lng": "-74.63434"
  },
  {
    "country": "CO",
    "name": "Toca",
    "lat": "5.56393",
    "lng": "-73.18398"
  },
  {
    "country": "CO",
    "name": "Titiribí",
    "lat": "6.06276",
    "lng": "-75.7937"
  },
  {
    "country": "CO",
    "name": "Tipacoque",
    "lat": "6.42031",
    "lng": "-72.69184"
  },
  {
    "country": "CO",
    "name": "Tinjacá",
    "lat": "5.57916",
    "lng": "-73.64486"
  },
  {
    "country": "CO",
    "name": "Timbiquí",
    "lat": "2.7717",
    "lng": "-77.66536"
  },
  {
    "country": "CO",
    "name": "Timbío",
    "lat": "2.35017",
    "lng": "-76.68341"
  },
  {
    "country": "CO",
    "name": "Timaná",
    "lat": "1.97136",
    "lng": "-75.93123"
  },
  {
    "country": "CO",
    "name": "Tierralta",
    "lat": "8.17361",
    "lng": "-76.05917"
  },
  {
    "country": "CO",
    "name": "Tibú",
    "lat": "8.63895",
    "lng": "-72.73583"
  },
  {
    "country": "CO",
    "name": "Tibirita",
    "lat": "5.05227",
    "lng": "-73.50459"
  },
  {
    "country": "CO",
    "name": "Tibasosa",
    "lat": "5.75",
    "lng": "-73"
  },
  {
    "country": "CO",
    "name": "Tibaná",
    "lat": "5.31728",
    "lng": "-73.39655"
  },
  {
    "country": "CO",
    "name": "Tibacuy",
    "lat": "4.35",
    "lng": "-74.45179"
  },
  {
    "country": "CO",
    "name": "Tesalia",
    "lat": "2.48587",
    "lng": "-75.72921"
  },
  {
    "country": "CO",
    "name": "Teruel",
    "lat": "2.74193",
    "lng": "-75.56738"
  },
  {
    "country": "CO",
    "name": "Teorama",
    "lat": "8.43633",
    "lng": "-73.28981"
  },
  {
    "country": "CO",
    "name": "Tenza",
    "lat": "5.07664",
    "lng": "-73.42077"
  },
  {
    "country": "CO",
    "name": "Tenjo",
    "lat": "4.8727",
    "lng": "-74.14435"
  },
  {
    "country": "CO",
    "name": "Tenerife",
    "lat": "9.90093",
    "lng": "-74.85985"
  },
  {
    "country": "CO",
    "name": "Tena",
    "lat": "4.66001",
    "lng": "-74.39258"
  },
  {
    "country": "CO",
    "name": "Tello",
    "lat": "3.06694",
    "lng": "-75.13778"
  },
  {
    "country": "CO",
    "name": "Tausa",
    "lat": "5.19903",
    "lng": "-73.89128"
  },
  {
    "country": "CO",
    "name": "Tauramena",
    "lat": "5.01789",
    "lng": "-72.74675"
  },
  {
    "country": "CO",
    "name": "Tasco",
    "lat": "5.91044",
    "lng": "-72.78001"
  },
  {
    "country": "CO",
    "name": "Tarso",
    "lat": "5.86467",
    "lng": "-75.82192"
  },
  {
    "country": "CO",
    "name": "Tarqui",
    "lat": "2.11248",
    "lng": "-75.82419"
  },
  {
    "country": "CO",
    "name": "Tarazá",
    "lat": "7.58358",
    "lng": "-75.40068"
  },
  {
    "country": "CO",
    "name": "Tarapacá",
    "lat": "-2.892",
    "lng": "-69.742"
  },
  {
    "country": "CO",
    "name": "Tangua",
    "lat": "1.09473",
    "lng": "-77.39482"
  },
  {
    "country": "CO",
    "name": "Taminango",
    "lat": "1.57032",
    "lng": "-77.28043"
  },
  {
    "country": "CO",
    "name": "Támesis",
    "lat": "5.66462",
    "lng": "-75.71339"
  },
  {
    "country": "CO",
    "name": "Tame",
    "lat": "6.46065",
    "lng": "-71.73618"
  },
  {
    "country": "CO",
    "name": "Támara",
    "lat": "5.82998",
    "lng": "-72.16286"
  },
  {
    "country": "CO",
    "name": "Tamalameque",
    "lat": "8.85221",
    "lng": "-73.81229"
  },
  {
    "country": "CO",
    "name": "Talaigua Viejo",
    "lat": "9.31206",
    "lng": "-74.58544"
  },
  {
    "country": "CO",
    "name": "Talaigua Nuevo",
    "lat": "9.30347",
    "lng": "-74.56477"
  },
  {
    "country": "CO",
    "name": "Tadó",
    "lat": "5.26598",
    "lng": "-76.56487"
  },
  {
    "country": "CO",
    "name": "Tabio",
    "lat": "4.91726",
    "lng": "-74.09364"
  },
  {
    "country": "CO",
    "name": "Sutatenza",
    "lat": "5.02311",
    "lng": "-73.4523"
  },
  {
    "country": "CO",
    "name": "Sutatausa",
    "lat": "5.24779",
    "lng": "-73.85238"
  },
  {
    "country": "CO",
    "name": "Sutamarchán",
    "lat": "5.61538",
    "lng": "-73.61701"
  },
  {
    "country": "CO",
    "name": "Susacón",
    "lat": "6.22978",
    "lng": "-72.6901"
  },
  {
    "country": "CO",
    "name": "Susa",
    "lat": "5.4519",
    "lng": "-73.81436"
  },
  {
    "country": "CO",
    "name": "Suratá",
    "lat": "7.36633",
    "lng": "-72.98361"
  },
  {
    "country": "CO",
    "name": "Supía",
    "lat": "5.45303",
    "lng": "-75.65072"
  },
  {
    "country": "CO",
    "name": "Supatá",
    "lat": "5.06097",
    "lng": "-74.23721"
  },
  {
    "country": "CO",
    "name": "Suesca",
    "lat": "5.10289",
    "lng": "-73.79845"
  },
  {
    "country": "CO",
    "name": "Sucre",
    "lat": "8.81136",
    "lng": "-74.72084"
  },
  {
    "country": "CO",
    "name": "Sucre",
    "lat": "5.91833",
    "lng": "-73.79109"
  },
  {
    "country": "CO",
    "name": "Sucre",
    "lat": "2.03805",
    "lng": "-76.92446"
  },
  {
    "country": "CO",
    "name": "Subachoque",
    "lat": "4.92614",
    "lng": "-74.17299"
  },
  {
    "country": "CO",
    "name": "Suaza",
    "lat": "1.97611",
    "lng": "-75.79454"
  },
  {
    "country": "CO",
    "name": "Suárez",
    "lat": "4.04906",
    "lng": "-74.83198"
  },
  {
    "country": "CO",
    "name": "Suárez",
    "lat": "2.95395",
    "lng": "-76.69644"
  },
  {
    "country": "CO",
    "name": "Suan",
    "lat": "10.33347",
    "lng": "-74.88016"
  },
  {
    "country": "CO",
    "name": "Suaita",
    "lat": "6.1014",
    "lng": "-73.44041"
  },
  {
    "country": "CO",
    "name": "Sotomayor",
    "lat": "1.49474",
    "lng": "-77.52136"
  },
  {
    "country": "CO",
    "name": "Sotaquirá",
    "lat": "5.76483",
    "lng": "-73.24758"
  },
  {
    "country": "CO",
    "name": "Soracá",
    "lat": "5.50055",
    "lng": "-73.33299"
  },
  {
    "country": "CO",
    "name": "Sora",
    "lat": "5.56514",
    "lng": "-73.45017"
  },
  {
    "country": "CO",
    "name": "Sopó",
    "lat": "4.9075",
    "lng": "-73.9384"
  },
  {
    "country": "CO",
    "name": "Soplaviento",
    "lat": "10.39306",
    "lng": "-75.14083"
  },
  {
    "country": "CO",
    "name": "Sonsón",
    "lat": "5.71062",
    "lng": "-75.31069"
  },
  {
    "country": "CO",
    "name": "Somondoco",
    "lat": "4.98495",
    "lng": "-73.43238"
  },
  {
    "country": "CO",
    "name": "Soledad",
    "lat": "10.91843",
    "lng": "-74.76459"
  },
  {
    "country": "CO",
    "name": "Solano",
    "lat": "0.69937",
    "lng": "-75.25353"
  },
  {
    "country": "CO",
    "name": "Sogamoso",
    "lat": "5.71434",
    "lng": "-72.93391"
  },
  {
    "country": "CO",
    "name": "Socotá",
    "lat": "6.04028",
    "lng": "-72.63509"
  },
  {
    "country": "CO",
    "name": "Socorro",
    "lat": "6.46838",
    "lng": "-73.26022"
  },
  {
    "country": "CO",
    "name": "Socha Viejo",
    "lat": "5.9817",
    "lng": "-72.71503"
  },
  {
    "country": "CO",
    "name": "Soatá",
    "lat": "6.33369",
    "lng": "-72.68283"
  },
  {
    "country": "CO",
    "name": "Soacha",
    "lat": "4.57937",
    "lng": "-74.21682"
  },
  {
    "country": "CO",
    "name": "Sitionuevo",
    "lat": "10.77737",
    "lng": "-74.72049"
  },
  {
    "country": "CO",
    "name": "Sipí",
    "lat": "4.65374",
    "lng": "-76.64442"
  },
  {
    "country": "CO",
    "name": "Sincelejo",
    "lat": "9.30472",
    "lng": "-75.39778"
  },
  {
    "country": "CO",
    "name": "San Luis de Sincé",
    "lat": "9.24391",
    "lng": "-75.14675"
  },
  {
    "country": "CO",
    "name": "Simití",
    "lat": "7.9579",
    "lng": "-73.9436"
  },
  {
    "country": "CO",
    "name": "Simijaca",
    "lat": "5.50291",
    "lng": "-73.85227"
  },
  {
    "country": "CO",
    "name": "Simacota",
    "lat": "6.4429",
    "lng": "-73.33688"
  },
  {
    "country": "CO",
    "name": "Silvia",
    "lat": "2.61557",
    "lng": "-76.38261"
  },
  {
    "country": "CO",
    "name": "Silvania",
    "lat": "4.40367",
    "lng": "-74.3867"
  },
  {
    "country": "CO",
    "name": "Silos",
    "lat": "7.20524",
    "lng": "-72.75639"
  },
  {
    "country": "CO",
    "name": "Sibundoy",
    "lat": "1.20296",
    "lng": "-76.92275"
  },
  {
    "country": "CO",
    "name": "Sibaté",
    "lat": "4.49154",
    "lng": "-74.25957"
  },
  {
    "country": "CO",
    "name": "Siachoque",
    "lat": "5.51238",
    "lng": "-73.24436"
  },
  {
    "country": "CO",
    "name": "Prado-Sevilla",
    "lat": "10.76343",
    "lng": "-74.13916"
  },
  {
    "country": "CO",
    "name": "Sevilla",
    "lat": "4.26425",
    "lng": "-75.93085"
  },
  {
    "country": "CO",
    "name": "Sesquilé",
    "lat": "5.04463",
    "lng": "-73.79724"
  },
  {
    "country": "CO",
    "name": "Segovia",
    "lat": "7.07993",
    "lng": "-74.6989"
  },
  {
    "country": "CO",
    "name": "Sativasur",
    "lat": "6.08959",
    "lng": "-72.72432"
  },
  {
    "country": "CO",
    "name": "Sativanorte",
    "lat": "6.13156",
    "lng": "-72.70895"
  },
  {
    "country": "CO",
    "name": "Sasaima",
    "lat": "4.96705",
    "lng": "-74.43512"
  },
  {
    "country": "CO",
    "name": "Sardinata",
    "lat": "8.08289",
    "lng": "-72.80071"
  },
  {
    "country": "CO",
    "name": "Saravena",
    "lat": "6.96319",
    "lng": "-71.8823"
  },
  {
    "country": "CO",
    "name": "Sapuyes",
    "lat": "1.03728",
    "lng": "-77.62094"
  },
  {
    "country": "CO",
    "name": "San Zenón",
    "lat": "9.24217",
    "lng": "-74.50037"
  },
  {
    "country": "CO",
    "name": "San Vicente del Caguán",
    "lat": "2.12172",
    "lng": "-74.76614"
  },
  {
    "country": "CO",
    "name": "San Vicente de Chucurí",
    "lat": "6.881",
    "lng": "-73.40977"
  },
  {
    "country": "CO",
    "name": "San Vicente",
    "lat": "6.28535",
    "lng": "-75.33385"
  },
  {
    "country": "CO",
    "name": "Santuario",
    "lat": "6.13833",
    "lng": "-75.26417"
  },
  {
    "country": "CO",
    "name": "Santuario",
    "lat": "5.07415",
    "lng": "-75.96423"
  },
  {
    "country": "CO",
    "name": "Santo Tomás",
    "lat": "10.75773",
    "lng": "-74.75451"
  },
  {
    "country": "CO",
    "name": "Santo Domingo",
    "lat": "6.47282",
    "lng": "-75.16547"
  },
  {
    "country": "CO",
    "name": "Santiago",
    "lat": "7.86432",
    "lng": "-72.7162"
  },
  {
    "country": "CO",
    "name": "Santiago",
    "lat": "1.14844",
    "lng": "-77.0045"
  },
  {
    "country": "CO",
    "name": "Santa Sofía",
    "lat": "5.70908",
    "lng": "-73.60404"
  },
  {
    "country": "CO",
    "name": "Santa Rosalia",
    "lat": "5.13356",
    "lng": "-70.86233"
  },
  {
    "country": "CO",
    "name": "Santa Rosa de Viterbo",
    "lat": "5.87401",
    "lng": "-72.98217"
  },
  {
    "country": "CO",
    "name": "Santa Rosa de Osos",
    "lat": "6.64738",
    "lng": "-75.46031"
  },
  {
    "country": "CO",
    "name": "Santa Rosa de Cabal",
    "lat": "4.86806",
    "lng": "-75.62139"
  },
  {
    "country": "CO",
    "name": "Santa Rosa",
    "lat": "10.44472",
    "lng": "-75.36972"
  },
  {
    "country": "CO",
    "name": "Santa Rosa",
    "lat": "1.70267",
    "lng": "-76.57389"
  },
  {
    "country": "CO",
    "name": "Santa Rita",
    "lat": "5.18333",
    "lng": "-76.48333"
  },
  {
    "country": "CO",
    "name": "Santander de Quilichao",
    "lat": "3.00945",
    "lng": "-76.48494"
  },
  {
    "country": "CO",
    "name": "Santana",
    "lat": "6.0575",
    "lng": "-73.48112"
  },
  {
    "country": "CO",
    "name": "Santa Marta",
    "lat": "11.24079",
    "lng": "-74.19904"
  },
  {
    "country": "CO",
    "name": "Santa María",
    "lat": "4.86048",
    "lng": "-73.26234"
  },
  {
    "country": "CO",
    "name": "Santa María",
    "lat": "2.95",
    "lng": "-75.65"
  },
  {
    "country": "CO",
    "name": "Santa Lucía",
    "lat": "10.3242",
    "lng": "-74.96017"
  },
  {
    "country": "CO",
    "name": "Santa Isabel",
    "lat": "13.38166",
    "lng": "-81.36891"
  },
  {
    "country": "CO",
    "name": "Santa Isabel",
    "lat": "4.71418",
    "lng": "-75.09799"
  },
  {
    "country": "CO",
    "name": "Santa Catalina",
    "lat": "10.60361",
    "lng": "-75.28824"
  },
  {
    "country": "CO",
    "name": "Santa Bárbara",
    "lat": "6.99022",
    "lng": "-72.907"
  },
  {
    "country": "CO",
    "name": "Santa Bárbara",
    "lat": "5.87458",
    "lng": "-75.56706"
  },
  {
    "country": "CO",
    "name": "Santa Ana",
    "lat": "9.32125",
    "lng": "-74.56848"
  },
  {
    "country": "CO",
    "name": "San Sebastián de Buenavista",
    "lat": "9.23778",
    "lng": "-74.35166"
  },
  {
    "country": "CO",
    "name": "San Sebastián",
    "lat": "1.83861",
    "lng": "-76.77189"
  },
  {
    "country": "CO",
    "name": "San Roque",
    "lat": "6.48511",
    "lng": "-75.0196"
  },
  {
    "country": "CO",
    "name": "San Rafael",
    "lat": "6.29436",
    "lng": "-75.02589"
  },
  {
    "country": "CO",
    "name": "San Pelayo",
    "lat": "8.95833",
    "lng": "-75.83627"
  },
  {
    "country": "CO",
    "name": "San Pedro de Urabá",
    "lat": "8.27515",
    "lng": "-76.37641"
  },
  {
    "country": "CO",
    "name": "San Pedro",
    "lat": "9.3956",
    "lng": "-75.06476"
  },
  {
    "country": "CO",
    "name": "San Pedro",
    "lat": "6.46135",
    "lng": "-75.55778"
  },
  {
    "country": "CO",
    "name": "San Pedro",
    "lat": "3.99445",
    "lng": "-76.22885"
  },
  {
    "country": "CO",
    "name": "San Pablo de Borbur",
    "lat": "5.65138",
    "lng": "-74.06991"
  },
  {
    "country": "CO",
    "name": "San Pablo",
    "lat": "10.05154",
    "lng": "-75.26775"
  },
  {
    "country": "CO",
    "name": "San Pablo",
    "lat": "7.47754",
    "lng": "-73.92255"
  },
  {
    "country": "CO",
    "name": "San Pablo",
    "lat": "1.6725",
    "lng": "-77.01389"
  },
  {
    "country": "CO",
    "name": "San Onofre",
    "lat": "9.73586",
    "lng": "-75.52626"
  },
  {
    "country": "CO",
    "name": "San Miguel de Sema",
    "lat": "5.51847",
    "lng": "-73.72238"
  },
  {
    "country": "CO",
    "name": "San Miguel",
    "lat": "6.57583",
    "lng": "-72.64591"
  },
  {
    "country": "CO",
    "name": "La Dorada",
    "lat": "0.34314",
    "lng": "-76.91124"
  },
  {
    "country": "CO",
    "name": "San Mateo",
    "lat": "6.40195",
    "lng": "-72.55314"
  },
  {
    "country": "CO",
    "name": "San Martín",
    "lat": "3.69637",
    "lng": "-73.69957"
  },
  {
    "country": "CO",
    "name": "San Marcos",
    "lat": "8.65972",
    "lng": "-75.12809"
  },
  {
    "country": "CO",
    "name": "San Luis de Palenque",
    "lat": "5.42139",
    "lng": "-71.73167"
  },
  {
    "country": "CO",
    "name": "San Luis de Gaceno",
    "lat": "4.82052",
    "lng": "-73.16851"
  },
  {
    "country": "CO",
    "name": "Cubarral",
    "lat": "3.79536",
    "lng": "-73.84063"
  },
  {
    "country": "CO",
    "name": "San Luis",
    "lat": "6.04343",
    "lng": "-74.99366"
  },
  {
    "country": "CO",
    "name": "San Luis",
    "lat": "4.13258",
    "lng": "-75.09499"
  },
  {
    "country": "CO",
    "name": "San Lorenzo",
    "lat": "1.50294",
    "lng": "-77.21537"
  },
  {
    "country": "CO",
    "name": "San Juan Nepomuceno",
    "lat": "9.95157",
    "lng": "-75.08198"
  },
  {
    "country": "CO",
    "name": "San Juanito",
    "lat": "4.46103",
    "lng": "-73.68048"
  },
  {
    "country": "CO",
    "name": "San Juan de Urabá",
    "lat": "8.75924",
    "lng": "-76.52969"
  },
  {
    "country": "CO",
    "name": "San Juan de Rioseco",
    "lat": "4.84778",
    "lng": "-74.62148"
  },
  {
    "country": "CO",
    "name": "San Juan del Cesar",
    "lat": "10.77107",
    "lng": "-73.00314"
  },
  {
    "country": "CO",
    "name": "San Juan de Betulia",
    "lat": "9.27345",
    "lng": "-75.24103"
  },
  {
    "country": "CO",
    "name": "San Juan de Arama",
    "lat": "3.36985",
    "lng": "-73.87267"
  },
  {
    "country": "CO",
    "name": "San José de Pare",
    "lat": "6.01746",
    "lng": "-73.54703"
  },
  {
    "country": "CO",
    "name": "San José de Miranda",
    "lat": "6.6587",
    "lng": "-72.73344"
  },
  {
    "country": "CO",
    "name": "San José del Palmar",
    "lat": "4.89616",
    "lng": "-76.23422"
  },
  {
    "country": "CO",
    "name": "San José de la Montaña",
    "lat": "6.85028",
    "lng": "-75.68333"
  },
  {
    "country": "CO",
    "name": "Isnos",
    "lat": "1.92874",
    "lng": "-76.21104"
  },
  {
    "country": "CO",
    "name": "San José",
    "lat": "5.08221",
    "lng": "-75.79107"
  },
  {
    "country": "CO",
    "name": "San José",
    "lat": "1.69659",
    "lng": "-78.24482"
  },
  {
    "country": "CO",
    "name": "San José",
    "lat": "1.47446",
    "lng": "-77.08144"
  },
  {
    "country": "CO",
    "name": "San Joaquín",
    "lat": "6.43004",
    "lng": "-72.86768"
  },
  {
    "country": "CO",
    "name": "San Jerónimo",
    "lat": "6.44344",
    "lng": "-75.72815"
  },
  {
    "country": "CO",
    "name": "San Jacinto del Cauca",
    "lat": "8.24976",
    "lng": "-74.72079"
  },
  {
    "country": "CO",
    "name": "San Jacinto",
    "lat": "9.82767",
    "lng": "-75.1217"
  },
  {
    "country": "CO",
    "name": "San Gil",
    "lat": "6.55952",
    "lng": "-73.13637"
  },
  {
    "country": "CO",
    "name": "San Francisco",
    "lat": "6.11667",
    "lng": "-75.98333"
  },
  {
    "country": "CO",
    "name": "San Francisco",
    "lat": "5.96426",
    "lng": "-75.10165"
  },
  {
    "country": "CO",
    "name": "San Francisco",
    "lat": "4.97876",
    "lng": "-74.2927"
  },
  {
    "country": "CO",
    "name": "San Francisco",
    "lat": "1.17644",
    "lng": "-76.87838"
  },
  {
    "country": "CO",
    "name": "San Fernando",
    "lat": "9.27972",
    "lng": "-74.53389"
  },
  {
    "country": "CO",
    "name": "San Estanislao",
    "lat": "10.39833",
    "lng": "-75.15111"
  },
  {
    "country": "CO",
    "name": "San Eduardo",
    "lat": "5.22396",
    "lng": "-73.07696"
  },
  {
    "country": "CO",
    "name": "Sandoná",
    "lat": "1.28626",
    "lng": "-77.46921"
  },
  {
    "country": "CO",
    "name": "San Diego",
    "lat": "10.33623",
    "lng": "-73.18203"
  },
  {
    "country": "CO",
    "name": "San Cristóbal",
    "lat": "10.39523",
    "lng": "-75.06562"
  },
  {
    "country": "CO",
    "name": "San Cristóbal",
    "lat": "9.87809",
    "lng": "-75.25248"
  },
  {
    "country": "CO",
    "name": "San Cayetano",
    "lat": "7.87707",
    "lng": "-72.6243"
  },
  {
    "country": "CO",
    "name": "San Carlos de Guaroa",
    "lat": "3.71161",
    "lng": "-73.24344"
  },
  {
    "country": "CO",
    "name": "San Carlos",
    "lat": "8.79577",
    "lng": "-75.69947"
  },
  {
    "country": "CO",
    "name": "San Carlos",
    "lat": "7.79177",
    "lng": "-74.77316"
  },
  {
    "country": "CO",
    "name": "San Carlos",
    "lat": "6.18789",
    "lng": "-74.99315"
  },
  {
    "country": "CO",
    "name": "San Calixto",
    "lat": "8.4021",
    "lng": "-73.20737"
  },
  {
    "country": "CO",
    "name": "San Bernardo del Viento",
    "lat": "9.3533",
    "lng": "-75.95244"
  },
  {
    "country": "CO",
    "name": "San Bernardo",
    "lat": "4.17864",
    "lng": "-74.42311"
  },
  {
    "country": "CO",
    "name": "San Bernardo",
    "lat": "1.51525",
    "lng": "-77.04679"
  },
  {
    "country": "CO",
    "name": "San Benito Abad",
    "lat": "8.92901",
    "lng": "-75.02709"
  },
  {
    "country": "CO",
    "name": "San Benito",
    "lat": "6.13269",
    "lng": "-73.49065"
  },
  {
    "country": "CO",
    "name": "San Antonio del Tequendama",
    "lat": "4.61617",
    "lng": "-74.352"
  },
  {
    "country": "CO",
    "name": "San Antonio",
    "lat": "9.93303",
    "lng": "-74.69346"
  },
  {
    "country": "CO",
    "name": "San Antonio",
    "lat": "3.91423",
    "lng": "-75.48009"
  },
  {
    "country": "CO",
    "name": "San Antero",
    "lat": "9.3741",
    "lng": "-75.75891"
  },
  {
    "country": "CO",
    "name": "San Ángel",
    "lat": "10.03047",
    "lng": "-74.21482"
  },
  {
    "country": "CO",
    "name": "San Andrés de Sotavento",
    "lat": "9.14475",
    "lng": "-75.50877"
  },
  {
    "country": "CO",
    "name": "San Andrés",
    "lat": "12.58317",
    "lng": "-81.70636"
  },
  {
    "country": "CO",
    "name": "San Andrés",
    "lat": "6.81148",
    "lng": "-72.84929"
  },
  {
    "country": "CO",
    "name": "San Alberto",
    "lat": "7.76107",
    "lng": "-73.3922"
  },
  {
    "country": "CO",
    "name": "San Agustín",
    "lat": "1.87884",
    "lng": "-76.26722"
  },
  {
    "country": "CO",
    "name": "Sampués",
    "lat": "9.18361",
    "lng": "-75.38167"
  },
  {
    "country": "CO",
    "name": "Samaniego",
    "lat": "1.33849",
    "lng": "-77.5957"
  },
  {
    "country": "CO",
    "name": "Samacá",
    "lat": "5.49273",
    "lng": "-73.48537"
  },
  {
    "country": "CO",
    "name": "Salgar",
    "lat": "5.96502",
    "lng": "-75.96541"
  },
  {
    "country": "CO",
    "name": "Salento",
    "lat": "4.6375",
    "lng": "-75.57028"
  },
  {
    "country": "CO",
    "name": "Saldaña",
    "lat": "3.92923",
    "lng": "-75.01517"
  },
  {
    "country": "CO",
    "name": "Salamina",
    "lat": "10.49027",
    "lng": "-74.79463"
  },
  {
    "country": "CO",
    "name": "Salamina",
    "lat": "5.40733",
    "lng": "-75.48749"
  },
  {
    "country": "CO",
    "name": "Saladoblanco",
    "lat": "1.99244",
    "lng": "-76.04335"
  },
  {
    "country": "CO",
    "name": "Sahagún",
    "lat": "8.94617",
    "lng": "-75.44275"
  },
  {
    "country": "CO",
    "name": "Sáchica",
    "lat": "5.58453",
    "lng": "-73.54184"
  },
  {
    "country": "CO",
    "name": "Sácama",
    "lat": "6.09908",
    "lng": "-72.2488"
  },
  {
    "country": "CO",
    "name": "Saboyá",
    "lat": "5.69636",
    "lng": "-73.76932"
  },
  {
    "country": "CO",
    "name": "Sabaneta",
    "lat": "6.15153",
    "lng": "-75.61657"
  },
  {
    "country": "CO",
    "name": "Sabanalarga",
    "lat": "10.63072",
    "lng": "-74.92214"
  },
  {
    "country": "CO",
    "name": "Sabanalarga",
    "lat": "6.84893",
    "lng": "-75.81711"
  },
  {
    "country": "CO",
    "name": "Sabanagrande",
    "lat": "10.79115",
    "lng": "-74.76059"
  },
  {
    "country": "CO",
    "name": "Sabana de Torres",
    "lat": "7.3915",
    "lng": "-73.49574"
  },
  {
    "country": "CO",
    "name": "Rovira",
    "lat": "4.23922",
    "lng": "-75.23996"
  },
  {
    "country": "CO",
    "name": "Rosas",
    "lat": "2.26093",
    "lng": "-76.73986"
  },
  {
    "country": "CO",
    "name": "Rondón",
    "lat": "5.35642",
    "lng": "-73.20918"
  },
  {
    "country": "CO",
    "name": "Roncesvalles",
    "lat": "4.0108",
    "lng": "-75.60493"
  },
  {
    "country": "CO",
    "name": "Roldanillo",
    "lat": "4.41256",
    "lng": "-76.15457"
  },
  {
    "country": "CO",
    "name": "Rivera",
    "lat": "2.77717",
    "lng": "-75.25642"
  },
  {
    "country": "CO",
    "name": "Risaralda",
    "lat": "5.16647",
    "lng": "-75.76595"
  },
  {
    "country": "CO",
    "name": "Río Viejo",
    "lat": "8.5874",
    "lng": "-73.83901"
  },
  {
    "country": "CO",
    "name": "Riosucio",
    "lat": "7.44348",
    "lng": "-77.11964"
  },
  {
    "country": "CO",
    "name": "Riosucio",
    "lat": "5.42164",
    "lng": "-75.70318"
  },
  {
    "country": "CO",
    "name": "Rionegro",
    "lat": "6.15515",
    "lng": "-75.37371"
  },
  {
    "country": "CO",
    "name": "Riohacha",
    "lat": "11.54444",
    "lng": "-72.90722"
  },
  {
    "country": "CO",
    "name": "Riofrío",
    "lat": "4.1571",
    "lng": "-76.28852"
  },
  {
    "country": "CO",
    "name": "Río de Oro",
    "lat": "8.2919",
    "lng": "-73.38485"
  },
  {
    "country": "CO",
    "name": "Rioblanco",
    "lat": "3.52973",
    "lng": "-75.64525"
  },
  {
    "country": "CO",
    "name": "Ricaurte",
    "lat": "4.28075",
    "lng": "-74.76469"
  },
  {
    "country": "CO",
    "name": "Ricaurte",
    "lat": "1.21474",
    "lng": "-77.99801"
  },
  {
    "country": "CO",
    "name": "Retiro",
    "lat": "6.05861",
    "lng": "-75.50306"
  },
  {
    "country": "CO",
    "name": "Restrepo",
    "lat": "4.25833",
    "lng": "-73.56142"
  },
  {
    "country": "CO",
    "name": "Restrepo",
    "lat": "3.82203",
    "lng": "-76.52242"
  },
  {
    "country": "CO",
    "name": "Repelón",
    "lat": "10.4952",
    "lng": "-75.12448"
  },
  {
    "country": "CO",
    "name": "Remolino",
    "lat": "10.70199",
    "lng": "-74.71602"
  },
  {
    "country": "CO",
    "name": "Remedios",
    "lat": "7.02835",
    "lng": "-74.69379"
  },
  {
    "country": "CO",
    "name": "Regidor",
    "lat": "8.66565",
    "lng": "-73.82151"
  },
  {
    "country": "CO",
    "name": "Recetor",
    "lat": "5.22947",
    "lng": "-72.76099"
  },
  {
    "country": "CO",
    "name": "Ráquira",
    "lat": "5.53793",
    "lng": "-73.63201"
  },
  {
    "country": "CO",
    "name": "Ramiriquí",
    "lat": "5.4002",
    "lng": "-73.33544"
  },
  {
    "country": "CO",
    "name": "Ragonvalia",
    "lat": "7.57749",
    "lng": "-72.47574"
  },
  {
    "country": "CO",
    "name": "Apulo",
    "lat": "4.51952",
    "lng": "-74.59293"
  },
  {
    "country": "CO",
    "name": "Quipile",
    "lat": "4.74517",
    "lng": "-74.53378"
  },
  {
    "country": "CO",
    "name": "Quinchía",
    "lat": "5.33957",
    "lng": "-75.73018"
  },
  {
    "country": "CO",
    "name": "Quimbaya",
    "lat": "4.62306",
    "lng": "-75.76278"
  },
  {
    "country": "CO",
    "name": "Quibdó",
    "lat": "5.69188",
    "lng": "-76.65835"
  },
  {
    "country": "CO",
    "name": "Quetame",
    "lat": "4.33234",
    "lng": "-73.86141"
  },
  {
    "country": "CO",
    "name": "Quebradanegra",
    "lat": "5.11737",
    "lng": "-74.47944"
  },
  {
    "country": "CO",
    "name": "Purísima de la Concepción",
    "lat": "9.23657",
    "lng": "-75.72191"
  },
  {
    "country": "CO",
    "name": "Purificación",
    "lat": "3.85871",
    "lng": "-74.93129"
  },
  {
    "country": "CO",
    "name": "Pupiales",
    "lat": "0.87136",
    "lng": "-77.64027"
  },
  {
    "country": "CO",
    "name": "Punta de Piedras",
    "lat": "10.16863",
    "lng": "-74.71682"
  },
  {
    "country": "CO",
    "name": "Pulí",
    "lat": "4.68116",
    "lng": "-74.71406"
  },
  {
    "country": "CO",
    "name": "Puerto Wilches",
    "lat": "7.34828",
    "lng": "-73.89601"
  },
  {
    "country": "CO",
    "name": "Puerto Triunfo",
    "lat": "5.87259",
    "lng": "-74.6405"
  },
  {
    "country": "CO",
    "name": "Puerto Tejada",
    "lat": "3.23114",
    "lng": "-76.41668"
  },
  {
    "country": "CO",
    "name": "Puerto Santander",
    "lat": "8.36361",
    "lng": "-72.4063"
  },
  {
    "country": "CO",
    "name": "Puerto Salgar",
    "lat": "5.46304",
    "lng": "-74.65436"
  },
  {
    "country": "CO",
    "name": "Puerto Rondón",
    "lat": "6.28048",
    "lng": "-71.1"
  },
  {
    "country": "CO",
    "name": "Puerto Yuca",
    "lat": "2.93833",
    "lng": "-73.20833"
  },
  {
    "country": "CO",
    "name": "Puerto Rico",
    "lat": "1.90999",
    "lng": "-75.15931"
  },
  {
    "country": "CO",
    "name": "Puerto Parra",
    "lat": "6.65149",
    "lng": "-74.05734"
  },
  {
    "country": "CO",
    "name": "Puerto Nariño",
    "lat": "-3.78889",
    "lng": "-70.35584"
  },
  {
    "country": "CO",
    "name": "Puerto Meluk",
    "lat": "5.22134",
    "lng": "-76.93691"
  },
  {
    "country": "CO",
    "name": "Puerto López",
    "lat": "4.09912",
    "lng": "-72.95647"
  },
  {
    "country": "CO",
    "name": "Puerto Lleras",
    "lat": "3.02225",
    "lng": "-73.4044"
  },
  {
    "country": "CO",
    "name": "Puerto Leguízamo",
    "lat": "-0.19337",
    "lng": "-74.78189"
  },
  {
    "country": "CO",
    "name": "Inírida",
    "lat": "3.86528",
    "lng": "-67.92389"
  },
  {
    "country": "CO",
    "name": "Puerto Escondido",
    "lat": "9.01811",
    "lng": "-76.26413"
  },
  {
    "country": "CO",
    "name": "Puerto Colombia",
    "lat": "10.98778",
    "lng": "-74.95472"
  },
  {
    "country": "CO",
    "name": "Puerto Carreño",
    "lat": "6.18903",
    "lng": "-67.48588"
  },
  {
    "country": "CO",
    "name": "Puerto Boyacá",
    "lat": "5.976",
    "lng": "-74.58516"
  },
  {
    "country": "CO",
    "name": "Puerto Bogotá",
    "lat": "5.19994",
    "lng": "-74.72733"
  },
  {
    "country": "CO",
    "name": "Puerto Berrío",
    "lat": "6.49156",
    "lng": "-74.40326"
  },
  {
    "country": "CO",
    "name": "Puerto Asís",
    "lat": "0.50514",
    "lng": "-76.49571"
  },
  {
    "country": "CO",
    "name": "Puerres",
    "lat": "1.19374",
    "lng": "-77.26661"
  },
  {
    "country": "CO",
    "name": "Puerres",
    "lat": "0.88371",
    "lng": "-77.50324"
  },
  {
    "country": "CO",
    "name": "Puente Nacional",
    "lat": "5.87739",
    "lng": "-73.6781"
  },
  {
    "country": "CO",
    "name": "Puebloviejo",
    "lat": "10.99376",
    "lng": "-74.28439"
  },
  {
    "country": "CO",
    "name": "Pueblorrico",
    "lat": "5.79176",
    "lng": "-75.84101"
  },
  {
    "country": "CO",
    "name": "Pueblo Rico",
    "lat": "5.22263",
    "lng": "-76.03026"
  },
  {
    "country": "CO",
    "name": "Pueblo Nuevo",
    "lat": "8.50122",
    "lng": "-75.508"
  },
  {
    "country": "CO",
    "name": "Pueblo Nuevo",
    "lat": "8.2411",
    "lng": "-74.95815"
  },
  {
    "country": "CO",
    "name": "Pueblo Bello",
    "lat": "10.41706",
    "lng": "-73.5804"
  },
  {
    "country": "CO",
    "name": "Providencia",
    "lat": "1.56976",
    "lng": "-77.464"
  },
  {
    "country": "CO",
    "name": "Prado",
    "lat": "3.75118",
    "lng": "-74.93004"
  },
  {
    "country": "CO",
    "name": "Pradera",
    "lat": "3.42111",
    "lng": "-76.24472"
  },
  {
    "country": "CO",
    "name": "Potosí",
    "lat": "0.80739",
    "lng": "-77.57216"
  },
  {
    "country": "CO",
    "name": "Pore",
    "lat": "5.72792",
    "lng": "-71.99266"
  },
  {
    "country": "CO",
    "name": "Popayán",
    "lat": "2.43823",
    "lng": "-76.61316"
  },
  {
    "country": "CO",
    "name": "Ponedera",
    "lat": "10.64297",
    "lng": "-74.75393"
  },
  {
    "country": "CO",
    "name": "Polonuevo",
    "lat": "10.77697",
    "lng": "-74.85344"
  },
  {
    "country": "CO",
    "name": "Policarpa",
    "lat": "1.62843",
    "lng": "-77.45956"
  },
  {
    "country": "CO",
    "name": "Playarrica",
    "lat": "4.05694",
    "lng": "-75.41028"
  },
  {
    "country": "CO",
    "name": "Planeta Rica",
    "lat": "8.4115",
    "lng": "-75.58508"
  },
  {
    "country": "CO",
    "name": "Planadas",
    "lat": "3.19698",
    "lng": "-75.64506"
  },
  {
    "country": "CO",
    "name": "Pizarro",
    "lat": "4.95334",
    "lng": "-77.36598"
  },
  {
    "country": "CO",
    "name": "Salahonda",
    "lat": "2.0406",
    "lng": "-78.65877"
  },
  {
    "country": "CO",
    "name": "Pivijay",
    "lat": "10.46167",
    "lng": "-74.61621"
  },
  {
    "country": "CO",
    "name": "Pitalito",
    "lat": "1.85371",
    "lng": "-76.05071"
  },
  {
    "country": "CO",
    "name": "Pital",
    "lat": "2.2665",
    "lng": "-75.80442"
  },
  {
    "country": "CO",
    "name": "Pisba",
    "lat": "5.72396",
    "lng": "-72.48646"
  },
  {
    "country": "CO",
    "name": "Piojó",
    "lat": "10.74846",
    "lng": "-75.10776"
  },
  {
    "country": "CO",
    "name": "Santa Bárbara de Pinto",
    "lat": "9.43251",
    "lng": "-74.70414"
  },
  {
    "country": "CO",
    "name": "Pinillos",
    "lat": "8.91925",
    "lng": "-74.46771"
  },
  {
    "country": "CO",
    "name": "Pinchote",
    "lat": "6.53226",
    "lng": "-73.17309"
  },
  {
    "country": "CO",
    "name": "Pijiño del Carmen",
    "lat": "9.32908",
    "lng": "-74.45302"
  },
  {
    "country": "CO",
    "name": "Pijao",
    "lat": "4.3335",
    "lng": "-75.70463"
  },
  {
    "country": "CO",
    "name": "Piedras",
    "lat": "4.54261",
    "lng": "-74.87823"
  },
  {
    "country": "CO",
    "name": "Piedrancha",
    "lat": "1.14109",
    "lng": "-77.86479"
  },
  {
    "country": "CO",
    "name": "Pie de Pató",
    "lat": "5.51604",
    "lng": "-76.97449"
  },
  {
    "country": "CO",
    "name": "Piedecuesta",
    "lat": "6.98789",
    "lng": "-73.04953"
  },
  {
    "country": "CO",
    "name": "Pesca",
    "lat": "5.55",
    "lng": "-73.05"
  },
  {
    "country": "CO",
    "name": "Pereira",
    "lat": "4.81333",
    "lng": "-75.69611"
  },
  {
    "country": "CO",
    "name": "Peque",
    "lat": "7.02123",
    "lng": "-75.90926"
  },
  {
    "country": "CO",
    "name": "Pensilvania",
    "lat": "5.38346",
    "lng": "-75.16122"
  },
  {
    "country": "CO",
    "name": "Pelaya",
    "lat": "8.68819",
    "lng": "-73.66451"
  },
  {
    "country": "CO",
    "name": "Pedraza",
    "lat": "10.18739",
    "lng": "-74.91504"
  },
  {
    "country": "CO",
    "name": "Paz de Río",
    "lat": "5.98452",
    "lng": "-72.7505"
  },
  {
    "country": "CO",
    "name": "Paz de Ariporo",
    "lat": "5.88148",
    "lng": "-71.89167"
  },
  {
    "country": "CO",
    "name": "Payandé",
    "lat": "4.2975",
    "lng": "-75.09667"
  },
  {
    "country": "CO",
    "name": "Payán",
    "lat": "1.76645",
    "lng": "-78.18326"
  },
  {
    "country": "CO",
    "name": "Paya",
    "lat": "5.62492",
    "lng": "-72.42345"
  },
  {
    "country": "CO",
    "name": "Pauna",
    "lat": "5.65861",
    "lng": "-73.9825"
  },
  {
    "country": "CO",
    "name": "Patía",
    "lat": "2.06895",
    "lng": "-77.05273"
  },
  {
    "country": "CO",
    "name": "Pasto",
    "lat": "1.21361",
    "lng": "-77.28111"
  },
  {
    "country": "CO",
    "name": "Pasca",
    "lat": "4.30722",
    "lng": "-74.30056"
  },
  {
    "country": "CO",
    "name": "Páramo",
    "lat": "6.41639",
    "lng": "-73.17"
  },
  {
    "country": "CO",
    "name": "Panqueba",
    "lat": "6.44533",
    "lng": "-72.46268"
  },
  {
    "country": "CO",
    "name": "Pandi",
    "lat": "4.19111",
    "lng": "-74.4875"
  },
  {
    "country": "CO",
    "name": "Pamplonita",
    "lat": "7.43637",
    "lng": "-72.63808"
  },
  {
    "country": "CO",
    "name": "Pamplona",
    "lat": "7.37565",
    "lng": "-72.64795"
  },
  {
    "country": "CO",
    "name": "Palocabildo",
    "lat": "5.11705",
    "lng": "-75.01732"
  },
  {
    "country": "CO",
    "name": "Palmito",
    "lat": "9.33189",
    "lng": "-75.5417"
  },
  {
    "country": "CO",
    "name": "Palmira",
    "lat": "3.53944",
    "lng": "-76.30361"
  },
  {
    "country": "CO",
    "name": "Palmas del Socorro",
    "lat": "6.40756",
    "lng": "-73.28824"
  },
  {
    "country": "CO",
    "name": "Palmar de Varela",
    "lat": "10.74055",
    "lng": "-74.75443"
  },
  {
    "country": "CO",
    "name": "Palmar",
    "lat": "6.53773",
    "lng": "-73.29234"
  },
  {
    "country": "CO",
    "name": "Palestina",
    "lat": "5.0161",
    "lng": "-75.62854"
  },
  {
    "country": "CO",
    "name": "Palestina",
    "lat": "1.72362",
    "lng": "-76.13403"
  },
  {
    "country": "CO",
    "name": "Palermo",
    "lat": "2.89167",
    "lng": "-75.4375"
  },
  {
    "country": "CO",
    "name": "Pajarito",
    "lat": "5.2929",
    "lng": "-72.70277"
  },
  {
    "country": "CO",
    "name": "Paispamba",
    "lat": "2.25462",
    "lng": "-76.61086"
  },
  {
    "country": "CO",
    "name": "Paipa",
    "lat": "5.78013",
    "lng": "-73.11708"
  },
  {
    "country": "CO",
    "name": "Paime",
    "lat": "5.37054",
    "lng": "-74.15219"
  },
  {
    "country": "CO",
    "name": "Paimadó",
    "lat": "5.48309",
    "lng": "-76.74053"
  },
  {
    "country": "CO",
    "name": "Pailitas",
    "lat": "8.95652",
    "lng": "-73.62548"
  },
  {
    "country": "CO",
    "name": "Paicol",
    "lat": "2.44962",
    "lng": "-75.775"
  },
  {
    "country": "CO",
    "name": "Páez",
    "lat": "5.10112",
    "lng": "-73.05123"
  },
  {
    "country": "CO",
    "name": "Belalcázar",
    "lat": "2.64644",
    "lng": "-75.97269"
  },
  {
    "country": "CO",
    "name": "Padua",
    "lat": "5.13429",
    "lng": "-75.14001"
  },
  {
    "country": "CO",
    "name": "Padilla",
    "lat": "3.22038",
    "lng": "-76.31385"
  },
  {
    "country": "CO",
    "name": "Pácora",
    "lat": "5.52708",
    "lng": "-75.4593"
  },
  {
    "country": "CO",
    "name": "Pacho",
    "lat": "5.13278",
    "lng": "-74.15977"
  },
  {
    "country": "CO",
    "name": "Pachavita",
    "lat": "5.13969",
    "lng": "-73.39739"
  },
  {
    "country": "CO",
    "name": "Ovejas",
    "lat": "9.52716",
    "lng": "-75.22873"
  },
  {
    "country": "CO",
    "name": "Otanche",
    "lat": "5.65672",
    "lng": "-74.18249"
  },
  {
    "country": "CO",
    "name": "Ospina",
    "lat": "1.0595",
    "lng": "-77.56554"
  },
  {
    "country": "CO",
    "name": "Ortega",
    "lat": "3.9361",
    "lng": "-75.22169"
  },
  {
    "country": "CO",
    "name": "Orocué",
    "lat": "4.79035",
    "lng": "-71.33917"
  },
  {
    "country": "CO",
    "name": "Oporapa",
    "lat": "2.02378",
    "lng": "-75.99588"
  },
  {
    "country": "CO",
    "name": "Onzaga",
    "lat": "6.34434",
    "lng": "-72.81726"
  },
  {
    "country": "CO",
    "name": "Olaya Herrera",
    "lat": "1.24803",
    "lng": "-77.49085"
  },
  {
    "country": "CO",
    "name": "Olaya",
    "lat": "6.62773",
    "lng": "-75.8127"
  },
  {
    "country": "CO",
    "name": "Oicatá",
    "lat": "5.59548",
    "lng": "-73.3082"
  },
  {
    "country": "CO",
    "name": "Oiba",
    "lat": "6.26387",
    "lng": "-73.29876"
  },
  {
    "country": "CO",
    "name": "Ocaña",
    "lat": "8.23773",
    "lng": "-73.35604"
  },
  {
    "country": "CO",
    "name": "Ocamonte",
    "lat": "6.34001",
    "lng": "-73.12205"
  },
  {
    "country": "CO",
    "name": "Obando",
    "lat": "4.57583",
    "lng": "-75.97389"
  },
  {
    "country": "CO",
    "name": "Nuquí",
    "lat": "5.7125",
    "lng": "-77.27083"
  },
  {
    "country": "CO",
    "name": "Nunchía",
    "lat": "5.63589",
    "lng": "-72.19543"
  },
  {
    "country": "CO",
    "name": "Nuevo Colón",
    "lat": "5.35368",
    "lng": "-73.4566"
  },
  {
    "country": "CO",
    "name": "Nueva Granada",
    "lat": "9.80168",
    "lng": "-74.39304"
  },
  {
    "country": "CO",
    "name": "Nóvita",
    "lat": "4.95511",
    "lng": "-76.60526"
  },
  {
    "country": "CO",
    "name": "Norosí",
    "lat": "8.52692",
    "lng": "-74.03736"
  },
  {
    "country": "CO",
    "name": "Norcasia",
    "lat": "5.57535",
    "lng": "-74.88831"
  },
  {
    "country": "CO",
    "name": "Nocaima",
    "lat": "5.06696",
    "lng": "-74.38439"
  },
  {
    "country": "CO",
    "name": "Nobsa",
    "lat": "5.76978",
    "lng": "-72.94099"
  },
  {
    "country": "CO",
    "name": "Nimaima",
    "lat": "5.12614",
    "lng": "-74.38495"
  },
  {
    "country": "CO",
    "name": "Nilo",
    "lat": "4.30604",
    "lng": "-74.62083"
  },
  {
    "country": "CO",
    "name": "Nemocón",
    "lat": "5.06767",
    "lng": "-73.87769"
  },
  {
    "country": "CO",
    "name": "Neiva",
    "lat": "2.9273",
    "lng": "-75.28189"
  },
  {
    "country": "CO",
    "name": "Neira",
    "lat": "5.1665",
    "lng": "-75.52001"
  },
  {
    "country": "CO",
    "name": "Necoclí",
    "lat": "8.42627",
    "lng": "-76.78926"
  },
  {
    "country": "CO",
    "name": "Nechí",
    "lat": "8.09419",
    "lng": "-74.77573"
  },
  {
    "country": "CO",
    "name": "Natagaima",
    "lat": "3.62057",
    "lng": "-75.09415"
  },
  {
    "country": "CO",
    "name": "Nátaga",
    "lat": "2.54359",
    "lng": "-75.80852"
  },
  {
    "country": "CO",
    "name": "Nariño",
    "lat": "5.60893",
    "lng": "-75.17656"
  },
  {
    "country": "CO",
    "name": "Nariño",
    "lat": "4.39781",
    "lng": "-74.82731"
  },
  {
    "country": "CO",
    "name": "Nariño",
    "lat": "1.28995",
    "lng": "-77.35721"
  },
  {
    "country": "CO",
    "name": "Muzo",
    "lat": "5.53528",
    "lng": "-74.10778"
  },
  {
    "country": "CO",
    "name": "Mutiscua",
    "lat": "7.30061",
    "lng": "-72.74667"
  },
  {
    "country": "CO",
    "name": "Mutatá",
    "lat": "7.24407",
    "lng": "-76.43564"
  },
  {
    "country": "CO",
    "name": "Murindó",
    "lat": "6.98057",
    "lng": "-76.82119"
  },
  {
    "country": "CO",
    "name": "Murillo",
    "lat": "4.87393",
    "lng": "-75.17151"
  },
  {
    "country": "CO",
    "name": "Mountain",
    "lat": "13.36667",
    "lng": "-81.36667"
  },
  {
    "country": "CO",
    "name": "Motavita",
    "lat": "5.57655",
    "lng": "-73.36696"
  },
  {
    "country": "CO",
    "name": "Mosquera",
    "lat": "4.70592",
    "lng": "-74.23021"
  },
  {
    "country": "CO",
    "name": "Mosquera",
    "lat": "2.50861",
    "lng": "-78.4511"
  },
  {
    "country": "CO",
    "name": "Morroa",
    "lat": "9.33348",
    "lng": "-75.30542"
  },
  {
    "country": "CO",
    "name": "Morelia",
    "lat": "1.48747",
    "lng": "-75.72581"
  },
  {
    "country": "CO",
    "name": "Morales",
    "lat": "8.2752",
    "lng": "-73.86884"
  },
  {
    "country": "CO",
    "name": "Montería",
    "lat": "8.74798",
    "lng": "-75.88143"
  },
  {
    "country": "CO",
    "name": "Montenegro",
    "lat": "4.56639",
    "lng": "-75.75111"
  },
  {
    "country": "CO",
    "name": "Montelíbano",
    "lat": "7.97917",
    "lng": "-75.4202"
  },
  {
    "country": "CO",
    "name": "Montecristo",
    "lat": "8.2971",
    "lng": "-74.4733"
  },
  {
    "country": "CO",
    "name": "Montebello",
    "lat": "5.94806",
    "lng": "-75.5275"
  },
  {
    "country": "CO",
    "name": "Moñitos",
    "lat": "9.2455",
    "lng": "-76.13017"
  },
  {
    "country": "CO",
    "name": "Moñitos",
    "lat": "8.25",
    "lng": "-76.05"
  },
  {
    "country": "CO",
    "name": "Moniquirá",
    "lat": "5.87638",
    "lng": "-73.57284"
  },
  {
    "country": "CO",
    "name": "Monguí",
    "lat": "5.72151",
    "lng": "-72.84908"
  },
  {
    "country": "CO",
    "name": "Mongua",
    "lat": "5.75084",
    "lng": "-72.80339"
  },
  {
    "country": "CO",
    "name": "Mompós",
    "lat": "9.24194",
    "lng": "-74.42667"
  },
  {
    "country": "CO",
    "name": "Momil",
    "lat": "9.23767",
    "lng": "-75.67489"
  },
  {
    "country": "CO",
    "name": "Molagavita",
    "lat": "6.67315",
    "lng": "-72.80875"
  },
  {
    "country": "CO",
    "name": "Mogotes",
    "lat": "6.47559",
    "lng": "-72.97046"
  },
  {
    "country": "CO",
    "name": "Mocoa",
    "lat": "1.15284",
    "lng": "-76.65208"
  },
  {
    "country": "CO",
    "name": "Mitú",
    "lat": "1.25778",
    "lng": "-70.23472"
  },
  {
    "country": "CO",
    "name": "Mistrató",
    "lat": "5.29622",
    "lng": "-75.8839"
  },
  {
    "country": "CO",
    "name": "Miranda",
    "lat": "3.25283",
    "lng": "-76.22924"
  },
  {
    "country": "CO",
    "name": "Miraflores",
    "lat": "5.19608",
    "lng": "-73.14504"
  },
  {
    "country": "CO",
    "name": "Miraflores",
    "lat": "1.33667",
    "lng": "-71.95111"
  },
  {
    "country": "CO",
    "name": "Milán",
    "lat": "1.29034",
    "lng": "-75.50757"
  },
  {
    "country": "CO",
    "name": "Mercaderes",
    "lat": "1.80175",
    "lng": "-77.17032"
  },
  {
    "country": "CO",
    "name": "Melgar",
    "lat": "4.20475",
    "lng": "-74.64075"
  },
  {
    "country": "CO",
    "name": "Medina",
    "lat": "4.51005",
    "lng": "-73.34982"
  },
  {
    "country": "CO",
    "name": "Medellín",
    "lat": "6.25184",
    "lng": "-75.56359"
  },
  {
    "country": "CO",
    "name": "Matanza",
    "lat": "7.32233",
    "lng": "-73.01516"
  },
  {
    "country": "CO",
    "name": "Marulanda",
    "lat": "5.28393",
    "lng": "-75.26016"
  },
  {
    "country": "CO",
    "name": "Marsella",
    "lat": "4.93722",
    "lng": "-75.73778"
  },
  {
    "country": "CO",
    "name": "Marquetalia",
    "lat": "5.29659",
    "lng": "-75.05496"
  },
  {
    "country": "CO",
    "name": "Marmato",
    "lat": "5.47501",
    "lng": "-75.6004"
  },
  {
    "country": "CO",
    "name": "San Sebastián de Mariquita",
    "lat": "5.19889",
    "lng": "-74.89295"
  },
  {
    "country": "CO",
    "name": "Maripí",
    "lat": "5.55194",
    "lng": "-74.00861"
  },
  {
    "country": "CO",
    "name": "Marinilla",
    "lat": "6.17358",
    "lng": "-75.33621"
  },
  {
    "country": "CO",
    "name": "María la Baja",
    "lat": "9.9832",
    "lng": "-75.30155"
  },
  {
    "country": "CO",
    "name": "Margarita",
    "lat": "9.15596",
    "lng": "-74.26618"
  },
  {
    "country": "CO",
    "name": "Manzanares",
    "lat": "5.25397",
    "lng": "-75.15403"
  },
  {
    "country": "CO",
    "name": "Manta",
    "lat": "5.00864",
    "lng": "-73.54115"
  },
  {
    "country": "CO",
    "name": "Manizales",
    "lat": "5.06889",
    "lng": "-75.51738"
  },
  {
    "country": "CO",
    "name": "Maní",
    "lat": "4.81638",
    "lng": "-72.27946"
  },
  {
    "country": "CO",
    "name": "Manaure",
    "lat": "11.77505",
    "lng": "-72.44447"
  },
  {
    "country": "CO",
    "name": "Manatí",
    "lat": "10.44589",
    "lng": "-74.95869"
  },
  {
    "country": "CO",
    "name": "Managrú",
    "lat": "5.33653",
    "lng": "-76.72756"
  },
  {
    "country": "CO",
    "name": "Malambo",
    "lat": "10.85953",
    "lng": "-74.77386"
  },
  {
    "country": "CO",
    "name": "Málaga",
    "lat": "6.69903",
    "lng": "-72.73233"
  },
  {
    "country": "CO",
    "name": "Majagual",
    "lat": "8.54119",
    "lng": "-74.62942"
  },
  {
    "country": "CO",
    "name": "Maicao",
    "lat": "11.37837",
    "lng": "-72.2395"
  },
  {
    "country": "CO",
    "name": "Mahates",
    "lat": "10.23293",
    "lng": "-75.18985"
  },
  {
    "country": "CO",
    "name": "Magangué",
    "lat": "9.24202",
    "lng": "-74.75467"
  },
  {
    "country": "CO",
    "name": "Madrid",
    "lat": "4.73245",
    "lng": "-74.26419"
  },
  {
    "country": "CO",
    "name": "Machetá",
    "lat": "5.08154",
    "lng": "-73.60761"
  },
  {
    "country": "CO",
    "name": "Maceo",
    "lat": "6.55196",
    "lng": "-74.78741"
  },
  {
    "country": "CO",
    "name": "Macaravita",
    "lat": "6.50567",
    "lng": "-72.59299"
  },
  {
    "country": "CO",
    "name": "Macanal",
    "lat": "4.97214",
    "lng": "-73.31959"
  },
  {
    "country": "CO",
    "name": "Luruaco",
    "lat": "10.61712",
    "lng": "-75.15146"
  },
  {
    "country": "CO",
    "name": "Lourdes",
    "lat": "7.94411",
    "lng": "-72.83253"
  },
  {
    "country": "CO",
    "name": "Los Santos",
    "lat": "6.75343",
    "lng": "-73.10473"
  },
  {
    "country": "CO",
    "name": "Los Patios",
    "lat": "7.83793",
    "lng": "-72.5037"
  },
  {
    "country": "CO",
    "name": "Los Palmitos",
    "lat": "9.37899",
    "lng": "-75.26769"
  },
  {
    "country": "CO",
    "name": "Los Córdobas",
    "lat": "8.89403",
    "lng": "-76.35455"
  },
  {
    "country": "CO",
    "name": "Lorica",
    "lat": "9.23648",
    "lng": "-75.8135"
  },
  {
    "country": "CO",
    "name": "López",
    "lat": "2.8454",
    "lng": "-77.24791"
  },
  {
    "country": "CO",
    "name": "López",
    "lat": "2.43333",
    "lng": "-76.8"
  },
  {
    "country": "CO",
    "name": "Lloró",
    "lat": "5.49605",
    "lng": "-76.54945"
  },
  {
    "country": "CO",
    "name": "Linares",
    "lat": "1.35078",
    "lng": "-77.52339"
  },
  {
    "country": "CO",
    "name": "Liborina",
    "lat": "6.6779",
    "lng": "-75.81218"
  },
  {
    "country": "CO",
    "name": "Líbano",
    "lat": "4.9218",
    "lng": "-75.06232"
  },
  {
    "country": "CO",
    "name": "Leticia",
    "lat": "-4.21528",
    "lng": "-69.94056"
  },
  {
    "country": "CO",
    "name": "Lérida",
    "lat": "4.86242",
    "lng": "-74.90977"
  },
  {
    "country": "CO",
    "name": "Lenguazaque",
    "lat": "5.30711",
    "lng": "-73.71152"
  },
  {
    "country": "CO",
    "name": "Leiva",
    "lat": "1.93497",
    "lng": "-77.30634"
  },
  {
    "country": "CO",
    "name": "Lebrija",
    "lat": "7.11317",
    "lng": "-73.2178"
  },
  {
    "country": "CO",
    "name": "La Virginia",
    "lat": "4.89972",
    "lng": "-75.8825"
  },
  {
    "country": "CO",
    "name": "La Victoria",
    "lat": "4.52483",
    "lng": "-76.03921"
  },
  {
    "country": "CO",
    "name": "La Vega",
    "lat": "5.00177",
    "lng": "-74.34174"
  },
  {
    "country": "CO",
    "name": "La Vega",
    "lat": "2.00187",
    "lng": "-76.7789"
  },
  {
    "country": "CO",
    "name": "La Uvita",
    "lat": "6.32064",
    "lng": "-72.56281"
  },
  {
    "country": "CO",
    "name": "La Unión",
    "lat": "8.84965",
    "lng": "-75.27942"
  },
  {
    "country": "CO",
    "name": "La Unión",
    "lat": "5.97431",
    "lng": "-75.36195"
  },
  {
    "country": "CO",
    "name": "La Unión",
    "lat": "4.53282",
    "lng": "-76.10318"
  },
  {
    "country": "CO",
    "name": "La Unión",
    "lat": "1.6045",
    "lng": "-77.13152"
  },
  {
    "country": "CO",
    "name": "La Tebaida",
    "lat": "4.45265",
    "lng": "-75.78746"
  },
  {
    "country": "CO",
    "name": "La Sierra",
    "lat": "2.17835",
    "lng": "-76.76265"
  },
  {
    "country": "CO",
    "name": "Ánimas",
    "lat": "5.27784",
    "lng": "-76.63082"
  },
  {
    "country": "CO",
    "name": "La Salina",
    "lat": "6.13162",
    "lng": "-72.33841"
  },
  {
    "country": "CO",
    "name": "La Primavera",
    "lat": "5.49056",
    "lng": "-70.40917"
  },
  {
    "country": "CO",
    "name": "La Playa",
    "lat": "8.21321",
    "lng": "-73.23827"
  },
  {
    "country": "CO",
    "name": "La Plata",
    "lat": "2.39341",
    "lng": "-75.89232"
  },
  {
    "country": "CO",
    "name": "La Pintada",
    "lat": "5.74867",
    "lng": "-75.60626"
  },
  {
    "country": "CO",
    "name": "La Peña",
    "lat": "5.19847",
    "lng": "-74.39368"
  },
  {
    "country": "CO",
    "name": "La Paz",
    "lat": "10.38439",
    "lng": "-73.17332"
  },
  {
    "country": "CO",
    "name": "La Paz",
    "lat": "6.17848",
    "lng": "-73.58948"
  },
  {
    "country": "CO",
    "name": "La Palma",
    "lat": "5.3592",
    "lng": "-74.39047"
  },
  {
    "country": "CO",
    "name": "Landázuri",
    "lat": "6.21826",
    "lng": "-73.81121"
  },
  {
    "country": "CO",
    "name": "La Montañita",
    "lat": "1.48016",
    "lng": "-75.43664"
  },
  {
    "country": "CO",
    "name": "La Mesa",
    "lat": "5.26667",
    "lng": "-73.91667"
  },
  {
    "country": "CO",
    "name": "La Merced",
    "lat": "5.40194",
    "lng": "-75.88472"
  },
  {
    "country": "CO",
    "name": "La Llanada",
    "lat": "1.4731",
    "lng": "-77.58024"
  },
  {
    "country": "CO",
    "name": "La Jagua del Pilar",
    "lat": "10.51061",
    "lng": "-73.07178"
  },
  {
    "country": "CO",
    "name": "La Jagua de Ibirico",
    "lat": "9.56228",
    "lng": "-73.33405"
  },
  {
    "country": "CO",
    "name": "La Gloria",
    "lat": "8.61868",
    "lng": "-73.80265"
  },
  {
    "country": "CO",
    "name": "La Florida",
    "lat": "1.29851",
    "lng": "-77.40614"
  },
  {
    "country": "CO",
    "name": "La Estrella",
    "lat": "6.15769",
    "lng": "-75.64317"
  },
  {
    "country": "CO",
    "name": "La Esperanza",
    "lat": "8.21043",
    "lng": "-72.46399"
  },
  {
    "country": "CO",
    "name": "La Dorada",
    "lat": "5.44783",
    "lng": "-74.66311"
  },
  {
    "country": "CO",
    "name": "La Cumbre",
    "lat": "3.64999",
    "lng": "-76.56984"
  },
  {
    "country": "CO",
    "name": "La Cruz",
    "lat": "1.60221",
    "lng": "-76.9713"
  },
  {
    "country": "CO",
    "name": "La Chamba",
    "lat": "4.02649",
    "lng": "-74.86844"
  },
  {
    "country": "CO",
    "name": "La Celia",
    "lat": "5.00332",
    "lng": "-76.00355"
  },
  {
    "country": "CO",
    "name": "La Ceja",
    "lat": "6.03131",
    "lng": "-75.43333"
  },
  {
    "country": "CO",
    "name": "La Capilla",
    "lat": "5.70493",
    "lng": "-73.47527"
  },
  {
    "country": "CO",
    "name": "La Capilla",
    "lat": "5.0959",
    "lng": "-73.44407"
  },
  {
    "country": "CO",
    "name": "La Calera",
    "lat": "4.72069",
    "lng": "-73.96926"
  },
  {
    "country": "CO",
    "name": "Labranzagrande",
    "lat": "5.56223",
    "lng": "-72.57499"
  },
  {
    "country": "CO",
    "name": "La Belleza",
    "lat": "5.86371",
    "lng": "-73.96167"
  },
  {
    "country": "CO",
    "name": "La Argentina",
    "lat": "2.19762",
    "lng": "-75.9799"
  },
  {
    "country": "CO",
    "name": "Juradó",
    "lat": "7.10421",
    "lng": "-77.762"
  },
  {
    "country": "CO",
    "name": "Junín",
    "lat": "4.78333",
    "lng": "-75.01667"
  },
  {
    "country": "CO",
    "name": "Junín",
    "lat": "4.79027",
    "lng": "-73.66011"
  },
  {
    "country": "CO",
    "name": "Juan de Acosta",
    "lat": "10.8293",
    "lng": "-75.03346"
  },
  {
    "country": "CO",
    "name": "Jordán",
    "lat": "6.733",
    "lng": "-73.09588"
  },
  {
    "country": "CO",
    "name": "Jesús María",
    "lat": "5.87715",
    "lng": "-73.78097"
  },
  {
    "country": "CO",
    "name": "Jerusalén",
    "lat": "4.56309",
    "lng": "-74.69519"
  },
  {
    "country": "CO",
    "name": "Jericó",
    "lat": "6.14592",
    "lng": "-72.5708"
  },
  {
    "country": "CO",
    "name": "Jericó",
    "lat": "5.79211",
    "lng": "-75.78601"
  },
  {
    "country": "CO",
    "name": "Jenesano",
    "lat": "5.38541",
    "lng": "-73.36364"
  },
  {
    "country": "CO",
    "name": "Jardín",
    "lat": "5.59902",
    "lng": "-75.81976"
  },
  {
    "country": "CO",
    "name": "Jamundí",
    "lat": "3.26074",
    "lng": "-76.53499"
  },
  {
    "country": "CO",
    "name": "Jambaló",
    "lat": "2.77762",
    "lng": "-76.32444"
  },
  {
    "country": "CO",
    "name": "Iza",
    "lat": "5.61203",
    "lng": "-72.9793"
  },
  {
    "country": "CO",
    "name": "Ituango",
    "lat": "7.17117",
    "lng": "-75.76404"
  },
  {
    "country": "CO",
    "name": "Itagüí",
    "lat": "6.18461",
    "lng": "-75.59913"
  },
  {
    "country": "CO",
    "name": "Istmina",
    "lat": "5.16054",
    "lng": "-76.68397"
  },
  {
    "country": "CO",
    "name": "Iscuandé",
    "lat": "2.45065",
    "lng": "-77.97998"
  },
  {
    "country": "CO",
    "name": "Íquira",
    "lat": "2.64867",
    "lng": "-75.63457"
  },
  {
    "country": "CO",
    "name": "Ipiales",
    "lat": "0.82501",
    "lng": "-77.63966"
  },
  {
    "country": "CO",
    "name": "Inzá",
    "lat": "2.55452",
    "lng": "-76.06722"
  },
  {
    "country": "CO",
    "name": "Imués",
    "lat": "1.05516",
    "lng": "-77.49669"
  },
  {
    "country": "CO",
    "name": "Iles",
    "lat": "0.9704",
    "lng": "-77.52146"
  },
  {
    "country": "CO",
    "name": "Icononzo",
    "lat": "4.17698",
    "lng": "-74.53254"
  },
  {
    "country": "CO",
    "name": "Ibagué",
    "lat": "4.43889",
    "lng": "-75.23222"
  },
  {
    "country": "CO",
    "name": "Honda",
    "lat": "5.20856",
    "lng": "-74.73584"
  },
  {
    "country": "CO",
    "name": "Hobo",
    "lat": "2.58333",
    "lng": "-75.45"
  },
  {
    "country": "CO",
    "name": "Hispania",
    "lat": "5.79925",
    "lng": "-75.90718"
  },
  {
    "country": "CO",
    "name": "Herveo",
    "lat": "5.08004",
    "lng": "-75.17556"
  },
  {
    "country": "CO",
    "name": "Herrán",
    "lat": "7.50611",
    "lng": "-72.48332"
  },
  {
    "country": "CO",
    "name": "Heliconia",
    "lat": "6.20831",
    "lng": "-75.73565"
  },
  {
    "country": "CO",
    "name": "Municipio Hato Corozal",
    "lat": "6.15676",
    "lng": "-71.76372"
  },
  {
    "country": "CO",
    "name": "Hato",
    "lat": "6.54302",
    "lng": "-73.30826"
  },
  {
    "country": "CO",
    "name": "Hatillo de Loba",
    "lat": "8.95635",
    "lng": "-74.07819"
  },
  {
    "country": "CO",
    "name": "Hacarí",
    "lat": "8.32333",
    "lng": "-73.14889"
  },
  {
    "country": "CO",
    "name": "Gutiérrez",
    "lat": "4.25472",
    "lng": "-74.0025"
  },
  {
    "country": "CO",
    "name": "Güicán",
    "lat": "6.46554",
    "lng": "-72.41539"
  },
  {
    "country": "CO",
    "name": "Güepsa",
    "lat": "6.02505",
    "lng": "-73.57313"
  },
  {
    "country": "CO",
    "name": "Guayatá",
    "lat": "4.96417",
    "lng": "-73.4875"
  },
  {
    "country": "CO",
    "name": "Guayabetal",
    "lat": "4.21472",
    "lng": "-73.81719"
  },
  {
    "country": "CO",
    "name": "Guayabal de Síquima",
    "lat": "4.87739",
    "lng": "-74.46744"
  },
  {
    "country": "CO",
    "name": "Guavatá",
    "lat": "5.95502",
    "lng": "-73.70018"
  },
  {
    "country": "CO",
    "name": "Guática",
    "lat": "5.31569",
    "lng": "-75.79826"
  },
  {
    "country": "CO",
    "name": "Guateque",
    "lat": "5.00619",
    "lng": "-73.47274"
  },
  {
    "country": "CO",
    "name": "Guatavita",
    "lat": "4.93658",
    "lng": "-73.83314"
  },
  {
    "country": "CO",
    "name": "Guataquí",
    "lat": "4.51573",
    "lng": "-74.78935"
  },
  {
    "country": "CO",
    "name": "Guatapé",
    "lat": "6.23429",
    "lng": "-75.16335"
  },
  {
    "country": "CO",
    "name": "Guasca",
    "lat": "4.86601",
    "lng": "-73.87748"
  },
  {
    "country": "CO",
    "name": "Guarne",
    "lat": "6.28046",
    "lng": "-75.44354"
  },
  {
    "country": "CO",
    "name": "Guaranda",
    "lat": "8.46746",
    "lng": "-74.53617"
  },
  {
    "country": "CO",
    "name": "Guapotá",
    "lat": "6.30798",
    "lng": "-73.3202"
  },
  {
    "country": "CO",
    "name": "Guapí",
    "lat": "2.57082",
    "lng": "-77.88542"
  },
  {
    "country": "CO",
    "name": "Guamo",
    "lat": "4.03078",
    "lng": "-74.9701"
  },
  {
    "country": "CO",
    "name": "Guamal",
    "lat": "9.14334",
    "lng": "-74.22384"
  },
  {
    "country": "CO",
    "name": "Guamal",
    "lat": "3.88043",
    "lng": "-73.76566"
  },
  {
    "country": "CO",
    "name": "Gualmatán",
    "lat": "0.91992",
    "lng": "-77.56738"
  },
  {
    "country": "CO",
    "name": "Guaitarilla",
    "lat": "1.13103",
    "lng": "-77.54815"
  },
  {
    "country": "CO",
    "name": "Guaduas",
    "lat": "5.06692",
    "lng": "-74.59499"
  },
  {
    "country": "CO",
    "name": "Guadalupe",
    "lat": "6.81449",
    "lng": "-75.24063"
  },
  {
    "country": "CO",
    "name": "Guadalupe",
    "lat": "6.2464",
    "lng": "-73.41833"
  },
  {
    "country": "CO",
    "name": "Guadalupe",
    "lat": "2.0248",
    "lng": "-75.75589"
  },
  {
    "country": "CO",
    "name": "Guachucal",
    "lat": "0.96093",
    "lng": "-77.73161"
  },
  {
    "country": "CO",
    "name": "Guachetá",
    "lat": "5.38425",
    "lng": "-73.68617"
  },
  {
    "country": "CO",
    "name": "Guachené",
    "lat": "3.13333",
    "lng": "-76.3927"
  },
  {
    "country": "CO",
    "name": "Guachavés",
    "lat": "1.2224",
    "lng": "-77.67766"
  },
  {
    "country": "CO",
    "name": "Guacarí",
    "lat": "3.76383",
    "lng": "-76.33292"
  },
  {
    "country": "CO",
    "name": "Guacamayas",
    "lat": "6.46243",
    "lng": "-72.50465"
  },
  {
    "country": "CO",
    "name": "Guaca",
    "lat": "6.87621",
    "lng": "-72.85594"
  },
  {
    "country": "CO",
    "name": "Granada",
    "lat": "6.14353",
    "lng": "-75.18532"
  },
  {
    "country": "CO",
    "name": "Granada",
    "lat": "5.06667",
    "lng": "-74.56667"
  },
  {
    "country": "CO",
    "name": "Granada",
    "lat": "4.51997",
    "lng": "-74.35261"
  },
  {
    "country": "CO",
    "name": "Granada",
    "lat": "3.54625",
    "lng": "-73.70687"
  },
  {
    "country": "CO",
    "name": "Gramalote",
    "lat": "7.88752",
    "lng": "-72.79749"
  },
  {
    "country": "CO",
    "name": "González",
    "lat": "8.38944",
    "lng": "-73.37989"
  },
  {
    "country": "CO",
    "name": "Gómez Plata",
    "lat": "6.68178",
    "lng": "-75.21907"
  },
  {
    "country": "CO",
    "name": "Girón",
    "lat": "7.0682",
    "lng": "-73.16981"
  },
  {
    "country": "CO",
    "name": "Girardota",
    "lat": "6.37747",
    "lng": "-75.44883"
  },
  {
    "country": "CO",
    "name": "Girardot City",
    "lat": "4.30079",
    "lng": "-74.80754"
  },
  {
    "country": "CO",
    "name": "Giraldo",
    "lat": "6.68013",
    "lng": "-75.95259"
  },
  {
    "country": "CO",
    "name": "Ginebra",
    "lat": "3.72461",
    "lng": "-76.26675"
  },
  {
    "country": "CO",
    "name": "Gigante",
    "lat": "2.38678",
    "lng": "-75.54736"
  },
  {
    "country": "CO",
    "name": "Génova",
    "lat": "4.31667",
    "lng": "-75.76667"
  },
  {
    "country": "CO",
    "name": "Génova",
    "lat": "1.64367",
    "lng": "-77.01924"
  },
  {
    "country": "CO",
    "name": "Garzón",
    "lat": "2.19593",
    "lng": "-75.62777"
  },
  {
    "country": "CO",
    "name": "Garagoa",
    "lat": "5.08236",
    "lng": "-73.36334"
  },
  {
    "country": "CO",
    "name": "Gámeza",
    "lat": "5.80263",
    "lng": "-72.80586"
  },
  {
    "country": "CO",
    "name": "Gámbita",
    "lat": "5.94597",
    "lng": "-73.34435"
  },
  {
    "country": "CO",
    "name": "Gamarra",
    "lat": "8.32279",
    "lng": "-73.74268"
  },
  {
    "country": "CO",
    "name": "Gama",
    "lat": "4.76288",
    "lng": "-73.61091"
  },
  {
    "country": "CO",
    "name": "Galeras",
    "lat": "9.16095",
    "lng": "-75.04811"
  },
  {
    "country": "CO",
    "name": "Galapa",
    "lat": "10.89686",
    "lng": "-74.886"
  },
  {
    "country": "CO",
    "name": "Galán",
    "lat": "6.63781",
    "lng": "-73.28878"
  },
  {
    "country": "CO",
    "name": "Gaitania",
    "lat": "3.15",
    "lng": "-75.81667"
  },
  {
    "country": "CO",
    "name": "Gachantivá",
    "lat": "5.75662",
    "lng": "-73.5395"
  },
  {
    "country": "CO",
    "name": "Gachancipá",
    "lat": "4.99111",
    "lng": "-73.87154"
  },
  {
    "country": "CO",
    "name": "Gachalá",
    "lat": "4.69244",
    "lng": "-73.52042"
  },
  {
    "country": "CO",
    "name": "Fusagasugá",
    "lat": "4.33646",
    "lng": "-74.36378"
  },
  {
    "country": "CO",
    "name": "Fúquene",
    "lat": "5.40425",
    "lng": "-73.7964"
  },
  {
    "country": "CO",
    "name": "Funza",
    "lat": "4.71638",
    "lng": "-74.21195"
  },
  {
    "country": "CO",
    "name": "Funes",
    "lat": "1.00075",
    "lng": "-77.44918"
  },
  {
    "country": "CO",
    "name": "Fundación",
    "lat": "10.52066",
    "lng": "-74.18504"
  },
  {
    "country": "CO",
    "name": "Fuente de Oro",
    "lat": "3.46263",
    "lng": "-73.62162"
  },
  {
    "country": "CO",
    "name": "Frontino",
    "lat": "6.77133",
    "lng": "-76.13324"
  },
  {
    "country": "CO",
    "name": "Frías",
    "lat": "5.02973",
    "lng": "-75.0086"
  },
  {
    "country": "CO",
    "name": "Fresno",
    "lat": "5.15264",
    "lng": "-75.03624"
  },
  {
    "country": "CO",
    "name": "Fosca",
    "lat": "4.33916",
    "lng": "-73.93852"
  },
  {
    "country": "CO",
    "name": "Fortul",
    "lat": "6.79261",
    "lng": "-71.77596"
  },
  {
    "country": "CO",
    "name": "Fonseca",
    "lat": "10.88606",
    "lng": "-72.8487"
  },
  {
    "country": "CO",
    "name": "Fómeque",
    "lat": "4.48797",
    "lng": "-73.89749"
  },
  {
    "country": "CO",
    "name": "Floridablanca",
    "lat": "7.06222",
    "lng": "-73.08644"
  },
  {
    "country": "CO",
    "name": "Florida",
    "lat": "3.3223",
    "lng": "-76.2348"
  },
  {
    "country": "CO",
    "name": "Florián",
    "lat": "5.80487",
    "lng": "-73.97029"
  },
  {
    "country": "CO",
    "name": "Floresta",
    "lat": "5.85903",
    "lng": "-72.91882"
  },
  {
    "country": "CO",
    "name": "Florencia",
    "lat": "1.68318",
    "lng": "-77.07331"
  },
  {
    "country": "CO",
    "name": "Florencia",
    "lat": "1.61438",
    "lng": "-75.60623"
  },
  {
    "country": "CO",
    "name": "Flandes",
    "lat": "4.29005",
    "lng": "-74.81612"
  },
  {
    "country": "CO",
    "name": "Firavitoba",
    "lat": "5.66885",
    "lng": "-72.99289"
  },
  {
    "country": "CO",
    "name": "Filandia",
    "lat": "4.67472",
    "lng": "-75.65833"
  },
  {
    "country": "CO",
    "name": "Filadelfia",
    "lat": "5.29606",
    "lng": "-75.5612"
  },
  {
    "country": "CO",
    "name": "Falan",
    "lat": "5.12383",
    "lng": "-74.95181"
  },
  {
    "country": "CO",
    "name": "Facatativá",
    "lat": "4.81367",
    "lng": "-74.35453"
  },
  {
    "country": "CO",
    "name": "Espinal",
    "lat": "4.14924",
    "lng": "-74.88429"
  },
  {
    "country": "CO",
    "name": "Envigado",
    "lat": "6.17591",
    "lng": "-75.59174"
  },
  {
    "country": "CO",
    "name": "Entrerríos",
    "lat": "6.5654",
    "lng": "-75.5169"
  },
  {
    "country": "CO",
    "name": "Enciso",
    "lat": "6.66808",
    "lng": "-72.69986"
  },
  {
    "country": "CO",
    "name": "Encino",
    "lat": "6.13735",
    "lng": "-73.09847"
  },
  {
    "country": "CO",
    "name": "El Zulia",
    "lat": "7.93248",
    "lng": "-72.60125"
  },
  {
    "country": "CO",
    "name": "El Tambo",
    "lat": "2.45199",
    "lng": "-76.81029"
  },
  {
    "country": "CO",
    "name": "El Tambo",
    "lat": "1.40785",
    "lng": "-77.39218"
  },
  {
    "country": "CO",
    "name": "El Tablón",
    "lat": "1.42717",
    "lng": "-77.09693"
  },
  {
    "country": "CO",
    "name": "El Rosario",
    "lat": "1.74404",
    "lng": "-77.33481"
  },
  {
    "country": "CO",
    "name": "El Rosal",
    "lat": "4.85314",
    "lng": "-74.25996"
  },
  {
    "country": "CO",
    "name": "El Roble",
    "lat": "9.10193",
    "lng": "-75.19508"
  },
  {
    "country": "CO",
    "name": "El Retén",
    "lat": "10.61135",
    "lng": "-74.26824"
  },
  {
    "country": "CO",
    "name": "El Piñón",
    "lat": "10.40283",
    "lng": "-74.82415"
  },
  {
    "country": "CO",
    "name": "El Peñón",
    "lat": "8.98691",
    "lng": "-73.94697"
  },
  {
    "country": "CO",
    "name": "El Peñón",
    "lat": "6.05489",
    "lng": "-73.81519"
  },
  {
    "country": "CO",
    "name": "El Peñón",
    "lat": "5.25264",
    "lng": "-74.29069"
  },
  {
    "country": "CO",
    "name": "El Peñol",
    "lat": "1.45365",
    "lng": "-77.44017"
  },
  {
    "country": "CO",
    "name": "El Paujíl",
    "lat": "1.57006",
    "lng": "-75.32863"
  },
  {
    "country": "CO",
    "name": "El Paso",
    "lat": "9.65724",
    "lng": "-73.74685"
  },
  {
    "country": "CO",
    "name": "El Molino",
    "lat": "10.65296",
    "lng": "-72.92461"
  },
  {
    "country": "CO",
    "name": "Elías",
    "lat": "2.0117",
    "lng": "-75.93968"
  },
  {
    "country": "CO",
    "name": "El Guamo",
    "lat": "10.03155",
    "lng": "-74.97612"
  },
  {
    "country": "CO",
    "name": "El Guacamayo",
    "lat": "6.24518",
    "lng": "-73.49655"
  },
  {
    "country": "CO",
    "name": "El Espino",
    "lat": "6.48277",
    "lng": "-72.49718"
  },
  {
    "country": "CO",
    "name": "El Dovio",
    "lat": "4.5079",
    "lng": "-76.23619"
  },
  {
    "country": "CO",
    "name": "El Doncello",
    "lat": "1.67817",
    "lng": "-75.28466"
  },
  {
    "country": "CO",
    "name": "El Difícil",
    "lat": "9.84975",
    "lng": "-74.23627"
  },
  {
    "country": "CO",
    "name": "El Copey",
    "lat": "10.15031",
    "lng": "-73.9614"
  },
  {
    "country": "CO",
    "name": "El Cocuy",
    "lat": "6.41151",
    "lng": "-72.44876"
  },
  {
    "country": "CO",
    "name": "El Charco",
    "lat": "2.47926",
    "lng": "-78.10972"
  },
  {
    "country": "CO",
    "name": "El Cerrito",
    "lat": "3.68549",
    "lng": "-76.31372"
  },
  {
    "country": "CO",
    "name": "El Castillo",
    "lat": "3.56363",
    "lng": "-73.79488"
  },
  {
    "country": "CO",
    "name": "El Carmen de Bolívar",
    "lat": "9.7174",
    "lng": "-75.12023"
  },
  {
    "country": "CO",
    "name": "El Carmen",
    "lat": "8.51064",
    "lng": "-73.44776"
  },
  {
    "country": "CO",
    "name": "El Carmen de Chucurí",
    "lat": "6.69736",
    "lng": "-73.51117"
  },
  {
    "country": "CO",
    "name": "El Carmen",
    "lat": "5.88778",
    "lng": "-75.16417"
  },
  {
    "country": "CO",
    "name": "El Calvario",
    "lat": "4.35342",
    "lng": "-73.71147"
  },
  {
    "country": "CO",
    "name": "El Cairo",
    "lat": "4.76279",
    "lng": "-76.221"
  },
  {
    "country": "CO",
    "name": "El Bordo",
    "lat": "2.11696",
    "lng": "-76.98214"
  },
  {
    "country": "CO",
    "name": "El Banco",
    "lat": "9.00114",
    "lng": "-73.97581"
  },
  {
    "country": "CO",
    "name": "El Bagre",
    "lat": "7.60347",
    "lng": "-74.80951"
  },
  {
    "country": "CO",
    "name": "Algarrobo",
    "lat": "10.18618",
    "lng": "-74.06085"
  },
  {
    "country": "CO",
    "name": "El Águila",
    "lat": "4.91345",
    "lng": "-76.04004"
  },
  {
    "country": "CO",
    "name": "Ebéjico",
    "lat": "6.32598",
    "lng": "-75.76835"
  },
  {
    "country": "CO",
    "name": "Durania",
    "lat": "7.71307",
    "lng": "-72.65759"
  },
  {
    "country": "CO",
    "name": "Duitama",
    "lat": "5.8245",
    "lng": "-73.03408"
  },
  {
    "country": "CO",
    "name": "Dosquebradas",
    "lat": "4.83916",
    "lng": "-75.66727"
  },
  {
    "country": "CO",
    "name": "Donmatías",
    "lat": "6.48569",
    "lng": "-75.39496"
  },
  {
    "country": "CO",
    "name": "Doima",
    "lat": "4.42692",
    "lng": "-74.97548"
  },
  {
    "country": "CO",
    "name": "Distracción",
    "lat": "10.89784",
    "lng": "-72.88666"
  },
  {
    "country": "CO",
    "name": "Dibulla",
    "lat": "11.27251",
    "lng": "-73.30911"
  },
  {
    "country": "CO",
    "name": "Darien",
    "lat": "3.93135",
    "lng": "-76.48481"
  },
  {
    "country": "CO",
    "name": "Dagua",
    "lat": "3.65685",
    "lng": "-76.68859"
  },
  {
    "country": "CO",
    "name": "Dabeiba",
    "lat": "7.00017",
    "lng": "-76.26915"
  },
  {
    "country": "CO",
    "name": "Curumaní",
    "lat": "9.19992",
    "lng": "-73.54274"
  },
  {
    "country": "CO",
    "name": "Curití",
    "lat": "6.60519",
    "lng": "-73.06809"
  },
  {
    "country": "CO",
    "name": "Cunday",
    "lat": "4.06004",
    "lng": "-74.69212"
  },
  {
    "country": "CO",
    "name": "Cumbitara",
    "lat": "1.64786",
    "lng": "-77.57819"
  },
  {
    "country": "CO",
    "name": "Cumbal",
    "lat": "0.90875",
    "lng": "-77.79145"
  },
  {
    "country": "CO",
    "name": "Cumaribo",
    "lat": "4.44552",
    "lng": "-69.79897"
  },
  {
    "country": "CO",
    "name": "Cumaral",
    "lat": "4.2708",
    "lng": "-73.48669"
  },
  {
    "country": "CO",
    "name": "Cuítiva",
    "lat": "5.58007",
    "lng": "-72.96687"
  },
  {
    "country": "CO",
    "name": "Cucutilla",
    "lat": "7.53941",
    "lng": "-72.77238"
  },
  {
    "country": "CO",
    "name": "Cúcuta",
    "lat": "7.89391",
    "lng": "-72.50782"
  },
  {
    "country": "CO",
    "name": "Cucunubá",
    "lat": "5.24958",
    "lng": "-73.7661"
  },
  {
    "country": "CO",
    "name": "Cucaita",
    "lat": "5.54373",
    "lng": "-73.45433"
  },
  {
    "country": "CO",
    "name": "Cubará",
    "lat": "7.00578",
    "lng": "-72.10568"
  },
  {
    "country": "CO",
    "name": "Cruces de Anorí",
    "lat": "7.18333",
    "lng": "-75.06667"
  },
  {
    "country": "CO",
    "name": "Cravo Norte",
    "lat": "6.30173",
    "lng": "-70.20415"
  },
  {
    "country": "CO",
    "name": "Coyaima",
    "lat": "3.79936",
    "lng": "-75.19467"
  },
  {
    "country": "CO",
    "name": "Coveñas",
    "lat": "9.40254",
    "lng": "-75.68029"
  },
  {
    "country": "CO",
    "name": "Cotorra",
    "lat": "9.03886",
    "lng": "-75.78969"
  },
  {
    "country": "CO",
    "name": "Cota",
    "lat": "4.80938",
    "lng": "-74.098"
  },
  {
    "country": "CO",
    "name": "Corrales",
    "lat": "5.82968",
    "lng": "-72.84332"
  },
  {
    "country": "CO",
    "name": "Corozal",
    "lat": "9.31847",
    "lng": "-75.2933"
  },
  {
    "country": "CO",
    "name": "Coromoro",
    "lat": "6.29461",
    "lng": "-73.04022"
  },
  {
    "country": "CO",
    "name": "Corinto",
    "lat": "3.17301",
    "lng": "-76.26275"
  },
  {
    "country": "CO",
    "name": "Córdoba",
    "lat": "9.58612",
    "lng": "-74.82705"
  },
  {
    "country": "CO",
    "name": "Córdoba",
    "lat": "4.39158",
    "lng": "-75.68723"
  },
  {
    "country": "CO",
    "name": "Córdoba",
    "lat": "0.85362",
    "lng": "-77.51817"
  },
  {
    "country": "CO",
    "name": "Coper",
    "lat": "5.47681",
    "lng": "-74.04416"
  },
  {
    "country": "CO",
    "name": "Copacabana",
    "lat": "6.34633",
    "lng": "-75.50888"
  },
  {
    "country": "CO",
    "name": "Convención",
    "lat": "8.46894",
    "lng": "-73.33765"
  },
  {
    "country": "CO",
    "name": "Contratación",
    "lat": "6.29005",
    "lng": "-73.47354"
  },
  {
    "country": "CO",
    "name": "Contadero",
    "lat": "0.90841",
    "lng": "-77.5477"
  },
  {
    "country": "CO",
    "name": "Consacá",
    "lat": "1.20805",
    "lng": "-77.46548"
  },
  {
    "country": "CO",
    "name": "Confines",
    "lat": "6.35625",
    "lng": "-73.24131"
  },
  {
    "country": "CO",
    "name": "Condoto",
    "lat": "5.09351",
    "lng": "-76.64973"
  },
  {
    "country": "CO",
    "name": "Concordia",
    "lat": "10.25757",
    "lng": "-74.83333"
  },
  {
    "country": "CO",
    "name": "Concordia",
    "lat": "9.83545",
    "lng": "-74.45548"
  },
  {
    "country": "CO",
    "name": "Concordia",
    "lat": "6.04639",
    "lng": "-75.90705"
  },
  {
    "country": "CO",
    "name": "Concepción",
    "lat": "6.76619",
    "lng": "-72.694"
  },
  {
    "country": "CO",
    "name": "Concepción",
    "lat": "6.39408",
    "lng": "-75.2583"
  },
  {
    "country": "CO",
    "name": "Combita",
    "lat": "5.63333",
    "lng": "-73.31667"
  },
  {
    "country": "CO",
    "name": "Cómbita",
    "lat": "5.63312",
    "lng": "-73.32398"
  },
  {
    "country": "CO",
    "name": "Colosó",
    "lat": "9.49477",
    "lng": "-75.35271"
  },
  {
    "country": "CO",
    "name": "Colón",
    "lat": "1.19034",
    "lng": "-76.97369"
  },
  {
    "country": "CO",
    "name": "Colombia",
    "lat": "3.37606",
    "lng": "-74.8015"
  },
  {
    "country": "CO",
    "name": "Cogua",
    "lat": "5.06051",
    "lng": "-73.97925"
  },
  {
    "country": "CO",
    "name": "Coello",
    "lat": "4.40306",
    "lng": "-75.29417"
  },
  {
    "country": "CO",
    "name": "Coello",
    "lat": "4.28908",
    "lng": "-74.89825"
  },
  {
    "country": "CO",
    "name": "Cocorná",
    "lat": "6.0573",
    "lng": "-75.18524"
  },
  {
    "country": "CO",
    "name": "Coconuco",
    "lat": "2.34249",
    "lng": "-76.49581"
  },
  {
    "country": "CO",
    "name": "Clemencia",
    "lat": "10.56645",
    "lng": "-75.32499"
  },
  {
    "country": "CO",
    "name": "Cisneros",
    "lat": "6.53833",
    "lng": "-75.08861"
  },
  {
    "country": "CO",
    "name": "Circasia",
    "lat": "4.61889",
    "lng": "-75.63583"
  },
  {
    "country": "CO",
    "name": "Cimitarra",
    "lat": "6.31419",
    "lng": "-73.94968"
  },
  {
    "country": "CO",
    "name": "Ciénega",
    "lat": "5.40867",
    "lng": "-73.29572"
  },
  {
    "country": "CO",
    "name": "Ciénaga de Oro",
    "lat": "8.87443",
    "lng": "-75.62028"
  },
  {
    "country": "CO",
    "name": "Ciénaga",
    "lat": "11.00703",
    "lng": "-74.24765"
  },
  {
    "country": "CO",
    "name": "Cicuco",
    "lat": "9.27756",
    "lng": "-74.64312"
  },
  {
    "country": "CO",
    "name": "Chocontá",
    "lat": "5.14468",
    "lng": "-73.68578"
  },
  {
    "country": "CO",
    "name": "Choachí",
    "lat": "4.52897",
    "lng": "-73.92273"
  },
  {
    "country": "CO",
    "name": "Chivolo",
    "lat": "10.02502",
    "lng": "-74.62279"
  },
  {
    "country": "CO",
    "name": "Chivatá",
    "lat": "5.55823",
    "lng": "-73.28198"
  },
  {
    "country": "CO",
    "name": "Chitagá",
    "lat": "7.13781",
    "lng": "-72.66456"
  },
  {
    "country": "CO",
    "name": "Chita",
    "lat": "6.19053",
    "lng": "-72.47588"
  },
  {
    "country": "CO",
    "name": "Chiscas",
    "lat": "6.55642",
    "lng": "-72.50378"
  },
  {
    "country": "CO",
    "name": "Chiriguaná",
    "lat": "9.36238",
    "lng": "-73.60313"
  },
  {
    "country": "CO",
    "name": "Chíquiza",
    "lat": "5.60412",
    "lng": "-73.48518"
  },
  {
    "country": "CO",
    "name": "Chiquinquirá",
    "lat": "5.61637",
    "lng": "-73.81748"
  },
  {
    "country": "CO",
    "name": "Chipatá",
    "lat": "6.06196",
    "lng": "-73.63718"
  },
  {
    "country": "CO",
    "name": "Chipaque",
    "lat": "4.4425",
    "lng": "-74.04417"
  },
  {
    "country": "CO",
    "name": "Chinú",
    "lat": "9.10569",
    "lng": "-75.39812"
  },
  {
    "country": "CO",
    "name": "Chinchiná",
    "lat": "4.9825",
    "lng": "-75.60361"
  },
  {
    "country": "CO",
    "name": "Chinavita",
    "lat": "5.16723",
    "lng": "-73.36823"
  },
  {
    "country": "CO",
    "name": "Chinácota",
    "lat": "7.60731",
    "lng": "-72.60108"
  },
  {
    "country": "CO",
    "name": "Chimichagua",
    "lat": "9.25778",
    "lng": "-73.81228"
  },
  {
    "country": "CO",
    "name": "Chimá",
    "lat": "9.14893",
    "lng": "-75.62841"
  },
  {
    "country": "CO",
    "name": "Chima",
    "lat": "6.34431",
    "lng": "-73.37393"
  },
  {
    "country": "CO",
    "name": "Chigorodó",
    "lat": "7.66638",
    "lng": "-76.68106"
  },
  {
    "country": "CO",
    "name": "Chicoral",
    "lat": "4.21536",
    "lng": "-74.98189"
  },
  {
    "country": "CO",
    "name": "Chía",
    "lat": "4.85876",
    "lng": "-74.05866"
  },
  {
    "country": "CO",
    "name": "Charta",
    "lat": "7.28025",
    "lng": "-72.96782"
  },
  {
    "country": "CO",
    "name": "Charalá",
    "lat": "6.28581",
    "lng": "-73.14722"
  },
  {
    "country": "CO",
    "name": "Chaparral",
    "lat": "3.72315",
    "lng": "-75.48316"
  },
  {
    "country": "CO",
    "name": "Chámeza",
    "lat": "5.21421",
    "lng": "-72.86948"
  },
  {
    "country": "CO",
    "name": "Chalán",
    "lat": "9.54765",
    "lng": "-75.31128"
  },
  {
    "country": "CO",
    "name": "Chaguaní",
    "lat": "4.94829",
    "lng": "-74.59392"
  },
  {
    "country": "CO",
    "name": "Chachagüí",
    "lat": "1.35943",
    "lng": "-77.28367"
  },
  {
    "country": "CO",
    "name": "Cértegui",
    "lat": "5.37073",
    "lng": "-76.6044"
  },
  {
    "country": "CO",
    "name": "Cerro de San Antonio",
    "lat": "10.32585",
    "lng": "-74.86933"
  },
  {
    "country": "CO",
    "name": "Cerrito",
    "lat": "6.84315",
    "lng": "-72.69404"
  },
  {
    "country": "CO",
    "name": "Cerinza",
    "lat": "5.95568",
    "lng": "-72.94783"
  },
  {
    "country": "CO",
    "name": "Cereté",
    "lat": "8.88479",
    "lng": "-75.79052"
  },
  {
    "country": "CO",
    "name": "Cepitá",
    "lat": "6.75427",
    "lng": "-72.9744"
  },
  {
    "country": "CO",
    "name": "Caucasia",
    "lat": "7.98654",
    "lng": "-75.19349"
  },
  {
    "country": "CO",
    "name": "Castilla La Nueva",
    "lat": "3.82722",
    "lng": "-73.68831"
  },
  {
    "country": "CO",
    "name": "Casabianca",
    "lat": "5.07959",
    "lng": "-75.12059"
  },
  {
    "country": "CO",
    "name": "Cartago",
    "lat": "4.74639",
    "lng": "-75.91167"
  },
  {
    "country": "CO",
    "name": "Cartago",
    "lat": "1.55151",
    "lng": "-77.11948"
  },
  {
    "country": "CO",
    "name": "Cartagena",
    "lat": "10.39972",
    "lng": "-75.51444"
  },
  {
    "country": "CO",
    "name": "Carolina",
    "lat": "6.72439",
    "lng": "-75.28168"
  },
  {
    "country": "CO",
    "name": "Carmen de Viboral",
    "lat": "6.08236",
    "lng": "-75.33509"
  },
  {
    "country": "CO",
    "name": "Carmen de Carupa",
    "lat": "5.34862",
    "lng": "-73.90168"
  },
  {
    "country": "CO",
    "name": "Carmen de Apicalá",
    "lat": "4.14725",
    "lng": "-74.72014"
  },
  {
    "country": "CO",
    "name": "Carlosama",
    "lat": "0.86292",
    "lng": "-77.72734"
  },
  {
    "country": "CO",
    "name": "Carcasí",
    "lat": "6.62711",
    "lng": "-72.62625"
  },
  {
    "country": "CO",
    "name": "Caramanta",
    "lat": "5.54782",
    "lng": "-75.64368"
  },
  {
    "country": "CO",
    "name": "Caracolí",
    "lat": "6.4092",
    "lng": "-74.75715"
  },
  {
    "country": "CO",
    "name": "Cáqueza",
    "lat": "4.40569",
    "lng": "-73.94683"
  },
  {
    "country": "CO",
    "name": "Capitanejo",
    "lat": "6.52881",
    "lng": "-72.69595"
  },
  {
    "country": "CO",
    "name": "Caparrapí",
    "lat": "5.34644",
    "lng": "-74.49147"
  },
  {
    "country": "CO",
    "name": "Cantagallo",
    "lat": "7.37926",
    "lng": "-73.9155"
  },
  {
    "country": "CO",
    "name": "Candelaria",
    "lat": "10.45912",
    "lng": "-74.8797"
  },
  {
    "country": "CO",
    "name": "Candelaria",
    "lat": "3.40671",
    "lng": "-76.34819"
  },
  {
    "country": "CO",
    "name": "Cañasgordas",
    "lat": "6.74989",
    "lng": "-76.02539"
  },
  {
    "country": "CO",
    "name": "Canalete",
    "lat": "8.78558",
    "lng": "-76.24065"
  },
  {
    "country": "CO",
    "name": "Campohermoso",
    "lat": "5.03132",
    "lng": "-73.10327"
  },
  {
    "country": "CO",
    "name": "Campo de la Cruz",
    "lat": "10.37808",
    "lng": "-74.88356"
  },
  {
    "country": "CO",
    "name": "Campoalegre",
    "lat": "2.68489",
    "lng": "-75.32311"
  },
  {
    "country": "CO",
    "name": "Campamento",
    "lat": "6.9792",
    "lng": "-75.29724"
  },
  {
    "country": "CO",
    "name": "Caloto",
    "lat": "3.03586",
    "lng": "-76.40788"
  },
  {
    "country": "CO",
    "name": "Calimita",
    "lat": "3.91667",
    "lng": "-76.5"
  },
  {
    "country": "CO",
    "name": "California",
    "lat": "7.34776",
    "lng": "-72.9458"
  },
  {
    "country": "CO",
    "name": "Cali",
    "lat": "3.43722",
    "lng": "-76.5225"
  },
  {
    "country": "CO",
    "name": "Caldono",
    "lat": "2.79739",
    "lng": "-76.48316"
  },
  {
    "country": "CO",
    "name": "Caldas",
    "lat": "6.09106",
    "lng": "-75.63569"
  },
  {
    "country": "CO",
    "name": "Caldas",
    "lat": "5.55456",
    "lng": "-73.86567"
  },
  {
    "country": "CO",
    "name": "Calarcá",
    "lat": "4.52949",
    "lng": "-75.64091"
  },
  {
    "country": "CO",
    "name": "Calamar",
    "lat": "10.25271",
    "lng": "-74.91574"
  },
  {
    "country": "CO",
    "name": "Calamar",
    "lat": "1.9596",
    "lng": "-72.65315"
  },
  {
    "country": "CO",
    "name": "Cajicá",
    "lat": "4.91857",
    "lng": "-74.02799"
  },
  {
    "country": "CO",
    "name": "Cajibío",
    "lat": "2.62271",
    "lng": "-76.57039"
  },
  {
    "country": "CO",
    "name": "Cajamarca",
    "lat": "4.44234",
    "lng": "-75.42874"
  },
  {
    "country": "CO",
    "name": "Caimito",
    "lat": "8.78962",
    "lng": "-75.11686"
  },
  {
    "country": "CO",
    "name": "Caicedonia",
    "lat": "4.3324",
    "lng": "-75.82665"
  },
  {
    "country": "CO",
    "name": "Caicedo",
    "lat": "6.40511",
    "lng": "-75.98255"
  },
  {
    "country": "CO",
    "name": "Cácota",
    "lat": "7.26787",
    "lng": "-72.64197"
  },
  {
    "country": "CO",
    "name": "Cáchira",
    "lat": "7.74104",
    "lng": "-73.0483"
  },
  {
    "country": "CO",
    "name": "Cachipay",
    "lat": "5.26667",
    "lng": "-74.56667"
  },
  {
    "country": "CO",
    "name": "Cachipay",
    "lat": "4.73035",
    "lng": "-74.43663"
  },
  {
    "country": "CO",
    "name": "Cáceres",
    "lat": "7.58078",
    "lng": "-75.34842"
  },
  {
    "country": "CO",
    "name": "Cabuyaro",
    "lat": "4.2817",
    "lng": "-72.79399"
  },
  {
    "country": "CO",
    "name": "Cabrera",
    "lat": "6.5928",
    "lng": "-73.2465"
  },
  {
    "country": "CO",
    "name": "Cabrera",
    "lat": "3.98598",
    "lng": "-74.48283"
  },
  {
    "country": "CO",
    "name": "Busbanzá",
    "lat": "5.83047",
    "lng": "-72.88419"
  },
  {
    "country": "CO",
    "name": "Bugalagrande",
    "lat": "4.21207",
    "lng": "-76.15564"
  },
  {
    "country": "CO",
    "name": "Guadalajara de Buga",
    "lat": "3.90089",
    "lng": "-76.29783"
  },
  {
    "country": "CO",
    "name": "Buesaco",
    "lat": "1.38364",
    "lng": "-77.15622"
  },
  {
    "country": "CO",
    "name": "Buenos Aires",
    "lat": "3.01397",
    "lng": "-76.64612"
  },
  {
    "country": "CO",
    "name": "Buenavista",
    "lat": "9.31939",
    "lng": "-74.97358"
  },
  {
    "country": "CO",
    "name": "Buenavista",
    "lat": "9.21433",
    "lng": "-74.31363"
  },
  {
    "country": "CO",
    "name": "Buenavista",
    "lat": "9.04963",
    "lng": "-76.0028"
  },
  {
    "country": "CO",
    "name": "Buenavista",
    "lat": "8.22245",
    "lng": "-75.48173"
  },
  {
    "country": "CO",
    "name": "Buenavista",
    "lat": "5.51377",
    "lng": "-73.94913"
  },
  {
    "country": "CO",
    "name": "Buenavista",
    "lat": "4.35969",
    "lng": "-75.73888"
  },
  {
    "country": "CO",
    "name": "Buenaventura",
    "lat": "3.8801",
    "lng": "-77.03116"
  },
  {
    "country": "CO",
    "name": "Buenaventura",
    "lat": "3.58333",
    "lng": "-77"
  },
  {
    "country": "CO",
    "name": "Bucarasica",
    "lat": "8.04096",
    "lng": "-72.86538"
  },
  {
    "country": "CO",
    "name": "Bucaramanga",
    "lat": "7.12539",
    "lng": "-73.1198"
  },
  {
    "country": "CO",
    "name": "Briceño",
    "lat": "7.11096",
    "lng": "-75.55152"
  },
  {
    "country": "CO",
    "name": "Briceño",
    "lat": "5.68822",
    "lng": "-73.91784"
  },
  {
    "country": "CO",
    "name": "Providencia",
    "lat": "1.23907",
    "lng": "-77.59721"
  },
  {
    "country": "CO",
    "name": "Boyacá",
    "lat": "5.45371",
    "lng": "-73.3625"
  },
  {
    "country": "CO",
    "name": "Bosconia",
    "lat": "9.97106",
    "lng": "-73.88817"
  },
  {
    "country": "CO",
    "name": "Bolívar",
    "lat": "5.9893",
    "lng": "-73.77058"
  },
  {
    "country": "CO",
    "name": "Bolívar",
    "lat": "4.3387",
    "lng": "-76.18342"
  },
  {
    "country": "CO",
    "name": "Bolívar",
    "lat": "1.83994",
    "lng": "-76.96889"
  },
  {
    "country": "CO",
    "name": "Bojacá",
    "lat": "4.73176",
    "lng": "-74.34129"
  },
  {
    "country": "CO",
    "name": "Bogotá",
    "lat": "4.60971",
    "lng": "-74.08175"
  },
  {
    "country": "CO",
    "name": "Bochalema",
    "lat": "7.61095",
    "lng": "-72.64773"
  },
  {
    "country": "CO",
    "name": "Bocas de Satinga",
    "lat": "2.34814",
    "lng": "-78.32571"
  },
  {
    "country": "CO",
    "name": "Curbaradó",
    "lat": "7.15778",
    "lng": "-76.97111"
  },
  {
    "country": "CO",
    "name": "Boavita",
    "lat": "6.33031",
    "lng": "-72.58505"
  },
  {
    "country": "CO",
    "name": "Bituima",
    "lat": "4.87252",
    "lng": "-74.53925"
  },
  {
    "country": "CO",
    "name": "Betulia",
    "lat": "6.90069",
    "lng": "-73.28347"
  },
  {
    "country": "CO",
    "name": "Betulia",
    "lat": "6.11284",
    "lng": "-75.98378"
  },
  {
    "country": "CO",
    "name": "Betéitiva",
    "lat": "5.91102",
    "lng": "-72.80926"
  },
  {
    "country": "CO",
    "name": "Beté",
    "lat": "5.99458",
    "lng": "-76.7812"
  },
  {
    "country": "CO",
    "name": "Betania",
    "lat": "5.74601",
    "lng": "-75.97765"
  },
  {
    "country": "CO",
    "name": "Arboleda",
    "lat": "1.49766",
    "lng": "-77.13587"
  },
  {
    "country": "CO",
    "name": "Berbeo",
    "lat": "5.22675",
    "lng": "-73.12608"
  },
  {
    "country": "CO",
    "name": "Beltrán",
    "lat": "4.80165",
    "lng": "-74.74177"
  },
  {
    "country": "CO",
    "name": "Belmira",
    "lat": "6.60508",
    "lng": "-75.66619"
  },
  {
    "country": "CO",
    "name": "Bello",
    "lat": "6.33732",
    "lng": "-75.55795"
  },
  {
    "country": "CO",
    "name": "Belén de Umbría",
    "lat": "5.20087",
    "lng": "-75.86865"
  },
  {
    "country": "CO",
    "name": "Belén de los Andaquíes",
    "lat": "1.41828",
    "lng": "-75.87753"
  },
  {
    "country": "CO",
    "name": "Belén",
    "lat": "5.98892",
    "lng": "-72.91254"
  },
  {
    "country": "CO",
    "name": "Belén",
    "lat": "1.59477",
    "lng": "-77.05408"
  },
  {
    "country": "CO",
    "name": "Belalcázar",
    "lat": "4.99528",
    "lng": "-75.81278"
  },
  {
    "country": "CO",
    "name": "Becerril",
    "lat": "9.70413",
    "lng": "-73.2793"
  },
  {
    "country": "CO",
    "name": "Barranquilla",
    "lat": "10.96854",
    "lng": "-74.78132"
  },
  {
    "country": "CO",
    "name": "Barranco de Loba",
    "lat": "8.94597",
    "lng": "-74.10647"
  },
  {
    "country": "CO",
    "name": "Barrancas",
    "lat": "10.95672",
    "lng": "-72.79456"
  },
  {
    "country": "CO",
    "name": "Barranca de Upía",
    "lat": "4.56963",
    "lng": "-72.96676"
  },
  {
    "country": "CO",
    "name": "Barrancabermeja",
    "lat": "7.06528",
    "lng": "-73.85472"
  },
  {
    "country": "CO",
    "name": "Barichara",
    "lat": "6.63572",
    "lng": "-73.22282"
  },
  {
    "country": "CO",
    "name": "Barbosa",
    "lat": "6.43809",
    "lng": "-75.33136"
  },
  {
    "country": "CO",
    "name": "Barbosa",
    "lat": "5.93168",
    "lng": "-73.61507"
  },
  {
    "country": "CO",
    "name": "Barbacoas",
    "lat": "1.67154",
    "lng": "-78.13978"
  },
  {
    "country": "CO",
    "name": "Baraya",
    "lat": "3.15333",
    "lng": "-75.05306"
  },
  {
    "country": "CO",
    "name": "Baranoa",
    "lat": "10.79408",
    "lng": "-74.9164"
  },
  {
    "country": "CO",
    "name": "Balboa",
    "lat": "4.94985",
    "lng": "-75.95826"
  },
  {
    "country": "CO",
    "name": "Balboa",
    "lat": "2.04183",
    "lng": "-77.21646"
  },
  {
    "country": "CO",
    "name": "Bahía Solano",
    "lat": "6.22622",
    "lng": "-77.40439"
  },
  {
    "country": "CO",
    "name": "Bagadó",
    "lat": "5.41164",
    "lng": "-76.4152"
  },
  {
    "country": "CO",
    "name": "Ayapel",
    "lat": "8.31372",
    "lng": "-75.13982"
  },
  {
    "country": "CO",
    "name": "Ataco",
    "lat": "3.59147",
    "lng": "-75.38178"
  },
  {
    "country": "CO",
    "name": "Astrea",
    "lat": "9.49828",
    "lng": "-73.97591"
  },
  {
    "country": "CO",
    "name": "Arroyohondo",
    "lat": "10.2522",
    "lng": "-75.0198"
  },
  {
    "country": "CO",
    "name": "Guayabal",
    "lat": "5.03103",
    "lng": "-74.88683"
  },
  {
    "country": "CO",
    "name": "Armenia",
    "lat": "6.15639",
    "lng": "-75.78722"
  },
  {
    "country": "CO",
    "name": "Armenia",
    "lat": "4.53389",
    "lng": "-75.68111"
  },
  {
    "country": "CO",
    "name": "Arjona",
    "lat": "10.25444",
    "lng": "-75.34389"
  },
  {
    "country": "CO",
    "name": "Ariguaní",
    "lat": "10.25",
    "lng": "-74"
  },
  {
    "country": "CO",
    "name": "Argelia",
    "lat": "5.73127",
    "lng": "-75.14257"
  },
  {
    "country": "CO",
    "name": "Argelia",
    "lat": "4.72342",
    "lng": "-76.11909"
  },
  {
    "country": "CO",
    "name": "Argelia",
    "lat": "2.25563",
    "lng": "-77.24876"
  },
  {
    "country": "CO",
    "name": "Arenal",
    "lat": "8.45928",
    "lng": "-73.94331"
  },
  {
    "country": "CO",
    "name": "Arcabuco",
    "lat": "5.75463",
    "lng": "-73.43669"
  },
  {
    "country": "CO",
    "name": "Arboletes",
    "lat": "8.85051",
    "lng": "-76.42694"
  },
  {
    "country": "CO",
    "name": "Arboledas",
    "lat": "7.64233",
    "lng": "-72.79944"
  },
  {
    "country": "CO",
    "name": "Arbeláez",
    "lat": "4.27254",
    "lng": "-74.41513"
  },
  {
    "country": "CO",
    "name": "Arauquita",
    "lat": "7.02917",
    "lng": "-71.42806"
  },
  {
    "country": "CO",
    "name": "Arauca",
    "lat": "7.08471",
    "lng": "-70.75908"
  },
  {
    "country": "CO",
    "name": "Aratoca",
    "lat": "6.69432",
    "lng": "-73.01868"
  },
  {
    "country": "CO",
    "name": "Aranzazu",
    "lat": "5.27123",
    "lng": "-75.49044"
  },
  {
    "country": "CO",
    "name": "Aracataca",
    "lat": "10.59181",
    "lng": "-74.18983"
  },
  {
    "country": "CO",
    "name": "Aquitania",
    "lat": "5.51858",
    "lng": "-72.88387"
  },
  {
    "country": "CO",
    "name": "Apía",
    "lat": "5.10658",
    "lng": "-75.94244"
  },
  {
    "country": "CO",
    "name": "Apartadó",
    "lat": "7.88299",
    "lng": "-76.62587"
  },
  {
    "country": "CO",
    "name": "Anzoátegui",
    "lat": "4.63087",
    "lng": "-75.0946"
  },
  {
    "country": "CO",
    "name": "Anzá",
    "lat": "6.30322",
    "lng": "-75.85381"
  },
  {
    "country": "CO",
    "name": "Santa Fe de Antioquia",
    "lat": "6.55687",
    "lng": "-75.82806"
  },
  {
    "country": "CO",
    "name": "Ansermanuevo",
    "lat": "4.79722",
    "lng": "-75.995"
  },
  {
    "country": "CO",
    "name": "Anserma",
    "lat": "5.33278",
    "lng": "-75.79111"
  },
  {
    "country": "CO",
    "name": "Anorí",
    "lat": "7.07273",
    "lng": "-75.14768"
  },
  {
    "country": "CO",
    "name": "Anolaima",
    "lat": "4.83362",
    "lng": "-74.4995"
  },
  {
    "country": "CO",
    "name": "Angostura",
    "lat": "6.88508",
    "lng": "-75.33467"
  },
  {
    "country": "CO",
    "name": "Angelópolis",
    "lat": "6.11072",
    "lng": "-75.70923"
  },
  {
    "country": "CO",
    "name": "Andes",
    "lat": "5.6561",
    "lng": "-75.87877"
  },
  {
    "country": "CO",
    "name": "Andalucía",
    "lat": "4.17061",
    "lng": "-76.16641"
  },
  {
    "country": "CO",
    "name": "Ancuya",
    "lat": "1.2633",
    "lng": "-77.51376"
  },
  {
    "country": "CO",
    "name": "Anapoima",
    "lat": "4.55099",
    "lng": "-74.53517"
  },
  {
    "country": "CO",
    "name": "Anaime",
    "lat": "4.39639",
    "lng": "-75.445"
  },
  {
    "country": "CO",
    "name": "Ambalema",
    "lat": "4.78405",
    "lng": "-74.76268"
  },
  {
    "country": "CO",
    "name": "Amalfi",
    "lat": "6.91016",
    "lng": "-75.07764"
  },
  {
    "country": "CO",
    "name": "Amagá",
    "lat": "6.04001",
    "lng": "-75.70315"
  },
  {
    "country": "CO",
    "name": "Alvarado",
    "lat": "4.56826",
    "lng": "-74.9523"
  },
  {
    "country": "CO",
    "name": "Altamira",
    "lat": "2.06278",
    "lng": "-75.78722"
  },
  {
    "country": "CO",
    "name": "Almeida",
    "lat": "4.97083",
    "lng": "-73.37972"
  },
  {
    "country": "CO",
    "name": "Almaguer",
    "lat": "1.91472",
    "lng": "-76.85482"
  },
  {
    "country": "CO",
    "name": "Algeciras",
    "lat": "2.52385",
    "lng": "-75.31733"
  },
  {
    "country": "CO",
    "name": "Algarrobo",
    "lat": "10.18694",
    "lng": "-74.57528"
  },
  {
    "country": "CO",
    "name": "Alejandría",
    "lat": "6.37745",
    "lng": "-75.14065"
  },
  {
    "country": "CO",
    "name": "Aldana",
    "lat": "0.88283",
    "lng": "-77.70103"
  },
  {
    "country": "CO",
    "name": "Alcalá",
    "lat": "4.67472",
    "lng": "-75.7825"
  },
  {
    "country": "CO",
    "name": "Albania",
    "lat": "11.16099",
    "lng": "-72.59238"
  },
  {
    "country": "CO",
    "name": "Albania",
    "lat": "5.75894",
    "lng": "-73.91376"
  },
  {
    "country": "CO",
    "name": "Albania",
    "lat": "1.32866",
    "lng": "-75.87824"
  },
  {
    "country": "CO",
    "name": "Albán",
    "lat": "4.87661",
    "lng": "-74.43768"
  },
  {
    "country": "CO",
    "name": "Aipe",
    "lat": "3.22222",
    "lng": "-75.23667"
  },
  {
    "country": "CO",
    "name": "Aguazul",
    "lat": "5.17282",
    "lng": "-72.54706"
  },
  {
    "country": "CO",
    "name": "Agua de Dios",
    "lat": "4.37648",
    "lng": "-74.66995"
  },
  {
    "country": "CO",
    "name": "Aguadas",
    "lat": "5.61161",
    "lng": "-75.45624"
  },
  {
    "country": "CO",
    "name": "Aguachica",
    "lat": "8.30844",
    "lng": "-73.6166"
  },
  {
    "country": "CO",
    "name": "Agrado",
    "lat": "2.25725",
    "lng": "-75.77142"
  },
  {
    "country": "CO",
    "name": "Achí",
    "lat": "8.5695",
    "lng": "-74.55715"
  },
  {
    "country": "CO",
    "name": "Acevedo",
    "lat": "1.80464",
    "lng": "-75.89036"
  },
  {
    "country": "CO",
    "name": "Acandí",
    "lat": "8.51158",
    "lng": "-77.27719"
  },
  {
    "country": "CO",
    "name": "Acacías",
    "lat": "3.98695",
    "lng": "-73.75797"
  },
  {
    "country": "CO",
    "name": "Abriaquí",
    "lat": "6.63148",
    "lng": "-76.06444"
  },
  {
    "country": "CO",
    "name": "Ábrego",
    "lat": "8.08065",
    "lng": "-73.22054"
  },
  {
    "country": "CO",
    "name": "Abejorral",
    "lat": "5.78928",
    "lng": "-75.42725"
  },
  {
    "country": "CO",
    "name": "Los Santos",
    "lat": "7.17",
    "lng": "-73.09306"
  },
  {
    "country": "CO",
    "name": "Lejanías",
    "lat": "3.52762",
    "lng": "-74.02335"
  },
  {
    "country": "CO",
    "name": "El Dorado",
    "lat": "2.77411",
    "lng": "-72.86834"
  },
  {
    "country": "CO",
    "name": "Curillo",
    "lat": "1.03327",
    "lng": "-75.91907"
  },
  {
    "country": "CO",
    "name": "Laureles",
    "lat": "4.25917",
    "lng": "-75.3225"
  },
  {
    "country": "CO",
    "name": "Santacruz",
    "lat": "1.5209",
    "lng": "-77.26206"
  },
  {
    "country": "CO",
    "name": "Campo Alegre",
    "lat": "3.18917",
    "lng": "-75.70361"
  },
  {
    "country": "CO",
    "name": "Santiago Pérez",
    "lat": "3.39806",
    "lng": "-75.605"
  },
  {
    "country": "CO",
    "name": "El Tarra",
    "lat": "8.57562",
    "lng": "-73.09489"
  },
  {
    "country": "CO",
    "name": "Labateca",
    "lat": "7.29889",
    "lng": "-72.49472"
  },
  {
    "country": "CO",
    "name": "La Hormiga",
    "lat": "0.4258",
    "lng": "-76.90558"
  },
  {
    "country": "CO",
    "name": "Mesetas",
    "lat": "3.38463",
    "lng": "-74.04424"
  },
  {
    "country": "CO",
    "name": "Bellavista",
    "lat": "6.55645",
    "lng": "-76.88389"
  },
  {
    "country": "CO",
    "name": "Génova",
    "lat": "4.20796",
    "lng": "-75.78881"
  },
  {
    "country": "CO",
    "name": "Chivor",
    "lat": "4.88556",
    "lng": "-73.36889"
  },
  {
    "country": "CO",
    "name": "Monterrey",
    "lat": "4.87802",
    "lng": "-72.89575"
  },
  {
    "country": "CO",
    "name": "Paratebueno",
    "lat": "4.37575",
    "lng": "-73.21547"
  },
  {
    "country": "CO",
    "name": "Puerto Gaitán",
    "lat": "4.31328",
    "lng": "-72.08157"
  },
  {
    "country": "CO",
    "name": "Sabanalarga",
    "lat": "4.8543",
    "lng": "-73.04003"
  },
  {
    "country": "CO",
    "name": "Villanueva",
    "lat": "4.61208",
    "lng": "-72.92761"
  },
  {
    "country": "CO",
    "name": "Puerto Nare",
    "lat": "6.18762",
    "lng": "-74.59972"
  },
  {
    "country": "CO",
    "name": "Morales",
    "lat": "2.75446",
    "lng": "-76.62791"
  },
  {
    "country": "CO",
    "name": "Villa Rica",
    "lat": "2.5142",
    "lng": "-76.84939"
  },
  {
    "country": "CO",
    "name": "Quípama",
    "lat": "5.5194",
    "lng": "-74.17765"
  },
  {
    "country": "CO",
    "name": "La Cumbre",
    "lat": "3.7225",
    "lng": "-76.02083"
  },
  {
    "country": "CO",
    "name": "Canalete",
    "lat": "8.67611",
    "lng": "-76.20417"
  },
  {
    "country": "CO",
    "name": "Fredonia",
    "lat": "5.92583",
    "lng": "-75.67056"
  },
  {
    "country": "CO",
    "name": "Santa María",
    "lat": "2.93897",
    "lng": "-75.5858"
  },
  {
    "country": "CO",
    "name": "Gachetá",
    "lat": "4.81854",
    "lng": "-73.63659"
  },
  {
    "country": "CO",
    "name": "San Carlos",
    "lat": "8.74372",
    "lng": "-75.71331"
  },
  {
    "country": "CO",
    "name": "San Andrés",
    "lat": "6.90333",
    "lng": "-75.6825"
  },
  {
    "country": "CO",
    "name": "Buriticá",
    "lat": "6.71873",
    "lng": "-75.90734"
  },
  {
    "country": "CO",
    "name": "Carepa",
    "lat": "7.75849",
    "lng": "-76.65255"
  },
  {
    "country": "CO",
    "name": "Ciudad Bolívar",
    "lat": "5.85389",
    "lng": "-76.02528"
  },
  {
    "country": "CO",
    "name": "Vegachí",
    "lat": "6.76141",
    "lng": "-74.79473"
  },
  {
    "country": "CO",
    "name": "Altos del Rosario",
    "lat": "8.79162",
    "lng": "-74.16556"
  },
  {
    "country": "CO",
    "name": "Santa Rosa del Sur",
    "lat": "7.96444",
    "lng": "-74.05444"
  },
  {
    "country": "CO",
    "name": "Tiquisio",
    "lat": "8.55666",
    "lng": "-74.26355"
  },
  {
    "country": "CO",
    "name": "Covarachía",
    "lat": "6.50563",
    "lng": "-72.7331"
  },
  {
    "country": "CO",
    "name": "Cartagena del Chairá",
    "lat": "1.33488",
    "lng": "-74.84289"
  },
  {
    "country": "CO",
    "name": "Agustín Codazzi",
    "lat": "10.03672",
    "lng": "-73.23558"
  },
  {
    "country": "CO",
    "name": "Manaure Balcón del Cesar",
    "lat": "10.39278",
    "lng": "-73.0325"
  },
  {
    "country": "CO",
    "name": "San Martín",
    "lat": "8.00151",
    "lng": "-73.51126"
  },
  {
    "country": "CO",
    "name": "El Cantón de San Pablo",
    "lat": "5.33889",
    "lng": "-76.73139"
  },
  {
    "country": "CO",
    "name": "El Retorno",
    "lat": "2.33022",
    "lng": "-72.62765"
  },
  {
    "country": "CO",
    "name": "Isnos",
    "lat": "1.93556",
    "lng": "-76.24056"
  },
  {
    "country": "CO",
    "name": "Plato",
    "lat": "9.79029",
    "lng": "-74.78244"
  },
  {
    "country": "CO",
    "name": "El Dorado",
    "lat": "3.73924",
    "lng": "-73.83489"
  },
  {
    "country": "CO",
    "name": "Mapiripán",
    "lat": "2.89115",
    "lng": "-72.13328"
  },
  {
    "country": "CO",
    "name": "Puerto Concordia",
    "lat": "2.62206",
    "lng": "-72.75724"
  },
  {
    "country": "CO",
    "name": "La Tola",
    "lat": "2.39949",
    "lng": "-78.18923"
  },
  {
    "country": "CO",
    "name": "La Esperanza",
    "lat": "7.64059",
    "lng": "-73.32762"
  },
  {
    "country": "CO",
    "name": "Puerto Guzmán",
    "lat": "0.97028",
    "lng": "-76.58583"
  },
  {
    "country": "CO",
    "name": "El Playón",
    "lat": "7.47131",
    "lng": "-73.2031"
  },
  {
    "country": "CO",
    "name": "Santa Helena del Opón",
    "lat": "6.33997",
    "lng": "-73.61696"
  },
  {
    "country": "CO",
    "name": "Carurú",
    "lat": "1.01402",
    "lng": "-71.29624"
  },
  {
    "country": "CO",
    "name": "Tibacuy",
    "lat": "4.35111",
    "lng": "-72.45639"
  },
  {
    "country": "CO",
    "name": "Santa Genoveva de Docordó",
    "lat": "4.25875",
    "lng": "-77.36516"
  },
  {
    "country": "CO",
    "name": "Aguada",
    "lat": "6.16232",
    "lng": "-73.5221"
  },
  {
    "country": "CO",
    "name": "La Macarena",
    "lat": "2.18266",
    "lng": "-73.7871"
  },
  {
    "country": "CO",
    "name": "Valle del Guamuez",
    "lat": "0.4525",
    "lng": "-76.91917"
  },
  {
    "country": "CO",
    "name": "Santa Isabel",
    "lat": "3.34944",
    "lng": "-74.98056"
  },
  {
    "country": "CO",
    "name": "San José del Fragua",
    "lat": "1.33196",
    "lng": "-75.97409"
  },
  {
    "country": "CO",
    "name": "San José del Guaviare",
    "lat": "2.57286",
    "lng": "-72.64591"
  },
  {
    "country": "CO",
    "name": "Orito",
    "lat": "0.66749",
    "lng": "-76.87297"
  },
  {
    "country": "CO",
    "name": "Puerto Caicedo",
    "lat": "0.68362",
    "lng": "-76.60439"
  },
  {
    "country": "CO",
    "name": "Solita",
    "lat": "0.87516",
    "lng": "-75.61943"
  },
  {
    "country": "CO",
    "name": "Samaná",
    "lat": "5.41258",
    "lng": "-74.99219"
  },
  {
    "country": "CO",
    "name": "Puerto Guzmán",
    "lat": "0.96454",
    "lng": "-76.40795"
  },
  {
    "country": "CO",
    "name": "Piamonte",
    "lat": "1.12002",
    "lng": "-76.32131"
  },
  {
    "country": "CO",
    "name": "Rionegro",
    "lat": "7.26456",
    "lng": "-73.15012"
  },
  {
    "country": "CO",
    "name": "Alpujarra",
    "lat": "3.39176",
    "lng": "-74.93344"
  },
  {
    "country": "CO",
    "name": "Dolores",
    "lat": "3.5391",
    "lng": "-74.89752"
  },
  {
    "country": "CO",
    "name": "Puerto Lleras",
    "lat": "3.26942",
    "lng": "-73.37537"
  },
  {
    "country": "CO",
    "name": "Piendamo",
    "lat": "2.63918",
    "lng": "-76.53055"
  },
  {
    "country": "CO",
    "name": "Barrio San Luis",
    "lat": "4.66779",
    "lng": "-74.0215"
  },
  {
    "country": "CO",
    "name": "Armero-Guyabal",
    "lat": "4.96701",
    "lng": "-74.90294"
  },
  {
    "country": "CO",
    "name": "Sopetrán",
    "lat": "6.5018",
    "lng": "-75.74309"
  },
  {
    "country": "CO",
    "name": "Valdivia",
    "lat": "7.16433",
    "lng": "-75.43906"
  },
  {
    "country": "CO",
    "name": "Socha",
    "lat": "5.99732",
    "lng": "-72.69138"
  },
  {
    "country": "CO",
    "name": "Chitaraque",
    "lat": "6.02839",
    "lng": "-73.44703"
  },
  {
    "country": "CO",
    "name": "San Fernando",
    "lat": "9.21093",
    "lng": "-74.31797"
  },
  {
    "country": "CO",
    "name": "San Martín de Loba",
    "lat": "8.936",
    "lng": "-74.03975"
  },
  {
    "country": "CO",
    "name": "Anserma",
    "lat": "5.23479",
    "lng": "-75.78465"
  },
  {
    "country": "CO",
    "name": "La Merced",
    "lat": "5.39961",
    "lng": "-75.54719"
  },
  {
    "country": "CO",
    "name": "El Carmen de Atrato",
    "lat": "5.89862",
    "lng": "-76.14205"
  },
  {
    "country": "CO",
    "name": "Puerto Libertador",
    "lat": "7.8894",
    "lng": "-75.67015"
  },
  {
    "country": "CO",
    "name": "La Apartada",
    "lat": "8.04911",
    "lng": "-75.33728"
  },
  {
    "country": "CO",
    "name": "San Cayetano",
    "lat": "5.3359",
    "lng": "-74.02659"
  },
  {
    "country": "CO",
    "name": "Ubalá",
    "lat": "4.74389",
    "lng": "-73.53472"
  },
  {
    "country": "CO",
    "name": "El Colegio",
    "lat": "4.58103",
    "lng": "-74.44293"
  },
  {
    "country": "CR",
    "name": "Zarcero",
    "lat": "10.18561",
    "lng": "-84.39076"
  },
  {
    "country": "CR",
    "name": "Zapotal",
    "lat": "10",
    "lng": "-85.3"
  },
  {
    "country": "CR",
    "name": "Upala",
    "lat": "10.89792",
    "lng": "-85.01454"
  },
  {
    "country": "CR",
    "name": "Turrialba",
    "lat": "9.90467",
    "lng": "-83.68352"
  },
  {
    "country": "CR",
    "name": "Tucurrique",
    "lat": "9.85336",
    "lng": "-83.72273"
  },
  {
    "country": "CR",
    "name": "Tres Ríos",
    "lat": "9.90644",
    "lng": "-83.9876"
  },
  {
    "country": "CR",
    "name": "Tobosi",
    "lat": "9.83837",
    "lng": "-83.98391"
  },
  {
    "country": "CR",
    "name": "Tilarán",
    "lat": "10.46701",
    "lng": "-84.96775"
  },
  {
    "country": "CR",
    "name": "Tejar",
    "lat": "9.74622",
    "lng": "-84.23368"
  },
  {
    "country": "CR",
    "name": "Sixaola",
    "lat": "9.52766",
    "lng": "-82.62185"
  },
  {
    "country": "CR",
    "name": "Siquirres",
    "lat": "10.09748",
    "lng": "-83.50659"
  },
  {
    "country": "CR",
    "name": "Sardinal",
    "lat": "10.51674",
    "lng": "-85.64748"
  },
  {
    "country": "CR",
    "name": "Sarchí",
    "lat": "10.0897",
    "lng": "-84.34752"
  },
  {
    "country": "CR",
    "name": "San Vito",
    "lat": "8.82079",
    "lng": "-82.97092"
  },
  {
    "country": "CR",
    "name": "San Vicente",
    "lat": "9.96016",
    "lng": "-84.04762"
  },
  {
    "country": "CR",
    "name": "Santo Domingo",
    "lat": "10.06389",
    "lng": "-84.15499"
  },
  {
    "country": "CR",
    "name": "Santiago",
    "lat": "10.02275",
    "lng": "-84.4442"
  },
  {
    "country": "CR",
    "name": "Santiago",
    "lat": "9.84636",
    "lng": "-84.31428"
  },
  {
    "country": "CR",
    "name": "Santa Cruz",
    "lat": "10.26053",
    "lng": "-85.5851"
  },
  {
    "country": "CR",
    "name": "Santa Ana",
    "lat": "9.9326",
    "lng": "-84.18255"
  },
  {
    "country": "CR",
    "name": "San Ramón",
    "lat": "10.08802",
    "lng": "-84.47022"
  },
  {
    "country": "CR",
    "name": "San Rafael Arriba",
    "lat": "9.87556",
    "lng": "-84.07661"
  },
  {
    "country": "CR",
    "name": "San Rafael Abajo",
    "lat": "9.831",
    "lng": "-84.29008"
  },
  {
    "country": "CR",
    "name": "San Rafael",
    "lat": "10.06403",
    "lng": "-84.47281"
  },
  {
    "country": "CR",
    "name": "San Rafael",
    "lat": "10.0132",
    "lng": "-84.10016"
  },
  {
    "country": "CR",
    "name": "San Rafael",
    "lat": "9.92787",
    "lng": "-84.13722"
  },
  {
    "country": "CR",
    "name": "San Pedro",
    "lat": "9.92829",
    "lng": "-84.05074"
  },
  {
    "country": "CR",
    "name": "San Pablo",
    "lat": "9.99559",
    "lng": "-84.09656"
  },
  {
    "country": "CR",
    "name": "San Pablo",
    "lat": "9.68323",
    "lng": "-84.0405"
  },
  {
    "country": "CR",
    "name": "San Miguel",
    "lat": "9.87121",
    "lng": "-84.06084"
  },
  {
    "country": "CR",
    "name": "San Marcos",
    "lat": "9.6601",
    "lng": "-84.02026"
  },
  {
    "country": "CR",
    "name": "San Juan de Dios",
    "lat": "9.8773",
    "lng": "-84.0847"
  },
  {
    "country": "CR",
    "name": "San Juan",
    "lat": "10.10248",
    "lng": "-84.31694"
  },
  {
    "country": "CR",
    "name": "San Juan",
    "lat": "9.95974",
    "lng": "-84.08165"
  },
  {
    "country": "CR",
    "name": "San Josecito",
    "lat": "10.01667",
    "lng": "-84.1"
  },
  {
    "country": "CR",
    "name": "San José",
    "lat": "10.95173",
    "lng": "-85.1361"
  },
  {
    "country": "CR",
    "name": "San José",
    "lat": "9.93333",
    "lng": "-84.08333"
  },
  {
    "country": "CR",
    "name": "San Isidro",
    "lat": "9.3674",
    "lng": "-83.69713"
  },
  {
    "country": "CR",
    "name": "San Ignacio",
    "lat": "9.79853",
    "lng": "-84.16173"
  },
  {
    "country": "CR",
    "name": "San Francisco",
    "lat": "9.99299",
    "lng": "-84.12934"
  },
  {
    "country": "CR",
    "name": "San Felipe",
    "lat": "9.90488",
    "lng": "-84.10551"
  },
  {
    "country": "CR",
    "name": "San Diego",
    "lat": "9.89898",
    "lng": "-84.00287"
  },
  {
    "country": "CR",
    "name": "San Antonio",
    "lat": "9.98333",
    "lng": "-84.18333"
  },
  {
    "country": "CR",
    "name": "Sámara",
    "lat": "9.88147",
    "lng": "-85.52809"
  },
  {
    "country": "CR",
    "name": "Salitrillos",
    "lat": "9.85259",
    "lng": "-84.09062"
  },
  {
    "country": "CR",
    "name": "Salitral",
    "lat": "9.91163",
    "lng": "-84.17835"
  },
  {
    "country": "CR",
    "name": "Sabanilla",
    "lat": "10.07404",
    "lng": "-84.21551"
  },
  {
    "country": "CR",
    "name": "Sabanilla",
    "lat": "9.94522",
    "lng": "-84.03927"
  },
  {
    "country": "CR",
    "name": "Sabalito",
    "lat": "8.81814",
    "lng": "-82.90911"
  },
  {
    "country": "CR",
    "name": "Roxana",
    "lat": "10.26712",
    "lng": "-83.7511"
  },
  {
    "country": "CR",
    "name": "Río Segundo",
    "lat": "10.24138",
    "lng": "-84.27933"
  },
  {
    "country": "CR",
    "name": "Quesada",
    "lat": "10.32381",
    "lng": "-84.42714"
  },
  {
    "country": "CR",
    "name": "Quepos",
    "lat": "9.43063",
    "lng": "-84.16231"
  },
  {
    "country": "CR",
    "name": "Purral",
    "lat": "9.95808",
    "lng": "-84.0305"
  },
  {
    "country": "CR",
    "name": "Puntarenas",
    "lat": "9.97625",
    "lng": "-84.83836"
  },
  {
    "country": "CR",
    "name": "Limón",
    "lat": "9.99074",
    "lng": "-83.03596"
  },
  {
    "country": "CR",
    "name": "Pocosol",
    "lat": "10.36667",
    "lng": "-84.61667"
  },
  {
    "country": "CR",
    "name": "Pocora",
    "lat": "10.17185",
    "lng": "-83.60439"
  },
  {
    "country": "CR",
    "name": "Pital",
    "lat": "10.45056",
    "lng": "-84.27406"
  },
  {
    "country": "CR",
    "name": "Pejibaye",
    "lat": "9.81135",
    "lng": "-83.70336"
  },
  {
    "country": "CR",
    "name": "Patarrá",
    "lat": "9.88071",
    "lng": "-84.03501"
  },
  {
    "country": "CR",
    "name": "Parrita",
    "lat": "9.52012",
    "lng": "-84.32249"
  },
  {
    "country": "CR",
    "name": "Paraíso",
    "lat": "9.83832",
    "lng": "-83.86557"
  },
  {
    "country": "CR",
    "name": "Paquera",
    "lat": "9.82005",
    "lng": "-84.93513"
  },
  {
    "country": "CR",
    "name": "Palmichal",
    "lat": "9.83778",
    "lng": "-84.20478"
  },
  {
    "country": "CR",
    "name": "Pacayas",
    "lat": "9.80709",
    "lng": "-84.04764"
  },
  {
    "country": "CR",
    "name": "Orotina",
    "lat": "9.91197",
    "lng": "-84.52337"
  },
  {
    "country": "CR",
    "name": "Orosí",
    "lat": "9.79617",
    "lng": "-83.85383"
  },
  {
    "country": "CR",
    "name": "Nicoya",
    "lat": "10.15038",
    "lng": "-85.45093"
  },
  {
    "country": "CR",
    "name": "Naranjo",
    "lat": "10.09866",
    "lng": "-84.37824"
  },
  {
    "country": "CR",
    "name": "Nandayure",
    "lat": "10.03333",
    "lng": "-85.2"
  },
  {
    "country": "CR",
    "name": "Monterrey",
    "lat": "9.7573",
    "lng": "-84.10956"
  },
  {
    "country": "CR",
    "name": "Miramar",
    "lat": "10.0925",
    "lng": "-84.72978"
  },
  {
    "country": "CR",
    "name": "Mercedes",
    "lat": "10.00695",
    "lng": "-84.13396"
  },
  {
    "country": "CR",
    "name": "Mercedes",
    "lat": "9.2627",
    "lng": "-83.58202"
  },
  {
    "country": "CR",
    "name": "Matina",
    "lat": "10.08363",
    "lng": "-83.28431"
  },
  {
    "country": "CR",
    "name": "Los Chiles",
    "lat": "11.03333",
    "lng": "-84.71667"
  },
  {
    "country": "CR",
    "name": "Llorente",
    "lat": "9.99844",
    "lng": "-84.15448"
  },
  {
    "country": "CR",
    "name": "Liberia",
    "lat": "10.63504",
    "lng": "-85.43772"
  },
  {
    "country": "CR",
    "name": "La Virgen",
    "lat": "10.40174",
    "lng": "-84.13348"
  },
  {
    "country": "CR",
    "name": "La Suiza",
    "lat": "9.85065",
    "lng": "-83.6169"
  },
  {
    "country": "CR",
    "name": "La Cruz",
    "lat": "11.07377",
    "lng": "-85.63272"
  },
  {
    "country": "CR",
    "name": "La Asunción",
    "lat": "9.97961",
    "lng": "-84.17281"
  },
  {
    "country": "CR",
    "name": "Juntas",
    "lat": "10.28089",
    "lng": "-84.95951"
  },
  {
    "country": "CR",
    "name": "Jacó",
    "lat": "9.61497",
    "lng": "-84.62975"
  },
  {
    "country": "CR",
    "name": "Ipís",
    "lat": "9.96745",
    "lng": "-84.01326"
  },
  {
    "country": "CR",
    "name": "Hojancha",
    "lat": "10.0579",
    "lng": "-85.41803"
  },
  {
    "country": "CR",
    "name": "Heredia",
    "lat": "10.00236",
    "lng": "-84.11651"
  },
  {
    "country": "CR",
    "name": "Guápiles",
    "lat": "10.21682",
    "lng": "-83.78483"
  },
  {
    "country": "CR",
    "name": "Guadalupe",
    "lat": "9.94805",
    "lng": "-84.05665"
  },
  {
    "country": "CR",
    "name": "Guácimo",
    "lat": "10.2129",
    "lng": "-83.68793"
  },
  {
    "country": "CR",
    "name": "Granadilla",
    "lat": "9.93491",
    "lng": "-84.01688"
  },
  {
    "country": "CR",
    "name": "Golfito",
    "lat": "8.60327",
    "lng": "-83.11342"
  },
  {
    "country": "CR",
    "name": "Fortuna",
    "lat": "10.67384",
    "lng": "-85.19984"
  },
  {
    "country": "CR",
    "name": "La Fortuna",
    "lat": "10.47089",
    "lng": "-84.64535"
  },
  {
    "country": "CR",
    "name": "Esquipulas",
    "lat": "10.05676",
    "lng": "-84.42337"
  },
  {
    "country": "CR",
    "name": "Esparza",
    "lat": "9.99447",
    "lng": "-84.66466"
  },
  {
    "country": "CR",
    "name": "Escazú",
    "lat": "9.91887",
    "lng": "-84.13989"
  },
  {
    "country": "CR",
    "name": "Desamparados",
    "lat": "9.94727",
    "lng": "-84.50626"
  },
  {
    "country": "CR",
    "name": "Daniel Flores",
    "lat": "9.33554",
    "lng": "-83.6694"
  },
  {
    "country": "CR",
    "name": "Curridabat",
    "lat": "9.91179",
    "lng": "-84.03407"
  },
  {
    "country": "CR",
    "name": "Cot",
    "lat": "9.89449",
    "lng": "-83.87302"
  },
  {
    "country": "CR",
    "name": "Corredor",
    "lat": "8.64002",
    "lng": "-82.946"
  },
  {
    "country": "CR",
    "name": "Concepción",
    "lat": "9.93333",
    "lng": "-84"
  },
  {
    "country": "CR",
    "name": "Colón",
    "lat": "9.91491",
    "lng": "-84.2417"
  },
  {
    "country": "CR",
    "name": "Colima",
    "lat": "9.95091",
    "lng": "-84.08503"
  },
  {
    "country": "CR",
    "name": "Ciudad Cortés",
    "lat": "8.95988",
    "lng": "-83.52381"
  },
  {
    "country": "CR",
    "name": "Chacarita",
    "lat": "9.98424",
    "lng": "-84.77892"
  },
  {
    "country": "CR",
    "name": "Cartago",
    "lat": "9.86444",
    "lng": "-83.91944"
  },
  {
    "country": "CR",
    "name": "Carrillos",
    "lat": "10.02918",
    "lng": "-84.27403"
  },
  {
    "country": "CR",
    "name": "Canoas",
    "lat": "8.53305",
    "lng": "-82.83844"
  },
  {
    "country": "CR",
    "name": "Cañas",
    "lat": "10.43105",
    "lng": "-85.09825"
  },
  {
    "country": "CR",
    "name": "Calle Blancos",
    "lat": "9.95",
    "lng": "-84.06667"
  },
  {
    "country": "CR",
    "name": "Buenos Aires",
    "lat": "9.17189",
    "lng": "-83.33417"
  },
  {
    "country": "CR",
    "name": "Bijagua",
    "lat": "10.73279",
    "lng": "-85.05676"
  },
  {
    "country": "CR",
    "name": "Belén",
    "lat": "10.40789",
    "lng": "-85.58836"
  },
  {
    "country": "CR",
    "name": "Bejuco",
    "lat": "9.85014",
    "lng": "-85.32923"
  },
  {
    "country": "CR",
    "name": "Batán",
    "lat": "10.08354",
    "lng": "-83.33413"
  },
  {
    "country": "CR",
    "name": "Barrio Jesús",
    "lat": "9.97439",
    "lng": "-84.42166"
  },
  {
    "country": "CR",
    "name": "Bagaces",
    "lat": "10.52541",
    "lng": "-85.25537"
  },
  {
    "country": "CR",
    "name": "Atenas",
    "lat": "9.97489",
    "lng": "-84.37886"
  },
  {
    "country": "CR",
    "name": "Aserrí",
    "lat": "9.85876",
    "lng": "-84.0923"
  },
  {
    "country": "CR",
    "name": "Ángeles",
    "lat": "9.99591",
    "lng": "-84.05126"
  },
  {
    "country": "CR",
    "name": "Alajuelita",
    "lat": "9.90163",
    "lng": "-84.10042"
  },
  {
    "country": "CR",
    "name": "Alajuela",
    "lat": "10.01625",
    "lng": "-84.21163"
  },
  {
    "country": "CR",
    "name": "San Vicente de Moravia",
    "lat": "9.96164",
    "lng": "-84.0488"
  },
  {
    "country": "CR",
    "name": "Cariari",
    "lat": "10.35719",
    "lng": "-83.7362"
  },
  {
    "country": "CR",
    "name": "Dulce Nombre de Jesus",
    "lat": "10.15144",
    "lng": "-83.97748"
  },
  {
    "country": "CU",
    "name": "Zaza del Medio",
    "lat": "21.99712",
    "lng": "-79.36678"
  },
  {
    "country": "CU",
    "name": "Yara",
    "lat": "20.27465",
    "lng": "-76.95132"
  },
  {
    "country": "CU",
    "name": "Yaguajay",
    "lat": "22.32691",
    "lng": "-79.23567"
  },
  {
    "country": "CU",
    "name": "Viñales",
    "lat": "22.61892",
    "lng": "-83.70694"
  },
  {
    "country": "CU",
    "name": "Vertientes",
    "lat": "21.25817",
    "lng": "-78.14979"
  },
  {
    "country": "CU",
    "name": "Venezuela",
    "lat": "21.73748",
    "lng": "-78.79336"
  },
  {
    "country": "CU",
    "name": "Varadero",
    "lat": "23.15678",
    "lng": "-81.24441"
  },
  {
    "country": "CU",
    "name": "San Germán",
    "lat": "20.60009",
    "lng": "-76.13364"
  },
  {
    "country": "CU",
    "name": "Unión de Reyes",
    "lat": "22.79505",
    "lng": "-81.53617"
  },
  {
    "country": "CU",
    "name": "Trinidad",
    "lat": "21.80224",
    "lng": "-79.98467"
  },
  {
    "country": "CU",
    "name": "Topes de Collantes",
    "lat": "21.91524",
    "lng": "-80.01929"
  },
  {
    "country": "CU",
    "name": "Taguasco",
    "lat": "22.00198",
    "lng": "-79.26387"
  },
  {
    "country": "CU",
    "name": "Soroa",
    "lat": "22.8",
    "lng": "-83.01667"
  },
  {
    "country": "CU",
    "name": "Sibanicú",
    "lat": "21.23631",
    "lng": "-77.52561"
  },
  {
    "country": "CU",
    "name": "Santo Domingo",
    "lat": "22.58677",
    "lng": "-80.24261"
  },
  {
    "country": "CU",
    "name": "Santiago de las Vegas",
    "lat": "22.97",
    "lng": "-82.38694"
  },
  {
    "country": "CU",
    "name": "Santiago de Cuba",
    "lat": "20.02083",
    "lng": "-75.82667"
  },
  {
    "country": "CU",
    "name": "Santa Cruz del Sur",
    "lat": "20.71633",
    "lng": "-77.99816"
  },
  {
    "country": "CU",
    "name": "Santa Cruz del Norte",
    "lat": "23.15424",
    "lng": "-81.92556"
  },
  {
    "country": "CU",
    "name": "Santa Clara",
    "lat": "22.40694",
    "lng": "-79.96472"
  },
  {
    "country": "CU",
    "name": "San Nicolás de Bari",
    "lat": "22.78444",
    "lng": "-81.91333"
  },
  {
    "country": "CU",
    "name": "San Miguel del Padrón",
    "lat": "23.06639",
    "lng": "-82.29472"
  },
  {
    "country": "CU",
    "name": "San Luis",
    "lat": "22.27898",
    "lng": "-83.75956"
  },
  {
    "country": "CU",
    "name": "San Luis",
    "lat": "20.18809",
    "lng": "-75.85031"
  },
  {
    "country": "CU",
    "name": "San Juan y Martínez",
    "lat": "22.27967",
    "lng": "-83.8401"
  },
  {
    "country": "CU",
    "name": "San José de las Lajas",
    "lat": "22.96139",
    "lng": "-82.15111"
  },
  {
    "country": "CU",
    "name": "San Diego de Los Baños",
    "lat": "22.64667",
    "lng": "-83.36972"
  },
  {
    "country": "CU",
    "name": "Sancti Spíritus",
    "lat": "21.92972",
    "lng": "-79.4425"
  },
  {
    "country": "CU",
    "name": "San Cristobal",
    "lat": "22.71658",
    "lng": "-83.05647"
  },
  {
    "country": "CU",
    "name": "San Antonio del Sur",
    "lat": "20.05756",
    "lng": "-74.81054"
  },
  {
    "country": "CU",
    "name": "San Antonio de los Baños",
    "lat": "22.89018",
    "lng": "-82.50099"
  },
  {
    "country": "CU",
    "name": "Sagua la Grande",
    "lat": "22.80667",
    "lng": "-80.07556"
  },
  {
    "country": "CU",
    "name": "Sagua de Tánamo",
    "lat": "20.58269",
    "lng": "-75.24116"
  },
  {
    "country": "CU",
    "name": "Rodas",
    "lat": "22.34184",
    "lng": "-80.55596"
  },
  {
    "country": "CU",
    "name": "Río Guayabal de Yateras",
    "lat": "20.36667",
    "lng": "-75.01667"
  },
  {
    "country": "CU",
    "name": "Río Cauto",
    "lat": "20.55971",
    "lng": "-76.91673"
  },
  {
    "country": "CU",
    "name": "Remedios",
    "lat": "22.49502",
    "lng": "-79.54548"
  },
  {
    "country": "CU",
    "name": "Regla",
    "lat": "23.125",
    "lng": "-82.33194"
  },
  {
    "country": "CU",
    "name": "Ranchuelo",
    "lat": "22.37266",
    "lng": "-80.15046"
  },
  {
    "country": "CU",
    "name": "Rancho Veloz",
    "lat": "22.88042",
    "lng": "-80.39098"
  },
  {
    "country": "CU",
    "name": "Santa Lucía",
    "lat": "21.02942",
    "lng": "-75.99441"
  },
  {
    "country": "CU",
    "name": "Quivicán",
    "lat": "22.82313",
    "lng": "-82.35558"
  },
  {
    "country": "CU",
    "name": "Quemado de Güines",
    "lat": "22.78816",
    "lng": "-80.25226"
  },
  {
    "country": "CU",
    "name": "Puerto Padre",
    "lat": "21.19517",
    "lng": "-76.60358"
  },
  {
    "country": "CU",
    "name": "Primero de Enero",
    "lat": "21.94501",
    "lng": "-78.4313"
  },
  {
    "country": "CU",
    "name": "Placetas",
    "lat": "22.31184",
    "lng": "-79.6544"
  },
  {
    "country": "CU",
    "name": "Pinar del Río",
    "lat": "22.41667",
    "lng": "-83.69667"
  },
  {
    "country": "CU",
    "name": "Pilón",
    "lat": "19.90553",
    "lng": "-77.32152"
  },
  {
    "country": "CU",
    "name": "Perico",
    "lat": "22.76987",
    "lng": "-81.0183"
  },
  {
    "country": "CU",
    "name": "Pedro Betancourt",
    "lat": "22.72709",
    "lng": "-81.28963"
  },
  {
    "country": "CU",
    "name": "Palmira",
    "lat": "22.24126",
    "lng": "-80.3911"
  },
  {
    "country": "CU",
    "name": "Palma Soriano",
    "lat": "20.2113",
    "lng": "-75.99362"
  },
  {
    "country": "CU",
    "name": "Palenque",
    "lat": "20.36373",
    "lng": "-74.9704"
  },
  {
    "country": "CU",
    "name": "Nuevitas",
    "lat": "21.54585",
    "lng": "-77.26504"
  },
  {
    "country": "CU",
    "name": "Nueva Paz",
    "lat": "22.76266",
    "lng": "-81.75617"
  },
  {
    "country": "CU",
    "name": "Nueva Gerona",
    "lat": "21.88667",
    "lng": "-82.80556"
  },
  {
    "country": "CU",
    "name": "Niquero",
    "lat": "20.04698",
    "lng": "-77.58089"
  },
  {
    "country": "CU",
    "name": "Najasa",
    "lat": "21.07308",
    "lng": "-77.74516"
  },
  {
    "country": "CU",
    "name": "Morón",
    "lat": "22.10774",
    "lng": "-78.62667"
  },
  {
    "country": "CU",
    "name": "Moa",
    "lat": "20.65776",
    "lng": "-74.95075"
  },
  {
    "country": "CU",
    "name": "Minas de Matahambre",
    "lat": "22.58691",
    "lng": "-83.94551"
  },
  {
    "country": "CU",
    "name": "Minas",
    "lat": "21.48802",
    "lng": "-77.61033"
  },
  {
    "country": "CU",
    "name": "Melena del Sur",
    "lat": "22.78813",
    "lng": "-82.15138"
  },
  {
    "country": "CU",
    "name": "Media Luna",
    "lat": "20.14298",
    "lng": "-77.43532"
  },
  {
    "country": "CU",
    "name": "Mayarí",
    "lat": "20.65417",
    "lng": "-75.67945"
  },
  {
    "country": "CU",
    "name": "Matanzas",
    "lat": "23.04111",
    "lng": "-81.5775"
  },
  {
    "country": "CU",
    "name": "Martí",
    "lat": "22.94714",
    "lng": "-80.91902"
  },
  {
    "country": "CU",
    "name": "Mariel",
    "lat": "22.98931",
    "lng": "-82.75376"
  },
  {
    "country": "CU",
    "name": "Manzanillo",
    "lat": "20.34173",
    "lng": "-77.12126"
  },
  {
    "country": "CU",
    "name": "Mantua",
    "lat": "22.29058",
    "lng": "-84.28599"
  },
  {
    "country": "CU",
    "name": "Manicaragua",
    "lat": "22.15021",
    "lng": "-79.97867"
  },
  {
    "country": "CU",
    "name": "Manguito",
    "lat": "22.58733",
    "lng": "-80.91451"
  },
  {
    "country": "CU",
    "name": "Manatí",
    "lat": "21.3107",
    "lng": "-76.93403"
  },
  {
    "country": "CU",
    "name": "Majagua",
    "lat": "21.91717",
    "lng": "-79.00329"
  },
  {
    "country": "CU",
    "name": "Maisí",
    "lat": "20.24673",
    "lng": "-74.15181"
  },
  {
    "country": "CU",
    "name": "Madruga",
    "lat": "22.91",
    "lng": "-81.85639"
  },
  {
    "country": "CU",
    "name": "Los Palacios",
    "lat": "22.58882",
    "lng": "-83.24671"
  },
  {
    "country": "CU",
    "name": "Los Arabos",
    "lat": "22.72969",
    "lng": "-80.72081"
  },
  {
    "country": "CU",
    "name": "Limonar",
    "lat": "22.95035",
    "lng": "-81.41059"
  },
  {
    "country": "CU",
    "name": "Las Tunas",
    "lat": "20.96167",
    "lng": "-76.95111"
  },
  {
    "country": "CU",
    "name": "La Sierpe",
    "lat": "21.77241",
    "lng": "-79.26832"
  },
  {
    "country": "CU",
    "name": "La Salud",
    "lat": "22.87199",
    "lng": "-82.42328"
  },
  {
    "country": "CU",
    "name": "La Palma",
    "lat": "22.74995",
    "lng": "-83.55415"
  },
  {
    "country": "CU",
    "name": "Lajas",
    "lat": "22.41479",
    "lng": "-80.2931"
  },
  {
    "country": "CU",
    "name": "Havana",
    "lat": "23.13302",
    "lng": "-82.38304"
  },
  {
    "country": "CU",
    "name": "Puerto Esperanza",
    "lat": "22.77041",
    "lng": "-83.73138"
  },
  {
    "country": "CU",
    "name": "Jovellanos",
    "lat": "22.80375",
    "lng": "-81.19127"
  },
  {
    "country": "CU",
    "name": "Jobabo",
    "lat": "20.96917",
    "lng": "-76.29944"
  },
  {
    "country": "CU",
    "name": "Jobabo",
    "lat": "20.90748",
    "lng": "-77.28194"
  },
  {
    "country": "CU",
    "name": "Jiguaní",
    "lat": "20.36785",
    "lng": "-76.42741"
  },
  {
    "country": "CU",
    "name": "Jesús Menéndez",
    "lat": "21.16139",
    "lng": "-76.47919"
  },
  {
    "country": "CU",
    "name": "Jatibonico",
    "lat": "21.94333",
    "lng": "-79.16906"
  },
  {
    "country": "CU",
    "name": "Jaruco",
    "lat": "23.04419",
    "lng": "-82.00919"
  },
  {
    "country": "CU",
    "name": "Jamaica",
    "lat": "22.97559",
    "lng": "-82.16852"
  },
  {
    "country": "CU",
    "name": "Jagüey Grande",
    "lat": "22.52694",
    "lng": "-81.12861"
  },
  {
    "country": "CU",
    "name": "Imías",
    "lat": "20.06936",
    "lng": "-74.6314"
  },
  {
    "country": "CU",
    "name": "Holguín",
    "lat": "20.88722",
    "lng": "-76.26306"
  },
  {
    "country": "CU",
    "name": "Guisa",
    "lat": "20.25494",
    "lng": "-76.5393"
  },
  {
    "country": "CU",
    "name": "Güira de Melena",
    "lat": "22.79613",
    "lng": "-82.50667"
  },
  {
    "country": "CU",
    "name": "Güines",
    "lat": "22.83727",
    "lng": "-82.02641"
  },
  {
    "country": "CU",
    "name": "Guayos",
    "lat": "22.04956",
    "lng": "-79.46106"
  },
  {
    "country": "CU",
    "name": "Guara",
    "lat": "22.81",
    "lng": "-82.20306"
  },
  {
    "country": "CU",
    "name": "Guantánamo",
    "lat": "20.14444",
    "lng": "-75.20917"
  },
  {
    "country": "CU",
    "name": "Guane",
    "lat": "22.20179",
    "lng": "-84.08484"
  },
  {
    "country": "CU",
    "name": "Guanajay",
    "lat": "22.92639",
    "lng": "-82.6875"
  },
  {
    "country": "CU",
    "name": "Guanabacoa",
    "lat": "23.1236",
    "lng": "-82.30082"
  },
  {
    "country": "CU",
    "name": "Guáimaro",
    "lat": "21.05222",
    "lng": "-77.3499"
  },
  {
    "country": "CU",
    "name": "Mañalich",
    "lat": "22.81112",
    "lng": "-82.14748"
  },
  {
    "country": "CU",
    "name": "Gibara",
    "lat": "21.10988",
    "lng": "-76.13145"
  },
  {
    "country": "CU",
    "name": "Gaspar",
    "lat": "21.73872",
    "lng": "-78.54434"
  },
  {
    "country": "CU",
    "name": "Fomento",
    "lat": "22.10475",
    "lng": "-79.72141"
  },
  {
    "country": "CU",
    "name": "Florida",
    "lat": "21.52536",
    "lng": "-78.22579"
  },
  {
    "country": "CU",
    "name": "Florencia",
    "lat": "22.1461",
    "lng": "-78.97328"
  },
  {
    "country": "CU",
    "name": "Esperanza",
    "lat": "22.4468",
    "lng": "-80.09711"
  },
  {
    "country": "CU",
    "name": "Esmeralda",
    "lat": "21.85139",
    "lng": "-78.11725"
  },
  {
    "country": "CU",
    "name": "Encrucijada",
    "lat": "22.61802",
    "lng": "-79.86603"
  },
  {
    "country": "CU",
    "name": "El Cobre",
    "lat": "20.0485",
    "lng": "-75.94579"
  },
  {
    "country": "CU",
    "name": "El Caney",
    "lat": "21.3",
    "lng": "-78.48333"
  },
  {
    "country": "CU",
    "name": "Cumanayagua",
    "lat": "22.15247",
    "lng": "-80.20354"
  },
  {
    "country": "CU",
    "name": "Cueto",
    "lat": "20.64855",
    "lng": "-75.92967"
  },
  {
    "country": "CU",
    "name": "Cruces",
    "lat": "22.34203",
    "lng": "-80.27021"
  },
  {
    "country": "CU",
    "name": "Corralillo",
    "lat": "22.98212",
    "lng": "-80.58556"
  },
  {
    "country": "CU",
    "name": "Contramaestre",
    "lat": "20.29879",
    "lng": "-76.24511"
  },
  {
    "country": "CU",
    "name": "Consolación del Sur",
    "lat": "22.50419",
    "lng": "-83.51442"
  },
  {
    "country": "CU",
    "name": "Condado",
    "lat": "21.8767",
    "lng": "-79.84014"
  },
  {
    "country": "CU",
    "name": "Colón",
    "lat": "22.72064",
    "lng": "-80.90492"
  },
  {
    "country": "CU",
    "name": "Colombia",
    "lat": "20.98812",
    "lng": "-77.42598"
  },
  {
    "country": "CU",
    "name": "Ciro Redondo",
    "lat": "22.01921",
    "lng": "-78.70365"
  },
  {
    "country": "CU",
    "name": "Cifuentes",
    "lat": "22.6493",
    "lng": "-80.04935"
  },
  {
    "country": "CU",
    "name": "Cienfuegos",
    "lat": "22.14957",
    "lng": "-80.44662"
  },
  {
    "country": "CU",
    "name": "Ciego de Ávila",
    "lat": "21.84",
    "lng": "-78.76194"
  },
  {
    "country": "CU",
    "name": "Chambas",
    "lat": "22.19534",
    "lng": "-78.9123"
  },
  {
    "country": "CU",
    "name": "Cerro",
    "lat": "23.10861",
    "lng": "-82.37778"
  },
  {
    "country": "CU",
    "name": "Cayo Mambí",
    "lat": "20.66381",
    "lng": "-75.26882"
  },
  {
    "country": "CU",
    "name": "Cauto Cristo",
    "lat": "20.55709",
    "lng": "-76.4727"
  },
  {
    "country": "CU",
    "name": "Carlos Manuel de Céspedes",
    "lat": "21.57572",
    "lng": "-78.28251"
  },
  {
    "country": "CU",
    "name": "Cárdenas",
    "lat": "23.03661",
    "lng": "-81.20596"
  },
  {
    "country": "CU",
    "name": "Candelaria",
    "lat": "22.74057",
    "lng": "-82.95912"
  },
  {
    "country": "CU",
    "name": "Campechuela",
    "lat": "20.23329",
    "lng": "-77.2799"
  },
  {
    "country": "CU",
    "name": "Camajuaní",
    "lat": "22.48333",
    "lng": "-79.75"
  },
  {
    "country": "CU",
    "name": "Camajuaní",
    "lat": "22.46476",
    "lng": "-79.72324"
  },
  {
    "country": "CU",
    "name": "Camagüey",
    "lat": "21.38083",
    "lng": "-77.91694"
  },
  {
    "country": "CU",
    "name": "Calixto",
    "lat": "20.92036",
    "lng": "-76.87144"
  },
  {
    "country": "CU",
    "name": "Calimete",
    "lat": "22.5342",
    "lng": "-80.91105"
  },
  {
    "country": "CU",
    "name": "Calabazar de Sagua",
    "lat": "22.64515",
    "lng": "-79.8951"
  },
  {
    "country": "CU",
    "name": "Caimito",
    "lat": "22.95052",
    "lng": "-82.59435"
  },
  {
    "country": "CU",
    "name": "Caibarién",
    "lat": "22.51996",
    "lng": "-79.46599"
  },
  {
    "country": "CU",
    "name": "Cacocum",
    "lat": "20.73775",
    "lng": "-76.32574"
  },
  {
    "country": "CU",
    "name": "Cabañas",
    "lat": "22.97944",
    "lng": "-82.92214"
  },
  {
    "country": "CU",
    "name": "Cabaiguán",
    "lat": "22.07874",
    "lng": "-79.49726"
  },
  {
    "country": "CU",
    "name": "Buey Arriba",
    "lat": "20.17182",
    "lng": "-76.75659"
  },
  {
    "country": "CU",
    "name": "Bolondrón",
    "lat": "22.76307",
    "lng": "-81.4478"
  },
  {
    "country": "CU",
    "name": "Bolivia",
    "lat": "22.08397",
    "lng": "-78.33884"
  },
  {
    "country": "CU",
    "name": "Bejucal",
    "lat": "22.92861",
    "lng": "-82.38861"
  },
  {
    "country": "CU",
    "name": "Bayamo",
    "lat": "20.37417",
    "lng": "-76.64361"
  },
  {
    "country": "CU",
    "name": "Bauta",
    "lat": "22.98226",
    "lng": "-82.54719"
  },
  {
    "country": "CU",
    "name": "Batabanó",
    "lat": "22.71794",
    "lng": "-82.28965"
  },
  {
    "country": "CU",
    "name": "Bartolomé Masó",
    "lat": "20.16635",
    "lng": "-76.94291"
  },
  {
    "country": "CU",
    "name": "Baraguá",
    "lat": "21.68216",
    "lng": "-78.62567"
  },
  {
    "country": "CU",
    "name": "Baracoa",
    "lat": "20.34711",
    "lng": "-74.49624"
  },
  {
    "country": "CU",
    "name": "Banes",
    "lat": "20.96116",
    "lng": "-75.722"
  },
  {
    "country": "CU",
    "name": "Bahía Honda",
    "lat": "22.90332",
    "lng": "-83.15994"
  },
  {
    "country": "CU",
    "name": "Báguanos",
    "lat": "20.75103",
    "lng": "-76.02571"
  },
  {
    "country": "CU",
    "name": "Artemisa",
    "lat": "22.81667",
    "lng": "-82.75944"
  },
  {
    "country": "CU",
    "name": "Arroyo Naranjo",
    "lat": "23.03677",
    "lng": "-82.36937"
  },
  {
    "country": "CU",
    "name": "Antilla",
    "lat": "20.83104",
    "lng": "-75.73566"
  },
  {
    "country": "CU",
    "name": "Amancio",
    "lat": "20.81914",
    "lng": "-77.57958"
  },
  {
    "country": "CU",
    "name": "Alquízar",
    "lat": "22.80517",
    "lng": "-82.58392"
  },
  {
    "country": "CU",
    "name": "Alamar",
    "lat": "23.15794",
    "lng": "-82.27837"
  },
  {
    "country": "CU",
    "name": "Alacranes",
    "lat": "22.76719",
    "lng": "-81.56803"
  },
  {
    "country": "CU",
    "name": "Aguada de Pasajeros",
    "lat": "22.3852",
    "lng": "-80.84792"
  },
  {
    "country": "CU",
    "name": "Abreus",
    "lat": "22.27797",
    "lng": "-80.56931"
  },
  {
    "country": "CU",
    "name": "Habana del Este",
    "lat": "23.15917",
    "lng": "-82.33056"
  },
  {
    "country": "CU",
    "name": "Centro Habana",
    "lat": "23.13833",
    "lng": "-82.36417"
  },
  {
    "country": "CU",
    "name": "La Habana Vieja",
    "lat": "23.13028",
    "lng": "-82.35306"
  },
  {
    "country": "CU",
    "name": "Jimaguayú",
    "lat": "21.24224",
    "lng": "-77.82625"
  },
  {
    "country": "CU",
    "name": "Boyeros",
    "lat": "23.0072",
    "lng": "-82.4017"
  },
  {
    "country": "CU",
    "name": "Diez de Octubre",
    "lat": "23.0881",
    "lng": "-82.3597"
  },
  {
    "country": "CU",
    "name": "Segundo Frente",
    "lat": "20.41384",
    "lng": "-75.49635"
  },
  {
    "country": "CU",
    "name": "Cubitas",
    "lat": "21.71212",
    "lng": "-77.7613"
  },
  {
    "country": "CU",
    "name": "La Máquina",
    "lat": "20.19198",
    "lng": "-74.22719"
  },
  {
    "country": "CV",
    "name": "Vila Nova Sintra",
    "lat": "14.86667",
    "lng": "-24.71667"
  },
  {
    "country": "CV",
    "name": "Vila do Maio",
    "lat": "15.13823",
    "lng": "-23.21158"
  },
  {
    "country": "CV",
    "name": "Vila da Ribeira Brava",
    "lat": "16.61667",
    "lng": "-24.3"
  },
  {
    "country": "CV",
    "name": "Tarrafal de São Nicolau",
    "lat": "16.56622",
    "lng": "-24.35793"
  },
  {
    "country": "CV",
    "name": "Tarrafal",
    "lat": "15.27881",
    "lng": "-23.75192"
  },
  {
    "country": "CV",
    "name": "São Filipe",
    "lat": "14.8961",
    "lng": "-24.49556"
  },
  {
    "country": "CV",
    "name": "São Domingos",
    "lat": "15.02438",
    "lng": "-23.5625"
  },
  {
    "country": "CV",
    "name": "Santa Maria",
    "lat": "16.59796",
    "lng": "-22.90509"
  },
  {
    "country": "CV",
    "name": "Santa Cruz",
    "lat": "15.13333",
    "lng": "-23.56667"
  },
  {
    "country": "CV",
    "name": "Vila de Sal Rei",
    "lat": "16.18333",
    "lng": "-22.91667"
  },
  {
    "country": "CV",
    "name": "Ribeira Grande",
    "lat": "17.18561",
    "lng": "-25.07243"
  },
  {
    "country": "CV",
    "name": "Praia",
    "lat": "14.93152",
    "lng": "-23.51254"
  },
  {
    "country": "CV",
    "name": "Porto Novo",
    "lat": "17.01969",
    "lng": "-25.06471"
  },
  {
    "country": "CV",
    "name": "Porto dos Mosteiros",
    "lat": "15.03333",
    "lng": "-24.33333"
  },
  {
    "country": "CV",
    "name": "Ponta do Sol",
    "lat": "17.20171",
    "lng": "-25.09217"
  },
  {
    "country": "CV",
    "name": "Pombas",
    "lat": "17.15026",
    "lng": "-25.02007"
  },
  {
    "country": "CV",
    "name": "Picos",
    "lat": "15.0836",
    "lng": "-23.63236"
  },
  {
    "country": "CV",
    "name": "Mindelo",
    "lat": "16.89014",
    "lng": "-24.98042"
  },
  {
    "country": "CV",
    "name": "Cova Figueira",
    "lat": "14.89054",
    "lng": "-24.29343"
  },
  {
    "country": "CV",
    "name": "Cidade Velha",
    "lat": "14.91531",
    "lng": "-23.60527"
  },
  {
    "country": "CV",
    "name": "Calheta",
    "lat": "15.18613",
    "lng": "-23.59228"
  },
  {
    "country": "CV",
    "name": "Assomada",
    "lat": "15.1",
    "lng": "-23.68333"
  },
  {
    "country": "CV",
    "name": "João Teves",
    "lat": "15.06457",
    "lng": "-23.58969"
  },
  {
    "country": "CV",
    "name": "Pedra Badejo",
    "lat": "15.13493",
    "lng": "-23.53215"
  },
  {
    "country": "CV",
    "name": "Espargos",
    "lat": "16.75524",
    "lng": "-22.9446"
  },
  {
    "country": "CW",
    "name": "Willemstad",
    "lat": "12.1084",
    "lng": "-68.93354"
  },
  {
    "country": "CW",
    "name": "Sint Michiel Liber",
    "lat": "12.15",
    "lng": "-68.98333"
  },
  {
    "country": "CW",
    "name": "Dorp Soto",
    "lat": "12.27749",
    "lng": "-69.1125"
  },
  {
    "country": "CW",
    "name": "Barber",
    "lat": "12.29014",
    "lng": "-69.07389"
  },
  {
    "country": "CX",
    "name": "Flying Fish Cove",
    "lat": "-10.42172",
    "lng": "105.67912"
  },
  {
    "country": "CY",
    "name": "Protaras",
    "lat": "35.0125",
    "lng": "34.05833"
  },
  {
    "country": "CY",
    "name": "Ýpsonas",
    "lat": "34.68797",
    "lng": "32.96191"
  },
  {
    "country": "CY",
    "name": "Geroskípou (quarter)",
    "lat": "34.7619",
    "lng": "32.45135"
  },
  {
    "country": "CY",
    "name": "Géri",
    "lat": "35.1056",
    "lng": "33.41977"
  },
  {
    "country": "CY",
    "name": "Xylotymbou",
    "lat": "35.0172",
    "lng": "33.74245"
  },
  {
    "country": "CY",
    "name": "Tséri",
    "lat": "35.07307",
    "lng": "33.32344"
  },
  {
    "country": "CY",
    "name": "Voróklini",
    "lat": "34.986",
    "lng": "33.65387"
  },
  {
    "country": "CY",
    "name": "Troúlloi",
    "lat": "35.03203",
    "lng": "33.61501"
  },
  {
    "country": "CY",
    "name": "Tríkomo",
    "lat": "35.28628",
    "lng": "33.89167"
  },
  {
    "country": "CY",
    "name": "Tersefánou",
    "lat": "34.85411",
    "lng": "33.54746"
  },
  {
    "country": "CY",
    "name": "Tála",
    "lat": "34.83745",
    "lng": "32.43272"
  },
  {
    "country": "CY",
    "name": "Sotíra",
    "lat": "34.71189",
    "lng": "32.8634"
  },
  {
    "country": "CY",
    "name": "Rizokárpaso",
    "lat": "35.59719",
    "lng": "34.37916"
  },
  {
    "country": "CY",
    "name": "Pyrgos",
    "lat": "34.74167",
    "lng": "33.18333"
  },
  {
    "country": "CY",
    "name": "Pýla",
    "lat": "35.01237",
    "lng": "33.69188"
  },
  {
    "country": "CY",
    "name": "Psimolofou",
    "lat": "35.0625",
    "lng": "33.2625"
  },
  {
    "country": "CY",
    "name": "Psevdás",
    "lat": "34.94653",
    "lng": "33.46277"
  },
  {
    "country": "CY",
    "name": "Pólis",
    "lat": "35.03534",
    "lng": "32.42575"
  },
  {
    "country": "CY",
    "name": "Pissoúri",
    "lat": "34.66942",
    "lng": "32.70132"
  },
  {
    "country": "CY",
    "name": "Frénaros",
    "lat": "35.04121",
    "lng": "33.92242"
  },
  {
    "country": "CY",
    "name": "Pégeia",
    "lat": "34.88341",
    "lng": "32.38166"
  },
  {
    "country": "CY",
    "name": "Perivólia",
    "lat": "34.83355",
    "lng": "33.58196"
  },
  {
    "country": "CY",
    "name": "Peristeróna",
    "lat": "35.12928",
    "lng": "33.07858"
  },
  {
    "country": "CY",
    "name": "Pérgamos",
    "lat": "35.04167",
    "lng": "33.70833"
  },
  {
    "country": "CY",
    "name": "Péra",
    "lat": "35.0335",
    "lng": "33.25413"
  },
  {
    "country": "CY",
    "name": "Peléndri",
    "lat": "34.89597",
    "lng": "32.96817"
  },
  {
    "country": "CY",
    "name": "Parekklisha",
    "lat": "34.74583",
    "lng": "33.15833"
  },
  {
    "country": "CY",
    "name": "Paralímni",
    "lat": "35.03945",
    "lng": "33.98181"
  },
  {
    "country": "CY",
    "name": "Paphos",
    "lat": "34.77679",
    "lng": "32.42451"
  },
  {
    "country": "CY",
    "name": "Páno Polemídia",
    "lat": "34.70559",
    "lng": "32.99269"
  },
  {
    "country": "CY",
    "name": "Páno Defterá",
    "lat": "35.07778",
    "lng": "33.26584"
  },
  {
    "country": "CY",
    "name": "Páchna",
    "lat": "34.77874",
    "lng": "32.79355"
  },
  {
    "country": "CY",
    "name": "Nicosia",
    "lat": "35.17531",
    "lng": "33.3642"
  },
  {
    "country": "CY",
    "name": "Mouttagiáka",
    "lat": "34.72022",
    "lng": "33.10066"
  },
  {
    "country": "CY",
    "name": "Mosfilotí",
    "lat": "34.95256",
    "lng": "33.42511"
  },
  {
    "country": "CY",
    "name": "Mórfou",
    "lat": "35.19869",
    "lng": "32.99338"
  },
  {
    "country": "CY",
    "name": "Mesógi",
    "lat": "34.81577",
    "lng": "32.45542"
  },
  {
    "country": "CY",
    "name": "Meneou",
    "lat": "34.86114",
    "lng": "33.59516"
  },
  {
    "country": "CY",
    "name": "Mámmari",
    "lat": "35.17604",
    "lng": "33.20435"
  },
  {
    "country": "CY",
    "name": "Lythrodóntas",
    "lat": "34.95105",
    "lng": "33.29777"
  },
  {
    "country": "CY",
    "name": "Lýmpia",
    "lat": "34.99889",
    "lng": "33.46175"
  },
  {
    "country": "CY",
    "name": "Livádia",
    "lat": "34.95118",
    "lng": "33.62658"
  },
  {
    "country": "CY",
    "name": "Liopétri",
    "lat": "35.00885",
    "lng": "33.89256"
  },
  {
    "country": "CY",
    "name": "Limassol",
    "lat": "34.68406",
    "lng": "33.03794"
  },
  {
    "country": "CY",
    "name": "Leonárisso",
    "lat": "35.46892",
    "lng": "34.13886"
  },
  {
    "country": "CY",
    "name": "Lefkónoiko",
    "lat": "35.2598",
    "lng": "33.73189"
  },
  {
    "country": "CY",
    "name": "Léfka",
    "lat": "35.11199",
    "lng": "32.84997"
  },
  {
    "country": "CY",
    "name": "Larnaca",
    "lat": "34.92291",
    "lng": "33.6233"
  },
  {
    "country": "CY",
    "name": "Lápithos",
    "lat": "35.33823",
    "lng": "33.17368"
  },
  {
    "country": "CY",
    "name": "Kyrenia",
    "lat": "35.33634",
    "lng": "33.31729"
  },
  {
    "country": "CY",
    "name": "Kyperoúnta",
    "lat": "34.93815",
    "lng": "32.97551"
  },
  {
    "country": "CY",
    "name": "Kórnos",
    "lat": "34.92396",
    "lng": "33.39764"
  },
  {
    "country": "CY",
    "name": "Kofínou",
    "lat": "34.82449",
    "lng": "33.3913"
  },
  {
    "country": "CY",
    "name": "Kolossi",
    "lat": "34.66865",
    "lng": "32.93375"
  },
  {
    "country": "CY",
    "name": "Koloni",
    "lat": "34.75228",
    "lng": "32.46487"
  },
  {
    "country": "CY",
    "name": "Kokkinotrimithiá",
    "lat": "35.15303",
    "lng": "33.19966"
  },
  {
    "country": "CY",
    "name": "Klírou",
    "lat": "35.02004",
    "lng": "33.17806"
  },
  {
    "country": "CY",
    "name": "Kíti",
    "lat": "34.84696",
    "lng": "33.57344"
  },
  {
    "country": "CY",
    "name": "Kissónerga",
    "lat": "34.82217",
    "lng": "32.40191"
  },
  {
    "country": "CY",
    "name": "Chlórakas",
    "lat": "34.79768",
    "lng": "32.41207"
  },
  {
    "country": "CY",
    "name": "Káto Pýrgos",
    "lat": "35.17897",
    "lng": "32.686"
  },
  {
    "country": "CY",
    "name": "Káto Defterá",
    "lat": "35.08489",
    "lng": "33.27558"
  },
  {
    "country": "CY",
    "name": "Kakopetriá",
    "lat": "34.98768",
    "lng": "32.90468"
  },
  {
    "country": "CY",
    "name": "Famagusta",
    "lat": "35.12054",
    "lng": "33.93894"
  },
  {
    "country": "CY",
    "name": "Erími",
    "lat": "34.67766",
    "lng": "32.91815"
  },
  {
    "country": "CY",
    "name": "Émpa",
    "lat": "34.80765",
    "lng": "32.42402"
  },
  {
    "country": "CY",
    "name": "Dhromolaxia",
    "lat": "34.87551",
    "lng": "33.58684"
  },
  {
    "country": "CY",
    "name": "Derýneia",
    "lat": "35.06484",
    "lng": "33.96083"
  },
  {
    "country": "CY",
    "name": "Dáli",
    "lat": "35.02294",
    "lng": "33.42195"
  },
  {
    "country": "CY",
    "name": "Ágios Týchon",
    "lat": "34.72606",
    "lng": "33.13872"
  },
  {
    "country": "CY",
    "name": "Ayia Napa",
    "lat": "34.98213",
    "lng": "34.00183"
  },
  {
    "country": "CY",
    "name": "Avgórou",
    "lat": "35.03615",
    "lng": "33.83918"
  },
  {
    "country": "CY",
    "name": "Áchna",
    "lat": "35.05515",
    "lng": "33.78388"
  },
  {
    "country": "CY",
    "name": "Athíenou",
    "lat": "35.0618",
    "lng": "33.54156"
  },
  {
    "country": "CY",
    "name": "Astromerítis",
    "lat": "35.14096",
    "lng": "33.03793"
  },
  {
    "country": "CY",
    "name": "Ergátes",
    "lat": "35.05365",
    "lng": "33.24292"
  },
  {
    "country": "CY",
    "name": "Aradíppou",
    "lat": "34.95151",
    "lng": "33.59199"
  },
  {
    "country": "CY",
    "name": "Aredioú",
    "lat": "35.04844",
    "lng": "33.1961"
  },
  {
    "country": "CY",
    "name": "Alámpra",
    "lat": "34.98898",
    "lng": "33.39887"
  },
  {
    "country": "CY",
    "name": "Acherítou",
    "lat": "35.10022",
    "lng": "33.86155"
  },
  {
    "country": "CY",
    "name": "Akáki",
    "lat": "35.13341",
    "lng": "33.12873"
  },
  {
    "country": "CY",
    "name": "Méniko",
    "lat": "35.10945",
    "lng": "33.14474"
  },
  {
    "country": "CZ",
    "name": "Dvůr Králové nad Labem",
    "lat": "50.43172",
    "lng": "15.81402"
  },
  {
    "country": "CZ",
    "name": "Zvole",
    "lat": "49.93466",
    "lng": "14.41769"
  },
  {
    "country": "CZ",
    "name": "Žulová",
    "lat": "50.30933",
    "lng": "17.09871"
  },
  {
    "country": "CZ",
    "name": "Zubří",
    "lat": "49.46603",
    "lng": "18.09249"
  },
  {
    "country": "CZ",
    "name": "Zruč nad Sázavou",
    "lat": "49.7401",
    "lng": "15.10606"
  },
  {
    "country": "CZ",
    "name": "Znojmo",
    "lat": "48.8555",
    "lng": "16.0488"
  },
  {
    "country": "CZ",
    "name": "Žlutice",
    "lat": "50.09192",
    "lng": "13.16297"
  },
  {
    "country": "CZ",
    "name": "Žlutava",
    "lat": "49.19976",
    "lng": "17.49037"
  },
  {
    "country": "CZ",
    "name": "Zlonice",
    "lat": "50.2875",
    "lng": "14.09214"
  },
  {
    "country": "CZ",
    "name": "Zliv",
    "lat": "49.06608",
    "lng": "14.36613"
  },
  {
    "country": "CZ",
    "name": "Zlín",
    "lat": "49.22645",
    "lng": "17.67065"
  },
  {
    "country": "CZ",
    "name": "Zlechov",
    "lat": "49.07396",
    "lng": "17.37938"
  },
  {
    "country": "CZ",
    "name": "Žleby",
    "lat": "49.88958",
    "lng": "15.48853"
  },
  {
    "country": "CZ",
    "name": "Zlaté Hory",
    "lat": "50.2638",
    "lng": "17.39602"
  },
  {
    "country": "CZ",
    "name": "Žiželice",
    "lat": "50.13192",
    "lng": "15.3932"
  },
  {
    "country": "CZ",
    "name": "Žitenice",
    "lat": "50.55528",
    "lng": "14.15665"
  },
  {
    "country": "CZ",
    "name": "Žirovnice",
    "lat": "49.25318",
    "lng": "15.18824"
  },
  {
    "country": "CZ",
    "name": "Žihle",
    "lat": "50.04491",
    "lng": "13.37502"
  },
  {
    "country": "CZ",
    "name": "Židlochovice",
    "lat": "49.03952",
    "lng": "16.61881"
  },
  {
    "country": "CZ",
    "name": "Žeravice",
    "lat": "49.02288",
    "lng": "17.23726"
  },
  {
    "country": "CZ",
    "name": "Želiv",
    "lat": "49.52984",
    "lng": "15.22181"
  },
  {
    "country": "CZ",
    "name": "Železný Brod",
    "lat": "50.64274",
    "lng": "15.25408"
  },
  {
    "country": "CZ",
    "name": "Železnice",
    "lat": "50.47274",
    "lng": "15.38459"
  },
  {
    "country": "CZ",
    "name": "Železná Ruda",
    "lat": "49.13743",
    "lng": "13.2352"
  },
  {
    "country": "CZ",
    "name": "Želetava",
    "lat": "49.14187",
    "lng": "15.673"
  },
  {
    "country": "CZ",
    "name": "Želešice",
    "lat": "49.11689",
    "lng": "16.58137"
  },
  {
    "country": "CZ",
    "name": "Zeleneč",
    "lat": "50.13362",
    "lng": "14.6607"
  },
  {
    "country": "CZ",
    "name": "Žebrák",
    "lat": "49.87574",
    "lng": "13.89735"
  },
  {
    "country": "CZ",
    "name": "Zdounky",
    "lat": "49.22771",
    "lng": "17.31899"
  },
  {
    "country": "CZ",
    "name": "Zdíkov",
    "lat": "49.08456",
    "lng": "13.69738"
  },
  {
    "country": "CZ",
    "name": "Zdice",
    "lat": "49.91207",
    "lng": "13.97747"
  },
  {
    "country": "CZ",
    "name": "Zdiby",
    "lat": "50.16799",
    "lng": "14.45118"
  },
  {
    "country": "CZ",
    "name": "Žďár nad Sázavou Druhy",
    "lat": "49.58726",
    "lng": "15.93215"
  },
  {
    "country": "CZ",
    "name": "Žďár nad Sázavou",
    "lat": "49.56263",
    "lng": "15.93924"
  },
  {
    "country": "CZ",
    "name": "Žďár",
    "lat": "50.54366",
    "lng": "15.08034"
  },
  {
    "country": "CZ",
    "name": "Ždánice",
    "lat": "49.06729",
    "lng": "17.02751"
  },
  {
    "country": "CZ",
    "name": "Zbýšov",
    "lat": "49.15524",
    "lng": "16.34951"
  },
  {
    "country": "CZ",
    "name": "Zbůch",
    "lat": "49.6784",
    "lng": "13.22564"
  },
  {
    "country": "CZ",
    "name": "Zbraslavice",
    "lat": "49.81179",
    "lng": "15.18319"
  },
  {
    "country": "CZ",
    "name": "Zbraslav",
    "lat": "49.22155",
    "lng": "16.29415"
  },
  {
    "country": "CZ",
    "name": "Zborovice",
    "lat": "49.24889",
    "lng": "17.28464"
  },
  {
    "country": "CZ",
    "name": "Zbiroh",
    "lat": "49.86024",
    "lng": "13.77262"
  },
  {
    "country": "CZ",
    "name": "Zátor",
    "lat": "50.03413",
    "lng": "17.59296"
  },
  {
    "country": "CZ",
    "name": "Žatec",
    "lat": "50.32717",
    "lng": "13.54577"
  },
  {
    "country": "CZ",
    "name": "Zastávka",
    "lat": "49.188",
    "lng": "16.3631"
  },
  {
    "country": "CZ",
    "name": "Zašová",
    "lat": "49.4741",
    "lng": "18.04436"
  },
  {
    "country": "CZ",
    "name": "Zásmuky",
    "lat": "49.9547",
    "lng": "15.03058"
  },
  {
    "country": "CZ",
    "name": "Žandov",
    "lat": "50.71394",
    "lng": "14.39623"
  },
  {
    "country": "CZ",
    "name": "Žamberk",
    "lat": "50.08601",
    "lng": "16.46738"
  },
  {
    "country": "CZ",
    "name": "Zákupy",
    "lat": "50.68475",
    "lng": "14.64522"
  },
  {
    "country": "CZ",
    "name": "Zaječov",
    "lat": "49.77435",
    "lng": "13.84072"
  },
  {
    "country": "CZ",
    "name": "Zaječí",
    "lat": "48.87295",
    "lng": "16.76646"
  },
  {
    "country": "CZ",
    "name": "Záhorovice",
    "lat": "49.02266",
    "lng": "17.77922"
  },
  {
    "country": "CZ",
    "name": "Zadní Mostek",
    "lat": "50.4967",
    "lng": "15.69804"
  },
  {
    "country": "CZ",
    "name": "Žacléř",
    "lat": "50.66329",
    "lng": "15.91063"
  },
  {
    "country": "CZ",
    "name": "Zabrušany",
    "lat": "50.60495",
    "lng": "13.78748"
  },
  {
    "country": "CZ",
    "name": "Zábřeh",
    "lat": "49.8826",
    "lng": "16.87223"
  },
  {
    "country": "CZ",
    "name": "Žabčice",
    "lat": "49.0116",
    "lng": "16.60257"
  },
  {
    "country": "CZ",
    "name": "Vyšší Brod",
    "lat": "48.61598",
    "lng": "14.31183"
  },
  {
    "country": "CZ",
    "name": "Vysoké nad Jizerou",
    "lat": "50.68559",
    "lng": "15.40152"
  },
  {
    "country": "CZ",
    "name": "Vysoké Mýto",
    "lat": "49.9532",
    "lng": "16.16169"
  },
  {
    "country": "CZ",
    "name": "Vysočany",
    "lat": "50.10938",
    "lng": "14.51667"
  },
  {
    "country": "CZ",
    "name": "Vyškov",
    "lat": "49.27747",
    "lng": "16.99897"
  },
  {
    "country": "CZ",
    "name": "Vsetín",
    "lat": "49.33871",
    "lng": "17.99619"
  },
  {
    "country": "CZ",
    "name": "Všetaty",
    "lat": "50.28187",
    "lng": "14.59297"
  },
  {
    "country": "CZ",
    "name": "Všestary",
    "lat": "50.2566",
    "lng": "15.75983"
  },
  {
    "country": "CZ",
    "name": "Všeruby",
    "lat": "49.84167",
    "lng": "13.22943"
  },
  {
    "country": "CZ",
    "name": "Všenory",
    "lat": "49.92883",
    "lng": "14.30392"
  },
  {
    "country": "CZ",
    "name": "Všemina",
    "lat": "49.281",
    "lng": "17.87682"
  },
  {
    "country": "CZ",
    "name": "Vroutek",
    "lat": "50.17999",
    "lng": "13.37986"
  },
  {
    "country": "CZ",
    "name": "Vřesina",
    "lat": "49.94581",
    "lng": "18.19005"
  },
  {
    "country": "CZ",
    "name": "Vřesina",
    "lat": "49.82418",
    "lng": "18.12569"
  },
  {
    "country": "CZ",
    "name": "Vrdy",
    "lat": "49.92153",
    "lng": "15.47243"
  },
  {
    "country": "CZ",
    "name": "Vrchlabí",
    "lat": "50.62697",
    "lng": "15.60937"
  },
  {
    "country": "CZ",
    "name": "Vrbovec",
    "lat": "48.79978",
    "lng": "16.10061"
  },
  {
    "country": "CZ",
    "name": "Vrbno pod Pradědem",
    "lat": "50.12095",
    "lng": "17.38316"
  },
  {
    "country": "CZ",
    "name": "Vrbice",
    "lat": "48.91508",
    "lng": "16.89779"
  },
  {
    "country": "CZ",
    "name": "Vrbátky",
    "lat": "49.50805",
    "lng": "17.19994"
  },
  {
    "country": "CZ",
    "name": "Vratimov",
    "lat": "49.76995",
    "lng": "18.31015"
  },
  {
    "country": "CZ",
    "name": "Vranovice",
    "lat": "48.966",
    "lng": "16.6066"
  },
  {
    "country": "CZ",
    "name": "Vrané nad Vltavou",
    "lat": "49.93585",
    "lng": "14.37706"
  },
  {
    "country": "CZ",
    "name": "Vracov",
    "lat": "48.97523",
    "lng": "17.211"
  },
  {
    "country": "CZ",
    "name": "Votice",
    "lat": "49.64013",
    "lng": "14.63809"
  },
  {
    "country": "CZ",
    "name": "Volyně",
    "lat": "49.16578",
    "lng": "13.88624"
  },
  {
    "country": "CZ",
    "name": "Volary",
    "lat": "48.90881",
    "lng": "13.88657"
  },
  {
    "country": "CZ",
    "name": "Vojkovice",
    "lat": "49.05138",
    "lng": "16.6082"
  },
  {
    "country": "CZ",
    "name": "Vodňany",
    "lat": "49.14789",
    "lng": "14.17513"
  },
  {
    "country": "CZ",
    "name": "Vnorovy",
    "lat": "48.93096",
    "lng": "17.3505"
  },
  {
    "country": "CZ",
    "name": "Vlkoš",
    "lat": "48.9896",
    "lng": "17.16356"
  },
  {
    "country": "CZ",
    "name": "Vlčnov",
    "lat": "49.57866",
    "lng": "17.95458"
  },
  {
    "country": "CZ",
    "name": "Vlčnov",
    "lat": "49.0099",
    "lng": "17.58183"
  },
  {
    "country": "CZ",
    "name": "Vlašim",
    "lat": "49.70632",
    "lng": "14.89881"
  },
  {
    "country": "CZ",
    "name": "Vladislav",
    "lat": "49.21017",
    "lng": "15.9883"
  },
  {
    "country": "CZ",
    "name": "Vlachovo Březí",
    "lat": "49.08135",
    "lng": "13.95842"
  },
  {
    "country": "CZ",
    "name": "Vlachovice",
    "lat": "49.12377",
    "lng": "17.94001"
  },
  {
    "country": "CZ",
    "name": "Vizovice",
    "lat": "49.22287",
    "lng": "17.85455"
  },
  {
    "country": "CZ",
    "name": "Vítkov",
    "lat": "49.77445",
    "lng": "17.74941"
  },
  {
    "country": "CZ",
    "name": "Višňové",
    "lat": "48.98241",
    "lng": "16.15025"
  },
  {
    "country": "CZ",
    "name": "Višňova",
    "lat": "50.96663",
    "lng": "15.02495"
  },
  {
    "country": "CZ",
    "name": "Vintířov",
    "lat": "50.23382",
    "lng": "12.71748"
  },
  {
    "country": "CZ",
    "name": "Viničné Šumice",
    "lat": "49.21358",
    "lng": "16.82541"
  },
  {
    "country": "CZ",
    "name": "Vinařice",
    "lat": "50.17585",
    "lng": "14.09106"
  },
  {
    "country": "CZ",
    "name": "Vimperk",
    "lat": "49.05857",
    "lng": "13.78286"
  },
  {
    "country": "CZ",
    "name": "Vilémov",
    "lat": "50.99054",
    "lng": "14.33531"
  },
  {
    "country": "CZ",
    "name": "Vilémov",
    "lat": "49.81566",
    "lng": "15.53584"
  },
  {
    "country": "CZ",
    "name": "Vilémov",
    "lat": "49.53578",
    "lng": "15.38347"
  },
  {
    "country": "CZ",
    "name": "Vikýřovice",
    "lat": "49.97792",
    "lng": "17.01234"
  },
  {
    "country": "CZ",
    "name": "Vidnava",
    "lat": "50.37234",
    "lng": "17.18626"
  },
  {
    "country": "CZ",
    "name": "Vidče",
    "lat": "49.44151",
    "lng": "18.09473"
  },
  {
    "country": "CZ",
    "name": "Veverská Bítýška",
    "lat": "49.27591",
    "lng": "16.43686"
  },
  {
    "country": "CZ",
    "name": "Větřní",
    "lat": "48.77425",
    "lng": "14.28616"
  },
  {
    "country": "CZ",
    "name": "Vestec",
    "lat": "49.9805",
    "lng": "14.50487"
  },
  {
    "country": "CZ",
    "name": "Veselí nad Moravou",
    "lat": "48.95363",
    "lng": "17.37648"
  },
  {
    "country": "CZ",
    "name": "Veselí nad Lužnicí",
    "lat": "49.1843",
    "lng": "14.69734"
  },
  {
    "country": "CZ",
    "name": "Veřovice",
    "lat": "49.53916",
    "lng": "18.11425"
  },
  {
    "country": "CZ",
    "name": "Věrovany",
    "lat": "49.46109",
    "lng": "17.28795"
  },
  {
    "country": "CZ",
    "name": "Verneřice",
    "lat": "50.66114",
    "lng": "14.30114"
  },
  {
    "country": "CZ",
    "name": "Vendryně",
    "lat": "49.66662",
    "lng": "18.71307"
  },
  {
    "country": "CZ",
    "name": "Velvary",
    "lat": "50.28152",
    "lng": "14.23616"
  },
  {
    "country": "CZ",
    "name": "Veltrusy",
    "lat": "50.27046",
    "lng": "14.32857"
  },
  {
    "country": "CZ",
    "name": "Veltruby",
    "lat": "50.07059",
    "lng": "15.18454"
  },
  {
    "country": "CZ",
    "name": "Velký Újezd",
    "lat": "49.57858",
    "lng": "17.48347"
  },
  {
    "country": "CZ",
    "name": "Velký Týnec",
    "lat": "49.54994",
    "lng": "17.33359"
  },
  {
    "country": "CZ",
    "name": "Velký Šenov",
    "lat": "50.99078",
    "lng": "14.37428"
  },
  {
    "country": "CZ",
    "name": "Velký Osek",
    "lat": "50.09867",
    "lng": "15.18629"
  },
  {
    "country": "CZ",
    "name": "Velký Beranov",
    "lat": "49.40504",
    "lng": "15.667"
  },
  {
    "country": "CZ",
    "name": "Velké Svatoňovice",
    "lat": "50.53164",
    "lng": "16.02853"
  },
  {
    "country": "CZ",
    "name": "Velké Přílepy",
    "lat": "50.1605",
    "lng": "14.31447"
  },
  {
    "country": "CZ",
    "name": "Velké Poříčí",
    "lat": "50.46177",
    "lng": "16.18931"
  },
  {
    "country": "CZ",
    "name": "Velké Popovice",
    "lat": "49.92252",
    "lng": "14.63934"
  },
  {
    "country": "CZ",
    "name": "Velké Pavlovice",
    "lat": "48.90469",
    "lng": "16.81605"
  },
  {
    "country": "CZ",
    "name": "Velké Opatovice",
    "lat": "49.61237",
    "lng": "16.67947"
  },
  {
    "country": "CZ",
    "name": "Velké Němčice",
    "lat": "48.99168",
    "lng": "16.67208"
  },
  {
    "country": "CZ",
    "name": "Velké Meziříčí",
    "lat": "49.35522",
    "lng": "16.01224"
  },
  {
    "country": "CZ",
    "name": "Velké Losiny",
    "lat": "50.03197",
    "lng": "17.04058"
  },
  {
    "country": "CZ",
    "name": "Velké Karlovice",
    "lat": "49.36064",
    "lng": "18.28355"
  },
  {
    "country": "CZ",
    "name": "Velké Hoštice",
    "lat": "49.93609",
    "lng": "17.9738"
  },
  {
    "country": "CZ",
    "name": "Velké Heraltice",
    "lat": "49.97493",
    "lng": "17.72879"
  },
  {
    "country": "CZ",
    "name": "Velké Hamry",
    "lat": "50.71373",
    "lng": "15.31539"
  },
  {
    "country": "CZ",
    "name": "Velké Březno",
    "lat": "50.6627",
    "lng": "14.14174"
  },
  {
    "country": "CZ",
    "name": "Velké Bílovice",
    "lat": "48.84929",
    "lng": "16.89227"
  },
  {
    "country": "CZ",
    "name": "Velká Polom",
    "lat": "49.86359",
    "lng": "18.09331"
  },
  {
    "country": "CZ",
    "name": "Velká nad Veličkou",
    "lat": "48.88257",
    "lng": "17.5206"
  },
  {
    "country": "CZ",
    "name": "Velká Hleďsebe",
    "lat": "49.96151",
    "lng": "12.66763"
  },
  {
    "country": "CZ",
    "name": "Velká Dobrá",
    "lat": "50.10964",
    "lng": "14.0698"
  },
  {
    "country": "CZ",
    "name": "Velká Bystřice",
    "lat": "49.5948",
    "lng": "17.36544"
  },
  {
    "country": "CZ",
    "name": "Velká Bíteš",
    "lat": "49.28838",
    "lng": "16.22742"
  },
  {
    "country": "CZ",
    "name": "Velim",
    "lat": "50.05965",
    "lng": "15.10711"
  },
  {
    "country": "CZ",
    "name": "Velešín",
    "lat": "48.82949",
    "lng": "14.46252"
  },
  {
    "country": "CZ",
    "name": "Velemín",
    "lat": "50.53898",
    "lng": "13.97675"
  },
  {
    "country": "CZ",
    "name": "Velehrad",
    "lat": "49.10543",
    "lng": "17.39426"
  },
  {
    "country": "CZ",
    "name": "Vejprty",
    "lat": "50.49232",
    "lng": "13.03212"
  },
  {
    "country": "CZ",
    "name": "Vejprnice",
    "lat": "49.72988",
    "lng": "13.27628"
  },
  {
    "country": "CZ",
    "name": "Včelná",
    "lat": "48.92373",
    "lng": "14.45383"
  },
  {
    "country": "CZ",
    "name": "Varnsdorf",
    "lat": "50.91154",
    "lng": "14.61824"
  },
  {
    "country": "CZ",
    "name": "Vápenná",
    "lat": "50.28338",
    "lng": "17.09762"
  },
  {
    "country": "CZ",
    "name": "Vamberk",
    "lat": "50.11756",
    "lng": "16.29067"
  },
  {
    "country": "CZ",
    "name": "Valtice",
    "lat": "48.74069",
    "lng": "16.75499"
  },
  {
    "country": "CZ",
    "name": "Valdice",
    "lat": "50.5835",
    "lng": "15.41248"
  },
  {
    "country": "CZ",
    "name": "Valdice",
    "lat": "50.45501",
    "lng": "15.38488"
  },
  {
    "country": "CZ",
    "name": "Valašské Meziříčí",
    "lat": "49.47181",
    "lng": "17.97113"
  },
  {
    "country": "CZ",
    "name": "Valašské Klobouky",
    "lat": "49.14064",
    "lng": "18.0076"
  },
  {
    "country": "CZ",
    "name": "Valašská Polanka",
    "lat": "49.26215",
    "lng": "17.99667"
  },
  {
    "country": "CZ",
    "name": "Valašská Bystřice",
    "lat": "49.41507",
    "lng": "18.10977"
  },
  {
    "country": "CZ",
    "name": "Vacov",
    "lat": "49.13686",
    "lng": "13.72911"
  },
  {
    "country": "CZ",
    "name": "Václavovice",
    "lat": "49.75531",
    "lng": "18.3722"
  },
  {
    "country": "CZ",
    "name": "Vacenovice",
    "lat": "48.9451",
    "lng": "17.17404"
  },
  {
    "country": "CZ",
    "name": "Úvaly",
    "lat": "50.07394",
    "lng": "14.7308"
  },
  {
    "country": "CZ",
    "name": "Ústí nad Orlicí",
    "lat": "49.97387",
    "lng": "16.39361"
  },
  {
    "country": "CZ",
    "name": "Ústí nad Labem",
    "lat": "50.6607",
    "lng": "14.03227"
  },
  {
    "country": "CZ",
    "name": "Úštěk",
    "lat": "50.58474",
    "lng": "14.34332"
  },
  {
    "country": "CZ",
    "name": "Úsov",
    "lat": "49.79831",
    "lng": "17.01055"
  },
  {
    "country": "CZ",
    "name": "Určice",
    "lat": "49.43045",
    "lng": "17.07291"
  },
  {
    "country": "CZ",
    "name": "Úpice",
    "lat": "50.51237",
    "lng": "16.01607"
  },
  {
    "country": "CZ",
    "name": "Uničov",
    "lat": "49.77092",
    "lng": "17.12144"
  },
  {
    "country": "CZ",
    "name": "Unhošť",
    "lat": "50.08535",
    "lng": "14.13007"
  },
  {
    "country": "CZ",
    "name": "Únanov",
    "lat": "48.90082",
    "lng": "16.06351"
  },
  {
    "country": "CZ",
    "name": "Újezd",
    "lat": "49.76397",
    "lng": "17.1804"
  },
  {
    "country": "CZ",
    "name": "Újezd",
    "lat": "49.16809",
    "lng": "17.9061"
  },
  {
    "country": "CZ",
    "name": "Uhlířské Janovice",
    "lat": "49.88019",
    "lng": "15.06481"
  },
  {
    "country": "CZ",
    "name": "Uherský Ostroh",
    "lat": "48.98556",
    "lng": "17.38984"
  },
  {
    "country": "CZ",
    "name": "Uherský Brod",
    "lat": "49.02513",
    "lng": "17.64715"
  },
  {
    "country": "CZ",
    "name": "Uherské Hradiště",
    "lat": "49.06975",
    "lng": "17.45969"
  },
  {
    "country": "CZ",
    "name": "Údlice",
    "lat": "50.4406",
    "lng": "13.45738"
  },
  {
    "country": "CZ",
    "name": "Týn nad Vltavou",
    "lat": "49.2234",
    "lng": "14.42057"
  },
  {
    "country": "CZ",
    "name": "Týniště nad Orlicí",
    "lat": "50.15136",
    "lng": "16.0777"
  },
  {
    "country": "CZ",
    "name": "Týnec nad Sázavou",
    "lat": "49.83348",
    "lng": "14.58983"
  },
  {
    "country": "CZ",
    "name": "Týnec nad Labem",
    "lat": "50.04202",
    "lng": "15.35836"
  },
  {
    "country": "CZ",
    "name": "Týnec",
    "lat": "48.77943",
    "lng": "17.01322"
  },
  {
    "country": "CZ",
    "name": "Tvrdonice",
    "lat": "48.76048",
    "lng": "16.99446"
  },
  {
    "country": "CZ",
    "name": "Tvarožná",
    "lat": "49.19177",
    "lng": "16.77146"
  },
  {
    "country": "CZ",
    "name": "Turnov",
    "lat": "50.58356",
    "lng": "15.15186"
  },
  {
    "country": "CZ",
    "name": "Tupesy",
    "lat": "49.08427",
    "lng": "17.36983"
  },
  {
    "country": "CZ",
    "name": "Tuchoměřice",
    "lat": "50.13543",
    "lng": "14.28218"
  },
  {
    "country": "CZ",
    "name": "Tuchlovice",
    "lat": "50.13803",
    "lng": "13.99115"
  },
  {
    "country": "CZ",
    "name": "Trutnov",
    "lat": "50.56101",
    "lng": "15.9127"
  },
  {
    "country": "CZ",
    "name": "Tršice",
    "lat": "49.54237",
    "lng": "17.42483"
  },
  {
    "country": "CZ",
    "name": "Troubsko",
    "lat": "49.16951",
    "lng": "16.51078"
  },
  {
    "country": "CZ",
    "name": "Troubky",
    "lat": "49.43215",
    "lng": "17.34914"
  },
  {
    "country": "CZ",
    "name": "Troubelice",
    "lat": "49.81731",
    "lng": "17.081"
  },
  {
    "country": "CZ",
    "name": "Trojanovice",
    "lat": "49.52039",
    "lng": "18.238"
  },
  {
    "country": "CZ",
    "name": "Trnava",
    "lat": "49.29603",
    "lng": "17.84191"
  },
  {
    "country": "CZ",
    "name": "Trmice",
    "lat": "50.64286",
    "lng": "13.99449"
  },
  {
    "country": "CZ",
    "name": "Třinec",
    "lat": "49.67763",
    "lng": "18.67078"
  },
  {
    "country": "CZ",
    "name": "Trhový Štěpánov",
    "lat": "49.71147",
    "lng": "15.01356"
  },
  {
    "country": "CZ",
    "name": "Trhové Sviny",
    "lat": "48.84231",
    "lng": "14.63924"
  },
  {
    "country": "CZ",
    "name": "Třešť",
    "lat": "49.29092",
    "lng": "15.48211"
  },
  {
    "country": "CZ",
    "name": "Třemošnice",
    "lat": "49.86912",
    "lng": "15.58002"
  },
  {
    "country": "CZ",
    "name": "Třemošná",
    "lat": "49.81584",
    "lng": "13.39499"
  },
  {
    "country": "CZ",
    "name": "Třebotov",
    "lat": "49.97244",
    "lng": "14.29127"
  },
  {
    "country": "CZ",
    "name": "Třeboň",
    "lat": "49.00364",
    "lng": "14.77065"
  },
  {
    "country": "CZ",
    "name": "Třebíč",
    "lat": "49.21492",
    "lng": "15.88166"
  },
  {
    "country": "CZ",
    "name": "Třebenice",
    "lat": "50.47632",
    "lng": "13.99005"
  },
  {
    "country": "CZ",
    "name": "Třebechovice pod Orebem",
    "lat": "50.20097",
    "lng": "15.99223"
  },
  {
    "country": "CZ",
    "name": "Traplice",
    "lat": "49.13088",
    "lng": "17.43622"
  },
  {
    "country": "CZ",
    "name": "Tovačov",
    "lat": "49.43083",
    "lng": "17.28795"
  },
  {
    "country": "CZ",
    "name": "Toužim",
    "lat": "50.06049",
    "lng": "12.98506"
  },
  {
    "country": "CZ",
    "name": "Topolná",
    "lat": "49.12187",
    "lng": "17.54434"
  },
  {
    "country": "CZ",
    "name": "Tlumačov",
    "lat": "49.25351",
    "lng": "17.49559"
  },
  {
    "country": "CZ",
    "name": "Tlučná",
    "lat": "49.72425",
    "lng": "13.23534"
  },
  {
    "country": "CZ",
    "name": "Tišnov",
    "lat": "49.34872",
    "lng": "16.42438"
  },
  {
    "country": "CZ",
    "name": "Tišice",
    "lat": "50.2698",
    "lng": "14.55411"
  },
  {
    "country": "CZ",
    "name": "Tichá",
    "lat": "49.56999",
    "lng": "18.22148"
  },
  {
    "country": "CZ",
    "name": "Těšetice",
    "lat": "49.59317",
    "lng": "17.12607"
  },
  {
    "country": "CZ",
    "name": "Těšany",
    "lat": "49.03956",
    "lng": "16.77003"
  },
  {
    "country": "CZ",
    "name": "Terezín",
    "lat": "50.511",
    "lng": "14.15055"
  },
  {
    "country": "CZ",
    "name": "Teplice nad Metují",
    "lat": "50.59332",
    "lng": "16.17026"
  },
  {
    "country": "CZ",
    "name": "Teplice",
    "lat": "50.6404",
    "lng": "13.82451"
  },
  {
    "country": "CZ",
    "name": "Telnice",
    "lat": "49.10187",
    "lng": "16.71774"
  },
  {
    "country": "CZ",
    "name": "Telč",
    "lat": "49.18418",
    "lng": "15.45275"
  },
  {
    "country": "CZ",
    "name": "Tečovice",
    "lat": "49.22107",
    "lng": "17.58733"
  },
  {
    "country": "CZ",
    "name": "Tasovice",
    "lat": "48.8361",
    "lng": "16.15558"
  },
  {
    "country": "CZ",
    "name": "Tanvald",
    "lat": "50.73735",
    "lng": "15.30585"
  },
  {
    "country": "CZ",
    "name": "Tachov",
    "lat": "49.79528",
    "lng": "12.63365"
  },
  {
    "country": "CZ",
    "name": "Tábor",
    "lat": "49.41441",
    "lng": "14.6578"
  },
  {
    "country": "CZ",
    "name": "Svratka",
    "lat": "49.71066",
    "lng": "16.03214"
  },
  {
    "country": "CZ",
    "name": "Svoboda nad Úpou",
    "lat": "50.62596",
    "lng": "15.81648"
  },
  {
    "country": "CZ",
    "name": "Svitavy",
    "lat": "49.75594",
    "lng": "16.46829"
  },
  {
    "country": "CZ",
    "name": "Svitávka",
    "lat": "49.50178",
    "lng": "16.59793"
  },
  {
    "country": "CZ",
    "name": "Švihov",
    "lat": "49.48136",
    "lng": "13.28417"
  },
  {
    "country": "CZ",
    "name": "Sviadnov",
    "lat": "49.68926",
    "lng": "18.32762"
  },
  {
    "country": "CZ",
    "name": "Světlá nad Sázavou",
    "lat": "49.66801",
    "lng": "15.40393"
  },
  {
    "country": "CZ",
    "name": "Svatava",
    "lat": "50.19223",
    "lng": "12.62524"
  },
  {
    "country": "CZ",
    "name": "Sušice",
    "lat": "49.23106",
    "lng": "13.52018"
  },
  {
    "country": "CZ",
    "name": "Šumperk",
    "lat": "49.96528",
    "lng": "16.97061"
  },
  {
    "country": "CZ",
    "name": "Šumice",
    "lat": "49.02858",
    "lng": "17.72205"
  },
  {
    "country": "CZ",
    "name": "Sudoměřice",
    "lat": "48.86723",
    "lng": "17.25676"
  },
  {
    "country": "CZ",
    "name": "Sudkov",
    "lat": "49.91903",
    "lng": "16.94516"
  },
  {
    "country": "CZ",
    "name": "Suchohrdly",
    "lat": "48.86822",
    "lng": "16.09471"
  },
  {
    "country": "CZ",
    "name": "Suchdol nad Lužnicí",
    "lat": "48.89",
    "lng": "14.8772"
  },
  {
    "country": "CZ",
    "name": "Suchdol",
    "lat": "49.95247",
    "lng": "15.16651"
  },
  {
    "country": "CZ",
    "name": "Suchá Loz",
    "lat": "48.97001",
    "lng": "17.71379"
  },
  {
    "country": "CZ",
    "name": "Studénka",
    "lat": "49.72342",
    "lng": "18.07853"
  },
  {
    "country": "CZ",
    "name": "Studenec",
    "lat": "50.55344",
    "lng": "15.54936"
  },
  {
    "country": "CZ",
    "name": "Studená",
    "lat": "49.18516",
    "lng": "15.28688"
  },
  {
    "country": "CZ",
    "name": "Strunkovice nad Blanicí",
    "lat": "49.08402",
    "lng": "14.05522"
  },
  {
    "country": "CZ",
    "name": "Strmilov",
    "lat": "49.15846",
    "lng": "15.19934"
  },
  {
    "country": "CZ",
    "name": "Střížkov",
    "lat": "50.12674",
    "lng": "14.49363"
  },
  {
    "country": "CZ",
    "name": "Stříbro",
    "lat": "49.75565",
    "lng": "12.997"
  },
  {
    "country": "CZ",
    "name": "Střelice",
    "lat": "49.15221",
    "lng": "16.50399"
  },
  {
    "country": "CZ",
    "name": "Stráž pod Ralskem",
    "lat": "50.7028",
    "lng": "14.80102"
  },
  {
    "country": "CZ",
    "name": "Strážov",
    "lat": "49.30326",
    "lng": "13.24623"
  },
  {
    "country": "CZ",
    "name": "Strážnice",
    "lat": "48.90102",
    "lng": "17.3168"
  },
  {
    "country": "CZ",
    "name": "Stráž nad Nisou",
    "lat": "50.79099",
    "lng": "15.02683"
  },
  {
    "country": "CZ",
    "name": "Strážná",
    "lat": "49.83104",
    "lng": "17.13275"
  },
  {
    "country": "CZ",
    "name": "Stráž",
    "lat": "49.66878",
    "lng": "12.77546"
  },
  {
    "country": "CZ",
    "name": "Strašice",
    "lat": "49.73552",
    "lng": "13.75755"
  },
  {
    "country": "CZ",
    "name": "Strání",
    "lat": "48.90216",
    "lng": "17.70671"
  },
  {
    "country": "CZ",
    "name": "Strančice",
    "lat": "49.94811",
    "lng": "14.67745"
  },
  {
    "country": "CZ",
    "name": "Štramberk",
    "lat": "49.59181",
    "lng": "18.11741"
  },
  {
    "country": "CZ",
    "name": "Strakonice",
    "lat": "49.26141",
    "lng": "13.90237"
  },
  {
    "country": "CZ",
    "name": "Stonava",
    "lat": "49.81691",
    "lng": "18.52518"
  },
  {
    "country": "CZ",
    "name": "Štoky",
    "lat": "49.50249",
    "lng": "15.58863"
  },
  {
    "country": "CZ",
    "name": "Stod",
    "lat": "49.63909",
    "lng": "13.16474"
  },
  {
    "country": "CZ",
    "name": "Stochov",
    "lat": "50.14631",
    "lng": "13.96345"
  },
  {
    "country": "CZ",
    "name": "Štíty",
    "lat": "49.96122",
    "lng": "16.76576"
  },
  {
    "country": "CZ",
    "name": "Štítná nad Vláří",
    "lat": "49.06881",
    "lng": "17.98274"
  },
  {
    "country": "CZ",
    "name": "Štítina",
    "lat": "49.91487",
    "lng": "18.01245"
  },
  {
    "country": "CZ",
    "name": "Stěžery",
    "lat": "50.21572",
    "lng": "15.74831"
  },
  {
    "country": "CZ",
    "name": "Štětí",
    "lat": "50.45298",
    "lng": "14.37421"
  },
  {
    "country": "CZ",
    "name": "Šternberk",
    "lat": "49.73044",
    "lng": "17.29889"
  },
  {
    "country": "CZ",
    "name": "Štěpánov",
    "lat": "50.16238",
    "lng": "16.91702"
  },
  {
    "country": "CZ",
    "name": "Štěpánov",
    "lat": "49.68404",
    "lng": "17.22041"
  },
  {
    "country": "CZ",
    "name": "Štěpánkovice",
    "lat": "49.95738",
    "lng": "18.03741"
  },
  {
    "country": "CZ",
    "name": "Štěnovice",
    "lat": "49.67051",
    "lng": "13.39963"
  },
  {
    "country": "CZ",
    "name": "Štěchovice",
    "lat": "49.85109",
    "lng": "14.40543"
  },
  {
    "country": "CZ",
    "name": "Stěbořice",
    "lat": "49.93708",
    "lng": "17.80547"
  },
  {
    "country": "CZ",
    "name": "Starý Plzenec",
    "lat": "49.69768",
    "lng": "13.4735"
  },
  {
    "country": "CZ",
    "name": "Starý Kolín",
    "lat": "50.00977",
    "lng": "15.29388"
  },
  {
    "country": "CZ",
    "name": "Starý Jičín",
    "lat": "49.57686",
    "lng": "17.96169"
  },
  {
    "country": "CZ",
    "name": "Starý Bohumín",
    "lat": "49.9169",
    "lng": "18.33619"
  },
  {
    "country": "CZ",
    "name": "Staříč",
    "lat": "49.68594",
    "lng": "18.27281"
  },
  {
    "country": "CZ",
    "name": "Staré Nechanice",
    "lat": "50.24298",
    "lng": "15.61787"
  },
  {
    "country": "CZ",
    "name": "Staré Město",
    "lat": "50.087",
    "lng": "14.42024"
  },
  {
    "country": "CZ",
    "name": "Staré Město",
    "lat": "50.16174",
    "lng": "16.94734"
  },
  {
    "country": "CZ",
    "name": "Staré Město",
    "lat": "49.66992",
    "lng": "18.36349"
  },
  {
    "country": "CZ",
    "name": "Staré Město",
    "lat": "49.07515",
    "lng": "17.43338"
  },
  {
    "country": "CZ",
    "name": "Staré Křečany",
    "lat": "50.95044",
    "lng": "14.49617"
  },
  {
    "country": "CZ",
    "name": "Staré Hradiště",
    "lat": "50.0654",
    "lng": "15.77885"
  },
  {
    "country": "CZ",
    "name": "Stařeč",
    "lat": "49.19783",
    "lng": "15.82791"
  },
  {
    "country": "CZ",
    "name": "Stará Ves nad Ondřejnicí",
    "lat": "49.72775",
    "lng": "18.1885"
  },
  {
    "country": "CZ",
    "name": "Stará Paka",
    "lat": "50.51032",
    "lng": "15.49444"
  },
  {
    "country": "CZ",
    "name": "Stará Huť",
    "lat": "49.78225",
    "lng": "14.19735"
  },
  {
    "country": "CZ",
    "name": "Staňkov",
    "lat": "49.55348",
    "lng": "13.06976"
  },
  {
    "country": "CZ",
    "name": "Šťáhlavy",
    "lat": "49.67555",
    "lng": "13.50394"
  },
  {
    "country": "CZ",
    "name": "Stachy",
    "lat": "49.10179",
    "lng": "13.66659"
  },
  {
    "country": "CZ",
    "name": "Srubec",
    "lat": "48.94806",
    "lng": "14.54131"
  },
  {
    "country": "CZ",
    "name": "Spytihněv",
    "lat": "49.14115",
    "lng": "17.49808"
  },
  {
    "country": "CZ",
    "name": "Špindlerův Mlýn",
    "lat": "50.72615",
    "lng": "15.60944"
  },
  {
    "country": "CZ",
    "name": "Spálené Poříčí",
    "lat": "49.61371",
    "lng": "13.60556"
  },
  {
    "country": "CZ",
    "name": "Solnice",
    "lat": "50.20366",
    "lng": "16.23762"
  },
  {
    "country": "CZ",
    "name": "Sokolov",
    "lat": "50.1813",
    "lng": "12.6401"
  },
  {
    "country": "CZ",
    "name": "Sokolnice",
    "lat": "49.11392",
    "lng": "16.72156"
  },
  {
    "country": "CZ",
    "name": "Sobotka",
    "lat": "50.46741",
    "lng": "15.17619"
  },
  {
    "country": "CZ",
    "name": "Sobotín",
    "lat": "50.01039",
    "lng": "17.09129"
  },
  {
    "country": "CZ",
    "name": "Soběslav",
    "lat": "49.25993",
    "lng": "14.71861"
  },
  {
    "country": "CZ",
    "name": "Smržovka",
    "lat": "50.7382",
    "lng": "15.24639"
  },
  {
    "country": "CZ",
    "name": "Smržice",
    "lat": "49.50569",
    "lng": "17.10698"
  },
  {
    "country": "CZ",
    "name": "Smiřice",
    "lat": "50.29978",
    "lng": "15.86508"
  },
  {
    "country": "CZ",
    "name": "Smidary",
    "lat": "50.29146",
    "lng": "15.47725"
  },
  {
    "country": "CZ",
    "name": "Smečno",
    "lat": "50.18844",
    "lng": "14.04037"
  },
  {
    "country": "CZ",
    "name": "Slušovice",
    "lat": "49.24782",
    "lng": "17.8015"
  },
  {
    "country": "CZ",
    "name": "Šluknov",
    "lat": "51.00369",
    "lng": "14.45258"
  },
  {
    "country": "CZ",
    "name": "Slavonice",
    "lat": "48.99753",
    "lng": "15.35154"
  },
  {
    "country": "CZ",
    "name": "Slavkov u Brna",
    "lat": "49.15325",
    "lng": "16.87649"
  },
  {
    "country": "CZ",
    "name": "Slavkov",
    "lat": "49.9218",
    "lng": "17.83641"
  },
  {
    "country": "CZ",
    "name": "Slavičín",
    "lat": "49.08799",
    "lng": "17.87349"
  },
  {
    "country": "CZ",
    "name": "Slatinice",
    "lat": "49.56155",
    "lng": "17.09992"
  },
  {
    "country": "CZ",
    "name": "Slatiňany",
    "lat": "49.9211",
    "lng": "15.81377"
  },
  {
    "country": "CZ",
    "name": "Šlapanice",
    "lat": "49.16863",
    "lng": "16.72731"
  },
  {
    "country": "CZ",
    "name": "Slaný",
    "lat": "50.23046",
    "lng": "14.08693"
  },
  {
    "country": "CZ",
    "name": "Skuteč",
    "lat": "49.84347",
    "lng": "15.99655"
  },
  {
    "country": "CZ",
    "name": "Skuhrov nad Bělou",
    "lat": "50.22946",
    "lng": "16.2923"
  },
  {
    "country": "CZ",
    "name": "Skrbeň",
    "lat": "49.64115",
    "lng": "17.1765"
  },
  {
    "country": "CZ",
    "name": "Skalná",
    "lat": "50.1703",
    "lng": "12.36144"
  },
  {
    "country": "CZ",
    "name": "Šitbořice",
    "lat": "49.01433",
    "lng": "16.77975"
  },
  {
    "country": "CZ",
    "name": "Šilheřovice",
    "lat": "49.92602",
    "lng": "18.27017"
  },
  {
    "country": "CZ",
    "name": "Sezimovo Ústí",
    "lat": "49.38519",
    "lng": "14.6848"
  },
  {
    "country": "CZ",
    "name": "Sezemice",
    "lat": "50.06651",
    "lng": "15.8527"
  },
  {
    "country": "CZ",
    "name": "Ševětín",
    "lat": "49.10005",
    "lng": "14.5722"
  },
  {
    "country": "CZ",
    "name": "Šestajovice",
    "lat": "50.10845",
    "lng": "14.68013"
  },
  {
    "country": "CZ",
    "name": "Sepekov",
    "lat": "49.42865",
    "lng": "14.41815"
  },
  {
    "country": "CZ",
    "name": "Šenov",
    "lat": "49.79315",
    "lng": "18.37607"
  },
  {
    "country": "CZ",
    "name": "Senice na Hané",
    "lat": "49.62401",
    "lng": "17.08578"
  },
  {
    "country": "CZ",
    "name": "Semily",
    "lat": "50.60191",
    "lng": "15.33552"
  },
  {
    "country": "CZ",
    "name": "Sedlnice",
    "lat": "49.6577",
    "lng": "18.0869"
  },
  {
    "country": "CZ",
    "name": "Sedliště",
    "lat": "49.71836",
    "lng": "18.36869"
  },
  {
    "country": "CZ",
    "name": "Sedlice",
    "lat": "49.37715",
    "lng": "13.93895"
  },
  {
    "country": "CZ",
    "name": "Sedlice",
    "lat": "48.77401",
    "lng": "14.39115"
  },
  {
    "country": "CZ",
    "name": "Sedlec",
    "lat": "49.96391",
    "lng": "15.28846"
  },
  {
    "country": "CZ",
    "name": "Sedlčany",
    "lat": "49.66057",
    "lng": "14.42664"
  },
  {
    "country": "CZ",
    "name": "Seč",
    "lat": "49.84694",
    "lng": "15.65643"
  },
  {
    "country": "CZ",
    "name": "Sázava",
    "lat": "49.87164",
    "lng": "14.89674"
  },
  {
    "country": "CZ",
    "name": "Šatov",
    "lat": "48.79317",
    "lng": "16.00992"
  },
  {
    "country": "CZ",
    "name": "Satalice",
    "lat": "50.12484",
    "lng": "14.57191"
  },
  {
    "country": "CZ",
    "name": "Šardice",
    "lat": "48.96403",
    "lng": "17.02812"
  },
  {
    "country": "CZ",
    "name": "Šanov",
    "lat": "48.80089",
    "lng": "16.37858"
  },
  {
    "country": "CZ",
    "name": "Samotíšky",
    "lat": "49.63042",
    "lng": "17.32807"
  },
  {
    "country": "CZ",
    "name": "Šakvice",
    "lat": "48.89746",
    "lng": "16.71424"
  },
  {
    "country": "CZ",
    "name": "Sadská",
    "lat": "50.13596",
    "lng": "14.98633"
  },
  {
    "country": "CZ",
    "name": "Sadov",
    "lat": "50.26711",
    "lng": "12.89708"
  },
  {
    "country": "CZ",
    "name": "Rýmařov",
    "lat": "49.93183",
    "lng": "17.27177"
  },
  {
    "country": "CZ",
    "name": "Rychvald",
    "lat": "49.86625",
    "lng": "18.37626"
  },
  {
    "country": "CZ",
    "name": "Rychnov nad Kněžnou",
    "lat": "50.16284",
    "lng": "16.27488"
  },
  {
    "country": "CZ",
    "name": "Rybitví",
    "lat": "50.06015",
    "lng": "15.70472"
  },
  {
    "country": "CZ",
    "name": "Rybí",
    "lat": "49.60073",
    "lng": "18.07592"
  },
  {
    "country": "CZ",
    "name": "Rumburk",
    "lat": "50.95151",
    "lng": "14.55699"
  },
  {
    "country": "CZ",
    "name": "Rudolfov",
    "lat": "48.99339",
    "lng": "14.54179"
  },
  {
    "country": "CZ",
    "name": "Rudník",
    "lat": "50.59517",
    "lng": "15.73362"
  },
  {
    "country": "CZ",
    "name": "Rudná",
    "lat": "50.03502",
    "lng": "14.23435"
  },
  {
    "country": "CZ",
    "name": "Ruda nad Moravou",
    "lat": "49.981",
    "lng": "16.87782"
  },
  {
    "country": "CZ",
    "name": "Rtyně v Podkrkonoší",
    "lat": "50.50523",
    "lng": "16.07187"
  },
  {
    "country": "CZ",
    "name": "Roztoky",
    "lat": "50.15841",
    "lng": "14.3976"
  },
  {
    "country": "CZ",
    "name": "Roztoky",
    "lat": "50.02671",
    "lng": "13.86787"
  },
  {
    "country": "CZ",
    "name": "Rožnov pod Radhoštěm",
    "lat": "49.45853",
    "lng": "18.14302"
  },
  {
    "country": "CZ",
    "name": "Rožmitál pod Třemšínem",
    "lat": "49.60196",
    "lng": "13.8643"
  },
  {
    "country": "CZ",
    "name": "Rožďalovice",
    "lat": "50.30476",
    "lng": "15.16962"
  },
  {
    "country": "CZ",
    "name": "Rovensko pod Troskami",
    "lat": "50.53532",
    "lng": "15.25941"
  },
  {
    "country": "CZ",
    "name": "Rousínov",
    "lat": "49.20128",
    "lng": "16.88215"
  },
  {
    "country": "CZ",
    "name": "Roudnice nad Labem",
    "lat": "50.42528",
    "lng": "14.26175"
  },
  {
    "country": "CZ",
    "name": "Rouchovany",
    "lat": "49.07036",
    "lng": "16.1076"
  },
  {
    "country": "CZ",
    "name": "Rotava",
    "lat": "50.29627",
    "lng": "12.57341"
  },
  {
    "country": "CZ",
    "name": "Rosice",
    "lat": "49.92226",
    "lng": "15.95127"
  },
  {
    "country": "CZ",
    "name": "Rosice",
    "lat": "49.18232",
    "lng": "16.38787"
  },
  {
    "country": "CZ",
    "name": "Ropice",
    "lat": "49.70536",
    "lng": "18.61345"
  },
  {
    "country": "CZ",
    "name": "Ronov nad Doubravou",
    "lat": "49.88825",
    "lng": "15.53144"
  },
  {
    "country": "CZ",
    "name": "Rokytnice v Orlických Horách",
    "lat": "50.16473",
    "lng": "16.46567"
  },
  {
    "country": "CZ",
    "name": "Rokytnice nad Jizerou",
    "lat": "50.72561",
    "lng": "15.43357"
  },
  {
    "country": "CZ",
    "name": "Rokytnice",
    "lat": "49.46592",
    "lng": "17.3912"
  },
  {
    "country": "CZ",
    "name": "Rokycany",
    "lat": "49.7427",
    "lng": "13.59459"
  },
  {
    "country": "CZ",
    "name": "Rohatec",
    "lat": "48.8804",
    "lng": "17.1833"
  },
  {
    "country": "CZ",
    "name": "Říčany",
    "lat": "49.99168",
    "lng": "14.65427"
  },
  {
    "country": "CZ",
    "name": "Říčany",
    "lat": "49.21497",
    "lng": "16.39362"
  },
  {
    "country": "CZ",
    "name": "Řež",
    "lat": "50.17734",
    "lng": "14.35733"
  },
  {
    "country": "CZ",
    "name": "Řevničov",
    "lat": "50.18489",
    "lng": "13.80823"
  },
  {
    "country": "CZ",
    "name": "Řevnice",
    "lat": "49.91395",
    "lng": "14.23589"
  },
  {
    "country": "CZ",
    "name": "Řepiště",
    "lat": "49.73338",
    "lng": "18.31707"
  },
  {
    "country": "CZ",
    "name": "Řehlovice",
    "lat": "50.60712",
    "lng": "13.95412"
  },
  {
    "country": "CZ",
    "name": "Řečany nad Labem",
    "lat": "50.03589",
    "lng": "15.47735"
  },
  {
    "country": "CZ",
    "name": "Ratíškovice",
    "lat": "48.92002",
    "lng": "17.16561"
  },
  {
    "country": "CZ",
    "name": "Ratiboř",
    "lat": "49.36769",
    "lng": "17.91499"
  },
  {
    "country": "CZ",
    "name": "Rataje",
    "lat": "49.2713",
    "lng": "17.33555"
  },
  {
    "country": "CZ",
    "name": "Raspenava",
    "lat": "50.90415",
    "lng": "15.11465"
  },
  {
    "country": "CZ",
    "name": "Raškovice",
    "lat": "49.61975",
    "lng": "18.47286"
  },
  {
    "country": "CZ",
    "name": "Rapotín",
    "lat": "50.01094",
    "lng": "17.03121"
  },
  {
    "country": "CZ",
    "name": "Rakvice",
    "lat": "48.85811",
    "lng": "16.8133"
  },
  {
    "country": "CZ",
    "name": "Rakovník",
    "lat": "50.1037",
    "lng": "13.7334"
  },
  {
    "country": "CZ",
    "name": "Rajhradice",
    "lat": "49.09203",
    "lng": "16.62933"
  },
  {
    "country": "CZ",
    "name": "Rajhrad",
    "lat": "49.09021",
    "lng": "16.60388"
  },
  {
    "country": "CZ",
    "name": "Ráječko",
    "lat": "49.39393",
    "lng": "16.64497"
  },
  {
    "country": "CZ",
    "name": "Rájec-Jestřebí",
    "lat": "49.41094",
    "lng": "16.63902"
  },
  {
    "country": "CZ",
    "name": "Radvanice",
    "lat": "50.56745",
    "lng": "16.06172"
  },
  {
    "country": "CZ",
    "name": "Radslavice",
    "lat": "49.47817",
    "lng": "17.51656"
  },
  {
    "country": "CZ",
    "name": "Radonice",
    "lat": "50.29803",
    "lng": "13.28464"
  },
  {
    "country": "CZ",
    "name": "Radomyšl",
    "lat": "49.31634",
    "lng": "13.93024"
  },
  {
    "country": "CZ",
    "name": "Radnice",
    "lat": "49.85677",
    "lng": "13.6057"
  },
  {
    "country": "CZ",
    "name": "Radiměř",
    "lat": "49.6985",
    "lng": "16.4407"
  },
  {
    "country": "CZ",
    "name": "Pyšely",
    "lat": "49.87678",
    "lng": "14.67713"
  },
  {
    "country": "CZ",
    "name": "Pustiměř",
    "lat": "49.32251",
    "lng": "17.02792"
  },
  {
    "country": "CZ",
    "name": "Pustá Polom",
    "lat": "49.84917",
    "lng": "17.9979"
  },
  {
    "country": "CZ",
    "name": "Ptení",
    "lat": "49.51163",
    "lng": "16.9611"
  },
  {
    "country": "CZ",
    "name": "Psáry",
    "lat": "49.93622",
    "lng": "14.51276"
  },
  {
    "country": "CZ",
    "name": "Prusinovice",
    "lat": "49.37898",
    "lng": "17.5871"
  },
  {
    "country": "CZ",
    "name": "Prušánky",
    "lat": "48.8284",
    "lng": "16.98068"
  },
  {
    "country": "CZ",
    "name": "Průhonice",
    "lat": "49.99962",
    "lng": "14.55017"
  },
  {
    "country": "CZ",
    "name": "Protivín",
    "lat": "49.19949",
    "lng": "14.21717"
  },
  {
    "country": "CZ",
    "name": "Protivanov",
    "lat": "49.48351",
    "lng": "16.83594"
  },
  {
    "country": "CZ",
    "name": "Prostřední Bečva",
    "lat": "49.43609",
    "lng": "18.252"
  },
  {
    "country": "CZ",
    "name": "Prostějov",
    "lat": "49.47188",
    "lng": "17.11184"
  },
  {
    "country": "CZ",
    "name": "Prosek",
    "lat": "50.11525",
    "lng": "14.50685"
  },
  {
    "country": "CZ",
    "name": "Proseč",
    "lat": "49.8059",
    "lng": "16.11621"
  },
  {
    "country": "CZ",
    "name": "Proboštov",
    "lat": "50.66773",
    "lng": "13.83601"
  },
  {
    "country": "CZ",
    "name": "Příšovice",
    "lat": "50.57813",
    "lng": "15.0839"
  },
  {
    "country": "CZ",
    "name": "Přimda",
    "lat": "49.67488",
    "lng": "12.67366"
  },
  {
    "country": "CZ",
    "name": "Příkazy",
    "lat": "49.6436",
    "lng": "17.14337"
  },
  {
    "country": "CZ",
    "name": "Přibyslav",
    "lat": "49.57684",
    "lng": "15.73855"
  },
  {
    "country": "CZ",
    "name": "Příbram",
    "lat": "49.68988",
    "lng": "14.01043"
  },
  {
    "country": "CZ",
    "name": "Příbor",
    "lat": "49.64094",
    "lng": "18.14499"
  },
  {
    "country": "CZ",
    "name": "Přeštice",
    "lat": "49.57298",
    "lng": "13.3335"
  },
  {
    "country": "CZ",
    "name": "Přerov nad Labem",
    "lat": "50.16027",
    "lng": "14.82502"
  },
  {
    "country": "CZ",
    "name": "Přerov",
    "lat": "49.45511",
    "lng": "17.4509"
  },
  {
    "country": "CZ",
    "name": "Přemyslovice",
    "lat": "49.55637",
    "lng": "16.95581"
  },
  {
    "country": "CZ",
    "name": "Přelouč",
    "lat": "50.03985",
    "lng": "15.56031"
  },
  {
    "country": "CZ",
    "name": "Předměřice nad Labem",
    "lat": "50.25633",
    "lng": "15.81556"
  },
  {
    "country": "CZ",
    "name": "Předklášteří",
    "lat": "49.35253",
    "lng": "16.40241"
  },
  {
    "country": "CZ",
    "name": "Pražmo",
    "lat": "49.60876",
    "lng": "18.48617"
  },
  {
    "country": "CZ",
    "name": "Přáslavice",
    "lat": "49.58568",
    "lng": "17.38209"
  },
  {
    "country": "CZ",
    "name": "Prague",
    "lat": "50.08804",
    "lng": "14.42076"
  },
  {
    "country": "CZ",
    "name": "Prachovice",
    "lat": "49.89379",
    "lng": "15.62872"
  },
  {
    "country": "CZ",
    "name": "Prachatice",
    "lat": "49.01292",
    "lng": "13.99752"
  },
  {
    "country": "CZ",
    "name": "Pozořice",
    "lat": "49.20976",
    "lng": "16.79074"
  },
  {
    "country": "CZ",
    "name": "Pozlovice",
    "lat": "49.12921",
    "lng": "17.76925"
  },
  {
    "country": "CZ",
    "name": "Povrly",
    "lat": "50.67276",
    "lng": "14.16033"
  },
  {
    "country": "CZ",
    "name": "Potštát",
    "lat": "49.63693",
    "lng": "17.65174"
  },
  {
    "country": "CZ",
    "name": "Postupice",
    "lat": "49.72798",
    "lng": "14.77722"
  },
  {
    "country": "CZ",
    "name": "Postřelmov",
    "lat": "49.90756",
    "lng": "16.91226"
  },
  {
    "country": "CZ",
    "name": "Postřekov",
    "lat": "49.45827",
    "lng": "12.80678"
  },
  {
    "country": "CZ",
    "name": "Postoloprty",
    "lat": "50.35979",
    "lng": "13.70291"
  },
  {
    "country": "CZ",
    "name": "Poříčí nad Sázavou",
    "lat": "49.83895",
    "lng": "14.67446"
  },
  {
    "country": "CZ",
    "name": "Poříčany",
    "lat": "50.10806",
    "lng": "14.91818"
  },
  {
    "country": "CZ",
    "name": "Popovice",
    "lat": "49.05255",
    "lng": "17.52712"
  },
  {
    "country": "CZ",
    "name": "Poniklá",
    "lat": "50.66152",
    "lng": "15.46329"
  },
  {
    "country": "CZ",
    "name": "Pomezí",
    "lat": "49.71026",
    "lng": "16.31729"
  },
  {
    "country": "CZ",
    "name": "Polná",
    "lat": "49.487",
    "lng": "15.71881"
  },
  {
    "country": "CZ",
    "name": "Polička",
    "lat": "49.71465",
    "lng": "16.26543"
  },
  {
    "country": "CZ",
    "name": "Police nad Metují",
    "lat": "50.53687",
    "lng": "16.2335"
  },
  {
    "country": "CZ",
    "name": "Polešovice",
    "lat": "49.0339",
    "lng": "17.34064"
  },
  {
    "country": "CZ",
    "name": "Polepy",
    "lat": "50.50563",
    "lng": "14.26447"
  },
  {
    "country": "CZ",
    "name": "Pohořelice",
    "lat": "48.98119",
    "lng": "16.52445"
  },
  {
    "country": "CZ",
    "name": "Podolí",
    "lat": "49.19042",
    "lng": "16.72084"
  },
  {
    "country": "CZ",
    "name": "Podivín",
    "lat": "48.82554",
    "lng": "16.84822"
  },
  {
    "country": "CZ",
    "name": "Poděbrady",
    "lat": "50.14242",
    "lng": "15.11881"
  },
  {
    "country": "CZ",
    "name": "Podbořany",
    "lat": "50.22937",
    "lng": "13.41192"
  },
  {
    "country": "CZ",
    "name": "Počátky",
    "lat": "49.2602",
    "lng": "15.24022"
  },
  {
    "country": "CZ",
    "name": "Poběžovice",
    "lat": "49.51029",
    "lng": "12.80261"
  },
  {
    "country": "CZ",
    "name": "Pilsen",
    "lat": "49.74747",
    "lng": "13.37759"
  },
  {
    "country": "CZ",
    "name": "Plumlov",
    "lat": "49.46614",
    "lng": "17.01502"
  },
  {
    "country": "CZ",
    "name": "Plesná",
    "lat": "50.2207",
    "lng": "12.34669"
  },
  {
    "country": "CZ",
    "name": "Plavy",
    "lat": "50.70324",
    "lng": "15.31736"
  },
  {
    "country": "CZ",
    "name": "Plasy",
    "lat": "49.93449",
    "lng": "13.39035"
  },
  {
    "country": "CZ",
    "name": "Plánice",
    "lat": "49.38993",
    "lng": "13.47106"
  },
  {
    "country": "CZ",
    "name": "Plaňany",
    "lat": "50.0501",
    "lng": "15.02944"
  },
  {
    "country": "CZ",
    "name": "Planá nad Lužnicí",
    "lat": "49.35444",
    "lng": "14.70147"
  },
  {
    "country": "CZ",
    "name": "Planá",
    "lat": "49.86816",
    "lng": "12.74378"
  },
  {
    "country": "CZ",
    "name": "Píšť",
    "lat": "49.97857",
    "lng": "18.19349"
  },
  {
    "country": "CZ",
    "name": "Písek",
    "lat": "49.55924",
    "lng": "18.80231"
  },
  {
    "country": "CZ",
    "name": "Písek",
    "lat": "49.3088",
    "lng": "14.1475"
  },
  {
    "country": "CZ",
    "name": "Písečná",
    "lat": "50.27303",
    "lng": "17.25373"
  },
  {
    "country": "CZ",
    "name": "Pilníkov",
    "lat": "50.53247",
    "lng": "15.8202"
  },
  {
    "country": "CZ",
    "name": "Petřvald",
    "lat": "49.831",
    "lng": "18.3894"
  },
  {
    "country": "CZ",
    "name": "Petřvald",
    "lat": "49.70872",
    "lng": "18.15719"
  },
  {
    "country": "CZ",
    "name": "Petrovice u Karviné",
    "lat": "49.89587",
    "lng": "18.54779"
  },
  {
    "country": "CZ",
    "name": "Petrovice",
    "lat": "49.55426",
    "lng": "14.33737"
  },
  {
    "country": "CZ",
    "name": "Petrov",
    "lat": "48.88196",
    "lng": "17.2781"
  },
  {
    "country": "CZ",
    "name": "Peruc",
    "lat": "50.3425",
    "lng": "13.95986"
  },
  {
    "country": "CZ",
    "name": "Perštejn",
    "lat": "50.38166",
    "lng": "13.1102"
  },
  {
    "country": "CZ",
    "name": "Pěnčín",
    "lat": "50.68769",
    "lng": "15.23593"
  },
  {
    "country": "CZ",
    "name": "Pelhřimov",
    "lat": "49.43134",
    "lng": "15.22336"
  },
  {
    "country": "CZ",
    "name": "Pečky",
    "lat": "50.09043",
    "lng": "15.03017"
  },
  {
    "country": "CZ",
    "name": "Pecka",
    "lat": "50.48034",
    "lng": "15.60822"
  },
  {
    "country": "CZ",
    "name": "Pchery",
    "lat": "50.19378",
    "lng": "14.11782"
  },
  {
    "country": "CZ",
    "name": "Pavlíkov",
    "lat": "50.05599",
    "lng": "13.73636"
  },
  {
    "country": "CZ",
    "name": "Paskov",
    "lat": "49.73179",
    "lng": "18.29037"
  },
  {
    "country": "CZ",
    "name": "Paseka",
    "lat": "49.79644",
    "lng": "17.22276"
  },
  {
    "country": "CZ",
    "name": "Pardubice",
    "lat": "50.04075",
    "lng": "15.77659"
  },
  {
    "country": "CZ",
    "name": "Palkovice",
    "lat": "49.63467",
    "lng": "18.31508"
  },
  {
    "country": "CZ",
    "name": "Pacov",
    "lat": "49.47076",
    "lng": "15.00168"
  },
  {
    "country": "CZ",
    "name": "Otrokovice",
    "lat": "49.20934",
    "lng": "17.53944"
  },
  {
    "country": "CZ",
    "name": "Otnice",
    "lat": "49.08642",
    "lng": "16.81443"
  },
  {
    "country": "CZ",
    "name": "Otice",
    "lat": "49.91684",
    "lng": "17.86982"
  },
  {
    "country": "CZ",
    "name": "Otaslavice",
    "lat": "49.38833",
    "lng": "17.07108"
  },
  {
    "country": "CZ",
    "name": "Ostrožská Nová Ves",
    "lat": "49.00434",
    "lng": "17.43632"
  },
  {
    "country": "CZ",
    "name": "Ostrožská Lhota",
    "lat": "48.97559",
    "lng": "17.46751"
  },
  {
    "country": "CZ",
    "name": "Ostrov u Macochy",
    "lat": "49.38236",
    "lng": "16.76268"
  },
  {
    "country": "CZ",
    "name": "Ostrov",
    "lat": "50.30592",
    "lng": "12.93907"
  },
  {
    "country": "CZ",
    "name": "Ostroměř",
    "lat": "50.37246",
    "lng": "15.54949"
  },
  {
    "country": "CZ",
    "name": "Ostravice",
    "lat": "49.5351",
    "lng": "18.39164"
  },
  {
    "country": "CZ",
    "name": "Ostrava",
    "lat": "49.83465",
    "lng": "18.28204"
  },
  {
    "country": "CZ",
    "name": "Ostopovice",
    "lat": "49.161",
    "lng": "16.54548"
  },
  {
    "country": "CZ",
    "name": "Osoblaha",
    "lat": "50.27517",
    "lng": "17.71523"
  },
  {
    "country": "CZ",
    "name": "Oslavany",
    "lat": "49.12335",
    "lng": "16.33653"
  },
  {
    "country": "CZ",
    "name": "Oskava",
    "lat": "49.89523",
    "lng": "17.13214"
  },
  {
    "country": "CZ",
    "name": "Osík",
    "lat": "49.84355",
    "lng": "16.28467"
  },
  {
    "country": "CZ",
    "name": "Osek nad Bečvou",
    "lat": "49.51121",
    "lng": "17.52829"
  },
  {
    "country": "CZ",
    "name": "Osek",
    "lat": "50.62115",
    "lng": "13.69274"
  },
  {
    "country": "CZ",
    "name": "Osek",
    "lat": "49.77594",
    "lng": "13.5906"
  },
  {
    "country": "CZ",
    "name": "Osečná",
    "lat": "50.69489",
    "lng": "14.92138"
  },
  {
    "country": "CZ",
    "name": "Orlová",
    "lat": "49.84527",
    "lng": "18.43011"
  },
  {
    "country": "CZ",
    "name": "Ořechov",
    "lat": "49.11118",
    "lng": "16.52329"
  },
  {
    "country": "CZ",
    "name": "Opočno",
    "lat": "50.26742",
    "lng": "16.1148"
  },
  {
    "country": "CZ",
    "name": "Opava",
    "lat": "49.93866",
    "lng": "17.90257"
  },
  {
    "country": "CZ",
    "name": "Opatovice nad Labem",
    "lat": "50.14541",
    "lng": "15.79045"
  },
  {
    "country": "CZ",
    "name": "Opatov",
    "lat": "49.825",
    "lng": "16.50458"
  },
  {
    "country": "CZ",
    "name": "Opařany",
    "lat": "49.39678",
    "lng": "14.48137"
  },
  {
    "country": "CZ",
    "name": "Ondřejov",
    "lat": "49.90461",
    "lng": "14.7842"
  },
  {
    "country": "CZ",
    "name": "Olšany",
    "lat": "49.96509",
    "lng": "16.85894"
  },
  {
    "country": "CZ",
    "name": "Oloví",
    "lat": "50.25113",
    "lng": "12.55877"
  },
  {
    "country": "CZ",
    "name": "Olomouc",
    "lat": "49.59552",
    "lng": "17.25175"
  },
  {
    "country": "CZ",
    "name": "Olešnice",
    "lat": "49.55755",
    "lng": "16.42169"
  },
  {
    "country": "CZ",
    "name": "Oldřišov",
    "lat": "49.9913",
    "lng": "17.96074"
  },
  {
    "country": "CZ",
    "name": "Olbramovice",
    "lat": "48.9848",
    "lng": "16.40239"
  },
  {
    "country": "CZ",
    "name": "Okrouhlice",
    "lat": "49.62991",
    "lng": "15.49083"
  },
  {
    "country": "CZ",
    "name": "Okříšky",
    "lat": "49.24539",
    "lng": "15.76959"
  },
  {
    "country": "CZ",
    "name": "Ohrazenice",
    "lat": "50.59765",
    "lng": "15.12596"
  },
  {
    "country": "CZ",
    "name": "Odry",
    "lat": "49.66255",
    "lng": "17.83084"
  },
  {
    "country": "CZ",
    "name": "Odolena Voda",
    "lat": "50.23341",
    "lng": "14.41078"
  },
  {
    "country": "CZ",
    "name": "Obrnice",
    "lat": "50.50498",
    "lng": "13.6954"
  },
  {
    "country": "CZ",
    "name": "Obecnice",
    "lat": "49.71615",
    "lng": "13.94731"
  },
  {
    "country": "CZ",
    "name": "Nýrsko",
    "lat": "49.29387",
    "lng": "13.14353"
  },
  {
    "country": "CZ",
    "name": "Nýřany",
    "lat": "49.71145",
    "lng": "13.21185"
  },
  {
    "country": "CZ",
    "name": "Nymburk",
    "lat": "50.18605",
    "lng": "15.04167"
  },
  {
    "country": "CZ",
    "name": "Nýdek",
    "lat": "49.65609",
    "lng": "18.75687"
  },
  {
    "country": "CZ",
    "name": "Nový Malín",
    "lat": "49.94262",
    "lng": "17.03191"
  },
  {
    "country": "CZ",
    "name": "Nový Knín",
    "lat": "49.788",
    "lng": "14.29355"
  },
  {
    "country": "CZ",
    "name": "Nový Jičín",
    "lat": "49.59438",
    "lng": "18.01028"
  },
  {
    "country": "CZ",
    "name": "Nový Hrozenkov",
    "lat": "49.33697",
    "lng": "18.19793"
  },
  {
    "country": "CZ",
    "name": "Nový Bydžov",
    "lat": "50.2415",
    "lng": "15.49082"
  },
  {
    "country": "CZ",
    "name": "Nový Bor",
    "lat": "50.75761",
    "lng": "14.55555"
  },
  {
    "country": "CZ",
    "name": "Novosedly",
    "lat": "48.83704",
    "lng": "16.49273"
  },
  {
    "country": "CZ",
    "name": "Novosedlice",
    "lat": "50.65633",
    "lng": "13.82304"
  },
  {
    "country": "CZ",
    "name": "Nové Veselí",
    "lat": "49.51976",
    "lng": "15.90853"
  },
  {
    "country": "CZ",
    "name": "Nové Syrovice",
    "lat": "49.01763",
    "lng": "15.77345"
  },
  {
    "country": "CZ",
    "name": "Nové Strašecí",
    "lat": "50.15272",
    "lng": "13.90043"
  },
  {
    "country": "CZ",
    "name": "Nové Sedlo",
    "lat": "50.20647",
    "lng": "12.738"
  },
  {
    "country": "CZ",
    "name": "Nové Město pod Smrkem",
    "lat": "50.92491",
    "lng": "15.22943"
  },
  {
    "country": "CZ",
    "name": "Nové Město na Moravě",
    "lat": "49.56144",
    "lng": "16.07418"
  },
  {
    "country": "CZ",
    "name": "Nové Město nad Metují",
    "lat": "50.34456",
    "lng": "16.15147"
  },
  {
    "country": "CZ",
    "name": "Nové Hrady",
    "lat": "48.78963",
    "lng": "14.77839"
  },
  {
    "country": "CZ",
    "name": "Nová Včelnice",
    "lat": "49.23935",
    "lng": "15.0726"
  },
  {
    "country": "CZ",
    "name": "Nová Role",
    "lat": "50.27092",
    "lng": "12.78422"
  },
  {
    "country": "CZ",
    "name": "Nová Paka",
    "lat": "50.49449",
    "lng": "15.51503"
  },
  {
    "country": "CZ",
    "name": "Nová Cerekev",
    "lat": "49.41723",
    "lng": "15.11675"
  },
  {
    "country": "CZ",
    "name": "Nová Bystřice",
    "lat": "49.01926",
    "lng": "15.10316"
  },
  {
    "country": "CZ",
    "name": "Nosislav",
    "lat": "49.0138",
    "lng": "16.65431"
  },
  {
    "country": "CZ",
    "name": "Nižbor",
    "lat": "49.99995",
    "lng": "14.00237"
  },
  {
    "country": "CZ",
    "name": "Nivnice",
    "lat": "48.97465",
    "lng": "17.64757"
  },
  {
    "country": "CZ",
    "name": "Nezvěstice",
    "lat": "49.64043",
    "lng": "13.51962"
  },
  {
    "country": "CZ",
    "name": "Nezamyslice",
    "lat": "49.32543",
    "lng": "17.17326"
  },
  {
    "country": "CZ",
    "name": "Neveklov",
    "lat": "49.75373",
    "lng": "14.53291"
  },
  {
    "country": "CZ",
    "name": "Netvořice",
    "lat": "49.81569",
    "lng": "14.51827"
  },
  {
    "country": "CZ",
    "name": "Netolice",
    "lat": "49.0493",
    "lng": "14.197"
  },
  {
    "country": "CZ",
    "name": "Nesovice",
    "lat": "49.15111",
    "lng": "17.08095"
  },
  {
    "country": "CZ",
    "name": "Neratovice",
    "lat": "50.25926",
    "lng": "14.51759"
  },
  {
    "country": "CZ",
    "name": "Nepomuk",
    "lat": "49.48616",
    "lng": "13.58225"
  },
  {
    "country": "CZ",
    "name": "Němčice nad Hanou",
    "lat": "49.34181",
    "lng": "17.20596"
  },
  {
    "country": "CZ",
    "name": "Nelahozeves",
    "lat": "50.26148",
    "lng": "14.29881"
  },
  {
    "country": "CZ",
    "name": "Nejdek",
    "lat": "50.32242",
    "lng": "12.72936"
  },
  {
    "country": "CZ",
    "name": "Nehvizdy",
    "lat": "50.13056",
    "lng": "14.72993"
  },
  {
    "country": "CZ",
    "name": "Nedvědice",
    "lat": "49.45702",
    "lng": "16.33406"
  },
  {
    "country": "CZ",
    "name": "Nedašov",
    "lat": "49.10778",
    "lng": "18.07036"
  },
  {
    "country": "CZ",
    "name": "Nedakonice",
    "lat": "49.03159",
    "lng": "17.38141"
  },
  {
    "country": "CZ",
    "name": "Nechanice",
    "lat": "50.23737",
    "lng": "15.63276"
  },
  {
    "country": "CZ",
    "name": "Návsí u Jablunkova",
    "lat": "49.5872",
    "lng": "18.75907"
  },
  {
    "country": "CZ",
    "name": "Nasavrky",
    "lat": "49.8445",
    "lng": "15.80461"
  },
  {
    "country": "CZ",
    "name": "Napajedla",
    "lat": "49.17156",
    "lng": "17.51194"
  },
  {
    "country": "CZ",
    "name": "Náměšť na Hané",
    "lat": "49.60213",
    "lng": "17.06539"
  },
  {
    "country": "CZ",
    "name": "Náměšť nad Oslavou",
    "lat": "49.20726",
    "lng": "16.15849"
  },
  {
    "country": "CZ",
    "name": "Náklo",
    "lat": "49.65462",
    "lng": "17.12969"
  },
  {
    "country": "CZ",
    "name": "Náchod",
    "lat": "50.4167",
    "lng": "16.16289"
  },
  {
    "country": "CZ",
    "name": "Načeradec",
    "lat": "49.61018",
    "lng": "14.90633"
  },
  {
    "country": "CZ",
    "name": "Mýto",
    "lat": "49.78904",
    "lng": "13.73461"
  },
  {
    "country": "CZ",
    "name": "Mutěnice",
    "lat": "48.90413",
    "lng": "17.02917"
  },
  {
    "country": "CZ",
    "name": "Mukařov",
    "lat": "49.99115",
    "lng": "14.74155"
  },
  {
    "country": "CZ",
    "name": "Mšeno",
    "lat": "50.43809",
    "lng": "14.6325"
  },
  {
    "country": "CZ",
    "name": "Mrákov",
    "lat": "49.40314",
    "lng": "12.9512"
  },
  {
    "country": "CZ",
    "name": "Moutnice",
    "lat": "49.04924",
    "lng": "16.73741"
  },
  {
    "country": "CZ",
    "name": "Mosty u Jablunkova",
    "lat": "49.52737",
    "lng": "18.75417"
  },
  {
    "country": "CZ",
    "name": "Mostkovice",
    "lat": "49.47215",
    "lng": "17.05212"
  },
  {
    "country": "CZ",
    "name": "Mostek",
    "lat": "50.48623",
    "lng": "15.69622"
  },
  {
    "country": "CZ",
    "name": "Most",
    "lat": "50.50301",
    "lng": "13.63617"
  },
  {
    "country": "CZ",
    "name": "Mořkov",
    "lat": "49.53684",
    "lng": "18.05968"
  },
  {
    "country": "CZ",
    "name": "Moravský Žižkov",
    "lat": "48.83285",
    "lng": "16.9314"
  },
  {
    "country": "CZ",
    "name": "Moravský Písek",
    "lat": "48.99016",
    "lng": "17.33269"
  },
  {
    "country": "CZ",
    "name": "Moravský Krumlov",
    "lat": "49.04893",
    "lng": "16.31169"
  },
  {
    "country": "CZ",
    "name": "Moravský Beroun",
    "lat": "49.79374",
    "lng": "17.44212"
  },
  {
    "country": "CZ",
    "name": "Moravské Budějovice",
    "lat": "49.05209",
    "lng": "15.80864"
  },
  {
    "country": "CZ",
    "name": "Moravská Třebová",
    "lat": "49.75793",
    "lng": "16.66426"
  },
  {
    "country": "CZ",
    "name": "Moravská Nová Ves",
    "lat": "48.80304",
    "lng": "17.01371"
  },
  {
    "country": "CZ",
    "name": "Morávka",
    "lat": "49.59607",
    "lng": "18.52471"
  },
  {
    "country": "CZ",
    "name": "Moravičany",
    "lat": "49.75694",
    "lng": "16.96042"
  },
  {
    "country": "CZ",
    "name": "Moravany",
    "lat": "50.00095",
    "lng": "15.94071"
  },
  {
    "country": "CZ",
    "name": "Moravany",
    "lat": "49.1478",
    "lng": "16.58026"
  },
  {
    "country": "CZ",
    "name": "Mokré Lazce",
    "lat": "49.90462",
    "lng": "18.02954"
  },
  {
    "country": "CZ",
    "name": "Mokrá Hora",
    "lat": "49.26176",
    "lng": "16.59107"
  },
  {
    "country": "CZ",
    "name": "Mohelno",
    "lat": "49.11412",
    "lng": "16.19022"
  },
  {
    "country": "CZ",
    "name": "Mohelnice",
    "lat": "49.77698",
    "lng": "16.91946"
  },
  {
    "country": "CZ",
    "name": "Modřice",
    "lat": "49.11928",
    "lng": "16.60446"
  },
  {
    "country": "CZ",
    "name": "Modřany",
    "lat": "50.01116",
    "lng": "14.4096"
  },
  {
    "country": "CZ",
    "name": "Mníšek pod Brdy",
    "lat": "49.8665",
    "lng": "14.26176"
  },
  {
    "country": "CZ",
    "name": "Mníšek",
    "lat": "50.83163",
    "lng": "15.0563"
  },
  {
    "country": "CZ",
    "name": "Mnichovo Hradiště",
    "lat": "50.5272",
    "lng": "14.97134"
  },
  {
    "country": "CZ",
    "name": "Mnichovice",
    "lat": "49.93601",
    "lng": "14.70907"
  },
  {
    "country": "CZ",
    "name": "Mladé Buky",
    "lat": "50.60643",
    "lng": "15.83348"
  },
  {
    "country": "CZ",
    "name": "Mladá Vožice",
    "lat": "49.53313",
    "lng": "14.80857"
  },
  {
    "country": "CZ",
    "name": "Mladá Boleslav",
    "lat": "50.41135",
    "lng": "14.90318"
  },
  {
    "country": "CZ",
    "name": "Mistřice",
    "lat": "49.08668",
    "lng": "17.53597"
  },
  {
    "country": "CZ",
    "name": "Mirovice",
    "lat": "49.51555",
    "lng": "14.03582"
  },
  {
    "country": "CZ",
    "name": "Mirotice",
    "lat": "49.42908",
    "lng": "14.03697"
  },
  {
    "country": "CZ",
    "name": "Mirošov",
    "lat": "49.68782",
    "lng": "13.65807"
  },
  {
    "country": "CZ",
    "name": "Miroslav",
    "lat": "48.94767",
    "lng": "16.31252"
  },
  {
    "country": "CZ",
    "name": "Miřetice",
    "lat": "49.84126",
    "lng": "15.88472"
  },
  {
    "country": "CZ",
    "name": "Mimoň",
    "lat": "50.65869",
    "lng": "14.72474"
  },
  {
    "country": "CZ",
    "name": "Milovice",
    "lat": "50.22596",
    "lng": "14.88863"
  },
  {
    "country": "CZ",
    "name": "Milotice",
    "lat": "48.95528",
    "lng": "17.14241"
  },
  {
    "country": "CZ",
    "name": "Milín",
    "lat": "49.63192",
    "lng": "14.046"
  },
  {
    "country": "CZ",
    "name": "Milíkov",
    "lat": "49.58565",
    "lng": "18.71943"
  },
  {
    "country": "CZ",
    "name": "Milevsko",
    "lat": "49.45089",
    "lng": "14.36"
  },
  {
    "country": "CZ",
    "name": "Mikulovice",
    "lat": "50.29854",
    "lng": "17.32155"
  },
  {
    "country": "CZ",
    "name": "Mikulov",
    "lat": "48.80556",
    "lng": "16.6378"
  },
  {
    "country": "CZ",
    "name": "Mikulčice",
    "lat": "48.81643",
    "lng": "17.05107"
  },
  {
    "country": "CZ",
    "name": "Mikulášovice",
    "lat": "50.96507",
    "lng": "14.36368"
  },
  {
    "country": "CZ",
    "name": "Meziměstí",
    "lat": "50.62461",
    "lng": "16.24207"
  },
  {
    "country": "CZ",
    "name": "Meziboři",
    "lat": "50.62115",
    "lng": "13.5987"
  },
  {
    "country": "CZ",
    "name": "Metylovice",
    "lat": "49.60666",
    "lng": "18.33911"
  },
  {
    "country": "CZ",
    "name": "Město Touškov",
    "lat": "49.77587",
    "lng": "13.25108"
  },
  {
    "country": "CZ",
    "name": "Město Libavá",
    "lat": "49.72162",
    "lng": "17.52013"
  },
  {
    "country": "CZ",
    "name": "Město Albrechtice",
    "lat": "50.16294",
    "lng": "17.57481"
  },
  {
    "country": "CZ",
    "name": "Město",
    "lat": "49.97997",
    "lng": "12.86432"
  },
  {
    "country": "CZ",
    "name": "Městec Králové",
    "lat": "50.20718",
    "lng": "15.29758"
  },
  {
    "country": "CZ",
    "name": "Městečko Trnávka",
    "lat": "49.70926",
    "lng": "16.72744"
  },
  {
    "country": "CZ",
    "name": "Měšice",
    "lat": "50.19799",
    "lng": "14.51992"
  },
  {
    "country": "CZ",
    "name": "Merklín",
    "lat": "50.32808",
    "lng": "12.8635"
  },
  {
    "country": "CZ",
    "name": "Merklín",
    "lat": "49.56043",
    "lng": "13.1979"
  },
  {
    "country": "CZ",
    "name": "Měřín",
    "lat": "49.39321",
    "lng": "15.88381"
  },
  {
    "country": "CZ",
    "name": "Měnín",
    "lat": "49.0824",
    "lng": "16.69424"
  },
  {
    "country": "CZ",
    "name": "Mělník",
    "lat": "50.3505",
    "lng": "14.47411"
  },
  {
    "country": "CZ",
    "name": "Medlov",
    "lat": "49.78754",
    "lng": "17.06261"
  },
  {
    "country": "CZ",
    "name": "Meclov",
    "lat": "49.50556",
    "lng": "12.88082"
  },
  {
    "country": "CZ",
    "name": "Měčín",
    "lat": "49.48009",
    "lng": "13.40289"
  },
  {
    "country": "CZ",
    "name": "Měcholupy",
    "lat": "50.26666",
    "lng": "13.53737"
  },
  {
    "country": "CZ",
    "name": "Markvartovice",
    "lat": "49.90595",
    "lng": "18.23602"
  },
  {
    "country": "CZ",
    "name": "Mariánské Lázně",
    "lat": "49.96459",
    "lng": "12.70118"
  },
  {
    "country": "CZ",
    "name": "Manětín",
    "lat": "49.99177",
    "lng": "13.23319"
  },
  {
    "country": "CZ",
    "name": "Malšice",
    "lat": "49.36391",
    "lng": "14.57868"
  },
  {
    "country": "CZ",
    "name": "Malonty",
    "lat": "48.68611",
    "lng": "14.57678"
  },
  {
    "country": "CZ",
    "name": "Malé Svatoňovice",
    "lat": "50.53395",
    "lng": "16.04978"
  },
  {
    "country": "CZ",
    "name": "Malá Strana",
    "lat": "50.08774",
    "lng": "14.40449"
  },
  {
    "country": "CZ",
    "name": "Malá Skála",
    "lat": "50.64631",
    "lng": "15.19543"
  },
  {
    "country": "CZ",
    "name": "Majetín",
    "lat": "49.49808",
    "lng": "17.33314"
  },
  {
    "country": "CZ",
    "name": "Machov",
    "lat": "50.49927",
    "lng": "16.2769"
  },
  {
    "country": "CZ",
    "name": "Lysice",
    "lat": "49.4516",
    "lng": "16.53716"
  },
  {
    "country": "CZ",
    "name": "Lysá nad Labem",
    "lat": "50.20143",
    "lng": "14.83281"
  },
  {
    "country": "CZ",
    "name": "Lužná",
    "lat": "50.12377",
    "lng": "13.77004"
  },
  {
    "country": "CZ",
    "name": "Lužice",
    "lat": "48.84098",
    "lng": "17.07104"
  },
  {
    "country": "CZ",
    "name": "Lužec nad Vltavou",
    "lat": "50.32138",
    "lng": "14.40022"
  },
  {
    "country": "CZ",
    "name": "Luže",
    "lat": "49.89341",
    "lng": "16.0285"
  },
  {
    "country": "CZ",
    "name": "Lutín",
    "lat": "49.55845",
    "lng": "17.13572"
  },
  {
    "country": "CZ",
    "name": "Luštěnice",
    "lat": "50.32296",
    "lng": "14.93667"
  },
  {
    "country": "CZ",
    "name": "Lukov",
    "lat": "49.29027",
    "lng": "17.72959"
  },
  {
    "country": "CZ",
    "name": "Lukavice",
    "lat": "50.06029",
    "lng": "16.48207"
  },
  {
    "country": "CZ",
    "name": "Lukavec",
    "lat": "49.56541",
    "lng": "14.99041"
  },
  {
    "country": "CZ",
    "name": "Luka nad Jihlavou",
    "lat": "49.37403",
    "lng": "15.70194"
  },
  {
    "country": "CZ",
    "name": "Luhačovice",
    "lat": "49.09982",
    "lng": "17.75747"
  },
  {
    "country": "CZ",
    "name": "Ludgeřovice",
    "lat": "49.89042",
    "lng": "18.24008"
  },
  {
    "country": "CZ",
    "name": "Lučany nad Nisou",
    "lat": "50.74136",
    "lng": "15.22046"
  },
  {
    "country": "CZ",
    "name": "Luby",
    "lat": "50.25248",
    "lng": "12.40595"
  },
  {
    "country": "CZ",
    "name": "Lubenec",
    "lat": "50.13207",
    "lng": "13.31319"
  },
  {
    "country": "CZ",
    "name": "Lovosice",
    "lat": "50.51504",
    "lng": "14.05103"
  },
  {
    "country": "CZ",
    "name": "Louny",
    "lat": "50.35699",
    "lng": "13.79667"
  },
  {
    "country": "CZ",
    "name": "Louka",
    "lat": "48.91517",
    "lng": "17.48927"
  },
  {
    "country": "CZ",
    "name": "Loučovice",
    "lat": "48.62019",
    "lng": "14.25747"
  },
  {
    "country": "CZ",
    "name": "Loučná nad Desnou",
    "lat": "50.07433",
    "lng": "17.09052"
  },
  {
    "country": "CZ",
    "name": "Loučeň",
    "lat": "50.28537",
    "lng": "15.02049"
  },
  {
    "country": "CZ",
    "name": "Loštice",
    "lat": "49.7447",
    "lng": "16.92892"
  },
  {
    "country": "CZ",
    "name": "Lom u Mostu",
    "lat": "50.59328",
    "lng": "13.65729"
  },
  {
    "country": "CZ",
    "name": "Lomnice nad Popelkou",
    "lat": "50.53062",
    "lng": "15.37341"
  },
  {
    "country": "CZ",
    "name": "Lomnice nad Lužnicí",
    "lat": "49.08468",
    "lng": "14.71727"
  },
  {
    "country": "CZ",
    "name": "Lomnice",
    "lat": "50.21174",
    "lng": "12.63267"
  },
  {
    "country": "CZ",
    "name": "Lomnice",
    "lat": "49.40462",
    "lng": "16.41359"
  },
  {
    "country": "CZ",
    "name": "Loket",
    "lat": "50.186",
    "lng": "12.75405"
  },
  {
    "country": "CZ",
    "name": "Loděnice",
    "lat": "49.99486",
    "lng": "14.15785"
  },
  {
    "country": "CZ",
    "name": "Lochovice",
    "lat": "49.85318",
    "lng": "13.98126"
  },
  {
    "country": "CZ",
    "name": "Litvínovice",
    "lat": "48.96207",
    "lng": "14.45146"
  },
  {
    "country": "CZ",
    "name": "Litvínov",
    "lat": "50.6042",
    "lng": "13.61812"
  },
  {
    "country": "CZ",
    "name": "Litovel",
    "lat": "49.70121",
    "lng": "17.07615"
  },
  {
    "country": "CZ",
    "name": "Litomyšl",
    "lat": "49.86809",
    "lng": "16.31298"
  },
  {
    "country": "CZ",
    "name": "Litoměřice",
    "lat": "50.53348",
    "lng": "14.1318"
  },
  {
    "country": "CZ",
    "name": "Lišov",
    "lat": "49.01597",
    "lng": "14.60838"
  },
  {
    "country": "CZ",
    "name": "Lipůvka",
    "lat": "49.33933",
    "lng": "16.55313"
  },
  {
    "country": "CZ",
    "name": "Liptál",
    "lat": "49.29051",
    "lng": "17.92177"
  },
  {
    "country": "CZ",
    "name": "Lipovec",
    "lat": "49.38394",
    "lng": "16.80583"
  },
  {
    "country": "CZ",
    "name": "Lipov",
    "lat": "48.90495",
    "lng": "17.46171"
  },
  {
    "country": "CZ",
    "name": "Lipník nad Bečvou",
    "lat": "49.52721",
    "lng": "17.58594"
  },
  {
    "country": "CZ",
    "name": "Lípa",
    "lat": "49.55418",
    "lng": "15.54465"
  },
  {
    "country": "CZ",
    "name": "Líně",
    "lat": "49.69472",
    "lng": "13.25693"
  },
  {
    "country": "CZ",
    "name": "Lidečko",
    "lat": "49.20303",
    "lng": "18.0513"
  },
  {
    "country": "CZ",
    "name": "Lichnov",
    "lat": "50.00786",
    "lng": "17.6264"
  },
  {
    "country": "CZ",
    "name": "Lichnov (o. Nový Jičín)",
    "lat": "49.56423",
    "lng": "18.16898"
  },
  {
    "country": "CZ",
    "name": "Libušín",
    "lat": "50.16819",
    "lng": "14.05458"
  },
  {
    "country": "CZ",
    "name": "Libouchec",
    "lat": "50.75854",
    "lng": "14.04071"
  },
  {
    "country": "CZ",
    "name": "Libochovice",
    "lat": "50.40626",
    "lng": "14.04439"
  },
  {
    "country": "CZ",
    "name": "Libiš",
    "lat": "50.27417",
    "lng": "14.5024"
  },
  {
    "country": "CZ",
    "name": "Libice nad Cidlinou",
    "lat": "50.12677",
    "lng": "15.1782"
  },
  {
    "country": "CZ",
    "name": "Líbeznice",
    "lat": "50.19198",
    "lng": "14.49357"
  },
  {
    "country": "CZ",
    "name": "Liběšice",
    "lat": "50.56886",
    "lng": "14.28906"
  },
  {
    "country": "CZ",
    "name": "Liberec",
    "lat": "50.76711",
    "lng": "15.05619"
  },
  {
    "country": "CZ",
    "name": "Libeň",
    "lat": "50.10819",
    "lng": "14.47457"
  },
  {
    "country": "CZ",
    "name": "Libčice nad Vltavou",
    "lat": "50.19778",
    "lng": "14.36385"
  },
  {
    "country": "CZ",
    "name": "Libáň",
    "lat": "50.37542",
    "lng": "15.21684"
  },
  {
    "country": "CZ",
    "name": "Lhenice",
    "lat": "48.99479",
    "lng": "14.1498"
  },
  {
    "country": "CZ",
    "name": "Letovice",
    "lat": "49.54709",
    "lng": "16.57357"
  },
  {
    "country": "CZ",
    "name": "Letonice",
    "lat": "49.17726",
    "lng": "16.95913"
  },
  {
    "country": "CZ",
    "name": "Letohrad",
    "lat": "50.0358",
    "lng": "16.49879"
  },
  {
    "country": "CZ",
    "name": "Letňany",
    "lat": "50.13333",
    "lng": "14.51667"
  },
  {
    "country": "CZ",
    "name": "Leština",
    "lat": "49.86879",
    "lng": "16.92748"
  },
  {
    "country": "CZ",
    "name": "Lešná",
    "lat": "49.52055",
    "lng": "17.93004"
  },
  {
    "country": "CZ",
    "name": "Lenešice",
    "lat": "50.37516",
    "lng": "13.7659"
  },
  {
    "country": "CZ",
    "name": "Lelekovice",
    "lat": "49.29144",
    "lng": "16.57874"
  },
  {
    "country": "CZ",
    "name": "Lednice",
    "lat": "48.79992",
    "lng": "16.80339"
  },
  {
    "country": "CZ",
    "name": "Ledenice",
    "lat": "48.93329",
    "lng": "14.61886"
  },
  {
    "country": "CZ",
    "name": "Ledeč nad Sázavou",
    "lat": "49.69517",
    "lng": "15.27772"
  },
  {
    "country": "CZ",
    "name": "Lázně Kynžvart",
    "lat": "50.01058",
    "lng": "12.62474"
  },
  {
    "country": "CZ",
    "name": "Lázně Bělohrad",
    "lat": "50.42874",
    "lng": "15.58269"
  },
  {
    "country": "CZ",
    "name": "Lanžhot",
    "lat": "48.72443",
    "lng": "16.96695"
  },
  {
    "country": "CZ",
    "name": "Lány",
    "lat": "50.12471",
    "lng": "13.95041"
  },
  {
    "country": "CZ",
    "name": "Lanškroun",
    "lat": "49.91217",
    "lng": "16.6119"
  },
  {
    "country": "CZ",
    "name": "Kynšperk nad Ohří",
    "lat": "50.11893",
    "lng": "12.53027"
  },
  {
    "country": "CZ",
    "name": "Kyjov",
    "lat": "49.01018",
    "lng": "17.12253"
  },
  {
    "country": "CZ",
    "name": "Kvasiny",
    "lat": "50.2125",
    "lng": "16.26323"
  },
  {
    "country": "CZ",
    "name": "Kvasice",
    "lat": "49.24223",
    "lng": "17.46974"
  },
  {
    "country": "CZ",
    "name": "Kutná Hora",
    "lat": "49.94839",
    "lng": "15.26816"
  },
  {
    "country": "CZ",
    "name": "Kuřim",
    "lat": "49.29852",
    "lng": "16.53144"
  },
  {
    "country": "CZ",
    "name": "Kunžak",
    "lat": "49.12119",
    "lng": "15.19028"
  },
  {
    "country": "CZ",
    "name": "Kunvald",
    "lat": "50.12927",
    "lng": "16.49996"
  },
  {
    "country": "CZ",
    "name": "Kunštát",
    "lat": "49.50645",
    "lng": "16.51722"
  },
  {
    "country": "CZ",
    "name": "Kunovice",
    "lat": "49.04499",
    "lng": "17.47011"
  },
  {
    "country": "CZ",
    "name": "Kunín",
    "lat": "49.63377",
    "lng": "17.98965"
  },
  {
    "country": "CZ",
    "name": "Kunčina",
    "lat": "49.79455",
    "lng": "16.62763"
  },
  {
    "country": "CZ",
    "name": "Kunčice pod Ondřejníkem",
    "lat": "49.5507",
    "lng": "18.26113"
  },
  {
    "country": "CZ",
    "name": "Kryry",
    "lat": "50.17437",
    "lng": "13.4266"
  },
  {
    "country": "CZ",
    "name": "Krupka",
    "lat": "50.68449",
    "lng": "13.85815"
  },
  {
    "country": "CZ",
    "name": "Krumvíř",
    "lat": "48.98901",
    "lng": "16.91027"
  },
  {
    "country": "CZ",
    "name": "Krouna",
    "lat": "49.7724",
    "lng": "16.02674"
  },
  {
    "country": "CZ",
    "name": "Kroměříž",
    "lat": "49.29785",
    "lng": "17.39312"
  },
  {
    "country": "CZ",
    "name": "Krnov",
    "lat": "50.08967",
    "lng": "17.70385"
  },
  {
    "country": "CZ",
    "name": "Krmelín",
    "lat": "49.72914",
    "lng": "18.23541"
  },
  {
    "country": "CZ",
    "name": "Křížová",
    "lat": "49.68841",
    "lng": "15.85207"
  },
  {
    "country": "CZ",
    "name": "Křižanov",
    "lat": "49.38858",
    "lng": "16.1096"
  },
  {
    "country": "CZ",
    "name": "Křinec",
    "lat": "50.26449",
    "lng": "15.13782"
  },
  {
    "country": "CZ",
    "name": "Křešice",
    "lat": "50.52259",
    "lng": "14.2145"
  },
  {
    "country": "CZ",
    "name": "Křepice",
    "lat": "48.99986",
    "lng": "16.71989"
  },
  {
    "country": "CZ",
    "name": "Křenovice",
    "lat": "49.14216",
    "lng": "16.82932"
  },
  {
    "country": "CZ",
    "name": "Křemže",
    "lat": "48.90497",
    "lng": "14.30568"
  },
  {
    "country": "CZ",
    "name": "Kravaře",
    "lat": "49.93203",
    "lng": "18.00472"
  },
  {
    "country": "CZ",
    "name": "Krásná Lípa",
    "lat": "50.91303",
    "lng": "14.50999"
  },
  {
    "country": "CZ",
    "name": "Krásná Lípa",
    "lat": "50.48378",
    "lng": "13.3575"
  },
  {
    "country": "CZ",
    "name": "Krásná Hora nad Vltavou",
    "lat": "49.60461",
    "lng": "14.27742"
  },
  {
    "country": "CZ",
    "name": "Kraslice",
    "lat": "50.32372",
    "lng": "12.51747"
  },
  {
    "country": "CZ",
    "name": "Králův Dvůr",
    "lat": "49.94981",
    "lng": "14.03445"
  },
  {
    "country": "CZ",
    "name": "Kralupy nad Vltavou",
    "lat": "50.24107",
    "lng": "14.31149"
  },
  {
    "country": "CZ",
    "name": "Kralovice",
    "lat": "49.98192",
    "lng": "13.48747"
  },
  {
    "country": "CZ",
    "name": "Králíky",
    "lat": "50.08384",
    "lng": "16.76054"
  },
  {
    "country": "CZ",
    "name": "Kralice na Hané",
    "lat": "49.46296",
    "lng": "17.18048"
  },
  {
    "country": "CZ",
    "name": "Kozmice",
    "lat": "49.9128",
    "lng": "18.15584"
  },
  {
    "country": "CZ",
    "name": "Kozlovice",
    "lat": "49.5904",
    "lng": "18.25656"
  },
  {
    "country": "CZ",
    "name": "Kožlany",
    "lat": "49.99389",
    "lng": "13.54107"
  },
  {
    "country": "CZ",
    "name": "Kovářská",
    "lat": "50.43821",
    "lng": "13.05388"
  },
  {
    "country": "CZ",
    "name": "Kovářov",
    "lat": "49.5176",
    "lng": "14.27809"
  },
  {
    "country": "CZ",
    "name": "Kout na Šumavě",
    "lat": "49.40255",
    "lng": "13.00208"
  },
  {
    "country": "CZ",
    "name": "Kouřim",
    "lat": "50.00306",
    "lng": "14.97703"
  },
  {
    "country": "CZ",
    "name": "Kostice",
    "lat": "48.74685",
    "lng": "16.97869"
  },
  {
    "country": "CZ",
    "name": "Kostelec na Hané",
    "lat": "49.51398",
    "lng": "17.05824"
  },
  {
    "country": "CZ",
    "name": "Kostelec nad Orlicí",
    "lat": "50.12267",
    "lng": "16.21319"
  },
  {
    "country": "CZ",
    "name": "Kostelec nad Labem",
    "lat": "50.22653",
    "lng": "14.58552"
  },
  {
    "country": "CZ",
    "name": "Kostelec nad Černými Lesy",
    "lat": "49.99403",
    "lng": "14.85922"
  },
  {
    "country": "CZ",
    "name": "Košťany",
    "lat": "50.65507",
    "lng": "13.75554"
  },
  {
    "country": "CZ",
    "name": "Košťálov",
    "lat": "50.57165",
    "lng": "15.40403"
  },
  {
    "country": "CZ",
    "name": "Kosova Hora",
    "lat": "49.65414",
    "lng": "14.47173"
  },
  {
    "country": "CZ",
    "name": "Kosmonosy",
    "lat": "50.4385",
    "lng": "14.93"
  },
  {
    "country": "CZ",
    "name": "Koryčany",
    "lat": "49.10639",
    "lng": "17.16433"
  },
  {
    "country": "CZ",
    "name": "Kořenov",
    "lat": "50.75926",
    "lng": "15.36532"
  },
  {
    "country": "CZ",
    "name": "Kopřivnice",
    "lat": "49.59947",
    "lng": "18.1448"
  },
  {
    "country": "CZ",
    "name": "Kopidlno",
    "lat": "50.33085",
    "lng": "15.27029"
  },
  {
    "country": "CZ",
    "name": "Konice",
    "lat": "49.5903",
    "lng": "16.88911"
  },
  {
    "country": "CZ",
    "name": "Komorní Lhotka",
    "lat": "49.65811",
    "lng": "18.52777"
  },
  {
    "country": "CZ",
    "name": "Komárov",
    "lat": "49.8065",
    "lng": "13.85636"
  },
  {
    "country": "CZ",
    "name": "Kolinec",
    "lat": "49.29895",
    "lng": "13.439"
  },
  {
    "country": "CZ",
    "name": "Kolín",
    "lat": "50.02806",
    "lng": "15.1998"
  },
  {
    "country": "CZ",
    "name": "Kokory",
    "lat": "49.49482",
    "lng": "17.37544"
  },
  {
    "country": "CZ",
    "name": "Kojetín",
    "lat": "49.35179",
    "lng": "17.30207"
  },
  {
    "country": "CZ",
    "name": "Kobylí",
    "lat": "48.93286",
    "lng": "16.89159"
  },
  {
    "country": "CZ",
    "name": "Kobeřice",
    "lat": "49.98548",
    "lng": "18.05212"
  },
  {
    "country": "CZ",
    "name": "Kněžpole",
    "lat": "49.09855",
    "lng": "17.51671"
  },
  {
    "country": "CZ",
    "name": "Kněžmost",
    "lat": "50.48917",
    "lng": "15.03829"
  },
  {
    "country": "CZ",
    "name": "Kněžice",
    "lat": "49.27078",
    "lng": "15.67216"
  },
  {
    "country": "CZ",
    "name": "Kněždub",
    "lat": "48.88666",
    "lng": "17.39546"
  },
  {
    "country": "CZ",
    "name": "Klobuky",
    "lat": "50.29401",
    "lng": "13.98748"
  },
  {
    "country": "CZ",
    "name": "Klobouky",
    "lat": "48.99609",
    "lng": "16.86298"
  },
  {
    "country": "CZ",
    "name": "Klimkovice",
    "lat": "49.78809",
    "lng": "18.12585"
  },
  {
    "country": "CZ",
    "name": "Klenčí pod Čerchovem",
    "lat": "49.43484",
    "lng": "12.81473"
  },
  {
    "country": "CZ",
    "name": "Klecany",
    "lat": "50.17599",
    "lng": "14.41148"
  },
  {
    "country": "CZ",
    "name": "Klatovy",
    "lat": "49.39552",
    "lng": "13.29505"
  },
  {
    "country": "CZ",
    "name": "Klášterec nad Ohří",
    "lat": "50.3886",
    "lng": "13.18342"
  },
  {
    "country": "CZ",
    "name": "Klášter",
    "lat": "49.96762",
    "lng": "12.87623"
  },
  {
    "country": "CZ",
    "name": "Kladruby",
    "lat": "49.71498",
    "lng": "12.98232"
  },
  {
    "country": "CZ",
    "name": "Kladno",
    "lat": "50.14734",
    "lng": "14.10285"
  },
  {
    "country": "CZ",
    "name": "Kelč",
    "lat": "49.47844",
    "lng": "17.81533"
  },
  {
    "country": "CZ",
    "name": "Kdyně",
    "lat": "49.39077",
    "lng": "13.03968"
  },
  {
    "country": "CZ",
    "name": "Kbely",
    "lat": "50.13333",
    "lng": "14.55"
  },
  {
    "country": "CZ",
    "name": "Kaznějov",
    "lat": "49.89313",
    "lng": "13.38295"
  },
  {
    "country": "CZ",
    "name": "Katovice",
    "lat": "49.27348",
    "lng": "13.83035"
  },
  {
    "country": "CZ",
    "name": "Kašperské Hory",
    "lat": "49.14289",
    "lng": "13.55616"
  },
  {
    "country": "CZ",
    "name": "Kasejovice",
    "lat": "49.4627",
    "lng": "13.7406"
  },
  {
    "country": "CZ",
    "name": "Karviná",
    "lat": "49.854",
    "lng": "18.54169"
  },
  {
    "country": "CZ",
    "name": "Karolinka",
    "lat": "49.35128",
    "lng": "18.24006"
  },
  {
    "country": "CZ",
    "name": "Karlovy Vary",
    "lat": "50.23271",
    "lng": "12.87117"
  },
  {
    "country": "CZ",
    "name": "Karlovice",
    "lat": "50.10564",
    "lng": "17.44563"
  },
  {
    "country": "CZ",
    "name": "Karlín",
    "lat": "50.09272",
    "lng": "14.44711"
  },
  {
    "country": "CZ",
    "name": "Kardašova Řečice",
    "lat": "49.18478",
    "lng": "14.85315"
  },
  {
    "country": "CZ",
    "name": "Kaplice",
    "lat": "48.73881",
    "lng": "14.49449"
  },
  {
    "country": "CZ",
    "name": "Kamenný Újezd",
    "lat": "48.89753",
    "lng": "14.44638"
  },
  {
    "country": "CZ",
    "name": "Kamenný Přívoz",
    "lat": "49.86299",
    "lng": "14.50339"
  },
  {
    "country": "CZ",
    "name": "Kamenné Žehrovice",
    "lat": "50.12697",
    "lng": "14.01809"
  },
  {
    "country": "CZ",
    "name": "Kamenický Šenov",
    "lat": "50.77359",
    "lng": "14.47287"
  },
  {
    "country": "CZ",
    "name": "Kamenice nad Lipou",
    "lat": "49.30303",
    "lng": "15.07519"
  },
  {
    "country": "CZ",
    "name": "Kamenice",
    "lat": "49.90151",
    "lng": "14.58242"
  },
  {
    "country": "CZ",
    "name": "Kamenice",
    "lat": "49.36659",
    "lng": "15.78023"
  },
  {
    "country": "CZ",
    "name": "Kájov",
    "lat": "48.81082",
    "lng": "14.25859"
  },
  {
    "country": "CZ",
    "name": "Kadaň",
    "lat": "50.38333",
    "lng": "13.26667"
  },
  {
    "country": "CZ",
    "name": "Kačice",
    "lat": "50.16261",
    "lng": "13.98815"
  },
  {
    "country": "CZ",
    "name": "Josefův Důl",
    "lat": "50.78191",
    "lng": "15.23146"
  },
  {
    "country": "CZ",
    "name": "Jistebník",
    "lat": "49.754",
    "lng": "18.13063"
  },
  {
    "country": "CZ",
    "name": "Jistebnice",
    "lat": "49.48553",
    "lng": "14.5276"
  },
  {
    "country": "CZ",
    "name": "Jirny",
    "lat": "50.11578",
    "lng": "14.69923"
  },
  {
    "country": "CZ",
    "name": "Jirkov",
    "lat": "50.49979",
    "lng": "13.44769"
  },
  {
    "country": "CZ",
    "name": "Jiříkov",
    "lat": "50.99514",
    "lng": "14.5691"
  },
  {
    "country": "CZ",
    "name": "Jindřichův Hradec",
    "lat": "49.14404",
    "lng": "15.00301"
  },
  {
    "country": "CZ",
    "name": "Jindřichov",
    "lat": "50.25184",
    "lng": "17.51903"
  },
  {
    "country": "CZ",
    "name": "Jince",
    "lat": "49.78624",
    "lng": "13.97867"
  },
  {
    "country": "CZ",
    "name": "Jimramov",
    "lat": "49.63719",
    "lng": "16.22632"
  },
  {
    "country": "CZ",
    "name": "Jílové u Prahy",
    "lat": "49.89545",
    "lng": "14.49333"
  },
  {
    "country": "CZ",
    "name": "Jílové",
    "lat": "50.76082",
    "lng": "14.10383"
  },
  {
    "country": "CZ",
    "name": "Jilemnice",
    "lat": "50.6089",
    "lng": "15.50653"
  },
  {
    "country": "CZ",
    "name": "Jihlava",
    "lat": "49.3961",
    "lng": "15.59124"
  },
  {
    "country": "CZ",
    "name": "Jičín",
    "lat": "50.43723",
    "lng": "15.35162"
  },
  {
    "country": "CZ",
    "name": "Jevišovice",
    "lat": "48.98736",
    "lng": "15.98992"
  },
  {
    "country": "CZ",
    "name": "Jevíčko",
    "lat": "49.6322",
    "lng": "16.71125"
  },
  {
    "country": "CZ",
    "name": "Jeseník nad Odrou",
    "lat": "49.61194",
    "lng": "17.90526"
  },
  {
    "country": "CZ",
    "name": "Jeseník",
    "lat": "50.22937",
    "lng": "17.20464"
  },
  {
    "country": "CZ",
    "name": "Jesenice",
    "lat": "50.09703",
    "lng": "13.46948"
  },
  {
    "country": "CZ",
    "name": "Jesenice",
    "lat": "49.96814",
    "lng": "14.5135"
  },
  {
    "country": "CZ",
    "name": "Jeneč",
    "lat": "50.0873",
    "lng": "14.21482"
  },
  {
    "country": "CZ",
    "name": "Jemnice",
    "lat": "49.01898",
    "lng": "15.56994"
  },
  {
    "country": "CZ",
    "name": "Jedovnice",
    "lat": "49.34453",
    "lng": "16.75595"
  },
  {
    "country": "CZ",
    "name": "Jedlová",
    "lat": "49.661",
    "lng": "16.30608"
  },
  {
    "country": "CZ",
    "name": "Javorník",
    "lat": "50.39077",
    "lng": "17.00272"
  },
  {
    "country": "CZ",
    "name": "Jarošov nad Nežárkou",
    "lat": "49.18989",
    "lng": "15.06734"
  },
  {
    "country": "CZ",
    "name": "Jaroslavice",
    "lat": "48.75657",
    "lng": "16.23351"
  },
  {
    "country": "CZ",
    "name": "Jaroměřice nad Rokytnou",
    "lat": "49.09408",
    "lng": "15.89331"
  },
  {
    "country": "CZ",
    "name": "Jaroměřice",
    "lat": "49.62556",
    "lng": "16.75185"
  },
  {
    "country": "CZ",
    "name": "Jaroměř",
    "lat": "50.3562",
    "lng": "15.92136"
  },
  {
    "country": "CZ",
    "name": "Janov nad Nisou",
    "lat": "50.77204",
    "lng": "15.16913"
  },
  {
    "country": "CZ",
    "name": "Janovice nad Úhlavou",
    "lat": "49.34515",
    "lng": "13.21813"
  },
  {
    "country": "CZ",
    "name": "Janovice",
    "lat": "49.62141",
    "lng": "18.40602"
  },
  {
    "country": "CZ",
    "name": "Jalubí",
    "lat": "49.11626",
    "lng": "17.42788"
  },
  {
    "country": "CZ",
    "name": "Jakartovice",
    "lat": "49.9151",
    "lng": "17.684"
  },
  {
    "country": "CZ",
    "name": "Jáchymov",
    "lat": "50.35846",
    "lng": "12.93465"
  },
  {
    "country": "CZ",
    "name": "Jablunkov",
    "lat": "49.57672",
    "lng": "18.76458"
  },
  {
    "country": "CZ",
    "name": "Jablůnka",
    "lat": "49.38355",
    "lng": "17.95021"
  },
  {
    "country": "CZ",
    "name": "Jablonné v Podještědí",
    "lat": "50.76528",
    "lng": "14.76052"
  },
  {
    "country": "CZ",
    "name": "Jablonné nad Orlicí",
    "lat": "50.02964",
    "lng": "16.60059"
  },
  {
    "country": "CZ",
    "name": "Jablonec nad Nisou",
    "lat": "50.72431",
    "lng": "15.17108"
  },
  {
    "country": "CZ",
    "name": "Jablonec nad Jizerou",
    "lat": "50.70347",
    "lng": "15.42959"
  },
  {
    "country": "CZ",
    "name": "Ivanovice na Hané",
    "lat": "49.30542",
    "lng": "17.09343"
  },
  {
    "country": "CZ",
    "name": "Ivančice",
    "lat": "49.10144",
    "lng": "16.37752"
  },
  {
    "country": "CZ",
    "name": "Hýskov",
    "lat": "49.99072",
    "lng": "14.05055"
  },
  {
    "country": "CZ",
    "name": "Hvozdná",
    "lat": "49.24848",
    "lng": "17.75163"
  },
  {
    "country": "CZ",
    "name": "Hustopeče Nad Bečvou",
    "lat": "49.53053",
    "lng": "17.86994"
  },
  {
    "country": "CZ",
    "name": "Hustopeče",
    "lat": "48.94085",
    "lng": "16.73762"
  },
  {
    "country": "CZ",
    "name": "Husinec",
    "lat": "49.05496",
    "lng": "13.98697"
  },
  {
    "country": "CZ",
    "name": "Humpolec",
    "lat": "49.54152",
    "lng": "15.35932"
  },
  {
    "country": "CZ",
    "name": "Hulín",
    "lat": "49.31689",
    "lng": "17.46374"
  },
  {
    "country": "CZ",
    "name": "Hukvaldy",
    "lat": "49.62381",
    "lng": "18.22189"
  },
  {
    "country": "CZ",
    "name": "Hudlice",
    "lat": "49.96096",
    "lng": "13.97063"
  },
  {
    "country": "CZ",
    "name": "Hrušovany u Brna",
    "lat": "49.03863",
    "lng": "16.59429"
  },
  {
    "country": "CZ",
    "name": "Hrušovany nad Jevišovkou",
    "lat": "48.82991",
    "lng": "16.40271"
  },
  {
    "country": "CZ",
    "name": "Hrušky",
    "lat": "48.79272",
    "lng": "16.97404"
  },
  {
    "country": "CZ",
    "name": "Hroznová Lhota",
    "lat": "48.90784",
    "lng": "17.41697"
  },
  {
    "country": "CZ",
    "name": "Hroznětín",
    "lat": "50.3094",
    "lng": "12.8718"
  },
  {
    "country": "CZ",
    "name": "Hrotovice",
    "lat": "49.1077",
    "lng": "16.06067"
  },
  {
    "country": "CZ",
    "name": "Hronov",
    "lat": "50.47968",
    "lng": "16.1823"
  },
  {
    "country": "CZ",
    "name": "Hromnice",
    "lat": "49.84907",
    "lng": "13.44146"
  },
  {
    "country": "CZ",
    "name": "Hrochův Týnec",
    "lat": "49.95946",
    "lng": "15.91054"
  },
  {
    "country": "CZ",
    "name": "Hrob",
    "lat": "50.65919",
    "lng": "13.72676"
  },
  {
    "country": "CZ",
    "name": "Hřebeč",
    "lat": "50.13595",
    "lng": "14.16446"
  },
  {
    "country": "CZ",
    "name": "Hrdějovice",
    "lat": "49.01893",
    "lng": "14.47857"
  },
  {
    "country": "CZ",
    "name": "Hranice",
    "lat": "50.30459",
    "lng": "12.17577"
  },
  {
    "country": "CZ",
    "name": "Hranice",
    "lat": "49.54796",
    "lng": "17.73469"
  },
  {
    "country": "CZ",
    "name": "Hradištko",
    "lat": "49.86828",
    "lng": "14.40935"
  },
  {
    "country": "CZ",
    "name": "Hrádek nad Nisou",
    "lat": "50.85279",
    "lng": "14.84455"
  },
  {
    "country": "CZ",
    "name": "Hrádek",
    "lat": "49.71316",
    "lng": "13.65296"
  },
  {
    "country": "CZ",
    "name": "Hrádek",
    "lat": "49.61661",
    "lng": "18.7372"
  },
  {
    "country": "CZ",
    "name": "Hrádek",
    "lat": "49.26127",
    "lng": "13.4985"
  },
  {
    "country": "CZ",
    "name": "Hradec nad Svitavou",
    "lat": "49.71143",
    "lng": "16.48058"
  },
  {
    "country": "CZ",
    "name": "Hradec Králové",
    "lat": "50.20923",
    "lng": "15.83277"
  },
  {
    "country": "CZ",
    "name": "Hradec nad Moravici",
    "lat": "49.87042",
    "lng": "17.87843"
  },
  {
    "country": "CZ",
    "name": "Hrabyně",
    "lat": "49.88249",
    "lng": "18.05483"
  },
  {
    "country": "CZ",
    "name": "Hovorčovice",
    "lat": "50.17866",
    "lng": "14.51789"
  },
  {
    "country": "CZ",
    "name": "Hovorany",
    "lat": "48.95493",
    "lng": "16.99346"
  },
  {
    "country": "CZ",
    "name": "Hovězí",
    "lat": "49.30365",
    "lng": "18.06062"
  },
  {
    "country": "CZ",
    "name": "Hostouň",
    "lat": "49.55971",
    "lng": "12.77147"
  },
  {
    "country": "CZ",
    "name": "Hostomice",
    "lat": "50.5877",
    "lng": "13.80803"
  },
  {
    "country": "CZ",
    "name": "Hostomice",
    "lat": "49.82526",
    "lng": "14.0456"
  },
  {
    "country": "CZ",
    "name": "Hošťka",
    "lat": "50.48859",
    "lng": "14.335"
  },
  {
    "country": "CZ",
    "name": "Hostivice",
    "lat": "50.08158",
    "lng": "14.25856"
  },
  {
    "country": "CZ",
    "name": "Hostinné",
    "lat": "50.54066",
    "lng": "15.72334"
  },
  {
    "country": "CZ",
    "name": "Hostěradice",
    "lat": "48.95006",
    "lng": "16.25931"
  },
  {
    "country": "CZ",
    "name": "Hostavice",
    "lat": "50.09283",
    "lng": "14.55822"
  },
  {
    "country": "CZ",
    "name": "Hošťálková",
    "lat": "49.35467",
    "lng": "17.86944"
  },
  {
    "country": "CZ",
    "name": "Horšovský Týn",
    "lat": "49.52965",
    "lng": "12.94405"
  },
  {
    "country": "CZ",
    "name": "Hořovice",
    "lat": "49.83597",
    "lng": "13.90268"
  },
  {
    "country": "CZ",
    "name": "Horoměřice",
    "lat": "50.13173",
    "lng": "14.33879"
  },
  {
    "country": "CZ",
    "name": "Horní Těrlicko",
    "lat": "49.75177",
    "lng": "18.4829"
  },
  {
    "country": "CZ",
    "name": "Horní Suchá",
    "lat": "49.7978",
    "lng": "18.48189"
  },
  {
    "country": "CZ",
    "name": "Horní Stropnice",
    "lat": "48.76124",
    "lng": "14.73502"
  },
  {
    "country": "CZ",
    "name": "Horní Štěpánov",
    "lat": "49.54901",
    "lng": "16.79078"
  },
  {
    "country": "CZ",
    "name": "Horní Sloupnice",
    "lat": "49.92138",
    "lng": "16.33948"
  },
  {
    "country": "CZ",
    "name": "Horní Slavkov",
    "lat": "50.13863",
    "lng": "12.80758"
  },
  {
    "country": "CZ",
    "name": "Horní Počernice",
    "lat": "50.1121",
    "lng": "14.61036"
  },
  {
    "country": "CZ",
    "name": "Horní Počaply",
    "lat": "50.4244",
    "lng": "14.38993"
  },
  {
    "country": "CZ",
    "name": "Horní Planá",
    "lat": "48.76736",
    "lng": "14.03257"
  },
  {
    "country": "CZ",
    "name": "Horní Moštěnice",
    "lat": "49.41213",
    "lng": "17.45879"
  },
  {
    "country": "CZ",
    "name": "Horní Město",
    "lat": "49.90845",
    "lng": "17.21112"
  },
  {
    "country": "CZ",
    "name": "Horní Lideč",
    "lat": "49.18121",
    "lng": "18.06099"
  },
  {
    "country": "CZ",
    "name": "Horní Jiřetín",
    "lat": "50.57309",
    "lng": "13.54717"
  },
  {
    "country": "CZ",
    "name": "Horní Jelení",
    "lat": "50.04901",
    "lng": "16.08396"
  },
  {
    "country": "CZ",
    "name": "Horní Čermná",
    "lat": "49.97053",
    "lng": "16.60772"
  },
  {
    "country": "CZ",
    "name": "Horní Cerekev",
    "lat": "49.32026",
    "lng": "15.32769"
  },
  {
    "country": "CZ",
    "name": "Horní Bříza",
    "lat": "49.84012",
    "lng": "13.35558"
  },
  {
    "country": "CZ",
    "name": "Horní Branná",
    "lat": "50.60826",
    "lng": "15.57146"
  },
  {
    "country": "CZ",
    "name": "Horní Bludovice",
    "lat": "49.74965",
    "lng": "18.43677"
  },
  {
    "country": "CZ",
    "name": "Horní Benešov",
    "lat": "49.96682",
    "lng": "17.60262"
  },
  {
    "country": "CZ",
    "name": "Horní Bečva",
    "lat": "49.43216",
    "lng": "18.28859"
  },
  {
    "country": "CZ",
    "name": "Horka nad Moravou",
    "lat": "49.64009",
    "lng": "17.2107"
  },
  {
    "country": "CZ",
    "name": "Hořice",
    "lat": "50.36609",
    "lng": "15.63183"
  },
  {
    "country": "CZ",
    "name": "Horažďovice",
    "lat": "49.32069",
    "lng": "13.701"
  },
  {
    "country": "CZ",
    "name": "Holýšov",
    "lat": "49.59361",
    "lng": "13.10129"
  },
  {
    "country": "CZ",
    "name": "Holoubkov",
    "lat": "49.77598",
    "lng": "13.69246"
  },
  {
    "country": "CZ",
    "name": "Holice",
    "lat": "50.06601",
    "lng": "15.9859"
  },
  {
    "country": "CZ",
    "name": "Holešov",
    "lat": "49.33331",
    "lng": "17.57832"
  },
  {
    "country": "CZ",
    "name": "Holasovice",
    "lat": "49.99843",
    "lng": "17.80847"
  },
  {
    "country": "CZ",
    "name": "Hodslavice",
    "lat": "49.53856",
    "lng": "18.02367"
  },
  {
    "country": "CZ",
    "name": "Hodonín",
    "lat": "48.84893",
    "lng": "17.13244"
  },
  {
    "country": "CZ",
    "name": "Hodonice",
    "lat": "48.8368",
    "lng": "16.16337"
  },
  {
    "country": "CZ",
    "name": "Hodkovičky",
    "lat": "50.02346",
    "lng": "14.41415"
  },
  {
    "country": "CZ",
    "name": "Hodkovice nad Mohelkou",
    "lat": "50.66586",
    "lng": "15.08985"
  },
  {
    "country": "CZ",
    "name": "Hnojník",
    "lat": "49.6825",
    "lng": "18.54143"
  },
  {
    "country": "CZ",
    "name": "Hněvotín",
    "lat": "49.57205",
    "lng": "17.17954"
  },
  {
    "country": "CZ",
    "name": "Hněvošice",
    "lat": "50.00299",
    "lng": "18.00829"
  },
  {
    "country": "CZ",
    "name": "Hluk",
    "lat": "48.98805",
    "lng": "17.52744"
  },
  {
    "country": "CZ",
    "name": "Hlučín",
    "lat": "49.89795",
    "lng": "18.19196"
  },
  {
    "country": "CZ",
    "name": "Hluboká nad Vltavou",
    "lat": "49.05225",
    "lng": "14.43427"
  },
  {
    "country": "CZ",
    "name": "Hlubočky",
    "lat": "49.61783",
    "lng": "17.39436"
  },
  {
    "country": "CZ",
    "name": "Hlohovec",
    "lat": "48.77399",
    "lng": "16.7623"
  },
  {
    "country": "CZ",
    "name": "Hlinsko",
    "lat": "49.76213",
    "lng": "15.90756"
  },
  {
    "country": "CZ",
    "name": "Hevlín",
    "lat": "48.75209",
    "lng": "16.38131"
  },
  {
    "country": "CZ",
    "name": "Heřmanův Městec",
    "lat": "49.94707",
    "lng": "15.66492"
  },
  {
    "country": "CZ",
    "name": "Heřmanova Huť",
    "lat": "49.70679",
    "lng": "13.10069"
  },
  {
    "country": "CZ",
    "name": "Herálec",
    "lat": "49.68891",
    "lng": "15.99431"
  },
  {
    "country": "CZ",
    "name": "Herálec",
    "lat": "49.53083",
    "lng": "15.45708"
  },
  {
    "country": "CZ",
    "name": "Hejnice",
    "lat": "50.8772",
    "lng": "15.18168"
  },
  {
    "country": "CZ",
    "name": "Hazlov",
    "lat": "50.15634",
    "lng": "12.27238"
  },
  {
    "country": "CZ",
    "name": "Havlíčkův Brod",
    "lat": "49.6069",
    "lng": "15.57937"
  },
  {
    "country": "CZ",
    "name": "Havířov",
    "lat": "49.77984",
    "lng": "18.43688"
  },
  {
    "country": "CZ",
    "name": "Hať",
    "lat": "49.94644",
    "lng": "18.23931"
  },
  {
    "country": "CZ",
    "name": "Hartmanice",
    "lat": "49.16948",
    "lng": "13.45455"
  },
  {
    "country": "CZ",
    "name": "Harrachov",
    "lat": "50.77209",
    "lng": "15.43141"
  },
  {
    "country": "CZ",
    "name": "Hanušovice",
    "lat": "50.08049",
    "lng": "16.93641"
  },
  {
    "country": "CZ",
    "name": "Halenkovice",
    "lat": "49.17102",
    "lng": "17.47156"
  },
  {
    "country": "CZ",
    "name": "Halenkov",
    "lat": "49.3174",
    "lng": "18.14749"
  },
  {
    "country": "CZ",
    "name": "Háj ve Slezsku",
    "lat": "49.89856",
    "lng": "18.0954"
  },
  {
    "country": "CZ",
    "name": "Habry",
    "lat": "49.75603",
    "lng": "15.48486"
  },
  {
    "country": "CZ",
    "name": "Habartov",
    "lat": "50.18297",
    "lng": "12.55054"
  },
  {
    "country": "CZ",
    "name": "Grygov",
    "lat": "49.53841",
    "lng": "17.30887"
  },
  {
    "country": "CZ",
    "name": "Golčův Jeníkov",
    "lat": "49.81626",
    "lng": "15.47686"
  },
  {
    "country": "CZ",
    "name": "Fulnek",
    "lat": "49.71238",
    "lng": "17.90319"
  },
  {
    "country": "CZ",
    "name": "Fryšták",
    "lat": "49.2852",
    "lng": "17.68346"
  },
  {
    "country": "CZ",
    "name": "Frymburk",
    "lat": "48.66094",
    "lng": "14.16564"
  },
  {
    "country": "CZ",
    "name": "Frýdlant nad Ostravicí",
    "lat": "49.5928",
    "lng": "18.35967"
  },
  {
    "country": "CZ",
    "name": "Frýdlant",
    "lat": "50.92139",
    "lng": "15.07974"
  },
  {
    "country": "CZ",
    "name": "Frýdek-Místek",
    "lat": "49.68333",
    "lng": "18.35"
  },
  {
    "country": "CZ",
    "name": "Fryčovice",
    "lat": "49.66677",
    "lng": "18.22321"
  },
  {
    "country": "CZ",
    "name": "Frenštát pod Radhoštěm",
    "lat": "49.54835",
    "lng": "18.21078"
  },
  {
    "country": "CZ",
    "name": "Františkovy Lázně",
    "lat": "50.12033",
    "lng": "12.35174"
  },
  {
    "country": "CZ",
    "name": "Francova Lhota",
    "lat": "49.20174",
    "lng": "18.11175"
  },
  {
    "country": "CZ",
    "name": "Dýšina",
    "lat": "49.77735",
    "lng": "13.4915"
  },
  {
    "country": "CZ",
    "name": "Dvorce",
    "lat": "49.83332",
    "lng": "17.54762"
  },
  {
    "country": "CZ",
    "name": "Duchcov",
    "lat": "50.60376",
    "lng": "13.74621"
  },
  {
    "country": "CZ",
    "name": "Dubné",
    "lat": "48.97619",
    "lng": "14.36038"
  },
  {
    "country": "CZ",
    "name": "Dubňany",
    "lat": "48.91694",
    "lng": "17.09004"
  },
  {
    "country": "CZ",
    "name": "Dub nad Moravou",
    "lat": "49.48249",
    "lng": "17.27723"
  },
  {
    "country": "CZ",
    "name": "Dubicko",
    "lat": "49.82806",
    "lng": "16.96266"
  },
  {
    "country": "CZ",
    "name": "Dubí",
    "lat": "50.68558",
    "lng": "13.78561"
  },
  {
    "country": "CZ",
    "name": "Dubá",
    "lat": "50.54034",
    "lng": "14.54023"
  },
  {
    "country": "CZ",
    "name": "Drnovice",
    "lat": "49.46931",
    "lng": "16.54223"
  },
  {
    "country": "CZ",
    "name": "Drnovice",
    "lat": "49.2763",
    "lng": "16.95146"
  },
  {
    "country": "CZ",
    "name": "Drnholec",
    "lat": "48.85746",
    "lng": "16.48586"
  },
  {
    "country": "CZ",
    "name": "Dřiteň",
    "lat": "49.1428",
    "lng": "14.34596"
  },
  {
    "country": "CZ",
    "name": "Dřevohostice",
    "lat": "49.42594",
    "lng": "17.59204"
  },
  {
    "country": "CZ",
    "name": "Drásov",
    "lat": "49.33183",
    "lng": "16.47798"
  },
  {
    "country": "CZ",
    "name": "Drahanovice",
    "lat": "49.57856",
    "lng": "17.07701"
  },
  {
    "country": "CZ",
    "name": "Doudleby nad Orlicí",
    "lat": "50.10742",
    "lng": "16.26131"
  },
  {
    "country": "CZ",
    "name": "Doubravice nad Svitavou",
    "lat": "49.43664",
    "lng": "16.62937"
  },
  {
    "country": "CZ",
    "name": "Doubrava",
    "lat": "49.85873",
    "lng": "18.48018"
  },
  {
    "country": "CZ",
    "name": "Domažlice",
    "lat": "49.44049",
    "lng": "12.92976"
  },
  {
    "country": "CZ",
    "name": "Domanín",
    "lat": "49.00167",
    "lng": "17.28476"
  },
  {
    "country": "CZ",
    "name": "Doloplazy",
    "lat": "49.56876",
    "lng": "17.41393"
  },
  {
    "country": "CZ",
    "name": "Dolní Životice",
    "lat": "49.89732",
    "lng": "17.77969"
  },
  {
    "country": "CZ",
    "name": "Dolní Žandov",
    "lat": "50.01794",
    "lng": "12.55101"
  },
  {
    "country": "CZ",
    "name": "Dolní Újezd",
    "lat": "49.82562",
    "lng": "16.25461"
  },
  {
    "country": "CZ",
    "name": "Dolní Újezd",
    "lat": "49.54597",
    "lng": "17.53547"
  },
  {
    "country": "CZ",
    "name": "Dolní Studénky",
    "lat": "49.93506",
    "lng": "16.97107"
  },
  {
    "country": "CZ",
    "name": "Dolní Sloupnice",
    "lat": "49.92721",
    "lng": "16.29401"
  },
  {
    "country": "CZ",
    "name": "Dolní Rychnov",
    "lat": "50.16462",
    "lng": "12.64507"
  },
  {
    "country": "CZ",
    "name": "Dolní Roveň",
    "lat": "50.02927",
    "lng": "15.96774"
  },
  {
    "country": "CZ",
    "name": "Dolní Poustevna",
    "lat": "50.98251",
    "lng": "14.28684"
  },
  {
    "country": "CZ",
    "name": "Dolní Podluží",
    "lat": "50.87988",
    "lng": "14.59503"
  },
  {
    "country": "CZ",
    "name": "Dolní Počernice",
    "lat": "50.0876",
    "lng": "14.57199"
  },
  {
    "country": "CZ",
    "name": "Dolní Němčí",
    "lat": "48.96837",
    "lng": "17.58585"
  },
  {
    "country": "CZ",
    "name": "Dolní Lutyně",
    "lat": "49.89876",
    "lng": "18.42815"
  },
  {
    "country": "CZ",
    "name": "Dolní Loućky",
    "lat": "49.36099",
    "lng": "16.35871"
  },
  {
    "country": "CZ",
    "name": "Dolní Lhota",
    "lat": "49.84236",
    "lng": "18.09241"
  },
  {
    "country": "CZ",
    "name": "Dolní Kounice",
    "lat": "49.07011",
    "lng": "16.46492"
  },
  {
    "country": "CZ",
    "name": "Dolní Dvořiště",
    "lat": "48.65642",
    "lng": "14.45221"
  },
  {
    "country": "CZ",
    "name": "Dolní Dunajovice",
    "lat": "48.85447",
    "lng": "16.59283"
  },
  {
    "country": "CZ",
    "name": "Dolní Dobrouč",
    "lat": "49.99273",
    "lng": "16.49766"
  },
  {
    "country": "CZ",
    "name": "Dolní Černilov",
    "lat": "50.2611",
    "lng": "15.96107"
  },
  {
    "country": "CZ",
    "name": "Dolní Čermná",
    "lat": "49.97954",
    "lng": "16.56475"
  },
  {
    "country": "CZ",
    "name": "Dolní Cerekev",
    "lat": "49.34449",
    "lng": "15.45655"
  },
  {
    "country": "CZ",
    "name": "Dolní Bukovsko",
    "lat": "49.17086",
    "lng": "14.58127"
  },
  {
    "country": "CZ",
    "name": "Dolní Břežany",
    "lat": "49.96321",
    "lng": "14.4585"
  },
  {
    "country": "CZ",
    "name": "Dolní Bousov",
    "lat": "50.43825",
    "lng": "15.12812"
  },
  {
    "country": "CZ",
    "name": "Dolní Bojanovice",
    "lat": "48.85861",
    "lng": "17.02859"
  },
  {
    "country": "CZ",
    "name": "Dolní Bohdíkov",
    "lat": "50.00996",
    "lng": "16.90433"
  },
  {
    "country": "CZ",
    "name": "Dolní Beřkovice",
    "lat": "50.39313",
    "lng": "14.45024"
  },
  {
    "country": "CZ",
    "name": "Dolní Benešov",
    "lat": "49.92101",
    "lng": "18.10835"
  },
  {
    "country": "CZ",
    "name": "Dolní Bečva",
    "lat": "49.45498",
    "lng": "18.19419"
  },
  {
    "country": "CZ",
    "name": "Dolany",
    "lat": "49.64987",
    "lng": "17.3224"
  },
  {
    "country": "CZ",
    "name": "Doksy",
    "lat": "50.56471",
    "lng": "14.65553"
  },
  {
    "country": "CZ",
    "name": "Doksy",
    "lat": "50.119",
    "lng": "14.04782"
  },
  {
    "country": "CZ",
    "name": "Dobšice",
    "lat": "48.84834",
    "lng": "16.08218"
  },
  {
    "country": "CZ",
    "name": "Dobruška",
    "lat": "50.29201",
    "lng": "16.16001"
  },
  {
    "country": "CZ",
    "name": "Dobrovice",
    "lat": "50.36933",
    "lng": "14.96233"
  },
  {
    "country": "CZ",
    "name": "Dobronín",
    "lat": "49.47833",
    "lng": "15.64992"
  },
  {
    "country": "CZ",
    "name": "Dobroměřice",
    "lat": "50.37009",
    "lng": "13.79473"
  },
  {
    "country": "CZ",
    "name": "Dobřív",
    "lat": "49.71566",
    "lng": "13.68681"
  },
  {
    "country": "CZ",
    "name": "Dobříš",
    "lat": "49.78113",
    "lng": "14.16717"
  },
  {
    "country": "CZ",
    "name": "Dobřichovice",
    "lat": "49.92749",
    "lng": "14.27469"
  },
  {
    "country": "CZ",
    "name": "Dobratice",
    "lat": "49.66039",
    "lng": "18.49226"
  },
  {
    "country": "CZ",
    "name": "Dobřany",
    "lat": "49.65482",
    "lng": "13.29307"
  },
  {
    "country": "CZ",
    "name": "Dobrá",
    "lat": "49.67383",
    "lng": "18.41393"
  },
  {
    "country": "CZ",
    "name": "Dlouhá Třebová",
    "lat": "49.9404",
    "lng": "16.42329"
  },
  {
    "country": "CZ",
    "name": "Divišov",
    "lat": "49.78849",
    "lng": "14.87579"
  },
  {
    "country": "CZ",
    "name": "Dětmarovice",
    "lat": "49.89412",
    "lng": "18.46079"
  },
  {
    "country": "CZ",
    "name": "Desná",
    "lat": "50.75987",
    "lng": "15.30284"
  },
  {
    "country": "CZ",
    "name": "Děčín",
    "lat": "50.78215",
    "lng": "14.21478"
  },
  {
    "country": "CZ",
    "name": "Davle",
    "lat": "49.89218",
    "lng": "14.40037"
  },
  {
    "country": "CZ",
    "name": "Dašice",
    "lat": "50.02844",
    "lng": "15.91244"
  },
  {
    "country": "CZ",
    "name": "Darkovice",
    "lat": "49.93592",
    "lng": "18.22213"
  },
  {
    "country": "CZ",
    "name": "Dambořice",
    "lat": "49.03828",
    "lng": "16.91757"
  },
  {
    "country": "CZ",
    "name": "Dalovice",
    "lat": "50.24779",
    "lng": "12.89581"
  },
  {
    "country": "CZ",
    "name": "Dačice",
    "lat": "49.08154",
    "lng": "15.43727"
  },
  {
    "country": "CZ",
    "name": "Cvikov",
    "lat": "50.77668",
    "lng": "14.63298"
  },
  {
    "country": "CZ",
    "name": "Čkyně",
    "lat": "49.11503",
    "lng": "13.82906"
  },
  {
    "country": "CZ",
    "name": "Čížkovice",
    "lat": "50.48418",
    "lng": "14.02839"
  },
  {
    "country": "CZ",
    "name": "Cítov",
    "lat": "50.37225",
    "lng": "14.39813"
  },
  {
    "country": "CZ",
    "name": "Církvice",
    "lat": "49.9456",
    "lng": "15.33505"
  },
  {
    "country": "CZ",
    "name": "Čimelice",
    "lat": "49.46557",
    "lng": "14.06922"
  },
  {
    "country": "CZ",
    "name": "Chyšky",
    "lat": "49.52346",
    "lng": "14.42757"
  },
  {
    "country": "CZ",
    "name": "Chýnov",
    "lat": "49.40677",
    "lng": "14.81122"
  },
  {
    "country": "CZ",
    "name": "Chyňava",
    "lat": "50.02736",
    "lng": "14.07398"
  },
  {
    "country": "CZ",
    "name": "Chvalšiny",
    "lat": "48.85401",
    "lng": "14.21114"
  },
  {
    "country": "CZ",
    "name": "Chvaletice",
    "lat": "50.03443",
    "lng": "15.41846"
  },
  {
    "country": "CZ",
    "name": "Chvalčov",
    "lat": "49.38918",
    "lng": "17.71149"
  },
  {
    "country": "CZ",
    "name": "Chuchelná",
    "lat": "49.98664",
    "lng": "18.11656"
  },
  {
    "country": "CZ",
    "name": "Chrudim",
    "lat": "49.95109",
    "lng": "15.79558"
  },
  {
    "country": "CZ",
    "name": "Chroustovice",
    "lat": "49.95553",
    "lng": "15.99143"
  },
  {
    "country": "CZ",
    "name": "Chropyně",
    "lat": "49.35644",
    "lng": "17.36451"
  },
  {
    "country": "CZ",
    "name": "Chřibská",
    "lat": "50.86079",
    "lng": "14.48444"
  },
  {
    "country": "CZ",
    "name": "Chrastava",
    "lat": "50.81693",
    "lng": "14.96884"
  },
  {
    "country": "CZ",
    "name": "Chrast",
    "lat": "49.90205",
    "lng": "15.93396"
  },
  {
    "country": "CZ",
    "name": "Chrást",
    "lat": "49.7932",
    "lng": "13.49358"
  },
  {
    "country": "CZ",
    "name": "Chotoviny",
    "lat": "49.47803",
    "lng": "14.67695"
  },
  {
    "country": "CZ",
    "name": "Chotěšov",
    "lat": "49.65408",
    "lng": "13.20271"
  },
  {
    "country": "CZ",
    "name": "Chotěbuz",
    "lat": "49.76849",
    "lng": "18.56912"
  },
  {
    "country": "CZ",
    "name": "Chotěboř",
    "lat": "49.72072",
    "lng": "15.67018"
  },
  {
    "country": "CZ",
    "name": "Chomutov",
    "lat": "50.46048",
    "lng": "13.41779"
  },
  {
    "country": "CZ",
    "name": "Chodová Planá",
    "lat": "49.89321",
    "lng": "12.73014"
  },
  {
    "country": "CZ",
    "name": "Chodov",
    "lat": "50.24018",
    "lng": "12.74551"
  },
  {
    "country": "CZ",
    "name": "Choceň",
    "lat": "50.00161",
    "lng": "16.22303"
  },
  {
    "country": "CZ",
    "name": "Chlum u Třeboně",
    "lat": "48.96235",
    "lng": "14.92799"
  },
  {
    "country": "CZ",
    "name": "Chlumec nad Cidlinou",
    "lat": "50.1544",
    "lng": "15.46026"
  },
  {
    "country": "CZ",
    "name": "Chlumec",
    "lat": "50.69972",
    "lng": "13.93964"
  },
  {
    "country": "CZ",
    "name": "Chlumčany",
    "lat": "49.63256",
    "lng": "13.31323"
  },
  {
    "country": "CZ",
    "name": "Chlebičov",
    "lat": "49.95942",
    "lng": "17.96748"
  },
  {
    "country": "CZ",
    "name": "Cheb",
    "lat": "50.07963",
    "lng": "12.37392"
  },
  {
    "country": "CZ",
    "name": "Chabařovice",
    "lat": "50.67318",
    "lng": "13.94184"
  },
  {
    "country": "CZ",
    "name": "Český Těšín",
    "lat": "49.74613",
    "lng": "18.62613"
  },
  {
    "country": "CZ",
    "name": "Český Rudolec",
    "lat": "49.06835",
    "lng": "15.32437"
  },
  {
    "country": "CZ",
    "name": "Český Krumlov",
    "lat": "48.81091",
    "lng": "14.31521"
  },
  {
    "country": "CZ",
    "name": "Český Dub",
    "lat": "50.66054",
    "lng": "14.99617"
  },
  {
    "country": "CZ",
    "name": "Český Brod",
    "lat": "50.0742",
    "lng": "14.86081"
  },
  {
    "country": "CZ",
    "name": "České Velenice",
    "lat": "48.76851",
    "lng": "14.96368"
  },
  {
    "country": "CZ",
    "name": "České Meziříčí",
    "lat": "50.2868",
    "lng": "16.04428"
  },
  {
    "country": "CZ",
    "name": "České Budějovice",
    "lat": "48.97447",
    "lng": "14.47434"
  },
  {
    "country": "CZ",
    "name": "Česká Ves",
    "lat": "50.25736",
    "lng": "17.22805"
  },
  {
    "country": "CZ",
    "name": "Česká Třebová",
    "lat": "49.90436",
    "lng": "16.44413"
  },
  {
    "country": "CZ",
    "name": "Česká Skalice",
    "lat": "50.39467",
    "lng": "16.04276"
  },
  {
    "country": "CZ",
    "name": "Česká Lípa",
    "lat": "50.68551",
    "lng": "14.53764"
  },
  {
    "country": "CZ",
    "name": "Česká Kamenice",
    "lat": "50.7978",
    "lng": "14.41767"
  },
  {
    "country": "CZ",
    "name": "Červený Kostelec",
    "lat": "50.47626",
    "lng": "16.09289"
  },
  {
    "country": "CZ",
    "name": "Červenka",
    "lat": "49.72068",
    "lng": "17.07773"
  },
  {
    "country": "CZ",
    "name": "Červené Pečky",
    "lat": "49.97822",
    "lng": "15.20856"
  },
  {
    "country": "CZ",
    "name": "Červená Voda",
    "lat": "50.04029",
    "lng": "16.74268"
  },
  {
    "country": "CZ",
    "name": "Černožice",
    "lat": "50.31863",
    "lng": "15.87403"
  },
  {
    "country": "CZ",
    "name": "Černovice",
    "lat": "49.37265",
    "lng": "14.96089"
  },
  {
    "country": "CZ",
    "name": "Černošín",
    "lat": "49.81613",
    "lng": "12.88381"
  },
  {
    "country": "CZ",
    "name": "Černošice",
    "lat": "49.96008",
    "lng": "14.31979"
  },
  {
    "country": "CZ",
    "name": "Černilov",
    "lat": "50.26265",
    "lng": "15.92254"
  },
  {
    "country": "CZ",
    "name": "Černčice",
    "lat": "50.36138",
    "lng": "13.84521"
  },
  {
    "country": "CZ",
    "name": "Černá Hora",
    "lat": "49.41361",
    "lng": "16.5814"
  },
  {
    "country": "CZ",
    "name": "Cerhenice",
    "lat": "50.07127",
    "lng": "15.07203"
  },
  {
    "country": "CZ",
    "name": "Čerčany",
    "lat": "49.85293",
    "lng": "14.70299"
  },
  {
    "country": "CZ",
    "name": "Čelechovice na Hané",
    "lat": "49.51626",
    "lng": "17.09379"
  },
  {
    "country": "CZ",
    "name": "Čelákovice",
    "lat": "50.16038",
    "lng": "14.75005"
  },
  {
    "country": "CZ",
    "name": "Čeladná",
    "lat": "49.54873",
    "lng": "18.33759"
  },
  {
    "country": "CZ",
    "name": "Čejkovice",
    "lat": "48.90592",
    "lng": "16.9423"
  },
  {
    "country": "CZ",
    "name": "Čejč",
    "lat": "48.94653",
    "lng": "16.96511"
  },
  {
    "country": "CZ",
    "name": "Čechtice",
    "lat": "49.62403",
    "lng": "15.04824"
  },
  {
    "country": "CZ",
    "name": "Čebín",
    "lat": "49.31324",
    "lng": "16.47791"
  },
  {
    "country": "CZ",
    "name": "Častolovice",
    "lat": "50.1291",
    "lng": "16.18128"
  },
  {
    "country": "CZ",
    "name": "Čáslav",
    "lat": "49.91099",
    "lng": "15.38972"
  },
  {
    "country": "CZ",
    "name": "Bzenec",
    "lat": "48.97336",
    "lng": "17.26685"
  },
  {
    "country": "CZ",
    "name": "Bystřice pod Hostýnem",
    "lat": "49.39924",
    "lng": "17.67401"
  },
  {
    "country": "CZ",
    "name": "Bystřice nad Pernštejnem",
    "lat": "49.52295",
    "lng": "16.26147"
  },
  {
    "country": "CZ",
    "name": "Bystřice",
    "lat": "49.73213",
    "lng": "14.6674"
  },
  {
    "country": "CZ",
    "name": "Bystřice",
    "lat": "49.63657",
    "lng": "18.72038"
  },
  {
    "country": "CZ",
    "name": "Bystřec",
    "lat": "50.01168",
    "lng": "16.619"
  },
  {
    "country": "CZ",
    "name": "Bystré",
    "lat": "49.62846",
    "lng": "16.34679"
  },
  {
    "country": "CZ",
    "name": "Bystřany",
    "lat": "50.62867",
    "lng": "13.86419"
  },
  {
    "country": "CZ",
    "name": "Býšť",
    "lat": "50.13243",
    "lng": "15.91116"
  },
  {
    "country": "CZ",
    "name": "Byšice",
    "lat": "50.31044",
    "lng": "14.61136"
  },
  {
    "country": "CZ",
    "name": "Buštěhrad",
    "lat": "50.15594",
    "lng": "14.18897"
  },
  {
    "country": "CZ",
    "name": "Bukovec",
    "lat": "49.55114",
    "lng": "18.82683"
  },
  {
    "country": "CZ",
    "name": "Bukovany",
    "lat": "50.16632",
    "lng": "12.57265"
  },
  {
    "country": "CZ",
    "name": "Budyně nad Ohří",
    "lat": "50.40427",
    "lng": "14.12591"
  },
  {
    "country": "CZ",
    "name": "Budišov nad Budišovkou",
    "lat": "49.79511",
    "lng": "17.62969"
  },
  {
    "country": "CZ",
    "name": "Budišov",
    "lat": "49.27138",
    "lng": "16.00383"
  },
  {
    "country": "CZ",
    "name": "Bučovice",
    "lat": "49.14896",
    "lng": "17.00191"
  },
  {
    "country": "CZ",
    "name": "Buchlovice",
    "lat": "49.08627",
    "lng": "17.33852"
  },
  {
    "country": "CZ",
    "name": "Brušperk",
    "lat": "49.7001",
    "lng": "18.2221"
  },
  {
    "country": "CZ",
    "name": "Bruntál",
    "lat": "49.98844",
    "lng": "17.4647"
  },
  {
    "country": "CZ",
    "name": "Brumovice",
    "lat": "50.0153",
    "lng": "17.74958"
  },
  {
    "country": "CZ",
    "name": "Brtnice",
    "lat": "49.30695",
    "lng": "15.67642"
  },
  {
    "country": "CZ",
    "name": "Broumov",
    "lat": "50.58566",
    "lng": "16.33181"
  },
  {
    "country": "CZ",
    "name": "Brodek u Přerova",
    "lat": "49.48419",
    "lng": "17.33825"
  },
  {
    "country": "CZ",
    "name": "Brno",
    "lat": "49.19522",
    "lng": "16.60796"
  },
  {
    "country": "CZ",
    "name": "Brniště",
    "lat": "50.72919",
    "lng": "14.70338"
  },
  {
    "country": "CZ",
    "name": "Brněnec",
    "lat": "49.62735",
    "lng": "16.52202"
  },
  {
    "country": "CZ",
    "name": "Brloh",
    "lat": "48.92987",
    "lng": "14.21857"
  },
  {
    "country": "CZ",
    "name": "Břidličná",
    "lat": "49.91167",
    "lng": "17.37107"
  },
  {
    "country": "CZ",
    "name": "Březová nad Svitavou",
    "lat": "49.64418",
    "lng": "16.51799"
  },
  {
    "country": "CZ",
    "name": "Březová",
    "lat": "50.14557",
    "lng": "12.64996"
  },
  {
    "country": "CZ",
    "name": "Březová",
    "lat": "49.79158",
    "lng": "17.86556"
  },
  {
    "country": "CZ",
    "name": "Březová",
    "lat": "48.92543",
    "lng": "17.73986"
  },
  {
    "country": "CZ",
    "name": "Březolupy",
    "lat": "49.12138",
    "lng": "17.58034"
  },
  {
    "country": "CZ",
    "name": "Březno",
    "lat": "50.40185",
    "lng": "13.42118"
  },
  {
    "country": "CZ",
    "name": "Březnice",
    "lat": "49.55763",
    "lng": "13.95063"
  },
  {
    "country": "CZ",
    "name": "Březnice",
    "lat": "49.18643",
    "lng": "17.66277"
  },
  {
    "country": "CZ",
    "name": "Březí",
    "lat": "48.81928",
    "lng": "16.56748"
  },
  {
    "country": "CZ",
    "name": "Břeclav",
    "lat": "48.75897",
    "lng": "16.88203"
  },
  {
    "country": "CZ",
    "name": "Břasy",
    "lat": "49.837",
    "lng": "13.57833"
  },
  {
    "country": "CZ",
    "name": "Brantice",
    "lat": "50.06351",
    "lng": "17.62911"
  },
  {
    "country": "CZ",
    "name": "Braník",
    "lat": "50.03498",
    "lng": "14.41518"
  },
  {
    "country": "CZ",
    "name": "Brandýs nad Orlicí",
    "lat": "50.00194",
    "lng": "16.28528"
  },
  {
    "country": "CZ",
    "name": "Brandýs nad Labem-Stará Boleslav",
    "lat": "50.18709",
    "lng": "14.66326"
  },
  {
    "country": "CZ",
    "name": "Brandýsek",
    "lat": "50.18923",
    "lng": "14.16199"
  },
  {
    "country": "CZ",
    "name": "Braňany",
    "lat": "50.54295",
    "lng": "13.70017"
  },
  {
    "country": "CZ",
    "name": "Božice",
    "lat": "48.83687",
    "lng": "16.28875"
  },
  {
    "country": "CZ",
    "name": "Bouzov",
    "lat": "49.70426",
    "lng": "16.89288"
  },
  {
    "country": "CZ",
    "name": "Bošovice",
    "lat": "49.05351",
    "lng": "16.83676"
  },
  {
    "country": "CZ",
    "name": "Boskovice",
    "lat": "49.48751",
    "lng": "16.65997"
  },
  {
    "country": "CZ",
    "name": "Boršice",
    "lat": "49.06254",
    "lng": "17.35084"
  },
  {
    "country": "CZ",
    "name": "Borovany",
    "lat": "48.8986",
    "lng": "14.64227"
  },
  {
    "country": "CZ",
    "name": "Borová Lada",
    "lat": "48.98983",
    "lng": "13.65986"
  },
  {
    "country": "CZ",
    "name": "Borohrádek",
    "lat": "50.09777",
    "lng": "16.09326"
  },
  {
    "country": "CZ",
    "name": "Bořitov",
    "lat": "49.42504",
    "lng": "16.59119"
  },
  {
    "country": "CZ",
    "name": "Bořetice",
    "lat": "48.91302",
    "lng": "16.85306"
  },
  {
    "country": "CZ",
    "name": "Borek",
    "lat": "49.02339",
    "lng": "14.50088"
  },
  {
    "country": "CZ",
    "name": "Bor",
    "lat": "49.71159",
    "lng": "12.77516"
  },
  {
    "country": "CZ",
    "name": "Bolatice",
    "lat": "49.95172",
    "lng": "18.08358"
  },
  {
    "country": "CZ",
    "name": "Bojkovice",
    "lat": "49.03864",
    "lng": "17.81487"
  },
  {
    "country": "CZ",
    "name": "Bohutín",
    "lat": "49.65551",
    "lng": "13.94389"
  },
  {
    "country": "CZ",
    "name": "Bohušovice nad Ohří",
    "lat": "50.49316",
    "lng": "14.15048"
  },
  {
    "country": "CZ",
    "name": "Bohuslavice",
    "lat": "49.94232",
    "lng": "18.12866"
  },
  {
    "country": "CZ",
    "name": "Bohuňovice",
    "lat": "49.66301",
    "lng": "17.28693"
  },
  {
    "country": "CZ",
    "name": "Bohumín",
    "lat": "49.90411",
    "lng": "18.35755"
  },
  {
    "country": "CZ",
    "name": "Bohdalov",
    "lat": "49.47921",
    "lng": "15.87582"
  },
  {
    "country": "CZ",
    "name": "Bochov",
    "lat": "50.14872",
    "lng": "13.05227"
  },
  {
    "country": "CZ",
    "name": "Bludov",
    "lat": "49.9408",
    "lng": "16.92849"
  },
  {
    "country": "CZ",
    "name": "Blučina",
    "lat": "49.05497",
    "lng": "16.6445"
  },
  {
    "country": "CZ",
    "name": "Blovice",
    "lat": "49.5822",
    "lng": "13.54009"
  },
  {
    "country": "CZ",
    "name": "Blížkovice",
    "lat": "48.99976",
    "lng": "15.83482"
  },
  {
    "country": "CZ",
    "name": "Blížejov",
    "lat": "49.5",
    "lng": "12.98926"
  },
  {
    "country": "CZ",
    "name": "Blažovice",
    "lat": "49.16569",
    "lng": "16.78611"
  },
  {
    "country": "CZ",
    "name": "Blatná",
    "lat": "49.42489",
    "lng": "13.88176"
  },
  {
    "country": "CZ",
    "name": "Blansko",
    "lat": "49.36304",
    "lng": "16.64446"
  },
  {
    "country": "CZ",
    "name": "Bílovice nad Svitavou",
    "lat": "49.24708",
    "lng": "16.67247"
  },
  {
    "country": "CZ",
    "name": "Bílovice",
    "lat": "49.09965",
    "lng": "17.54961"
  },
  {
    "country": "CZ",
    "name": "Bílovec",
    "lat": "49.75639",
    "lng": "18.01581"
  },
  {
    "country": "CZ",
    "name": "Bílina Kyselka",
    "lat": "50.55",
    "lng": "13.76667"
  },
  {
    "country": "CZ",
    "name": "Bílina",
    "lat": "50.54854",
    "lng": "13.77535"
  },
  {
    "country": "CZ",
    "name": "Bílá Třemešná",
    "lat": "50.44465",
    "lng": "15.74101"
  },
  {
    "country": "CZ",
    "name": "Bílá Lhota",
    "lat": "49.70953",
    "lng": "16.97507"
  },
  {
    "country": "CZ",
    "name": "Bezdružice",
    "lat": "49.90724",
    "lng": "12.9711"
  },
  {
    "country": "CZ",
    "name": "Beroun",
    "lat": "49.96382",
    "lng": "14.072"
  },
  {
    "country": "CZ",
    "name": "Bernartice",
    "lat": "49.36889",
    "lng": "14.38101"
  },
  {
    "country": "CZ",
    "name": "Benešov nad Ploučnicí",
    "lat": "50.74159",
    "lng": "14.31239"
  },
  {
    "country": "CZ",
    "name": "Benešov nad Černou",
    "lat": "48.7294",
    "lng": "14.62737"
  },
  {
    "country": "CZ",
    "name": "Benešov",
    "lat": "49.78162",
    "lng": "14.68697"
  },
  {
    "country": "CZ",
    "name": "Benecko",
    "lat": "50.66633",
    "lng": "15.54816"
  },
  {
    "country": "CZ",
    "name": "Benátky nad Jizerou",
    "lat": "50.29085",
    "lng": "14.82343"
  },
  {
    "country": "CZ",
    "name": "Bělotín",
    "lat": "49.5912",
    "lng": "17.80654"
  },
  {
    "country": "CZ",
    "name": "Bělá pod Bezdězem",
    "lat": "50.50121",
    "lng": "14.80418"
  },
  {
    "country": "CZ",
    "name": "Bělá nad Radbuzou",
    "lat": "49.59115",
    "lng": "12.71761"
  },
  {
    "country": "CZ",
    "name": "Bedihošť",
    "lat": "49.44826",
    "lng": "17.16643"
  },
  {
    "country": "CZ",
    "name": "Bečov",
    "lat": "50.44972",
    "lng": "13.71784"
  },
  {
    "country": "CZ",
    "name": "Bechyně",
    "lat": "49.29523",
    "lng": "14.4681"
  },
  {
    "country": "CZ",
    "name": "Bechlín",
    "lat": "50.41615",
    "lng": "14.34092"
  },
  {
    "country": "CZ",
    "name": "Bavorov",
    "lat": "49.12184",
    "lng": "14.07893"
  },
  {
    "country": "CZ",
    "name": "Batelov",
    "lat": "49.31425",
    "lng": "15.39465"
  },
  {
    "country": "CZ",
    "name": "Baška",
    "lat": "49.64584",
    "lng": "18.37233"
  },
  {
    "country": "CZ",
    "name": "Bartošovice",
    "lat": "49.66884",
    "lng": "18.05461"
  },
  {
    "country": "CZ",
    "name": "Bánov",
    "lat": "48.98801",
    "lng": "17.71752"
  },
  {
    "country": "CZ",
    "name": "Bakov nad Jizerou",
    "lat": "50.4823",
    "lng": "14.94149"
  },
  {
    "country": "CZ",
    "name": "Babice",
    "lat": "49.12167",
    "lng": "17.48075"
  },
  {
    "country": "CZ",
    "name": "Aš",
    "lat": "50.22387",
    "lng": "12.19499"
  },
  {
    "country": "CZ",
    "name": "Albrechtice nad Orlicí",
    "lat": "50.13979",
    "lng": "16.06437"
  },
  {
    "country": "CZ",
    "name": "Albrechtice",
    "lat": "49.78645",
    "lng": "18.52444"
  },
  {
    "country": "CZ",
    "name": "Adamov",
    "lat": "49.30162",
    "lng": "16.65253"
  },
  {
    "country": "CZ",
    "name": "Abertamy",
    "lat": "50.36874",
    "lng": "12.81826"
  },
  {
    "country": "CZ",
    "name": "Lázně Bohdaneč",
    "lat": "50.0756",
    "lng": "15.67978"
  },
  {
    "country": "CZ",
    "name": "Černý Most",
    "lat": "50.10475",
    "lng": "14.57974"
  },
  {
    "country": "CZ",
    "name": "Lučina",
    "lat": "49.72082",
    "lng": "18.44776"
  },
  {
    "country": "CZ",
    "name": "Vysehrad",
    "lat": "50.06509",
    "lng": "14.41711"
  },
  {
    "country": "CZ",
    "name": "Provodov-Šonov",
    "lat": "50.38711",
    "lng": "16.10797"
  },
  {
    "country": "CZ",
    "name": "Libina",
    "lat": "49.87916",
    "lng": "17.08007"
  },
  {
    "country": "DE",
    "name": "Zwota",
    "lat": "50.35103",
    "lng": "12.42241"
  },
  {
    "country": "DE",
    "name": "Zwönitz",
    "lat": "50.63027",
    "lng": "12.80999"
  },
  {
    "country": "DE",
    "name": "Zwochau",
    "lat": "51.46467",
    "lng": "12.26844"
  },
  {
    "country": "DE",
    "name": "Zwingenberg",
    "lat": "49.72389",
    "lng": "8.61084"
  },
  {
    "country": "DE",
    "name": "Zwiesel",
    "lat": "49.01693",
    "lng": "13.23765"
  },
  {
    "country": "DE",
    "name": "Zwiefalten",
    "lat": "48.23396",
    "lng": "9.46232"
  },
  {
    "country": "DE",
    "name": "Zwickau",
    "lat": "50.72724",
    "lng": "12.48839"
  },
  {
    "country": "DE",
    "name": "Zwenkau",
    "lat": "51.21872",
    "lng": "12.33008"
  },
  {
    "country": "DE",
    "name": "Zweiflingen",
    "lat": "49.25639",
    "lng": "9.51806"
  },
  {
    "country": "DE",
    "name": "Zweibrücken",
    "lat": "49.24686",
    "lng": "7.36977"
  },
  {
    "country": "DE",
    "name": "Zuzenhausen",
    "lat": "49.29636",
    "lng": "8.82254"
  },
  {
    "country": "DE",
    "name": "Züssow",
    "lat": "53.97709",
    "lng": "13.54855"
  },
  {
    "country": "DE",
    "name": "Zusmarshausen",
    "lat": "48.40014",
    "lng": "10.59917"
  },
  {
    "country": "DE",
    "name": "Zusamaltheim",
    "lat": "48.53104",
    "lng": "10.63562"
  },
  {
    "country": "DE",
    "name": "Zurow",
    "lat": "53.86429",
    "lng": "11.61434"
  },
  {
    "country": "DE",
    "name": "Zulpich",
    "lat": "50.69447",
    "lng": "6.65414"
  },
  {
    "country": "DE",
    "name": "Zschortau",
    "lat": "51.4793",
    "lng": "12.35893"
  },
  {
    "country": "DE",
    "name": "Zschornewitz",
    "lat": "51.71585",
    "lng": "12.39998"
  },
  {
    "country": "DE",
    "name": "Zschorlau",
    "lat": "50.56667",
    "lng": "12.65"
  },
  {
    "country": "DE",
    "name": "Zschopau",
    "lat": "50.74818",
    "lng": "13.07691"
  },
  {
    "country": "DE",
    "name": "Zscherndorf",
    "lat": "51.61087",
    "lng": "12.26755"
  },
  {
    "country": "DE",
    "name": "Zscherben",
    "lat": "51.46709",
    "lng": "11.87058"
  },
  {
    "country": "DE",
    "name": "Zscherben",
    "lat": "51.33576",
    "lng": "11.96969"
  },
  {
    "country": "DE",
    "name": "Zschepplin",
    "lat": "51.5",
    "lng": "12.6"
  },
  {
    "country": "DE",
    "name": "Zschadrass",
    "lat": "51.13828",
    "lng": "12.81848"
  },
  {
    "country": "DE",
    "name": "Zossen",
    "lat": "52.216",
    "lng": "13.44909"
  },
  {
    "country": "DE",
    "name": "Zöschen",
    "lat": "51.35802",
    "lng": "12.11652"
  },
  {
    "country": "DE",
    "name": "Zornheim",
    "lat": "49.89",
    "lng": "8.22472"
  },
  {
    "country": "DE",
    "name": "Zorneding",
    "lat": "48.08433",
    "lng": "11.82446"
  },
  {
    "country": "DE",
    "name": "Zorge",
    "lat": "51.63333",
    "lng": "10.63333"
  },
  {
    "country": "DE",
    "name": "Zörbig",
    "lat": "51.62894",
    "lng": "12.1174"
  },
  {
    "country": "DE",
    "name": "Zolling",
    "lat": "48.45",
    "lng": "11.76667"
  },
  {
    "country": "DE",
    "name": "Zöblitz",
    "lat": "50.65912",
    "lng": "13.22981"
  },
  {
    "country": "DE",
    "name": "Zittau",
    "lat": "50.89772",
    "lng": "14.80764"
  },
  {
    "country": "DE",
    "name": "Zirndorf",
    "lat": "49.4424",
    "lng": "10.95414"
  },
  {
    "country": "DE",
    "name": "Ostseebad Zinnowitz",
    "lat": "54.07668",
    "lng": "13.91127"
  },
  {
    "country": "DE",
    "name": "Zinna",
    "lat": "51.5679",
    "lng": "12.95354"
  },
  {
    "country": "DE",
    "name": "Zingst",
    "lat": "54.43572",
    "lng": "12.6888"
  },
  {
    "country": "DE",
    "name": "Zimmern ob Rottweil",
    "lat": "48.1666",
    "lng": "8.59436"
  },
  {
    "country": "DE",
    "name": "Ziltendorf",
    "lat": "52.20608",
    "lng": "14.62411"
  },
  {
    "country": "DE",
    "name": "Ziesendorf",
    "lat": "53.99433",
    "lng": "12.03933"
  },
  {
    "country": "DE",
    "name": "Ziesar",
    "lat": "52.26616",
    "lng": "12.28997"
  },
  {
    "country": "DE",
    "name": "Ziertheim",
    "lat": "48.65244",
    "lng": "10.39882"
  },
  {
    "country": "DE",
    "name": "Zierenberg",
    "lat": "51.36948",
    "lng": "9.30164"
  },
  {
    "country": "DE",
    "name": "Ziemetshausen",
    "lat": "48.29244",
    "lng": "10.53503"
  },
  {
    "country": "DE",
    "name": "Zielitz",
    "lat": "52.28958",
    "lng": "11.67572"
  },
  {
    "country": "DE",
    "name": "Zeven",
    "lat": "53.29657",
    "lng": "9.27685"
  },
  {
    "country": "DE",
    "name": "Zeuthen",
    "lat": "52.34803",
    "lng": "13.62174"
  },
  {
    "country": "DE",
    "name": "Zeulenroda",
    "lat": "50.65278",
    "lng": "11.98377"
  },
  {
    "country": "DE",
    "name": "Zetel",
    "lat": "53.41667",
    "lng": "7.98333"
  },
  {
    "country": "DE",
    "name": "Zernien",
    "lat": "53.06845",
    "lng": "10.88325"
  },
  {
    "country": "DE",
    "name": "Zerf",
    "lat": "49.6",
    "lng": "6.68333"
  },
  {
    "country": "DE",
    "name": "Zerbst",
    "lat": "51.9662",
    "lng": "12.08517"
  },
  {
    "country": "DE",
    "name": "Zenting",
    "lat": "48.79128",
    "lng": "13.25968"
  },
  {
    "country": "DE",
    "name": "Zemmer",
    "lat": "49.9",
    "lng": "6.7"
  },
  {
    "country": "DE",
    "name": "Zell unter Aichelberg",
    "lat": "48.64882",
    "lng": "9.57137"
  },
  {
    "country": "DE",
    "name": "Zellingen",
    "lat": "49.89737",
    "lng": "9.81746"
  },
  {
    "country": "DE",
    "name": "Zell im Wiesental",
    "lat": "47.70555",
    "lng": "7.85248"
  },
  {
    "country": "DE",
    "name": "Zell am Main",
    "lat": "49.81214",
    "lng": "9.86962"
  },
  {
    "country": "DE",
    "name": "Zella-Mehlis",
    "lat": "50.65642",
    "lng": "10.66046"
  },
  {
    "country": "DE",
    "name": "Zell im Fichtelgebirge",
    "lat": "50.13532",
    "lng": "11.82266"
  },
  {
    "country": "DE",
    "name": "Zell",
    "lat": "50.02918",
    "lng": "7.18232"
  },
  {
    "country": "DE",
    "name": "Zell",
    "lat": "48.69235",
    "lng": "8.06301"
  },
  {
    "country": "DE",
    "name": "Zeitz",
    "lat": "51.04962",
    "lng": "12.1369"
  },
  {
    "country": "DE",
    "name": "Zeitlofs",
    "lat": "50.26189",
    "lng": "9.67243"
  },
  {
    "country": "DE",
    "name": "Zeitlarn",
    "lat": "49.07848",
    "lng": "12.11174"
  },
  {
    "country": "DE",
    "name": "Zeithain",
    "lat": "51.33356",
    "lng": "13.33809"
  },
  {
    "country": "DE",
    "name": "Zeiskam",
    "lat": "49.23278",
    "lng": "8.24722"
  },
  {
    "country": "DE",
    "name": "Zeilarn",
    "lat": "48.30003",
    "lng": "12.8426"
  },
  {
    "country": "DE",
    "name": "Zeil",
    "lat": "50.00986",
    "lng": "10.5947"
  },
  {
    "country": "DE",
    "name": "Zehlendorf",
    "lat": "52.43333",
    "lng": "13.25"
  },
  {
    "country": "DE",
    "name": "Zehdenick",
    "lat": "52.97852",
    "lng": "13.33165"
  },
  {
    "country": "DE",
    "name": "Zarrentin",
    "lat": "53.55075",
    "lng": "10.9155"
  },
  {
    "country": "DE",
    "name": "Zarrendorf",
    "lat": "54.23689",
    "lng": "13.10094"
  },
  {
    "country": "DE",
    "name": "Zarpen",
    "lat": "53.86667",
    "lng": "10.51667"
  },
  {
    "country": "DE",
    "name": "Zappendorf",
    "lat": "51.51024",
    "lng": "11.79514"
  },
  {
    "country": "DE",
    "name": "Zapfendorf",
    "lat": "50.01783",
    "lng": "10.93243"
  },
  {
    "country": "DE",
    "name": "Zangberg",
    "lat": "48.2748",
    "lng": "12.42311"
  },
  {
    "country": "DE",
    "name": "Zandt",
    "lat": "49.15",
    "lng": "12.73333"
  },
  {
    "country": "DE",
    "name": "Zaisenhausen",
    "lat": "49.10667",
    "lng": "8.81278"
  },
  {
    "country": "DE",
    "name": "Zahna",
    "lat": "51.9141",
    "lng": "12.78561"
  },
  {
    "country": "DE",
    "name": "Zachenberg",
    "lat": "48.96667",
    "lng": "13"
  },
  {
    "country": "DE",
    "name": "Zaberfeld",
    "lat": "49.05611",
    "lng": "8.92694"
  },
  {
    "country": "DE",
    "name": "Zabeltitz",
    "lat": "51.35147",
    "lng": "13.50462"
  },
  {
    "country": "DE",
    "name": "Xanten",
    "lat": "51.65877",
    "lng": "6.45297"
  },
  {
    "country": "DE",
    "name": "Wyk auf Föhr",
    "lat": "54.6914",
    "lng": "8.56702"
  },
  {
    "country": "DE",
    "name": "Wyhl",
    "lat": "48.16617",
    "lng": "7.64917"
  },
  {
    "country": "DE",
    "name": "Wutöschingen",
    "lat": "47.66019",
    "lng": "8.36755"
  },
  {
    "country": "DE",
    "name": "Wustrow",
    "lat": "53.47765",
    "lng": "13.15569"
  },
  {
    "country": "DE",
    "name": "Wustrow",
    "lat": "52.9237",
    "lng": "11.12846"
  },
  {
    "country": "DE",
    "name": "Wusterwitz",
    "lat": "52.36666",
    "lng": "12.38488"
  },
  {
    "country": "DE",
    "name": "Wustermark",
    "lat": "52.55",
    "lng": "12.95"
  },
  {
    "country": "DE",
    "name": "Wusterhusen",
    "lat": "54.11312",
    "lng": "13.61608"
  },
  {
    "country": "DE",
    "name": "Wusterhausen",
    "lat": "52.8912",
    "lng": "12.46021"
  },
  {
    "country": "DE",
    "name": "Wüstenrot",
    "lat": "49.08083",
    "lng": "9.46056"
  },
  {
    "country": "DE",
    "name": "Wurzen",
    "lat": "51.3707",
    "lng": "12.73939"
  },
  {
    "country": "DE",
    "name": "Würzburg",
    "lat": "49.79391",
    "lng": "9.95121"
  },
  {
    "country": "DE",
    "name": "Wurzbach",
    "lat": "50.46357",
    "lng": "11.53779"
  },
  {
    "country": "DE",
    "name": "Würselen",
    "lat": "50.81809",
    "lng": "6.1347"
  },
  {
    "country": "DE",
    "name": "Wurmsham",
    "lat": "48.35",
    "lng": "12.33333"
  },
  {
    "country": "DE",
    "name": "Wurmlingen",
    "lat": "48",
    "lng": "8.78333"
  },
  {
    "country": "DE",
    "name": "Wurmberg",
    "lat": "48.86667",
    "lng": "8.81667"
  },
  {
    "country": "DE",
    "name": "Wurmannsquick",
    "lat": "48.35334",
    "lng": "12.78603"
  },
  {
    "country": "DE",
    "name": "Wuppertal",
    "lat": "51.25627",
    "lng": "7.14816"
  },
  {
    "country": "DE",
    "name": "Wunstorf",
    "lat": "52.42377",
    "lng": "9.43585"
  },
  {
    "country": "DE",
    "name": "Wunsiedel",
    "lat": "50.03923",
    "lng": "12.00342"
  },
  {
    "country": "DE",
    "name": "Wünschendorf",
    "lat": "50.79662",
    "lng": "12.09824"
  },
  {
    "country": "DE",
    "name": "Wünnenberg",
    "lat": "51.52002",
    "lng": "8.69934"
  },
  {
    "country": "DE",
    "name": "Wulsbüttel",
    "lat": "53.31667",
    "lng": "8.66667"
  },
  {
    "country": "DE",
    "name": "Wülknitz",
    "lat": "51.36667",
    "lng": "13.4"
  },
  {
    "country": "DE",
    "name": "Wulkenzin",
    "lat": "53.54445",
    "lng": "13.16921"
  },
  {
    "country": "DE",
    "name": "Wulften",
    "lat": "51.65999",
    "lng": "10.17437"
  },
  {
    "country": "DE",
    "name": "Wulfsen",
    "lat": "53.3",
    "lng": "10.15"
  },
  {
    "country": "DE",
    "name": "Wülfrath",
    "lat": "51.28195",
    "lng": "7.03821"
  },
  {
    "country": "DE",
    "name": "Wülfershausen",
    "lat": "50.33201",
    "lng": "10.34084"
  },
  {
    "country": "DE",
    "name": "Wulfen",
    "lat": "51.81938",
    "lng": "11.93063"
  },
  {
    "country": "DE",
    "name": "Wrist",
    "lat": "53.93333",
    "lng": "9.76667"
  },
  {
    "country": "DE",
    "name": "Wriezen",
    "lat": "52.72091",
    "lng": "14.13425"
  },
  {
    "country": "DE",
    "name": "Wriedel",
    "lat": "53.0313",
    "lng": "10.29848"
  },
  {
    "country": "DE",
    "name": "Wrestedt",
    "lat": "52.90435",
    "lng": "10.57494"
  },
  {
    "country": "DE",
    "name": "Wremen",
    "lat": "53.65",
    "lng": "8.51667"
  },
  {
    "country": "DE",
    "name": "Wössingen",
    "lat": "49.01205",
    "lng": "8.60754"
  },
  {
    "country": "DE",
    "name": "Wörthsee",
    "lat": "48.0725",
    "lng": "11.20175"
  },
  {
    "country": "DE",
    "name": "Wörth an der Isar",
    "lat": "48.623",
    "lng": "12.33944"
  },
  {
    "country": "DE",
    "name": "Wörth an der Donau",
    "lat": "49.00093",
    "lng": "12.40539"
  },
  {
    "country": "DE",
    "name": "Wörth am Rhein",
    "lat": "49.04888",
    "lng": "8.25959"
  },
  {
    "country": "DE",
    "name": "Wörth am Main",
    "lat": "49.7972",
    "lng": "9.15389"
  },
  {
    "country": "DE",
    "name": "Wört",
    "lat": "49.03047",
    "lng": "10.27239"
  },
  {
    "country": "DE",
    "name": "Wörrstadt",
    "lat": "49.84861",
    "lng": "8.12417"
  },
  {
    "country": "DE",
    "name": "Worpswede",
    "lat": "53.21667",
    "lng": "8.93333"
  },
  {
    "country": "DE",
    "name": "Worms",
    "lat": "49.63278",
    "lng": "8.35916"
  },
  {
    "country": "DE",
    "name": "Wörlitz",
    "lat": "51.84172",
    "lng": "12.42116"
  },
  {
    "country": "DE",
    "name": "Woringen",
    "lat": "47.91667",
    "lng": "10.2"
  },
  {
    "country": "DE",
    "name": "Worbis",
    "lat": "51.41997",
    "lng": "10.3633"
  },
  {
    "country": "DE",
    "name": "Wonsees",
    "lat": "49.97614",
    "lng": "11.30047"
  },
  {
    "country": "DE",
    "name": "Wonfurt",
    "lat": "50.01667",
    "lng": "10.46667"
  },
  {
    "country": "DE",
    "name": "Woltersdorf",
    "lat": "52.95",
    "lng": "11.21667"
  },
  {
    "country": "DE",
    "name": "Woltersdorf",
    "lat": "52.45554",
    "lng": "13.74986"
  },
  {
    "country": "DE",
    "name": "Wolsdorf",
    "lat": "52.19098",
    "lng": "10.93878"
  },
  {
    "country": "DE",
    "name": "Wölpinghausen",
    "lat": "52.41667",
    "lng": "9.23333"
  },
  {
    "country": "DE",
    "name": "Wolpertswende",
    "lat": "47.89471",
    "lng": "9.61202"
  },
  {
    "country": "DE",
    "name": "Wolpertshausen",
    "lat": "49.1675",
    "lng": "9.84472"
  },
  {
    "country": "DE",
    "name": "Wolnzach",
    "lat": "48.6038",
    "lng": "11.62568"
  },
  {
    "country": "DE",
    "name": "Wolmirstedt",
    "lat": "52.24856",
    "lng": "11.62945"
  },
  {
    "country": "DE",
    "name": "Wolmirsleben",
    "lat": "51.95",
    "lng": "11.48333"
  },
  {
    "country": "DE",
    "name": "Wöllstein",
    "lat": "49.81667",
    "lng": "7.96667"
  },
  {
    "country": "DE",
    "name": "Wollbach",
    "lat": "50.36667",
    "lng": "10.23333"
  },
  {
    "country": "DE",
    "name": "Wolkramshausen",
    "lat": "51.42185",
    "lng": "10.73815"
  },
  {
    "country": "DE",
    "name": "Wolkenstein",
    "lat": "50.65552",
    "lng": "13.07132"
  },
  {
    "country": "DE",
    "name": "Wolken",
    "lat": "50.33333",
    "lng": "7.46667"
  },
  {
    "country": "DE",
    "name": "Wolgast",
    "lat": "54.05275",
    "lng": "13.77201"
  },
  {
    "country": "DE",
    "name": "Wolfstein",
    "lat": "49.58411",
    "lng": "7.60496"
  },
  {
    "country": "DE",
    "name": "Wolfsegg",
    "lat": "49.10731",
    "lng": "11.9781"
  },
  {
    "country": "DE",
    "name": "Wolfschlugen",
    "lat": "48.65",
    "lng": "9.28333"
  },
  {
    "country": "DE",
    "name": "Wolfsburg",
    "lat": "52.42452",
    "lng": "10.7815"
  },
  {
    "country": "DE",
    "name": "Wolfratshausen",
    "lat": "47.91289",
    "lng": "11.42166"
  },
  {
    "country": "DE",
    "name": "Wolframs-Eschenbach",
    "lat": "49.22675",
    "lng": "10.72769"
  },
  {
    "country": "DE",
    "name": "Wölfis",
    "lat": "50.80825",
    "lng": "10.77905"
  },
  {
    "country": "DE",
    "name": "Wolfhagen",
    "lat": "51.32611",
    "lng": "9.17015"
  },
  {
    "country": "DE",
    "name": "Wolfertschwenden",
    "lat": "47.8935",
    "lng": "10.26715"
  },
  {
    "country": "DE",
    "name": "Wolferstadt",
    "lat": "48.90352",
    "lng": "10.78129"
  },
  {
    "country": "DE",
    "name": "Wölfersheim",
    "lat": "50.4",
    "lng": "8.81667"
  },
  {
    "country": "DE",
    "name": "Wolfersdorf",
    "lat": "48.47937",
    "lng": "11.70949"
  },
  {
    "country": "DE",
    "name": "Wolferode",
    "lat": "51.5065",
    "lng": "11.51299"
  },
  {
    "country": "DE",
    "name": "Wolfenbüttel",
    "lat": "52.16442",
    "lng": "10.54095"
  },
  {
    "country": "DE",
    "name": "Wolfen",
    "lat": "51.66122",
    "lng": "12.26873"
  },
  {
    "country": "DE",
    "name": "Wolfegg",
    "lat": "47.8203",
    "lng": "9.79491"
  },
  {
    "country": "DE",
    "name": "Wolfach",
    "lat": "48.29319",
    "lng": "8.2158"
  },
  {
    "country": "DE",
    "name": "Woldegk",
    "lat": "53.46058",
    "lng": "13.58356"
  },
  {
    "country": "DE",
    "name": "Wöhrden",
    "lat": "54.16667",
    "lng": "9"
  },
  {
    "country": "DE",
    "name": "Wohnbach",
    "lat": "50.42864",
    "lng": "8.82923"
  },
  {
    "country": "DE",
    "name": "Wohltorf",
    "lat": "53.51667",
    "lng": "10.28333"
  },
  {
    "country": "DE",
    "name": "Wohldorf-Ohlstedt",
    "lat": "53.69282",
    "lng": "10.13117"
  },
  {
    "country": "DE",
    "name": "Witzmannsberg",
    "lat": "48.62224",
    "lng": "13.49444"
  },
  {
    "country": "DE",
    "name": "Witzhave",
    "lat": "53.56667",
    "lng": "10.33333"
  },
  {
    "country": "DE",
    "name": "Witzenhausen",
    "lat": "51.34103",
    "lng": "9.8554"
  },
  {
    "country": "DE",
    "name": "Wittstock",
    "lat": "53.16118",
    "lng": "12.48287"
  },
  {
    "country": "DE",
    "name": "Wittorf",
    "lat": "53.33333",
    "lng": "10.38333"
  },
  {
    "country": "DE",
    "name": "Wittorf",
    "lat": "53.01207",
    "lng": "9.51675"
  },
  {
    "country": "DE",
    "name": "Wittnau",
    "lat": "47.95",
    "lng": "7.81667"
  },
  {
    "country": "DE",
    "name": "Wittmund",
    "lat": "53.57674",
    "lng": "7.77839"
  },
  {
    "country": "DE",
    "name": "Wittmar",
    "lat": "52.12969",
    "lng": "10.64"
  },
  {
    "country": "DE",
    "name": "Wittlich",
    "lat": "49.98596",
    "lng": "6.89308"
  },
  {
    "country": "DE",
    "name": "Wittislingen",
    "lat": "48.61917",
    "lng": "10.41722"
  },
  {
    "country": "DE",
    "name": "Wittingen",
    "lat": "52.72694",
    "lng": "10.73613"
  },
  {
    "country": "DE",
    "name": "Wittichenau",
    "lat": "51.38496",
    "lng": "14.24403"
  },
  {
    "country": "DE",
    "name": "Wittgensdorf",
    "lat": "50.88316",
    "lng": "12.87031"
  },
  {
    "country": "DE",
    "name": "Witterda",
    "lat": "51.03615",
    "lng": "10.89028"
  },
  {
    "country": "DE",
    "name": "Wittenhagen",
    "lat": "54.18379",
    "lng": "13.07133"
  },
  {
    "country": "DE",
    "name": "Wittenförden",
    "lat": "53.62917",
    "lng": "11.32982"
  },
  {
    "country": "DE",
    "name": "Wittenburg",
    "lat": "53.50599",
    "lng": "11.08049"
  },
  {
    "country": "DE",
    "name": "Wittenberge",
    "lat": "53.00543",
    "lng": "11.75032"
  },
  {
    "country": "DE",
    "name": "Wittenau",
    "lat": "52.59319",
    "lng": "13.32127"
  },
  {
    "country": "DE",
    "name": "Witten",
    "lat": "51.44362",
    "lng": "7.35258"
  },
  {
    "country": "DE",
    "name": "Wittelshofen",
    "lat": "49.06121",
    "lng": "10.48121"
  },
  {
    "country": "DE",
    "name": "Wistedt",
    "lat": "53.26667",
    "lng": "9.68333"
  },
  {
    "country": "DE",
    "name": "Wissen",
    "lat": "50.77915",
    "lng": "7.73466"
  },
  {
    "country": "DE",
    "name": "Wismar",
    "lat": "53.89314",
    "lng": "11.45286"
  },
  {
    "country": "DE",
    "name": "Wischhafen",
    "lat": "53.78333",
    "lng": "9.31667"
  },
  {
    "country": "DE",
    "name": "Wirsberg",
    "lat": "50.10572",
    "lng": "11.60515"
  },
  {
    "country": "DE",
    "name": "Wirges",
    "lat": "50.47195",
    "lng": "7.79844"
  },
  {
    "country": "DE",
    "name": "Wirdum",
    "lat": "53.47667",
    "lng": "7.20594"
  },
  {
    "country": "DE",
    "name": "Wippra",
    "lat": "51.573",
    "lng": "11.27498"
  },
  {
    "country": "DE",
    "name": "Wipperfürth",
    "lat": "51.1161",
    "lng": "7.39865"
  },
  {
    "country": "DE",
    "name": "Wipperdorf",
    "lat": "51.4556",
    "lng": "10.64388"
  },
  {
    "country": "DE",
    "name": "Wipfeld",
    "lat": "49.91667",
    "lng": "10.16667"
  },
  {
    "country": "DE",
    "name": "Winzer",
    "lat": "48.72285",
    "lng": "13.07751"
  },
  {
    "country": "DE",
    "name": "Wintersdorf",
    "lat": "51.0532",
    "lng": "12.35445"
  },
  {
    "country": "DE",
    "name": "Winterlingen",
    "lat": "48.18333",
    "lng": "9.11667"
  },
  {
    "country": "DE",
    "name": "Winterhude",
    "lat": "53.6",
    "lng": "10"
  },
  {
    "country": "DE",
    "name": "Winterhausen",
    "lat": "49.70683",
    "lng": "10.01661"
  },
  {
    "country": "DE",
    "name": "Winterberg",
    "lat": "51.19248",
    "lng": "8.53468"
  },
  {
    "country": "DE",
    "name": "Winterbach",
    "lat": "48.79918",
    "lng": "9.47914"
  },
  {
    "country": "DE",
    "name": "Winsen",
    "lat": "53.35753",
    "lng": "10.21282"
  },
  {
    "country": "DE",
    "name": "Winsen",
    "lat": "52.68301",
    "lng": "9.91362"
  },
  {
    "country": "DE",
    "name": "Winnweiler",
    "lat": "49.56667",
    "lng": "7.85"
  },
  {
    "country": "DE",
    "name": "Winningen",
    "lat": "50.31667",
    "lng": "7.51667"
  },
  {
    "country": "DE",
    "name": "Winnenden",
    "lat": "48.87563",
    "lng": "9.39819"
  },
  {
    "country": "DE",
    "name": "Winklarn",
    "lat": "49.42688",
    "lng": "12.47986"
  },
  {
    "country": "DE",
    "name": "Winkelhaid",
    "lat": "49.38963",
    "lng": "11.29888"
  },
  {
    "country": "DE",
    "name": "Winhöring",
    "lat": "48.26667",
    "lng": "12.65"
  },
  {
    "country": "DE",
    "name": "Wingst",
    "lat": "53.73572",
    "lng": "9.08054"
  },
  {
    "country": "DE",
    "name": "Wingerode",
    "lat": "51.39032",
    "lng": "10.23954"
  },
  {
    "country": "DE",
    "name": "Windsbach",
    "lat": "49.24786",
    "lng": "10.82651"
  },
  {
    "country": "DE",
    "name": "Windischleuba",
    "lat": "51.01556",
    "lng": "12.46914"
  },
  {
    "country": "DE",
    "name": "Windischeschenbach",
    "lat": "49.80108",
    "lng": "12.1571"
  },
  {
    "country": "DE",
    "name": "Windhausen",
    "lat": "51.78544",
    "lng": "10.21218"
  },
  {
    "country": "DE",
    "name": "Windhagen",
    "lat": "50.64121",
    "lng": "7.35352"
  },
  {
    "country": "DE",
    "name": "Windesheim",
    "lat": "49.9",
    "lng": "7.81667"
  },
  {
    "country": "DE",
    "name": "Winden",
    "lat": "49.09778",
    "lng": "8.11694"
  },
  {
    "country": "DE",
    "name": "Windelsbach",
    "lat": "49.4",
    "lng": "10.3"
  },
  {
    "country": "DE",
    "name": "Windeby",
    "lat": "54.46667",
    "lng": "9.81667"
  },
  {
    "country": "DE",
    "name": "Windberg",
    "lat": "48.94285",
    "lng": "12.7462"
  },
  {
    "country": "DE",
    "name": "Windach",
    "lat": "48.06667",
    "lng": "11.03333"
  },
  {
    "country": "DE",
    "name": "Wincheringen",
    "lat": "49.60904",
    "lng": "6.42597"
  },
  {
    "country": "DE",
    "name": "Wimsheim",
    "lat": "48.85",
    "lng": "8.83333"
  },
  {
    "country": "DE",
    "name": "Wimmelburg",
    "lat": "51.52069",
    "lng": "11.50696"
  },
  {
    "country": "DE",
    "name": "Wiltingen",
    "lat": "49.65919",
    "lng": "6.59255"
  },
  {
    "country": "DE",
    "name": "Wilthen",
    "lat": "51.09745",
    "lng": "14.3929"
  },
  {
    "country": "DE",
    "name": "Wilsum",
    "lat": "52.53333",
    "lng": "6.85"
  },
  {
    "country": "DE",
    "name": "Wilster",
    "lat": "53.92253",
    "lng": "9.37465"
  },
  {
    "country": "DE",
    "name": "Wilstedt",
    "lat": "53.19493",
    "lng": "9.09595"
  },
  {
    "country": "DE",
    "name": "Wilsdruff",
    "lat": "51.05199",
    "lng": "13.53657"
  },
  {
    "country": "DE",
    "name": "Wilnsdorf",
    "lat": "50.81667",
    "lng": "8.1"
  },
  {
    "country": "DE",
    "name": "Wilmersdorf",
    "lat": "52.48333",
    "lng": "13.31667"
  },
  {
    "country": "DE",
    "name": "Willstätt",
    "lat": "48.54071",
    "lng": "7.89314"
  },
  {
    "country": "DE",
    "name": "Willmering",
    "lat": "49.25",
    "lng": "12.66667"
  },
  {
    "country": "DE",
    "name": "Willingshausen",
    "lat": "50.85",
    "lng": "9.2"
  },
  {
    "country": "DE",
    "name": "Willingen",
    "lat": "51.29418",
    "lng": "8.6091"
  },
  {
    "country": "DE",
    "name": "Willich",
    "lat": "51.26371",
    "lng": "6.54734"
  },
  {
    "country": "DE",
    "name": "Willebadessen",
    "lat": "51.62564",
    "lng": "9.03694"
  },
  {
    "country": "DE",
    "name": "Willanzheim",
    "lat": "49.68011",
    "lng": "10.23248"
  },
  {
    "country": "DE",
    "name": "Wilkau-Haßlau",
    "lat": "50.67504",
    "lng": "12.51482"
  },
  {
    "country": "DE",
    "name": "Wilhermsdorf",
    "lat": "49.48308",
    "lng": "10.71555"
  },
  {
    "country": "DE",
    "name": "Wilhelmsthal",
    "lat": "50.31113",
    "lng": "11.37278"
  },
  {
    "country": "DE",
    "name": "Wilhelmstadt",
    "lat": "52.52462",
    "lng": "13.17707"
  },
  {
    "country": "DE",
    "name": "Wilhelmsruh",
    "lat": "52.5871",
    "lng": "13.36855"
  },
  {
    "country": "DE",
    "name": "Wilhelmshaven",
    "lat": "53.52998",
    "lng": "8.11253"
  },
  {
    "country": "DE",
    "name": "Wilhelmsfeld",
    "lat": "49.47056",
    "lng": "8.75361"
  },
  {
    "country": "DE",
    "name": "Wilhelmsdorf",
    "lat": "49.56419",
    "lng": "10.73716"
  },
  {
    "country": "DE",
    "name": "Wilhelmsdorf",
    "lat": "47.86612",
    "lng": "9.42621"
  },
  {
    "country": "DE",
    "name": "Wilgartswiesen",
    "lat": "49.20891",
    "lng": "7.87346"
  },
  {
    "country": "DE",
    "name": "Wildsteig",
    "lat": "47.70145",
    "lng": "10.93753"
  },
  {
    "country": "DE",
    "name": "Wildpoldsried",
    "lat": "47.76667",
    "lng": "10.4"
  },
  {
    "country": "DE",
    "name": "Wildflecken",
    "lat": "50.37764",
    "lng": "9.91092"
  },
  {
    "country": "DE",
    "name": "Wildeshausen",
    "lat": "52.89446",
    "lng": "8.43375"
  },
  {
    "country": "DE",
    "name": "Wildenhain",
    "lat": "51.3076",
    "lng": "13.47678"
  },
  {
    "country": "DE",
    "name": "Wildenfels",
    "lat": "50.66784",
    "lng": "12.60886"
  },
  {
    "country": "DE",
    "name": "Wildenberg",
    "lat": "48.72981",
    "lng": "11.89845"
  },
  {
    "country": "DE",
    "name": "Wildemann",
    "lat": "51.8281",
    "lng": "10.28152"
  },
  {
    "country": "DE",
    "name": "Wildberg",
    "lat": "48.62336",
    "lng": "8.74518"
  },
  {
    "country": "DE",
    "name": "Bad Wildbad",
    "lat": "48.75071",
    "lng": "8.5504"
  },
  {
    "country": "DE",
    "name": "Wilburgstetten",
    "lat": "49.02427",
    "lng": "10.39505"
  },
  {
    "country": "DE",
    "name": "Wiggensbach",
    "lat": "47.74781",
    "lng": "10.22987"
  },
  {
    "country": "DE",
    "name": "Wietzendorf",
    "lat": "52.91667",
    "lng": "9.98333"
  },
  {
    "country": "DE",
    "name": "Wietzen",
    "lat": "52.71667",
    "lng": "9.08333"
  },
  {
    "country": "DE",
    "name": "Wietze",
    "lat": "52.65",
    "lng": "9.83333"
  },
  {
    "country": "DE",
    "name": "Wietmarschen",
    "lat": "52.51806",
    "lng": "7.13408"
  },
  {
    "country": "DE",
    "name": "Wiesthal",
    "lat": "50.03333",
    "lng": "9.43333"
  },
  {
    "country": "DE",
    "name": "Wiesmoor",
    "lat": "53.41667",
    "lng": "7.73333"
  },
  {
    "country": "DE",
    "name": "Wiesloch",
    "lat": "49.29504",
    "lng": "8.69846"
  },
  {
    "country": "DE",
    "name": "Wiesentheid",
    "lat": "49.79451",
    "lng": "10.34509"
  },
  {
    "country": "DE",
    "name": "Wiesenthau",
    "lat": "49.71326",
    "lng": "11.13564"
  },
  {
    "country": "DE",
    "name": "Wiesent",
    "lat": "49.01667",
    "lng": "12.38333"
  },
  {
    "country": "DE",
    "name": "Wiesensteig",
    "lat": "48.56127",
    "lng": "9.6254"
  },
  {
    "country": "DE",
    "name": "Wiesenfelden",
    "lat": "49.04066",
    "lng": "12.54008"
  },
  {
    "country": "DE",
    "name": "Wiesenburg",
    "lat": "52.11456",
    "lng": "12.45534"
  },
  {
    "country": "DE",
    "name": "Wiesenbach",
    "lat": "49.36139",
    "lng": "8.80361"
  },
  {
    "country": "DE",
    "name": "Wiesenau",
    "lat": "52.23071",
    "lng": "14.59107"
  },
  {
    "country": "DE",
    "name": "Wiesen",
    "lat": "50.11667",
    "lng": "9.36667"
  },
  {
    "country": "DE",
    "name": "Wiesbaden",
    "lat": "50.08258",
    "lng": "8.24932"
  },
  {
    "country": "DE",
    "name": "Wiesau",
    "lat": "49.90817",
    "lng": "12.18889"
  },
  {
    "country": "DE",
    "name": "Wiesa",
    "lat": "50.61114",
    "lng": "13.01377"
  },
  {
    "country": "DE",
    "name": "Wiernsheim",
    "lat": "48.88333",
    "lng": "8.85"
  },
  {
    "country": "DE",
    "name": "Wieren",
    "lat": "52.88529",
    "lng": "10.65871"
  },
  {
    "country": "DE",
    "name": "Wienhausen",
    "lat": "52.58021",
    "lng": "10.18862"
  },
  {
    "country": "DE",
    "name": "Wiemersdorf",
    "lat": "53.95815",
    "lng": "9.90297"
  },
  {
    "country": "DE",
    "name": "Wiek",
    "lat": "54.62",
    "lng": "13.28914"
  },
  {
    "country": "DE",
    "name": "Wiehl",
    "lat": "50.9495",
    "lng": "7.55062"
  },
  {
    "country": "DE",
    "name": "Wiehe",
    "lat": "51.26586",
    "lng": "11.41282"
  },
  {
    "country": "DE",
    "name": "Wiefelstede",
    "lat": "53.25",
    "lng": "8.11667"
  },
  {
    "country": "DE",
    "name": "Wiednitz",
    "lat": "51.38608",
    "lng": "14.02683"
  },
  {
    "country": "DE",
    "name": "Wiederstedt",
    "lat": "51.66526",
    "lng": "11.52723"
  },
  {
    "country": "DE",
    "name": "Wiedergeltingen",
    "lat": "48.03946",
    "lng": "10.67406"
  },
  {
    "country": "DE",
    "name": "Wiedensahl",
    "lat": "52.38385",
    "lng": "9.12019"
  },
  {
    "country": "DE",
    "name": "Wiedemar",
    "lat": "51.46667",
    "lng": "12.2"
  },
  {
    "country": "DE",
    "name": "Wieda",
    "lat": "51.634",
    "lng": "10.58704"
  },
  {
    "country": "DE",
    "name": "Widdern",
    "lat": "49.31825",
    "lng": "9.42209"
  },
  {
    "country": "DE",
    "name": "Wickede",
    "lat": "51.4964",
    "lng": "7.86587"
  },
  {
    "country": "DE",
    "name": "Weyhausen",
    "lat": "52.46208",
    "lng": "10.71699"
  },
  {
    "country": "DE",
    "name": "Weyerbusch",
    "lat": "50.71667",
    "lng": "7.55"
  },
  {
    "country": "DE",
    "name": "Weyarn",
    "lat": "47.85838",
    "lng": "11.79923"
  },
  {
    "country": "DE",
    "name": "Wewelsfleth",
    "lat": "53.85",
    "lng": "9.4"
  },
  {
    "country": "DE",
    "name": "Wetzlar",
    "lat": "50.56109",
    "lng": "8.50495"
  },
  {
    "country": "DE",
    "name": "Wetzendorf",
    "lat": "49.47056",
    "lng": "11.04148"
  },
  {
    "country": "DE",
    "name": "Wettringen",
    "lat": "52.20939",
    "lng": "7.31895"
  },
  {
    "country": "DE",
    "name": "Wettin",
    "lat": "51.58604",
    "lng": "11.8063"
  },
  {
    "country": "DE",
    "name": "Wetterzeube",
    "lat": "51",
    "lng": "12.01667"
  },
  {
    "country": "DE",
    "name": "Wetter (Ruhr)",
    "lat": "51.38747",
    "lng": "7.39277"
  },
  {
    "country": "DE",
    "name": "Wetter",
    "lat": "50.90254",
    "lng": "8.72366"
  },
  {
    "country": "DE",
    "name": "Wetschen",
    "lat": "52.61295",
    "lng": "8.44883"
  },
  {
    "country": "DE",
    "name": "Westhofen",
    "lat": "49.70444",
    "lng": "8.24806"
  },
  {
    "country": "DE",
    "name": "Westheim",
    "lat": "49.2464",
    "lng": "8.32357"
  },
  {
    "country": "DE",
    "name": "Westheim",
    "lat": "49",
    "lng": "10.66667"
  },
  {
    "country": "DE",
    "name": "Westhausen",
    "lat": "48.88333",
    "lng": "10.18333"
  },
  {
    "country": "DE",
    "name": "Westerstetten",
    "lat": "48.51916",
    "lng": "9.95494"
  },
  {
    "country": "DE",
    "name": "Westerstede",
    "lat": "53.25682",
    "lng": "7.92737"
  },
  {
    "country": "DE",
    "name": "Westerrönfeld",
    "lat": "54.28333",
    "lng": "9.65"
  },
  {
    "country": "DE",
    "name": "Wester-Ohrstedt",
    "lat": "54.50796",
    "lng": "9.18574"
  },
  {
    "country": "DE",
    "name": "Westerland",
    "lat": "54.9079",
    "lng": "8.30326"
  },
  {
    "country": "DE",
    "name": "Westerkappeln",
    "lat": "52.31667",
    "lng": "7.88333"
  },
  {
    "country": "DE",
    "name": "Westerhorn",
    "lat": "53.85711",
    "lng": "9.67959"
  },
  {
    "country": "DE",
    "name": "Westerholt",
    "lat": "53.6",
    "lng": "7.45"
  },
  {
    "country": "DE",
    "name": "Westerheim",
    "lat": "48.51511",
    "lng": "9.62424"
  },
  {
    "country": "DE",
    "name": "Westerheim",
    "lat": "48.01667",
    "lng": "10.3"
  },
  {
    "country": "DE",
    "name": "Westerhausen",
    "lat": "51.80566",
    "lng": "11.05631"
  },
  {
    "country": "DE",
    "name": "Westergellersen",
    "lat": "53.23333",
    "lng": "10.25"
  },
  {
    "country": "DE",
    "name": "Westeregeln",
    "lat": "51.96328",
    "lng": "11.39265"
  },
  {
    "country": "DE",
    "name": "Westerburg",
    "lat": "50.55938",
    "lng": "7.97482"
  },
  {
    "country": "DE",
    "name": "Westensee",
    "lat": "54.27452",
    "lng": "9.89584"
  },
  {
    "country": "DE",
    "name": "Westendorf",
    "lat": "48.57209",
    "lng": "10.84049"
  },
  {
    "country": "DE",
    "name": "Westendorf",
    "lat": "47.93333",
    "lng": "10.71667"
  },
  {
    "country": "DE",
    "name": "Westend",
    "lat": "52.51708",
    "lng": "13.27636"
  },
  {
    "country": "DE",
    "name": "Weste",
    "lat": "53.05943",
    "lng": "10.70283"
  },
  {
    "country": "DE",
    "name": "Wessobrunn",
    "lat": "47.87407",
    "lng": "11.02461"
  },
  {
    "country": "DE",
    "name": "Weßling",
    "lat": "48.07452",
    "lng": "11.2482"
  },
  {
    "country": "DE",
    "name": "Wesseln",
    "lat": "54.20985",
    "lng": "9.07644"
  },
  {
    "country": "DE",
    "name": "Wesseling",
    "lat": "50.82709",
    "lng": "6.9747"
  },
  {
    "country": "DE",
    "name": "Wesselburen",
    "lat": "54.21217",
    "lng": "8.92419"
  },
  {
    "country": "DE",
    "name": "Wesendorf",
    "lat": "52.6",
    "lng": "10.53333"
  },
  {
    "country": "DE",
    "name": "Wesenberg",
    "lat": "53.2803",
    "lng": "12.96936"
  },
  {
    "country": "DE",
    "name": "Weselberg",
    "lat": "49.33662",
    "lng": "7.6078"
  },
  {
    "country": "DE",
    "name": "Wesel",
    "lat": "51.6669",
    "lng": "6.62037"
  },
  {
    "country": "DE",
    "name": "Wertingen",
    "lat": "48.56314",
    "lng": "10.68149"
  },
  {
    "country": "DE",
    "name": "Werther",
    "lat": "52.07771",
    "lng": "8.41793"
  },
  {
    "country": "DE",
    "name": "Wertheim",
    "lat": "49.759",
    "lng": "9.50852"
  },
  {
    "country": "DE",
    "name": "Wertach",
    "lat": "47.60301",
    "lng": "10.40966"
  },
  {
    "country": "DE",
    "name": "Werpeloh",
    "lat": "52.87207",
    "lng": "7.50831"
  },
  {
    "country": "DE",
    "name": "Wernshausen",
    "lat": "50.72404",
    "lng": "10.35086"
  },
  {
    "country": "DE",
    "name": "Wernigerode",
    "lat": "51.83652",
    "lng": "10.78216"
  },
  {
    "country": "DE",
    "name": "Werneuchen",
    "lat": "52.63275",
    "lng": "13.73437"
  },
  {
    "country": "DE",
    "name": "Wernersberg",
    "lat": "49.19062",
    "lng": "7.92756"
  },
  {
    "country": "DE",
    "name": "Werneck",
    "lat": "49.98201",
    "lng": "10.09884"
  },
  {
    "country": "DE",
    "name": "Werne",
    "lat": "51.66446",
    "lng": "7.63421"
  },
  {
    "country": "DE",
    "name": "Wernberg-Köblitz",
    "lat": "49.53931",
    "lng": "12.1613"
  },
  {
    "country": "DE",
    "name": "Wernau",
    "lat": "48.69306",
    "lng": "9.41533"
  },
  {
    "country": "DE",
    "name": "Wermsdorf",
    "lat": "51.28333",
    "lng": "12.95"
  },
  {
    "country": "DE",
    "name": "Wermelskirchen",
    "lat": "51.1397",
    "lng": "7.21583"
  },
  {
    "country": "DE",
    "name": "Werlte",
    "lat": "52.85",
    "lng": "7.68333"
  },
  {
    "country": "DE",
    "name": "Werl",
    "lat": "51.55493",
    "lng": "7.91403"
  },
  {
    "country": "DE",
    "name": "Werftpfuhl",
    "lat": "52.66014",
    "lng": "13.79351"
  },
  {
    "country": "DE",
    "name": "Werdohl",
    "lat": "51.26011",
    "lng": "7.76608"
  },
  {
    "country": "DE",
    "name": "Werder",
    "lat": "52.37874",
    "lng": "12.934"
  },
  {
    "country": "DE",
    "name": "Werdau",
    "lat": "50.73604",
    "lng": "12.37534"
  },
  {
    "country": "DE",
    "name": "Werda",
    "lat": "50.43811",
    "lng": "12.30473"
  },
  {
    "country": "DE",
    "name": "Werben",
    "lat": "51.81667",
    "lng": "14.18333"
  },
  {
    "country": "DE",
    "name": "Werbach",
    "lat": "49.67083",
    "lng": "9.63944"
  },
  {
    "country": "DE",
    "name": "Wenzendorf",
    "lat": "53.34948",
    "lng": "9.77234"
  },
  {
    "country": "DE",
    "name": "Wenzenbach",
    "lat": "49.07561",
    "lng": "12.19954"
  },
  {
    "country": "DE",
    "name": "Wentorf bei Hamburg",
    "lat": "53.5",
    "lng": "10.25"
  },
  {
    "country": "DE",
    "name": "Wennigsen",
    "lat": "52.27404",
    "lng": "9.57287"
  },
  {
    "country": "DE",
    "name": "Weng",
    "lat": "48.65866",
    "lng": "12.36927"
  },
  {
    "country": "DE",
    "name": "Wendtorf",
    "lat": "54.41212",
    "lng": "10.28952"
  },
  {
    "country": "DE",
    "name": "Wendorf",
    "lat": "54.2554",
    "lng": "13.07682"
  },
  {
    "country": "DE",
    "name": "Wendlingen am Neckar",
    "lat": "48.67124",
    "lng": "9.37632"
  },
  {
    "country": "DE",
    "name": "Wendisch Rietz",
    "lat": "52.21613",
    "lng": "14.00845"
  },
  {
    "country": "DE",
    "name": "Wendisch Evern",
    "lat": "53.21667",
    "lng": "10.46667"
  },
  {
    "country": "DE",
    "name": "Wenden",
    "lat": "50.96667",
    "lng": "7.86667"
  },
  {
    "country": "DE",
    "name": "Wendelstein",
    "lat": "49.3523",
    "lng": "11.15069"
  },
  {
    "country": "DE",
    "name": "Wendelsheim",
    "lat": "49.76667",
    "lng": "8"
  },
  {
    "country": "DE",
    "name": "Wendeburg",
    "lat": "52.32957",
    "lng": "10.39255"
  },
  {
    "country": "DE",
    "name": "Wemding",
    "lat": "48.87461",
    "lng": "10.72452"
  },
  {
    "country": "DE",
    "name": "Welzow",
    "lat": "51.58381",
    "lng": "14.17082"
  },
  {
    "country": "DE",
    "name": "Welzheim",
    "lat": "48.87675",
    "lng": "9.63434"
  },
  {
    "country": "DE",
    "name": "Welver",
    "lat": "51.61667",
    "lng": "7.96667"
  },
  {
    "country": "DE",
    "name": "Welsleben",
    "lat": "52.00304",
    "lng": "11.63851"
  },
  {
    "country": "DE",
    "name": "Welschbillig",
    "lat": "49.85",
    "lng": "6.56667"
  },
  {
    "country": "DE",
    "name": "Wellingsbüttel",
    "lat": "53.64104",
    "lng": "10.0798"
  },
  {
    "country": "DE",
    "name": "Wellendingen",
    "lat": "48.14745",
    "lng": "8.70375"
  },
  {
    "country": "DE",
    "name": "Wellen",
    "lat": "52.14518",
    "lng": "11.44106"
  },
  {
    "country": "DE",
    "name": "Welle",
    "lat": "53.23985",
    "lng": "9.80178"
  },
  {
    "country": "DE",
    "name": "Welden",
    "lat": "48.45505",
    "lng": "10.66086"
  },
  {
    "country": "DE",
    "name": "Weitramsdorf",
    "lat": "50.256",
    "lng": "10.87989"
  },
  {
    "country": "DE",
    "name": "Weitnau",
    "lat": "47.64171",
    "lng": "10.12732"
  },
  {
    "country": "DE",
    "name": "Weiterstadt",
    "lat": "49.9039",
    "lng": "8.58874"
  },
  {
    "country": "DE",
    "name": "Weitersburg",
    "lat": "50.41667",
    "lng": "7.6"
  },
  {
    "country": "DE",
    "name": "Weitenhagen",
    "lat": "54.05372",
    "lng": "13.40998"
  },
  {
    "country": "DE",
    "name": "Weiten",
    "lat": "49.53011",
    "lng": "6.54064"
  },
  {
    "country": "DE",
    "name": "Weitefeld",
    "lat": "50.72541",
    "lng": "7.92805"
  },
  {
    "country": "DE",
    "name": "Weisweil",
    "lat": "48.19939",
    "lng": "7.67713"
  },
  {
    "country": "DE",
    "name": "Weißwasser",
    "lat": "51.50403",
    "lng": "14.64017"
  },
  {
    "country": "DE",
    "name": "Weißkeißel",
    "lat": "51.49405",
    "lng": "14.71515"
  },
  {
    "country": "DE",
    "name": "Weißig",
    "lat": "51.29192",
    "lng": "13.44117"
  },
  {
    "country": "DE",
    "name": "Weißenthurm",
    "lat": "50.41719",
    "lng": "7.45072"
  },
  {
    "country": "DE",
    "name": "Weißenstadt",
    "lat": "50.10217",
    "lng": "11.88849"
  },
  {
    "country": "DE",
    "name": "Weißensee",
    "lat": "51.19989",
    "lng": "11.06914"
  },
  {
    "country": "DE",
    "name": "Weißensberg",
    "lat": "47.5813",
    "lng": "9.72586"
  },
  {
    "country": "DE",
    "name": "Weißenohe",
    "lat": "49.63089",
    "lng": "11.25369"
  },
  {
    "country": "DE",
    "name": "Weißenhorn",
    "lat": "48.30501",
    "lng": "10.16047"
  },
  {
    "country": "DE",
    "name": "Weißenfels",
    "lat": "51.20148",
    "lng": "11.96843"
  },
  {
    "country": "DE",
    "name": "Weißenburg in Bayern",
    "lat": "49.03095",
    "lng": "10.97221"
  },
  {
    "country": "DE",
    "name": "Weißenbrunn",
    "lat": "50.2",
    "lng": "11.35"
  },
  {
    "country": "DE",
    "name": "Weißenborn-Lüderode",
    "lat": "51.5319",
    "lng": "10.41889"
  },
  {
    "country": "DE",
    "name": "Weißenborn",
    "lat": "50.92393",
    "lng": "11.87947"
  },
  {
    "country": "DE",
    "name": "Weißenborn",
    "lat": "50.73952",
    "lng": "12.47051"
  },
  {
    "country": "DE",
    "name": "Weißenberg",
    "lat": "51.19644",
    "lng": "14.65874"
  },
  {
    "country": "DE",
    "name": "Weißdorf",
    "lat": "50.18333",
    "lng": "11.85"
  },
  {
    "country": "DE",
    "name": "Weißbach",
    "lat": "49.29717",
    "lng": "9.59531"
  },
  {
    "country": "DE",
    "name": "Weißandt-Gölzau",
    "lat": "51.6707",
    "lng": "12.07338"
  },
  {
    "country": "DE",
    "name": "Weissach",
    "lat": "48.84687",
    "lng": "8.92828"
  },
  {
    "country": "DE",
    "name": "Weismain",
    "lat": "50.08512",
    "lng": "11.24024"
  },
  {
    "country": "DE",
    "name": "Weiskirchen",
    "lat": "49.55",
    "lng": "6.81667"
  },
  {
    "country": "DE",
    "name": "Weisendorf",
    "lat": "49.62283",
    "lng": "10.82531"
  },
  {
    "country": "DE",
    "name": "Weisenbach",
    "lat": "48.72757",
    "lng": "8.35378"
  },
  {
    "country": "DE",
    "name": "Weisen",
    "lat": "53.02518",
    "lng": "11.7871"
  },
  {
    "country": "DE",
    "name": "Weisel",
    "lat": "50.11667",
    "lng": "7.8"
  },
  {
    "country": "DE",
    "name": "Weischlitz",
    "lat": "50.45",
    "lng": "12.06667"
  },
  {
    "country": "DE",
    "name": "Weinstadt-Endersbach",
    "lat": "48.81311",
    "lng": "9.36387"
  },
  {
    "country": "DE",
    "name": "Weinsheim",
    "lat": "50.23333",
    "lng": "6.46667"
  },
  {
    "country": "DE",
    "name": "Weinsheim",
    "lat": "49.83333",
    "lng": "7.76667"
  },
  {
    "country": "DE",
    "name": "Weinsberg",
    "lat": "49.15127",
    "lng": "9.28762"
  },
  {
    "country": "DE",
    "name": "Weinheim",
    "lat": "49.54887",
    "lng": "8.66697"
  },
  {
    "country": "DE",
    "name": "Weingarten",
    "lat": "49.25946",
    "lng": "8.2862"
  },
  {
    "country": "DE",
    "name": "Weingarten",
    "lat": "49.05457",
    "lng": "8.52678"
  },
  {
    "country": "DE",
    "name": "Weingarten",
    "lat": "47.81009",
    "lng": "9.63863"
  },
  {
    "country": "DE",
    "name": "Weinböhla",
    "lat": "51.16667",
    "lng": "13.56667"
  },
  {
    "country": "DE",
    "name": "Weinbach",
    "lat": "50.43843",
    "lng": "8.29133"
  },
  {
    "country": "DE",
    "name": "Weimar",
    "lat": "50.9803",
    "lng": "11.32903"
  },
  {
    "country": "DE",
    "name": "Weiltingen",
    "lat": "49.03878",
    "lng": "10.45052"
  },
  {
    "country": "DE",
    "name": "Weilmünster",
    "lat": "50.43143",
    "lng": "8.37673"
  },
  {
    "country": "DE",
    "name": "Weil im Schönbuch",
    "lat": "48.6227",
    "lng": "9.06355"
  },
  {
    "country": "DE",
    "name": "Weilheim an der Teck",
    "lat": "48.61572",
    "lng": "9.53751"
  },
  {
    "country": "DE",
    "name": "Weilheim",
    "lat": "47.84147",
    "lng": "11.15484"
  },
  {
    "country": "DE",
    "name": "Weilheim",
    "lat": "47.66667",
    "lng": "8.23333"
  },
  {
    "country": "DE",
    "name": "Weilerswist",
    "lat": "50.75292",
    "lng": "6.84585"
  },
  {
    "country": "DE",
    "name": "Weilerbach",
    "lat": "49.48333",
    "lng": "7.63333"
  },
  {
    "country": "DE",
    "name": "Weiler",
    "lat": "49.95696",
    "lng": "7.86484"
  },
  {
    "country": "DE",
    "name": "Weil der Stadt",
    "lat": "48.74953",
    "lng": "8.87176"
  },
  {
    "country": "DE",
    "name": "Weilburg",
    "lat": "50.48438",
    "lng": "8.26249"
  },
  {
    "country": "DE",
    "name": "Weilbach",
    "lat": "49.66812",
    "lng": "9.21639"
  },
  {
    "country": "DE",
    "name": "Weil am Rhein",
    "lat": "47.59331",
    "lng": "7.62082"
  },
  {
    "country": "DE",
    "name": "Weil",
    "lat": "48.11717",
    "lng": "10.92161"
  },
  {
    "country": "DE",
    "name": "Weikersheim",
    "lat": "49.47866",
    "lng": "9.89977"
  },
  {
    "country": "DE",
    "name": "Weihmichl",
    "lat": "48.6",
    "lng": "12.05"
  },
  {
    "country": "DE",
    "name": "Weiherhammer",
    "lat": "49.63333",
    "lng": "12.06667"
  },
  {
    "country": "DE",
    "name": "Weihenzell",
    "lat": "49.35",
    "lng": "10.61667"
  },
  {
    "country": "DE",
    "name": "Weigendorf",
    "lat": "49.49773",
    "lng": "11.56869"
  },
  {
    "country": "DE",
    "name": "Weiding",
    "lat": "49.26282",
    "lng": "12.76311"
  },
  {
    "country": "DE",
    "name": "Weidhausen bei Coburg",
    "lat": "50.20354",
    "lng": "11.14006"
  },
  {
    "country": "DE",
    "name": "Weidenthal",
    "lat": "49.41667",
    "lng": "8"
  },
  {
    "country": "DE",
    "name": "Weidenstetten",
    "lat": "48.5525",
    "lng": "9.9961"
  },
  {
    "country": "DE",
    "name": "Weidenbach",
    "lat": "49.19817",
    "lng": "10.64489"
  },
  {
    "country": "DE",
    "name": "Weiden",
    "lat": "49.67682",
    "lng": "12.15613"
  },
  {
    "country": "DE",
    "name": "Weida",
    "lat": "50.77449",
    "lng": "12.06028"
  },
  {
    "country": "DE",
    "name": "Weichs",
    "lat": "48.38333",
    "lng": "11.41667"
  },
  {
    "country": "DE",
    "name": "Weichering",
    "lat": "48.71713",
    "lng": "11.32141"
  },
  {
    "country": "DE",
    "name": "Weibersbrunn",
    "lat": "49.93083",
    "lng": "9.36611"
  },
  {
    "country": "DE",
    "name": "Weibern",
    "lat": "50.40808",
    "lng": "7.14669"
  },
  {
    "country": "DE",
    "name": "Weißensee",
    "lat": "52.55632",
    "lng": "13.46649"
  },
  {
    "country": "DE",
    "name": "Wehringen",
    "lat": "48.25",
    "lng": "10.8"
  },
  {
    "country": "DE",
    "name": "Wehrheim",
    "lat": "50.3",
    "lng": "8.56667"
  },
  {
    "country": "DE",
    "name": "Wehr",
    "lat": "50.41667",
    "lng": "7.21667"
  },
  {
    "country": "DE",
    "name": "Wehr",
    "lat": "47.62983",
    "lng": "7.90423"
  },
  {
    "country": "DE",
    "name": "Wehingen",
    "lat": "48.14533",
    "lng": "8.79151"
  },
  {
    "country": "DE",
    "name": "Wegscheid",
    "lat": "48.60136",
    "lng": "13.78733"
  },
  {
    "country": "DE",
    "name": "Wegeleben",
    "lat": "51.88376",
    "lng": "11.17347"
  },
  {
    "country": "DE",
    "name": "Wegberg",
    "lat": "51.14221",
    "lng": "6.28436"
  },
  {
    "country": "DE",
    "name": "Weferlingen",
    "lat": "52.31205",
    "lng": "11.05791"
  },
  {
    "country": "DE",
    "name": "Wefensleben",
    "lat": "52.18319",
    "lng": "11.16074"
  },
  {
    "country": "DE",
    "name": "Weeze",
    "lat": "51.62678",
    "lng": "6.19792"
  },
  {
    "country": "DE",
    "name": "Wees",
    "lat": "54.80621",
    "lng": "9.51695"
  },
  {
    "country": "DE",
    "name": "Weener",
    "lat": "53.16332",
    "lng": "7.35052"
  },
  {
    "country": "DE",
    "name": "Wedel",
    "lat": "53.58374",
    "lng": "9.69835"
  },
  {
    "country": "DE",
    "name": "Weddingstedt",
    "lat": "54.23428",
    "lng": "9.09103"
  },
  {
    "country": "DE",
    "name": "Wedding",
    "lat": "52.54734",
    "lng": "13.35594"
  },
  {
    "country": "DE",
    "name": "Weddersleben",
    "lat": "51.76533",
    "lng": "11.08531"
  },
  {
    "country": "DE",
    "name": "Weddelbrook",
    "lat": "53.9",
    "lng": "9.83333"
  },
  {
    "country": "DE",
    "name": "Wechselburg",
    "lat": "51.00214",
    "lng": "12.77661"
  },
  {
    "country": "DE",
    "name": "Wechingen",
    "lat": "48.89229",
    "lng": "10.61331"
  },
  {
    "country": "DE",
    "name": "Waxweiler",
    "lat": "50.09257",
    "lng": "6.36299"
  },
  {
    "country": "DE",
    "name": "Wattmannshagen",
    "lat": "53.7759",
    "lng": "12.40701"
  },
  {
    "country": "DE",
    "name": "Wattenheim",
    "lat": "49.52167",
    "lng": "8.06167"
  },
  {
    "country": "DE",
    "name": "Wattenbek",
    "lat": "54.16667",
    "lng": "10.05"
  },
  {
    "country": "DE",
    "name": "Wathlingen",
    "lat": "52.5369",
    "lng": "10.15069"
  },
  {
    "country": "DE",
    "name": "Wasungen",
    "lat": "50.6619",
    "lng": "10.36947"
  },
  {
    "country": "DE",
    "name": "Wassertrüdingen",
    "lat": "49.04328",
    "lng": "10.59906"
  },
  {
    "country": "DE",
    "name": "Wasserlosen",
    "lat": "50.09476",
    "lng": "10.03017"
  },
  {
    "country": "DE",
    "name": "Wasserliesch",
    "lat": "49.70739",
    "lng": "6.53944"
  },
  {
    "country": "DE",
    "name": "Wasserleben",
    "lat": "51.92089",
    "lng": "10.7567"
  },
  {
    "country": "DE",
    "name": "Wasserburg am Inn",
    "lat": "48.0525",
    "lng": "12.22341"
  },
  {
    "country": "DE",
    "name": "Wasserburg",
    "lat": "48.44105",
    "lng": "10.2693"
  },
  {
    "country": "DE",
    "name": "Wassenberg",
    "lat": "51.10009",
    "lng": "6.15484"
  },
  {
    "country": "DE",
    "name": "Wassenach",
    "lat": "50.43333",
    "lng": "7.28333"
  },
  {
    "country": "DE",
    "name": "Wäschenbeuren",
    "lat": "48.75991",
    "lng": "9.68735"
  },
  {
    "country": "DE",
    "name": "Wasbüttel",
    "lat": "52.41331",
    "lng": "10.59357"
  },
  {
    "country": "DE",
    "name": "Wasbek",
    "lat": "54.07427",
    "lng": "9.89738"
  },
  {
    "country": "DE",
    "name": "Wartmannsroth",
    "lat": "50.16667",
    "lng": "9.78333"
  },
  {
    "country": "DE",
    "name": "Warthausen",
    "lat": "48.12863",
    "lng": "9.79749"
  },
  {
    "country": "DE",
    "name": "Wartenberg",
    "lat": "52.5752",
    "lng": "13.51559"
  },
  {
    "country": "DE",
    "name": "Wartenberg",
    "lat": "48.40597",
    "lng": "11.98865"
  },
  {
    "country": "DE",
    "name": "Warstein",
    "lat": "51.44488",
    "lng": "8.34851"
  },
  {
    "country": "DE",
    "name": "Warnow",
    "lat": "53.7858",
    "lng": "11.88106"
  },
  {
    "country": "DE",
    "name": "Warngau",
    "lat": "47.83217",
    "lng": "11.72173"
  },
  {
    "country": "DE",
    "name": "Warnemünde",
    "lat": "54.1767",
    "lng": "12.08402"
  },
  {
    "country": "DE",
    "name": "Warmsen",
    "lat": "52.45695",
    "lng": "8.84949"
  },
  {
    "country": "DE",
    "name": "Warmensteinach",
    "lat": "49.99348",
    "lng": "11.77866"
  },
  {
    "country": "DE",
    "name": "Warin",
    "lat": "53.80026",
    "lng": "11.70504"
  },
  {
    "country": "DE",
    "name": "Warendorf",
    "lat": "51.95109",
    "lng": "7.98756"
  },
  {
    "country": "DE",
    "name": "Waren",
    "lat": "53.5204",
    "lng": "12.67985"
  },
  {
    "country": "DE",
    "name": "Wardow",
    "lat": "53.93054",
    "lng": "12.40818"
  },
  {
    "country": "DE",
    "name": "Wardenburg",
    "lat": "53.06667",
    "lng": "8.2"
  },
  {
    "country": "DE",
    "name": "Warburg",
    "lat": "51.49011",
    "lng": "9.14641"
  },
  {
    "country": "DE",
    "name": "Wanzleben",
    "lat": "52.06087",
    "lng": "11.4408"
  },
  {
    "country": "DE",
    "name": "Wansleben",
    "lat": "51.46034",
    "lng": "11.75135"
  },
  {
    "country": "DE",
    "name": "Wannweil",
    "lat": "48.51667",
    "lng": "9.15"
  },
  {
    "country": "DE",
    "name": "Wannsee",
    "lat": "52.41915",
    "lng": "13.15531"
  },
  {
    "country": "DE",
    "name": "Wanna",
    "lat": "53.75",
    "lng": "8.8"
  },
  {
    "country": "DE",
    "name": "Wankendorf",
    "lat": "54.11224",
    "lng": "10.20546"
  },
  {
    "country": "DE",
    "name": "Wangerooge",
    "lat": "53.79002",
    "lng": "7.89938"
  },
  {
    "country": "DE",
    "name": "Wangen im Allgäu",
    "lat": "47.6895",
    "lng": "9.83247"
  },
  {
    "country": "DE",
    "name": "Wangen",
    "lat": "48.72933",
    "lng": "9.61175"
  },
  {
    "country": "DE",
    "name": "Wangels",
    "lat": "54.26667",
    "lng": "10.76667"
  },
  {
    "country": "DE",
    "name": "Wang",
    "lat": "48.49549",
    "lng": "11.93641"
  },
  {
    "country": "DE",
    "name": "Wanfried",
    "lat": "51.18207",
    "lng": "10.17283"
  },
  {
    "country": "DE",
    "name": "Wandlitz",
    "lat": "52.74196",
    "lng": "13.45799"
  },
  {
    "country": "DE",
    "name": "Wanderup",
    "lat": "54.68333",
    "lng": "9.33333"
  },
  {
    "country": "DE",
    "name": "Wandersleben",
    "lat": "50.89946",
    "lng": "10.84959"
  },
  {
    "country": "DE",
    "name": "Waltrop",
    "lat": "51.62125",
    "lng": "7.40238"
  },
  {
    "country": "DE",
    "name": "Waltershausen",
    "lat": "50.89827",
    "lng": "10.55791"
  },
  {
    "country": "DE",
    "name": "Waltenhofen",
    "lat": "47.67319",
    "lng": "10.30703"
  },
  {
    "country": "DE",
    "name": "Walsrode",
    "lat": "52.86147",
    "lng": "9.5926"
  },
  {
    "country": "DE",
    "name": "Walsdorf",
    "lat": "49.86667",
    "lng": "10.78333"
  },
  {
    "country": "DE",
    "name": "Walschleben",
    "lat": "51.06667",
    "lng": "10.93333"
  },
  {
    "country": "DE",
    "name": "Walpertskirchen",
    "lat": "48.2584",
    "lng": "11.97527"
  },
  {
    "country": "DE",
    "name": "Wallwitz",
    "lat": "51.58029",
    "lng": "11.92888"
  },
  {
    "country": "DE",
    "name": "Wallmerod",
    "lat": "50.48333",
    "lng": "7.95"
  },
  {
    "country": "DE",
    "name": "Wallmenroth",
    "lat": "50.8",
    "lng": "7.83333"
  },
  {
    "country": "DE",
    "name": "Wallhausen",
    "lat": "51.46117",
    "lng": "11.2076"
  },
  {
    "country": "DE",
    "name": "Wallhausen",
    "lat": "49.88333",
    "lng": "7.76667"
  },
  {
    "country": "DE",
    "name": "Wallhausen",
    "lat": "49.21042",
    "lng": "10.06219"
  },
  {
    "country": "DE",
    "name": "Wallgau",
    "lat": "47.51667",
    "lng": "11.28333"
  },
  {
    "country": "DE",
    "name": "Wallertheim",
    "lat": "49.83556",
    "lng": "8.05139"
  },
  {
    "country": "DE",
    "name": "Wallerstein",
    "lat": "48.88741",
    "lng": "10.47591"
  },
  {
    "country": "DE",
    "name": "Wallersdorf",
    "lat": "48.73767",
    "lng": "12.74744"
  },
  {
    "country": "DE",
    "name": "Wallerfing",
    "lat": "48.68416",
    "lng": "12.88035"
  },
  {
    "country": "DE",
    "name": "Wallerfangen",
    "lat": "49.32749",
    "lng": "6.71102"
  },
  {
    "country": "DE",
    "name": "Wallenhorst",
    "lat": "52.35",
    "lng": "8.01667"
  },
  {
    "country": "DE",
    "name": "Wallenfels",
    "lat": "50.2685",
    "lng": "11.47058"
  },
  {
    "country": "DE",
    "name": "Wallendorf",
    "lat": "51.35983",
    "lng": "12.07537"
  },
  {
    "country": "DE",
    "name": "Walldürn",
    "lat": "49.58358",
    "lng": "9.36642"
  },
  {
    "country": "DE",
    "name": "Walldorf",
    "lat": "50.61667",
    "lng": "10.38333"
  },
  {
    "country": "DE",
    "name": "Walldorf",
    "lat": "49.30637",
    "lng": "8.64236"
  },
  {
    "country": "DE",
    "name": "Walkertshofen",
    "lat": "48.22613",
    "lng": "10.58836"
  },
  {
    "country": "DE",
    "name": "Walkenried",
    "lat": "51.58333",
    "lng": "10.61667"
  },
  {
    "country": "DE",
    "name": "Walheim",
    "lat": "49.01417",
    "lng": "9.15111"
  },
  {
    "country": "DE",
    "name": "Waldthurn",
    "lat": "49.67221",
    "lng": "12.32919"
  },
  {
    "country": "DE",
    "name": "Waldstetten",
    "lat": "48.76615",
    "lng": "9.82135"
  },
  {
    "country": "DE",
    "name": "Waldstetten",
    "lat": "48.34815",
    "lng": "10.29385"
  },
  {
    "country": "DE",
    "name": "Waldsieversdorf",
    "lat": "52.54221",
    "lng": "14.07022"
  },
  {
    "country": "DE",
    "name": "Waldshut-Tiengen",
    "lat": "47.62323",
    "lng": "8.21717"
  },
  {
    "country": "DE",
    "name": "Waldsee",
    "lat": "49.39528",
    "lng": "8.44028"
  },
  {
    "country": "DE",
    "name": "Waldsassen",
    "lat": "50.00167",
    "lng": "12.30434"
  },
  {
    "country": "DE",
    "name": "Waldrach",
    "lat": "49.74623",
    "lng": "6.74543"
  },
  {
    "country": "DE",
    "name": "Waldmünchen",
    "lat": "49.37804",
    "lng": "12.70905"
  },
  {
    "country": "DE",
    "name": "Waldmohr",
    "lat": "49.38333",
    "lng": "7.33333"
  },
  {
    "country": "DE",
    "name": "Wald-Michelbach",
    "lat": "49.57",
    "lng": "8.83167"
  },
  {
    "country": "DE",
    "name": "Waldkraiburg",
    "lat": "48.20854",
    "lng": "12.39893"
  },
  {
    "country": "DE",
    "name": "Waldkirchen",
    "lat": "50.59667",
    "lng": "12.37994"
  },
  {
    "country": "DE",
    "name": "Waldkirchen",
    "lat": "48.7327",
    "lng": "13.60082"
  },
  {
    "country": "DE",
    "name": "Waldkirch",
    "lat": "48.09585",
    "lng": "7.96371"
  },
  {
    "country": "DE",
    "name": "Waldkappel",
    "lat": "51.14462",
    "lng": "9.87695"
  },
  {
    "country": "DE",
    "name": "Waldheim",
    "lat": "51.07282",
    "lng": "13.02004"
  },
  {
    "country": "DE",
    "name": "Waldfischbach-Burgalben",
    "lat": "49.28333",
    "lng": "7.66667"
  },
  {
    "country": "DE",
    "name": "Waldfeucht",
    "lat": "51.0661",
    "lng": "5.98815"
  },
  {
    "country": "DE",
    "name": "Waldershof",
    "lat": "49.98144",
    "lng": "12.06291"
  },
  {
    "country": "DE",
    "name": "Walderbach",
    "lat": "49.18333",
    "lng": "12.38333"
  },
  {
    "country": "DE",
    "name": "Waldenburg",
    "lat": "50.87653",
    "lng": "12.59919"
  },
  {
    "country": "DE",
    "name": "Waldenburg",
    "lat": "49.18468",
    "lng": "9.63994"
  },
  {
    "country": "DE",
    "name": "Waldenbuch",
    "lat": "48.6383",
    "lng": "9.13256"
  },
  {
    "country": "DE",
    "name": "Waldeck",
    "lat": "51.20618",
    "lng": "9.06286"
  },
  {
    "country": "DE",
    "name": "Waldbüttelbrunn",
    "lat": "49.78833",
    "lng": "9.84667"
  },
  {
    "country": "DE",
    "name": "Waldburg",
    "lat": "47.7571",
    "lng": "9.71342"
  },
  {
    "country": "DE",
    "name": "Waldbrunn",
    "lat": "49.75861",
    "lng": "9.80361"
  },
  {
    "country": "DE",
    "name": "Waldbröl",
    "lat": "50.87576",
    "lng": "7.61688"
  },
  {
    "country": "DE",
    "name": "Waldbreitbach",
    "lat": "50.55",
    "lng": "7.41667"
  },
  {
    "country": "DE",
    "name": "Waldböckelheim",
    "lat": "49.81667",
    "lng": "7.71667"
  },
  {
    "country": "DE",
    "name": "Waldaschaff",
    "lat": "49.97528",
    "lng": "9.30194"
  },
  {
    "country": "DE",
    "name": "Waldalgesheim",
    "lat": "49.95",
    "lng": "7.83333"
  },
  {
    "country": "DE",
    "name": "Wald",
    "lat": "49.15",
    "lng": "12.35"
  },
  {
    "country": "DE",
    "name": "Wald",
    "lat": "47.97223",
    "lng": "10.30054"
  },
  {
    "country": "DE",
    "name": "Wald",
    "lat": "47.93333",
    "lng": "9.16667"
  },
  {
    "country": "DE",
    "name": "Walchum",
    "lat": "52.92717",
    "lng": "7.28325"
  },
  {
    "country": "DE",
    "name": "Waischenfeld",
    "lat": "49.84645",
    "lng": "11.3481"
  },
  {
    "country": "DE",
    "name": "Wain",
    "lat": "48.18904",
    "lng": "10.0209"
  },
  {
    "country": "DE",
    "name": "Waigolshausen",
    "lat": "49.9643",
    "lng": "10.12001"
  },
  {
    "country": "DE",
    "name": "Waidhofen",
    "lat": "48.57681",
    "lng": "11.33537"
  },
  {
    "country": "DE",
    "name": "Waidhaus",
    "lat": "49.64218",
    "lng": "12.49523"
  },
  {
    "country": "DE",
    "name": "Waibstadt",
    "lat": "49.29505",
    "lng": "8.91771"
  },
  {
    "country": "DE",
    "name": "Waiblingen",
    "lat": "48.83241",
    "lng": "9.31641"
  },
  {
    "country": "DE",
    "name": "Wahrenholz",
    "lat": "52.61667",
    "lng": "10.6"
  },
  {
    "country": "DE",
    "name": "Wahn-Heide",
    "lat": "50.85891",
    "lng": "7.10662"
  },
  {
    "country": "DE",
    "name": "Wahlstedt",
    "lat": "53.95161",
    "lng": "10.20626"
  },
  {
    "country": "DE",
    "name": "Wahlitz",
    "lat": "52.10376",
    "lng": "11.77947"
  },
  {
    "country": "DE",
    "name": "Waging am See",
    "lat": "47.93414",
    "lng": "12.73392"
  },
  {
    "country": "DE",
    "name": "Waghäusel",
    "lat": "49.24991",
    "lng": "8.51257"
  },
  {
    "country": "DE",
    "name": "Wagenhoff",
    "lat": "52.55233",
    "lng": "10.52337"
  },
  {
    "country": "DE",
    "name": "Wagenfeld",
    "lat": "52.55",
    "lng": "8.58333"
  },
  {
    "country": "DE",
    "name": "Waffenbrunn",
    "lat": "49.26667",
    "lng": "12.66667"
  },
  {
    "country": "DE",
    "name": "Wadgassen",
    "lat": "49.26667",
    "lng": "6.78333"
  },
  {
    "country": "DE",
    "name": "Wadersloh",
    "lat": "51.73333",
    "lng": "8.25"
  },
  {
    "country": "DE",
    "name": "Wadern",
    "lat": "49.54122",
    "lng": "6.88774"
  },
  {
    "country": "DE",
    "name": "Wackersdorf",
    "lat": "49.31667",
    "lng": "12.18333"
  },
  {
    "country": "DE",
    "name": "Wackersberg",
    "lat": "47.73333",
    "lng": "11.55"
  },
  {
    "country": "DE",
    "name": "Wackerow",
    "lat": "53.67683",
    "lng": "12.98164"
  },
  {
    "country": "DE",
    "name": "Wackernheim",
    "lat": "49.97444",
    "lng": "8.11667"
  },
  {
    "country": "DE",
    "name": "Wacken",
    "lat": "54.02078",
    "lng": "9.37597"
  },
  {
    "country": "DE",
    "name": "Wächtersbach",
    "lat": "50.25511",
    "lng": "9.29564"
  },
  {
    "country": "DE",
    "name": "Wachtendonk",
    "lat": "51.40916",
    "lng": "6.33894"
  },
  {
    "country": "DE",
    "name": "Wachtberg",
    "lat": "50.63333",
    "lng": "7.1"
  },
  {
    "country": "DE",
    "name": "Wachenroth",
    "lat": "49.75185",
    "lng": "10.71335"
  },
  {
    "country": "DE",
    "name": "Wachenheim",
    "lat": "49.44045",
    "lng": "8.18041"
  },
  {
    "country": "DE",
    "name": "Wachau",
    "lat": "51.16172",
    "lng": "13.90651"
  },
  {
    "country": "DE",
    "name": "Wabern",
    "lat": "51.1",
    "lng": "9.35"
  },
  {
    "country": "DE",
    "name": "Waal",
    "lat": "47.99679",
    "lng": "10.77786"
  },
  {
    "country": "DE",
    "name": "Waakirchen",
    "lat": "47.7725",
    "lng": "11.67315"
  },
  {
    "country": "DE",
    "name": "Waake",
    "lat": "51.55637",
    "lng": "10.05713"
  },
  {
    "country": "DE",
    "name": "Waabs",
    "lat": "54.53333",
    "lng": "9.98333"
  },
  {
    "country": "DE",
    "name": "Vrees",
    "lat": "52.88333",
    "lng": "7.76667"
  },
  {
    "country": "DE",
    "name": "Vreden",
    "lat": "52.03792",
    "lng": "6.828"
  },
  {
    "country": "DE",
    "name": "Vorwerk",
    "lat": "53.18333",
    "lng": "9.15"
  },
  {
    "country": "DE",
    "name": "Vörstetten",
    "lat": "48.06667",
    "lng": "7.85"
  },
  {
    "country": "DE",
    "name": "Vorra",
    "lat": "49.55718",
    "lng": "11.49419"
  },
  {
    "country": "DE",
    "name": "Vordorf",
    "lat": "52.36522",
    "lng": "10.52035"
  },
  {
    "country": "DE",
    "name": "Vorbach",
    "lat": "49.82136",
    "lng": "11.73625"
  },
  {
    "country": "DE",
    "name": "Volxheim",
    "lat": "49.81667",
    "lng": "7.93333"
  },
  {
    "country": "DE",
    "name": "Voltlage",
    "lat": "52.43333",
    "lng": "7.75"
  },
  {
    "country": "DE",
    "name": "Völpke",
    "lat": "52.13865",
    "lng": "11.09877"
  },
  {
    "country": "DE",
    "name": "Vollersode",
    "lat": "53.33333",
    "lng": "8.91667"
  },
  {
    "country": "DE",
    "name": "Volkstedt",
    "lat": "51.56267",
    "lng": "11.55658"
  },
  {
    "country": "DE",
    "name": "Volkmarsen",
    "lat": "51.40895",
    "lng": "9.11814"
  },
  {
    "country": "DE",
    "name": "Völklingen",
    "lat": "49.25162",
    "lng": "6.85873"
  },
  {
    "country": "DE",
    "name": "Volkertshausen",
    "lat": "47.81667",
    "lng": "8.86667"
  },
  {
    "country": "DE",
    "name": "Völkershausen",
    "lat": "50.8",
    "lng": "10.05"
  },
  {
    "country": "DE",
    "name": "Volkenschwand",
    "lat": "48.6",
    "lng": "11.88333"
  },
  {
    "country": "DE",
    "name": "Volkach",
    "lat": "49.86352",
    "lng": "10.22813"
  },
  {
    "country": "DE",
    "name": "Voigtstedt",
    "lat": "51.39169",
    "lng": "11.30888"
  },
  {
    "country": "DE",
    "name": "Vöhringen",
    "lat": "48.33446",
    "lng": "8.66392"
  },
  {
    "country": "DE",
    "name": "Vöhringen",
    "lat": "48.27839",
    "lng": "10.08236"
  },
  {
    "country": "DE",
    "name": "Vöhrenbach",
    "lat": "48.05",
    "lng": "8.3"
  },
  {
    "country": "DE",
    "name": "Vöhl",
    "lat": "51.20565",
    "lng": "8.9451"
  },
  {
    "country": "DE",
    "name": "Vohenstrauß",
    "lat": "49.62383",
    "lng": "12.33808"
  },
  {
    "country": "DE",
    "name": "Vohburg an der Donau",
    "lat": "48.76977",
    "lng": "11.61845"
  },
  {
    "country": "DE",
    "name": "Vogtareuth",
    "lat": "47.94694",
    "lng": "12.18126"
  },
  {
    "country": "DE",
    "name": "Vogt",
    "lat": "47.76667",
    "lng": "9.76667"
  },
  {
    "country": "DE",
    "name": "Vögelsen",
    "lat": "53.27447",
    "lng": "10.35372"
  },
  {
    "country": "DE",
    "name": "Voerde",
    "lat": "51.59703",
    "lng": "6.6863"
  },
  {
    "country": "DE",
    "name": "Vockerode",
    "lat": "51.84698",
    "lng": "12.35208"
  },
  {
    "country": "DE",
    "name": "Vlotho",
    "lat": "52.1653",
    "lng": "8.85996"
  },
  {
    "country": "DE",
    "name": "Visselhövede",
    "lat": "52.98546",
    "lng": "9.58265"
  },
  {
    "country": "DE",
    "name": "Visbek",
    "lat": "52.83333",
    "lng": "8.31667"
  },
  {
    "country": "DE",
    "name": "Viöl",
    "lat": "54.56667",
    "lng": "9.18333"
  },
  {
    "country": "DE",
    "name": "Vinningen",
    "lat": "49.15635",
    "lng": "7.55191"
  },
  {
    "country": "DE",
    "name": "Vilshofen",
    "lat": "48.62695",
    "lng": "13.19222"
  },
  {
    "country": "DE",
    "name": "Vilsheim",
    "lat": "48.44882",
    "lng": "12.10686"
  },
  {
    "country": "DE",
    "name": "Vilseck",
    "lat": "49.6148",
    "lng": "11.80261"
  },
  {
    "country": "DE",
    "name": "Vilsbiburg",
    "lat": "48.45296",
    "lng": "12.35604"
  },
  {
    "country": "DE",
    "name": "Villmar",
    "lat": "50.39287",
    "lng": "8.1931"
  },
  {
    "country": "DE",
    "name": "Villingen-Schwenningen",
    "lat": "48.06226",
    "lng": "8.49358"
  },
  {
    "country": "DE",
    "name": "Villingendorf",
    "lat": "48.2",
    "lng": "8.58333"
  },
  {
    "country": "DE",
    "name": "Villenbach",
    "lat": "48.50887",
    "lng": "10.61468"
  },
  {
    "country": "DE",
    "name": "Vilgertshofen",
    "lat": "47.95",
    "lng": "10.91667"
  },
  {
    "country": "DE",
    "name": "Viersen",
    "lat": "51.25435",
    "lng": "6.39441"
  },
  {
    "country": "DE",
    "name": "Viernheim",
    "lat": "49.54033",
    "lng": "8.5782"
  },
  {
    "country": "DE",
    "name": "Viernau",
    "lat": "50.66225",
    "lng": "10.55778"
  },
  {
    "country": "DE",
    "name": "Vierkirchen",
    "lat": "48.36667",
    "lng": "11.46667"
  },
  {
    "country": "DE",
    "name": "Viereck",
    "lat": "53.54898",
    "lng": "14.04001"
  },
  {
    "country": "DE",
    "name": "Vienenburg",
    "lat": "51.95242",
    "lng": "10.56374"
  },
  {
    "country": "DE",
    "name": "Viechtach",
    "lat": "49.08001",
    "lng": "12.88566"
  },
  {
    "country": "DE",
    "name": "Vettweiß",
    "lat": "50.73333",
    "lng": "6.6"
  },
  {
    "country": "DE",
    "name": "Vettelschoß",
    "lat": "50.61667",
    "lng": "7.35"
  },
  {
    "country": "DE",
    "name": "Vetschau",
    "lat": "51.78638",
    "lng": "14.07941"
  },
  {
    "country": "DE",
    "name": "Vestenbergsgreuth",
    "lat": "49.68764",
    "lng": "10.65157"
  },
  {
    "country": "DE",
    "name": "Versmold",
    "lat": "52.04009",
    "lng": "8.15272"
  },
  {
    "country": "DE",
    "name": "Verl",
    "lat": "51.88333",
    "lng": "8.51667"
  },
  {
    "country": "DE",
    "name": "Veringenstadt",
    "lat": "48.18515",
    "lng": "9.21079"
  },
  {
    "country": "DE",
    "name": "Verden",
    "lat": "52.92343",
    "lng": "9.23491"
  },
  {
    "country": "DE",
    "name": "Venusberg",
    "lat": "50.69918",
    "lng": "13.01854"
  },
  {
    "country": "DE",
    "name": "Veltheim",
    "lat": "52.21874",
    "lng": "10.68327"
  },
  {
    "country": "DE",
    "name": "Velten",
    "lat": "52.69149",
    "lng": "13.17533"
  },
  {
    "country": "DE",
    "name": "Velpke",
    "lat": "52.40797",
    "lng": "10.93637"
  },
  {
    "country": "DE",
    "name": "Vellberg",
    "lat": "49.0843",
    "lng": "9.87914"
  },
  {
    "country": "DE",
    "name": "Velgast",
    "lat": "54.27204",
    "lng": "12.81075"
  },
  {
    "country": "DE",
    "name": "Velen",
    "lat": "51.89447",
    "lng": "6.98807"
  },
  {
    "country": "DE",
    "name": "Velden",
    "lat": "49.61388",
    "lng": "11.51008"
  },
  {
    "country": "DE",
    "name": "Velden",
    "lat": "48.36632",
    "lng": "12.25596"
  },
  {
    "country": "DE",
    "name": "Velburg",
    "lat": "49.23212",
    "lng": "11.6716"
  },
  {
    "country": "DE",
    "name": "Velbert",
    "lat": "51.33537",
    "lng": "7.04348"
  },
  {
    "country": "DE",
    "name": "Veitshöchheim",
    "lat": "49.83278",
    "lng": "9.88167"
  },
  {
    "country": "DE",
    "name": "Veitsbronn",
    "lat": "49.51239",
    "lng": "10.88797"
  },
  {
    "country": "DE",
    "name": "Veilsdorf",
    "lat": "50.40876",
    "lng": "10.80947"
  },
  {
    "country": "DE",
    "name": "Veckenstedt",
    "lat": "51.90113",
    "lng": "10.73203"
  },
  {
    "country": "DE",
    "name": "Vechta",
    "lat": "52.72632",
    "lng": "8.28598"
  },
  {
    "country": "DE",
    "name": "Vechelde",
    "lat": "52.26038",
    "lng": "10.36491"
  },
  {
    "country": "DE",
    "name": "Vaterstetten",
    "lat": "48.10537",
    "lng": "11.76825"
  },
  {
    "country": "DE",
    "name": "Varrel",
    "lat": "52.6215",
    "lng": "8.7331"
  },
  {
    "country": "DE",
    "name": "Varel",
    "lat": "53.39693",
    "lng": "8.13621"
  },
  {
    "country": "DE",
    "name": "Valley",
    "lat": "47.8931",
    "lng": "11.77915"
  },
  {
    "country": "DE",
    "name": "Vallendar",
    "lat": "50.39586",
    "lng": "7.62427"
  },
  {
    "country": "DE",
    "name": "Vaihingen an der Enz",
    "lat": "48.93563",
    "lng": "8.96045"
  },
  {
    "country": "DE",
    "name": "Vagen",
    "lat": "47.8741",
    "lng": "11.88446"
  },
  {
    "country": "DE",
    "name": "Vachendorf",
    "lat": "47.84256",
    "lng": "12.60606"
  },
  {
    "country": "DE",
    "name": "Vacha",
    "lat": "50.8279",
    "lng": "10.02185"
  },
  {
    "country": "DE",
    "name": "Vaale",
    "lat": "54",
    "lng": "9.38333"
  },
  {
    "country": "DE",
    "name": "Üxheim",
    "lat": "50.35",
    "lng": "6.75"
  },
  {
    "country": "DE",
    "name": "Utting am Ammersee",
    "lat": "48.02608",
    "lng": "11.08612"
  },
  {
    "country": "DE",
    "name": "Uttenweiler",
    "lat": "48.15",
    "lng": "9.61667"
  },
  {
    "country": "DE",
    "name": "Uttenreuth",
    "lat": "49.59675",
    "lng": "11.07216"
  },
  {
    "country": "DE",
    "name": "Uthlede",
    "lat": "53.31119",
    "lng": "8.57861"
  },
  {
    "country": "DE",
    "name": "Uthleben",
    "lat": "51.44912",
    "lng": "10.838"
  },
  {
    "country": "DE",
    "name": "Uetersen",
    "lat": "53.68769",
    "lng": "9.66394"
  },
  {
    "country": "DE",
    "name": "Ustersbach",
    "lat": "48.31667",
    "lng": "10.65"
  },
  {
    "country": "DE",
    "name": "Uslar",
    "lat": "51.6569",
    "lng": "9.63501"
  },
  {
    "country": "DE",
    "name": "Usingen",
    "lat": "50.33554",
    "lng": "8.53688"
  },
  {
    "country": "DE",
    "name": "Usedom",
    "lat": "53.87537",
    "lng": "13.92394"
  },
  {
    "country": "DE",
    "name": "Urspringen",
    "lat": "49.90166",
    "lng": "9.67123"
  },
  {
    "country": "DE",
    "name": "Ursensollen",
    "lat": "49.40204",
    "lng": "11.75503"
  },
  {
    "country": "DE",
    "name": "Ursberg",
    "lat": "48.26428",
    "lng": "10.44594"
  },
  {
    "country": "DE",
    "name": "Urmitz",
    "lat": "50.41667",
    "lng": "7.51667"
  },
  {
    "country": "DE",
    "name": "Urbar",
    "lat": "50.38333",
    "lng": "7.63333"
  },
  {
    "country": "DE",
    "name": "Urbach-Überdorf",
    "lat": "50.5569",
    "lng": "7.58695"
  },
  {
    "country": "DE",
    "name": "Urbach",
    "lat": "51.29468",
    "lng": "10.6054"
  },
  {
    "country": "DE",
    "name": "Bad Urach",
    "lat": "48.49107",
    "lng": "9.40009"
  },
  {
    "country": "DE",
    "name": "Upgant-Schott",
    "lat": "53.51667",
    "lng": "7.28333"
  },
  {
    "country": "DE",
    "name": "Untrasried",
    "lat": "47.83333",
    "lng": "10.38333"
  },
  {
    "country": "DE",
    "name": "Unterwössen",
    "lat": "47.73333",
    "lng": "12.46667"
  },
  {
    "country": "DE",
    "name": "Unterwellenborn",
    "lat": "50.65",
    "lng": "11.43333"
  },
  {
    "country": "DE",
    "name": "Unterthingau",
    "lat": "47.77155",
    "lng": "10.50446"
  },
  {
    "country": "DE",
    "name": "Untersteinach",
    "lat": "50.13333",
    "lng": "11.51667"
  },
  {
    "country": "DE",
    "name": "Untersiemau",
    "lat": "50.19415",
    "lng": "10.97448"
  },
  {
    "country": "DE",
    "name": "Unterschneidheim",
    "lat": "48.93333",
    "lng": "10.36667"
  },
  {
    "country": "DE",
    "name": "Unterschleißheim",
    "lat": "48.28038",
    "lng": "11.57684"
  },
  {
    "country": "DE",
    "name": "Unterreit",
    "lat": "48.11667",
    "lng": "12.33333"
  },
  {
    "country": "DE",
    "name": "Unterreichenbach",
    "lat": "48.82496",
    "lng": "8.70885"
  },
  {
    "country": "DE",
    "name": "Unterpleichfeld",
    "lat": "49.86886",
    "lng": "10.04399"
  },
  {
    "country": "DE",
    "name": "Unterneukirchen",
    "lat": "48.16667",
    "lng": "12.61667"
  },
  {
    "country": "DE",
    "name": "Untermünkheim",
    "lat": "49.15255",
    "lng": "9.73384"
  },
  {
    "country": "DE",
    "name": "Untermerzbach",
    "lat": "50.12754",
    "lng": "10.85634"
  },
  {
    "country": "DE",
    "name": "Untermeitingen",
    "lat": "48.16082",
    "lng": "10.80694"
  },
  {
    "country": "DE",
    "name": "Untermaßfeld",
    "lat": "50.53333",
    "lng": "10.41667"
  },
  {
    "country": "DE",
    "name": "Unterlüß",
    "lat": "52.83471",
    "lng": "10.29685"
  },
  {
    "country": "DE",
    "name": "Unterleinleiter",
    "lat": "49.82303",
    "lng": "11.18906"
  },
  {
    "country": "DE",
    "name": "Unterkirnach",
    "lat": "48.07946",
    "lng": "8.36575"
  },
  {
    "country": "DE",
    "name": "Unterjettingen",
    "lat": "48.5623",
    "lng": "8.78445"
  },
  {
    "country": "DE",
    "name": "Unterhausen",
    "lat": "48.4298",
    "lng": "9.25504"
  },
  {
    "country": "DE",
    "name": "Unterhaching",
    "lat": "48.06598",
    "lng": "11.61564"
  },
  {
    "country": "DE",
    "name": "Untergruppenbach",
    "lat": "49.0894",
    "lng": "9.27516"
  },
  {
    "country": "DE",
    "name": "Untergriesbach",
    "lat": "48.57434",
    "lng": "13.66725"
  },
  {
    "country": "DE",
    "name": "Unterföhring",
    "lat": "48.19253",
    "lng": "11.64293"
  },
  {
    "country": "DE",
    "name": "Unterensingen",
    "lat": "48.65452",
    "lng": "9.35799"
  },
  {
    "country": "DE",
    "name": "Untereisesheim",
    "lat": "49.21111",
    "lng": "9.20194"
  },
  {
    "country": "DE",
    "name": "Unteregg",
    "lat": "47.96667",
    "lng": "10.46667"
  },
  {
    "country": "DE",
    "name": "Unterdietfurt",
    "lat": "48.38333",
    "lng": "12.66667"
  },
  {
    "country": "DE",
    "name": "Unterdießen",
    "lat": "47.98333",
    "lng": "10.83333"
  },
  {
    "country": "DE",
    "name": "Unterbreizbach",
    "lat": "50.81667",
    "lng": "9.98333"
  },
  {
    "country": "DE",
    "name": "Unterkrozingen",
    "lat": "47.91933",
    "lng": "7.69045"
  },
  {
    "country": "DE",
    "name": "Unterammergau",
    "lat": "47.61658",
    "lng": "11.02718"
  },
  {
    "country": "DE",
    "name": "Unter-Abtsteinach",
    "lat": "49.52711",
    "lng": "8.78679"
  },
  {
    "country": "DE",
    "name": "Unseburg",
    "lat": "51.93284",
    "lng": "11.51281"
  },
  {
    "country": "DE",
    "name": "Unnau",
    "lat": "50.64881",
    "lng": "7.90827"
  },
  {
    "country": "DE",
    "name": "Unna",
    "lat": "51.53795",
    "lng": "7.68969"
  },
  {
    "country": "DE",
    "name": "Unlingen",
    "lat": "48.16734",
    "lng": "9.52219"
  },
  {
    "country": "DE",
    "name": "Unkel",
    "lat": "50.59653",
    "lng": "7.21888"
  },
  {
    "country": "DE",
    "name": "Ungerhausen",
    "lat": "48.00566",
    "lng": "10.26672"
  },
  {
    "country": "DE",
    "name": "Undenheim",
    "lat": "49.83806",
    "lng": "8.21889"
  },
  {
    "country": "DE",
    "name": "Ummern",
    "lat": "52.59111",
    "lng": "10.43195"
  },
  {
    "country": "DE",
    "name": "Ummendorf",
    "lat": "52.15645",
    "lng": "11.18151"
  },
  {
    "country": "DE",
    "name": "Ummendorf",
    "lat": "48.06667",
    "lng": "9.83333"
  },
  {
    "country": "DE",
    "name": "Umkirch",
    "lat": "48.03333",
    "lng": "7.76667"
  },
  {
    "country": "DE",
    "name": "Ulrichstein",
    "lat": "50.5755",
    "lng": "9.19272"
  },
  {
    "country": "DE",
    "name": "Ulmen",
    "lat": "50.20943",
    "lng": "6.97941"
  },
  {
    "country": "DE",
    "name": "Ulm",
    "lat": "48.39841",
    "lng": "9.99155"
  },
  {
    "country": "DE",
    "name": "Uichteritz",
    "lat": "51.20652",
    "lng": "11.92215"
  },
  {
    "country": "DE",
    "name": "Uhyst",
    "lat": "51.36469",
    "lng": "14.506"
  },
  {
    "country": "DE",
    "name": "Uehrde",
    "lat": "52.09902",
    "lng": "10.76523"
  },
  {
    "country": "DE",
    "name": "Uehlfeld",
    "lat": "49.67085",
    "lng": "10.72017"
  },
  {
    "country": "DE",
    "name": "Uhingen",
    "lat": "48.70475",
    "lng": "9.5857"
  },
  {
    "country": "DE",
    "name": "Uftrungen",
    "lat": "51.49859",
    "lng": "10.98066"
  },
  {
    "country": "DE",
    "name": "Uffing",
    "lat": "47.71378",
    "lng": "11.15034"
  },
  {
    "country": "DE",
    "name": "Uffenheim",
    "lat": "49.54415",
    "lng": "10.23286"
  },
  {
    "country": "DE",
    "name": "Uetze",
    "lat": "52.46511",
    "lng": "10.20467"
  },
  {
    "country": "DE",
    "name": "Uettingen",
    "lat": "49.79472",
    "lng": "9.73056"
  },
  {
    "country": "DE",
    "name": "Uenglingen",
    "lat": "52.61797",
    "lng": "11.80893"
  },
  {
    "country": "DE",
    "name": "Uelzen",
    "lat": "52.96572",
    "lng": "10.56111"
  },
  {
    "country": "DE",
    "name": "Uelversheim",
    "lat": "49.81",
    "lng": "8.28861"
  },
  {
    "country": "DE",
    "name": "Uelsen",
    "lat": "52.5",
    "lng": "6.88333"
  },
  {
    "country": "DE",
    "name": "Uedem",
    "lat": "51.6652",
    "lng": "6.27371"
  },
  {
    "country": "DE",
    "name": "Ueckermünde",
    "lat": "53.73795",
    "lng": "14.04473"
  },
  {
    "country": "DE",
    "name": "Uebigau",
    "lat": "51.59415",
    "lng": "13.29983"
  },
  {
    "country": "DE",
    "name": "Üdersdorf",
    "lat": "50.15",
    "lng": "6.8"
  },
  {
    "country": "DE",
    "name": "Uder",
    "lat": "51.36243",
    "lng": "10.0721"
  },
  {
    "country": "DE",
    "name": "Udenheim",
    "lat": "49.86472",
    "lng": "8.17167"
  },
  {
    "country": "DE",
    "name": "Udenhausen",
    "lat": "51.46385",
    "lng": "9.46335"
  },
  {
    "country": "DE",
    "name": "Uchtspringe",
    "lat": "52.54011",
    "lng": "11.59959"
  },
  {
    "country": "DE",
    "name": "Üchtelhausen",
    "lat": "50.09184",
    "lng": "10.26861"
  },
  {
    "country": "DE",
    "name": "Uchte",
    "lat": "52.49975",
    "lng": "8.90928"
  },
  {
    "country": "DE",
    "name": "Übersee",
    "lat": "47.81667",
    "lng": "12.48333"
  },
  {
    "country": "DE",
    "name": "Überlingen",
    "lat": "47.76977",
    "lng": "9.17136"
  },
  {
    "country": "DE",
    "name": "Überherrn",
    "lat": "49.24187",
    "lng": "6.6984"
  },
  {
    "country": "DE",
    "name": "Übach-Palenberg",
    "lat": "50.91775",
    "lng": "6.12336"
  },
  {
    "country": "DE",
    "name": "Tschernitz",
    "lat": "51.58333",
    "lng": "14.61667"
  },
  {
    "country": "DE",
    "name": "Tyrlaching",
    "lat": "48.06667",
    "lng": "12.66667"
  },
  {
    "country": "DE",
    "name": "Twistringen",
    "lat": "52.79926",
    "lng": "8.64163"
  },
  {
    "country": "DE",
    "name": "Tutzing",
    "lat": "47.90938",
    "lng": "11.2803"
  },
  {
    "country": "DE",
    "name": "Tuttlingen",
    "lat": "47.98464",
    "lng": "8.8177"
  },
  {
    "country": "DE",
    "name": "Tüttendorf",
    "lat": "54.4",
    "lng": "10"
  },
  {
    "country": "DE",
    "name": "Tutow",
    "lat": "53.91566",
    "lng": "13.24814"
  },
  {
    "country": "DE",
    "name": "Tüßling",
    "lat": "48.21218",
    "lng": "12.59954"
  },
  {
    "country": "DE",
    "name": "Tussenhausen",
    "lat": "48.10218",
    "lng": "10.56069"
  },
  {
    "country": "DE",
    "name": "Türnich",
    "lat": "50.85892",
    "lng": "6.75535"
  },
  {
    "country": "DE",
    "name": "Türkheim",
    "lat": "48.06401",
    "lng": "10.64156"
  },
  {
    "country": "DE",
    "name": "Türkenfeld",
    "lat": "48.10531",
    "lng": "11.08303"
  },
  {
    "country": "DE",
    "name": "Tuntenhausen",
    "lat": "47.93509",
    "lng": "12.01518"
  },
  {
    "country": "DE",
    "name": "Tuningen",
    "lat": "48.03333",
    "lng": "8.6"
  },
  {
    "country": "DE",
    "name": "Tülau",
    "lat": "52.57578",
    "lng": "10.87818"
  },
  {
    "country": "DE",
    "name": "Tuchenbach",
    "lat": "49.52794",
    "lng": "10.85973"
  },
  {
    "country": "DE",
    "name": "Tucheim",
    "lat": "52.28923",
    "lng": "12.18423"
  },
  {
    "country": "DE",
    "name": "Tübingen",
    "lat": "48.52266",
    "lng": "9.05222"
  },
  {
    "country": "DE",
    "name": "Trusetal",
    "lat": "50.78333",
    "lng": "10.41667"
  },
  {
    "country": "DE",
    "name": "Trunkelsberg",
    "lat": "48",
    "lng": "10.21667"
  },
  {
    "country": "DE",
    "name": "Trulben",
    "lat": "49.13916",
    "lng": "7.5437"
  },
  {
    "country": "DE",
    "name": "Trostberg an der Alz",
    "lat": "48.02802",
    "lng": "12.55804"
  },
  {
    "country": "DE",
    "name": "Tröstau",
    "lat": "50.01667",
    "lng": "11.95"
  },
  {
    "country": "DE",
    "name": "Trossingen",
    "lat": "48.07667",
    "lng": "8.64409"
  },
  {
    "country": "DE",
    "name": "Trossin",
    "lat": "51.61667",
    "lng": "12.81667"
  },
  {
    "country": "DE",
    "name": "Trollenhagen",
    "lat": "53.60706",
    "lng": "13.29103"
  },
  {
    "country": "DE",
    "name": "Troisdorf",
    "lat": "50.80901",
    "lng": "7.14968"
  },
  {
    "country": "DE",
    "name": "Trogen",
    "lat": "50.36667",
    "lng": "11.95"
  },
  {
    "country": "DE",
    "name": "Trochtelfingen",
    "lat": "48.30843",
    "lng": "9.24491"
  },
  {
    "country": "DE",
    "name": "Trittenheim",
    "lat": "49.82471",
    "lng": "6.89929"
  },
  {
    "country": "DE",
    "name": "Trittau",
    "lat": "53.61667",
    "lng": "10.4"
  },
  {
    "country": "DE",
    "name": "Triptis",
    "lat": "50.73567",
    "lng": "11.87015"
  },
  {
    "country": "DE",
    "name": "Trippstadt",
    "lat": "49.35935",
    "lng": "7.7748"
  },
  {
    "country": "DE",
    "name": "Trinwillershagen",
    "lat": "54.25048",
    "lng": "12.62312"
  },
  {
    "country": "DE",
    "name": "Triftern",
    "lat": "48.39468",
    "lng": "13.00627"
  },
  {
    "country": "DE",
    "name": "Trierweiler",
    "lat": "49.76231",
    "lng": "6.55987"
  },
  {
    "country": "DE",
    "name": "Trier",
    "lat": "49.75565",
    "lng": "6.63935"
  },
  {
    "country": "DE",
    "name": "Triebes",
    "lat": "50.68489",
    "lng": "12.02042"
  },
  {
    "country": "DE",
    "name": "Tribsees",
    "lat": "54.09556",
    "lng": "12.75683"
  },
  {
    "country": "DE",
    "name": "Triberg im Schwarzwald",
    "lat": "48.13175",
    "lng": "8.23317"
  },
  {
    "country": "DE",
    "name": "Treuenbrietzen",
    "lat": "52.09754",
    "lng": "12.87258"
  },
  {
    "country": "DE",
    "name": "Treuen",
    "lat": "50.54247",
    "lng": "12.30339"
  },
  {
    "country": "DE",
    "name": "Treuchtlingen",
    "lat": "48.95473",
    "lng": "10.90833"
  },
  {
    "country": "DE",
    "name": "Alt-Treptow",
    "lat": "52.48863",
    "lng": "13.4586"
  },
  {
    "country": "DE",
    "name": "Trendelburg",
    "lat": "51.57408",
    "lng": "9.42095"
  },
  {
    "country": "DE",
    "name": "Tremsbüttel",
    "lat": "53.74384",
    "lng": "10.31024"
  },
  {
    "country": "DE",
    "name": "Treis-Karden",
    "lat": "50.17174",
    "lng": "7.30218"
  },
  {
    "country": "DE",
    "name": "Treia",
    "lat": "54.5",
    "lng": "9.31667"
  },
  {
    "country": "DE",
    "name": "Treffurt",
    "lat": "51.13691",
    "lng": "10.23361"
  },
  {
    "country": "DE",
    "name": "Treffelstein",
    "lat": "49.42246",
    "lng": "12.61574"
  },
  {
    "country": "DE",
    "name": "Trechtingshausen",
    "lat": "50.01031",
    "lng": "7.84709"
  },
  {
    "country": "DE",
    "name": "Trebur",
    "lat": "49.92639",
    "lng": "8.40732"
  },
  {
    "country": "DE",
    "name": "Trebsen",
    "lat": "51.28898",
    "lng": "12.75496"
  },
  {
    "country": "DE",
    "name": "Trebitz",
    "lat": "51.58615",
    "lng": "11.91965"
  },
  {
    "country": "DE",
    "name": "Trebgast",
    "lat": "50.06667",
    "lng": "11.55"
  },
  {
    "country": "DE",
    "name": "Trebendorf",
    "lat": "51.53333",
    "lng": "14.56667"
  },
  {
    "country": "DE",
    "name": "Trebbin",
    "lat": "52.21675",
    "lng": "13.22496"
  },
  {
    "country": "DE",
    "name": "Travemünde",
    "lat": "53.96304",
    "lng": "10.8709"
  },
  {
    "country": "DE",
    "name": "Trautskirchen",
    "lat": "49.4581",
    "lng": "10.59361"
  },
  {
    "country": "DE",
    "name": "Trausnitz",
    "lat": "49.52114",
    "lng": "12.26249"
  },
  {
    "country": "DE",
    "name": "Traunstein",
    "lat": "47.86825",
    "lng": "12.64335"
  },
  {
    "country": "DE",
    "name": "Traunreut",
    "lat": "47.96269",
    "lng": "12.59231"
  },
  {
    "country": "DE",
    "name": "Trassem",
    "lat": "49.57849",
    "lng": "6.5254"
  },
  {
    "country": "DE",
    "name": "Trappstadt",
    "lat": "50.3188",
    "lng": "10.56995"
  },
  {
    "country": "DE",
    "name": "Trappenkamp",
    "lat": "54.03988",
    "lng": "10.21496"
  },
  {
    "country": "DE",
    "name": "Traitsching",
    "lat": "49.15",
    "lng": "12.65"
  },
  {
    "country": "DE",
    "name": "Train",
    "lat": "48.73333",
    "lng": "11.83333"
  },
  {
    "country": "DE",
    "name": "Trabitz",
    "lat": "49.8",
    "lng": "11.9"
  },
  {
    "country": "DE",
    "name": "Traben-Trarbach",
    "lat": "49.95076",
    "lng": "7.11562"
  },
  {
    "country": "DE",
    "name": "Tostedt",
    "lat": "53.28333",
    "lng": "9.71667"
  },
  {
    "country": "DE",
    "name": "Tornesch",
    "lat": "53.7",
    "lng": "9.71667"
  },
  {
    "country": "DE",
    "name": "Torgelow",
    "lat": "53.63415",
    "lng": "14.01346"
  },
  {
    "country": "DE",
    "name": "Torgau",
    "lat": "51.56016",
    "lng": "12.99617"
  },
  {
    "country": "DE",
    "name": "Toppenstedt",
    "lat": "53.2643",
    "lng": "10.11451"
  },
  {
    "country": "DE",
    "name": "Töpen",
    "lat": "50.39067",
    "lng": "11.87329"
  },
  {
    "country": "DE",
    "name": "Tönning",
    "lat": "54.31879",
    "lng": "8.94234"
  },
  {
    "country": "DE",
    "name": "Tönisvorst",
    "lat": "51.32092",
    "lng": "6.49412"
  },
  {
    "country": "DE",
    "name": "Tollwitz",
    "lat": "51.28601",
    "lng": "12.09733"
  },
  {
    "country": "DE",
    "name": "Tolk",
    "lat": "54.57987",
    "lng": "9.63844"
  },
  {
    "country": "DE",
    "name": "Töging am Inn",
    "lat": "48.26018",
    "lng": "12.5846"
  },
  {
    "country": "DE",
    "name": "Todtnau",
    "lat": "47.82941",
    "lng": "7.9438"
  },
  {
    "country": "DE",
    "name": "Todtmoos",
    "lat": "47.74014",
    "lng": "8.00183"
  },
  {
    "country": "DE",
    "name": "Todtenweis",
    "lat": "48.51712",
    "lng": "10.92856"
  },
  {
    "country": "DE",
    "name": "Todesfelde",
    "lat": "53.9",
    "lng": "10.18333"
  },
  {
    "country": "DE",
    "name": "Todendorf",
    "lat": "53.69461",
    "lng": "10.34781"
  },
  {
    "country": "DE",
    "name": "Todenbüttel",
    "lat": "54.13333",
    "lng": "9.55"
  },
  {
    "country": "DE",
    "name": "Titz",
    "lat": "51.00619",
    "lng": "6.42477"
  },
  {
    "country": "DE",
    "name": "Tittmoning",
    "lat": "48.06164",
    "lng": "12.7676"
  },
  {
    "country": "DE",
    "name": "Tittling",
    "lat": "48.72619",
    "lng": "13.38221"
  },
  {
    "country": "DE",
    "name": "Titisee-Neustadt",
    "lat": "47.92104",
    "lng": "8.19063"
  },
  {
    "country": "DE",
    "name": "Tirschenreuth",
    "lat": "49.88263",
    "lng": "12.33112"
  },
  {
    "country": "DE",
    "name": "Tirpersdorf",
    "lat": "50.43333",
    "lng": "12.25"
  },
  {
    "country": "DE",
    "name": "Tinnum",
    "lat": "54.89932",
    "lng": "8.33476"
  },
  {
    "country": "DE",
    "name": "Timmenrode",
    "lat": "51.77113",
    "lng": "11.00624"
  },
  {
    "country": "DE",
    "name": "Timmendorfer Strand",
    "lat": "53.9953",
    "lng": "10.77676"
  },
  {
    "country": "DE",
    "name": "Timmaspe",
    "lat": "54.13967",
    "lng": "9.8943"
  },
  {
    "country": "DE",
    "name": "Tiergarten",
    "lat": "52.51667",
    "lng": "13.36667"
  },
  {
    "country": "DE",
    "name": "Tiefenort",
    "lat": "50.83946",
    "lng": "10.16604"
  },
  {
    "country": "DE",
    "name": "Tiefenbronn",
    "lat": "48.82398",
    "lng": "8.80129"
  },
  {
    "country": "DE",
    "name": "Tiefenbach",
    "lat": "49.18525",
    "lng": "12.32337"
  },
  {
    "country": "DE",
    "name": "Tiefenbach",
    "lat": "48.5",
    "lng": "12.1"
  },
  {
    "country": "DE",
    "name": "Tiddische",
    "lat": "52.51667",
    "lng": "10.8"
  },
  {
    "country": "DE",
    "name": "Thyrnau",
    "lat": "48.61667",
    "lng": "13.53333"
  },
  {
    "country": "DE",
    "name": "Thurnau",
    "lat": "50.02542",
    "lng": "11.39348"
  },
  {
    "country": "DE",
    "name": "Thurmansbang",
    "lat": "48.76627",
    "lng": "13.3155"
  },
  {
    "country": "DE",
    "name": "Thür",
    "lat": "50.35692",
    "lng": "7.27689"
  },
  {
    "country": "DE",
    "name": "Thüngersheim",
    "lat": "49.87833",
    "lng": "9.84917"
  },
  {
    "country": "DE",
    "name": "Thüngen",
    "lat": "49.9414",
    "lng": "9.8586"
  },
  {
    "country": "DE",
    "name": "Thundorf in Unterfranken",
    "lat": "50.20097",
    "lng": "10.31906"
  },
  {
    "country": "DE",
    "name": "Thum",
    "lat": "50.67081",
    "lng": "12.95091"
  },
  {
    "country": "DE",
    "name": "Thuine",
    "lat": "52.5",
    "lng": "7.48333"
  },
  {
    "country": "DE",
    "name": "Thomm",
    "lat": "49.7414",
    "lng": "6.80492"
  },
  {
    "country": "DE",
    "name": "Thomasburg",
    "lat": "53.23333",
    "lng": "10.66667"
  },
  {
    "country": "DE",
    "name": "Tholey",
    "lat": "49.48374",
    "lng": "7.03691"
  },
  {
    "country": "DE",
    "name": "Thierstein",
    "lat": "50.10643",
    "lng": "12.10203"
  },
  {
    "country": "DE",
    "name": "Thiersheim",
    "lat": "50.07609",
    "lng": "12.1265"
  },
  {
    "country": "DE",
    "name": "Thierhaupten",
    "lat": "48.56531",
    "lng": "10.90862"
  },
  {
    "country": "DE",
    "name": "Thiendorf",
    "lat": "51.29375",
    "lng": "13.74124"
  },
  {
    "country": "DE",
    "name": "Theuma",
    "lat": "50.47007",
    "lng": "12.22195"
  },
  {
    "country": "DE",
    "name": "Themar",
    "lat": "50.50465",
    "lng": "10.61536"
  },
  {
    "country": "DE",
    "name": "Theißen",
    "lat": "51.08748",
    "lng": "12.10659"
  },
  {
    "country": "DE",
    "name": "Theisseil",
    "lat": "49.69034",
    "lng": "12.22744"
  },
  {
    "country": "DE",
    "name": "Theilheim",
    "lat": "49.75403",
    "lng": "10.03056"
  },
  {
    "country": "DE",
    "name": "Thedinghausen",
    "lat": "52.96667",
    "lng": "9.01667"
  },
  {
    "country": "DE",
    "name": "Tharandt",
    "lat": "50.98525",
    "lng": "13.58035"
  },
  {
    "country": "DE",
    "name": "Thanstein",
    "lat": "49.38333",
    "lng": "12.46667"
  },
  {
    "country": "DE",
    "name": "Thannhausen",
    "lat": "48.28334",
    "lng": "10.46917"
  },
  {
    "country": "DE",
    "name": "Thalmässing",
    "lat": "49.08834",
    "lng": "11.2215"
  },
  {
    "country": "DE",
    "name": "Thalmassing",
    "lat": "48.91167",
    "lng": "12.155"
  },
  {
    "country": "DE",
    "name": "Thallwitz",
    "lat": "51.43333",
    "lng": "12.68333"
  },
  {
    "country": "DE",
    "name": "Thalheim",
    "lat": "51.65268",
    "lng": "12.22756"
  },
  {
    "country": "DE",
    "name": "Thalheim",
    "lat": "50.70077",
    "lng": "12.84996"
  },
  {
    "country": "DE",
    "name": "Thaleischweiler-Fröschen",
    "lat": "49.26667",
    "lng": "7.58333"
  },
  {
    "country": "DE",
    "name": "Thale",
    "lat": "51.74861",
    "lng": "11.041"
  },
  {
    "country": "DE",
    "name": "Thal",
    "lat": "50.91684",
    "lng": "10.39209"
  },
  {
    "country": "DE",
    "name": "Teutschenthal",
    "lat": "51.45",
    "lng": "11.8"
  },
  {
    "country": "DE",
    "name": "Teuschnitz",
    "lat": "50.39839",
    "lng": "11.38235"
  },
  {
    "country": "DE",
    "name": "Teupitz",
    "lat": "52.12967",
    "lng": "13.6196"
  },
  {
    "country": "DE",
    "name": "Teunz",
    "lat": "49.48333",
    "lng": "12.38333"
  },
  {
    "country": "DE",
    "name": "Teugn",
    "lat": "48.89299",
    "lng": "12.01175"
  },
  {
    "country": "DE",
    "name": "Teuchern",
    "lat": "51.12094",
    "lng": "12.0241"
  },
  {
    "country": "DE",
    "name": "Teuchel",
    "lat": "51.88842",
    "lng": "12.64587"
  },
  {
    "country": "DE",
    "name": "Teublitz",
    "lat": "49.22289",
    "lng": "12.08727"
  },
  {
    "country": "DE",
    "name": "Tettnang",
    "lat": "47.66857",
    "lng": "9.59132"
  },
  {
    "country": "DE",
    "name": "Tettenweis",
    "lat": "48.44281",
    "lng": "13.26955"
  },
  {
    "country": "DE",
    "name": "Tettau",
    "lat": "50.46979",
    "lng": "11.25888"
  },
  {
    "country": "DE",
    "name": "Teterow",
    "lat": "53.77545",
    "lng": "12.57487"
  },
  {
    "country": "DE",
    "name": "Tessin",
    "lat": "54.02764",
    "lng": "12.46519"
  },
  {
    "country": "DE",
    "name": "Tespe",
    "lat": "53.3964",
    "lng": "10.41084"
  },
  {
    "country": "DE",
    "name": "Tennenbronn",
    "lat": "48.19041",
    "lng": "8.35176"
  },
  {
    "country": "DE",
    "name": "Teningen",
    "lat": "48.12952",
    "lng": "7.81205"
  },
  {
    "country": "DE",
    "name": "Tengen",
    "lat": "47.82128",
    "lng": "8.66117"
  },
  {
    "country": "DE",
    "name": "Templin",
    "lat": "53.11865",
    "lng": "13.5022"
  },
  {
    "country": "DE",
    "name": "Tempelhof",
    "lat": "52.46667",
    "lng": "13.4"
  },
  {
    "country": "DE",
    "name": "Teltow",
    "lat": "52.4031",
    "lng": "13.26014"
  },
  {
    "country": "DE",
    "name": "Tellingstedt",
    "lat": "54.21667",
    "lng": "9.28333"
  },
  {
    "country": "DE",
    "name": "Telgte",
    "lat": "51.97995",
    "lng": "7.78293"
  },
  {
    "country": "DE",
    "name": "Teistungen",
    "lat": "51.46667",
    "lng": "10.26667"
  },
  {
    "country": "DE",
    "name": "Teisnach",
    "lat": "49.04114",
    "lng": "12.98784"
  },
  {
    "country": "DE",
    "name": "Teising",
    "lat": "48.22721",
    "lng": "12.61137"
  },
  {
    "country": "DE",
    "name": "Teisendorf",
    "lat": "47.84921",
    "lng": "12.81919"
  },
  {
    "country": "DE",
    "name": "Teichwolframsdorf",
    "lat": "50.72093",
    "lng": "12.24689"
  },
  {
    "country": "DE",
    "name": "Teicha",
    "lat": "51.55887",
    "lng": "11.95482"
  },
  {
    "country": "DE",
    "name": "Tegernsee",
    "lat": "47.7123",
    "lng": "11.7582"
  },
  {
    "country": "DE",
    "name": "Tegernheim",
    "lat": "49.02394",
    "lng": "12.17303"
  },
  {
    "country": "DE",
    "name": "Tegel",
    "lat": "52.57601",
    "lng": "13.29389"
  },
  {
    "country": "DE",
    "name": "Tecklenburg",
    "lat": "52.21957",
    "lng": "7.81357"
  },
  {
    "country": "DE",
    "name": "Tawern",
    "lat": "49.66667",
    "lng": "6.51667"
  },
  {
    "country": "DE",
    "name": "Tautenhain",
    "lat": "50.9247",
    "lng": "11.91945"
  },
  {
    "country": "DE",
    "name": "Tauscha",
    "lat": "51.26667",
    "lng": "13.8"
  },
  {
    "country": "DE",
    "name": "Taura",
    "lat": "50.91667",
    "lng": "12.85"
  },
  {
    "country": "DE",
    "name": "Taunusstein",
    "lat": "50.14993",
    "lng": "8.15206"
  },
  {
    "country": "DE",
    "name": "Taufkirchen",
    "lat": "48.34987",
    "lng": "12.13202"
  },
  {
    "country": "DE",
    "name": "Taufkirchen",
    "lat": "48.15",
    "lng": "12.45"
  },
  {
    "country": "DE",
    "name": "Taufkirchen",
    "lat": "48.0486",
    "lng": "11.61701"
  },
  {
    "country": "DE",
    "name": "Tauche",
    "lat": "52.15",
    "lng": "14.16667"
  },
  {
    "country": "DE",
    "name": "Taucha",
    "lat": "51.38333",
    "lng": "12.48333"
  },
  {
    "country": "DE",
    "name": "Tauberbischofsheim",
    "lat": "49.62472",
    "lng": "9.66278"
  },
  {
    "country": "DE",
    "name": "Tating",
    "lat": "54.32607",
    "lng": "8.70802"
  },
  {
    "country": "DE",
    "name": "Markt Taschendorf",
    "lat": "49.70111",
    "lng": "10.55557"
  },
  {
    "country": "DE",
    "name": "Tarp",
    "lat": "54.66667",
    "lng": "9.4"
  },
  {
    "country": "DE",
    "name": "Tarnow",
    "lat": "53.77941",
    "lng": "12.01785"
  },
  {
    "country": "DE",
    "name": "Tarmstedt",
    "lat": "53.22505",
    "lng": "9.07763"
  },
  {
    "country": "DE",
    "name": "Tappenbeck",
    "lat": "52.47055",
    "lng": "10.74068"
  },
  {
    "country": "DE",
    "name": "Tapfheim",
    "lat": "48.67322",
    "lng": "10.68377"
  },
  {
    "country": "DE",
    "name": "Tannheim",
    "lat": "48",
    "lng": "10.08333"
  },
  {
    "country": "DE",
    "name": "Tannhausen",
    "lat": "48.9787",
    "lng": "10.36129"
  },
  {
    "country": "DE",
    "name": "Tännesberg",
    "lat": "49.53182",
    "lng": "12.32765"
  },
  {
    "country": "DE",
    "name": "Tannenbergsthal",
    "lat": "50.43665",
    "lng": "12.45754"
  },
  {
    "country": "DE",
    "name": "Tannenberg",
    "lat": "50.60738",
    "lng": "12.93798"
  },
  {
    "country": "DE",
    "name": "Tanna",
    "lat": "50.4946",
    "lng": "11.85725"
  },
  {
    "country": "DE",
    "name": "Tann",
    "lat": "50.64284",
    "lng": "10.02385"
  },
  {
    "country": "DE",
    "name": "Tann",
    "lat": "48.31463",
    "lng": "12.89301"
  },
  {
    "country": "DE",
    "name": "Tangstedt",
    "lat": "53.73333",
    "lng": "10.08333"
  },
  {
    "country": "DE",
    "name": "Tangstedt",
    "lat": "53.67711",
    "lng": "9.8488"
  },
  {
    "country": "DE",
    "name": "Tangermünde",
    "lat": "52.54463",
    "lng": "11.97647"
  },
  {
    "country": "DE",
    "name": "Tangerhütte",
    "lat": "52.4353",
    "lng": "11.80724"
  },
  {
    "country": "DE",
    "name": "Tamm",
    "lat": "48.91988",
    "lng": "9.11556"
  },
  {
    "country": "DE",
    "name": "Tambach-Dietharz",
    "lat": "50.79245",
    "lng": "10.61568"
  },
  {
    "country": "DE",
    "name": "Talheim",
    "lat": "49.08333",
    "lng": "9.19306"
  },
  {
    "country": "DE",
    "name": "Talheim",
    "lat": "48.01667",
    "lng": "8.66667"
  },
  {
    "country": "DE",
    "name": "Tagmersheim",
    "lat": "48.81667",
    "lng": "10.96667"
  },
  {
    "country": "DE",
    "name": "Täferrot",
    "lat": "48.84972",
    "lng": "9.83824"
  },
  {
    "country": "DE",
    "name": "Taching am See",
    "lat": "47.95942",
    "lng": "12.72933"
  },
  {
    "country": "DE",
    "name": "Tacherting",
    "lat": "48.07825",
    "lng": "12.57008"
  },
  {
    "country": "DE",
    "name": "Tabarz",
    "lat": "50.87529",
    "lng": "10.51607"
  },
  {
    "country": "DE",
    "name": "Syrau",
    "lat": "50.54297",
    "lng": "12.07933"
  },
  {
    "country": "DE",
    "name": "Syke",
    "lat": "52.91345",
    "lng": "8.82209"
  },
  {
    "country": "DE",
    "name": "Sustrum",
    "lat": "52.91667",
    "lng": "7.28333"
  },
  {
    "country": "DE",
    "name": "Süstedt",
    "lat": "52.86165",
    "lng": "8.92213"
  },
  {
    "country": "DE",
    "name": "Süßen",
    "lat": "48.67934",
    "lng": "9.75534"
  },
  {
    "country": "DE",
    "name": "Süsel",
    "lat": "54.08135",
    "lng": "10.70172"
  },
  {
    "country": "DE",
    "name": "Surwold",
    "lat": "52.978",
    "lng": "7.51534"
  },
  {
    "country": "DE",
    "name": "Surberg",
    "lat": "47.86667",
    "lng": "12.7"
  },
  {
    "country": "DE",
    "name": "Süpplingen",
    "lat": "52.22811",
    "lng": "10.90393"
  },
  {
    "country": "DE",
    "name": "Süplingen",
    "lat": "52.28759",
    "lng": "11.3245"
  },
  {
    "country": "DE",
    "name": "Sundern",
    "lat": "51.3281",
    "lng": "8.00369"
  },
  {
    "country": "DE",
    "name": "Sünching",
    "lat": "48.87855",
    "lng": "12.35129"
  },
  {
    "country": "DE",
    "name": "Sulzheim",
    "lat": "49.95",
    "lng": "10.33333"
  },
  {
    "country": "DE",
    "name": "Sulzheim",
    "lat": "49.84306",
    "lng": "8.09167"
  },
  {
    "country": "DE",
    "name": "Sulzfeld am Main",
    "lat": "49.70694",
    "lng": "10.13248"
  },
  {
    "country": "DE",
    "name": "Sulzfeld",
    "lat": "50.25972",
    "lng": "10.40525"
  },
  {
    "country": "DE",
    "name": "Sulzfeld",
    "lat": "49.10472",
    "lng": "8.85583"
  },
  {
    "country": "DE",
    "name": "Sulzemoos",
    "lat": "48.29107",
    "lng": "11.26356"
  },
  {
    "country": "DE",
    "name": "Sulzdorf",
    "lat": "49.65002",
    "lng": "9.90389"
  },
  {
    "country": "DE",
    "name": "Sulzburg",
    "lat": "47.84116",
    "lng": "7.70777"
  },
  {
    "country": "DE",
    "name": "Sulzberg",
    "lat": "47.66033",
    "lng": "10.34991"
  },
  {
    "country": "DE",
    "name": "Sulzbach-Rosenberg",
    "lat": "49.50126",
    "lng": "11.74598"
  },
  {
    "country": "DE",
    "name": "Sulzbach an der Murr",
    "lat": "49.00303",
    "lng": "9.5003"
  },
  {
    "country": "DE",
    "name": "Sulzbach am Main",
    "lat": "49.91149",
    "lng": "9.15315"
  },
  {
    "country": "DE",
    "name": "Sulzbach",
    "lat": "50.13396",
    "lng": "8.52797"
  },
  {
    "country": "DE",
    "name": "Sulzbach",
    "lat": "49.29882",
    "lng": "7.05696"
  },
  {
    "country": "DE",
    "name": "Sulz am Neckar",
    "lat": "48.36241",
    "lng": "8.63309"
  },
  {
    "country": "DE",
    "name": "Sulingen",
    "lat": "52.68373",
    "lng": "8.80949"
  },
  {
    "country": "DE",
    "name": "Sülfeld",
    "lat": "53.8",
    "lng": "10.23333"
  },
  {
    "country": "DE",
    "name": "Sukow",
    "lat": "53.54428",
    "lng": "11.56194"
  },
  {
    "country": "DE",
    "name": "Sülstorf",
    "lat": "53.50931",
    "lng": "11.37463"
  },
  {
    "country": "DE",
    "name": "Suhlendorf",
    "lat": "52.93333",
    "lng": "10.76667"
  },
  {
    "country": "DE",
    "name": "Suhl",
    "lat": "50.60911",
    "lng": "10.69401"
  },
  {
    "country": "DE",
    "name": "Sugenheim",
    "lat": "49.60276",
    "lng": "10.43563"
  },
  {
    "country": "DE",
    "name": "Sudwalde",
    "lat": "52.79337",
    "lng": "8.83611"
  },
  {
    "country": "DE",
    "name": "Südlohn",
    "lat": "51.93333",
    "lng": "6.86667"
  },
  {
    "country": "DE",
    "name": "Süderstapel",
    "lat": "54.34967",
    "lng": "9.21907"
  },
  {
    "country": "DE",
    "name": "Süderlügum",
    "lat": "54.87391",
    "lng": "8.91111"
  },
  {
    "country": "DE",
    "name": "Südergellersen",
    "lat": "53.21667",
    "lng": "10.3"
  },
  {
    "country": "DE",
    "name": "Suderburg",
    "lat": "52.89586",
    "lng": "10.45141"
  },
  {
    "country": "DE",
    "name": "Süderbrarup",
    "lat": "54.63333",
    "lng": "9.78333"
  },
  {
    "country": "DE",
    "name": "Suddendorf",
    "lat": "52.30096",
    "lng": "7.22572"
  },
  {
    "country": "DE",
    "name": "Stützerbach",
    "lat": "50.63333",
    "lng": "10.86667"
  },
  {
    "country": "DE",
    "name": "Stützengrün",
    "lat": "50.53333",
    "lng": "12.53333"
  },
  {
    "country": "DE",
    "name": "Stuttgart",
    "lat": "48.78232",
    "lng": "9.17702"
  },
  {
    "country": "DE",
    "name": "Stulln",
    "lat": "49.41667",
    "lng": "12.13333"
  },
  {
    "country": "DE",
    "name": "Stuhr",
    "lat": "53.03333",
    "lng": "8.75"
  },
  {
    "country": "DE",
    "name": "Stühlingen",
    "lat": "47.7458",
    "lng": "8.44813"
  },
  {
    "country": "DE",
    "name": "Stubenberg",
    "lat": "48.31667",
    "lng": "13.08333"
  },
  {
    "country": "DE",
    "name": "Struvenhütten",
    "lat": "53.86667",
    "lng": "10.05"
  },
  {
    "country": "DE",
    "name": "Struppen",
    "lat": "50.93333",
    "lng": "14.01667"
  },
  {
    "country": "DE",
    "name": "Strullendorf",
    "lat": "49.84429",
    "lng": "10.97208"
  },
  {
    "country": "DE",
    "name": "Stromberg",
    "lat": "50.45779",
    "lng": "7.60041"
  },
  {
    "country": "DE",
    "name": "Ströbeck",
    "lat": "51.91406",
    "lng": "10.94445"
  },
  {
    "country": "DE",
    "name": "Strehla",
    "lat": "51.35248",
    "lng": "13.2266"
  },
  {
    "country": "DE",
    "name": "Straußfurt",
    "lat": "51.16667",
    "lng": "10.98333"
  },
  {
    "country": "DE",
    "name": "Strausberg",
    "lat": "52.57859",
    "lng": "13.88741"
  },
  {
    "country": "DE",
    "name": "Straupitz",
    "lat": "51.91357",
    "lng": "14.12275"
  },
  {
    "country": "DE",
    "name": "Straubing",
    "lat": "48.88126",
    "lng": "12.57385"
  },
  {
    "country": "DE",
    "name": "Straßkirchen",
    "lat": "48.83071",
    "lng": "12.72105"
  },
  {
    "country": "DE",
    "name": "Straßberg",
    "lat": "48.17805",
    "lng": "9.09059"
  },
  {
    "country": "DE",
    "name": "Strasburg",
    "lat": "53.5103",
    "lng": "13.74513"
  },
  {
    "country": "DE",
    "name": "Strande",
    "lat": "54.43333",
    "lng": "10.16667"
  },
  {
    "country": "DE",
    "name": "Stralsund",
    "lat": "54.30911",
    "lng": "13.0818"
  },
  {
    "country": "DE",
    "name": "Stralendorf",
    "lat": "53.57498",
    "lng": "11.30356"
  },
  {
    "country": "DE",
    "name": "Straelen",
    "lat": "51.4419",
    "lng": "6.26639"
  },
  {
    "country": "DE",
    "name": "Stöttwang",
    "lat": "47.88333",
    "lng": "10.71667"
  },
  {
    "country": "DE",
    "name": "Stötten am Auerberg",
    "lat": "47.73871",
    "lng": "10.68881"
  },
  {
    "country": "DE",
    "name": "Stößen",
    "lat": "51.1144",
    "lng": "11.92405"
  },
  {
    "country": "DE",
    "name": "Stoßdorf",
    "lat": "50.78248",
    "lng": "7.25126"
  },
  {
    "country": "DE",
    "name": "Störnstein",
    "lat": "49.73232",
    "lng": "12.20547"
  },
  {
    "country": "DE",
    "name": "Storkow",
    "lat": "52.25662",
    "lng": "13.93337"
  },
  {
    "country": "DE",
    "name": "Stolzenau",
    "lat": "52.51667",
    "lng": "9.06667"
  },
  {
    "country": "DE",
    "name": "Stolpen",
    "lat": "51.04901",
    "lng": "14.07943"
  },
  {
    "country": "DE",
    "name": "Stolpe",
    "lat": "54.13333",
    "lng": "10.21667"
  },
  {
    "country": "DE",
    "name": "Stollberg",
    "lat": "50.70999",
    "lng": "12.78034"
  },
  {
    "country": "DE",
    "name": "Stolberg",
    "lat": "51.57426",
    "lng": "10.95582"
  },
  {
    "country": "DE",
    "name": "Stolberg",
    "lat": "50.77368",
    "lng": "6.22595"
  },
  {
    "country": "DE",
    "name": "Stödtlen",
    "lat": "49",
    "lng": "10.3"
  },
  {
    "country": "DE",
    "name": "Stockstadt am Main",
    "lat": "49.97005",
    "lng": "9.07153"
  },
  {
    "country": "DE",
    "name": "Stockstadt am Rhein",
    "lat": "49.80944",
    "lng": "8.47278"
  },
  {
    "country": "DE",
    "name": "Stöckse",
    "lat": "52.64067",
    "lng": "9.34027"
  },
  {
    "country": "DE",
    "name": "Stockheim",
    "lat": "50.45959",
    "lng": "10.27301"
  },
  {
    "country": "DE",
    "name": "Stockheim",
    "lat": "50.30639",
    "lng": "11.28172"
  },
  {
    "country": "DE",
    "name": "Stockelsdorf",
    "lat": "53.8922",
    "lng": "10.64713"
  },
  {
    "country": "DE",
    "name": "Stockach",
    "lat": "47.85105",
    "lng": "9.0091"
  },
  {
    "country": "DE",
    "name": "Stimpfach",
    "lat": "49.06135",
    "lng": "10.09274"
  },
  {
    "country": "DE",
    "name": "Steyerberg",
    "lat": "52.57017",
    "lng": "9.02423"
  },
  {
    "country": "DE",
    "name": "Stettfeld",
    "lat": "49.9709",
    "lng": "10.7217"
  },
  {
    "country": "DE",
    "name": "Stetten am Kalten Markt",
    "lat": "48.12419",
    "lng": "9.07775"
  },
  {
    "country": "DE",
    "name": "Stetten",
    "lat": "48.02382",
    "lng": "10.44474"
  },
  {
    "country": "DE",
    "name": "Sterup",
    "lat": "54.7265",
    "lng": "9.73572"
  },
  {
    "country": "DE",
    "name": "Sternenfels",
    "lat": "49.05139",
    "lng": "8.85083"
  },
  {
    "country": "DE",
    "name": "Sternberg",
    "lat": "53.71236",
    "lng": "11.82678"
  },
  {
    "country": "DE",
    "name": "Stephansposching",
    "lat": "48.81667",
    "lng": "12.8"
  },
  {
    "country": "DE",
    "name": "Stephanskirchen",
    "lat": "47.85389",
    "lng": "12.1856"
  },
  {
    "country": "DE",
    "name": "Stendal",
    "lat": "52.6069",
    "lng": "11.85867"
  },
  {
    "country": "DE",
    "name": "Stelzenberg",
    "lat": "49.37756",
    "lng": "7.73814"
  },
  {
    "country": "DE",
    "name": "Stellingen",
    "lat": "53.5922",
    "lng": "9.9287"
  },
  {
    "country": "DE",
    "name": "Stelle",
    "lat": "53.38416",
    "lng": "10.11138"
  },
  {
    "country": "DE",
    "name": "Steißlingen",
    "lat": "47.8",
    "lng": "8.93333"
  },
  {
    "country": "DE",
    "name": "Steinwiesen",
    "lat": "50.29444",
    "lng": "11.46295"
  },
  {
    "country": "DE",
    "name": "Steinwenden",
    "lat": "49.45708",
    "lng": "7.52726"
  },
  {
    "country": "DE",
    "name": "Steinweiler",
    "lat": "49.12111",
    "lng": "8.14139"
  },
  {
    "country": "DE",
    "name": "Steinsfeld",
    "lat": "49.41667",
    "lng": "10.21667"
  },
  {
    "country": "DE",
    "name": "Steinmauern",
    "lat": "48.90095",
    "lng": "8.19692"
  },
  {
    "country": "DE",
    "name": "Steinkirchen",
    "lat": "53.56601",
    "lng": "9.61111"
  },
  {
    "country": "DE",
    "name": "Steinkirchen",
    "lat": "48.38333",
    "lng": "12.08333"
  },
  {
    "country": "DE",
    "name": "Steinigtwolmsdorf",
    "lat": "51.06314",
    "lng": "14.3454"
  },
  {
    "country": "DE",
    "name": "Steinhorst",
    "lat": "52.68333",
    "lng": "10.4"
  },
  {
    "country": "DE",
    "name": "Steinhöring",
    "lat": "48.08679",
    "lng": "12.0314"
  },
  {
    "country": "DE",
    "name": "Steinhöfel",
    "lat": "52.4",
    "lng": "14.16667"
  },
  {
    "country": "DE",
    "name": "Steinheim am der Murr",
    "lat": "48.96821",
    "lng": "9.27708"
  },
  {
    "country": "DE",
    "name": "Steinheim am Albuch",
    "lat": "48.6909",
    "lng": "10.06382"
  },
  {
    "country": "DE",
    "name": "Steinheim",
    "lat": "51.87066",
    "lng": "9.09136"
  },
  {
    "country": "DE",
    "name": "Steinheim",
    "lat": "48.01473",
    "lng": "10.16081"
  },
  {
    "country": "DE",
    "name": "Steinheid",
    "lat": "50.46538",
    "lng": "11.08265"
  },
  {
    "country": "DE",
    "name": "Steinhagen",
    "lat": "54.22616",
    "lng": "12.98867"
  },
  {
    "country": "DE",
    "name": "Steinhagen",
    "lat": "52",
    "lng": "8.4"
  },
  {
    "country": "DE",
    "name": "Steingaden",
    "lat": "47.7",
    "lng": "10.86667"
  },
  {
    "country": "DE",
    "name": "Steinfurt",
    "lat": "52.15045",
    "lng": "7.33664"
  },
  {
    "country": "DE",
    "name": "Steinfeld",
    "lat": "52.58596",
    "lng": "8.21417"
  },
  {
    "country": "DE",
    "name": "Steinfeld",
    "lat": "49.95278",
    "lng": "9.66944"
  },
  {
    "country": "DE",
    "name": "Steinfeld",
    "lat": "49.04833",
    "lng": "8.03694"
  },
  {
    "country": "DE",
    "name": "Steinenbronn",
    "lat": "48.66667",
    "lng": "9.11667"
  },
  {
    "country": "DE",
    "name": "Steinen",
    "lat": "47.64446",
    "lng": "7.73914"
  },
  {
    "country": "DE",
    "name": "Steinbergkirche",
    "lat": "54.75463",
    "lng": "9.76069"
  },
  {
    "country": "DE",
    "name": "Steinberg",
    "lat": "54.76667",
    "lng": "9.78333"
  },
  {
    "country": "DE",
    "name": "Stein",
    "lat": "49.41581",
    "lng": "11.01599"
  },
  {
    "country": "DE",
    "name": "Steinbach-Hallenberg",
    "lat": "50.69624",
    "lng": "10.56541"
  },
  {
    "country": "DE",
    "name": "Steinbach am Taunus",
    "lat": "50.16774",
    "lng": "8.57278"
  },
  {
    "country": "DE",
    "name": "Steinbach",
    "lat": "50.83321",
    "lng": "10.36393"
  },
  {
    "country": "DE",
    "name": "Steinbach",
    "lat": "50.15328",
    "lng": "11.65055"
  },
  {
    "country": "DE",
    "name": "Steinau an der Straße",
    "lat": "50.31401",
    "lng": "9.46335"
  },
  {
    "country": "DE",
    "name": "Steinach",
    "lat": "50.43129",
    "lng": "11.15909"
  },
  {
    "country": "DE",
    "name": "Steinach",
    "lat": "48.95417",
    "lng": "12.60709"
  },
  {
    "country": "DE",
    "name": "Steinach",
    "lat": "48.3",
    "lng": "8.05"
  },
  {
    "country": "DE",
    "name": "Steina",
    "lat": "51.2",
    "lng": "14.05"
  },
  {
    "country": "DE",
    "name": "Steimel",
    "lat": "50.61667",
    "lng": "7.63333"
  },
  {
    "country": "DE",
    "name": "Steimbke",
    "lat": "52.65483",
    "lng": "9.39091"
  },
  {
    "country": "DE",
    "name": "Steilshoop",
    "lat": "53.61028",
    "lng": "10.05917"
  },
  {
    "country": "DE",
    "name": "Stiefenhofen",
    "lat": "47.5932",
    "lng": "10.00365"
  },
  {
    "country": "DE",
    "name": "Steglitz",
    "lat": "52.45606",
    "lng": "13.332"
  },
  {
    "country": "DE",
    "name": "Stegen",
    "lat": "47.98333",
    "lng": "7.96667"
  },
  {
    "country": "DE",
    "name": "Stegaurach",
    "lat": "49.86543",
    "lng": "10.84385"
  },
  {
    "country": "DE",
    "name": "Steeden",
    "lat": "50.41539",
    "lng": "8.12748"
  },
  {
    "country": "DE",
    "name": "Stedten",
    "lat": "51.44308",
    "lng": "11.69291"
  },
  {
    "country": "DE",
    "name": "Stedesdorf",
    "lat": "53.63333",
    "lng": "7.66667"
  },
  {
    "country": "DE",
    "name": "Staufenberg",
    "lat": "50.66197",
    "lng": "8.73158"
  },
  {
    "country": "DE",
    "name": "Staufen",
    "lat": "47.75686",
    "lng": "8.21078"
  },
  {
    "country": "DE",
    "name": "Staudernheim",
    "lat": "49.77675",
    "lng": "7.6889"
  },
  {
    "country": "DE",
    "name": "Staudach-Egerndach",
    "lat": "47.78333",
    "lng": "12.48333"
  },
  {
    "country": "DE",
    "name": "Stauchitz",
    "lat": "51.2435",
    "lng": "13.21437"
  },
  {
    "country": "DE",
    "name": "Staßfurt",
    "lat": "51.85186",
    "lng": "11.58508"
  },
  {
    "country": "DE",
    "name": "Starnberg",
    "lat": "48.00193",
    "lng": "11.34416"
  },
  {
    "country": "DE",
    "name": "Stapelfeld",
    "lat": "53.6",
    "lng": "10.21667"
  },
  {
    "country": "DE",
    "name": "Stapelburg",
    "lat": "51.90075",
    "lng": "10.6624"
  },
  {
    "country": "DE",
    "name": "Stamsried",
    "lat": "49.26755",
    "lng": "12.53051"
  },
  {
    "country": "DE",
    "name": "Stammham",
    "lat": "48.29604",
    "lng": "11.86961"
  },
  {
    "country": "DE",
    "name": "Stammham",
    "lat": "48.25",
    "lng": "12.88333"
  },
  {
    "country": "DE",
    "name": "Stammbach",
    "lat": "50.14551",
    "lng": "11.69129"
  },
  {
    "country": "DE",
    "name": "Stallwang",
    "lat": "48.55838",
    "lng": "12.23108"
  },
  {
    "country": "DE",
    "name": "Staig",
    "lat": "48.29998",
    "lng": "9.99138"
  },
  {
    "country": "DE",
    "name": "Stahnsdorf",
    "lat": "52.38333",
    "lng": "13.21667"
  },
  {
    "country": "DE",
    "name": "Bad Staffelstein",
    "lat": "50.10199",
    "lng": "11.00128"
  },
  {
    "country": "DE",
    "name": "Stadum",
    "lat": "54.73333",
    "lng": "9.05"
  },
  {
    "country": "DE",
    "name": "Stadt Wehlen",
    "lat": "50.95821",
    "lng": "14.03091"
  },
  {
    "country": "DE",
    "name": "Stadtsteinach",
    "lat": "50.16433",
    "lng": "11.50349"
  },
  {
    "country": "DE",
    "name": "Stadtroda",
    "lat": "50.85684",
    "lng": "11.72677"
  },
  {
    "country": "DE",
    "name": "Stadtprozelten",
    "lat": "49.78466",
    "lng": "9.41184"
  },
  {
    "country": "DE",
    "name": "Stadtoldendorf",
    "lat": "51.88242",
    "lng": "9.6265"
  },
  {
    "country": "DE",
    "name": "Stadtlohn",
    "lat": "51.99399",
    "lng": "6.91918"
  },
  {
    "country": "DE",
    "name": "Stadtlengsfeld",
    "lat": "50.78329",
    "lng": "10.12918"
  },
  {
    "country": "DE",
    "name": "Stadtlauringen",
    "lat": "50.18708",
    "lng": "10.36164"
  },
  {
    "country": "DE",
    "name": "Stadtkyll",
    "lat": "50.35",
    "lng": "6.53333"
  },
  {
    "country": "DE",
    "name": "Stadtilm",
    "lat": "50.77596",
    "lng": "11.08262"
  },
  {
    "country": "DE",
    "name": "Stadthagen",
    "lat": "52.32333",
    "lng": "9.20311"
  },
  {
    "country": "DE",
    "name": "Stadtbergen",
    "lat": "48.36641",
    "lng": "10.84636"
  },
  {
    "country": "DE",
    "name": "Stadtallendorf",
    "lat": "50.82261",
    "lng": "9.01294"
  },
  {
    "country": "DE",
    "name": "Stadensen",
    "lat": "52.87571",
    "lng": "10.55619"
  },
  {
    "country": "DE",
    "name": "Stadelhofen",
    "lat": "50.00317",
    "lng": "11.19757"
  },
  {
    "country": "DE",
    "name": "Stade",
    "lat": "53.59337",
    "lng": "9.47629"
  },
  {
    "country": "DE",
    "name": "Stäbelow",
    "lat": "54.04119",
    "lng": "12.02336"
  },
  {
    "country": "DE",
    "name": "Staaken",
    "lat": "52.53661",
    "lng": "13.15057"
  },
  {
    "country": "DE",
    "name": "Sprockhövel",
    "lat": "51.34669",
    "lng": "7.24343"
  },
  {
    "country": "DE",
    "name": "Springe",
    "lat": "52.20845",
    "lng": "9.55416"
  },
  {
    "country": "DE",
    "name": "Sprendlingen",
    "lat": "49.86667",
    "lng": "7.98333"
  },
  {
    "country": "DE",
    "name": "Spreenhagen",
    "lat": "52.34325",
    "lng": "13.87663"
  },
  {
    "country": "DE",
    "name": "Sprakensehl",
    "lat": "52.76668",
    "lng": "10.49177"
  },
  {
    "country": "DE",
    "name": "Spraitbach",
    "lat": "48.88065",
    "lng": "9.76217"
  },
  {
    "country": "DE",
    "name": "Spornitz",
    "lat": "53.40749",
    "lng": "11.71864"
  },
  {
    "country": "DE",
    "name": "Spiesheim",
    "lat": "49.81028",
    "lng": "8.1275"
  },
  {
    "country": "DE",
    "name": "Spiesen-Elversberg",
    "lat": "49.31667",
    "lng": "7.13333"
  },
  {
    "country": "DE",
    "name": "Spiegelberg",
    "lat": "49.04083",
    "lng": "9.44444"
  },
  {
    "country": "DE",
    "name": "Speyer",
    "lat": "49.32083",
    "lng": "8.43111"
  },
  {
    "country": "DE",
    "name": "Spergau",
    "lat": "51.29347",
    "lng": "12.02292"
  },
  {
    "country": "DE",
    "name": "Sperenberg",
    "lat": "52.14113",
    "lng": "13.365"
  },
  {
    "country": "DE",
    "name": "Spenge",
    "lat": "52.14021",
    "lng": "8.48475"
  },
  {
    "country": "DE",
    "name": "Spelle",
    "lat": "52.36667",
    "lng": "7.46667"
  },
  {
    "country": "DE",
    "name": "Speinshart",
    "lat": "49.79002",
    "lng": "11.81949"
  },
  {
    "country": "DE",
    "name": "Speichersdorf",
    "lat": "49.87133",
    "lng": "11.78123"
  },
  {
    "country": "DE",
    "name": "Speicher",
    "lat": "49.93333",
    "lng": "6.63333"
  },
  {
    "country": "DE",
    "name": "Spechbach",
    "lat": "49.34639",
    "lng": "8.88333"
  },
  {
    "country": "DE",
    "name": "Sparneck",
    "lat": "50.16214",
    "lng": "11.84349"
  },
  {
    "country": "DE",
    "name": "Spardorf",
    "lat": "49.60854",
    "lng": "11.05585"
  },
  {
    "country": "DE",
    "name": "Spangenberg",
    "lat": "51.11644",
    "lng": "9.6627"
  },
  {
    "country": "DE",
    "name": "Spalt",
    "lat": "49.17553",
    "lng": "10.92453"
  },
  {
    "country": "DE",
    "name": "Spaichingen",
    "lat": "48.07477",
    "lng": "8.73508"
  },
  {
    "country": "DE",
    "name": "Spabrücken",
    "lat": "49.9",
    "lng": "7.71667"
  },
  {
    "country": "DE",
    "name": "Soyen",
    "lat": "48.10808",
    "lng": "12.21006"
  },
  {
    "country": "DE",
    "name": "Sottrum",
    "lat": "53.11667",
    "lng": "9.23333"
  },
  {
    "country": "DE",
    "name": "Sosa",
    "lat": "50.49917",
    "lng": "12.6512"
  },
  {
    "country": "DE",
    "name": "Sörup",
    "lat": "54.71667",
    "lng": "9.66667"
  },
  {
    "country": "DE",
    "name": "Sörgenloch",
    "lat": "49.88306",
    "lng": "8.20111"
  },
  {
    "country": "DE",
    "name": "Sontra",
    "lat": "51.07171",
    "lng": "9.93558"
  },
  {
    "country": "DE",
    "name": "Sonthofen",
    "lat": "47.51821",
    "lng": "10.28262"
  },
  {
    "country": "DE",
    "name": "Sontheim an der Brenz",
    "lat": "48.55235",
    "lng": "10.29097"
  },
  {
    "country": "DE",
    "name": "Sontheim",
    "lat": "48.00704",
    "lng": "10.35461"
  },
  {
    "country": "DE",
    "name": "Sonsbeck",
    "lat": "51.60741",
    "lng": "6.37916"
  },
  {
    "country": "DE",
    "name": "Sonnewalde",
    "lat": "51.69223",
    "lng": "13.6473"
  },
  {
    "country": "DE",
    "name": "Sonnen",
    "lat": "48.68333",
    "lng": "13.71667"
  },
  {
    "country": "DE",
    "name": "Sonnefeld",
    "lat": "50.21667",
    "lng": "11.13333"
  },
  {
    "country": "DE",
    "name": "Sonneborn",
    "lat": "50.9927",
    "lng": "10.59173"
  },
  {
    "country": "DE",
    "name": "Sonneberg",
    "lat": "50.3592",
    "lng": "11.17463"
  },
  {
    "country": "DE",
    "name": "Sondheim vor der Rhön",
    "lat": "50.4651",
    "lng": "10.15675"
  },
  {
    "country": "DE",
    "name": "Sondershausen",
    "lat": "51.36973",
    "lng": "10.87011"
  },
  {
    "country": "DE",
    "name": "Sommersdorf",
    "lat": "52.16667",
    "lng": "11.08333"
  },
  {
    "country": "DE",
    "name": "Sommerkahl",
    "lat": "50.06961",
    "lng": "9.25676"
  },
  {
    "country": "DE",
    "name": "Sommerhausen",
    "lat": "49.70361",
    "lng": "10.02605"
  },
  {
    "country": "DE",
    "name": "Sömmerda",
    "lat": "51.15914",
    "lng": "11.11524"
  },
  {
    "country": "DE",
    "name": "Sommerach",
    "lat": "49.82923",
    "lng": "10.20792"
  },
  {
    "country": "DE",
    "name": "Soltendieck",
    "lat": "52.87369",
    "lng": "10.76162"
  },
  {
    "country": "DE",
    "name": "Soltau",
    "lat": "52.98638",
    "lng": "9.84338"
  },
  {
    "country": "DE",
    "name": "Solnhofen",
    "lat": "48.89582",
    "lng": "10.9956"
  },
  {
    "country": "DE",
    "name": "Sollstedt",
    "lat": "51.30976",
    "lng": "10.4881"
  },
  {
    "country": "DE",
    "name": "Solingen",
    "lat": "51.17343",
    "lng": "7.0845"
  },
  {
    "country": "DE",
    "name": "Sölden",
    "lat": "47.93333",
    "lng": "7.81667"
  },
  {
    "country": "DE",
    "name": "Sohren",
    "lat": "49.93333",
    "lng": "7.31667"
  },
  {
    "country": "DE",
    "name": "Söhlde",
    "lat": "52.18898",
    "lng": "10.23239"
  },
  {
    "country": "DE",
    "name": "Sohland am Rotstein",
    "lat": "51.11643",
    "lng": "14.78372"
  },
  {
    "country": "DE",
    "name": "Sohland",
    "lat": "51.04089",
    "lng": "14.41897"
  },
  {
    "country": "DE",
    "name": "Sögel",
    "lat": "52.85",
    "lng": "7.51667"
  },
  {
    "country": "DE",
    "name": "Soest",
    "lat": "51.57558",
    "lng": "8.10619"
  },
  {
    "country": "DE",
    "name": "Soderstorf",
    "lat": "53.14275",
    "lng": "10.14807"
  },
  {
    "country": "DE",
    "name": "Södel",
    "lat": "50.39382",
    "lng": "8.80474"
  },
  {
    "country": "DE",
    "name": "Söchtenau",
    "lat": "47.93118",
    "lng": "12.22959"
  },
  {
    "country": "DE",
    "name": "Sitzendorf",
    "lat": "50.63182",
    "lng": "11.17215"
  },
  {
    "country": "DE",
    "name": "Sittensen",
    "lat": "53.27615",
    "lng": "9.50429"
  },
  {
    "country": "DE",
    "name": "Sipplingen",
    "lat": "47.79678",
    "lng": "9.09737"
  },
  {
    "country": "DE",
    "name": "Sippersfeld",
    "lat": "49.55",
    "lng": "7.93333"
  },
  {
    "country": "DE",
    "name": "Sinzing",
    "lat": "49",
    "lng": "12.03333"
  },
  {
    "country": "DE",
    "name": "Sinzig",
    "lat": "50.54384",
    "lng": "7.24639"
  },
  {
    "country": "DE",
    "name": "Sinzheim",
    "lat": "48.76667",
    "lng": "8.16667"
  },
  {
    "country": "DE",
    "name": "Sinsheim",
    "lat": "49.2529",
    "lng": "8.87867"
  },
  {
    "country": "DE",
    "name": "Sinnersdorf",
    "lat": "51.02445",
    "lng": "6.81787"
  },
  {
    "country": "DE",
    "name": "Sinn",
    "lat": "50.65",
    "lng": "8.33333"
  },
  {
    "country": "DE",
    "name": "Singhofen",
    "lat": "50.2744",
    "lng": "7.83333"
  },
  {
    "country": "DE",
    "name": "Singen",
    "lat": "47.75935",
    "lng": "8.8403"
  },
  {
    "country": "DE",
    "name": "Sindelsdorf",
    "lat": "47.72458",
    "lng": "11.33295"
  },
  {
    "country": "DE",
    "name": "Sindelfingen",
    "lat": "48.7",
    "lng": "9.01667"
  },
  {
    "country": "DE",
    "name": "Simmozheim",
    "lat": "48.75127",
    "lng": "8.81142"
  },
  {
    "country": "DE",
    "name": "Simmersfeld",
    "lat": "48.61667",
    "lng": "8.51667"
  },
  {
    "country": "DE",
    "name": "Simmern",
    "lat": "50.38914",
    "lng": "7.67396"
  },
  {
    "country": "DE",
    "name": "Simmern",
    "lat": "49.98198",
    "lng": "7.52351"
  },
  {
    "country": "DE",
    "name": "Simmertal",
    "lat": "49.80981",
    "lng": "7.52282"
  },
  {
    "country": "DE",
    "name": "Simmerath",
    "lat": "50.6",
    "lng": "6.3"
  },
  {
    "country": "DE",
    "name": "Simmelsdorf",
    "lat": "49.59775",
    "lng": "11.33901"
  },
  {
    "country": "DE",
    "name": "Simbach am Inn",
    "lat": "48.26548",
    "lng": "13.02309"
  },
  {
    "country": "DE",
    "name": "Simbach",
    "lat": "48.56606",
    "lng": "12.73888"
  },
  {
    "country": "DE",
    "name": "Sillenstede",
    "lat": "53.57437",
    "lng": "7.985"
  },
  {
    "country": "DE",
    "name": "Silberstedt",
    "lat": "54.51667",
    "lng": "9.38333"
  },
  {
    "country": "DE",
    "name": "Sigmarszell",
    "lat": "47.58333",
    "lng": "9.76667"
  },
  {
    "country": "DE",
    "name": "Sigmaringendorf",
    "lat": "48.06586",
    "lng": "9.26208"
  },
  {
    "country": "DE",
    "name": "Sigmaringen",
    "lat": "48.08829",
    "lng": "9.23033"
  },
  {
    "country": "DE",
    "name": "Siggelkow",
    "lat": "53.38742",
    "lng": "11.93802"
  },
  {
    "country": "DE",
    "name": "Sieverstedt",
    "lat": "54.64145",
    "lng": "9.46949"
  },
  {
    "country": "DE",
    "name": "Sievershütten",
    "lat": "53.84238",
    "lng": "10.11216"
  },
  {
    "country": "DE",
    "name": "Siersleben",
    "lat": "51.60411",
    "lng": "11.54334"
  },
  {
    "country": "DE",
    "name": "Siershahn",
    "lat": "50.48639",
    "lng": "7.77972"
  },
  {
    "country": "DE",
    "name": "Siersdorf",
    "lat": "50.89827",
    "lng": "6.22684"
  },
  {
    "country": "DE",
    "name": "Sierksdorf",
    "lat": "54.06667",
    "lng": "10.76667"
  },
  {
    "country": "DE",
    "name": "Siemensstadt",
    "lat": "52.54053",
    "lng": "13.26294"
  },
  {
    "country": "DE",
    "name": "Sielenbach",
    "lat": "48.4",
    "lng": "11.16667"
  },
  {
    "country": "DE",
    "name": "Siek",
    "lat": "53.63333",
    "lng": "10.3"
  },
  {
    "country": "DE",
    "name": "Siegsdorf",
    "lat": "47.82278",
    "lng": "12.64277"
  },
  {
    "country": "DE",
    "name": "Siegenburg",
    "lat": "48.75421",
    "lng": "11.84831"
  },
  {
    "country": "DE",
    "name": "Siegen",
    "lat": "50.87481",
    "lng": "8.02431"
  },
  {
    "country": "DE",
    "name": "Siegelsbach",
    "lat": "49.26972",
    "lng": "9.08972"
  },
  {
    "country": "DE",
    "name": "Siegburg",
    "lat": "50.80019",
    "lng": "7.20769"
  },
  {
    "country": "DE",
    "name": "Siefersheim",
    "lat": "49.8",
    "lng": "7.95"
  },
  {
    "country": "DE",
    "name": "Siedenburg",
    "lat": "52.69293",
    "lng": "8.93961"
  },
  {
    "country": "DE",
    "name": "Siebeldingen",
    "lat": "49.20889",
    "lng": "8.05139"
  },
  {
    "country": "DE",
    "name": "Sickenhausen",
    "lat": "48.53252",
    "lng": "9.18114"
  },
  {
    "country": "DE",
    "name": "Sibbesse",
    "lat": "52.05",
    "lng": "9.9"
  },
  {
    "country": "DE",
    "name": "Seyda",
    "lat": "51.88163",
    "lng": "12.90812"
  },
  {
    "country": "DE",
    "name": "Seybothenreuth",
    "lat": "49.89372",
    "lng": "11.70531"
  },
  {
    "country": "DE",
    "name": "Sexau",
    "lat": "48.10209",
    "lng": "7.90757"
  },
  {
    "country": "DE",
    "name": "Seulingen",
    "lat": "51.54129",
    "lng": "10.16263"
  },
  {
    "country": "DE",
    "name": "Seukendorf",
    "lat": "49.48844",
    "lng": "10.87999"
  },
  {
    "country": "DE",
    "name": "Seubersdorf",
    "lat": "49.16212",
    "lng": "11.62714"
  },
  {
    "country": "DE",
    "name": "Seth",
    "lat": "53.84718",
    "lng": "10.17421"
  },
  {
    "country": "DE",
    "name": "Seßlach",
    "lat": "50.18969",
    "lng": "10.84197"
  },
  {
    "country": "DE",
    "name": "Sersheim",
    "lat": "48.96667",
    "lng": "9.01667"
  },
  {
    "country": "DE",
    "name": "Serrig",
    "lat": "49.57519",
    "lng": "6.57454"
  },
  {
    "country": "DE",
    "name": "Sennfeld",
    "lat": "50.03895",
    "lng": "10.25986"
  },
  {
    "country": "DE",
    "name": "Sennewitz",
    "lat": "51.54326",
    "lng": "11.95218"
  },
  {
    "country": "DE",
    "name": "Sengenthal",
    "lat": "49.23333",
    "lng": "11.46667"
  },
  {
    "country": "DE",
    "name": "Senftenberg",
    "lat": "51.52517",
    "lng": "14.00164"
  },
  {
    "country": "DE",
    "name": "Sendenhorst",
    "lat": "51.84303",
    "lng": "7.82996"
  },
  {
    "country": "DE",
    "name": "Senden",
    "lat": "51.85645",
    "lng": "7.48327"
  },
  {
    "country": "DE",
    "name": "Senden",
    "lat": "48.32441",
    "lng": "10.04442"
  },
  {
    "country": "DE",
    "name": "Sembach",
    "lat": "49.51177",
    "lng": "7.86661"
  },
  {
    "country": "DE",
    "name": "Selzen",
    "lat": "49.86056",
    "lng": "8.25528"
  },
  {
    "country": "DE",
    "name": "Selters",
    "lat": "50.53253",
    "lng": "7.75577"
  },
  {
    "country": "DE",
    "name": "Selters",
    "lat": "50.51681",
    "lng": "8.28953"
  },
  {
    "country": "DE",
    "name": "Selsingen",
    "lat": "53.37329",
    "lng": "9.21289"
  },
  {
    "country": "DE",
    "name": "Selmsdorf",
    "lat": "53.88224",
    "lng": "10.85997"
  },
  {
    "country": "DE",
    "name": "Selm",
    "lat": "51.69689",
    "lng": "7.46809"
  },
  {
    "country": "DE",
    "name": "Sellin",
    "lat": "53.88495",
    "lng": "11.6079"
  },
  {
    "country": "DE",
    "name": "Seligenstadt",
    "lat": "50.0432",
    "lng": "8.97394"
  },
  {
    "country": "DE",
    "name": "Selent",
    "lat": "54.28893",
    "lng": "10.42702"
  },
  {
    "country": "DE",
    "name": "Selbitz",
    "lat": "50.31702",
    "lng": "11.75019"
  },
  {
    "country": "DE",
    "name": "Selb",
    "lat": "50.17058",
    "lng": "12.13054"
  },
  {
    "country": "DE",
    "name": "Seinsheim",
    "lat": "49.64073",
    "lng": "10.22038"
  },
  {
    "country": "DE",
    "name": "Seifhennersdorf",
    "lat": "50.93492",
    "lng": "14.60194"
  },
  {
    "country": "DE",
    "name": "Seibersbach",
    "lat": "49.96667",
    "lng": "7.71667"
  },
  {
    "country": "DE",
    "name": "Sehnde",
    "lat": "52.31394",
    "lng": "9.9682"
  },
  {
    "country": "DE",
    "name": "Sehlen",
    "lat": "54.37971",
    "lng": "13.38907"
  },
  {
    "country": "DE",
    "name": "Sehlem",
    "lat": "52.01236",
    "lng": "9.97593"
  },
  {
    "country": "DE",
    "name": "Sehlde",
    "lat": "52.03887",
    "lng": "10.26569"
  },
  {
    "country": "DE",
    "name": "Seggebruch",
    "lat": "52.3005",
    "lng": "9.09462"
  },
  {
    "country": "DE",
    "name": "Seevetal",
    "lat": "53.4",
    "lng": "9.96667"
  },
  {
    "country": "DE",
    "name": "Seeshaupt",
    "lat": "47.82468",
    "lng": "11.30219"
  },
  {
    "country": "DE",
    "name": "Seesen",
    "lat": "51.89095",
    "lng": "10.17847"
  },
  {
    "country": "DE",
    "name": "Seelze",
    "lat": "52.39635",
    "lng": "9.59727"
  },
  {
    "country": "DE",
    "name": "Seelow",
    "lat": "52.53392",
    "lng": "14.38128"
  },
  {
    "country": "DE",
    "name": "Seelitz",
    "lat": "51.03333",
    "lng": "12.81667"
  },
  {
    "country": "DE",
    "name": "Seelingstädt",
    "lat": "50.77266",
    "lng": "12.24361"
  },
  {
    "country": "DE",
    "name": "Seelbach",
    "lat": "48.31055",
    "lng": "7.94069"
  },
  {
    "country": "DE",
    "name": "Seehof",
    "lat": "53.69249",
    "lng": "11.43256"
  },
  {
    "country": "DE",
    "name": "Seehausen am Staffelsee",
    "lat": "47.68928",
    "lng": "11.18498"
  },
  {
    "country": "DE",
    "name": "Seehausen",
    "lat": "52.88872",
    "lng": "11.75236"
  },
  {
    "country": "DE",
    "name": "Seehausen",
    "lat": "52.10287",
    "lng": "11.29153"
  },
  {
    "country": "DE",
    "name": "Seeg",
    "lat": "47.65",
    "lng": "10.6"
  },
  {
    "country": "DE",
    "name": "Seefeld",
    "lat": "48.03505",
    "lng": "11.21395"
  },
  {
    "country": "DE",
    "name": "Seedorf",
    "lat": "54.05",
    "lng": "10.41667"
  },
  {
    "country": "DE",
    "name": "Seedorf",
    "lat": "48.24908",
    "lng": "8.48993"
  },
  {
    "country": "DE",
    "name": "Seeburg",
    "lat": "51.56667",
    "lng": "10.15"
  },
  {
    "country": "DE",
    "name": "Seebergen",
    "lat": "50.92077",
    "lng": "10.7992"
  },
  {
    "country": "DE",
    "name": "Seebad Heringsdorf",
    "lat": "53.95379",
    "lng": "14.16852"
  },
  {
    "country": "DE",
    "name": "Seebad Bansin",
    "lat": "53.97102",
    "lng": "14.14147"
  },
  {
    "country": "DE",
    "name": "Seebach",
    "lat": "51.16506",
    "lng": "10.51428"
  },
  {
    "country": "DE",
    "name": "Seebach",
    "lat": "48.57621",
    "lng": "8.17048"
  },
  {
    "country": "DE",
    "name": "Seckach",
    "lat": "49.44222",
    "lng": "9.33417"
  },
  {
    "country": "DE",
    "name": "Seck",
    "lat": "50.57722",
    "lng": "8.04972"
  },
  {
    "country": "DE",
    "name": "Sebnitz",
    "lat": "50.9754",
    "lng": "14.27579"
  },
  {
    "country": "DE",
    "name": "Schwörstadt",
    "lat": "47.59314",
    "lng": "7.8784"
  },
  {
    "country": "DE",
    "name": "Schwindegg",
    "lat": "48.27155",
    "lng": "12.25978"
  },
  {
    "country": "DE",
    "name": "Schwieberdingen",
    "lat": "48.87644",
    "lng": "9.07439"
  },
  {
    "country": "DE",
    "name": "Schwetzingen",
    "lat": "49.38217",
    "lng": "8.5823"
  },
  {
    "country": "DE",
    "name": "Schwerte",
    "lat": "51.44387",
    "lng": "7.5675"
  },
  {
    "country": "DE",
    "name": "Schwerin",
    "lat": "53.62937",
    "lng": "11.41316"
  },
  {
    "country": "DE",
    "name": "Schwepnitz",
    "lat": "51.32809",
    "lng": "13.95772"
  },
  {
    "country": "DE",
    "name": "Schwenningen",
    "lat": "48.65",
    "lng": "10.65"
  },
  {
    "country": "DE",
    "name": "Schwenningen",
    "lat": "48.1",
    "lng": "9"
  },
  {
    "country": "DE",
    "name": "Schwendi",
    "lat": "48.17424",
    "lng": "9.97541"
  },
  {
    "country": "DE",
    "name": "Schwelm",
    "lat": "51.28635",
    "lng": "7.29388"
  },
  {
    "country": "DE",
    "name": "Schweitenkirchen",
    "lat": "48.50333",
    "lng": "11.60451"
  },
  {
    "country": "DE",
    "name": "Schweinfurt",
    "lat": "50.04937",
    "lng": "10.22175"
  },
  {
    "country": "DE",
    "name": "Schweina",
    "lat": "50.82502",
    "lng": "10.33788"
  },
  {
    "country": "DE",
    "name": "Schweich",
    "lat": "49.82215",
    "lng": "6.75256"
  },
  {
    "country": "DE",
    "name": "Schwegenheim",
    "lat": "49.27",
    "lng": "8.32861"
  },
  {
    "country": "DE",
    "name": "Schwedt (Oder)",
    "lat": "53.05963",
    "lng": "14.28154"
  },
  {
    "country": "DE",
    "name": "Schwedelbach",
    "lat": "49.49557",
    "lng": "7.59366"
  },
  {
    "country": "DE",
    "name": "Schwebheim",
    "lat": "49.99036",
    "lng": "10.24776"
  },
  {
    "country": "DE",
    "name": "Schwarzhofen",
    "lat": "49.37749",
    "lng": "12.3449"
  },
  {
    "country": "DE",
    "name": "Schwarzheide",
    "lat": "51.47671",
    "lng": "13.85559"
  },
  {
    "country": "DE",
    "name": "Schwarzenfeld",
    "lat": "49.38774",
    "lng": "12.13484"
  },
  {
    "country": "DE",
    "name": "Schwarzenbruck",
    "lat": "49.35778",
    "lng": "11.24333"
  },
  {
    "country": "DE",
    "name": "Schwarzenborn",
    "lat": "50.90977",
    "lng": "9.44658"
  },
  {
    "country": "DE",
    "name": "Schwarzenberg",
    "lat": "50.53791",
    "lng": "12.78522"
  },
  {
    "country": "DE",
    "name": "Schwarzenbek",
    "lat": "53.50303",
    "lng": "10.48055"
  },
  {
    "country": "DE",
    "name": "Schwarzenbach an der Saale",
    "lat": "50.22279",
    "lng": "11.93504"
  },
  {
    "country": "DE",
    "name": "Schwarzenbach",
    "lat": "49.83876",
    "lng": "12.38005"
  },
  {
    "country": "DE",
    "name": "Spiegelau",
    "lat": "48.91517",
    "lng": "13.36229"
  },
  {
    "country": "DE",
    "name": "Schwarzach",
    "lat": "48.91567",
    "lng": "12.81143"
  },
  {
    "country": "DE",
    "name": "Schwarzach",
    "lat": "48.74738",
    "lng": "8.03738"
  },
  {
    "country": "DE",
    "name": "Schwarza",
    "lat": "50.85386",
    "lng": "11.32433"
  },
  {
    "country": "DE",
    "name": "Schwarmstedt",
    "lat": "52.67794",
    "lng": "9.61767"
  },
  {
    "country": "DE",
    "name": "Schwarme",
    "lat": "52.9",
    "lng": "9.01667"
  },
  {
    "country": "DE",
    "name": "Schwangau",
    "lat": "47.57722",
    "lng": "10.73416"
  },
  {
    "country": "DE",
    "name": "Schwanfeld",
    "lat": "49.92166",
    "lng": "10.13866"
  },
  {
    "country": "DE",
    "name": "Schwanewede",
    "lat": "53.23333",
    "lng": "8.6"
  },
  {
    "country": "DE",
    "name": "Schwanebeck",
    "lat": "51.9679",
    "lng": "11.12393"
  },
  {
    "country": "DE",
    "name": "Schwandorf in Bayern",
    "lat": "49.32534",
    "lng": "12.1098"
  },
  {
    "country": "DE",
    "name": "Schwalmtal",
    "lat": "51.21667",
    "lng": "6.26667"
  },
  {
    "country": "DE",
    "name": "Schwalmtal",
    "lat": "50.68333",
    "lng": "9.21667"
  },
  {
    "country": "DE",
    "name": "Schwalmstadt",
    "lat": "50.93333",
    "lng": "9.21667"
  },
  {
    "country": "DE",
    "name": "Schwallungen",
    "lat": "50.6926",
    "lng": "10.35706"
  },
  {
    "country": "DE",
    "name": "Schwalbach",
    "lat": "50.49672",
    "lng": "8.46943"
  },
  {
    "country": "DE",
    "name": "Schwalbach am Taunus",
    "lat": "50.15",
    "lng": "8.53333"
  },
  {
    "country": "DE",
    "name": "Schwalbach",
    "lat": "49.3",
    "lng": "6.81667"
  },
  {
    "country": "DE",
    "name": "Schwaikheim",
    "lat": "48.87733",
    "lng": "9.34958"
  },
  {
    "country": "DE",
    "name": "Schwaigern",
    "lat": "49.14494",
    "lng": "9.05525"
  },
  {
    "country": "DE",
    "name": "Schwaig",
    "lat": "49.46955",
    "lng": "11.20064"
  },
  {
    "country": "DE",
    "name": "Schwaförden",
    "lat": "52.73775",
    "lng": "8.83026"
  },
  {
    "country": "DE",
    "name": "Schwabstedt",
    "lat": "54.39705",
    "lng": "9.18646"
  },
  {
    "country": "DE",
    "name": "Schwabsoien",
    "lat": "47.83333",
    "lng": "10.83333"
  },
  {
    "country": "DE",
    "name": "Schwabmünchen",
    "lat": "48.17928",
    "lng": "10.75675"
  },
  {
    "country": "DE",
    "name": "Schwäbisch Hall",
    "lat": "49.11127",
    "lng": "9.73908"
  },
  {
    "country": "DE",
    "name": "Schwäbisch Gmünd",
    "lat": "48.79947",
    "lng": "9.79809"
  },
  {
    "country": "DE",
    "name": "Schwabhausen",
    "lat": "48.40157",
    "lng": "11.35729"
  },
  {
    "country": "DE",
    "name": "Schwabenheim",
    "lat": "49.92879",
    "lng": "8.09525"
  },
  {
    "country": "DE",
    "name": "Schwabach",
    "lat": "49.33047",
    "lng": "11.02346"
  },
  {
    "country": "DE",
    "name": "Schwaan",
    "lat": "53.94047",
    "lng": "12.10715"
  },
  {
    "country": "DE",
    "name": "Schüttorf",
    "lat": "52.32281",
    "lng": "7.22176"
  },
  {
    "country": "DE",
    "name": "Schutterwald",
    "lat": "48.45",
    "lng": "7.88333"
  },
  {
    "country": "DE",
    "name": "Schuttertal",
    "lat": "48.26667",
    "lng": "7.95"
  },
  {
    "country": "DE",
    "name": "Bad Schussenried",
    "lat": "48.00468",
    "lng": "9.65741"
  },
  {
    "country": "DE",
    "name": "Schulzendorf",
    "lat": "52.35818",
    "lng": "13.59842"
  },
  {
    "country": "DE",
    "name": "Schülp",
    "lat": "54.25896",
    "lng": "9.63034"
  },
  {
    "country": "DE",
    "name": "Schuby",
    "lat": "54.51667",
    "lng": "9.48333"
  },
  {
    "country": "DE",
    "name": "Schrozberg",
    "lat": "49.34528",
    "lng": "9.97944"
  },
  {
    "country": "DE",
    "name": "Schrobenhausen",
    "lat": "48.56067",
    "lng": "11.26071"
  },
  {
    "country": "DE",
    "name": "Schriesheim",
    "lat": "49.47372",
    "lng": "8.6636"
  },
  {
    "country": "DE",
    "name": "Schrecksbach",
    "lat": "50.83333",
    "lng": "9.28333"
  },
  {
    "country": "DE",
    "name": "Schraplau",
    "lat": "51.4375",
    "lng": "11.66823"
  },
  {
    "country": "DE",
    "name": "Schramberg",
    "lat": "48.22399",
    "lng": "8.38583"
  },
  {
    "country": "DE",
    "name": "Schotten",
    "lat": "50.50346",
    "lng": "9.12516"
  },
  {
    "country": "DE",
    "name": "Schortens",
    "lat": "53.53333",
    "lng": "7.95"
  },
  {
    "country": "DE",
    "name": "Schornsheim",
    "lat": "49.84583",
    "lng": "8.175"
  },
  {
    "country": "DE",
    "name": "Schorndorf",
    "lat": "49.16041",
    "lng": "12.59316"
  },
  {
    "country": "DE",
    "name": "Schorndorf",
    "lat": "48.80537",
    "lng": "9.52721"
  },
  {
    "country": "DE",
    "name": "Schöppingen",
    "lat": "52.1",
    "lng": "7.23333"
  },
  {
    "country": "DE",
    "name": "Schöppenstedt",
    "lat": "52.14308",
    "lng": "10.7745"
  },
  {
    "country": "DE",
    "name": "Schopp",
    "lat": "49.35",
    "lng": "7.68333"
  },
  {
    "country": "DE",
    "name": "Schopfloch",
    "lat": "49.11917",
    "lng": "10.30774"
  },
  {
    "country": "DE",
    "name": "Schopfloch",
    "lat": "48.45477",
    "lng": "8.55131"
  },
  {
    "country": "DE",
    "name": "Schopfheim",
    "lat": "47.65105",
    "lng": "7.82089"
  },
  {
    "country": "DE",
    "name": "Schönwalde am Bungsberg",
    "lat": "54.18333",
    "lng": "10.75"
  },
  {
    "country": "DE",
    "name": "Schönwald",
    "lat": "50.1997",
    "lng": "12.08503"
  },
  {
    "country": "DE",
    "name": "Schönwald im Schwarzwald",
    "lat": "48.10549",
    "lng": "8.20387"
  },
  {
    "country": "DE",
    "name": "Schonungen",
    "lat": "50.05008",
    "lng": "10.30809"
  },
  {
    "country": "DE",
    "name": "Schönthal",
    "lat": "49.35",
    "lng": "12.6"
  },
  {
    "country": "DE",
    "name": "Schonstett",
    "lat": "47.98333",
    "lng": "12.25"
  },
  {
    "country": "DE",
    "name": "Schönsee",
    "lat": "49.5103",
    "lng": "12.54763"
  },
  {
    "country": "DE",
    "name": "Schönkirchen",
    "lat": "54.33333",
    "lng": "10.23333"
  },
  {
    "country": "DE",
    "name": "Schöningen",
    "lat": "52.13802",
    "lng": "10.96745"
  },
  {
    "country": "DE",
    "name": "Schönheide",
    "lat": "50.50458",
    "lng": "12.52158"
  },
  {
    "country": "DE",
    "name": "Schönhausen",
    "lat": "52.58076",
    "lng": "12.03923"
  },
  {
    "country": "DE",
    "name": "Schöngeising",
    "lat": "48.14135",
    "lng": "11.20399"
  },
  {
    "country": "DE",
    "name": "Schongau",
    "lat": "47.8124",
    "lng": "10.89664"
  },
  {
    "country": "DE",
    "name": "Schönfeld",
    "lat": "51.3",
    "lng": "13.7"
  },
  {
    "country": "DE",
    "name": "Schönewalde",
    "lat": "51.67901",
    "lng": "13.60247"
  },
  {
    "country": "DE",
    "name": "Schöneiche",
    "lat": "52.47286",
    "lng": "13.69226"
  },
  {
    "country": "DE",
    "name": "Schönefeld",
    "lat": "52.38897",
    "lng": "13.50374"
  },
  {
    "country": "DE",
    "name": "Schönecken",
    "lat": "50.15909",
    "lng": "6.4682"
  },
  {
    "country": "DE",
    "name": "Schöneck",
    "lat": "50.39052",
    "lng": "12.32731"
  },
  {
    "country": "DE",
    "name": "Schöneberg",
    "lat": "52.46667",
    "lng": "13.35"
  },
  {
    "country": "DE",
    "name": "Schönebeck",
    "lat": "52.01682",
    "lng": "11.7307"
  },
  {
    "country": "DE",
    "name": "Schondra",
    "lat": "50.26814",
    "lng": "9.86277"
  },
  {
    "country": "DE",
    "name": "Schönburg",
    "lat": "51.16667",
    "lng": "11.86667"
  },
  {
    "country": "DE",
    "name": "Schönborn",
    "lat": "51.60016",
    "lng": "13.48967"
  },
  {
    "country": "DE",
    "name": "Schönberg",
    "lat": "53.68319",
    "lng": "10.42671"
  },
  {
    "country": "DE",
    "name": "Schönberg",
    "lat": "50.86752",
    "lng": "12.49126"
  },
  {
    "country": "DE",
    "name": "Schönbach",
    "lat": "51.06667",
    "lng": "14.56667"
  },
  {
    "country": "DE",
    "name": "Schönau-Berzdorf",
    "lat": "51.06402",
    "lng": "14.88402"
  },
  {
    "country": "DE",
    "name": "Schönau",
    "lat": "50.07571",
    "lng": "9.72169"
  },
  {
    "country": "DE",
    "name": "Schönau",
    "lat": "49.43665",
    "lng": "8.8088"
  },
  {
    "country": "DE",
    "name": "Schönau",
    "lat": "48.48333",
    "lng": "12.85"
  },
  {
    "country": "DE",
    "name": "Schönau im Schwarzwald",
    "lat": "47.78623",
    "lng": "7.89445"
  },
  {
    "country": "DE",
    "name": "Schönau am Königssee",
    "lat": "47.60055",
    "lng": "12.98704"
  },
  {
    "country": "DE",
    "name": "Schönaich",
    "lat": "48.65871",
    "lng": "9.06012"
  },
  {
    "country": "DE",
    "name": "Schonach im Schwarzwald",
    "lat": "48.14229",
    "lng": "8.20289"
  },
  {
    "country": "DE",
    "name": "Schömberg",
    "lat": "48.78713",
    "lng": "8.64495"
  },
  {
    "country": "DE",
    "name": "Schömberg",
    "lat": "48.20997",
    "lng": "8.75949"
  },
  {
    "country": "DE",
    "name": "Schöllnach",
    "lat": "48.75412",
    "lng": "13.17781"
  },
  {
    "country": "DE",
    "name": "Schöllkrippen",
    "lat": "50.08545",
    "lng": "9.24697"
  },
  {
    "country": "DE",
    "name": "Schöfweg",
    "lat": "48.83882",
    "lng": "13.22861"
  },
  {
    "country": "DE",
    "name": "Schochwitz",
    "lat": "51.53174",
    "lng": "11.75485"
  },
  {
    "country": "DE",
    "name": "Schobüll",
    "lat": "54.5092",
    "lng": "9.00621"
  },
  {
    "country": "DE",
    "name": "Schnürpflingen",
    "lat": "48.2728",
    "lng": "9.99292"
  },
  {
    "country": "DE",
    "name": "Schneverdingen",
    "lat": "53.11685",
    "lng": "9.79524"
  },
  {
    "country": "DE",
    "name": "Schnelldorf",
    "lat": "49.2",
    "lng": "10.18333"
  },
  {
    "country": "DE",
    "name": "Schneizlreuth",
    "lat": "47.68333",
    "lng": "12.8"
  },
  {
    "country": "DE",
    "name": "Schneidlingen",
    "lat": "51.89454",
    "lng": "11.44487"
  },
  {
    "country": "DE",
    "name": "Schnega",
    "lat": "52.8913",
    "lng": "10.89226"
  },
  {
    "country": "DE",
    "name": "Schneeberg",
    "lat": "50.59465",
    "lng": "12.64139"
  },
  {
    "country": "DE",
    "name": "Schneckenlohe",
    "lat": "50.21184",
    "lng": "11.19395"
  },
  {
    "country": "DE",
    "name": "Schnaittenbach",
    "lat": "49.54692",
    "lng": "12.00184"
  },
  {
    "country": "DE",
    "name": "Schnaittach",
    "lat": "49.55958",
    "lng": "11.34328"
  },
  {
    "country": "DE",
    "name": "Schnaitsee",
    "lat": "48.06667",
    "lng": "12.36667"
  },
  {
    "country": "DE",
    "name": "Schmölln",
    "lat": "50.89678",
    "lng": "12.35339"
  },
  {
    "country": "DE",
    "name": "Schmöckwitz",
    "lat": "52.37513",
    "lng": "13.64948"
  },
  {
    "country": "DE",
    "name": "Schmitten",
    "lat": "50.26667",
    "lng": "8.45"
  },
  {
    "country": "DE",
    "name": "Schmiedefeld am Rennsteig",
    "lat": "50.60863",
    "lng": "10.81284"
  },
  {
    "country": "DE",
    "name": "Schmiedefeld",
    "lat": "50.53333",
    "lng": "11.21667"
  },
  {
    "country": "DE",
    "name": "Schmiedeberg",
    "lat": "50.83644",
    "lng": "13.67622"
  },
  {
    "country": "DE",
    "name": "Schmiechen",
    "lat": "48.21667",
    "lng": "10.96667"
  },
  {
    "country": "DE",
    "name": "Schmidmühlen",
    "lat": "49.26898",
    "lng": "11.92429"
  },
  {
    "country": "DE",
    "name": "Schmidgaden",
    "lat": "49.4234",
    "lng": "12.09247"
  },
  {
    "country": "DE",
    "name": "Schmelz",
    "lat": "49.43333",
    "lng": "6.85"
  },
  {
    "country": "DE",
    "name": "Schmargendorf",
    "lat": "52.47517",
    "lng": "13.29071"
  },
  {
    "country": "DE",
    "name": "Schmallenberg",
    "lat": "51.15473",
    "lng": "8.28505"
  },
  {
    "country": "DE",
    "name": "Schmalkalden",
    "lat": "50.72136",
    "lng": "10.44386"
  },
  {
    "country": "DE",
    "name": "Schmalfeld",
    "lat": "53.88333",
    "lng": "9.96667"
  },
  {
    "country": "DE",
    "name": "Schlüsselfeld",
    "lat": "49.75621",
    "lng": "10.61873"
  },
  {
    "country": "DE",
    "name": "Schlüchtern",
    "lat": "50.34891",
    "lng": "9.52532"
  },
  {
    "country": "DE",
    "name": "Schluchsee",
    "lat": "47.81667",
    "lng": "8.18333"
  },
  {
    "country": "DE",
    "name": "Schlotheim",
    "lat": "51.24643",
    "lng": "10.65842"
  },
  {
    "country": "DE",
    "name": "Schloßvippach",
    "lat": "51.10499",
    "lng": "11.14512"
  },
  {
    "country": "DE",
    "name": "Schlitz",
    "lat": "50.67416",
    "lng": "9.56102"
  },
  {
    "country": "DE",
    "name": "Schliersee",
    "lat": "47.73621",
    "lng": "11.85936"
  },
  {
    "country": "DE",
    "name": "Schlierbach",
    "lat": "48.67362",
    "lng": "9.51811"
  },
  {
    "country": "DE",
    "name": "Schlier",
    "lat": "47.77004",
    "lng": "9.67354"
  },
  {
    "country": "DE",
    "name": "Schliengen",
    "lat": "47.75698",
    "lng": "7.57645"
  },
  {
    "country": "DE",
    "name": "Schlieben",
    "lat": "51.72379",
    "lng": "13.38304"
  },
  {
    "country": "DE",
    "name": "Schleusingen",
    "lat": "50.51076",
    "lng": "10.75658"
  },
  {
    "country": "DE",
    "name": "Schlettau",
    "lat": "50.55882",
    "lng": "12.95269"
  },
  {
    "country": "DE",
    "name": "Schleswig",
    "lat": "54.52156",
    "lng": "9.5586"
  },
  {
    "country": "DE",
    "name": "Bad Schlema",
    "lat": "50.60257",
    "lng": "12.67288"
  },
  {
    "country": "DE",
    "name": "Schleiz",
    "lat": "50.57866",
    "lng": "11.81024"
  },
  {
    "country": "DE",
    "name": "Schleife",
    "lat": "51.53333",
    "lng": "14.53333"
  },
  {
    "country": "DE",
    "name": "Schleiden",
    "lat": "50.52896",
    "lng": "6.47692"
  },
  {
    "country": "DE",
    "name": "Schleid",
    "lat": "50.7",
    "lng": "9.96667"
  },
  {
    "country": "DE",
    "name": "Schlehdorf",
    "lat": "47.65795",
    "lng": "11.31494"
  },
  {
    "country": "DE",
    "name": "Schlegel",
    "lat": "50.97775",
    "lng": "14.87686"
  },
  {
    "country": "DE",
    "name": "Schleching",
    "lat": "47.72098",
    "lng": "12.39481"
  },
  {
    "country": "DE",
    "name": "Schlat",
    "lat": "48.65321",
    "lng": "9.70625"
  },
  {
    "country": "DE",
    "name": "Schlangenbad",
    "lat": "50.09322",
    "lng": "8.10312"
  },
  {
    "country": "DE",
    "name": "Schlangen",
    "lat": "51.80978",
    "lng": "8.84605"
  },
  {
    "country": "DE",
    "name": "Schlaitz",
    "lat": "51.65871",
    "lng": "12.42839"
  },
  {
    "country": "DE",
    "name": "Schlaitdorf",
    "lat": "48.60431",
    "lng": "9.22268"
  },
  {
    "country": "DE",
    "name": "Schlagsdorf",
    "lat": "53.73363",
    "lng": "10.82556"
  },
  {
    "country": "DE",
    "name": "Schladen",
    "lat": "52.02218",
    "lng": "10.53967"
  },
  {
    "country": "DE",
    "name": "Schkopau",
    "lat": "51.39186",
    "lng": "11.95224"
  },
  {
    "country": "DE",
    "name": "Schkölen",
    "lat": "51.04166",
    "lng": "11.82141"
  },
  {
    "country": "DE",
    "name": "Schkeuditz",
    "lat": "51.39678",
    "lng": "12.22141"
  },
  {
    "country": "DE",
    "name": "Schirnding",
    "lat": "50.08205",
    "lng": "12.22742"
  },
  {
    "country": "DE",
    "name": "Schirmitz",
    "lat": "49.65",
    "lng": "12.16667"
  },
  {
    "country": "DE",
    "name": "Schirgiswalde",
    "lat": "51.07641",
    "lng": "14.42834"
  },
  {
    "country": "DE",
    "name": "Schipkau",
    "lat": "51.51766",
    "lng": "13.89738"
  },
  {
    "country": "DE",
    "name": "Schiltberg",
    "lat": "48.46293",
    "lng": "11.24876"
  },
  {
    "country": "DE",
    "name": "Schiltach",
    "lat": "48.28932",
    "lng": "8.34169"
  },
  {
    "country": "DE",
    "name": "Schillingsfürst",
    "lat": "49.28775",
    "lng": "10.26276"
  },
  {
    "country": "DE",
    "name": "Schillingen",
    "lat": "49.63333",
    "lng": "6.78333"
  },
  {
    "country": "DE",
    "name": "Schillig",
    "lat": "53.70378",
    "lng": "8.0217"
  },
  {
    "country": "DE",
    "name": "Schildau",
    "lat": "51.45721",
    "lng": "12.93024"
  },
  {
    "country": "DE",
    "name": "Schiffweiler",
    "lat": "49.36667",
    "lng": "7.13333"
  },
  {
    "country": "DE",
    "name": "Schifferstadt",
    "lat": "49.38417",
    "lng": "8.3775"
  },
  {
    "country": "DE",
    "name": "Schiffdorf",
    "lat": "53.53333",
    "lng": "8.65"
  },
  {
    "country": "DE",
    "name": "Schierling",
    "lat": "48.83422",
    "lng": "12.13946"
  },
  {
    "country": "DE",
    "name": "Scheyern",
    "lat": "48.5",
    "lng": "11.46667"
  },
  {
    "country": "DE",
    "name": "Scheuring",
    "lat": "48.16769",
    "lng": "10.89569"
  },
  {
    "country": "DE",
    "name": "Scheuerfeld",
    "lat": "50.78736",
    "lng": "7.84128"
  },
  {
    "country": "DE",
    "name": "Scheßlitz",
    "lat": "49.97568",
    "lng": "11.03299"
  },
  {
    "country": "DE",
    "name": "Scherstetten",
    "lat": "48.18032",
    "lng": "10.64005"
  },
  {
    "country": "DE",
    "name": "Schernberg",
    "lat": "51.32774",
    "lng": "10.76928"
  },
  {
    "country": "DE",
    "name": "Schermen",
    "lat": "52.23206",
    "lng": "11.81382"
  },
  {
    "country": "DE",
    "name": "Schermbeck",
    "lat": "51.68333",
    "lng": "6.86667"
  },
  {
    "country": "DE",
    "name": "Schenklengsfeld",
    "lat": "50.81667",
    "lng": "9.85"
  },
  {
    "country": "DE",
    "name": "Schenkenzell",
    "lat": "48.31202",
    "lng": "8.37212"
  },
  {
    "country": "DE",
    "name": "Schenkendöbern",
    "lat": "51.95723",
    "lng": "14.63541"
  },
  {
    "country": "DE",
    "name": "Schenefeld",
    "lat": "54.05",
    "lng": "9.48333"
  },
  {
    "country": "DE",
    "name": "Schellhorn",
    "lat": "54.22952",
    "lng": "10.29402"
  },
  {
    "country": "DE",
    "name": "Schellerten",
    "lat": "52.1853",
    "lng": "10.10227"
  },
  {
    "country": "DE",
    "name": "Schelklingen",
    "lat": "48.37575",
    "lng": "9.73273"
  },
  {
    "country": "DE",
    "name": "Scheinfeld",
    "lat": "49.66931",
    "lng": "10.46554"
  },
  {
    "country": "DE",
    "name": "Scheidegg",
    "lat": "47.58141",
    "lng": "9.84829"
  },
  {
    "country": "DE",
    "name": "Scheibenberg",
    "lat": "50.54023",
    "lng": "12.91215"
  },
  {
    "country": "DE",
    "name": "Scheeßel",
    "lat": "53.16667",
    "lng": "9.48333"
  },
  {
    "country": "DE",
    "name": "Scheer",
    "lat": "48.07292",
    "lng": "9.29486"
  },
  {
    "country": "DE",
    "name": "Schechingen",
    "lat": "48.87341",
    "lng": "9.91744"
  },
  {
    "country": "DE",
    "name": "Schechen",
    "lat": "47.92911",
    "lng": "12.12393"
  },
  {
    "country": "DE",
    "name": "Schaufling",
    "lat": "48.85",
    "lng": "13.06667"
  },
  {
    "country": "DE",
    "name": "Schauenstein",
    "lat": "50.27826",
    "lng": "11.74169"
  },
  {
    "country": "DE",
    "name": "Schashagen",
    "lat": "54.13333",
    "lng": "10.88333"
  },
  {
    "country": "DE",
    "name": "Scharnebeck",
    "lat": "53.29237",
    "lng": "10.50188"
  },
  {
    "country": "DE",
    "name": "Scharfenstein",
    "lat": "50.70405",
    "lng": "13.05654"
  },
  {
    "country": "DE",
    "name": "Scharbeutz",
    "lat": "54.03333",
    "lng": "10.75"
  },
  {
    "country": "DE",
    "name": "Schapen",
    "lat": "52.4",
    "lng": "7.56667"
  },
  {
    "country": "DE",
    "name": "Schallstadt",
    "lat": "47.95855",
    "lng": "7.75755"
  },
  {
    "country": "DE",
    "name": "Schalksmühle",
    "lat": "51.2412",
    "lng": "7.5279"
  },
  {
    "country": "DE",
    "name": "Schalkau",
    "lat": "50.39536",
    "lng": "11.00732"
  },
  {
    "country": "DE",
    "name": "Schäftlarn",
    "lat": "47.99027",
    "lng": "11.45591"
  },
  {
    "country": "DE",
    "name": "Schafstädt",
    "lat": "51.38131",
    "lng": "11.77302"
  },
  {
    "country": "DE",
    "name": "Schafflund",
    "lat": "54.75845",
    "lng": "9.18329"
  },
  {
    "country": "DE",
    "name": "Schacht-Audorf",
    "lat": "54.31282",
    "lng": "9.71586"
  },
  {
    "country": "DE",
    "name": "Schaalby",
    "lat": "54.55",
    "lng": "9.63333"
  },
  {
    "country": "DE",
    "name": "Schaafheim",
    "lat": "49.92417",
    "lng": "9.00944"
  },
  {
    "country": "DE",
    "name": "Sayda",
    "lat": "50.71123",
    "lng": "13.42172"
  },
  {
    "country": "DE",
    "name": "Saulgrub",
    "lat": "47.66643",
    "lng": "11.02469"
  },
  {
    "country": "DE",
    "name": "Saulgau",
    "lat": "48.01676",
    "lng": "9.50064"
  },
  {
    "country": "DE",
    "name": "Sauldorf",
    "lat": "47.94371",
    "lng": "9.10833"
  },
  {
    "country": "DE",
    "name": "Sauerlach",
    "lat": "47.97171",
    "lng": "11.65383"
  },
  {
    "country": "DE",
    "name": "Sauensiek",
    "lat": "53.38333",
    "lng": "9.6"
  },
  {
    "country": "DE",
    "name": "Satteldorf",
    "lat": "49.16953",
    "lng": "10.07957"
  },
  {
    "country": "DE",
    "name": "Satrup",
    "lat": "54.69237",
    "lng": "9.60549"
  },
  {
    "country": "DE",
    "name": "Satow-Oberhagen",
    "lat": "53.99545",
    "lng": "11.88466"
  },
  {
    "country": "DE",
    "name": "Saßnitz",
    "lat": "54.5157",
    "lng": "13.64451"
  },
  {
    "country": "DE",
    "name": "Sassenberg",
    "lat": "51.99223",
    "lng": "8.04068"
  },
  {
    "country": "DE",
    "name": "Sasel",
    "lat": "53.65385",
    "lng": "10.11184"
  },
  {
    "country": "DE",
    "name": "Sasbachwalden",
    "lat": "48.61667",
    "lng": "8.13333"
  },
  {
    "country": "DE",
    "name": "Sasbach",
    "lat": "48.63971",
    "lng": "8.09375"
  },
  {
    "country": "DE",
    "name": "Sasbach",
    "lat": "48.13837",
    "lng": "7.61576"
  },
  {
    "country": "DE",
    "name": "Sarstedt",
    "lat": "52.23495",
    "lng": "9.85411"
  },
  {
    "country": "DE",
    "name": "Sankt Wolfgang",
    "lat": "48.21667",
    "lng": "12.13333"
  },
  {
    "country": "DE",
    "name": "Sankt Wendel",
    "lat": "49.46633",
    "lng": "7.16814"
  },
  {
    "country": "DE",
    "name": "Sankt Sebastian",
    "lat": "50.41077",
    "lng": "7.56175"
  },
  {
    "country": "DE",
    "name": "Sankt Peter-Ording",
    "lat": "54.30363",
    "lng": "8.64138"
  },
  {
    "country": "DE",
    "name": "Sankt Peter",
    "lat": "48.01475",
    "lng": "8.03294"
  },
  {
    "country": "DE",
    "name": "Sankt Michaelisdonn",
    "lat": "53.98333",
    "lng": "9.11667"
  },
  {
    "country": "DE",
    "name": "Sankt Martin",
    "lat": "49.30028",
    "lng": "8.10528"
  },
  {
    "country": "DE",
    "name": "Sankt Märgen",
    "lat": "48.00805",
    "lng": "8.09283"
  },
  {
    "country": "DE",
    "name": "Sankt Margarethen",
    "lat": "53.89199",
    "lng": "9.25301"
  },
  {
    "country": "DE",
    "name": "Sankt Kilian",
    "lat": "50.52749",
    "lng": "10.76301"
  },
  {
    "country": "DE",
    "name": "Sankt Julian",
    "lat": "49.61667",
    "lng": "7.51667"
  },
  {
    "country": "DE",
    "name": "Sankt Johann",
    "lat": "48.45397",
    "lng": "9.34396"
  },
  {
    "country": "DE",
    "name": "Sankt Ingbert",
    "lat": "49.27697",
    "lng": "7.11672"
  },
  {
    "country": "DE",
    "name": "Sankt Goarshausen",
    "lat": "50.15839",
    "lng": "7.71374"
  },
  {
    "country": "DE",
    "name": "Sankt Goar",
    "lat": "50.14878",
    "lng": "7.7072"
  },
  {
    "country": "DE",
    "name": "Sankt Georgen im Schwarzwald",
    "lat": "48.12716",
    "lng": "8.33513"
  },
  {
    "country": "DE",
    "name": "St. Georg",
    "lat": "53.55513",
    "lng": "10.01231"
  },
  {
    "country": "DE",
    "name": "Sankt Gangloff",
    "lat": "50.85522",
    "lng": "11.89446"
  },
  {
    "country": "DE",
    "name": "Sankt Egidien",
    "lat": "50.78617",
    "lng": "12.62395"
  },
  {
    "country": "DE",
    "name": "Sankt Blasien",
    "lat": "47.76252",
    "lng": "8.12714"
  },
  {
    "country": "DE",
    "name": "Sankt Augustin",
    "lat": "50.77538",
    "lng": "7.197"
  },
  {
    "country": "DE",
    "name": "Sankt Andreasberg",
    "lat": "51.71004",
    "lng": "10.51867"
  },
  {
    "country": "DE",
    "name": "Sankelmark",
    "lat": "54.71803",
    "lng": "9.42344"
  },
  {
    "country": "DE",
    "name": "Alt-Sanitz",
    "lat": "53.81363",
    "lng": "13.58786"
  },
  {
    "country": "DE",
    "name": "Sangerhausen",
    "lat": "51.47221",
    "lng": "11.29533"
  },
  {
    "country": "DE",
    "name": "Sandstedt",
    "lat": "53.35981",
    "lng": "8.52137"
  },
  {
    "country": "DE",
    "name": "Sandhausen",
    "lat": "49.34278",
    "lng": "8.65917"
  },
  {
    "country": "DE",
    "name": "Sandesneben",
    "lat": "53.68333",
    "lng": "10.5"
  },
  {
    "country": "DE",
    "name": "Sandersleben",
    "lat": "51.67745",
    "lng": "11.56795"
  },
  {
    "country": "DE",
    "name": "Sandersdorf",
    "lat": "51.62841",
    "lng": "12.26492"
  },
  {
    "country": "DE",
    "name": "Sande",
    "lat": "53.50489",
    "lng": "8.01418"
  },
  {
    "country": "DE",
    "name": "Sandberg",
    "lat": "50.34824",
    "lng": "10.00814"
  },
  {
    "country": "DE",
    "name": "Sandau",
    "lat": "52.78968",
    "lng": "12.04582"
  },
  {
    "country": "DE",
    "name": "Sand",
    "lat": "49.98585",
    "lng": "10.5862"
  },
  {
    "country": "DE",
    "name": "Samtens",
    "lat": "54.35481",
    "lng": "13.29311"
  },
  {
    "country": "DE",
    "name": "Samswegen",
    "lat": "52.26059",
    "lng": "11.56174"
  },
  {
    "country": "DE",
    "name": "Samerberg",
    "lat": "47.77654",
    "lng": "12.19139"
  },
  {
    "country": "DE",
    "name": "Salzweg",
    "lat": "48.61667",
    "lng": "13.48333"
  },
  {
    "country": "DE",
    "name": "Salzwedel",
    "lat": "52.85435",
    "lng": "11.1525"
  },
  {
    "country": "DE",
    "name": "Salzmünde",
    "lat": "51.52662",
    "lng": "11.8265"
  },
  {
    "country": "DE",
    "name": "Salzkotten",
    "lat": "51.6717",
    "lng": "8.60092"
  },
  {
    "country": "DE",
    "name": "Salzhemmendorf",
    "lat": "52.067",
    "lng": "9.5872"
  },
  {
    "country": "DE",
    "name": "Salzhausen",
    "lat": "53.22339",
    "lng": "10.16981"
  },
  {
    "country": "DE",
    "name": "Salzgitter",
    "lat": "52.15705",
    "lng": "10.4154"
  },
  {
    "country": "DE",
    "name": "Salzbergen",
    "lat": "52.33333",
    "lng": "7.35"
  },
  {
    "country": "DE",
    "name": "Salz",
    "lat": "50.30842",
    "lng": "10.21205"
  },
  {
    "country": "DE",
    "name": "Sallgast",
    "lat": "51.5887",
    "lng": "13.84861"
  },
  {
    "country": "DE",
    "name": "Salgen",
    "lat": "48.13069",
    "lng": "10.4789"
  },
  {
    "country": "DE",
    "name": "Saldenburg",
    "lat": "48.7731",
    "lng": "13.35586"
  },
  {
    "country": "DE",
    "name": "Salching",
    "lat": "48.81047",
    "lng": "12.57043"
  },
  {
    "country": "DE",
    "name": "Salach",
    "lat": "48.69198",
    "lng": "9.73715"
  },
  {
    "country": "DE",
    "name": "Sagard",
    "lat": "54.52556",
    "lng": "13.55387"
  },
  {
    "country": "DE",
    "name": "Saffig",
    "lat": "50.38333",
    "lng": "7.41667"
  },
  {
    "country": "DE",
    "name": "Saerbeck",
    "lat": "52.17372",
    "lng": "7.63395"
  },
  {
    "country": "DE",
    "name": "Sachsenkam",
    "lat": "47.80543",
    "lng": "11.64396"
  },
  {
    "country": "DE",
    "name": "Sachsenhausen",
    "lat": "51.24338",
    "lng": "9.00973"
  },
  {
    "country": "DE",
    "name": "Sachsenhagen",
    "lat": "52.39734",
    "lng": "9.26791"
  },
  {
    "country": "DE",
    "name": "Sachsen",
    "lat": "49.28999",
    "lng": "10.65971"
  },
  {
    "country": "DE",
    "name": "Saarwellingen",
    "lat": "49.3543",
    "lng": "6.80487"
  },
  {
    "country": "DE",
    "name": "Saarlouis",
    "lat": "49.31366",
    "lng": "6.75154"
  },
  {
    "country": "DE",
    "name": "Saarhölzbach",
    "lat": "49.51585",
    "lng": "6.60742"
  },
  {
    "country": "DE",
    "name": "Saarburg",
    "lat": "49.60641",
    "lng": "6.54365"
  },
  {
    "country": "DE",
    "name": "Saarbrücken",
    "lat": "49.23262",
    "lng": "7.00982"
  },
  {
    "country": "DE",
    "name": "Saara",
    "lat": "50.93284",
    "lng": "12.42096"
  },
  {
    "country": "DE",
    "name": "Saalfeld",
    "lat": "50.64826",
    "lng": "11.36536"
  },
  {
    "country": "DE",
    "name": "Saal an der Saale",
    "lat": "50.31673",
    "lng": "10.35769"
  },
  {
    "country": "DE",
    "name": "Saal",
    "lat": "54.31051",
    "lng": "12.49935"
  },
  {
    "country": "DE",
    "name": "Saal",
    "lat": "48.90099",
    "lng": "11.93196"
  },
  {
    "country": "DE",
    "name": "Rüthen",
    "lat": "51.4909",
    "lng": "8.43596"
  },
  {
    "country": "DE",
    "name": "Rutesheim",
    "lat": "48.80808",
    "lng": "8.94536"
  },
  {
    "country": "DE",
    "name": "Rust",
    "lat": "48.26667",
    "lng": "7.73333"
  },
  {
    "country": "DE",
    "name": "Rüsselsheim",
    "lat": "49.98955",
    "lng": "8.42251"
  },
  {
    "country": "DE",
    "name": "Ruppichteroth",
    "lat": "50.84367",
    "lng": "7.48409"
  },
  {
    "country": "DE",
    "name": "Ruppertsweiler",
    "lat": "49.19707",
    "lng": "7.68957"
  },
  {
    "country": "DE",
    "name": "Ruppertshofen",
    "lat": "48.88275",
    "lng": "9.81506"
  },
  {
    "country": "DE",
    "name": "Ruppertsberg",
    "lat": "49.40028",
    "lng": "8.19611"
  },
  {
    "country": "DE",
    "name": "Runkel",
    "lat": "50.40574",
    "lng": "8.15457"
  },
  {
    "country": "DE",
    "name": "Runding",
    "lat": "49.21513",
    "lng": "12.76208"
  },
  {
    "country": "DE",
    "name": "Rümpel",
    "lat": "53.78333",
    "lng": "10.35"
  },
  {
    "country": "DE",
    "name": "Rümmingen",
    "lat": "47.6412",
    "lng": "7.64198"
  },
  {
    "country": "DE",
    "name": "Rümmelsheim",
    "lat": "49.93307",
    "lng": "7.85977"
  },
  {
    "country": "DE",
    "name": "Rummelsburg",
    "lat": "52.50146",
    "lng": "13.4934"
  },
  {
    "country": "DE",
    "name": "Rülzheim",
    "lat": "49.15312",
    "lng": "8.29287"
  },
  {
    "country": "DE",
    "name": "Rullstorf",
    "lat": "53.28645",
    "lng": "10.52972"
  },
  {
    "country": "DE",
    "name": "Ruhwinkel",
    "lat": "54.1",
    "lng": "10.21667"
  },
  {
    "country": "DE",
    "name": "Ruhstorf",
    "lat": "48.53976",
    "lng": "12.68305"
  },
  {
    "country": "DE",
    "name": "Ruhpolding",
    "lat": "47.76667",
    "lng": "12.65"
  },
  {
    "country": "DE",
    "name": "Ruhmannsfelden",
    "lat": "48.98327",
    "lng": "12.98347"
  },
  {
    "country": "DE",
    "name": "Ruhland",
    "lat": "51.45755",
    "lng": "13.86643"
  },
  {
    "country": "DE",
    "name": "Ruhla",
    "lat": "50.89296",
    "lng": "10.36573"
  },
  {
    "country": "DE",
    "name": "Rühen",
    "lat": "52.4856",
    "lng": "10.88642"
  },
  {
    "country": "DE",
    "name": "Rügland",
    "lat": "49.4",
    "lng": "10.58333"
  },
  {
    "country": "DE",
    "name": "Rugendorf",
    "lat": "50.2",
    "lng": "11.46667"
  },
  {
    "country": "DE",
    "name": "Rudow",
    "lat": "52.42407",
    "lng": "13.48529"
  },
  {
    "country": "DE",
    "name": "Rudolstadt",
    "lat": "50.72043",
    "lng": "11.34046"
  },
  {
    "country": "DE",
    "name": "Rüdnitz",
    "lat": "52.72137",
    "lng": "13.62502"
  },
  {
    "country": "DE",
    "name": "Rüdesheim am Rhein",
    "lat": "49.9789",
    "lng": "7.92442"
  },
  {
    "country": "DE",
    "name": "Rüdesheim",
    "lat": "49.84546",
    "lng": "7.81452"
  },
  {
    "country": "DE",
    "name": "Ruderting",
    "lat": "48.65",
    "lng": "13.41667"
  },
  {
    "country": "DE",
    "name": "Rudersberg",
    "lat": "48.88515",
    "lng": "9.52927"
  },
  {
    "country": "DE",
    "name": "Ruderatshofen",
    "lat": "47.81667",
    "lng": "10.58333"
  },
  {
    "country": "DE",
    "name": "Rudelzhausen",
    "lat": "48.6",
    "lng": "11.76667"
  },
  {
    "country": "DE",
    "name": "Rückersdorf",
    "lat": "51.56955",
    "lng": "13.57226"
  },
  {
    "country": "DE",
    "name": "Rückersdorf",
    "lat": "49.49757",
    "lng": "11.24751"
  },
  {
    "country": "DE",
    "name": "Rübeland",
    "lat": "51.75591",
    "lng": "10.8466"
  },
  {
    "country": "DE",
    "name": "Roxheim",
    "lat": "49.86374",
    "lng": "7.8098"
  },
  {
    "country": "DE",
    "name": "Rövershagen",
    "lat": "54.17668",
    "lng": "12.24276"
  },
  {
    "country": "DE",
    "name": "Rötz",
    "lat": "49.34316",
    "lng": "12.52963"
  },
  {
    "country": "DE",
    "name": "Rottweil",
    "lat": "48.16783",
    "lng": "8.62719"
  },
  {
    "country": "DE",
    "name": "Rottleberode",
    "lat": "51.51636",
    "lng": "10.94658"
  },
  {
    "country": "DE",
    "name": "Röttingen",
    "lat": "49.50969",
    "lng": "9.97082"
  },
  {
    "country": "DE",
    "name": "Rotthalmünster",
    "lat": "48.35825",
    "lng": "13.20162"
  },
  {
    "country": "DE",
    "name": "Rottendorf",
    "lat": "49.7923",
    "lng": "10.02593"
  },
  {
    "country": "DE",
    "name": "Rottenburg an der Laaber",
    "lat": "48.70233",
    "lng": "12.02717"
  },
  {
    "country": "DE",
    "name": "Rottenburg",
    "lat": "48.47629",
    "lng": "8.93528"
  },
  {
    "country": "DE",
    "name": "Rottenbuch",
    "lat": "47.73333",
    "lng": "10.96667"
  },
  {
    "country": "DE",
    "name": "Rottenbach",
    "lat": "50.68782",
    "lng": "11.16674"
  },
  {
    "country": "DE",
    "name": "Röttenbach",
    "lat": "49.66429",
    "lng": "10.92607"
  },
  {
    "country": "DE",
    "name": "Röttenbach",
    "lat": "49.15",
    "lng": "11.03333"
  },
  {
    "country": "DE",
    "name": "Rottenacker",
    "lat": "48.23485",
    "lng": "9.68956"
  },
  {
    "country": "DE",
    "name": "Rottach-Egern",
    "lat": "47.68966",
    "lng": "11.77065"
  },
  {
    "country": "DE",
    "name": "Rott",
    "lat": "47.92008",
    "lng": "12.08771"
  },
  {
    "country": "DE",
    "name": "Röthlein",
    "lat": "49.98333",
    "lng": "10.21667"
  },
  {
    "country": "DE",
    "name": "Rothenstein",
    "lat": "50.85",
    "lng": "11.6"
  },
  {
    "country": "DE",
    "name": "Rothenfels",
    "lat": "49.89135",
    "lng": "9.5926"
  },
  {
    "country": "DE",
    "name": "Rothenburg ob der Tauber",
    "lat": "49.37885",
    "lng": "10.18711"
  },
  {
    "country": "DE",
    "name": "Rothenburg",
    "lat": "51.334",
    "lng": "14.96874"
  },
  {
    "country": "DE",
    "name": "Rothenbuch",
    "lat": "49.96528",
    "lng": "9.39389"
  },
  {
    "country": "DE",
    "name": "Rothenberg",
    "lat": "49.49917",
    "lng": "8.91917"
  },
  {
    "country": "DE",
    "name": "Röthenbach an der Pegnitz",
    "lat": "49.48301",
    "lng": "11.24116"
  },
  {
    "country": "DE",
    "name": "Röthenbach",
    "lat": "47.62303",
    "lng": "9.97387"
  },
  {
    "country": "DE",
    "name": "Rötha",
    "lat": "51.19783",
    "lng": "12.41447"
  },
  {
    "country": "DE",
    "name": "Roth",
    "lat": "50.7623",
    "lng": "7.70016"
  },
  {
    "country": "DE",
    "name": "Roth",
    "lat": "49.24762",
    "lng": "11.09111"
  },
  {
    "country": "DE",
    "name": "Rötgesbüttel",
    "lat": "52.41667",
    "lng": "10.53333"
  },
  {
    "country": "DE",
    "name": "Roetgen",
    "lat": "50.65",
    "lng": "6.2"
  },
  {
    "country": "DE",
    "name": "Rotenburg an der Fulda",
    "lat": "50.99556",
    "lng": "9.72838"
  },
  {
    "country": "DE",
    "name": "Rotenburg",
    "lat": "53.11125",
    "lng": "9.41082"
  },
  {
    "country": "DE",
    "name": "Rot am See",
    "lat": "49.25",
    "lng": "10.01667"
  },
  {
    "country": "DE",
    "name": "Rot",
    "lat": "47.92278",
    "lng": "9.10485"
  },
  {
    "country": "DE",
    "name": "Rostock",
    "lat": "54.0887",
    "lng": "12.14049"
  },
  {
    "country": "DE",
    "name": "Roßwein",
    "lat": "51.06589",
    "lng": "13.18308"
  },
  {
    "country": "DE",
    "name": "Roßtal",
    "lat": "49.39567",
    "lng": "10.88848"
  },
  {
    "country": "DE",
    "name": "Roßleben",
    "lat": "51.29886",
    "lng": "11.43435"
  },
  {
    "country": "DE",
    "name": "Roßlau",
    "lat": "51.88736",
    "lng": "12.24192"
  },
  {
    "country": "DE",
    "name": "Roßla",
    "lat": "51.46331",
    "lng": "11.07576"
  },
  {
    "country": "DE",
    "name": "Roßhaupten",
    "lat": "48.42943",
    "lng": "10.46911"
  },
  {
    "country": "DE",
    "name": "Roßdorf",
    "lat": "49.85972",
    "lng": "8.76167"
  },
  {
    "country": "DE",
    "name": "Rossbach",
    "lat": "48.58333",
    "lng": "12.95"
  },
  {
    "country": "DE",
    "name": "Rösrath",
    "lat": "50.89559",
    "lng": "7.18175"
  },
  {
    "country": "DE",
    "name": "Roskow",
    "lat": "52.47237",
    "lng": "12.71886"
  },
  {
    "country": "DE",
    "name": "Rositz",
    "lat": "51.01728",
    "lng": "12.36354"
  },
  {
    "country": "DE",
    "name": "Rosenthal",
    "lat": "52.59976",
    "lng": "13.37774"
  },
  {
    "country": "DE",
    "name": "Rosenthal",
    "lat": "50.97439",
    "lng": "8.86736"
  },
  {
    "country": "DE",
    "name": "Rosenow",
    "lat": "53.62966",
    "lng": "13.03849"
  },
  {
    "country": "DE",
    "name": "Rosenheim",
    "lat": "47.85637",
    "lng": "12.12247"
  },
  {
    "country": "DE",
    "name": "Rosenfeld",
    "lat": "48.28639",
    "lng": "8.72357"
  },
  {
    "country": "DE",
    "name": "Rosenberg",
    "lat": "49.01892",
    "lng": "10.0296"
  },
  {
    "country": "DE",
    "name": "Rosdorf",
    "lat": "51.5",
    "lng": "9.9"
  },
  {
    "country": "DE",
    "name": "Rosche",
    "lat": "52.98663",
    "lng": "10.75184"
  },
  {
    "country": "DE",
    "name": "Rosbach vor der Höhe",
    "lat": "50.30332",
    "lng": "8.68976"
  },
  {
    "country": "DE",
    "name": "Ronshausen",
    "lat": "50.95",
    "lng": "9.85"
  },
  {
    "country": "DE",
    "name": "Ronsberg",
    "lat": "47.8958",
    "lng": "10.41571"
  },
  {
    "country": "DE",
    "name": "Ronnenberg",
    "lat": "52.31939",
    "lng": "9.65544"
  },
  {
    "country": "DE",
    "name": "Ronneburg",
    "lat": "50.8634",
    "lng": "12.18666"
  },
  {
    "country": "DE",
    "name": "Romrod",
    "lat": "50.71341",
    "lng": "9.2201"
  },
  {
    "country": "DE",
    "name": "Rommerskirchen",
    "lat": "51.03333",
    "lng": "6.68333"
  },
  {
    "country": "DE",
    "name": "Römhild",
    "lat": "50.39639",
    "lng": "10.53889"
  },
  {
    "country": "DE",
    "name": "Röllbach",
    "lat": "49.77306",
    "lng": "9.24611"
  },
  {
    "country": "DE",
    "name": "Roitzsch",
    "lat": "51.57526",
    "lng": "12.26331"
  },
  {
    "country": "DE",
    "name": "Roigheim",
    "lat": "49.36472",
    "lng": "9.34"
  },
  {
    "country": "DE",
    "name": "Röhrsen",
    "lat": "52.71078",
    "lng": "9.23139"
  },
  {
    "country": "DE",
    "name": "Röhrnbach",
    "lat": "48.73859",
    "lng": "13.52271"
  },
  {
    "country": "DE",
    "name": "Röhrmoos",
    "lat": "48.32966",
    "lng": "11.44672"
  },
  {
    "country": "DE",
    "name": "Rohrenfels",
    "lat": "48.68654",
    "lng": "11.15619"
  },
  {
    "country": "DE",
    "name": "Rohrdorf",
    "lat": "48.56667",
    "lng": "8.7"
  },
  {
    "country": "DE",
    "name": "Rohrdorf",
    "lat": "47.79713",
    "lng": "12.1701"
  },
  {
    "country": "DE",
    "name": "Rohrbach",
    "lat": "49.13667",
    "lng": "8.12861"
  },
  {
    "country": "DE",
    "name": "Rohrbach",
    "lat": "48.28933",
    "lng": "12.55603"
  },
  {
    "country": "DE",
    "name": "Rohr",
    "lat": "50.57644",
    "lng": "10.49725"
  },
  {
    "country": "DE",
    "name": "Rohr",
    "lat": "49.34112",
    "lng": "10.88981"
  },
  {
    "country": "DE",
    "name": "Rohr",
    "lat": "48.76768",
    "lng": "11.97152"
  },
  {
    "country": "DE",
    "name": "Roggentin",
    "lat": "54.0707",
    "lng": "12.20424"
  },
  {
    "country": "DE",
    "name": "Roggendorf",
    "lat": "53.69292",
    "lng": "11.0144"
  },
  {
    "country": "DE",
    "name": "Roggenburg",
    "lat": "48.27588",
    "lng": "10.23136"
  },
  {
    "country": "DE",
    "name": "Rogätz",
    "lat": "52.31667",
    "lng": "11.76667"
  },
  {
    "country": "DE",
    "name": "Röfingen",
    "lat": "48.42442",
    "lng": "10.44268"
  },
  {
    "country": "DE",
    "name": "Rodleben",
    "lat": "51.89607",
    "lng": "12.20061"
  },
  {
    "country": "DE",
    "name": "Rödinghausen",
    "lat": "52.25",
    "lng": "8.48333"
  },
  {
    "country": "DE",
    "name": "Roding",
    "lat": "49.19426",
    "lng": "12.51956"
  },
  {
    "country": "DE",
    "name": "Rodewisch",
    "lat": "50.53083",
    "lng": "12.41329"
  },
  {
    "country": "DE",
    "name": "Rodenberg",
    "lat": "52.31152",
    "lng": "9.3564"
  },
  {
    "country": "DE",
    "name": "Rodenbach",
    "lat": "50.15",
    "lng": "9.03333"
  },
  {
    "country": "DE",
    "name": "Rodenbach",
    "lat": "49.57414",
    "lng": "8.10695"
  },
  {
    "country": "DE",
    "name": "Roden",
    "lat": "49.89556",
    "lng": "9.62639"
  },
  {
    "country": "DE",
    "name": "Rödelsee",
    "lat": "49.7284",
    "lng": "10.2436"
  },
  {
    "country": "DE",
    "name": "Rodalben",
    "lat": "49.2394",
    "lng": "7.63962"
  },
  {
    "country": "DE",
    "name": "Rockenhausen",
    "lat": "49.62974",
    "lng": "7.82134"
  },
  {
    "country": "DE",
    "name": "Rockenberg",
    "lat": "50.4305",
    "lng": "8.73688"
  },
  {
    "country": "DE",
    "name": "Rochlitz",
    "lat": "51.05007",
    "lng": "12.79754"
  },
  {
    "country": "DE",
    "name": "Röblingen am See",
    "lat": "51.45944",
    "lng": "11.68231"
  },
  {
    "country": "DE",
    "name": "Röbel",
    "lat": "53.37555",
    "lng": "12.60372"
  },
  {
    "country": "DE",
    "name": "Rittersgrün",
    "lat": "50.48031",
    "lng": "12.79336"
  },
  {
    "country": "DE",
    "name": "Rittersdorf",
    "lat": "50",
    "lng": "6.5"
  },
  {
    "country": "DE",
    "name": "Ritterhude",
    "lat": "53.18289",
    "lng": "8.7355"
  },
  {
    "country": "DE",
    "name": "Riol",
    "lat": "49.79301",
    "lng": "6.79211"
  },
  {
    "country": "DE",
    "name": "Rinteln",
    "lat": "52.18604",
    "lng": "9.07917"
  },
  {
    "country": "DE",
    "name": "Ringsheim",
    "lat": "48.24765",
    "lng": "7.77823"
  },
  {
    "country": "DE",
    "name": "Ringleben",
    "lat": "51.36667",
    "lng": "11.21667"
  },
  {
    "country": "DE",
    "name": "Ringelai",
    "lat": "48.81336",
    "lng": "13.4713"
  },
  {
    "country": "DE",
    "name": "Rinchnach",
    "lat": "48.94956",
    "lng": "13.20102"
  },
  {
    "country": "DE",
    "name": "Rimsting",
    "lat": "47.88078",
    "lng": "12.33713"
  },
  {
    "country": "DE",
    "name": "Rimschweiler",
    "lat": "49.2188",
    "lng": "7.37571"
  },
  {
    "country": "DE",
    "name": "Rimpar",
    "lat": "49.85692",
    "lng": "9.95705"
  },
  {
    "country": "DE",
    "name": "Rimbach",
    "lat": "49.625",
    "lng": "8.76306"
  },
  {
    "country": "DE",
    "name": "Rimbach",
    "lat": "49.23333",
    "lng": "12.88333"
  },
  {
    "country": "DE",
    "name": "Rietz Neuendorf",
    "lat": "52.22758",
    "lng": "14.17463"
  },
  {
    "country": "DE",
    "name": "Rietschen",
    "lat": "51.4",
    "lng": "14.78333"
  },
  {
    "country": "DE",
    "name": "Riethnordhausen",
    "lat": "51.08333",
    "lng": "11"
  },
  {
    "country": "DE",
    "name": "Rietberg",
    "lat": "51.80924",
    "lng": "8.42841"
  },
  {
    "country": "DE",
    "name": "Rieste",
    "lat": "52.48333",
    "lng": "8.01667"
  },
  {
    "country": "DE",
    "name": "Riestedt",
    "lat": "51.49496",
    "lng": "11.36023"
  },
  {
    "country": "DE",
    "name": "Rieseby",
    "lat": "54.5414",
    "lng": "9.81689"
  },
  {
    "country": "DE",
    "name": "Riesa",
    "lat": "51.30777",
    "lng": "13.29168"
  },
  {
    "country": "DE",
    "name": "Riepsdorf",
    "lat": "54.22611",
    "lng": "10.97242"
  },
  {
    "country": "DE",
    "name": "Rieneck",
    "lat": "50.09349",
    "lng": "9.64797"
  },
  {
    "country": "DE",
    "name": "Rielasingen-Worblingen",
    "lat": "47.73465",
    "lng": "8.84013"
  },
  {
    "country": "DE",
    "name": "Riehl",
    "lat": "50.96686",
    "lng": "6.97572"
  },
  {
    "country": "DE",
    "name": "Riegsee",
    "lat": "47.69867",
    "lng": "11.23391"
  },
  {
    "country": "DE",
    "name": "Riegelsberg",
    "lat": "49.3",
    "lng": "6.93333"
  },
  {
    "country": "DE",
    "name": "Riegel",
    "lat": "48.15111",
    "lng": "7.74915"
  },
  {
    "country": "DE",
    "name": "Riedlingen",
    "lat": "48.15455",
    "lng": "9.47558"
  },
  {
    "country": "DE",
    "name": "Riedering",
    "lat": "47.83874",
    "lng": "12.20778"
  },
  {
    "country": "DE",
    "name": "Riederich",
    "lat": "48.56029",
    "lng": "9.26883"
  },
  {
    "country": "DE",
    "name": "Rieder",
    "lat": "51.73333",
    "lng": "11.16667"
  },
  {
    "country": "DE",
    "name": "Riedenburg",
    "lat": "48.96383",
    "lng": "11.6888"
  },
  {
    "country": "DE",
    "name": "Rieden an der Kötz",
    "lat": "48.38499",
    "lng": "10.25711"
  },
  {
    "country": "DE",
    "name": "Rieden",
    "lat": "50.4",
    "lng": "7.18333"
  },
  {
    "country": "DE",
    "name": "Rieden",
    "lat": "49.32361",
    "lng": "11.94205"
  },
  {
    "country": "DE",
    "name": "Rieden",
    "lat": "47.95",
    "lng": "10.65"
  },
  {
    "country": "DE",
    "name": "Riede",
    "lat": "52.96667",
    "lng": "8.95"
  },
  {
    "country": "DE",
    "name": "Ried",
    "lat": "48.47698",
    "lng": "11.2606"
  },
  {
    "country": "DE",
    "name": "Rickling",
    "lat": "54.01667",
    "lng": "10.16667"
  },
  {
    "country": "DE",
    "name": "Rickert",
    "lat": "54.33333",
    "lng": "9.66667"
  },
  {
    "country": "DE",
    "name": "Rickenbach",
    "lat": "47.61895",
    "lng": "7.97873"
  },
  {
    "country": "DE",
    "name": "Richtenberg",
    "lat": "54.20131",
    "lng": "12.89409"
  },
  {
    "country": "DE",
    "name": "Ribnitz-Damgarten",
    "lat": "54.2422",
    "lng": "12.45666"
  },
  {
    "country": "DE",
    "name": "Ribbesbüttel",
    "lat": "52.43435",
    "lng": "10.50997"
  },
  {
    "country": "DE",
    "name": "Rhumspringe",
    "lat": "51.58333",
    "lng": "10.3"
  },
  {
    "country": "DE",
    "name": "Rhodt unter Rietburg",
    "lat": "49.26972",
    "lng": "8.10778"
  },
  {
    "country": "DE",
    "name": "Rhinow",
    "lat": "52.75094",
    "lng": "12.34194"
  },
  {
    "country": "DE",
    "name": "Rheurdt",
    "lat": "51.46667",
    "lng": "6.46667"
  },
  {
    "country": "DE",
    "name": "Rhens",
    "lat": "50.28125",
    "lng": "7.6175"
  },
  {
    "country": "DE",
    "name": "Rheinzabern",
    "lat": "49.11806",
    "lng": "8.27806"
  },
  {
    "country": "DE",
    "name": "Rheinsberg",
    "lat": "53.09972",
    "lng": "12.89885"
  },
  {
    "country": "DE",
    "name": "Rheinfelden (Baden)",
    "lat": "47.56013",
    "lng": "7.78715"
  },
  {
    "country": "DE",
    "name": "Rheine",
    "lat": "52.28509",
    "lng": "7.44055"
  },
  {
    "country": "DE",
    "name": "Rheinbrohl",
    "lat": "50.5",
    "lng": "7.33333"
  },
  {
    "country": "DE",
    "name": "Rheinbreitbach",
    "lat": "50.61667",
    "lng": "7.23333"
  },
  {
    "country": "DE",
    "name": "Rheinböllen",
    "lat": "50.01127",
    "lng": "7.67249"
  },
  {
    "country": "DE",
    "name": "Rheinberg",
    "lat": "51.54649",
    "lng": "6.59525"
  },
  {
    "country": "DE",
    "name": "Rheinbach",
    "lat": "50.62562",
    "lng": "6.94911"
  },
  {
    "country": "DE",
    "name": "Rheinau",
    "lat": "48.87173",
    "lng": "8.19133"
  },
  {
    "country": "DE",
    "name": "Rheden",
    "lat": "52.05784",
    "lng": "9.78714"
  },
  {
    "country": "DE",
    "name": "Rhede",
    "lat": "53.0602",
    "lng": "7.27127"
  },
  {
    "country": "DE",
    "name": "Rhede",
    "lat": "51.83537",
    "lng": "6.69602"
  },
  {
    "country": "DE",
    "name": "Rheda-Wiedenbrück",
    "lat": "51.84967",
    "lng": "8.30017"
  },
  {
    "country": "DE",
    "name": "Rhaunen",
    "lat": "49.8638",
    "lng": "7.34198"
  },
  {
    "country": "DE",
    "name": "Rhade",
    "lat": "53.32872",
    "lng": "9.1135"
  },
  {
    "country": "DE",
    "name": "Reutlingen",
    "lat": "48.49144",
    "lng": "9.20427"
  },
  {
    "country": "DE",
    "name": "Reuth",
    "lat": "50.61667",
    "lng": "12.21667"
  },
  {
    "country": "DE",
    "name": "Reuth",
    "lat": "49.99052",
    "lng": "11.6948"
  },
  {
    "country": "DE",
    "name": "Reut",
    "lat": "48.5917",
    "lng": "13.12332"
  },
  {
    "country": "DE",
    "name": "Reußen",
    "lat": "51.50109",
    "lng": "12.13044"
  },
  {
    "country": "DE",
    "name": "Retzstadt",
    "lat": "49.9125",
    "lng": "9.88194"
  },
  {
    "country": "DE",
    "name": "Rettenberg",
    "lat": "47.57428",
    "lng": "10.29173"
  },
  {
    "country": "DE",
    "name": "Rettenbach",
    "lat": "49.06667",
    "lng": "12.45"
  },
  {
    "country": "DE",
    "name": "Rettenbach",
    "lat": "48.45881",
    "lng": "10.35238"
  },
  {
    "country": "DE",
    "name": "Retschow",
    "lat": "54.04552",
    "lng": "11.8778"
  },
  {
    "country": "DE",
    "name": "Rethen",
    "lat": "52.37707",
    "lng": "10.47855"
  },
  {
    "country": "DE",
    "name": "Rethem",
    "lat": "52.78621",
    "lng": "9.37862"
  },
  {
    "country": "DE",
    "name": "Retgendorf",
    "lat": "53.72922",
    "lng": "11.50359"
  },
  {
    "country": "DE",
    "name": "Reppenstedt",
    "lat": "53.25",
    "lng": "10.35"
  },
  {
    "country": "DE",
    "name": "Rentweinsdorf",
    "lat": "50.06342",
    "lng": "10.79922"
  },
  {
    "country": "DE",
    "name": "Renningen",
    "lat": "48.76974",
    "lng": "8.93871"
  },
  {
    "country": "DE",
    "name": "Rennertshofen",
    "lat": "48.75943",
    "lng": "11.04544"
  },
  {
    "country": "DE",
    "name": "Rennerod",
    "lat": "50.6082",
    "lng": "8.06697"
  },
  {
    "country": "DE",
    "name": "Rengsdorf",
    "lat": "50.5",
    "lng": "7.5"
  },
  {
    "country": "DE",
    "name": "Rendsburg",
    "lat": "54.30663",
    "lng": "9.66313"
  },
  {
    "country": "DE",
    "name": "Renchen",
    "lat": "48.5885",
    "lng": "8.01321"
  },
  {
    "country": "DE",
    "name": "Remse",
    "lat": "50.85",
    "lng": "12.56667"
  },
  {
    "country": "DE",
    "name": "Remscheid",
    "lat": "51.17983",
    "lng": "7.1925"
  },
  {
    "country": "DE",
    "name": "Remptendorf",
    "lat": "50.53333",
    "lng": "11.65"
  },
  {
    "country": "DE",
    "name": "Remlingen",
    "lat": "52.11367",
    "lng": "10.67408"
  },
  {
    "country": "DE",
    "name": "Remlingen",
    "lat": "49.80477",
    "lng": "9.69484"
  },
  {
    "country": "DE",
    "name": "Remagen",
    "lat": "50.57879",
    "lng": "7.22703"
  },
  {
    "country": "DE",
    "name": "Rellingen",
    "lat": "53.65",
    "lng": "9.81667"
  },
  {
    "country": "DE",
    "name": "Reit im Winkl",
    "lat": "47.67729",
    "lng": "12.47086"
  },
  {
    "country": "DE",
    "name": "Reiskirchen",
    "lat": "50.6",
    "lng": "8.83333"
  },
  {
    "country": "DE",
    "name": "Reischach",
    "lat": "48.29073",
    "lng": "12.7262"
  },
  {
    "country": "DE",
    "name": "Reisbach",
    "lat": "48.57008",
    "lng": "12.62799"
  },
  {
    "country": "DE",
    "name": "Reinstorf",
    "lat": "53.23445",
    "lng": "10.57323"
  },
  {
    "country": "DE",
    "name": "Reinsfeld",
    "lat": "49.68333",
    "lng": "6.88333"
  },
  {
    "country": "DE",
    "name": "Reinsdorf",
    "lat": "50.69775",
    "lng": "12.55555"
  },
  {
    "country": "DE",
    "name": "Reinsberg",
    "lat": "51.00823",
    "lng": "13.36542"
  },
  {
    "country": "DE",
    "name": "Reinickendorf",
    "lat": "52.56667",
    "lng": "13.33333"
  },
  {
    "country": "DE",
    "name": "Reinheim",
    "lat": "49.82923",
    "lng": "8.83572"
  },
  {
    "country": "DE",
    "name": "Reinhausen",
    "lat": "49.03092",
    "lng": "12.11329"
  },
  {
    "country": "DE",
    "name": "Reinhardtsgrimma",
    "lat": "50.8927",
    "lng": "13.75534"
  },
  {
    "country": "DE",
    "name": "Reinhardshausen",
    "lat": "51.11166",
    "lng": "9.07514"
  },
  {
    "country": "DE",
    "name": "Reinfeld",
    "lat": "53.83184",
    "lng": "10.49126"
  },
  {
    "country": "DE",
    "name": "Reinberg",
    "lat": "53.67484",
    "lng": "13.14417"
  },
  {
    "country": "DE",
    "name": "Reinbek",
    "lat": "53.51703",
    "lng": "10.2488"
  },
  {
    "country": "DE",
    "name": "Reimlingen",
    "lat": "48.81667",
    "lng": "10.51667"
  },
  {
    "country": "DE",
    "name": "Reilingen",
    "lat": "49.29833",
    "lng": "8.56417"
  },
  {
    "country": "DE",
    "name": "Reil",
    "lat": "50.01667",
    "lng": "7.11667"
  },
  {
    "country": "DE",
    "name": "Reichling",
    "lat": "47.9228",
    "lng": "10.92847"
  },
  {
    "country": "DE",
    "name": "Reichertshofen",
    "lat": "48.65775",
    "lng": "11.46612"
  },
  {
    "country": "DE",
    "name": "Reichertsheim",
    "lat": "48.2",
    "lng": "12.28333"
  },
  {
    "country": "DE",
    "name": "Reichertshausen",
    "lat": "47.89882",
    "lng": "11.55843"
  },
  {
    "country": "DE",
    "name": "Reichersbeuern",
    "lat": "47.76667",
    "lng": "11.63333"
  },
  {
    "country": "DE",
    "name": "Reichenwalde",
    "lat": "52.26667",
    "lng": "14"
  },
  {
    "country": "DE",
    "name": "Reichenschwand",
    "lat": "49.51384",
    "lng": "11.37274"
  },
  {
    "country": "DE",
    "name": "Reichenberg",
    "lat": "49.73193",
    "lng": "9.91478"
  },
  {
    "country": "DE",
    "name": "Reichenbach-Steegen",
    "lat": "49.5",
    "lng": "7.55"
  },
  {
    "country": "DE",
    "name": "Reichenbach an der Fils",
    "lat": "48.71011",
    "lng": "9.46429"
  },
  {
    "country": "DE",
    "name": "Reichenbach",
    "lat": "51.14144",
    "lng": "14.8027"
  },
  {
    "country": "DE",
    "name": "Reichenbach/Vogtland",
    "lat": "50.62279",
    "lng": "12.30344"
  },
  {
    "country": "DE",
    "name": "Reichenbach",
    "lat": "49.18333",
    "lng": "12.35"
  },
  {
    "country": "DE",
    "name": "Reichelsheim",
    "lat": "50.35638",
    "lng": "8.87446"
  },
  {
    "country": "DE",
    "name": "Reichelsheim",
    "lat": "49.71211",
    "lng": "8.83896"
  },
  {
    "country": "DE",
    "name": "Reichartshausen",
    "lat": "49.355",
    "lng": "8.94528"
  },
  {
    "country": "DE",
    "name": "Reichardtswerben",
    "lat": "51.24851",
    "lng": "11.95349"
  },
  {
    "country": "DE",
    "name": "Rehna",
    "lat": "53.77877",
    "lng": "11.04929"
  },
  {
    "country": "DE",
    "name": "Rehling",
    "lat": "48.48333",
    "lng": "10.93333"
  },
  {
    "country": "DE",
    "name": "Rehfelde",
    "lat": "52.53417",
    "lng": "13.90884"
  },
  {
    "country": "DE",
    "name": "Rehe",
    "lat": "50.63333",
    "lng": "8.11667"
  },
  {
    "country": "DE",
    "name": "Rehden",
    "lat": "52.61024",
    "lng": "8.48093"
  },
  {
    "country": "DE",
    "name": "Rehburg-Loccum",
    "lat": "52.46952",
    "lng": "9.19957"
  },
  {
    "country": "DE",
    "name": "Rehau",
    "lat": "50.24921",
    "lng": "12.03422"
  },
  {
    "country": "DE",
    "name": "Regnitzlosau",
    "lat": "50.3",
    "lng": "12.05"
  },
  {
    "country": "DE",
    "name": "Regis-Breitingen",
    "lat": "51.08883",
    "lng": "12.43841"
  },
  {
    "country": "DE",
    "name": "Regesbostel",
    "lat": "53.38333",
    "lng": "9.65"
  },
  {
    "country": "DE",
    "name": "Regenstauf",
    "lat": "49.12014",
    "lng": "12.13027"
  },
  {
    "country": "DE",
    "name": "Regensburg",
    "lat": "49.01513",
    "lng": "12.10161"
  },
  {
    "country": "DE",
    "name": "Regen",
    "lat": "48.9719",
    "lng": "13.12824"
  },
  {
    "country": "DE",
    "name": "Reeßum",
    "lat": "53.13333",
    "lng": "9.21667"
  },
  {
    "country": "DE",
    "name": "Rees",
    "lat": "51.76263",
    "lng": "6.39778"
  },
  {
    "country": "DE",
    "name": "Redwitz an der Rodach",
    "lat": "50.17323",
    "lng": "11.20833"
  },
  {
    "country": "DE",
    "name": "Rednitzhembach",
    "lat": "49.30095",
    "lng": "11.07997"
  },
  {
    "country": "DE",
    "name": "Recklinghausen",
    "lat": "51.61379",
    "lng": "7.19738"
  },
  {
    "country": "DE",
    "name": "Recke",
    "lat": "52.36885",
    "lng": "7.72116"
  },
  {
    "country": "DE",
    "name": "Rechtsupweg",
    "lat": "53.53333",
    "lng": "7.33333"
  },
  {
    "country": "DE",
    "name": "Rechtmehring",
    "lat": "48.11667",
    "lng": "12.16667"
  },
  {
    "country": "DE",
    "name": "Rechtenbach",
    "lat": "49.98306",
    "lng": "9.50833"
  },
  {
    "country": "DE",
    "name": "Rechlin",
    "lat": "53.33549",
    "lng": "12.72543"
  },
  {
    "country": "DE",
    "name": "Rechenberg-Bienenmühle",
    "lat": "50.73777",
    "lng": "13.53502"
  },
  {
    "country": "DE",
    "name": "Rechberghausen",
    "lat": "48.7308",
    "lng": "9.64419"
  },
  {
    "country": "DE",
    "name": "Ravensburg",
    "lat": "47.78198",
    "lng": "9.61062"
  },
  {
    "country": "DE",
    "name": "Rauschenberg",
    "lat": "50.88329",
    "lng": "8.91864"
  },
  {
    "country": "DE",
    "name": "Raunheim",
    "lat": "50.0132",
    "lng": "8.45253"
  },
  {
    "country": "DE",
    "name": "Rauenberg",
    "lat": "49.26943",
    "lng": "8.70344"
  },
  {
    "country": "DE",
    "name": "Rauen",
    "lat": "52.33227",
    "lng": "14.02797"
  },
  {
    "country": "DE",
    "name": "Raubling",
    "lat": "47.7905",
    "lng": "12.11088"
  },
  {
    "country": "DE",
    "name": "Raubach",
    "lat": "50.57489",
    "lng": "7.62496"
  },
  {
    "country": "DE",
    "name": "Ratzeburg",
    "lat": "53.69965",
    "lng": "10.77256"
  },
  {
    "country": "DE",
    "name": "Rattiszell",
    "lat": "49.02573",
    "lng": "12.65924"
  },
  {
    "country": "DE",
    "name": "Rattenberg",
    "lat": "49.08612",
    "lng": "12.74912"
  },
  {
    "country": "DE",
    "name": "Rattelsdorf",
    "lat": "50.01502",
    "lng": "10.88857"
  },
  {
    "country": "DE",
    "name": "Ratingen",
    "lat": "51.29724",
    "lng": "6.84929"
  },
  {
    "country": "DE",
    "name": "Rathmannsdorf",
    "lat": "50.92993",
    "lng": "14.14224"
  },
  {
    "country": "DE",
    "name": "Rathenow",
    "lat": "52.60659",
    "lng": "12.33696"
  },
  {
    "country": "DE",
    "name": "Rath",
    "lat": "50.92379",
    "lng": "7.0927"
  },
  {
    "country": "DE",
    "name": "Ratekau",
    "lat": "53.95",
    "lng": "10.73333"
  },
  {
    "country": "DE",
    "name": "Rastow",
    "lat": "53.45709",
    "lng": "11.43145"
  },
  {
    "country": "DE",
    "name": "Rastenberg",
    "lat": "51.17496",
    "lng": "11.42029"
  },
  {
    "country": "DE",
    "name": "Rastede",
    "lat": "53.25",
    "lng": "8.2"
  },
  {
    "country": "DE",
    "name": "Rastatt",
    "lat": "48.85851",
    "lng": "8.20965"
  },
  {
    "country": "DE",
    "name": "Raßnitz",
    "lat": "51.39085",
    "lng": "12.09406"
  },
  {
    "country": "DE",
    "name": "Rasdorf",
    "lat": "50.71667",
    "lng": "9.9"
  },
  {
    "country": "DE",
    "name": "Raschau",
    "lat": "50.53127",
    "lng": "12.83312"
  },
  {
    "country": "DE",
    "name": "Rantrum",
    "lat": "54.44062",
    "lng": "9.12872"
  },
  {
    "country": "DE",
    "name": "Ranstadt",
    "lat": "50.35739",
    "lng": "8.98375"
  },
  {
    "country": "DE",
    "name": "Rannungen",
    "lat": "50.16537",
    "lng": "10.20484"
  },
  {
    "country": "DE",
    "name": "Ranis",
    "lat": "50.66132",
    "lng": "11.56912"
  },
  {
    "country": "DE",
    "name": "Rangsdorf",
    "lat": "52.29126",
    "lng": "13.41946"
  },
  {
    "country": "DE",
    "name": "Rangendingen",
    "lat": "48.38168",
    "lng": "8.8894"
  },
  {
    "country": "DE",
    "name": "Randersacker",
    "lat": "49.76021",
    "lng": "9.98277"
  },
  {
    "country": "DE",
    "name": "Ramsthal",
    "lat": "50.14039",
    "lng": "10.06777"
  },
  {
    "country": "DE",
    "name": "Ramstein-Miesenbach",
    "lat": "49.44452",
    "lng": "7.55533"
  },
  {
    "country": "DE",
    "name": "Ramsin",
    "lat": "51.61095",
    "lng": "12.23812"
  },
  {
    "country": "DE",
    "name": "Ramsen",
    "lat": "49.53694",
    "lng": "8.01333"
  },
  {
    "country": "DE",
    "name": "Ramsau",
    "lat": "48.17277",
    "lng": "12.22957"
  },
  {
    "country": "DE",
    "name": "Ramsau",
    "lat": "47.61667",
    "lng": "12.9"
  },
  {
    "country": "DE",
    "name": "Rammingen",
    "lat": "48.51814",
    "lng": "10.17197"
  },
  {
    "country": "DE",
    "name": "Rammenau",
    "lat": "51.15",
    "lng": "14.13333"
  },
  {
    "country": "DE",
    "name": "Rammelsbach",
    "lat": "49.5417",
    "lng": "7.44392"
  },
  {
    "country": "DE",
    "name": "Ramerberg",
    "lat": "48.01806",
    "lng": "12.14513"
  },
  {
    "country": "DE",
    "name": "Rambin",
    "lat": "54.35566",
    "lng": "13.20445"
  },
  {
    "country": "DE",
    "name": "Ramberg",
    "lat": "49.26028",
    "lng": "8.00833"
  },
  {
    "country": "DE",
    "name": "Ralingen",
    "lat": "49.81667",
    "lng": "6.5"
  },
  {
    "country": "DE",
    "name": "Raitenbuch",
    "lat": "49.01468",
    "lng": "11.12486"
  },
  {
    "country": "DE",
    "name": "Raisting",
    "lat": "47.91667",
    "lng": "11.1"
  },
  {
    "country": "DE",
    "name": "Raisdorf",
    "lat": "54.28127",
    "lng": "10.24915"
  },
  {
    "country": "DE",
    "name": "Rain",
    "lat": "48.90496",
    "lng": "12.46871"
  },
  {
    "country": "DE",
    "name": "Rain",
    "lat": "48.69029",
    "lng": "10.91611"
  },
  {
    "country": "DE",
    "name": "Rahnsdorf",
    "lat": "52.44115",
    "lng": "13.68708"
  },
  {
    "country": "DE",
    "name": "Rahden",
    "lat": "52.43367",
    "lng": "8.61263"
  },
  {
    "country": "DE",
    "name": "Raguhn",
    "lat": "51.71167",
    "lng": "12.27531"
  },
  {
    "country": "DE",
    "name": "Raesfeld",
    "lat": "51.76667",
    "lng": "6.85"
  },
  {
    "country": "DE",
    "name": "Radolfzell am Bodensee",
    "lat": "47.74194",
    "lng": "8.97098"
  },
  {
    "country": "DE",
    "name": "Radis",
    "lat": "51.75226",
    "lng": "12.51453"
  },
  {
    "country": "DE",
    "name": "Radibor",
    "lat": "51.24481",
    "lng": "14.39842"
  },
  {
    "country": "DE",
    "name": "Radevormwald",
    "lat": "51.20219",
    "lng": "7.36027"
  },
  {
    "country": "DE",
    "name": "Radegast",
    "lat": "51.65654",
    "lng": "12.09485"
  },
  {
    "country": "DE",
    "name": "Radeburg",
    "lat": "51.21516",
    "lng": "13.7281"
  },
  {
    "country": "DE",
    "name": "Radebeul",
    "lat": "51.10654",
    "lng": "13.66047"
  },
  {
    "country": "DE",
    "name": "Radeberg",
    "lat": "51.11112",
    "lng": "13.91199"
  },
  {
    "country": "DE",
    "name": "Raddestorf",
    "lat": "52.45",
    "lng": "8.96667"
  },
  {
    "country": "DE",
    "name": "Radbruch",
    "lat": "53.31667",
    "lng": "10.28333"
  },
  {
    "country": "DE",
    "name": "Rackwitz",
    "lat": "51.43333",
    "lng": "12.38333"
  },
  {
    "country": "DE",
    "name": "Räckelwitz",
    "lat": "51.25",
    "lng": "14.23333"
  },
  {
    "country": "DE",
    "name": "Raben Steinfeld",
    "lat": "53.60141",
    "lng": "11.50487"
  },
  {
    "country": "DE",
    "name": "Rabenau",
    "lat": "50.96484",
    "lng": "13.64305"
  },
  {
    "country": "DE",
    "name": "Quitzdorf",
    "lat": "51.28333",
    "lng": "14.76667"
  },
  {
    "country": "DE",
    "name": "Quierschied",
    "lat": "49.31667",
    "lng": "7.05"
  },
  {
    "country": "DE",
    "name": "Quickborn",
    "lat": "53.72831",
    "lng": "9.90934"
  },
  {
    "country": "DE",
    "name": "Quern",
    "lat": "54.75",
    "lng": "9.71667"
  },
  {
    "country": "DE",
    "name": "Querfurt",
    "lat": "51.38124",
    "lng": "11.60047"
  },
  {
    "country": "DE",
    "name": "Quellendorf",
    "lat": "51.74916",
    "lng": "12.12796"
  },
  {
    "country": "DE",
    "name": "Queis",
    "lat": "51.47626",
    "lng": "12.13455"
  },
  {
    "country": "DE",
    "name": "Queidersbach",
    "lat": "49.36667",
    "lng": "7.63333"
  },
  {
    "country": "DE",
    "name": "Quedlinburg",
    "lat": "51.78843",
    "lng": "11.15006"
  },
  {
    "country": "DE",
    "name": "Quarnbek",
    "lat": "54.33333",
    "lng": "9.98333"
  },
  {
    "country": "DE",
    "name": "Quakenbrück",
    "lat": "52.67502",
    "lng": "7.94983"
  },
  {
    "country": "DE",
    "name": "Pyrbaum",
    "lat": "49.29622",
    "lng": "11.28655"
  },
  {
    "country": "DE",
    "name": "Putzbrunn",
    "lat": "48.07579",
    "lng": "11.71572"
  },
  {
    "country": "DE",
    "name": "Püttlingen",
    "lat": "49.2855",
    "lng": "6.88723"
  },
  {
    "country": "DE",
    "name": "Putlitz",
    "lat": "53.24899",
    "lng": "12.04179"
  },
  {
    "country": "DE",
    "name": "Putbus",
    "lat": "54.35511",
    "lng": "13.47634"
  },
  {
    "country": "DE",
    "name": "Puschwitz",
    "lat": "51.25501",
    "lng": "14.30111"
  },
  {
    "country": "DE",
    "name": "Puschendorf",
    "lat": "49.52398",
    "lng": "10.83192"
  },
  {
    "country": "DE",
    "name": "Pürgen",
    "lat": "48.02472",
    "lng": "10.92213"
  },
  {
    "country": "DE",
    "name": "Pullenreuth",
    "lat": "49.93333",
    "lng": "12"
  },
  {
    "country": "DE",
    "name": "Pullach im Isartal",
    "lat": "48.06122",
    "lng": "11.52148"
  },
  {
    "country": "DE",
    "name": "Pulheim",
    "lat": "50.99965",
    "lng": "6.80632"
  },
  {
    "country": "DE",
    "name": "Puderbach",
    "lat": "50.6",
    "lng": "7.61667"
  },
  {
    "country": "DE",
    "name": "Puchheim",
    "lat": "48.15",
    "lng": "11.35"
  },
  {
    "country": "DE",
    "name": "Püchersreuth",
    "lat": "49.75",
    "lng": "12.23333"
  },
  {
    "country": "DE",
    "name": "Prutting",
    "lat": "47.89321",
    "lng": "12.20238"
  },
  {
    "country": "DE",
    "name": "Briamhan",
    "lat": "50.20785",
    "lng": "6.42019"
  },
  {
    "country": "DE",
    "name": "Prötzel",
    "lat": "52.63723",
    "lng": "13.98783"
  },
  {
    "country": "DE",
    "name": "Prosselsheim",
    "lat": "49.86309",
    "lng": "10.12666"
  },
  {
    "country": "DE",
    "name": "Pronstorf",
    "lat": "53.95",
    "lng": "10.46667"
  },
  {
    "country": "DE",
    "name": "Prohn",
    "lat": "54.36901",
    "lng": "13.02369"
  },
  {
    "country": "DE",
    "name": "Probstzella",
    "lat": "50.53333",
    "lng": "11.38333"
  },
  {
    "country": "DE",
    "name": "Probsteierhagen",
    "lat": "54.36153",
    "lng": "10.28772"
  },
  {
    "country": "DE",
    "name": "Pritzwalk",
    "lat": "53.14945",
    "lng": "12.17405"
  },
  {
    "country": "DE",
    "name": "Prittriching",
    "lat": "48.20074",
    "lng": "10.92801"
  },
  {
    "country": "DE",
    "name": "Prittitz",
    "lat": "51.14996",
    "lng": "11.9302"
  },
  {
    "country": "DE",
    "name": "Prisdorf",
    "lat": "53.68333",
    "lng": "9.75"
  },
  {
    "country": "DE",
    "name": "Priestewitz",
    "lat": "51.25",
    "lng": "13.51667"
  },
  {
    "country": "DE",
    "name": "Priesendorf",
    "lat": "49.9075",
    "lng": "10.71183"
  },
  {
    "country": "DE",
    "name": "Prien am Chiemsee",
    "lat": "47.85602",
    "lng": "12.34623"
  },
  {
    "country": "DE",
    "name": "Prichsenstadt",
    "lat": "49.81933",
    "lng": "10.34773"
  },
  {
    "country": "DE",
    "name": "Preußisch Oldendorf",
    "lat": "52.30589",
    "lng": "8.49341"
  },
  {
    "country": "DE",
    "name": "Pretzschendorf",
    "lat": "50.87385",
    "lng": "13.52499"
  },
  {
    "country": "DE",
    "name": "Pretzsch",
    "lat": "51.71466",
    "lng": "12.80663"
  },
  {
    "country": "DE",
    "name": "Pretzier",
    "lat": "52.83224",
    "lng": "11.26105"
  },
  {
    "country": "DE",
    "name": "Pretzfeld",
    "lat": "49.75454",
    "lng": "11.1743"
  },
  {
    "country": "DE",
    "name": "Prettin",
    "lat": "51.66077",
    "lng": "12.92353"
  },
  {
    "country": "DE",
    "name": "Pressig",
    "lat": "50.35245",
    "lng": "11.30969"
  },
  {
    "country": "DE",
    "name": "Presseck",
    "lat": "50.22804",
    "lng": "11.55508"
  },
  {
    "country": "DE",
    "name": "Pressath",
    "lat": "49.76859",
    "lng": "11.93972"
  },
  {
    "country": "DE",
    "name": "Prenzlauer Berg",
    "lat": "52.53878",
    "lng": "13.42443"
  },
  {
    "country": "DE",
    "name": "Prenzlau",
    "lat": "53.31625",
    "lng": "13.86261"
  },
  {
    "country": "DE",
    "name": "Premnitz",
    "lat": "52.53184",
    "lng": "12.34845"
  },
  {
    "country": "DE",
    "name": "Preetz",
    "lat": "54.35017",
    "lng": "12.98936"
  },
  {
    "country": "DE",
    "name": "Preetz",
    "lat": "54.2354",
    "lng": "10.27795"
  },
  {
    "country": "DE",
    "name": "Prebitz",
    "lat": "49.83333",
    "lng": "11.68333"
  },
  {
    "country": "DE",
    "name": "Pratau",
    "lat": "51.84226",
    "lng": "12.64373"
  },
  {
    "country": "DE",
    "name": "Prackenbach",
    "lat": "49.09543",
    "lng": "12.82614"
  },
  {
    "country": "DE",
    "name": "Pracht",
    "lat": "50.76031",
    "lng": "7.64871"
  },
  {
    "country": "DE",
    "name": "Poxdorf",
    "lat": "49.93642",
    "lng": "11.12211"
  },
  {
    "country": "DE",
    "name": "Pouch",
    "lat": "51.62324",
    "lng": "12.40133"
  },
  {
    "country": "DE",
    "name": "Pottum",
    "lat": "50.6",
    "lng": "8"
  },
  {
    "country": "DE",
    "name": "Pöttmes",
    "lat": "48.58383",
    "lng": "11.08762"
  },
  {
    "country": "DE",
    "name": "Pottenstein",
    "lat": "49.77131",
    "lng": "11.40784"
  },
  {
    "country": "DE",
    "name": "Potsdam",
    "lat": "52.39886",
    "lng": "13.06566"
  },
  {
    "country": "DE",
    "name": "Postmünster",
    "lat": "48.41667",
    "lng": "12.9"
  },
  {
    "country": "DE",
    "name": "Postau",
    "lat": "48.65",
    "lng": "12.33333"
  },
  {
    "country": "DE",
    "name": "Pößneck",
    "lat": "50.69358",
    "lng": "11.59229"
  },
  {
    "country": "DE",
    "name": "Poseritz",
    "lat": "54.29811",
    "lng": "13.27492"
  },
  {
    "country": "DE",
    "name": "Porz am Rhein",
    "lat": "50.88637",
    "lng": "7.0583"
  },
  {
    "country": "DE",
    "name": "Porta Westfalica",
    "lat": "52.22961",
    "lng": "8.91612"
  },
  {
    "country": "DE",
    "name": "Porschdorf",
    "lat": "50.9418",
    "lng": "14.12687"
  },
  {
    "country": "DE",
    "name": "Pörnbach",
    "lat": "48.61667",
    "lng": "11.46667"
  },
  {
    "country": "DE",
    "name": "Poppenricht",
    "lat": "49.47557",
    "lng": "11.79778"
  },
  {
    "country": "DE",
    "name": "Poppenhausen",
    "lat": "50.48793",
    "lng": "9.86795"
  },
  {
    "country": "DE",
    "name": "Poppenhausen",
    "lat": "50.09999",
    "lng": "10.14244"
  },
  {
    "country": "DE",
    "name": "Poppenbüttel",
    "lat": "53.65917",
    "lng": "10.08472"
  },
  {
    "country": "DE",
    "name": "Ponitz",
    "lat": "50.85762",
    "lng": "12.42309"
  },
  {
    "country": "DE",
    "name": "Pommersfelden",
    "lat": "49.76667",
    "lng": "10.81667"
  },
  {
    "country": "DE",
    "name": "Pommelsbrunn",
    "lat": "49.50437",
    "lng": "11.51101"
  },
  {
    "country": "DE",
    "name": "Pölzig",
    "lat": "50.95",
    "lng": "12.2"
  },
  {
    "country": "DE",
    "name": "Polsingen",
    "lat": "48.92067",
    "lng": "10.7115"
  },
  {
    "country": "DE",
    "name": "Polling",
    "lat": "48.21667",
    "lng": "12.56667"
  },
  {
    "country": "DE",
    "name": "Polling",
    "lat": "47.81102",
    "lng": "11.13241"
  },
  {
    "country": "DE",
    "name": "Pollhagen",
    "lat": "52.38529",
    "lng": "9.18813"
  },
  {
    "country": "DE",
    "name": "Polleben",
    "lat": "51.57966",
    "lng": "11.59931"
  },
  {
    "country": "DE",
    "name": "Polle",
    "lat": "51.89871",
    "lng": "9.40386"
  },
  {
    "country": "DE",
    "name": "Poll",
    "lat": "50.91256",
    "lng": "6.99057"
  },
  {
    "country": "DE",
    "name": "Pölitz",
    "lat": "53.77303",
    "lng": "10.38276"
  },
  {
    "country": "DE",
    "name": "Polch",
    "lat": "50.29973",
    "lng": "7.31315"
  },
  {
    "country": "DE",
    "name": "Poing",
    "lat": "48.17004",
    "lng": "11.81863"
  },
  {
    "country": "DE",
    "name": "Pöhla",
    "lat": "50.51143",
    "lng": "12.81889"
  },
  {
    "country": "DE",
    "name": "Pöhl",
    "lat": "50.39311",
    "lng": "12.32908"
  },
  {
    "country": "DE",
    "name": "Podelzig",
    "lat": "52.47175",
    "lng": "14.53465"
  },
  {
    "country": "DE",
    "name": "Pocking",
    "lat": "48.40149",
    "lng": "13.31315"
  },
  {
    "country": "DE",
    "name": "Pöcking",
    "lat": "47.96667",
    "lng": "11.3"
  },
  {
    "country": "DE",
    "name": "Pockau",
    "lat": "50.7",
    "lng": "13.23333"
  },
  {
    "country": "DE",
    "name": "Pobershau",
    "lat": "50.64079",
    "lng": "13.21776"
  },
  {
    "country": "DE",
    "name": "Pluwig",
    "lat": "49.68976",
    "lng": "6.71239"
  },
  {
    "country": "DE",
    "name": "Plüderhausen",
    "lat": "48.79875",
    "lng": "9.59587"
  },
  {
    "country": "DE",
    "name": "Plötzky",
    "lat": "52.05207",
    "lng": "11.80202"
  },
  {
    "country": "DE",
    "name": "Plötzkau",
    "lat": "51.75",
    "lng": "11.68333"
  },
  {
    "country": "DE",
    "name": "Plößberg",
    "lat": "49.91977",
    "lng": "11.86883"
  },
  {
    "country": "DE",
    "name": "Plön",
    "lat": "54.16241",
    "lng": "10.42333"
  },
  {
    "country": "DE",
    "name": "Plochingen",
    "lat": "48.71067",
    "lng": "9.41949"
  },
  {
    "country": "DE",
    "name": "Pliezhausen",
    "lat": "48.55934",
    "lng": "9.20749"
  },
  {
    "country": "DE",
    "name": "Pliening",
    "lat": "48.19556",
    "lng": "11.80069"
  },
  {
    "country": "DE",
    "name": "Pleystein",
    "lat": "49.64907",
    "lng": "12.40631"
  },
  {
    "country": "DE",
    "name": "Plettenberg",
    "lat": "51.20949",
    "lng": "7.87261"
  },
  {
    "country": "DE",
    "name": "Plessa",
    "lat": "51.46667",
    "lng": "13.61667"
  },
  {
    "country": "DE",
    "name": "Pleiskirchen",
    "lat": "48.30713",
    "lng": "12.59832"
  },
  {
    "country": "DE",
    "name": "Pleinfeld",
    "lat": "49.10473",
    "lng": "10.98194"
  },
  {
    "country": "DE",
    "name": "Pleidelsheim",
    "lat": "48.9592",
    "lng": "9.20311"
  },
  {
    "country": "DE",
    "name": "Plauen",
    "lat": "50.4973",
    "lng": "12.13782"
  },
  {
    "country": "DE",
    "name": "Plaue",
    "lat": "50.77835",
    "lng": "10.89969"
  },
  {
    "country": "DE",
    "name": "Plau am See",
    "lat": "53.45821",
    "lng": "12.26246"
  },
  {
    "country": "DE",
    "name": "Plattling",
    "lat": "48.77866",
    "lng": "12.87509"
  },
  {
    "country": "DE",
    "name": "Plattenburg",
    "lat": "52.95919",
    "lng": "12.02951"
  },
  {
    "country": "DE",
    "name": "Plate",
    "lat": "53.55145",
    "lng": "11.50927"
  },
  {
    "country": "DE",
    "name": "Plankstadt",
    "lat": "49.39444",
    "lng": "8.59611"
  },
  {
    "country": "DE",
    "name": "Planegg",
    "lat": "48.10672",
    "lng": "11.42483"
  },
  {
    "country": "DE",
    "name": "Plaidt",
    "lat": "50.3926",
    "lng": "7.39251"
  },
  {
    "country": "DE",
    "name": "Pittenhart",
    "lat": "47.97724",
    "lng": "12.38997"
  },
  {
    "country": "DE",
    "name": "Pirna",
    "lat": "50.95843",
    "lng": "13.93702"
  },
  {
    "country": "DE",
    "name": "Pirmasens",
    "lat": "49.20145",
    "lng": "7.60529"
  },
  {
    "country": "DE",
    "name": "Pirk",
    "lat": "49.63333",
    "lng": "12.16667"
  },
  {
    "country": "DE",
    "name": "Pinzberg",
    "lat": "49.68971",
    "lng": "11.10207"
  },
  {
    "country": "DE",
    "name": "Pinnow",
    "lat": "53.60164",
    "lng": "11.54577"
  },
  {
    "country": "DE",
    "name": "Pinneberg",
    "lat": "53.66732",
    "lng": "9.78936"
  },
  {
    "country": "DE",
    "name": "Pilsting",
    "lat": "48.70116",
    "lng": "12.65105"
  },
  {
    "country": "DE",
    "name": "Pilsach",
    "lat": "49.32137",
    "lng": "11.50311"
  },
  {
    "country": "DE",
    "name": "Piesteritz",
    "lat": "51.86956",
    "lng": "12.59835"
  },
  {
    "country": "DE",
    "name": "Piesport",
    "lat": "49.8864",
    "lng": "6.91649"
  },
  {
    "country": "DE",
    "name": "Pielenhofen",
    "lat": "49.07235",
    "lng": "11.95699"
  },
  {
    "country": "DE",
    "name": "Piding",
    "lat": "47.76667",
    "lng": "12.91667"
  },
  {
    "country": "DE",
    "name": "Philippsthal",
    "lat": "50.83948",
    "lng": "10.00906"
  },
  {
    "country": "DE",
    "name": "Philippsburg",
    "lat": "49.2317",
    "lng": "8.46074"
  },
  {
    "country": "DE",
    "name": "Pfungstadt",
    "lat": "49.80557",
    "lng": "8.60307"
  },
  {
    "country": "DE",
    "name": "Pfullingen",
    "lat": "48.46458",
    "lng": "9.22796"
  },
  {
    "country": "DE",
    "name": "Pfullendorf",
    "lat": "47.9261",
    "lng": "9.2578"
  },
  {
    "country": "DE",
    "name": "Pfronten",
    "lat": "47.5822",
    "lng": "10.54962"
  },
  {
    "country": "DE",
    "name": "Pfronstetten",
    "lat": "48.27641",
    "lng": "9.35995"
  },
  {
    "country": "DE",
    "name": "Pfreimd",
    "lat": "49.49114",
    "lng": "12.18069"
  },
  {
    "country": "DE",
    "name": "Pforzheim",
    "lat": "48.88436",
    "lng": "8.69892"
  },
  {
    "country": "DE",
    "name": "Pforzen",
    "lat": "47.92997",
    "lng": "10.61357"
  },
  {
    "country": "DE",
    "name": "Pfofeld",
    "lat": "49.1059",
    "lng": "10.83664"
  },
  {
    "country": "DE",
    "name": "Pfeffenhausen",
    "lat": "48.66466",
    "lng": "11.96594"
  },
  {
    "country": "DE",
    "name": "Pfeffelbach",
    "lat": "49.53948",
    "lng": "7.32768"
  },
  {
    "country": "DE",
    "name": "Pfedelbach",
    "lat": "49.17806",
    "lng": "9.505"
  },
  {
    "country": "DE",
    "name": "Pfatter",
    "lat": "48.96309",
    "lng": "12.38254"
  },
  {
    "country": "DE",
    "name": "Pfarrweisach",
    "lat": "50.15",
    "lng": "10.73333"
  },
  {
    "country": "DE",
    "name": "Pfarrkirchen",
    "lat": "48.43205",
    "lng": "12.93812"
  },
  {
    "country": "DE",
    "name": "Pfalzgrafenweiler",
    "lat": "48.5265",
    "lng": "8.56582"
  },
  {
    "country": "DE",
    "name": "Pfakofen",
    "lat": "48.85822",
    "lng": "12.22744"
  },
  {
    "country": "DE",
    "name": "Pfaffroda",
    "lat": "50.86134",
    "lng": "12.51497"
  },
  {
    "country": "DE",
    "name": "Pfaffing",
    "lat": "48.05456",
    "lng": "12.10917"
  },
  {
    "country": "DE",
    "name": "Pfaffenweiler",
    "lat": "47.93333",
    "lng": "7.75"
  },
  {
    "country": "DE",
    "name": "Pfaffen-Schwabenheim",
    "lat": "49.85",
    "lng": "7.95"
  },
  {
    "country": "DE",
    "name": "Pfaffenhofen an der Roth",
    "lat": "48.35454",
    "lng": "10.16184"
  },
  {
    "country": "DE",
    "name": "Pfaffenhofen an der Ilm",
    "lat": "48.53053",
    "lng": "11.505"
  },
  {
    "country": "DE",
    "name": "Pfaffenhofen",
    "lat": "49.06444",
    "lng": "8.97639"
  },
  {
    "country": "DE",
    "name": "Pfaffenhofen",
    "lat": "48.39334",
    "lng": "11.20563"
  },
  {
    "country": "DE",
    "name": "Pfaffenhausen",
    "lat": "48.11878",
    "lng": "10.45504"
  },
  {
    "country": "DE",
    "name": "Pettstadt",
    "lat": "49.82996",
    "lng": "10.92839"
  },
  {
    "country": "DE",
    "name": "Petting",
    "lat": "47.91232",
    "lng": "12.81512"
  },
  {
    "country": "DE",
    "name": "Pettendorf",
    "lat": "49.35475",
    "lng": "12.35926"
  },
  {
    "country": "DE",
    "name": "Petershausen",
    "lat": "48.40967",
    "lng": "11.47056"
  },
  {
    "country": "DE",
    "name": "Petershagen",
    "lat": "52.52078",
    "lng": "13.78748"
  },
  {
    "country": "DE",
    "name": "Petershagen",
    "lat": "52.37513",
    "lng": "8.96538"
  },
  {
    "country": "DE",
    "name": "Petersdorf",
    "lat": "48.51667",
    "lng": "11.03333"
  },
  {
    "country": "DE",
    "name": "Petersaurach",
    "lat": "49.3",
    "lng": "10.75"
  },
  {
    "country": "DE",
    "name": "Perlesreut",
    "lat": "48.78181",
    "lng": "13.4384"
  },
  {
    "country": "DE",
    "name": "Perleberg",
    "lat": "53.07583",
    "lng": "11.85739"
  },
  {
    "country": "DE",
    "name": "Perkam",
    "lat": "48.85528",
    "lng": "12.43979"
  },
  {
    "country": "DE",
    "name": "Perach",
    "lat": "48.26667",
    "lng": "12.76667"
  },
  {
    "country": "DE",
    "name": "Penzlin",
    "lat": "53.504",
    "lng": "13.08407"
  },
  {
    "country": "DE",
    "name": "Penzing",
    "lat": "48.07481",
    "lng": "10.92745"
  },
  {
    "country": "DE",
    "name": "Penzberg",
    "lat": "47.75293",
    "lng": "11.377"
  },
  {
    "country": "DE",
    "name": "Pentling",
    "lat": "48.98343",
    "lng": "12.0587"
  },
  {
    "country": "DE",
    "name": "Pennigsehl",
    "lat": "52.64181",
    "lng": "9.0263"
  },
  {
    "country": "DE",
    "name": "Penkun",
    "lat": "53.29695",
    "lng": "14.23616"
  },
  {
    "country": "DE",
    "name": "Penig",
    "lat": "50.93336",
    "lng": "12.70422"
  },
  {
    "country": "DE",
    "name": "Pemfling",
    "lat": "49.26667",
    "lng": "12.61667"
  },
  {
    "country": "DE",
    "name": "Pelm",
    "lat": "50.23188",
    "lng": "6.69076"
  },
  {
    "country": "DE",
    "name": "Pellworm",
    "lat": "54.5161",
    "lng": "8.64512"
  },
  {
    "country": "DE",
    "name": "Pellingen",
    "lat": "49.67552",
    "lng": "6.67085"
  },
  {
    "country": "DE",
    "name": "Peitz",
    "lat": "51.85841",
    "lng": "14.41138"
  },
  {
    "country": "DE",
    "name": "Peiting",
    "lat": "47.79549",
    "lng": "10.92951"
  },
  {
    "country": "DE",
    "name": "Peißenberg",
    "lat": "47.80466",
    "lng": "11.0699"
  },
  {
    "country": "DE",
    "name": "Peißen",
    "lat": "51.74347",
    "lng": "11.75756"
  },
  {
    "country": "DE",
    "name": "Peißen",
    "lat": "51.50265",
    "lng": "12.05737"
  },
  {
    "country": "DE",
    "name": "Peine",
    "lat": "52.31928",
    "lng": "10.2352"
  },
  {
    "country": "DE",
    "name": "Pegnitz",
    "lat": "49.75216",
    "lng": "11.54187"
  },
  {
    "country": "DE",
    "name": "Pegau",
    "lat": "51.16715",
    "lng": "12.25144"
  },
  {
    "country": "DE",
    "name": "Pechbrunn",
    "lat": "49.96667",
    "lng": "12.16667"
  },
  {
    "country": "DE",
    "name": "Pausa",
    "lat": "50.58172",
    "lng": "11.99732"
  },
  {
    "country": "DE",
    "name": "Paunzhausen",
    "lat": "48.47486",
    "lng": "11.56463"
  },
  {
    "country": "DE",
    "name": "Paulinenaue",
    "lat": "52.67701",
    "lng": "12.71067"
  },
  {
    "country": "DE",
    "name": "Pattensen",
    "lat": "52.26448",
    "lng": "9.76436"
  },
  {
    "country": "DE",
    "name": "Patersdorf",
    "lat": "49.01667",
    "lng": "12.98333"
  },
  {
    "country": "DE",
    "name": "Pastetten",
    "lat": "48.19911",
    "lng": "11.94368"
  },
  {
    "country": "DE",
    "name": "Passau",
    "lat": "48.5665",
    "lng": "13.43122"
  },
  {
    "country": "DE",
    "name": "Pasing",
    "lat": "48.14146",
    "lng": "11.45599"
  },
  {
    "country": "DE",
    "name": "Pasewalk",
    "lat": "53.50627",
    "lng": "13.98997"
  },
  {
    "country": "DE",
    "name": "Partenstein",
    "lat": "50.04176",
    "lng": "9.51991"
  },
  {
    "country": "DE",
    "name": "Partenheim",
    "lat": "49.88389",
    "lng": "8.08222"
  },
  {
    "country": "DE",
    "name": "Parsberg",
    "lat": "49.16074",
    "lng": "11.71834"
  },
  {
    "country": "DE",
    "name": "Parsau",
    "lat": "52.53471",
    "lng": "10.8902"
  },
  {
    "country": "DE",
    "name": "Parkstetten",
    "lat": "48.91667",
    "lng": "12.6"
  },
  {
    "country": "DE",
    "name": "Parkstein",
    "lat": "49.72921",
    "lng": "12.06755"
  },
  {
    "country": "DE",
    "name": "Parchim",
    "lat": "53.42631",
    "lng": "11.84875"
  },
  {
    "country": "DE",
    "name": "Pappenheim",
    "lat": "50.79631",
    "lng": "10.47489"
  },
  {
    "country": "DE",
    "name": "Pappenheim",
    "lat": "48.93383",
    "lng": "10.97431"
  },
  {
    "country": "DE",
    "name": "Papendorf",
    "lat": "54.03523",
    "lng": "12.13263"
  },
  {
    "country": "DE",
    "name": "Papenburg",
    "lat": "53.07738",
    "lng": "7.40444"
  },
  {
    "country": "DE",
    "name": "Panschwitz-Kuckau",
    "lat": "51.23333",
    "lng": "14.2"
  },
  {
    "country": "DE",
    "name": "Pankow",
    "lat": "52.56926",
    "lng": "13.40186"
  },
  {
    "country": "DE",
    "name": "Panker",
    "lat": "54.33333",
    "lng": "10.56667"
  },
  {
    "country": "DE",
    "name": "Pampow",
    "lat": "53.75513",
    "lng": "12.60815"
  },
  {
    "country": "DE",
    "name": "Palzem",
    "lat": "49.56667",
    "lng": "6.36667"
  },
  {
    "country": "DE",
    "name": "Palling",
    "lat": "48.00204",
    "lng": "12.63702"
  },
  {
    "country": "DE",
    "name": "Painten",
    "lat": "48.99731",
    "lng": "11.81947"
  },
  {
    "country": "DE",
    "name": "Pahlen",
    "lat": "54.26667",
    "lng": "9.3"
  },
  {
    "country": "DE",
    "name": "Pähl",
    "lat": "47.9",
    "lng": "11.18333"
  },
  {
    "country": "DE",
    "name": "Paderborn",
    "lat": "51.71905",
    "lng": "8.75439"
  },
  {
    "country": "DE",
    "name": "Padenstedt",
    "lat": "54.05",
    "lng": "9.91667"
  },
  {
    "country": "DE",
    "name": "Oyten",
    "lat": "53.05",
    "lng": "9.01667"
  },
  {
    "country": "DE",
    "name": "Owschlag",
    "lat": "54.39336",
    "lng": "9.59243"
  },
  {
    "country": "DE",
    "name": "Owingen",
    "lat": "47.80967",
    "lng": "9.17173"
  },
  {
    "country": "DE",
    "name": "Owen",
    "lat": "48.58742",
    "lng": "9.44978"
  },
  {
    "country": "DE",
    "name": "Oeversee",
    "lat": "54.7",
    "lng": "9.43333"
  },
  {
    "country": "DE",
    "name": "Overath",
    "lat": "50.93275",
    "lng": "7.28389"
  },
  {
    "country": "DE",
    "name": "Ovelgönne",
    "lat": "53.34189",
    "lng": "8.42179"
  },
  {
    "country": "DE",
    "name": "Ötzingen",
    "lat": "50.5",
    "lng": "7.83333"
  },
  {
    "country": "DE",
    "name": "Otzing",
    "lat": "48.76134",
    "lng": "12.80877"
  },
  {
    "country": "DE",
    "name": "Ottweiler",
    "lat": "49.40133",
    "lng": "7.16424"
  },
  {
    "country": "DE",
    "name": "Ottrau",
    "lat": "50.80599",
    "lng": "9.38575"
  },
  {
    "country": "DE",
    "name": "Ottobrunn",
    "lat": "48.06489",
    "lng": "11.66327"
  },
  {
    "country": "DE",
    "name": "Ottobeuren",
    "lat": "47.9413",
    "lng": "10.29971"
  },
  {
    "country": "DE",
    "name": "Otterwisch",
    "lat": "51.2",
    "lng": "12.61667"
  },
  {
    "country": "DE",
    "name": "Ottersweier",
    "lat": "48.67022",
    "lng": "8.11323"
  },
  {
    "country": "DE",
    "name": "Otterstadt",
    "lat": "49.37222",
    "lng": "8.44778"
  },
  {
    "country": "DE",
    "name": "Ottersheim",
    "lat": "49.19129",
    "lng": "8.23176"
  },
  {
    "country": "DE",
    "name": "Ottersberg",
    "lat": "53.1099",
    "lng": "9.14408"
  },
  {
    "country": "DE",
    "name": "Otterndorf",
    "lat": "53.80908",
    "lng": "8.90068"
  },
  {
    "country": "DE",
    "name": "Otterfing",
    "lat": "47.90898",
    "lng": "11.67546"
  },
  {
    "country": "DE",
    "name": "Otterberg",
    "lat": "49.50301",
    "lng": "7.76995"
  },
  {
    "country": "DE",
    "name": "Otterbach",
    "lat": "49.48554",
    "lng": "7.7345"
  },
  {
    "country": "DE",
    "name": "Otter",
    "lat": "53.24015",
    "lng": "9.74247"
  },
  {
    "country": "DE",
    "name": "Ottenstein",
    "lat": "51.94707",
    "lng": "9.407"
  },
  {
    "country": "DE",
    "name": "Ottensoos",
    "lat": "49.50949",
    "lng": "11.34158"
  },
  {
    "country": "DE",
    "name": "Ottensen",
    "lat": "53.55",
    "lng": "9.91667"
  },
  {
    "country": "DE",
    "name": "Ottenhofen",
    "lat": "48.21667",
    "lng": "11.88333"
  },
  {
    "country": "DE",
    "name": "Ottenhofen",
    "lat": "48.7356",
    "lng": "8.12981"
  },
  {
    "country": "DE",
    "name": "Ottendorf-Okrilla",
    "lat": "51.18333",
    "lng": "13.83333"
  },
  {
    "country": "DE",
    "name": "Ottenbach",
    "lat": "48.73649",
    "lng": "9.74844"
  },
  {
    "country": "DE",
    "name": "Ötisheim",
    "lat": "48.96667",
    "lng": "8.8"
  },
  {
    "country": "DE",
    "name": "Ötigheim",
    "lat": "48.89085",
    "lng": "8.23442"
  },
  {
    "country": "DE",
    "name": "Oststeinbek",
    "lat": "53.54321",
    "lng": "10.16939"
  },
  {
    "country": "DE",
    "name": "Ostseebad Sellin",
    "lat": "54.37846",
    "lng": "13.69394"
  },
  {
    "country": "DE",
    "name": "Ostseebad Prerow",
    "lat": "54.44469",
    "lng": "12.57677"
  },
  {
    "country": "DE",
    "name": "Ostseebad Kühlungsborn",
    "lat": "54.15035",
    "lng": "11.75994"
  },
  {
    "country": "DE",
    "name": "Seeheilbad Graal-Müritz",
    "lat": "54.25124",
    "lng": "12.25139"
  },
  {
    "country": "DE",
    "name": "Ostseebad Göhren",
    "lat": "54.3414",
    "lng": "13.73823"
  },
  {
    "country": "DE",
    "name": "Ostseebad Dierhagen",
    "lat": "54.29243",
    "lng": "12.35799"
  },
  {
    "country": "DE",
    "name": "Ostseebad Boltenhagen",
    "lat": "53.98779",
    "lng": "11.20193"
  },
  {
    "country": "DE",
    "name": "Ostseebad Binz",
    "lat": "54.39995",
    "lng": "13.61052"
  },
  {
    "country": "DE",
    "name": "Ostritz",
    "lat": "51.01451",
    "lng": "14.93059"
  },
  {
    "country": "DE",
    "name": "Östringen",
    "lat": "49.21911",
    "lng": "8.71192"
  },
  {
    "country": "DE",
    "name": "Ostrhauderfehn",
    "lat": "53.13333",
    "lng": "7.61667"
  },
  {
    "country": "DE",
    "name": "Ostrau",
    "lat": "51.20639",
    "lng": "12.88421"
  },
  {
    "country": "DE",
    "name": "Ostrach",
    "lat": "47.95",
    "lng": "9.38333"
  },
  {
    "country": "DE",
    "name": "Osthofen",
    "lat": "49.70382",
    "lng": "8.32419"
  },
  {
    "country": "DE",
    "name": "Ostheim vor der Rhön",
    "lat": "50.45996",
    "lng": "10.23057"
  },
  {
    "country": "DE",
    "name": "Ostheim",
    "lat": "50.93117",
    "lng": "7.04412"
  },
  {
    "country": "DE",
    "name": "Osterwieck",
    "lat": "51.9699",
    "lng": "10.71042"
  },
  {
    "country": "DE",
    "name": "Osterspai",
    "lat": "50.24453",
    "lng": "7.61227"
  },
  {
    "country": "DE",
    "name": "Osterrönfeld",
    "lat": "54.29013",
    "lng": "9.699"
  },
  {
    "country": "DE",
    "name": "Osterode am Harz",
    "lat": "51.72686",
    "lng": "10.25089"
  },
  {
    "country": "DE",
    "name": "Osternienburg",
    "lat": "51.79384",
    "lng": "12.02616"
  },
  {
    "country": "DE",
    "name": "Osterholz-Scharmbeck",
    "lat": "53.22698",
    "lng": "8.79528"
  },
  {
    "country": "DE",
    "name": "Osterhofen",
    "lat": "48.7",
    "lng": "13.02221"
  },
  {
    "country": "DE",
    "name": "Osterhausen",
    "lat": "51.45417",
    "lng": "11.50456"
  },
  {
    "country": "DE",
    "name": "Osterfeld",
    "lat": "51.08014",
    "lng": "11.93047"
  },
  {
    "country": "DE",
    "name": "Ostercappeln",
    "lat": "52.35",
    "lng": "8.23333"
  },
  {
    "country": "DE",
    "name": "Osterburken",
    "lat": "49.42997",
    "lng": "9.42252"
  },
  {
    "country": "DE",
    "name": "Osterburg",
    "lat": "52.78721",
    "lng": "11.75297"
  },
  {
    "country": "DE",
    "name": "Ostenfeld",
    "lat": "54.464",
    "lng": "9.2343"
  },
  {
    "country": "DE",
    "name": "Osten",
    "lat": "53.7",
    "lng": "9.2"
  },
  {
    "country": "DE",
    "name": "Ostelsheim",
    "lat": "48.72633",
    "lng": "8.84816"
  },
  {
    "country": "DE",
    "name": "Osteel",
    "lat": "53.54417",
    "lng": "7.254"
  },
  {
    "country": "DE",
    "name": "Ostbevern",
    "lat": "52.04018",
    "lng": "7.84229"
  },
  {
    "country": "DE",
    "name": "Oßmanstedt",
    "lat": "51.01815",
    "lng": "11.42746"
  },
  {
    "country": "DE",
    "name": "Oßling",
    "lat": "51.35999",
    "lng": "14.16567"
  },
  {
    "country": "DE",
    "name": "Osnabrück",
    "lat": "52.27264",
    "lng": "8.0498"
  },
  {
    "country": "DE",
    "name": "Osloß",
    "lat": "52.46925",
    "lng": "10.68011"
  },
  {
    "country": "DE",
    "name": "Osdorf",
    "lat": "54.43333",
    "lng": "10.01667"
  },
  {
    "country": "DE",
    "name": "Oschersleben",
    "lat": "52.03039",
    "lng": "11.22898"
  },
  {
    "country": "DE",
    "name": "Oschatz",
    "lat": "51.30001",
    "lng": "13.10984"
  },
  {
    "country": "DE",
    "name": "Osburg",
    "lat": "49.71667",
    "lng": "6.78333"
  },
  {
    "country": "DE",
    "name": "Ortrand",
    "lat": "51.37505",
    "lng": "13.75982"
  },
  {
    "country": "DE",
    "name": "Ortenburg",
    "lat": "48.54597",
    "lng": "13.2225"
  },
  {
    "country": "DE",
    "name": "Ortenberg",
    "lat": "50.35584",
    "lng": "9.05602"
  },
  {
    "country": "DE",
    "name": "Ortenberg",
    "lat": "48.45158",
    "lng": "7.97178"
  },
  {
    "country": "DE",
    "name": "Orsingen-Nenzingen",
    "lat": "47.84272",
    "lng": "8.95909"
  },
  {
    "country": "DE",
    "name": "Orscholz",
    "lat": "49.50593",
    "lng": "6.52502"
  },
  {
    "country": "DE",
    "name": "Ornbau",
    "lat": "49.17623",
    "lng": "10.65797"
  },
  {
    "country": "DE",
    "name": "Oerlenbach",
    "lat": "50.15",
    "lng": "10.13333"
  },
  {
    "country": "DE",
    "name": "Orlamünde",
    "lat": "50.77486",
    "lng": "11.51929"
  },
  {
    "country": "DE",
    "name": "Orenhofen",
    "lat": "49.9",
    "lng": "6.65"
  },
  {
    "country": "DE",
    "name": "Oerel",
    "lat": "53.48333",
    "lng": "9.05"
  },
  {
    "country": "DE",
    "name": "Oranienburg",
    "lat": "52.75577",
    "lng": "13.24197"
  },
  {
    "country": "DE",
    "name": "Oranienbaum",
    "lat": "51.7986",
    "lng": "12.40583"
  },
  {
    "country": "DE",
    "name": "Oppurg",
    "lat": "50.71065",
    "lng": "11.65289"
  },
  {
    "country": "DE",
    "name": "Oppin",
    "lat": "51.55136",
    "lng": "12.03274"
  },
  {
    "country": "DE",
    "name": "Oppenweiler",
    "lat": "48.9827",
    "lng": "9.4585"
  },
  {
    "country": "DE",
    "name": "Oppenheim",
    "lat": "49.8547",
    "lng": "8.35974"
  },
  {
    "country": "DE",
    "name": "Oppenau",
    "lat": "48.47332",
    "lng": "8.1597"
  },
  {
    "country": "DE",
    "name": "Oppach",
    "lat": "51.06667",
    "lng": "14.5"
  },
  {
    "country": "DE",
    "name": "Opladen",
    "lat": "51.06863",
    "lng": "7.00387"
  },
  {
    "country": "DE",
    "name": "Öpfingen",
    "lat": "48.28636",
    "lng": "9.80259"
  },
  {
    "country": "DE",
    "name": "Opfenbach",
    "lat": "47.63333",
    "lng": "9.83333"
  },
  {
    "country": "DE",
    "name": "Olsbrücken",
    "lat": "49.53884",
    "lng": "7.65857"
  },
  {
    "country": "DE",
    "name": "Olsberg",
    "lat": "51.35613",
    "lng": "8.48899"
  },
  {
    "country": "DE",
    "name": "Olpe",
    "lat": "51.02899",
    "lng": "7.85139"
  },
  {
    "country": "DE",
    "name": "Oelixdorf",
    "lat": "53.92738",
    "lng": "9.56383"
  },
  {
    "country": "DE",
    "name": "Olfen",
    "lat": "51.70787",
    "lng": "7.37893"
  },
  {
    "country": "DE",
    "name": "Oldisleben",
    "lat": "51.30975",
    "lng": "11.17112"
  },
  {
    "country": "DE",
    "name": "Oldenswort",
    "lat": "54.37243",
    "lng": "8.93996"
  },
  {
    "country": "DE",
    "name": "Oldendorf",
    "lat": "53.95341",
    "lng": "9.45858"
  },
  {
    "country": "DE",
    "name": "Oldendorf",
    "lat": "53.58333",
    "lng": "9.25"
  },
  {
    "country": "DE",
    "name": "Oldendorf",
    "lat": "53.1558",
    "lng": "10.21431"
  },
  {
    "country": "DE",
    "name": "Oldenburg in Holstein",
    "lat": "54.29576",
    "lng": "10.90156"
  },
  {
    "country": "DE",
    "name": "Oldenburg",
    "lat": "53.14118",
    "lng": "8.21467"
  },
  {
    "country": "DE",
    "name": "Olching",
    "lat": "48.2",
    "lng": "11.33333"
  },
  {
    "country": "DE",
    "name": "Olbersdorf",
    "lat": "50.87304",
    "lng": "14.77035"
  },
  {
    "country": "DE",
    "name": "Olbernhau",
    "lat": "50.6587",
    "lng": "13.3425"
  },
  {
    "country": "DE",
    "name": "Öhringen",
    "lat": "49.19884",
    "lng": "9.5072"
  },
  {
    "country": "DE",
    "name": "Ohorn",
    "lat": "51.17199",
    "lng": "14.04669"
  },
  {
    "country": "DE",
    "name": "Öhningen",
    "lat": "47.66186",
    "lng": "8.88674"
  },
  {
    "country": "DE",
    "name": "Ohmden",
    "lat": "48.64599",
    "lng": "9.52698"
  },
  {
    "country": "DE",
    "name": "Ohlstadt",
    "lat": "47.63333",
    "lng": "11.23333"
  },
  {
    "country": "DE",
    "name": "Ohlsdorf",
    "lat": "53.62594",
    "lng": "10.03145"
  },
  {
    "country": "DE",
    "name": "Ohlsbach",
    "lat": "48.43222",
    "lng": "7.99384"
  },
  {
    "country": "DE",
    "name": "Oftersheim",
    "lat": "49.36528",
    "lng": "8.58306"
  },
  {
    "country": "DE",
    "name": "Ofterschwang",
    "lat": "47.5",
    "lng": "10.23333"
  },
  {
    "country": "DE",
    "name": "Ofterdingen",
    "lat": "48.41667",
    "lng": "9.03333"
  },
  {
    "country": "DE",
    "name": "Offstein",
    "lat": "49.60611",
    "lng": "8.23806"
  },
  {
    "country": "DE",
    "name": "Offingen",
    "lat": "48.48258",
    "lng": "10.36249"
  },
  {
    "country": "DE",
    "name": "Offenhausen",
    "lat": "49.44971",
    "lng": "11.41316"
  },
  {
    "country": "DE",
    "name": "Offenburg",
    "lat": "48.47377",
    "lng": "7.94495"
  },
  {
    "country": "DE",
    "name": "Offenberg",
    "lat": "48.86195",
    "lng": "12.86293"
  },
  {
    "country": "DE",
    "name": "Offenbach an der Queich",
    "lat": "49.19546",
    "lng": "8.19779"
  },
  {
    "country": "DE",
    "name": "Offenbach",
    "lat": "50.10061",
    "lng": "8.76647"
  },
  {
    "country": "DE",
    "name": "Offenau",
    "lat": "49.24583",
    "lng": "9.16056"
  },
  {
    "country": "DE",
    "name": "Oettingen in Bayern",
    "lat": "48.95274",
    "lng": "10.60465"
  },
  {
    "country": "DE",
    "name": "Oerlinghausen",
    "lat": "51.95453",
    "lng": "8.6622"
  },
  {
    "country": "DE",
    "name": "Oer-Erkenschwick",
    "lat": "51.64198",
    "lng": "7.26451"
  },
  {
    "country": "DE",
    "name": "Oelsnitz",
    "lat": "50.72584",
    "lng": "12.701"
  },
  {
    "country": "DE",
    "name": "Oelsnitz",
    "lat": "50.4147",
    "lng": "12.1695"
  },
  {
    "country": "DE",
    "name": "Oelde",
    "lat": "51.8289",
    "lng": "8.14724"
  },
  {
    "country": "DE",
    "name": "Oedheim",
    "lat": "49.24028",
    "lng": "9.25333"
  },
  {
    "country": "DE",
    "name": "Oederan",
    "lat": "50.86064",
    "lng": "13.17164"
  },
  {
    "country": "DE",
    "name": "Oebisfelde",
    "lat": "52.43421",
    "lng": "10.98786"
  },
  {
    "country": "DE",
    "name": "Oederquart",
    "lat": "53.80267",
    "lng": "9.2368"
  },
  {
    "country": "DE",
    "name": "Odernheim",
    "lat": "49.76511",
    "lng": "7.70427"
  },
  {
    "country": "DE",
    "name": "Oderberg",
    "lat": "52.86571",
    "lng": "14.04508"
  },
  {
    "country": "DE",
    "name": "Odenthal",
    "lat": "51.03333",
    "lng": "7.11667"
  },
  {
    "country": "DE",
    "name": "Odelzhausen",
    "lat": "48.30889",
    "lng": "11.19889"
  },
  {
    "country": "DE",
    "name": "Ockenheim",
    "lat": "49.94371",
    "lng": "7.97127"
  },
  {
    "country": "DE",
    "name": "Ockenfels",
    "lat": "50.5761",
    "lng": "7.27535"
  },
  {
    "country": "DE",
    "name": "Ochtrup",
    "lat": "52.20802",
    "lng": "7.18988"
  },
  {
    "country": "DE",
    "name": "Ochtendung",
    "lat": "50.35",
    "lng": "7.38333"
  },
  {
    "country": "DE",
    "name": "Ochsenhausen",
    "lat": "48.07029",
    "lng": "9.9503"
  },
  {
    "country": "DE",
    "name": "Ochsenfurt",
    "lat": "49.66429",
    "lng": "10.06227"
  },
  {
    "country": "DE",
    "name": "Obrigheim",
    "lat": "49.59161",
    "lng": "8.20483"
  },
  {
    "country": "DE",
    "name": "Obrigheim",
    "lat": "49.35194",
    "lng": "9.09083"
  },
  {
    "country": "DE",
    "name": "Obing",
    "lat": "48.00049",
    "lng": "12.40528"
  },
  {
    "country": "DE",
    "name": "Obhausen",
    "lat": "51.39172",
    "lng": "11.65312"
  },
  {
    "country": "DE",
    "name": "Oberzissen",
    "lat": "50.45",
    "lng": "7.2"
  },
  {
    "country": "DE",
    "name": "Oberwolfach",
    "lat": "48.31667",
    "lng": "8.21667"
  },
  {
    "country": "DE",
    "name": "Oberwiera",
    "lat": "50.88913",
    "lng": "12.54415"
  },
  {
    "country": "DE",
    "name": "Oberwesel",
    "lat": "50.10777",
    "lng": "7.72522"
  },
  {
    "country": "DE",
    "name": "Oberweißbach",
    "lat": "50.58231",
    "lng": "11.14382"
  },
  {
    "country": "DE",
    "name": "Heidstock",
    "lat": "49.25571",
    "lng": "6.88156"
  },
  {
    "country": "DE",
    "name": "Oberviechtach",
    "lat": "49.45809",
    "lng": "12.41669"
  },
  {
    "country": "DE",
    "name": "Oberursel",
    "lat": "50.20731",
    "lng": "8.57747"
  },
  {
    "country": "DE",
    "name": "Obertshausen",
    "lat": "50.07139",
    "lng": "8.85123"
  },
  {
    "country": "DE",
    "name": "Obertrubach",
    "lat": "49.7",
    "lng": "11.35"
  },
  {
    "country": "DE",
    "name": "Obertraubling",
    "lat": "48.96667",
    "lng": "12.16667"
  },
  {
    "country": "DE",
    "name": "Oberthulba",
    "lat": "50.19904",
    "lng": "9.95882"
  },
  {
    "country": "DE",
    "name": "Oberthal",
    "lat": "49.51257",
    "lng": "7.08382"
  },
  {
    "country": "DE",
    "name": "Oberteuringen",
    "lat": "47.72409",
    "lng": "9.46979"
  },
  {
    "country": "DE",
    "name": "Obertaufkirchen",
    "lat": "48.26046",
    "lng": "12.27904"
  },
  {
    "country": "DE",
    "name": "Obersüßbach",
    "lat": "48.61667",
    "lng": "11.95"
  },
  {
    "country": "DE",
    "name": "Oberstreu",
    "lat": "50.40338",
    "lng": "10.28775"
  },
  {
    "country": "DE",
    "name": "Oberstenfeld",
    "lat": "49.02611",
    "lng": "9.32083"
  },
  {
    "country": "DE",
    "name": "Oberstdorf",
    "lat": "47.40724",
    "lng": "10.27939"
  },
  {
    "country": "DE",
    "name": "Oberstaufen",
    "lat": "47.55568",
    "lng": "10.02245"
  },
  {
    "country": "DE",
    "name": "Oberstadion",
    "lat": "48.18596",
    "lng": "9.69241"
  },
  {
    "country": "DE",
    "name": "Obersontheim",
    "lat": "49.05667",
    "lng": "9.89917"
  },
  {
    "country": "DE",
    "name": "Obersöchering",
    "lat": "47.73333",
    "lng": "11.21667"
  },
  {
    "country": "DE",
    "name": "Obersinn",
    "lat": "50.20875",
    "lng": "9.61545"
  },
  {
    "country": "DE",
    "name": "Oberschweinbach",
    "lat": "48.23817",
    "lng": "11.15571"
  },
  {
    "country": "DE",
    "name": "Oberschwarzach",
    "lat": "49.86051",
    "lng": "10.40999"
  },
  {
    "country": "DE",
    "name": "Oberschöneweide",
    "lat": "52.46106",
    "lng": "13.52108"
  },
  {
    "country": "DE",
    "name": "Oberschöna",
    "lat": "50.89759",
    "lng": "13.25379"
  },
  {
    "country": "DE",
    "name": "Oberschneiding",
    "lat": "48.79573",
    "lng": "12.642"
  },
  {
    "country": "DE",
    "name": "Oberschleißheim",
    "lat": "48.25",
    "lng": "11.56667"
  },
  {
    "country": "DE",
    "name": "Oberscheinfeld",
    "lat": "49.70829",
    "lng": "10.43418"
  },
  {
    "country": "DE",
    "name": "Ober-Saulheim",
    "lat": "49.86376",
    "lng": "8.13526"
  },
  {
    "country": "DE",
    "name": "Oberrot",
    "lat": "49.01444",
    "lng": "9.66722"
  },
  {
    "country": "DE",
    "name": "Oberröblingen",
    "lat": "51.43705",
    "lng": "11.3075"
  },
  {
    "country": "DE",
    "name": "Oberriexingen",
    "lat": "48.92652",
    "lng": "9.02701"
  },
  {
    "country": "DE",
    "name": "Oberrieden",
    "lat": "48.08886",
    "lng": "10.42611"
  },
  {
    "country": "DE",
    "name": "Oberried",
    "lat": "47.93333",
    "lng": "7.95"
  },
  {
    "country": "DE",
    "name": "Oberreute",
    "lat": "47.56303",
    "lng": "9.94449"
  },
  {
    "country": "DE",
    "name": "Oberreichenbach",
    "lat": "49.58946",
    "lng": "10.76892"
  },
  {
    "country": "DE",
    "name": "Oberreichenbach",
    "lat": "48.73333",
    "lng": "8.66667"
  },
  {
    "country": "DE",
    "name": "Ober-Ramstadt",
    "lat": "49.83078",
    "lng": "8.74887"
  },
  {
    "country": "DE",
    "name": "Oberpöring",
    "lat": "48.70178",
    "lng": "12.82482"
  },
  {
    "country": "DE",
    "name": "Oberpleichfeld",
    "lat": "49.87694",
    "lng": "10.08682"
  },
  {
    "country": "DE",
    "name": "Oberpframmern",
    "lat": "48.02202",
    "lng": "11.81331"
  },
  {
    "country": "DE",
    "name": "Oberottmarshausen",
    "lat": "48.23716",
    "lng": "10.85754"
  },
  {
    "country": "DE",
    "name": "Oberotterbach",
    "lat": "49.07044",
    "lng": "7.96955"
  },
  {
    "country": "DE",
    "name": "Oberostendorf",
    "lat": "47.9436",
    "lng": "10.7427"
  },
  {
    "country": "DE",
    "name": "Ober-Olm",
    "lat": "49.93722",
    "lng": "8.18889"
  },
  {
    "country": "DE",
    "name": "Obernzenn",
    "lat": "49.45193",
    "lng": "10.4667"
  },
  {
    "country": "DE",
    "name": "Obernzell",
    "lat": "48.55485",
    "lng": "13.63729"
  },
  {
    "country": "DE",
    "name": "Obernkirchen",
    "lat": "52.2721",
    "lng": "9.12912"
  },
  {
    "country": "DE",
    "name": "Obernheim-Kirchenarnbach",
    "lat": "49.35",
    "lng": "7.58333"
  },
  {
    "country": "DE",
    "name": "Obernheim",
    "lat": "48.16297",
    "lng": "8.86113"
  },
  {
    "country": "DE",
    "name": "Obernfeld",
    "lat": "51.55",
    "lng": "10.23333"
  },
  {
    "country": "DE",
    "name": "Oberndorf",
    "lat": "53.75",
    "lng": "9.15"
  },
  {
    "country": "DE",
    "name": "Oberndorf",
    "lat": "48.66918",
    "lng": "10.86749"
  },
  {
    "country": "DE",
    "name": "Oberndorf",
    "lat": "48.2905",
    "lng": "8.57221"
  },
  {
    "country": "DE",
    "name": "Obernburg am Main",
    "lat": "49.83577",
    "lng": "9.13101"
  },
  {
    "country": "DE",
    "name": "Obernbreit",
    "lat": "49.65863",
    "lng": "10.16424"
  },
  {
    "country": "DE",
    "name": "Obermoschel",
    "lat": "49.72797",
    "lng": "7.77266"
  },
  {
    "country": "DE",
    "name": "Ober-Mörlen",
    "lat": "50.3735",
    "lng": "8.69087"
  },
  {
    "country": "DE",
    "name": "Obermichelbach",
    "lat": "49.53117",
    "lng": "10.90891"
  },
  {
    "country": "DE",
    "name": "Obermeitingen",
    "lat": "48.14685",
    "lng": "10.80626"
  },
  {
    "country": "DE",
    "name": "Obermehler",
    "lat": "51.26996",
    "lng": "10.59754"
  },
  {
    "country": "DE",
    "name": "Obermaßfeld-Grimmenthal",
    "lat": "50.52898",
    "lng": "10.43963"
  },
  {
    "country": "DE",
    "name": "Obermarchtal",
    "lat": "48.23279",
    "lng": "9.57235"
  },
  {
    "country": "DE",
    "name": "Oberlungwitz",
    "lat": "50.7823",
    "lng": "12.70789"
  },
  {
    "country": "DE",
    "name": "Oberlichtenau",
    "lat": "51.21875",
    "lng": "13.98992"
  },
  {
    "country": "DE",
    "name": "Oberleichtersbach",
    "lat": "50.28333",
    "lng": "9.8"
  },
  {
    "country": "DE",
    "name": "Langfurth",
    "lat": "49.10112",
    "lng": "10.45359"
  },
  {
    "country": "DE",
    "name": "Oberkotzau",
    "lat": "50.26236",
    "lng": "11.93484"
  },
  {
    "country": "DE",
    "name": "Oberkochen",
    "lat": "48.78379",
    "lng": "10.10519"
  },
  {
    "country": "DE",
    "name": "Oberkirch",
    "lat": "48.53241",
    "lng": "8.07864"
  },
  {
    "country": "DE",
    "name": "Oberjettingen",
    "lat": "48.57468",
    "lng": "8.77636"
  },
  {
    "country": "DE",
    "name": "Oberhof",
    "lat": "50.70435",
    "lng": "10.72716"
  },
  {
    "country": "DE",
    "name": "Oberhausen-Rheinhausen",
    "lat": "49.27389",
    "lng": "8.47167"
  },
  {
    "country": "DE",
    "name": "Oberhausen",
    "lat": "51.47805",
    "lng": "6.8625"
  },
  {
    "country": "DE",
    "name": "Oberhausen",
    "lat": "48.72201",
    "lng": "11.11151"
  },
  {
    "country": "DE",
    "name": "Oberhausen",
    "lat": "47.78333",
    "lng": "11.13333"
  },
  {
    "country": "DE",
    "name": "Oberharmersbach",
    "lat": "48.37358",
    "lng": "8.12542"
  },
  {
    "country": "DE",
    "name": "Oberhaid",
    "lat": "50.12614",
    "lng": "11.80514"
  },
  {
    "country": "DE",
    "name": "Oberhaching",
    "lat": "48.02455",
    "lng": "11.59744"
  },
  {
    "country": "DE",
    "name": "Obergurig",
    "lat": "51.13294",
    "lng": "14.40488"
  },
  {
    "country": "DE",
    "name": "Obergünzburg",
    "lat": "47.84545",
    "lng": "10.41821"
  },
  {
    "country": "DE",
    "name": "Obergriesbach",
    "lat": "48.42305",
    "lng": "11.0685"
  },
  {
    "country": "DE",
    "name": "Ober-Flörsheim",
    "lat": "49.68306",
    "lng": "8.15528"
  },
  {
    "country": "DE",
    "name": "Oberfell",
    "lat": "50.26038",
    "lng": "7.44461"
  },
  {
    "country": "DE",
    "name": "Oberelsbach",
    "lat": "50.44118",
    "lng": "10.11692"
  },
  {
    "country": "DE",
    "name": "Oberelbert",
    "lat": "50.39167",
    "lng": "7.81722"
  },
  {
    "country": "DE",
    "name": "Oberdorla",
    "lat": "51.16585",
    "lng": "10.42163"
  },
  {
    "country": "DE",
    "name": "Oberdischingen",
    "lat": "48.3",
    "lng": "9.83333"
  },
  {
    "country": "DE",
    "name": "Oberding",
    "lat": "48.31667",
    "lng": "11.85"
  },
  {
    "country": "DE",
    "name": "Oberderdingen",
    "lat": "49.06556",
    "lng": "8.80306"
  },
  {
    "country": "DE",
    "name": "Oberdachstetten",
    "lat": "49.41667",
    "lng": "10.43333"
  },
  {
    "country": "DE",
    "name": "Obercunnersdorf",
    "lat": "50.91711",
    "lng": "13.56015"
  },
  {
    "country": "DE",
    "name": "Oberboihingen",
    "lat": "48.65",
    "lng": "9.36667"
  },
  {
    "country": "DE",
    "name": "Oberbiel",
    "lat": "50.5532",
    "lng": "8.42797"
  },
  {
    "country": "DE",
    "name": "Oberbergkirchen",
    "lat": "48.3",
    "lng": "12.38333"
  },
  {
    "country": "DE",
    "name": "Oberaula",
    "lat": "50.85",
    "lng": "9.46667"
  },
  {
    "country": "DE",
    "name": "Oberaudorf",
    "lat": "47.64822",
    "lng": "12.17242"
  },
  {
    "country": "DE",
    "name": "Oberasbach",
    "lat": "49.42275",
    "lng": "10.95766"
  },
  {
    "country": "DE",
    "name": "Oberammergau",
    "lat": "47.59812",
    "lng": "11.06692"
  },
  {
    "country": "DE",
    "name": "Nützen",
    "lat": "53.86667",
    "lng": "9.91667"
  },
  {
    "country": "DE",
    "name": "Nußloch",
    "lat": "49.32389",
    "lng": "8.69556"
  },
  {
    "country": "DE",
    "name": "Nusse",
    "lat": "53.65654",
    "lng": "10.58391"
  },
  {
    "country": "DE",
    "name": "Nußdorf am Inn",
    "lat": "47.74232",
    "lng": "12.15611"
  },
  {
    "country": "DE",
    "name": "Nußdorf",
    "lat": "47.90564",
    "lng": "12.59608"
  },
  {
    "country": "DE",
    "name": "Nürtingen",
    "lat": "48.62565",
    "lng": "9.34203"
  },
  {
    "country": "DE",
    "name": "Nürnberg",
    "lat": "49.45421",
    "lng": "11.07752"
  },
  {
    "country": "DE",
    "name": "Nünchritz",
    "lat": "51.29993",
    "lng": "13.38555"
  },
  {
    "country": "DE",
    "name": "Nümbrecht",
    "lat": "50.90427",
    "lng": "7.54063"
  },
  {
    "country": "DE",
    "name": "Nufringen",
    "lat": "48.62253",
    "lng": "8.89009"
  },
  {
    "country": "DE",
    "name": "Nüdlingen",
    "lat": "50.22063",
    "lng": "10.12296"
  },
  {
    "country": "DE",
    "name": "Nudersdorf",
    "lat": "51.93025",
    "lng": "12.59554"
  },
  {
    "country": "DE",
    "name": "Nübbel",
    "lat": "54.26667",
    "lng": "9.61667"
  },
  {
    "country": "DE",
    "name": "Notzingen",
    "lat": "48.67076",
    "lng": "9.45721"
  },
  {
    "country": "DE",
    "name": "Nottuln",
    "lat": "51.93333",
    "lng": "7.35"
  },
  {
    "country": "DE",
    "name": "Nottensdorf",
    "lat": "53.48333",
    "lng": "9.6"
  },
  {
    "country": "DE",
    "name": "Nostorf",
    "lat": "53.40656",
    "lng": "10.65408"
  },
  {
    "country": "DE",
    "name": "Nossen",
    "lat": "51.05798",
    "lng": "13.29652"
  },
  {
    "country": "DE",
    "name": "Nörvenich",
    "lat": "50.80604",
    "lng": "6.63952"
  },
  {
    "country": "DE",
    "name": "Nortrup",
    "lat": "52.61503",
    "lng": "7.86072"
  },
  {
    "country": "DE",
    "name": "Nortorf",
    "lat": "54.16738",
    "lng": "9.85437"
  },
  {
    "country": "DE",
    "name": "Nortmoor",
    "lat": "53.24608",
    "lng": "7.57178"
  },
  {
    "country": "DE",
    "name": "Northeim",
    "lat": "51.70662",
    "lng": "9.99997"
  },
  {
    "country": "DE",
    "name": "Nörtershausen",
    "lat": "50.21667",
    "lng": "7.48333"
  },
  {
    "country": "DE",
    "name": "Nörten-Hardenberg",
    "lat": "51.62878",
    "lng": "9.93593"
  },
  {
    "country": "DE",
    "name": "Norheim",
    "lat": "49.81091",
    "lng": "7.81478"
  },
  {
    "country": "DE",
    "name": "Nordwalde",
    "lat": "52.08333",
    "lng": "7.48333"
  },
  {
    "country": "DE",
    "name": "Nordstemmen",
    "lat": "52.16196",
    "lng": "9.7835"
  },
  {
    "country": "DE",
    "name": "Nordrach",
    "lat": "48.4",
    "lng": "8.08333"
  },
  {
    "country": "DE",
    "name": "Nördlingen",
    "lat": "48.85122",
    "lng": "10.48868"
  },
  {
    "country": "DE",
    "name": "Nordleda",
    "lat": "53.76667",
    "lng": "8.83333"
  },
  {
    "country": "DE",
    "name": "Nordkirchen",
    "lat": "51.73827",
    "lng": "7.52197"
  },
  {
    "country": "DE",
    "name": "Nordhorn",
    "lat": "52.43081",
    "lng": "7.06833"
  },
  {
    "country": "DE",
    "name": "Nordholz",
    "lat": "53.78448",
    "lng": "8.61354"
  },
  {
    "country": "DE",
    "name": "Nordheim",
    "lat": "49.8587",
    "lng": "10.18545"
  },
  {
    "country": "DE",
    "name": "Nordheim",
    "lat": "49.10861",
    "lng": "9.12778"
  },
  {
    "country": "DE",
    "name": "Nordhausen",
    "lat": "51.5018",
    "lng": "10.7957"
  },
  {
    "country": "DE",
    "name": "Nordhastedt",
    "lat": "54.16667",
    "lng": "9.18333"
  },
  {
    "country": "DE",
    "name": "Nordhalben",
    "lat": "50.37411",
    "lng": "11.50992"
  },
  {
    "country": "DE",
    "name": "Norderstedt",
    "lat": "53.6859",
    "lng": "9.98041"
  },
  {
    "country": "DE",
    "name": "Norderney",
    "lat": "53.70828",
    "lng": "7.15819"
  },
  {
    "country": "DE",
    "name": "Nordenham",
    "lat": "53.4861",
    "lng": "8.48093"
  },
  {
    "country": "DE",
    "name": "Nordendorf",
    "lat": "48.59478",
    "lng": "10.83183"
  },
  {
    "country": "DE",
    "name": "Norden",
    "lat": "53.59552",
    "lng": "7.20639"
  },
  {
    "country": "DE",
    "name": "Norddeich",
    "lat": "53.61349",
    "lng": "7.16043"
  },
  {
    "country": "DE",
    "name": "Nonnweiler",
    "lat": "49.60762",
    "lng": "6.96986"
  },
  {
    "country": "DE",
    "name": "Nonnenhorn",
    "lat": "47.57386",
    "lng": "9.61038"
  },
  {
    "country": "DE",
    "name": "Nohra",
    "lat": "50.96136",
    "lng": "11.25971"
  },
  {
    "country": "DE",
    "name": "Nohfelden",
    "lat": "49.58693",
    "lng": "7.14283"
  },
  {
    "country": "DE",
    "name": "Nobitz",
    "lat": "50.97621",
    "lng": "12.48605"
  },
  {
    "country": "DE",
    "name": "Nöbdenitz",
    "lat": "50.86667",
    "lng": "12.28333"
  },
  {
    "country": "DE",
    "name": "Nittendorf",
    "lat": "49.02459",
    "lng": "11.96126"
  },
  {
    "country": "DE",
    "name": "Nittenau",
    "lat": "49.19425",
    "lng": "12.26741"
  },
  {
    "country": "DE",
    "name": "Nittel",
    "lat": "49.65",
    "lng": "6.45"
  },
  {
    "country": "DE",
    "name": "Nister",
    "lat": "50.67583",
    "lng": "7.83833"
  },
  {
    "country": "DE",
    "name": "Nippes",
    "lat": "50.96545",
    "lng": "6.95314"
  },
  {
    "country": "DE",
    "name": "Nindorf",
    "lat": "54.08333",
    "lng": "9.11667"
  },
  {
    "country": "DE",
    "name": "Nikolassee",
    "lat": "52.4344",
    "lng": "13.20095"
  },
  {
    "country": "DE",
    "name": "Niesky",
    "lat": "51.29241",
    "lng": "14.82107"
  },
  {
    "country": "DE",
    "name": "Nierstein",
    "lat": "49.87003",
    "lng": "8.33647"
  },
  {
    "country": "DE",
    "name": "Niepars",
    "lat": "54.31447",
    "lng": "12.92447"
  },
  {
    "country": "DE",
    "name": "Nienstädt",
    "lat": "52.29242",
    "lng": "9.1644"
  },
  {
    "country": "DE",
    "name": "Nienhagen",
    "lat": "54.14869",
    "lng": "12.17434"
  },
  {
    "country": "DE",
    "name": "Nienburg",
    "lat": "52.6461",
    "lng": "9.22086"
  },
  {
    "country": "DE",
    "name": "Nienburg/Saale",
    "lat": "51.83747",
    "lng": "11.76979"
  },
  {
    "country": "DE",
    "name": "Niemegk",
    "lat": "52.07388",
    "lng": "12.68947"
  },
  {
    "country": "DE",
    "name": "Niemberg",
    "lat": "51.55035",
    "lng": "12.09089"
  },
  {
    "country": "DE",
    "name": "Nieheim",
    "lat": "51.80499",
    "lng": "9.11302"
  },
  {
    "country": "DE",
    "name": "Niederzissen",
    "lat": "50.45876",
    "lng": "7.2181"
  },
  {
    "country": "DE",
    "name": "Niederzimmern",
    "lat": "51.00476",
    "lng": "11.19028"
  },
  {
    "country": "DE",
    "name": "Niederzier",
    "lat": "50.88333",
    "lng": "6.46667"
  },
  {
    "country": "DE",
    "name": "Niederwinkling",
    "lat": "48.88333",
    "lng": "12.8"
  },
  {
    "country": "DE",
    "name": "Niederwiesa",
    "lat": "50.86667",
    "lng": "13.01667"
  },
  {
    "country": "DE",
    "name": "Niederwerth",
    "lat": "50.4",
    "lng": "7.61667"
  },
  {
    "country": "DE",
    "name": "Niederwerrn",
    "lat": "50.06149",
    "lng": "10.1827"
  },
  {
    "country": "DE",
    "name": "Niederviehbach",
    "lat": "48.61667",
    "lng": "12.38333"
  },
  {
    "country": "DE",
    "name": "Niedertaufkirchen",
    "lat": "48.33333",
    "lng": "12.55"
  },
  {
    "country": "DE",
    "name": "Niederstriegis",
    "lat": "51.08243",
    "lng": "13.14925"
  },
  {
    "country": "DE",
    "name": "Niederstotzingen",
    "lat": "48.54127",
    "lng": "10.23505"
  },
  {
    "country": "DE",
    "name": "Niederstetten",
    "lat": "49.4",
    "lng": "9.91944"
  },
  {
    "country": "DE",
    "name": "Niederschönhausen",
    "lat": "52.58483",
    "lng": "13.40272"
  },
  {
    "country": "DE",
    "name": "Niederschöneweide",
    "lat": "52.45564",
    "lng": "13.51554"
  },
  {
    "country": "DE",
    "name": "Niederschönenfeld",
    "lat": "48.71667",
    "lng": "10.93333"
  },
  {
    "country": "DE",
    "name": "Niederschöna",
    "lat": "50.96671",
    "lng": "13.4191"
  },
  {
    "country": "DE",
    "name": "Niedersachswerfen",
    "lat": "51.55062",
    "lng": "10.76594"
  },
  {
    "country": "DE",
    "name": "Niederroßla",
    "lat": "51.03333",
    "lng": "11.48333"
  },
  {
    "country": "DE",
    "name": "Niederrieden",
    "lat": "48.0576",
    "lng": "10.18321"
  },
  {
    "country": "DE",
    "name": "Niederorschel",
    "lat": "51.37222",
    "lng": "10.42372"
  },
  {
    "country": "DE",
    "name": "Nieder-Olm",
    "lat": "49.91166",
    "lng": "8.20533"
  },
  {
    "country": "DE",
    "name": "Niedernwöhren",
    "lat": "52.35214",
    "lng": "9.14788"
  },
  {
    "country": "DE",
    "name": "Niedernhausen",
    "lat": "50.16307",
    "lng": "8.31338"
  },
  {
    "country": "DE",
    "name": "Niedernhall",
    "lat": "49.29516",
    "lng": "9.61604"
  },
  {
    "country": "DE",
    "name": "Niederneisen",
    "lat": "50.33333",
    "lng": "8.05"
  },
  {
    "country": "DE",
    "name": "Niederndodeleben",
    "lat": "52.13416",
    "lng": "11.50085"
  },
  {
    "country": "DE",
    "name": "Niedernberg",
    "lat": "49.91222",
    "lng": "9.13694"
  },
  {
    "country": "DE",
    "name": "Niedermurach",
    "lat": "49.44999",
    "lng": "12.3761"
  },
  {
    "country": "DE",
    "name": "Niedermohr",
    "lat": "49.45899",
    "lng": "7.46955"
  },
  {
    "country": "DE",
    "name": "Niedermerz",
    "lat": "50.88151",
    "lng": "6.26651"
  },
  {
    "country": "DE",
    "name": "Niederlauer",
    "lat": "50.29411",
    "lng": "10.17712"
  },
  {
    "country": "DE",
    "name": "Niederlangen",
    "lat": "52.85712",
    "lng": "7.28199"
  },
  {
    "country": "DE",
    "name": "Niederkrüchten",
    "lat": "51.2",
    "lng": "6.21667"
  },
  {
    "country": "DE",
    "name": "Niederklein",
    "lat": "50.794",
    "lng": "8.99694"
  },
  {
    "country": "DE",
    "name": "Niederkirchen bei Deidesheim",
    "lat": "49.415",
    "lng": "8.21"
  },
  {
    "country": "DE",
    "name": "Niederkirchen",
    "lat": "49.58333",
    "lng": "7.7"
  },
  {
    "country": "DE",
    "name": "Niederkassel",
    "lat": "50.81503",
    "lng": "7.03777"
  },
  {
    "country": "DE",
    "name": "Nieder-Ingelheim",
    "lat": "49.97756",
    "lng": "8.07246"
  },
  {
    "country": "DE",
    "name": "Nieder-Gründau",
    "lat": "50.21097",
    "lng": "9.10801"
  },
  {
    "country": "DE",
    "name": "Niedergörsdorf",
    "lat": "51.97943",
    "lng": "12.98541"
  },
  {
    "country": "DE",
    "name": "Niederfüllbach",
    "lat": "50.22002",
    "lng": "10.99086"
  },
  {
    "country": "DE",
    "name": "Niederfrohna",
    "lat": "50.9",
    "lng": "12.71667"
  },
  {
    "country": "DE",
    "name": "Niederfischbach",
    "lat": "50.85",
    "lng": "7.86667"
  },
  {
    "country": "DE",
    "name": "Niederfell",
    "lat": "50.28333",
    "lng": "7.46667"
  },
  {
    "country": "DE",
    "name": "Niedereschach",
    "lat": "48.13333",
    "lng": "8.53333"
  },
  {
    "country": "DE",
    "name": "Niedererbach",
    "lat": "50.4261",
    "lng": "7.97425"
  },
  {
    "country": "DE",
    "name": "Niederelbert",
    "lat": "50.40775",
    "lng": "7.8099"
  },
  {
    "country": "DE",
    "name": "Niederdürenbach",
    "lat": "50.45",
    "lng": "7.18333"
  },
  {
    "country": "DE",
    "name": "Niederdreisbach",
    "lat": "50.74955",
    "lng": "7.92352"
  },
  {
    "country": "DE",
    "name": "Niederdorla",
    "lat": "51.16025",
    "lng": "10.4482"
  },
  {
    "country": "DE",
    "name": "Niederdorfelden",
    "lat": "50.19415",
    "lng": "8.80005"
  },
  {
    "country": "DE",
    "name": "Niederdorf",
    "lat": "50.72623",
    "lng": "12.78587"
  },
  {
    "country": "DE",
    "name": "Niedercunnersdorf",
    "lat": "51.05398",
    "lng": "14.6583"
  },
  {
    "country": "DE",
    "name": "Niederbreitbach",
    "lat": "50.53051",
    "lng": "7.42099"
  },
  {
    "country": "DE",
    "name": "Niederbiel",
    "lat": "50.55505",
    "lng": "8.39845"
  },
  {
    "country": "DE",
    "name": "Niederbergkirchen",
    "lat": "48.31667",
    "lng": "12.5"
  },
  {
    "country": "DE",
    "name": "Niederaula",
    "lat": "50.8",
    "lng": "9.6"
  },
  {
    "country": "DE",
    "name": "Niederau",
    "lat": "51.1773",
    "lng": "13.54563"
  },
  {
    "country": "DE",
    "name": "Aschau im Chiemgau",
    "lat": "47.77689",
    "lng": "12.32297"
  },
  {
    "country": "DE",
    "name": "Niederalteich",
    "lat": "48.76564",
    "lng": "13.02412"
  },
  {
    "country": "DE",
    "name": "Niederaichbach",
    "lat": "48.6",
    "lng": "12.31667"
  },
  {
    "country": "DE",
    "name": "Niedenstein",
    "lat": "51.23342",
    "lng": "9.31029"
  },
  {
    "country": "DE",
    "name": "Niebüll",
    "lat": "54.78663",
    "lng": "8.82854"
  },
  {
    "country": "DE",
    "name": "Nideggen",
    "lat": "50.69268",
    "lng": "6.48437"
  },
  {
    "country": "DE",
    "name": "Nidderau",
    "lat": "50.23805",
    "lng": "8.86704"
  },
  {
    "country": "DE",
    "name": "Nidda",
    "lat": "50.4133",
    "lng": "9.00638"
  },
  {
    "country": "DE",
    "name": "Nickenich",
    "lat": "50.41421",
    "lng": "7.32728"
  },
  {
    "country": "DE",
    "name": "Newel",
    "lat": "49.8124",
    "lng": "6.58304"
  },
  {
    "country": "DE",
    "name": "Neverin",
    "lat": "53.62067",
    "lng": "13.3366"
  },
  {
    "country": "DE",
    "name": "Neuzelle",
    "lat": "52.09016",
    "lng": "14.64804"
  },
  {
    "country": "DE",
    "name": "Neu Zauche",
    "lat": "51.92757",
    "lng": "14.08812"
  },
  {
    "country": "DE",
    "name": "Neu Wulmstorf",
    "lat": "53.46667",
    "lng": "9.8"
  },
  {
    "country": "DE",
    "name": "Neuwittenbek",
    "lat": "54.36667",
    "lng": "10.01667"
  },
  {
    "country": "DE",
    "name": "Neuwied",
    "lat": "50.4336",
    "lng": "7.47057"
  },
  {
    "country": "DE",
    "name": "Neuweiler",
    "lat": "48.66667",
    "lng": "8.6"
  },
  {
    "country": "DE",
    "name": "Neu-Ulm",
    "lat": "48.39279",
    "lng": "10.01112"
  },
  {
    "country": "DE",
    "name": "Neutrebbin",
    "lat": "52.66482",
    "lng": "14.22802"
  },
  {
    "country": "DE",
    "name": "Neutraubling",
    "lat": "48.98737",
    "lng": "12.201"
  },
  {
    "country": "DE",
    "name": "Neustrelitz",
    "lat": "53.3613",
    "lng": "13.07292"
  },
  {
    "country": "DE",
    "name": "Neustadt in Holstein",
    "lat": "54.10707",
    "lng": "10.8145"
  },
  {
    "country": "DE",
    "name": "Neustadt-Glewe",
    "lat": "53.37846",
    "lng": "11.59264"
  },
  {
    "country": "DE",
    "name": "Neustadt bei Coburg",
    "lat": "50.32975",
    "lng": "11.12058"
  },
  {
    "country": "DE",
    "name": "Neustadt",
    "lat": "49.35009",
    "lng": "8.13886"
  },
  {
    "country": "DE",
    "name": "Neustadt an der Waldnaab",
    "lat": "49.73287",
    "lng": "12.17773"
  },
  {
    "country": "DE",
    "name": "Neustadt an der Donau",
    "lat": "48.80705",
    "lng": "11.76952"
  },
  {
    "country": "DE",
    "name": "Neustadt an der Aisch",
    "lat": "49.57953",
    "lng": "10.61126"
  },
  {
    "country": "DE",
    "name": "Neustadt am Rübenberge",
    "lat": "52.50462",
    "lng": "9.45871"
  },
  {
    "country": "DE",
    "name": "Neustadt am Rennsteig",
    "lat": "50.58333",
    "lng": "10.93333"
  },
  {
    "country": "DE",
    "name": "Neustadt am Main",
    "lat": "49.93021",
    "lng": "9.56808"
  },
  {
    "country": "DE",
    "name": "Neustadt",
    "lat": "53.55196",
    "lng": "9.98558"
  },
  {
    "country": "DE",
    "name": "Neue Neustadt",
    "lat": "52.15",
    "lng": "11.63333"
  },
  {
    "country": "DE",
    "name": "Neustadt in Sachsen",
    "lat": "51.02844",
    "lng": "14.21785"
  },
  {
    "country": "DE",
    "name": "Neustadt (Hessen)",
    "lat": "50.85",
    "lng": "9.11667"
  },
  {
    "country": "DE",
    "name": "Neustadt Vogtland",
    "lat": "50.461",
    "lng": "12.33224"
  },
  {
    "country": "DE",
    "name": "Neuss",
    "lat": "51.19807",
    "lng": "6.68504"
  },
  {
    "country": "DE",
    "name": "Neusorg",
    "lat": "49.93333",
    "lng": "11.96667"
  },
  {
    "country": "DE",
    "name": "Neusitz",
    "lat": "49.37185",
    "lng": "10.22559"
  },
  {
    "country": "DE",
    "name": "Neuschönau",
    "lat": "48.88419",
    "lng": "13.47576"
  },
  {
    "country": "DE",
    "name": "Neusalza-Spremberg",
    "lat": "51.03945",
    "lng": "14.5356"
  },
  {
    "country": "DE",
    "name": "Neuruppin",
    "lat": "52.92815",
    "lng": "12.80311"
  },
  {
    "country": "DE",
    "name": "Neuried",
    "lat": "48.09322",
    "lng": "11.46561"
  },
  {
    "country": "DE",
    "name": "Neureichenau",
    "lat": "48.74861",
    "lng": "13.74699"
  },
  {
    "country": "DE",
    "name": "Neupotz",
    "lat": "49.11778",
    "lng": "8.31944"
  },
  {
    "country": "DE",
    "name": "Neuötting",
    "lat": "48.24102",
    "lng": "12.68998"
  },
  {
    "country": "DE",
    "name": "Neunkirchen am Sand",
    "lat": "49.52464",
    "lng": "11.31955"
  },
  {
    "country": "DE",
    "name": "Neunkirchen am Main",
    "lat": "49.923",
    "lng": "11.64793"
  },
  {
    "country": "DE",
    "name": "Neunkirchen",
    "lat": "50.8",
    "lng": "8"
  },
  {
    "country": "DE",
    "name": "Neunkirchen",
    "lat": "49.38694",
    "lng": "9.01056"
  },
  {
    "country": "DE",
    "name": "Neunkirchen",
    "lat": "49.34449",
    "lng": "7.18045"
  },
  {
    "country": "DE",
    "name": "Neunkhausen",
    "lat": "50.70722",
    "lng": "7.90278"
  },
  {
    "country": "DE",
    "name": "Neundorf",
    "lat": "51.8208",
    "lng": "11.57484"
  },
  {
    "country": "DE",
    "name": "Neunburg vorm Wald",
    "lat": "49.34782",
    "lng": "12.38621"
  },
  {
    "country": "DE",
    "name": "Neumünster",
    "lat": "54.07477",
    "lng": "9.98195"
  },
  {
    "country": "DE",
    "name": "Neumühle",
    "lat": "53.63171",
    "lng": "11.37085"
  },
  {
    "country": "DE",
    "name": "Neumarkt-Sankt Veit",
    "lat": "48.36051",
    "lng": "12.50723"
  },
  {
    "country": "DE",
    "name": "Neumarkt in der Oberpfalz",
    "lat": "49.28028",
    "lng": "11.46278"
  },
  {
    "country": "DE",
    "name": "Neumark",
    "lat": "50.6601",
    "lng": "12.35619"
  },
  {
    "country": "DE",
    "name": "Neulußheim",
    "lat": "49.29806",
    "lng": "8.51833"
  },
  {
    "country": "DE",
    "name": "Neulewin",
    "lat": "52.72434",
    "lng": "14.27922"
  },
  {
    "country": "DE",
    "name": "Neuler",
    "lat": "48.92803",
    "lng": "10.06888"
  },
  {
    "country": "DE",
    "name": "Neukölln",
    "lat": "52.47719",
    "lng": "13.43126"
  },
  {
    "country": "DE",
    "name": "Neukloster",
    "lat": "53.86548",
    "lng": "11.68512"
  },
  {
    "country": "DE",
    "name": "Neukirchen-Balbini",
    "lat": "49.29101",
    "lng": "12.43643"
  },
  {
    "country": "DE",
    "name": "Neukirchen",
    "lat": "54.86667",
    "lng": "8.73333"
  },
  {
    "country": "DE",
    "name": "Neukirchen",
    "lat": "54.21465",
    "lng": "10.55381"
  },
  {
    "country": "DE",
    "name": "Neukirchen",
    "lat": "50.86906",
    "lng": "9.34655"
  },
  {
    "country": "DE",
    "name": "Neukirchen",
    "lat": "50.80188",
    "lng": "12.38416"
  },
  {
    "country": "DE",
    "name": "Neukirchen",
    "lat": "50.77955",
    "lng": "12.86755"
  },
  {
    "country": "DE",
    "name": "Neukirchen",
    "lat": "49.26015",
    "lng": "12.96921"
  },
  {
    "country": "DE",
    "name": "Neukirchen",
    "lat": "48.97506",
    "lng": "12.75547"
  },
  {
    "country": "DE",
    "name": "Neukirch",
    "lat": "51.28333",
    "lng": "13.98333"
  },
  {
    "country": "DE",
    "name": "Neukirch/Lausitz",
    "lat": "51.09727",
    "lng": "14.30789"
  },
  {
    "country": "DE",
    "name": "Neukirch",
    "lat": "47.65738",
    "lng": "9.70333"
  },
  {
    "country": "DE",
    "name": "Neukieritzsch",
    "lat": "51.14995",
    "lng": "12.4109"
  },
  {
    "country": "DE",
    "name": "Neu Kaliß",
    "lat": "53.17466",
    "lng": "11.29446"
  },
  {
    "country": "DE",
    "name": "Neukalen",
    "lat": "53.82275",
    "lng": "12.79015"
  },
  {
    "country": "DE",
    "name": "Neu Isenburg",
    "lat": "50.04832",
    "lng": "8.69406"
  },
  {
    "country": "DE",
    "name": "Neuhütten",
    "lat": "50",
    "lng": "9.41667"
  },
  {
    "country": "DE",
    "name": "Neuhofen",
    "lat": "49.42778",
    "lng": "8.42472"
  },
  {
    "country": "DE",
    "name": "Neuhof an der Zenn",
    "lat": "49.4569",
    "lng": "10.64548"
  },
  {
    "country": "DE",
    "name": "Neuhof",
    "lat": "50.45313",
    "lng": "9.6175"
  },
  {
    "country": "DE",
    "name": "Neuhaus-Schierschnitz",
    "lat": "50.31237",
    "lng": "11.24019"
  },
  {
    "country": "DE",
    "name": "Neuhausen auf den Fildern",
    "lat": "48.68333",
    "lng": "9.28333"
  },
  {
    "country": "DE",
    "name": "Neuhausen",
    "lat": "50.67647",
    "lng": "13.4675"
  },
  {
    "country": "DE",
    "name": "Neuhausen",
    "lat": "48.7926",
    "lng": "8.77649"
  },
  {
    "country": "DE",
    "name": "Neuhausen",
    "lat": "47.83754",
    "lng": "8.77449"
  },
  {
    "country": "DE",
    "name": "Neuhäusel",
    "lat": "50.3836",
    "lng": "7.7096"
  },
  {
    "country": "DE",
    "name": "Neuhaus an der Pegnitz",
    "lat": "49.62799",
    "lng": "11.55066"
  },
  {
    "country": "DE",
    "name": "Neuhaus an der Oste",
    "lat": "53.80043",
    "lng": "9.03348"
  },
  {
    "country": "DE",
    "name": "Neuhaus am Rennweg",
    "lat": "50.51006",
    "lng": "11.13787"
  },
  {
    "country": "DE",
    "name": "Neuhaus",
    "lat": "50.68333",
    "lng": "10.93333"
  },
  {
    "country": "DE",
    "name": "Neuharlingersiel",
    "lat": "53.69993",
    "lng": "7.70288"
  },
  {
    "country": "DE",
    "name": "Neuhardenberg",
    "lat": "52.59601",
    "lng": "14.23768"
  },
  {
    "country": "DE",
    "name": "Neugersdorf",
    "lat": "50.97729",
    "lng": "14.60881"
  },
  {
    "country": "DE",
    "name": "Neufraunhofen",
    "lat": "48.4",
    "lng": "12.21667"
  },
  {
    "country": "DE",
    "name": "Neufra",
    "lat": "48.1288",
    "lng": "9.47554"
  },
  {
    "country": "DE",
    "name": "Neuffen",
    "lat": "48.5546",
    "lng": "9.3755"
  },
  {
    "country": "DE",
    "name": "Neufahrn bei Freising",
    "lat": "48.31588",
    "lng": "11.66316"
  },
  {
    "country": "DE",
    "name": "Neufahrn",
    "lat": "48.25587",
    "lng": "12.44078"
  },
  {
    "country": "DE",
    "name": "Neuerburg",
    "lat": "50.00102",
    "lng": "6.94828"
  },
  {
    "country": "DE",
    "name": "Neuental",
    "lat": "51",
    "lng": "9.21667"
  },
  {
    "country": "DE",
    "name": "Neuenstein",
    "lat": "49.2049",
    "lng": "9.58"
  },
  {
    "country": "DE",
    "name": "Neuenstadt am Kocher",
    "lat": "49.23498",
    "lng": "9.33215"
  },
  {
    "country": "DE",
    "name": "Neuensalz",
    "lat": "50.5",
    "lng": "12.21667"
  },
  {
    "country": "DE",
    "name": "Neuenrade",
    "lat": "51.28278",
    "lng": "7.7825"
  },
  {
    "country": "DE",
    "name": "Neuenmarkt",
    "lat": "50.09193",
    "lng": "11.58033"
  },
  {
    "country": "DE",
    "name": "Neuenkirchen",
    "lat": "53.59729",
    "lng": "13.36942"
  },
  {
    "country": "DE",
    "name": "Neuenkirchen",
    "lat": "53.23173",
    "lng": "8.52665"
  },
  {
    "country": "DE",
    "name": "Neuenkirchen",
    "lat": "53.03259",
    "lng": "9.70642"
  },
  {
    "country": "DE",
    "name": "Neuenkirchen",
    "lat": "52.77629",
    "lng": "8.75044"
  },
  {
    "country": "DE",
    "name": "Neuenkirchen",
    "lat": "52.51037",
    "lng": "8.06371"
  },
  {
    "country": "DE",
    "name": "Neuenkirchen",
    "lat": "52.24472",
    "lng": "7.37183"
  },
  {
    "country": "DE",
    "name": "Neuenkirchen",
    "lat": "52.13778",
    "lng": "8.38835"
  },
  {
    "country": "DE",
    "name": "Neuenhagen",
    "lat": "52.52985",
    "lng": "13.68914"
  },
  {
    "country": "DE",
    "name": "Neuendettelsau",
    "lat": "49.28333",
    "lng": "10.78333"
  },
  {
    "country": "DE",
    "name": "Neuenbürg",
    "lat": "48.84516",
    "lng": "8.59574"
  },
  {
    "country": "DE",
    "name": "Neuenburg am Rhein",
    "lat": "47.81431",
    "lng": "7.56005"
  },
  {
    "country": "DE",
    "name": "Neudrossenfeld",
    "lat": "50.01667",
    "lng": "11.5"
  },
  {
    "country": "DE",
    "name": "Neudorf-Bornstein",
    "lat": "54.43333",
    "lng": "9.95"
  },
  {
    "country": "DE",
    "name": "Neudietendorf",
    "lat": "50.9125",
    "lng": "10.91346"
  },
  {
    "country": "DE",
    "name": "Neudenau",
    "lat": "49.29181",
    "lng": "9.26975"
  },
  {
    "country": "DE",
    "name": "Neu Darchau",
    "lat": "53.22901",
    "lng": "10.88529"
  },
  {
    "country": "DE",
    "name": "Neuburg an der Donau",
    "lat": "48.73218",
    "lng": "11.18709"
  },
  {
    "country": "DE",
    "name": "Neuburg",
    "lat": "53.40677",
    "lng": "11.91742"
  },
  {
    "country": "DE",
    "name": "Neuburg",
    "lat": "48.98933",
    "lng": "8.24715"
  },
  {
    "country": "DE",
    "name": "Neuburg",
    "lat": "48.50654",
    "lng": "13.44718"
  },
  {
    "country": "DE",
    "name": "Neuburg",
    "lat": "47.77056",
    "lng": "10.35563"
  },
  {
    "country": "DE",
    "name": "Neubulach",
    "lat": "48.66092",
    "lng": "8.69611"
  },
  {
    "country": "DE",
    "name": "Neubukow",
    "lat": "54.03177",
    "lng": "11.67391"
  },
  {
    "country": "DE",
    "name": "Neubrunn",
    "lat": "49.73088",
    "lng": "9.67161"
  },
  {
    "country": "DE",
    "name": "Neubrück",
    "lat": "52.37088",
    "lng": "10.41761"
  },
  {
    "country": "DE",
    "name": "Neubrück",
    "lat": "51.13434",
    "lng": "6.63857"
  },
  {
    "country": "DE",
    "name": "Neubrandenburg",
    "lat": "53.56414",
    "lng": "13.27532"
  },
  {
    "country": "DE",
    "name": "Neubörger",
    "lat": "52.95815",
    "lng": "7.44839"
  },
  {
    "country": "DE",
    "name": "Neubiberg",
    "lat": "48.0771",
    "lng": "11.65812"
  },
  {
    "country": "DE",
    "name": "Neubeuern",
    "lat": "47.77368",
    "lng": "12.14002"
  },
  {
    "country": "DE",
    "name": "Neuberend",
    "lat": "54.55",
    "lng": "9.53333"
  },
  {
    "country": "DE",
    "name": "Neu-Anspach",
    "lat": "50.31667",
    "lng": "8.5"
  },
  {
    "country": "DE",
    "name": "Neualbenreuth",
    "lat": "49.98037",
    "lng": "12.44373"
  },
  {
    "country": "DE",
    "name": "Netzschkau",
    "lat": "50.61411",
    "lng": "12.24382"
  },
  {
    "country": "DE",
    "name": "Nettetal",
    "lat": "51.31667",
    "lng": "6.28333"
  },
  {
    "country": "DE",
    "name": "Nettersheim",
    "lat": "50.49372",
    "lng": "6.62896"
  },
  {
    "country": "DE",
    "name": "Netphen",
    "lat": "50.91667",
    "lng": "8.1"
  },
  {
    "country": "DE",
    "name": "Nesselwang",
    "lat": "47.62342",
    "lng": "10.50243"
  },
  {
    "country": "DE",
    "name": "Neschwitz",
    "lat": "51.27056",
    "lng": "14.329"
  },
  {
    "country": "DE",
    "name": "Nersingen",
    "lat": "48.42829",
    "lng": "10.12356"
  },
  {
    "country": "DE",
    "name": "Neresheim",
    "lat": "48.75511",
    "lng": "10.33041"
  },
  {
    "country": "DE",
    "name": "Nerchau",
    "lat": "51.27094",
    "lng": "12.78912"
  },
  {
    "country": "DE",
    "name": "Nentershausen",
    "lat": "51.01667",
    "lng": "9.93333"
  },
  {
    "country": "DE",
    "name": "Nentershausen",
    "lat": "50.41667",
    "lng": "7.93333"
  },
  {
    "country": "DE",
    "name": "Nennslingen",
    "lat": "49.04709",
    "lng": "11.13052"
  },
  {
    "country": "DE",
    "name": "Nennhausen",
    "lat": "52.6",
    "lng": "12.5"
  },
  {
    "country": "DE",
    "name": "Nellingen",
    "lat": "48.54196",
    "lng": "9.79053"
  },
  {
    "country": "DE",
    "name": "Neinstedt",
    "lat": "51.7495",
    "lng": "11.08721"
  },
  {
    "country": "DE",
    "name": "Neidlingen",
    "lat": "48.57865",
    "lng": "9.56454"
  },
  {
    "country": "DE",
    "name": "Neidenstein",
    "lat": "49.31667",
    "lng": "8.88472"
  },
  {
    "country": "DE",
    "name": "Nehren",
    "lat": "48.43097",
    "lng": "9.0699"
  },
  {
    "country": "DE",
    "name": "Negernbötel",
    "lat": "53.98333",
    "lng": "10.25"
  },
  {
    "country": "DE",
    "name": "Neckarzimmern",
    "lat": "49.31917",
    "lng": "9.13278"
  },
  {
    "country": "DE",
    "name": "Neckarwestheim",
    "lat": "49.04694",
    "lng": "9.19"
  },
  {
    "country": "DE",
    "name": "Neckartenzlingen",
    "lat": "48.58981",
    "lng": "9.23478"
  },
  {
    "country": "DE",
    "name": "Neckartailfingen",
    "lat": "48.61172",
    "lng": "9.26371"
  },
  {
    "country": "DE",
    "name": "Neckarsulm",
    "lat": "49.18912",
    "lng": "9.22527"
  },
  {
    "country": "DE",
    "name": "Neckarsteinach",
    "lat": "49.40735",
    "lng": "8.84342"
  },
  {
    "country": "DE",
    "name": "Neckargerach",
    "lat": "49.4",
    "lng": "9.06667"
  },
  {
    "country": "DE",
    "name": "Neckargemünd",
    "lat": "49.38899",
    "lng": "8.7959"
  },
  {
    "country": "DE",
    "name": "Neckarbischofsheim",
    "lat": "49.29625",
    "lng": "8.9638"
  },
  {
    "country": "DE",
    "name": "Nebra",
    "lat": "51.2881",
    "lng": "11.57749"
  },
  {
    "country": "DE",
    "name": "Nebelschütz",
    "lat": "51.26227",
    "lng": "14.15849"
  },
  {
    "country": "DE",
    "name": "Nauwalde",
    "lat": "51.41837",
    "lng": "13.40974"
  },
  {
    "country": "DE",
    "name": "Nauroth",
    "lat": "50.69927",
    "lng": "7.87543"
  },
  {
    "country": "DE",
    "name": "Nauort",
    "lat": "50.46667",
    "lng": "7.63333"
  },
  {
    "country": "DE",
    "name": "Naunhof",
    "lat": "51.2777",
    "lng": "12.58827"
  },
  {
    "country": "DE",
    "name": "Naundorf",
    "lat": "51.25718",
    "lng": "13.1081"
  },
  {
    "country": "DE",
    "name": "Naumburg",
    "lat": "51.24816",
    "lng": "9.16569"
  },
  {
    "country": "DE",
    "name": "Naumburg",
    "lat": "51.14987",
    "lng": "11.80979"
  },
  {
    "country": "DE",
    "name": "Nauendorf",
    "lat": "51.60178",
    "lng": "11.88525"
  },
  {
    "country": "DE",
    "name": "Nauen",
    "lat": "52.60701",
    "lng": "12.87374"
  },
  {
    "country": "DE",
    "name": "Nattheim",
    "lat": "48.69963",
    "lng": "10.24209"
  },
  {
    "country": "DE",
    "name": "Nastätten",
    "lat": "50.19883",
    "lng": "7.85892"
  },
  {
    "country": "DE",
    "name": "Nassau",
    "lat": "50.31453",
    "lng": "7.80025"
  },
  {
    "country": "DE",
    "name": "Narsdorf",
    "lat": "51.01667",
    "lng": "12.71667"
  },
  {
    "country": "DE",
    "name": "Nanzdietschweiler",
    "lat": "49.45",
    "lng": "7.45"
  },
  {
    "country": "DE",
    "name": "Nandlstadt",
    "lat": "48.53644",
    "lng": "11.8073"
  },
  {
    "country": "DE",
    "name": "Namborn",
    "lat": "49.52166",
    "lng": "7.1407"
  },
  {
    "country": "DE",
    "name": "Nalbach",
    "lat": "49.38333",
    "lng": "6.78333"
  },
  {
    "country": "DE",
    "name": "Naila",
    "lat": "50.33034",
    "lng": "11.70463"
  },
  {
    "country": "DE",
    "name": "Nahrendorf",
    "lat": "53.17389",
    "lng": "10.81381"
  },
  {
    "country": "DE",
    "name": "Nahe",
    "lat": "53.8",
    "lng": "10.13333"
  },
  {
    "country": "DE",
    "name": "Nagold",
    "lat": "48.5498",
    "lng": "8.72366"
  },
  {
    "country": "DE",
    "name": "Nagel",
    "lat": "49.98333",
    "lng": "11.91667"
  },
  {
    "country": "DE",
    "name": "Nackenheim",
    "lat": "49.91528",
    "lng": "8.33889"
  },
  {
    "country": "DE",
    "name": "Nachterstedt",
    "lat": "51.80081",
    "lng": "11.33489"
  },
  {
    "country": "DE",
    "name": "Nachrodt-Wiblingwerde",
    "lat": "51.31667",
    "lng": "7.61667"
  },
  {
    "country": "DE",
    "name": "Nabburg",
    "lat": "49.45347",
    "lng": "12.17996"
  },
  {
    "country": "DE",
    "name": "Mylau",
    "lat": "50.61861",
    "lng": "12.26535"
  },
  {
    "country": "DE",
    "name": "Mutzschen",
    "lat": "51.26159",
    "lng": "12.89125"
  },
  {
    "country": "DE",
    "name": "Mutterstadt",
    "lat": "49.44139",
    "lng": "8.35611"
  },
  {
    "country": "DE",
    "name": "Mutlangen",
    "lat": "48.82588",
    "lng": "9.79714"
  },
  {
    "country": "DE",
    "name": "Muschwitz",
    "lat": "51.19296",
    "lng": "12.12065"
  },
  {
    "country": "DE",
    "name": "Müschenbach",
    "lat": "50.68333",
    "lng": "7.78333"
  },
  {
    "country": "DE",
    "name": "Murrhardt",
    "lat": "48.98191",
    "lng": "9.57047"
  },
  {
    "country": "DE",
    "name": "Murr",
    "lat": "48.96207",
    "lng": "9.25924"
  },
  {
    "country": "DE",
    "name": "Murnau am Staffelsee",
    "lat": "47.68085",
    "lng": "11.20125"
  },
  {
    "country": "DE",
    "name": "Murg",
    "lat": "47.55492",
    "lng": "8.02182"
  },
  {
    "country": "DE",
    "name": "Münzenberg",
    "lat": "50.45346",
    "lng": "8.7743"
  },
  {
    "country": "DE",
    "name": "Münster-Sarmsheim",
    "lat": "49.94341",
    "lng": "7.89426"
  },
  {
    "country": "DE",
    "name": "Münstermaifeld",
    "lat": "50.24638",
    "lng": "7.36208"
  },
  {
    "country": "DE",
    "name": "Münsterhausen",
    "lat": "48.30973",
    "lng": "10.455"
  },
  {
    "country": "DE",
    "name": "Münsterdorf",
    "lat": "53.90232",
    "lng": "9.54123"
  },
  {
    "country": "DE",
    "name": "Munster",
    "lat": "52.98569",
    "lng": "10.08756"
  },
  {
    "country": "DE",
    "name": "Münster",
    "lat": "51.96236",
    "lng": "7.62571"
  },
  {
    "country": "DE",
    "name": "Münster",
    "lat": "49.92278",
    "lng": "8.86778"
  },
  {
    "country": "DE",
    "name": "Münster",
    "lat": "48.22904",
    "lng": "10.63623"
  },
  {
    "country": "DE",
    "name": "Münsingen",
    "lat": "48.41126",
    "lng": "9.49704"
  },
  {
    "country": "DE",
    "name": "Münsing",
    "lat": "47.9",
    "lng": "11.36667"
  },
  {
    "country": "DE",
    "name": "Munningen",
    "lat": "48.91667",
    "lng": "10.6"
  },
  {
    "country": "DE",
    "name": "Münnerstadt",
    "lat": "50.24636",
    "lng": "10.20187"
  },
  {
    "country": "DE",
    "name": "Munkbrarup",
    "lat": "54.8",
    "lng": "9.56667"
  },
  {
    "country": "DE",
    "name": "Munderkingen",
    "lat": "48.23568",
    "lng": "9.64398"
  },
  {
    "country": "DE",
    "name": "Hannoversch Münden",
    "lat": "51.41505",
    "lng": "9.65046"
  },
  {
    "country": "DE",
    "name": "Mundelsheim",
    "lat": "49.00083",
    "lng": "9.20778"
  },
  {
    "country": "DE",
    "name": "Münchweiler an der Rodalbe",
    "lat": "49.21798",
    "lng": "7.70295"
  },
  {
    "country": "DE",
    "name": "Münchweiler an der Alsenz",
    "lat": "49.55",
    "lng": "7.88333"
  },
  {
    "country": "DE",
    "name": "Münchsteinach",
    "lat": "49.63937",
    "lng": "10.59502"
  },
  {
    "country": "DE",
    "name": "Münchsmünster",
    "lat": "48.76667",
    "lng": "11.68333"
  },
  {
    "country": "DE",
    "name": "Münchhausen",
    "lat": "50.96081",
    "lng": "8.71837"
  },
  {
    "country": "DE",
    "name": "Münchenbernsdorf",
    "lat": "50.82114",
    "lng": "11.93226"
  },
  {
    "country": "DE",
    "name": "Munich",
    "lat": "48.13743",
    "lng": "11.57549"
  },
  {
    "country": "DE",
    "name": "Müncheberg",
    "lat": "52.50704",
    "lng": "14.13716"
  },
  {
    "country": "DE",
    "name": "Münchberg",
    "lat": "50.18952",
    "lng": "11.78823"
  },
  {
    "country": "DE",
    "name": "Mülsen",
    "lat": "50.75",
    "lng": "12.56667"
  },
  {
    "country": "DE",
    "name": "Müllrose",
    "lat": "52.24736",
    "lng": "14.41794"
  },
  {
    "country": "DE",
    "name": "Müllheim",
    "lat": "47.8082",
    "lng": "7.63035"
  },
  {
    "country": "DE",
    "name": "Mülheim",
    "lat": "51.43218",
    "lng": "6.87967"
  },
  {
    "country": "DE",
    "name": "Mulfingen",
    "lat": "49.34028",
    "lng": "9.80083"
  },
  {
    "country": "DE",
    "name": "Muldenstein",
    "lat": "51.67192",
    "lng": "12.34548"
  },
  {
    "country": "DE",
    "name": "Mulda",
    "lat": "50.80789",
    "lng": "13.41477"
  },
  {
    "country": "DE",
    "name": "Mühltroff",
    "lat": "50.53919",
    "lng": "11.92828"
  },
  {
    "country": "DE",
    "name": "Mühl Rosin",
    "lat": "53.76383",
    "lng": "12.21388"
  },
  {
    "country": "DE",
    "name": "Mühlingen",
    "lat": "47.91667",
    "lng": "9.01667"
  },
  {
    "country": "DE",
    "name": "Mühlheim am Bach",
    "lat": "48.37863",
    "lng": "8.69735"
  },
  {
    "country": "DE",
    "name": "Mühlheim am Main",
    "lat": "50.11667",
    "lng": "8.83333"
  },
  {
    "country": "DE",
    "name": "Stuttgart Mühlhausen",
    "lat": "48.84232",
    "lng": "9.23028"
  },
  {
    "country": "DE",
    "name": "Mühlhausen",
    "lat": "51.20896",
    "lng": "10.45275"
  },
  {
    "country": "DE",
    "name": "Mühlhausen",
    "lat": "49.75443",
    "lng": "10.77563"
  },
  {
    "country": "DE",
    "name": "Mühlhausen",
    "lat": "49.24861",
    "lng": "8.72667"
  },
  {
    "country": "DE",
    "name": "Mühlhausen",
    "lat": "48.57661",
    "lng": "9.65733"
  },
  {
    "country": "DE",
    "name": "Mühlen Eichsen",
    "lat": "53.75775",
    "lng": "11.25006"
  },
  {
    "country": "DE",
    "name": "Mühlenbach",
    "lat": "48.25",
    "lng": "8.11667"
  },
  {
    "country": "DE",
    "name": "Mühldorf",
    "lat": "48.2467",
    "lng": "12.52155"
  },
  {
    "country": "DE",
    "name": "Mühlberg",
    "lat": "51.43453",
    "lng": "13.22177"
  },
  {
    "country": "DE",
    "name": "Mühlau",
    "lat": "50.9",
    "lng": "12.76667"
  },
  {
    "country": "DE",
    "name": "Mühlacker",
    "lat": "48.94754",
    "lng": "8.83675"
  },
  {
    "country": "DE",
    "name": "Muggensturm",
    "lat": "48.86667",
    "lng": "8.28333"
  },
  {
    "country": "DE",
    "name": "Müggelheim",
    "lat": "52.41137",
    "lng": "13.66403"
  },
  {
    "country": "DE",
    "name": "Mügeln",
    "lat": "51.23619",
    "lng": "13.04567"
  },
  {
    "country": "DE",
    "name": "Mudersbach",
    "lat": "50.82515",
    "lng": "7.94347"
  },
  {
    "country": "DE",
    "name": "Müden",
    "lat": "52.52771",
    "lng": "10.36011"
  },
  {
    "country": "DE",
    "name": "Mudau",
    "lat": "49.53444",
    "lng": "9.20444"
  },
  {
    "country": "DE",
    "name": "Mücka",
    "lat": "51.31667",
    "lng": "14.7"
  },
  {
    "country": "DE",
    "name": "Mücheln",
    "lat": "51.29688",
    "lng": "11.80759"
  },
  {
    "country": "DE",
    "name": "Much",
    "lat": "50.90383",
    "lng": "7.40306"
  },
  {
    "country": "DE",
    "name": "Mötzingen",
    "lat": "48.5332",
    "lng": "8.77447"
  },
  {
    "country": "DE",
    "name": "Mötzing",
    "lat": "48.8935",
    "lng": "12.37361"
  },
  {
    "country": "DE",
    "name": "Möttingen",
    "lat": "48.80924",
    "lng": "10.59022"
  },
  {
    "country": "DE",
    "name": "Motten",
    "lat": "50.39561",
    "lng": "9.77251"
  },
  {
    "country": "DE",
    "name": "Mössingen",
    "lat": "48.40567",
    "lng": "9.05419"
  },
  {
    "country": "DE",
    "name": "Möser",
    "lat": "52.21397",
    "lng": "11.79279"
  },
  {
    "country": "DE",
    "name": "Mosbach",
    "lat": "49.35357",
    "lng": "9.15106"
  },
  {
    "country": "DE",
    "name": "Morsum",
    "lat": "52.95347",
    "lng": "9.07962"
  },
  {
    "country": "DE",
    "name": "Morsbach",
    "lat": "50.86665",
    "lng": "7.72787"
  },
  {
    "country": "DE",
    "name": "Mörlenbach",
    "lat": "49.59917",
    "lng": "8.73472"
  },
  {
    "country": "DE",
    "name": "Moritzburg",
    "lat": "51.15922",
    "lng": "13.68021"
  },
  {
    "country": "DE",
    "name": "Moringen",
    "lat": "51.69915",
    "lng": "9.87107"
  },
  {
    "country": "DE",
    "name": "Morbach",
    "lat": "49.80772",
    "lng": "7.12714"
  },
  {
    "country": "DE",
    "name": "Moosthenning",
    "lat": "48.67659",
    "lng": "12.49737"
  },
  {
    "country": "DE",
    "name": "Moosinning",
    "lat": "48.27708",
    "lng": "11.84446"
  },
  {
    "country": "DE",
    "name": "Moosburg",
    "lat": "48.47089",
    "lng": "11.93811"
  },
  {
    "country": "DE",
    "name": "Moosbach",
    "lat": "49.58909",
    "lng": "12.41036"
  },
  {
    "country": "DE",
    "name": "Moosach",
    "lat": "48.03213",
    "lng": "11.8751"
  },
  {
    "country": "DE",
    "name": "Moos",
    "lat": "47.72439",
    "lng": "8.93479"
  },
  {
    "country": "DE",
    "name": "Moorrege",
    "lat": "53.66667",
    "lng": "9.66667"
  },
  {
    "country": "DE",
    "name": "Moorenweis",
    "lat": "48.15561",
    "lng": "11.07851"
  },
  {
    "country": "DE",
    "name": "Monzingen",
    "lat": "49.79763",
    "lng": "7.59284"
  },
  {
    "country": "DE",
    "name": "Monzelfeld",
    "lat": "49.89237",
    "lng": "7.07318"
  },
  {
    "country": "DE",
    "name": "Montabaur",
    "lat": "50.43588",
    "lng": "7.8232"
  },
  {
    "country": "DE",
    "name": "Monsheim",
    "lat": "49.63722",
    "lng": "8.21194"
  },
  {
    "country": "DE",
    "name": "Mönsheim",
    "lat": "48.86667",
    "lng": "8.86667"
  },
  {
    "country": "DE",
    "name": "Monschau",
    "lat": "50.55462",
    "lng": "6.24001"
  },
  {
    "country": "DE",
    "name": "Mönkeberg",
    "lat": "54.35",
    "lng": "10.18333"
  },
  {
    "country": "DE",
    "name": "Monheim am Rhein",
    "lat": "51.09162",
    "lng": "6.89217"
  },
  {
    "country": "DE",
    "name": "Monheim",
    "lat": "48.84389",
    "lng": "10.85834"
  },
  {
    "country": "DE",
    "name": "Mönchweiler",
    "lat": "48.1004",
    "lng": "8.42219"
  },
  {
    "country": "DE",
    "name": "Mönchsroth",
    "lat": "49.01851",
    "lng": "10.35856"
  },
  {
    "country": "DE",
    "name": "Mönchsdeggingen",
    "lat": "48.77605",
    "lng": "10.58043"
  },
  {
    "country": "DE",
    "name": "Mönchhagen",
    "lat": "54.15146",
    "lng": "12.2167"
  },
  {
    "country": "DE",
    "name": "Mönchenholzhausen",
    "lat": "50.96667",
    "lng": "11.15"
  },
  {
    "country": "DE",
    "name": "Mönchengladbach",
    "lat": "51.18539",
    "lng": "6.44172"
  },
  {
    "country": "DE",
    "name": "Mönchberg",
    "lat": "49.79326",
    "lng": "9.26858"
  },
  {
    "country": "DE",
    "name": "Mommenheim",
    "lat": "49.88028",
    "lng": "8.265"
  },
  {
    "country": "DE",
    "name": "Mömlingen",
    "lat": "49.85972",
    "lng": "9.08333"
  },
  {
    "country": "DE",
    "name": "Mömbris",
    "lat": "50.06921",
    "lng": "9.16371"
  },
  {
    "country": "DE",
    "name": "Molschleben",
    "lat": "51",
    "lng": "10.78333"
  },
  {
    "country": "DE",
    "name": "Mölln",
    "lat": "53.61702",
    "lng": "10.68742"
  },
  {
    "country": "DE",
    "name": "Möllenhagen",
    "lat": "53.52388",
    "lng": "12.92868"
  },
  {
    "country": "DE",
    "name": "Molfsee",
    "lat": "54.26667",
    "lng": "10.06667"
  },
  {
    "country": "DE",
    "name": "Molbergen",
    "lat": "52.85805",
    "lng": "7.92548"
  },
  {
    "country": "DE",
    "name": "Moisburg",
    "lat": "53.4062",
    "lng": "9.6988"
  },
  {
    "country": "DE",
    "name": "Möhrendorf",
    "lat": "49.63333",
    "lng": "11"
  },
  {
    "country": "DE",
    "name": "Mohlsdorf",
    "lat": "50.66974",
    "lng": "12.26519"
  },
  {
    "country": "DE",
    "name": "Möhlau",
    "lat": "51.73126",
    "lng": "12.35282"
  },
  {
    "country": "DE",
    "name": "Möglingen",
    "lat": "48.88741",
    "lng": "9.12694"
  },
  {
    "country": "DE",
    "name": "Mögglingen",
    "lat": "48.8232",
    "lng": "9.9625"
  },
  {
    "country": "DE",
    "name": "Mogendorf",
    "lat": "50.49444",
    "lng": "7.75972"
  },
  {
    "country": "DE",
    "name": "Moers",
    "lat": "51.45342",
    "lng": "6.6326"
  },
  {
    "country": "DE",
    "name": "Mödingen",
    "lat": "48.64327",
    "lng": "10.43173"
  },
  {
    "country": "DE",
    "name": "Mockrehna",
    "lat": "51.50757",
    "lng": "12.81418"
  },
  {
    "country": "DE",
    "name": "Möckmühl",
    "lat": "49.3249",
    "lng": "9.35837"
  },
  {
    "country": "DE",
    "name": "Möckern",
    "lat": "52.14099",
    "lng": "11.95203"
  },
  {
    "country": "DE",
    "name": "Mochau",
    "lat": "51.13333",
    "lng": "13.18333"
  },
  {
    "country": "DE",
    "name": "Moabit",
    "lat": "52.52635",
    "lng": "13.33903"
  },
  {
    "country": "DE",
    "name": "Mixdorf",
    "lat": "52.2",
    "lng": "14.4"
  },
  {
    "country": "DE",
    "name": "Mitwitz",
    "lat": "50.25111",
    "lng": "11.20818"
  },
  {
    "country": "DE",
    "name": "Mittweida",
    "lat": "50.98622",
    "lng": "12.97537"
  },
  {
    "country": "DE",
    "name": "Mitterteich",
    "lat": "49.95141",
    "lng": "12.24206"
  },
  {
    "country": "DE",
    "name": "Mitterskirchen",
    "lat": "48.35",
    "lng": "12.73333"
  },
  {
    "country": "DE",
    "name": "Mitterfels",
    "lat": "48.97633",
    "lng": "12.67848"
  },
  {
    "country": "DE",
    "name": "Mittenwalde",
    "lat": "52.26007",
    "lng": "13.53945"
  },
  {
    "country": "DE",
    "name": "Mittenwald",
    "lat": "47.4422",
    "lng": "11.26187"
  },
  {
    "country": "DE",
    "name": "Mittenaar",
    "lat": "50.7",
    "lng": "8.38333"
  },
  {
    "country": "DE",
    "name": "Mittelstetten",
    "lat": "48.25",
    "lng": "11.1"
  },
  {
    "country": "DE",
    "name": "Mittelschöntal",
    "lat": "48.94615",
    "lng": "9.3952"
  },
  {
    "country": "DE",
    "name": "Mittelneufnach",
    "lat": "48.17642",
    "lng": "10.59754"
  },
  {
    "country": "DE",
    "name": "Mittelhof",
    "lat": "50.77517",
    "lng": "7.80466"
  },
  {
    "country": "DE",
    "name": "Mittelherwigsdorf",
    "lat": "50.91667",
    "lng": "14.76667"
  },
  {
    "country": "DE",
    "name": "Mitteleschenbach",
    "lat": "49.21186",
    "lng": "10.79784"
  },
  {
    "country": "DE",
    "name": "Mittelbiberach",
    "lat": "48.08333",
    "lng": "9.75"
  },
  {
    "country": "DE",
    "name": "Mittegroßefehn",
    "lat": "53.39165",
    "lng": "7.56602"
  },
  {
    "country": "DE",
    "name": "Mistelgau",
    "lat": "49.9126",
    "lng": "11.46586"
  },
  {
    "country": "DE",
    "name": "Mirow",
    "lat": "53.5051",
    "lng": "11.50294"
  },
  {
    "country": "DE",
    "name": "Mintraching",
    "lat": "48.95357",
    "lng": "12.24209"
  },
  {
    "country": "DE",
    "name": "Minfeld",
    "lat": "49.07167",
    "lng": "8.14528"
  },
  {
    "country": "DE",
    "name": "Minden",
    "lat": "52.28953",
    "lng": "8.91455"
  },
  {
    "country": "DE",
    "name": "Mindelheim",
    "lat": "48.04578",
    "lng": "10.49222"
  },
  {
    "country": "DE",
    "name": "Milz",
    "lat": "50.3776",
    "lng": "10.53757"
  },
  {
    "country": "DE",
    "name": "Groß Miltzow",
    "lat": "53.53565",
    "lng": "13.59354"
  },
  {
    "country": "DE",
    "name": "Miltenberg",
    "lat": "49.70452",
    "lng": "9.26725"
  },
  {
    "country": "DE",
    "name": "Miltach",
    "lat": "49.16196",
    "lng": "12.76843"
  },
  {
    "country": "DE",
    "name": "Milmersdorf",
    "lat": "53.11185",
    "lng": "13.6415"
  },
  {
    "country": "DE",
    "name": "Mildstedt",
    "lat": "54.46667",
    "lng": "9.1"
  },
  {
    "country": "DE",
    "name": "Mildenau",
    "lat": "50.58689",
    "lng": "13.07263"
  },
  {
    "country": "DE",
    "name": "Mihla",
    "lat": "51.07617",
    "lng": "10.33175"
  },
  {
    "country": "DE",
    "name": "Mietingen",
    "lat": "48.18333",
    "lng": "9.9"
  },
  {
    "country": "DE",
    "name": "Mieste",
    "lat": "52.48226",
    "lng": "11.2064"
  },
  {
    "country": "DE",
    "name": "Miesbach",
    "lat": "47.78903",
    "lng": "11.83382"
  },
  {
    "country": "DE",
    "name": "Mielkendorf",
    "lat": "54.28333",
    "lng": "10.05"
  },
  {
    "country": "DE",
    "name": "Miehlen",
    "lat": "50.22574",
    "lng": "7.83196"
  },
  {
    "country": "DE",
    "name": "Midlum",
    "lat": "53.73135",
    "lng": "8.61695"
  },
  {
    "country": "DE",
    "name": "Mickhausen",
    "lat": "48.24171",
    "lng": "10.64026"
  },
  {
    "country": "DE",
    "name": "Michendorf",
    "lat": "52.31352",
    "lng": "13.02996"
  },
  {
    "country": "DE",
    "name": "Michelstadt",
    "lat": "49.67569",
    "lng": "9.00373"
  },
  {
    "country": "DE",
    "name": "Michelsneukirchen",
    "lat": "49.12291",
    "lng": "12.55284"
  },
  {
    "country": "DE",
    "name": "Michelfeld",
    "lat": "49.0975",
    "lng": "9.67861"
  },
  {
    "country": "DE",
    "name": "Michelbach an der Bilz",
    "lat": "49.07028",
    "lng": "9.7625"
  },
  {
    "country": "DE",
    "name": "Michelau",
    "lat": "50.16233",
    "lng": "11.11207"
  },
  {
    "country": "DE",
    "name": "Michelau",
    "lat": "49.90556",
    "lng": "10.43064"
  },
  {
    "country": "DE",
    "name": "Meyenburg",
    "lat": "53.04524",
    "lng": "14.23691"
  },
  {
    "country": "DE",
    "name": "Meuselwitz",
    "lat": "51.04315",
    "lng": "12.29935"
  },
  {
    "country": "DE",
    "name": "Meuselbach",
    "lat": "50.57152",
    "lng": "11.09143"
  },
  {
    "country": "DE",
    "name": "Meudt",
    "lat": "50.49889",
    "lng": "7.895"
  },
  {
    "country": "DE",
    "name": "Metzingen",
    "lat": "48.53695",
    "lng": "9.2833"
  },
  {
    "country": "DE",
    "name": "Mettmann",
    "lat": "51.2504",
    "lng": "6.97536"
  },
  {
    "country": "DE",
    "name": "Mettlach",
    "lat": "49.49489",
    "lng": "6.58562"
  },
  {
    "country": "DE",
    "name": "Mettingen",
    "lat": "52.31667",
    "lng": "7.78333"
  },
  {
    "country": "DE",
    "name": "Mettenheim",
    "lat": "49.74",
    "lng": "8.32583"
  },
  {
    "country": "DE",
    "name": "Mettenheim",
    "lat": "48.26667",
    "lng": "12.46667"
  },
  {
    "country": "DE",
    "name": "Mettendorf",
    "lat": "49.94784",
    "lng": "6.33003"
  },
  {
    "country": "DE",
    "name": "Metten",
    "lat": "48.85512",
    "lng": "12.91554"
  },
  {
    "country": "DE",
    "name": "Metelen",
    "lat": "52.14434",
    "lng": "7.2127"
  },
  {
    "country": "DE",
    "name": "Meßstetten",
    "lat": "48.18317",
    "lng": "8.96565"
  },
  {
    "country": "DE",
    "name": "Meßkirch",
    "lat": "47.99457",
    "lng": "9.11479"
  },
  {
    "country": "DE",
    "name": "Messingen",
    "lat": "52.46667",
    "lng": "7.46667"
  },
  {
    "country": "DE",
    "name": "Messel",
    "lat": "49.93833",
    "lng": "8.74056"
  },
  {
    "country": "DE",
    "name": "Mesekenhagen",
    "lat": "54.14846",
    "lng": "13.31843"
  },
  {
    "country": "DE",
    "name": "Meschede",
    "lat": "51.3502",
    "lng": "8.28332"
  },
  {
    "country": "DE",
    "name": "Merzig",
    "lat": "49.44331",
    "lng": "6.63874"
  },
  {
    "country": "DE",
    "name": "Merzhausen",
    "lat": "47.96667",
    "lng": "7.83333"
  },
  {
    "country": "DE",
    "name": "Merzen",
    "lat": "52.48333",
    "lng": "7.83333"
  },
  {
    "country": "DE",
    "name": "Merzalben",
    "lat": "49.24467",
    "lng": "7.73077"
  },
  {
    "country": "DE",
    "name": "Merxheim",
    "lat": "49.79297",
    "lng": "7.5601"
  },
  {
    "country": "DE",
    "name": "Mertloch",
    "lat": "50.26948",
    "lng": "7.30814"
  },
  {
    "country": "DE",
    "name": "Mertingen",
    "lat": "48.65695",
    "lng": "10.80557"
  },
  {
    "country": "DE",
    "name": "Mertesdorf",
    "lat": "49.77212",
    "lng": "6.7329"
  },
  {
    "country": "DE",
    "name": "Merseburg",
    "lat": "51.35478",
    "lng": "11.98923"
  },
  {
    "country": "DE",
    "name": "Merklingen",
    "lat": "48.51135",
    "lng": "9.75496"
  },
  {
    "country": "DE",
    "name": "Merkendorf",
    "lat": "49.20361",
    "lng": "10.70416"
  },
  {
    "country": "DE",
    "name": "Merkenbach",
    "lat": "50.65626",
    "lng": "8.29513"
  },
  {
    "country": "DE",
    "name": "Mering",
    "lat": "48.2656",
    "lng": "10.98461"
  },
  {
    "country": "DE",
    "name": "Merenberg",
    "lat": "50.50707",
    "lng": "8.19194"
  },
  {
    "country": "DE",
    "name": "Merdingen",
    "lat": "48.01667",
    "lng": "7.68333"
  },
  {
    "country": "DE",
    "name": "Merchweiler",
    "lat": "49.35",
    "lng": "7.05"
  },
  {
    "country": "DE",
    "name": "Merching",
    "lat": "48.24594",
    "lng": "10.9853"
  },
  {
    "country": "DE",
    "name": "Meppen",
    "lat": "52.69064",
    "lng": "7.29097"
  },
  {
    "country": "DE",
    "name": "Menteroda",
    "lat": "51.30763",
    "lng": "10.56323"
  },
  {
    "country": "DE",
    "name": "Menslage",
    "lat": "52.68333",
    "lng": "7.81667"
  },
  {
    "country": "DE",
    "name": "Mengkofen",
    "lat": "48.71894",
    "lng": "12.44047"
  },
  {
    "country": "DE",
    "name": "Mengerskirchen",
    "lat": "50.56392",
    "lng": "8.15555"
  },
  {
    "country": "DE",
    "name": "Mengersgereuth-Hämmern",
    "lat": "50.3973",
    "lng": "11.11649"
  },
  {
    "country": "DE",
    "name": "Mengenich",
    "lat": "50.9785",
    "lng": "6.86737"
  },
  {
    "country": "DE",
    "name": "Mengen",
    "lat": "48.04951",
    "lng": "9.33005"
  },
  {
    "country": "DE",
    "name": "Mendig",
    "lat": "50.36667",
    "lng": "7.28333"
  },
  {
    "country": "DE",
    "name": "Menden",
    "lat": "51.44337",
    "lng": "7.77825"
  },
  {
    "country": "DE",
    "name": "Memmingerberg",
    "lat": "47.98803",
    "lng": "10.22295"
  },
  {
    "country": "DE",
    "name": "Memmingen",
    "lat": "47.98372",
    "lng": "10.18527"
  },
  {
    "country": "DE",
    "name": "Memmelsdorf",
    "lat": "49.93012",
    "lng": "10.95921"
  },
  {
    "country": "DE",
    "name": "Melsungen",
    "lat": "51.13029",
    "lng": "9.55236"
  },
  {
    "country": "DE",
    "name": "Melsdorf",
    "lat": "54.31667",
    "lng": "10.03333"
  },
  {
    "country": "DE",
    "name": "Melsbach",
    "lat": "50.48333",
    "lng": "7.48333"
  },
  {
    "country": "DE",
    "name": "Mellrichstadt",
    "lat": "50.42849",
    "lng": "10.30334"
  },
  {
    "country": "DE",
    "name": "Mellinghausen",
    "lat": "52.70697",
    "lng": "8.89704"
  },
  {
    "country": "DE",
    "name": "Mellingen",
    "lat": "50.94123",
    "lng": "11.3964"
  },
  {
    "country": "DE",
    "name": "Mellenbach-Glasbach",
    "lat": "50.61667",
    "lng": "11.1"
  },
  {
    "country": "DE",
    "name": "Melle",
    "lat": "52.20197",
    "lng": "8.33826"
  },
  {
    "country": "DE",
    "name": "Meldorf",
    "lat": "54.09182",
    "lng": "9.0687"
  },
  {
    "country": "DE",
    "name": "Melchow",
    "lat": "52.77613",
    "lng": "13.70647"
  },
  {
    "country": "DE",
    "name": "Melbeck",
    "lat": "53.18333",
    "lng": "10.4"
  },
  {
    "country": "DE",
    "name": "Melbach",
    "lat": "50.37908",
    "lng": "8.80926"
  },
  {
    "country": "DE",
    "name": "Meitzendorf",
    "lat": "52.21308",
    "lng": "11.56174"
  },
  {
    "country": "DE",
    "name": "Meitingen",
    "lat": "48.54586",
    "lng": "10.85179"
  },
  {
    "country": "DE",
    "name": "Meißenheim",
    "lat": "48.41035",
    "lng": "7.77266"
  },
  {
    "country": "DE",
    "name": "Meissen",
    "lat": "51.16158",
    "lng": "13.4737"
  },
  {
    "country": "DE",
    "name": "Meisenheim",
    "lat": "49.70721",
    "lng": "7.66765"
  },
  {
    "country": "DE",
    "name": "Meiningen",
    "lat": "50.56787",
    "lng": "10.41521"
  },
  {
    "country": "DE",
    "name": "Meinerzhagen",
    "lat": "51.1074",
    "lng": "7.64838"
  },
  {
    "country": "DE",
    "name": "Meinersen",
    "lat": "52.47436",
    "lng": "10.35247"
  },
  {
    "country": "DE",
    "name": "Meiderich",
    "lat": "51.46667",
    "lng": "6.76667"
  },
  {
    "country": "DE",
    "name": "Mehrstetten",
    "lat": "48.37609",
    "lng": "9.566"
  },
  {
    "country": "DE",
    "name": "Mehringen",
    "lat": "51.72663",
    "lng": "11.51264"
  },
  {
    "country": "DE",
    "name": "Mehring",
    "lat": "49.8",
    "lng": "6.83333"
  },
  {
    "country": "DE",
    "name": "Mehring",
    "lat": "48.18333",
    "lng": "12.78333"
  },
  {
    "country": "DE",
    "name": "Mehrhoog",
    "lat": "51.73826",
    "lng": "6.51164"
  },
  {
    "country": "DE",
    "name": "Mehren",
    "lat": "50.18333",
    "lng": "6.88333"
  },
  {
    "country": "DE",
    "name": "Mehltheuer",
    "lat": "50.5453",
    "lng": "12.037"
  },
  {
    "country": "DE",
    "name": "Mehlmeisel",
    "lat": "49.97421",
    "lng": "11.862"
  },
  {
    "country": "DE",
    "name": "Mehlingen",
    "lat": "49.49136",
    "lng": "7.85467"
  },
  {
    "country": "DE",
    "name": "Mehlbach",
    "lat": "49.51667",
    "lng": "7.71667"
  },
  {
    "country": "DE",
    "name": "Meersburg",
    "lat": "47.69419",
    "lng": "9.27113"
  },
  {
    "country": "DE",
    "name": "Meerdorf",
    "lat": "52.34583",
    "lng": "10.31745"
  },
  {
    "country": "DE",
    "name": "Meerbusch",
    "lat": "51.25268",
    "lng": "6.68807"
  },
  {
    "country": "DE",
    "name": "Meerbeck",
    "lat": "52.34174",
    "lng": "9.15067"
  },
  {
    "country": "DE",
    "name": "Meerane",
    "lat": "50.84688",
    "lng": "12.46473"
  },
  {
    "country": "DE",
    "name": "Meeder",
    "lat": "50.32118",
    "lng": "10.90697"
  },
  {
    "country": "DE",
    "name": "Medebach",
    "lat": "51.19713",
    "lng": "8.70635"
  },
  {
    "country": "DE",
    "name": "Meddersheim",
    "lat": "49.77636",
    "lng": "7.61708"
  },
  {
    "country": "DE",
    "name": "Mecklenburg",
    "lat": "53.8427",
    "lng": "11.4633"
  },
  {
    "country": "DE",
    "name": "Meckesheim",
    "lat": "49.32167",
    "lng": "8.81944"
  },
  {
    "country": "DE",
    "name": "Meckenheim",
    "lat": "50.62388",
    "lng": "7.02942"
  },
  {
    "country": "DE",
    "name": "Meckenheim",
    "lat": "49.40444",
    "lng": "8.23917"
  },
  {
    "country": "DE",
    "name": "Meckenbeuren",
    "lat": "47.7",
    "lng": "9.56667"
  },
  {
    "country": "DE",
    "name": "Mechterstädt",
    "lat": "50.94201",
    "lng": "10.5238"
  },
  {
    "country": "DE",
    "name": "Mechernich",
    "lat": "50.59304",
    "lng": "6.65224"
  },
  {
    "country": "DE",
    "name": "Mayen",
    "lat": "50.32797",
    "lng": "7.22277"
  },
  {
    "country": "DE",
    "name": "Maxsain",
    "lat": "50.54316",
    "lng": "7.78512"
  },
  {
    "country": "DE",
    "name": "Maxhütte-Haidhof",
    "lat": "49.19963",
    "lng": "12.09229"
  },
  {
    "country": "DE",
    "name": "Maxdorf",
    "lat": "49.48806",
    "lng": "8.29167"
  },
  {
    "country": "DE",
    "name": "Mauth",
    "lat": "48.88972",
    "lng": "13.58459"
  },
  {
    "country": "DE",
    "name": "Maulburg",
    "lat": "47.64631",
    "lng": "7.7821"
  },
  {
    "country": "DE",
    "name": "Maulbronn",
    "lat": "48.99958",
    "lng": "8.80337"
  },
  {
    "country": "DE",
    "name": "Mauerstetten",
    "lat": "47.89358",
    "lng": "10.67127"
  },
  {
    "country": "DE",
    "name": "Mauern",
    "lat": "48.51667",
    "lng": "11.9"
  },
  {
    "country": "DE",
    "name": "Mauer",
    "lat": "49.34083",
    "lng": "8.80028"
  },
  {
    "country": "DE",
    "name": "Mastershausen",
    "lat": "50.06667",
    "lng": "7.35"
  },
  {
    "country": "DE",
    "name": "Maßweiler",
    "lat": "49.26667",
    "lng": "7.53333"
  },
  {
    "country": "DE",
    "name": "Massing",
    "lat": "48.39118",
    "lng": "12.60947"
  },
  {
    "country": "DE",
    "name": "Masserberg",
    "lat": "50.51981",
    "lng": "10.97087"
  },
  {
    "country": "DE",
    "name": "Massenbachhausen",
    "lat": "49.17778",
    "lng": "9.04333"
  },
  {
    "country": "DE",
    "name": "Maßbach",
    "lat": "50.18321",
    "lng": "10.27522"
  },
  {
    "country": "DE",
    "name": "Maselheim",
    "lat": "48.13333",
    "lng": "9.88333"
  },
  {
    "country": "DE",
    "name": "Masburg",
    "lat": "50.24065",
    "lng": "7.11736"
  },
  {
    "country": "DE",
    "name": "Marzling",
    "lat": "48.40904",
    "lng": "11.79382"
  },
  {
    "country": "DE",
    "name": "Marzahn",
    "lat": "52.54525",
    "lng": "13.56983"
  },
  {
    "country": "DE",
    "name": "Marxheim",
    "lat": "48.74153",
    "lng": "10.94504"
  },
  {
    "country": "DE",
    "name": "Marxen",
    "lat": "53.31211",
    "lng": "10.00415"
  },
  {
    "country": "DE",
    "name": "Martinshöhe",
    "lat": "49.36667",
    "lng": "7.48333"
  },
  {
    "country": "DE",
    "name": "Martinsheim",
    "lat": "49.6235",
    "lng": "10.14879"
  },
  {
    "country": "DE",
    "name": "Martinhagen",
    "lat": "51.28688",
    "lng": "9.28611"
  },
  {
    "country": "DE",
    "name": "Martfeld",
    "lat": "52.87572",
    "lng": "9.06081"
  },
  {
    "country": "DE",
    "name": "Martensrade",
    "lat": "54.28333",
    "lng": "10.4"
  },
  {
    "country": "DE",
    "name": "Marsberg",
    "lat": "51.46171",
    "lng": "8.84949"
  },
  {
    "country": "DE",
    "name": "Marquartstein",
    "lat": "47.75857",
    "lng": "12.46219"
  },
  {
    "country": "DE",
    "name": "Marpingen",
    "lat": "49.45228",
    "lng": "7.0582"
  },
  {
    "country": "DE",
    "name": "Maroldsweisach",
    "lat": "50.19578",
    "lng": "10.66003"
  },
  {
    "country": "DE",
    "name": "Marnheim",
    "lat": "49.63278",
    "lng": "8.04"
  },
  {
    "country": "DE",
    "name": "Marlow",
    "lat": "54.15439",
    "lng": "12.57261"
  },
  {
    "country": "DE",
    "name": "Marloffstein",
    "lat": "49.61794",
    "lng": "11.06323"
  },
  {
    "country": "DE",
    "name": "Marl",
    "lat": "51.65671",
    "lng": "7.09038"
  },
  {
    "country": "DE",
    "name": "Marktzeuln",
    "lat": "50.16673",
    "lng": "11.16692"
  },
  {
    "country": "DE",
    "name": "Markt Wald",
    "lat": "48.1368",
    "lng": "10.58198"
  },
  {
    "country": "DE",
    "name": "Marktsteft",
    "lat": "49.69606",
    "lng": "10.13626"
  },
  {
    "country": "DE",
    "name": "Markt Schwaben",
    "lat": "48.18949",
    "lng": "11.8691"
  },
  {
    "country": "DE",
    "name": "Marktschorgast",
    "lat": "50.09475",
    "lng": "11.65465"
  },
  {
    "country": "DE",
    "name": "Marktschellenberg",
    "lat": "47.69657",
    "lng": "13.0434"
  },
  {
    "country": "DE",
    "name": "Markt Rettenbach",
    "lat": "47.94733",
    "lng": "10.39608"
  },
  {
    "country": "DE",
    "name": "Marktredwitz",
    "lat": "50.00443",
    "lng": "12.08593"
  },
  {
    "country": "DE",
    "name": "Marktoffingen",
    "lat": "48.92566",
    "lng": "10.47078"
  },
  {
    "country": "DE",
    "name": "Marktoberdorf",
    "lat": "47.77964",
    "lng": "10.61713"
  },
  {
    "country": "DE",
    "name": "Markt Nordheim",
    "lat": "49.59095",
    "lng": "10.35564"
  },
  {
    "country": "DE",
    "name": "Marktleuthen",
    "lat": "50.13007",
    "lng": "12.00226"
  },
  {
    "country": "DE",
    "name": "Marktleugast",
    "lat": "50.17306",
    "lng": "11.63389"
  },
  {
    "country": "DE",
    "name": "Marktl",
    "lat": "48.25516",
    "lng": "12.8447"
  },
  {
    "country": "DE",
    "name": "Markt Indersdorf",
    "lat": "48.36058",
    "lng": "11.37789"
  },
  {
    "country": "DE",
    "name": "Marktheidenfeld",
    "lat": "49.8454",
    "lng": "9.60359"
  },
  {
    "country": "DE",
    "name": "Marktgraitz",
    "lat": "50.18358",
    "lng": "11.19441"
  },
  {
    "country": "DE",
    "name": "Markt Erlbach",
    "lat": "49.49367",
    "lng": "10.65265"
  },
  {
    "country": "DE",
    "name": "Marktbreit",
    "lat": "49.66541",
    "lng": "10.14811"
  },
  {
    "country": "DE",
    "name": "Markt Bibart",
    "lat": "49.64787",
    "lng": "10.42492"
  },
  {
    "country": "DE",
    "name": "Markt Berolzheim",
    "lat": "49.00955",
    "lng": "10.84473"
  },
  {
    "country": "DE",
    "name": "Marktbergel",
    "lat": "49.44156",
    "lng": "10.36355"
  },
  {
    "country": "DE",
    "name": "Marksuhl",
    "lat": "50.91667",
    "lng": "10.2"
  },
  {
    "country": "DE",
    "name": "Markranstädt",
    "lat": "51.30146",
    "lng": "12.2202"
  },
  {
    "country": "DE",
    "name": "Markneukirchen",
    "lat": "50.31144",
    "lng": "12.32951"
  },
  {
    "country": "DE",
    "name": "Marklohe",
    "lat": "52.66857",
    "lng": "9.14219"
  },
  {
    "country": "DE",
    "name": "Marklkofen",
    "lat": "48.55",
    "lng": "12.56667"
  },
  {
    "country": "DE",
    "name": "Markkleeberg",
    "lat": "51.2755",
    "lng": "12.36906"
  },
  {
    "country": "DE",
    "name": "Märkisches Viertel",
    "lat": "52.59841",
    "lng": "13.35766"
  },
  {
    "country": "DE",
    "name": "Markgröningen",
    "lat": "48.90493",
    "lng": "9.08059"
  },
  {
    "country": "DE",
    "name": "Markersdorf",
    "lat": "51.13333",
    "lng": "14.88333"
  },
  {
    "country": "DE",
    "name": "Markersbach",
    "lat": "50.53545",
    "lng": "12.86149"
  },
  {
    "country": "DE",
    "name": "Markdorf",
    "lat": "47.71916",
    "lng": "9.39028"
  },
  {
    "country": "DE",
    "name": "Maring-Noviand",
    "lat": "49.93333",
    "lng": "7"
  },
  {
    "country": "DE",
    "name": "Marienwerder",
    "lat": "52.84208",
    "lng": "13.59927"
  },
  {
    "country": "DE",
    "name": "Mariental",
    "lat": "52.27593",
    "lng": "10.98371"
  },
  {
    "country": "DE",
    "name": "Marienrachdorf",
    "lat": "50.55",
    "lng": "7.71667"
  },
  {
    "country": "DE",
    "name": "Marienheide",
    "lat": "51.08317",
    "lng": "7.53087"
  },
  {
    "country": "DE",
    "name": "Marienhafe",
    "lat": "53.52274",
    "lng": "7.27306"
  },
  {
    "country": "DE",
    "name": "Marienfelde",
    "lat": "52.41868",
    "lng": "13.36723"
  },
  {
    "country": "DE",
    "name": "Mariendorf",
    "lat": "52.4378",
    "lng": "13.38109"
  },
  {
    "country": "DE",
    "name": "Marienberg",
    "lat": "50.65051",
    "lng": "13.16122"
  },
  {
    "country": "DE",
    "name": "Mariaposching",
    "lat": "48.83333",
    "lng": "12.8"
  },
  {
    "country": "DE",
    "name": "Margetshöchheim",
    "lat": "49.8375",
    "lng": "9.86389"
  },
  {
    "country": "DE",
    "name": "Marburg an der Lahn",
    "lat": "50.80904",
    "lng": "8.77069"
  },
  {
    "country": "DE",
    "name": "Marbach am Neckar",
    "lat": "48.93964",
    "lng": "9.25995"
  },
  {
    "country": "DE",
    "name": "Mantel",
    "lat": "49.65412",
    "lng": "12.04074"
  },
  {
    "country": "DE",
    "name": "Mansfeld",
    "lat": "51.59234",
    "lng": "11.45223"
  },
  {
    "country": "DE",
    "name": "Manschnow",
    "lat": "52.5499",
    "lng": "14.55332"
  },
  {
    "country": "DE",
    "name": "Mannheim",
    "lat": "49.4891",
    "lng": "8.46694"
  },
  {
    "country": "DE",
    "name": "Manderscheid",
    "lat": "50.09672",
    "lng": "6.80981"
  },
  {
    "country": "DE",
    "name": "Manching",
    "lat": "48.71656",
    "lng": "11.49393"
  },
  {
    "country": "DE",
    "name": "Mamming",
    "lat": "48.65174",
    "lng": "12.60784"
  },
  {
    "country": "DE",
    "name": "Mammendorf",
    "lat": "48.20836",
    "lng": "11.16326"
  },
  {
    "country": "DE",
    "name": "Mammelzen",
    "lat": "50.7",
    "lng": "7.66667"
  },
  {
    "country": "DE",
    "name": "Malterdingen",
    "lat": "48.15719",
    "lng": "7.78608"
  },
  {
    "country": "DE",
    "name": "Malsfeld",
    "lat": "51.09083",
    "lng": "9.53889"
  },
  {
    "country": "DE",
    "name": "Malschwitz",
    "lat": "51.23759",
    "lng": "14.52163"
  },
  {
    "country": "DE",
    "name": "Malsch",
    "lat": "49.24722",
    "lng": "8.68278"
  },
  {
    "country": "DE",
    "name": "Malsch",
    "lat": "48.88333",
    "lng": "8.33333"
  },
  {
    "country": "DE",
    "name": "Malliß",
    "lat": "53.21132",
    "lng": "11.32716"
  },
  {
    "country": "DE",
    "name": "Malgersdorf",
    "lat": "48.53333",
    "lng": "12.75"
  },
  {
    "country": "DE",
    "name": "Malente",
    "lat": "54.17226",
    "lng": "10.55968"
  },
  {
    "country": "DE",
    "name": "Malchow",
    "lat": "53.47477",
    "lng": "12.4221"
  },
  {
    "country": "DE",
    "name": "Malching",
    "lat": "48.31226",
    "lng": "13.18746"
  },
  {
    "country": "DE",
    "name": "Malchin",
    "lat": "53.7399",
    "lng": "12.76539"
  },
  {
    "country": "DE",
    "name": "Malborn",
    "lat": "49.71667",
    "lng": "6.98333"
  },
  {
    "country": "DE",
    "name": "Maitenbeth",
    "lat": "48.15053",
    "lng": "12.09335"
  },
  {
    "country": "DE",
    "name": "Maisach",
    "lat": "48.21667",
    "lng": "11.26667"
  },
  {
    "country": "DE",
    "name": "Mainzweiler",
    "lat": "49.41714",
    "lng": "7.11804"
  },
  {
    "country": "DE",
    "name": "Mainz",
    "lat": "49.98419",
    "lng": "8.2791"
  },
  {
    "country": "DE",
    "name": "Maintal",
    "lat": "50.15",
    "lng": "8.83333"
  },
  {
    "country": "DE",
    "name": "Mainstockheim",
    "lat": "49.77156",
    "lng": "10.14807"
  },
  {
    "country": "DE",
    "name": "Mainleus",
    "lat": "50.09987",
    "lng": "11.37664"
  },
  {
    "country": "DE",
    "name": "Mainhardt",
    "lat": "49.07611",
    "lng": "9.55639"
  },
  {
    "country": "DE",
    "name": "Mainburg",
    "lat": "48.64182",
    "lng": "11.78093"
  },
  {
    "country": "DE",
    "name": "Mainbernheim",
    "lat": "49.70794",
    "lng": "10.219"
  },
  {
    "country": "DE",
    "name": "Mainaschaff",
    "lat": "49.98167",
    "lng": "9.09"
  },
  {
    "country": "DE",
    "name": "Maikammer",
    "lat": "49.30528",
    "lng": "8.13167"
  },
  {
    "country": "DE",
    "name": "Maihingen",
    "lat": "48.92745",
    "lng": "10.49867"
  },
  {
    "country": "DE",
    "name": "Maierhöfen",
    "lat": "47.65",
    "lng": "10.05"
  },
  {
    "country": "DE",
    "name": "Mähring",
    "lat": "49.91095",
    "lng": "12.52448"
  },
  {
    "country": "DE",
    "name": "Mahlsdorf",
    "lat": "52.50935",
    "lng": "13.61373"
  },
  {
    "country": "DE",
    "name": "Mahlberg",
    "lat": "48.28639",
    "lng": "7.81411"
  },
  {
    "country": "DE",
    "name": "Magstadt",
    "lat": "48.74471",
    "lng": "8.96675"
  },
  {
    "country": "DE",
    "name": "Magdeburg",
    "lat": "52.12773",
    "lng": "11.62916"
  },
  {
    "country": "DE",
    "name": "Magdala",
    "lat": "50.90698",
    "lng": "11.44801"
  },
  {
    "country": "DE",
    "name": "Mackenbach",
    "lat": "49.46667",
    "lng": "7.58333"
  },
  {
    "country": "DE",
    "name": "Machern",
    "lat": "51.36667",
    "lng": "12.63333"
  },
  {
    "country": "DE",
    "name": "Lychen",
    "lat": "53.21242",
    "lng": "13.31483"
  },
  {
    "country": "DE",
    "name": "Lützow",
    "lat": "53.65345",
    "lng": "11.17582"
  },
  {
    "country": "DE",
    "name": "Lutzerath",
    "lat": "50.12695",
    "lng": "7.0074"
  },
  {
    "country": "DE",
    "name": "Lützen",
    "lat": "51.25671",
    "lng": "12.14164"
  },
  {
    "country": "DE",
    "name": "Lützelbach",
    "lat": "49.74233",
    "lng": "8.76687"
  },
  {
    "country": "DE",
    "name": "Lutter am Barenberge",
    "lat": "51.98943",
    "lng": "10.2693"
  },
  {
    "country": "DE",
    "name": "Lütjensee",
    "lat": "53.65",
    "lng": "10.36667"
  },
  {
    "country": "DE",
    "name": "Lütjenburg",
    "lat": "54.29188",
    "lng": "10.58945"
  },
  {
    "country": "DE",
    "name": "Lustadt",
    "lat": "49.24476",
    "lng": "8.27407"
  },
  {
    "country": "DE",
    "name": "Lurup",
    "lat": "53.59266",
    "lng": "9.87697"
  },
  {
    "country": "DE",
    "name": "Lürschau",
    "lat": "54.55",
    "lng": "9.5"
  },
  {
    "country": "DE",
    "name": "Lupburg",
    "lat": "49.1551",
    "lng": "11.7564"
  },
  {
    "country": "DE",
    "name": "Lunzenau",
    "lat": "50.96269",
    "lng": "12.75594"
  },
  {
    "country": "DE",
    "name": "Lunestedt",
    "lat": "53.43621",
    "lng": "8.75193"
  },
  {
    "country": "DE",
    "name": "Lünen",
    "lat": "51.61634",
    "lng": "7.52872"
  },
  {
    "country": "DE",
    "name": "Lüneburg",
    "lat": "53.2509",
    "lng": "10.41409"
  },
  {
    "country": "DE",
    "name": "Lunden",
    "lat": "54.33131",
    "lng": "9.02523"
  },
  {
    "country": "DE",
    "name": "Luisenthal",
    "lat": "50.78333",
    "lng": "10.73333"
  },
  {
    "country": "DE",
    "name": "Luhe-Wildenau",
    "lat": "49.58367",
    "lng": "12.14921"
  },
  {
    "country": "DE",
    "name": "Luhden",
    "lat": "52.22538",
    "lng": "9.09256"
  },
  {
    "country": "DE",
    "name": "Lügde",
    "lat": "51.95828",
    "lng": "9.24706"
  },
  {
    "country": "DE",
    "name": "Lugau",
    "lat": "50.73843",
    "lng": "12.74861"
  },
  {
    "country": "DE",
    "name": "Ludwigsstadt",
    "lat": "50.48605",
    "lng": "11.38734"
  },
  {
    "country": "DE",
    "name": "Ludwigslust",
    "lat": "53.32917",
    "lng": "11.49714"
  },
  {
    "country": "DE",
    "name": "Ludwigshafen am Rhein",
    "lat": "49.48121",
    "lng": "8.44641"
  },
  {
    "country": "DE",
    "name": "Ludwigsfelde",
    "lat": "52.30322",
    "lng": "13.25405"
  },
  {
    "country": "DE",
    "name": "Ludwigsburg",
    "lat": "48.89731",
    "lng": "9.19161"
  },
  {
    "country": "DE",
    "name": "Lüdinghausen",
    "lat": "51.7683",
    "lng": "7.44379"
  },
  {
    "country": "DE",
    "name": "Lüdersfeld",
    "lat": "52.35993",
    "lng": "9.25422"
  },
  {
    "country": "DE",
    "name": "Lüdersdorf",
    "lat": "53.86835",
    "lng": "11.74902"
  },
  {
    "country": "DE",
    "name": "Lüderitz",
    "lat": "52.50912",
    "lng": "11.74301"
  },
  {
    "country": "DE",
    "name": "Lüder",
    "lat": "52.80878",
    "lng": "10.66609"
  },
  {
    "country": "DE",
    "name": "Lüdenscheid",
    "lat": "51.21977",
    "lng": "7.6273"
  },
  {
    "country": "DE",
    "name": "Luckenwalde",
    "lat": "52.09029",
    "lng": "13.16772"
  },
  {
    "country": "DE",
    "name": "Luckau",
    "lat": "51.85245",
    "lng": "13.70735"
  },
  {
    "country": "DE",
    "name": "Lucka",
    "lat": "51.09727",
    "lng": "12.33336"
  },
  {
    "country": "DE",
    "name": "Lüchow",
    "lat": "52.96811",
    "lng": "11.15397"
  },
  {
    "country": "DE",
    "name": "Lübz",
    "lat": "53.46261",
    "lng": "12.02917"
  },
  {
    "country": "DE",
    "name": "Lübtheen",
    "lat": "53.30118",
    "lng": "11.08368"
  },
  {
    "country": "DE",
    "name": "Lübstorf",
    "lat": "53.72561",
    "lng": "11.41471"
  },
  {
    "country": "DE",
    "name": "Lübow",
    "lat": "53.85256",
    "lng": "11.5244"
  },
  {
    "country": "DE",
    "name": "Lubmin",
    "lat": "54.13509",
    "lng": "13.61687"
  },
  {
    "country": "DE",
    "name": "Lübeck",
    "lat": "53.86893",
    "lng": "10.68729"
  },
  {
    "country": "DE",
    "name": "Lübbenau",
    "lat": "51.86217",
    "lng": "13.95168"
  },
  {
    "country": "DE",
    "name": "Lübben",
    "lat": "51.93814",
    "lng": "13.88826"
  },
  {
    "country": "DE",
    "name": "Lübbecke",
    "lat": "52.30699",
    "lng": "8.61423"
  },
  {
    "country": "DE",
    "name": "Lübars",
    "lat": "52.61591",
    "lng": "13.3535"
  },
  {
    "country": "DE",
    "name": "Loxstedt",
    "lat": "53.46667",
    "lng": "8.65"
  },
  {
    "country": "DE",
    "name": "Löwenstein",
    "lat": "49.09558",
    "lng": "9.38"
  },
  {
    "country": "DE",
    "name": "Lottstetten",
    "lat": "47.63333",
    "lng": "8.56667"
  },
  {
    "country": "DE",
    "name": "Lotte",
    "lat": "52.28333",
    "lng": "7.91667"
  },
  {
    "country": "DE",
    "name": "Lostau",
    "lat": "52.20871",
    "lng": "11.73795"
  },
  {
    "country": "DE",
    "name": "Lößnitz",
    "lat": "50.62181",
    "lng": "12.73147"
  },
  {
    "country": "DE",
    "name": "Loßburg",
    "lat": "48.4",
    "lng": "8.45"
  },
  {
    "country": "DE",
    "name": "Losheim",
    "lat": "49.5099",
    "lng": "6.74549"
  },
  {
    "country": "DE",
    "name": "Lörzweiler",
    "lat": "49.89833",
    "lng": "8.29472"
  },
  {
    "country": "DE",
    "name": "Lorup",
    "lat": "52.92495",
    "lng": "7.64339"
  },
  {
    "country": "DE",
    "name": "Lorsch",
    "lat": "49.65",
    "lng": "8.56667"
  },
  {
    "country": "DE",
    "name": "Lörrach",
    "lat": "47.61497",
    "lng": "7.66457"
  },
  {
    "country": "DE",
    "name": "Lorch",
    "lat": "48.79833",
    "lng": "9.6914"
  },
  {
    "country": "DE",
    "name": "Lonsee",
    "lat": "48.5434",
    "lng": "9.91999"
  },
  {
    "country": "DE",
    "name": "Lonnig",
    "lat": "50.31002",
    "lng": "7.40509"
  },
  {
    "country": "DE",
    "name": "Lonnerstadt",
    "lat": "49.69882",
    "lng": "10.76711"
  },
  {
    "country": "DE",
    "name": "Löningen",
    "lat": "52.73678",
    "lng": "7.75809"
  },
  {
    "country": "DE",
    "name": "Longuich",
    "lat": "49.80841",
    "lng": "6.76832"
  },
  {
    "country": "DE",
    "name": "Longkamp",
    "lat": "49.89044",
    "lng": "7.11764"
  },
  {
    "country": "DE",
    "name": "Lommatzsch",
    "lat": "51.19537",
    "lng": "13.30917"
  },
  {
    "country": "DE",
    "name": "Lollar",
    "lat": "50.64652",
    "lng": "8.70495"
  },
  {
    "country": "DE",
    "name": "Loitz",
    "lat": "53.44205",
    "lng": "13.38802"
  },
  {
    "country": "DE",
    "name": "Loiching",
    "lat": "48.61667",
    "lng": "12.43333"
  },
  {
    "country": "DE",
    "name": "Lohsa",
    "lat": "51.38333",
    "lng": "14.4"
  },
  {
    "country": "DE",
    "name": "Lohra",
    "lat": "50.73333",
    "lng": "8.63333"
  },
  {
    "country": "DE",
    "name": "Lohr am Main",
    "lat": "49.98922",
    "lng": "9.57223"
  },
  {
    "country": "DE",
    "name": "Lohne",
    "lat": "52.66625",
    "lng": "8.2375"
  },
  {
    "country": "DE",
    "name": "Lohne",
    "lat": "52.49778",
    "lng": "7.22629"
  },
  {
    "country": "DE",
    "name": "Löhne",
    "lat": "52.18848",
    "lng": "8.6922"
  },
  {
    "country": "DE",
    "name": "Löhnberg",
    "lat": "50.51299",
    "lng": "8.27202"
  },
  {
    "country": "DE",
    "name": "Lohmen",
    "lat": "50.98831",
    "lng": "14.00268"
  },
  {
    "country": "DE",
    "name": "Lohmar",
    "lat": "50.83868",
    "lng": "7.21399"
  },
  {
    "country": "DE",
    "name": "Lohfelden",
    "lat": "51.26667",
    "lng": "9.53333"
  },
  {
    "country": "DE",
    "name": "Lohberg",
    "lat": "49.17604",
    "lng": "13.10549"
  },
  {
    "country": "DE",
    "name": "Löffingen",
    "lat": "47.88405",
    "lng": "8.34384"
  },
  {
    "country": "DE",
    "name": "Loffenau",
    "lat": "48.77214",
    "lng": "8.38463"
  },
  {
    "country": "DE",
    "name": "Löf",
    "lat": "50.23333",
    "lng": "7.43333"
  },
  {
    "country": "DE",
    "name": "Loddin",
    "lat": "54.02252",
    "lng": "14.00754"
  },
  {
    "country": "DE",
    "name": "Löcknitz",
    "lat": "53.28694",
    "lng": "11.78108"
  },
  {
    "country": "DE",
    "name": "Löchgau",
    "lat": "49.00361",
    "lng": "9.10639"
  },
  {
    "country": "DE",
    "name": "Lochau",
    "lat": "51.39738",
    "lng": "12.05303"
  },
  {
    "country": "DE",
    "name": "Loburg",
    "lat": "52.11509",
    "lng": "12.0784"
  },
  {
    "country": "DE",
    "name": "Lobstädt",
    "lat": "51.13361",
    "lng": "12.44861"
  },
  {
    "country": "DE",
    "name": "Löbnitz",
    "lat": "51.59238",
    "lng": "12.46347"
  },
  {
    "country": "DE",
    "name": "Löbichau",
    "lat": "50.89383",
    "lng": "12.26366"
  },
  {
    "country": "DE",
    "name": "Löberitz",
    "lat": "51.65393",
    "lng": "12.14655"
  },
  {
    "country": "DE",
    "name": "Bad Lobenstein",
    "lat": "50.45223",
    "lng": "11.6393"
  },
  {
    "country": "DE",
    "name": "Löbejün",
    "lat": "51.63533",
    "lng": "11.90106"
  },
  {
    "country": "DE",
    "name": "Löbau",
    "lat": "51.09954",
    "lng": "14.66738"
  },
  {
    "country": "DE",
    "name": "Litzendorf",
    "lat": "49.91444",
    "lng": "11.01028"
  },
  {
    "country": "DE",
    "name": "List",
    "lat": "55.01917",
    "lng": "8.43132"
  },
  {
    "country": "DE",
    "name": "Lissendorf",
    "lat": "50.31667",
    "lng": "6.6"
  },
  {
    "country": "DE",
    "name": "Lippstadt",
    "lat": "51.67369",
    "lng": "8.34482"
  },
  {
    "country": "DE",
    "name": "Linz am Rhein",
    "lat": "50.56884",
    "lng": "7.28445"
  },
  {
    "country": "DE",
    "name": "Lintig",
    "lat": "53.60341",
    "lng": "8.87876"
  },
  {
    "country": "DE",
    "name": "Linnich",
    "lat": "50.98002",
    "lng": "6.27049"
  },
  {
    "country": "DE",
    "name": "Lingenfeld",
    "lat": "49.25389",
    "lng": "8.33861"
  },
  {
    "country": "DE",
    "name": "Lingen",
    "lat": "52.52143",
    "lng": "7.31845"
  },
  {
    "country": "DE",
    "name": "Lindwedel",
    "lat": "52.60784",
    "lng": "9.68737"
  },
  {
    "country": "DE",
    "name": "Lindow",
    "lat": "52.96689",
    "lng": "12.98498"
  },
  {
    "country": "DE",
    "name": "Lindlar",
    "lat": "51.01959",
    "lng": "7.37758"
  },
  {
    "country": "DE",
    "name": "Lindhorst",
    "lat": "52.35789",
    "lng": "9.28319"
  },
  {
    "country": "DE",
    "name": "Lindewitt",
    "lat": "54.7",
    "lng": "9.2"
  },
  {
    "country": "DE",
    "name": "Lindenfels",
    "lat": "49.68369",
    "lng": "8.78151"
  },
  {
    "country": "DE",
    "name": "Lindenberg",
    "lat": "49.38028",
    "lng": "8.09861"
  },
  {
    "country": "DE",
    "name": "Linden",
    "lat": "49.35",
    "lng": "7.65"
  },
  {
    "country": "DE",
    "name": "Lindberg",
    "lat": "49.0368",
    "lng": "13.25423"
  },
  {
    "country": "DE",
    "name": "Lindau",
    "lat": "54.38333",
    "lng": "9.9"
  },
  {
    "country": "DE",
    "name": "Lindau",
    "lat": "52.03751",
    "lng": "12.10788"
  },
  {
    "country": "DE",
    "name": "Lindau",
    "lat": "47.54612",
    "lng": "9.68431"
  },
  {
    "country": "DE",
    "name": "Linau",
    "lat": "53.64446",
    "lng": "10.46853"
  },
  {
    "country": "DE",
    "name": "Limburgerhof",
    "lat": "49.42444",
    "lng": "8.39194"
  },
  {
    "country": "DE",
    "name": "Limburg an der Lahn",
    "lat": "50.3836",
    "lng": "8.0503"
  },
  {
    "country": "DE",
    "name": "Limbach-Oberfrohna",
    "lat": "50.85882",
    "lng": "12.76165"
  },
  {
    "country": "DE",
    "name": "Limbach",
    "lat": "50.58333",
    "lng": "12.25"
  },
  {
    "country": "DE",
    "name": "Lilienthal",
    "lat": "53.14193",
    "lng": "8.90338"
  },
  {
    "country": "DE",
    "name": "Lieskau",
    "lat": "51.50395",
    "lng": "11.86208"
  },
  {
    "country": "DE",
    "name": "Lieser",
    "lat": "49.91667",
    "lng": "7.01667"
  },
  {
    "country": "DE",
    "name": "Lienen",
    "lat": "52.15",
    "lng": "7.98333"
  },
  {
    "country": "DE",
    "name": "Liebstadt",
    "lat": "50.86417",
    "lng": "13.85694"
  },
  {
    "country": "DE",
    "name": "Lieberose",
    "lat": "51.98491",
    "lng": "14.29987"
  },
  {
    "country": "DE",
    "name": "Liebenwalde",
    "lat": "52.87125",
    "lng": "13.39465"
  },
  {
    "country": "DE",
    "name": "Liebenburg",
    "lat": "52.02176",
    "lng": "10.43169"
  },
  {
    "country": "DE",
    "name": "Liebenau",
    "lat": "52.60362",
    "lng": "9.09719"
  },
  {
    "country": "DE",
    "name": "Liebenau",
    "lat": "51.49699",
    "lng": "9.28207"
  },
  {
    "country": "DE",
    "name": "Lichterfelde",
    "lat": "52.4333",
    "lng": "13.30762"
  },
  {
    "country": "DE",
    "name": "Lichtentanne",
    "lat": "50.69255",
    "lng": "12.42585"
  },
  {
    "country": "DE",
    "name": "Lichtenstein",
    "lat": "50.75659",
    "lng": "12.63025"
  },
  {
    "country": "DE",
    "name": "Lichtenrade",
    "lat": "52.39844",
    "lng": "13.40637"
  },
  {
    "country": "DE",
    "name": "Lichtenfels",
    "lat": "50.14567",
    "lng": "11.05928"
  },
  {
    "country": "DE",
    "name": "Lichtenberg",
    "lat": "52.51395",
    "lng": "13.49975"
  },
  {
    "country": "DE",
    "name": "Lichtenberg",
    "lat": "51.18333",
    "lng": "13.96667"
  },
  {
    "country": "DE",
    "name": "Lichtenberg",
    "lat": "50.83492",
    "lng": "13.42478"
  },
  {
    "country": "DE",
    "name": "Lichtenberg",
    "lat": "50.38335",
    "lng": "11.67624"
  },
  {
    "country": "DE",
    "name": "Lichtenau",
    "lat": "51.61707",
    "lng": "8.89665"
  },
  {
    "country": "DE",
    "name": "Lichtenau",
    "lat": "49.15979",
    "lng": "10.37935"
  },
  {
    "country": "DE",
    "name": "Lichtenau",
    "lat": "48.72607",
    "lng": "8.00486"
  },
  {
    "country": "DE",
    "name": "Lichte",
    "lat": "50.51667",
    "lng": "11.18333"
  },
  {
    "country": "DE",
    "name": "Lich",
    "lat": "50.52085",
    "lng": "8.81567"
  },
  {
    "country": "DE",
    "name": "Leverkusen",
    "lat": "51.0303",
    "lng": "6.98432"
  },
  {
    "country": "DE",
    "name": "Leutkirch im Allgäu",
    "lat": "47.82672",
    "lng": "10.0205"
  },
  {
    "country": "DE",
    "name": "Leutesdorf",
    "lat": "50.45",
    "lng": "7.38333"
  },
  {
    "country": "DE",
    "name": "Leutershausen",
    "lat": "49.29869",
    "lng": "10.41189"
  },
  {
    "country": "DE",
    "name": "Leutersdorf",
    "lat": "50.95",
    "lng": "14.65"
  },
  {
    "country": "DE",
    "name": "Leutenberg",
    "lat": "50.56354",
    "lng": "11.45619"
  },
  {
    "country": "DE",
    "name": "Leutenbach",
    "lat": "49.7095",
    "lng": "11.17224"
  },
  {
    "country": "DE",
    "name": "Leutenbach",
    "lat": "48.88791",
    "lng": "9.39267"
  },
  {
    "country": "DE",
    "name": "Leupoldsgrün",
    "lat": "50.3",
    "lng": "11.8"
  },
  {
    "country": "DE",
    "name": "Leuna",
    "lat": "51.31783",
    "lng": "12.01589"
  },
  {
    "country": "DE",
    "name": "Leun",
    "lat": "50.55129",
    "lng": "8.35836"
  },
  {
    "country": "DE",
    "name": "Leuchtenberg",
    "lat": "49.59737",
    "lng": "12.2584"
  },
  {
    "country": "DE",
    "name": "Leubsdorf",
    "lat": "50.8",
    "lng": "13.16667"
  },
  {
    "country": "DE",
    "name": "Leubsdorf",
    "lat": "50.55",
    "lng": "7.3"
  },
  {
    "country": "DE",
    "name": "Leubnitz",
    "lat": "50.72313",
    "lng": "12.3566"
  },
  {
    "country": "DE",
    "name": "Letzlingen",
    "lat": "52.44615",
    "lng": "11.48518"
  },
  {
    "country": "DE",
    "name": "Letschin",
    "lat": "52.64379",
    "lng": "14.36007"
  },
  {
    "country": "DE",
    "name": "Leopoldshöhe",
    "lat": "52.01246",
    "lng": "8.69834"
  },
  {
    "country": "DE",
    "name": "Leonberg",
    "lat": "49.94708",
    "lng": "12.2852"
  },
  {
    "country": "DE",
    "name": "Leonberg",
    "lat": "48.8",
    "lng": "9.01667"
  },
  {
    "country": "DE",
    "name": "Lenzkirch",
    "lat": "47.86832",
    "lng": "8.20211"
  },
  {
    "country": "DE",
    "name": "Lenzen",
    "lat": "53.09176",
    "lng": "11.47453"
  },
  {
    "country": "DE",
    "name": "Lentföhrden",
    "lat": "53.86667",
    "lng": "9.88333"
  },
  {
    "country": "DE",
    "name": "Lensahn",
    "lat": "54.21652",
    "lng": "10.88326"
  },
  {
    "country": "DE",
    "name": "Lennestadt",
    "lat": "51.11721",
    "lng": "8.06707"
  },
  {
    "country": "DE",
    "name": "Lenggries",
    "lat": "47.68333",
    "lng": "11.56667"
  },
  {
    "country": "DE",
    "name": "Lengerich",
    "lat": "52.55381",
    "lng": "7.53164"
  },
  {
    "country": "DE",
    "name": "Lengerich",
    "lat": "52.18661",
    "lng": "7.86043"
  },
  {
    "country": "DE",
    "name": "Lengenwang",
    "lat": "47.7",
    "lng": "10.6"
  },
  {
    "country": "DE",
    "name": "Lengenfeld",
    "lat": "50.5694",
    "lng": "12.36408"
  },
  {
    "country": "DE",
    "name": "Lengefeld",
    "lat": "50.71911",
    "lng": "13.1929"
  },
  {
    "country": "DE",
    "name": "Lengede",
    "lat": "52.20487",
    "lng": "10.30775"
  },
  {
    "country": "DE",
    "name": "Lengdorf",
    "lat": "48.25737",
    "lng": "12.04973"
  },
  {
    "country": "DE",
    "name": "Lemwerder",
    "lat": "53.16667",
    "lng": "8.61667"
  },
  {
    "country": "DE",
    "name": "Lemsahl-Mellingstedt",
    "lat": "53.68998",
    "lng": "10.09648"
  },
  {
    "country": "DE",
    "name": "Lemgo",
    "lat": "52.02786",
    "lng": "8.89901"
  },
  {
    "country": "DE",
    "name": "Lemförde",
    "lat": "52.46557",
    "lng": "8.37621"
  },
  {
    "country": "DE",
    "name": "Lemberg",
    "lat": "49.17309",
    "lng": "7.65111"
  },
  {
    "country": "DE",
    "name": "Leiwen",
    "lat": "49.81667",
    "lng": "6.88333"
  },
  {
    "country": "DE",
    "name": "Leitzkau",
    "lat": "52.05818",
    "lng": "11.95203"
  },
  {
    "country": "DE",
    "name": "Leißling",
    "lat": "51.1826",
    "lng": "11.90954"
  },
  {
    "country": "DE",
    "name": "Leisnig",
    "lat": "51.15743",
    "lng": "12.9279"
  },
  {
    "country": "DE",
    "name": "Leipzig",
    "lat": "51.33962",
    "lng": "12.37129"
  },
  {
    "country": "DE",
    "name": "Leipheim",
    "lat": "48.45004",
    "lng": "10.22278"
  },
  {
    "country": "DE",
    "name": "Leinzell",
    "lat": "48.84941",
    "lng": "9.8775"
  },
  {
    "country": "DE",
    "name": "Leinfelden-Echterdingen",
    "lat": "48.69406",
    "lng": "9.16809"
  },
  {
    "country": "DE",
    "name": "Leinefelde-Worbis",
    "lat": "51.38796",
    "lng": "10.3262"
  },
  {
    "country": "DE",
    "name": "Leinburg",
    "lat": "49.45167",
    "lng": "11.31"
  },
  {
    "country": "DE",
    "name": "Leimersheim",
    "lat": "49.12421",
    "lng": "8.34531"
  },
  {
    "country": "DE",
    "name": "Leimen",
    "lat": "49.34737",
    "lng": "8.68733"
  },
  {
    "country": "DE",
    "name": "Leimbach",
    "lat": "50.81667",
    "lng": "10.2"
  },
  {
    "country": "DE",
    "name": "Leiferde",
    "lat": "52.20445",
    "lng": "10.50842"
  },
  {
    "country": "DE",
    "name": "Leidersbach",
    "lat": "49.90139",
    "lng": "9.22167"
  },
  {
    "country": "DE",
    "name": "Leichlingen",
    "lat": "51.10628",
    "lng": "7.01873"
  },
  {
    "country": "DE",
    "name": "Leiblfing",
    "lat": "48.77565",
    "lng": "12.51793"
  },
  {
    "country": "DE",
    "name": "Leibertingen",
    "lat": "48.04263",
    "lng": "9.01308"
  },
  {
    "country": "DE",
    "name": "Lehrte",
    "lat": "52.37193",
    "lng": "9.97919"
  },
  {
    "country": "DE",
    "name": "Lehrensteinsfeld",
    "lat": "49.13111",
    "lng": "9.32722"
  },
  {
    "country": "DE",
    "name": "Lehre",
    "lat": "52.33333",
    "lng": "10.66667"
  },
  {
    "country": "DE",
    "name": "Lehrberg",
    "lat": "49.34568",
    "lng": "10.51101"
  },
  {
    "country": "DE",
    "name": "Lehmkuhlen",
    "lat": "54.23333",
    "lng": "10.36667"
  },
  {
    "country": "DE",
    "name": "Lehmen",
    "lat": "50.28333",
    "lng": "7.45"
  },
  {
    "country": "DE",
    "name": "Lehesten",
    "lat": "50.98333",
    "lng": "11.58333"
  },
  {
    "country": "DE",
    "name": "Lehe",
    "lat": "54.34143",
    "lng": "9.02374"
  },
  {
    "country": "DE",
    "name": "Legden",
    "lat": "52.03333",
    "lng": "7.1"
  },
  {
    "country": "DE",
    "name": "Legau",
    "lat": "47.85628",
    "lng": "10.12981"
  },
  {
    "country": "DE",
    "name": "Leezen",
    "lat": "53.86667",
    "lng": "10.25"
  },
  {
    "country": "DE",
    "name": "Leezen",
    "lat": "53.66265",
    "lng": "11.49874"
  },
  {
    "country": "DE",
    "name": "Leezdorf",
    "lat": "53.55",
    "lng": "7.3"
  },
  {
    "country": "DE",
    "name": "Leese",
    "lat": "52.5",
    "lng": "9.11667"
  },
  {
    "country": "DE",
    "name": "Leer",
    "lat": "53.23157",
    "lng": "7.461"
  },
  {
    "country": "DE",
    "name": "Leegebruch",
    "lat": "52.7234",
    "lng": "13.19304"
  },
  {
    "country": "DE",
    "name": "Leck",
    "lat": "54.76667",
    "lng": "8.98333"
  },
  {
    "country": "DE",
    "name": "Lechbruck",
    "lat": "47.70162",
    "lng": "10.79493"
  },
  {
    "country": "DE",
    "name": "Lebus",
    "lat": "52.42719",
    "lng": "14.53235"
  },
  {
    "country": "DE",
    "name": "Lebach",
    "lat": "49.41122",
    "lng": "6.90988"
  },
  {
    "country": "DE",
    "name": "Lawalde",
    "lat": "51.08333",
    "lng": "14.6"
  },
  {
    "country": "DE",
    "name": "Lautrach",
    "lat": "47.89805",
    "lng": "10.11806"
  },
  {
    "country": "DE",
    "name": "Lautertal",
    "lat": "50.58333",
    "lng": "9.28333"
  },
  {
    "country": "DE",
    "name": "Lauterhofen",
    "lat": "49.3684",
    "lng": "11.60294"
  },
  {
    "country": "DE",
    "name": "Lauterecken",
    "lat": "49.64993",
    "lng": "7.59265"
  },
  {
    "country": "DE",
    "name": "Lauterbach",
    "lat": "50.63558",
    "lng": "9.39777"
  },
  {
    "country": "DE",
    "name": "Lauterbach/Schwarzwald",
    "lat": "48.22999",
    "lng": "8.3424"
  },
  {
    "country": "DE",
    "name": "Lauter",
    "lat": "50.56264",
    "lng": "12.73513"
  },
  {
    "country": "DE",
    "name": "Lauter",
    "lat": "49.97317",
    "lng": "10.78842"
  },
  {
    "country": "DE",
    "name": "Lautenbach",
    "lat": "48.48185",
    "lng": "8.02732"
  },
  {
    "country": "DE",
    "name": "Laußnitz",
    "lat": "51.25",
    "lng": "13.88333"
  },
  {
    "country": "DE",
    "name": "Laußig",
    "lat": "51.54676",
    "lng": "12.6293"
  },
  {
    "country": "DE",
    "name": "Lauscha",
    "lat": "50.47687",
    "lng": "11.15962"
  },
  {
    "country": "DE",
    "name": "Laupheim",
    "lat": "48.22786",
    "lng": "9.87874"
  },
  {
    "country": "DE",
    "name": "Lauingen",
    "lat": "48.56775",
    "lng": "10.42706"
  },
  {
    "country": "DE",
    "name": "Laugna",
    "lat": "48.53333",
    "lng": "10.7"
  },
  {
    "country": "DE",
    "name": "Lauffen am Neckar",
    "lat": "49.0734",
    "lng": "9.14567"
  },
  {
    "country": "DE",
    "name": "Laufenburg",
    "lat": "47.56512",
    "lng": "8.06045"
  },
  {
    "country": "DE",
    "name": "Laufen",
    "lat": "47.93568",
    "lng": "12.92856"
  },
  {
    "country": "DE",
    "name": "Laufdorf",
    "lat": "50.51605",
    "lng": "8.45982"
  },
  {
    "country": "DE",
    "name": "Lauf an der Pegnitz",
    "lat": "49.51386",
    "lng": "11.28247"
  },
  {
    "country": "DE",
    "name": "Laufach",
    "lat": "50.01667",
    "lng": "9.3"
  },
  {
    "country": "DE",
    "name": "Lauf",
    "lat": "48.65",
    "lng": "8.13333"
  },
  {
    "country": "DE",
    "name": "Lauenhagen",
    "lat": "52.35547",
    "lng": "9.20637"
  },
  {
    "country": "DE",
    "name": "Lauenburg",
    "lat": "53.37199",
    "lng": "10.55654"
  },
  {
    "country": "DE",
    "name": "Lauenbrück",
    "lat": "53.2",
    "lng": "9.56667"
  },
  {
    "country": "DE",
    "name": "Lauenau",
    "lat": "52.27393",
    "lng": "9.36928"
  },
  {
    "country": "DE",
    "name": "Laudenbach",
    "lat": "49.74583",
    "lng": "9.17611"
  },
  {
    "country": "DE",
    "name": "Laudenbach",
    "lat": "49.61333",
    "lng": "8.65389"
  },
  {
    "country": "DE",
    "name": "Lauchröden",
    "lat": "50.99371",
    "lng": "10.15694"
  },
  {
    "country": "DE",
    "name": "Lauchheim",
    "lat": "48.87135",
    "lng": "10.24222"
  },
  {
    "country": "DE",
    "name": "Lauchhammer",
    "lat": "51.48813",
    "lng": "13.76623"
  },
  {
    "country": "DE",
    "name": "Laucha",
    "lat": "51.22422",
    "lng": "11.67988"
  },
  {
    "country": "DE",
    "name": "Lauben",
    "lat": "48.05928",
    "lng": "10.29014"
  },
  {
    "country": "DE",
    "name": "Lauben",
    "lat": "47.78333",
    "lng": "10.3"
  },
  {
    "country": "DE",
    "name": "Laubach",
    "lat": "50.54196",
    "lng": "8.99034"
  },
  {
    "country": "DE",
    "name": "Laubach",
    "lat": "50.23277",
    "lng": "7.07333"
  },
  {
    "country": "DE",
    "name": "Lathen",
    "lat": "52.86667",
    "lng": "7.31667"
  },
  {
    "country": "DE",
    "name": "Lastrup",
    "lat": "52.79468",
    "lng": "7.86715"
  },
  {
    "country": "DE",
    "name": "Lassan",
    "lat": "53.94874",
    "lng": "13.85219"
  },
  {
    "country": "DE",
    "name": "Lasbek",
    "lat": "53.73333",
    "lng": "10.36667"
  },
  {
    "country": "DE",
    "name": "Lappersdorf",
    "lat": "49.04694",
    "lng": "12.0913"
  },
  {
    "country": "DE",
    "name": "Lanstrop",
    "lat": "51.57504",
    "lng": "7.56752"
  },
  {
    "country": "DE",
    "name": "Lankwitz",
    "lat": "52.43623",
    "lng": "13.3459"
  },
  {
    "country": "DE",
    "name": "Lankow",
    "lat": "53.64983",
    "lng": "11.36913"
  },
  {
    "country": "DE",
    "name": "Langweid",
    "lat": "48.49095",
    "lng": "10.8531"
  },
  {
    "country": "DE",
    "name": "Langwedel",
    "lat": "54.21033",
    "lng": "9.92761"
  },
  {
    "country": "DE",
    "name": "Langwedel",
    "lat": "52.97864",
    "lng": "9.18542"
  },
  {
    "country": "DE",
    "name": "Langula",
    "lat": "51.15001",
    "lng": "10.4167"
  },
  {
    "country": "DE",
    "name": "Langsur",
    "lat": "49.72442",
    "lng": "6.49906"
  },
  {
    "country": "DE",
    "name": "Langstedt",
    "lat": "54.61667",
    "lng": "9.38333"
  },
  {
    "country": "DE",
    "name": "Langquaid",
    "lat": "48.82318",
    "lng": "12.05134"
  },
  {
    "country": "DE",
    "name": "Langlingen",
    "lat": "52.55593",
    "lng": "10.28291"
  },
  {
    "country": "DE",
    "name": "Langgöns",
    "lat": "50.5",
    "lng": "8.66667"
  },
  {
    "country": "DE",
    "name": "Langewiesen",
    "lat": "50.67252",
    "lng": "10.97102"
  },
  {
    "country": "DE",
    "name": "Langerwehe",
    "lat": "50.81667",
    "lng": "6.35"
  },
  {
    "country": "DE",
    "name": "Langerringen",
    "lat": "48.1459",
    "lng": "10.75894"
  },
  {
    "country": "DE",
    "name": "Langeoog",
    "lat": "53.75",
    "lng": "7.48333"
  },
  {
    "country": "DE",
    "name": "Langenzenn",
    "lat": "49.49463",
    "lng": "10.7923"
  },
  {
    "country": "DE",
    "name": "Langenwetzendorf",
    "lat": "50.67884",
    "lng": "12.09407"
  },
  {
    "country": "DE",
    "name": "Langenstein",
    "lat": "51.85551",
    "lng": "10.98822"
  },
  {
    "country": "DE",
    "name": "Langensendelbach",
    "lat": "49.64051",
    "lng": "11.07104"
  },
  {
    "country": "DE",
    "name": "Langenselbold",
    "lat": "50.17657",
    "lng": "9.04003"
  },
  {
    "country": "DE",
    "name": "Langenpreising",
    "lat": "48.42569",
    "lng": "11.97217"
  },
  {
    "country": "DE",
    "name": "Langenorla",
    "lat": "50.74067",
    "lng": "11.58023"
  },
  {
    "country": "DE",
    "name": "Langenneufnach",
    "lat": "48.26667",
    "lng": "10.6"
  },
  {
    "country": "DE",
    "name": "Langenmosen",
    "lat": "48.60658",
    "lng": "11.21378"
  },
  {
    "country": "DE",
    "name": "Langenlonsheim",
    "lat": "49.9",
    "lng": "7.9"
  },
  {
    "country": "DE",
    "name": "Langenhorn",
    "lat": "54.66667",
    "lng": "8.91667"
  },
  {
    "country": "DE",
    "name": "Langenhahn",
    "lat": "50.58333",
    "lng": "7.91667"
  },
  {
    "country": "DE",
    "name": "Langenhagen",
    "lat": "52.44758",
    "lng": "9.73741"
  },
  {
    "country": "DE",
    "name": "Langenfeld",
    "lat": "51.10821",
    "lng": "6.94831"
  },
  {
    "country": "DE",
    "name": "Langenfeld",
    "lat": "49.61667",
    "lng": "10.51667"
  },
  {
    "country": "DE",
    "name": "Langenenslingen",
    "lat": "48.14851",
    "lng": "9.37765"
  },
  {
    "country": "DE",
    "name": "Langeneichstädt",
    "lat": "51.34537",
    "lng": "11.7433"
  },
  {
    "country": "DE",
    "name": "Langendorf",
    "lat": "51.17972",
    "lng": "11.9614"
  },
  {
    "country": "DE",
    "name": "Langenburg",
    "lat": "49.25401",
    "lng": "9.85673"
  },
  {
    "country": "DE",
    "name": "Langenbogen",
    "lat": "51.483",
    "lng": "11.77786"
  },
  {
    "country": "DE",
    "name": "Langenbernsdorf",
    "lat": "50.75583",
    "lng": "12.32669"
  },
  {
    "country": "DE",
    "name": "Langenberg",
    "lat": "51.77206",
    "lng": "8.31809"
  },
  {
    "country": "DE",
    "name": "Langenbach bei Marienberg",
    "lat": "50.63806",
    "lng": "7.94787"
  },
  {
    "country": "DE",
    "name": "Langenbach",
    "lat": "48.43333",
    "lng": "11.85"
  },
  {
    "country": "DE",
    "name": "Langenau",
    "lat": "48.49616",
    "lng": "10.11849"
  },
  {
    "country": "DE",
    "name": "Langenargen",
    "lat": "47.59858",
    "lng": "9.54163"
  },
  {
    "country": "DE",
    "name": "Langenaltheim",
    "lat": "48.89318",
    "lng": "10.93107"
  },
  {
    "country": "DE",
    "name": "Langen",
    "lat": "53.60554",
    "lng": "8.59509"
  },
  {
    "country": "DE",
    "name": "Langen",
    "lat": "52.53985",
    "lng": "7.4674"
  },
  {
    "country": "DE",
    "name": "Langen",
    "lat": "49.98955",
    "lng": "8.66852"
  },
  {
    "country": "DE",
    "name": "Langelsheim",
    "lat": "51.93789",
    "lng": "10.33264"
  },
  {
    "country": "DE",
    "name": "Langeln",
    "lat": "51.91188",
    "lng": "10.79436"
  },
  {
    "country": "DE",
    "name": "Langballig",
    "lat": "54.8",
    "lng": "9.63333"
  },
  {
    "country": "DE",
    "name": "Landstuhl",
    "lat": "49.41306",
    "lng": "7.57021"
  },
  {
    "country": "DE",
    "name": "Landshut",
    "lat": "48.52961",
    "lng": "12.16179"
  },
  {
    "country": "DE",
    "name": "Landscheid",
    "lat": "49.98333",
    "lng": "6.76667"
  },
  {
    "country": "DE",
    "name": "Landsberied",
    "lat": "48.16667",
    "lng": "11.16667"
  },
  {
    "country": "DE",
    "name": "Landsberg",
    "lat": "51.52698",
    "lng": "12.16076"
  },
  {
    "country": "DE",
    "name": "Landsberg am Lech",
    "lat": "48.04819",
    "lng": "10.88282"
  },
  {
    "country": "DE",
    "name": "Landolfshausen",
    "lat": "51.53333",
    "lng": "10.1"
  },
  {
    "country": "DE",
    "name": "Landesbergen",
    "lat": "52.55598",
    "lng": "9.12505"
  },
  {
    "country": "DE",
    "name": "Landau in der Pfalz",
    "lat": "49.19844",
    "lng": "8.11692"
  },
  {
    "country": "DE",
    "name": "Landau an der Isar",
    "lat": "48.67249",
    "lng": "12.69316"
  },
  {
    "country": "DE",
    "name": "Lamstedt",
    "lat": "53.63333",
    "lng": "9.1"
  },
  {
    "country": "DE",
    "name": "Lamspringe",
    "lat": "51.96071",
    "lng": "10.01105"
  },
  {
    "country": "DE",
    "name": "Lampertswalde",
    "lat": "51.31108",
    "lng": "13.67694"
  },
  {
    "country": "DE",
    "name": "Lampertheim",
    "lat": "49.59786",
    "lng": "8.4725"
  },
  {
    "country": "DE",
    "name": "Lamerdingen",
    "lat": "48.09195",
    "lng": "10.73982"
  },
  {
    "country": "DE",
    "name": "Lambsheim",
    "lat": "49.51361",
    "lng": "8.28778"
  },
  {
    "country": "DE",
    "name": "Lambrechtshagen",
    "lat": "54.10208",
    "lng": "12.01645"
  },
  {
    "country": "DE",
    "name": "Lambrecht",
    "lat": "49.37055",
    "lng": "8.07264"
  },
  {
    "country": "DE",
    "name": "Lam",
    "lat": "49.19665",
    "lng": "13.05051"
  },
  {
    "country": "DE",
    "name": "Lalling",
    "lat": "48.84525",
    "lng": "13.14008"
  },
  {
    "country": "DE",
    "name": "Lalendorf",
    "lat": "53.75774",
    "lng": "12.38983"
  },
  {
    "country": "DE",
    "name": "Laichingen",
    "lat": "48.48939",
    "lng": "9.68612"
  },
  {
    "country": "DE",
    "name": "Lahr",
    "lat": "48.34042",
    "lng": "7.86886"
  },
  {
    "country": "DE",
    "name": "Lahnstein",
    "lat": "50.3",
    "lng": "7.61667"
  },
  {
    "country": "DE",
    "name": "Lähden",
    "lat": "52.74547",
    "lng": "7.57036"
  },
  {
    "country": "DE",
    "name": "Lägerdorf",
    "lat": "53.88333",
    "lng": "9.58333"
  },
  {
    "country": "DE",
    "name": "Lage",
    "lat": "52.46667",
    "lng": "6.96667"
  },
  {
    "country": "DE",
    "name": "Lage",
    "lat": "51.99223",
    "lng": "8.79301"
  },
  {
    "country": "DE",
    "name": "Bad Laer",
    "lat": "52.1",
    "lng": "8.08333"
  },
  {
    "country": "DE",
    "name": "Laer",
    "lat": "52.05555",
    "lng": "7.35775"
  },
  {
    "country": "DE",
    "name": "Ladenburg",
    "lat": "49.47307",
    "lng": "8.60896"
  },
  {
    "country": "DE",
    "name": "Ladelund",
    "lat": "54.84084",
    "lng": "9.02135"
  },
  {
    "country": "DE",
    "name": "Ladbergen",
    "lat": "52.13333",
    "lng": "7.75"
  },
  {
    "country": "DE",
    "name": "Lachendorf",
    "lat": "52.61667",
    "lng": "10.25"
  },
  {
    "country": "DE",
    "name": "Lachen",
    "lat": "47.9459",
    "lng": "10.23943"
  },
  {
    "country": "DE",
    "name": "Laboe",
    "lat": "54.4",
    "lng": "10.21667"
  },
  {
    "country": "DE",
    "name": "Laberweinting",
    "lat": "48.8",
    "lng": "12.31667"
  },
  {
    "country": "DE",
    "name": "Laatzen",
    "lat": "52.31506",
    "lng": "9.79739"
  },
  {
    "country": "DE",
    "name": "Bad Laasphe",
    "lat": "50.93139",
    "lng": "8.42502"
  },
  {
    "country": "DE",
    "name": "Laar",
    "lat": "52.35581",
    "lng": "8.25388"
  },
  {
    "country": "DE",
    "name": "Laage",
    "lat": "53.9256",
    "lng": "12.34694"
  },
  {
    "country": "DE",
    "name": "Kyritz",
    "lat": "52.94212",
    "lng": "12.39704"
  },
  {
    "country": "DE",
    "name": "Kyllburg",
    "lat": "50.03864",
    "lng": "6.59478"
  },
  {
    "country": "DE",
    "name": "Kutzenhausen",
    "lat": "48.34202",
    "lng": "10.69459"
  },
  {
    "country": "DE",
    "name": "Kutenholz",
    "lat": "53.48152",
    "lng": "9.32118"
  },
  {
    "country": "DE",
    "name": "Kusterdingen",
    "lat": "48.52291",
    "lng": "9.11977"
  },
  {
    "country": "DE",
    "name": "Küsten",
    "lat": "52.97779",
    "lng": "11.0624"
  },
  {
    "country": "DE",
    "name": "Kusey",
    "lat": "52.57987",
    "lng": "11.09056"
  },
  {
    "country": "DE",
    "name": "Kusel",
    "lat": "49.53772",
    "lng": "7.40472"
  },
  {
    "country": "DE",
    "name": "Kürten",
    "lat": "51.05",
    "lng": "7.26667"
  },
  {
    "country": "DE",
    "name": "Seiffen",
    "lat": "50.65",
    "lng": "13.45"
  },
  {
    "country": "DE",
    "name": "Kurort Oybin",
    "lat": "50.84105",
    "lng": "14.74124"
  },
  {
    "country": "DE",
    "name": "Kurort Oberwiesenthal",
    "lat": "50.41943",
    "lng": "12.96836"
  },
  {
    "country": "DE",
    "name": "Kurort Jonsdorf",
    "lat": "50.85751",
    "lng": "14.70922"
  },
  {
    "country": "DE",
    "name": "Kurort Gohrisch",
    "lat": "50.91234",
    "lng": "14.10687"
  },
  {
    "country": "DE",
    "name": "Kürnbach",
    "lat": "49.0775",
    "lng": "8.84556"
  },
  {
    "country": "DE",
    "name": "Kürnach",
    "lat": "49.85",
    "lng": "10.03333"
  },
  {
    "country": "DE",
    "name": "Kueps Oberfranken",
    "lat": "50.19265",
    "lng": "11.27599"
  },
  {
    "country": "DE",
    "name": "Kuppenheim",
    "lat": "48.82794",
    "lng": "8.25417"
  },
  {
    "country": "DE",
    "name": "Kupferzell",
    "lat": "49.22778",
    "lng": "9.69"
  },
  {
    "country": "DE",
    "name": "Kupferberg",
    "lat": "50.1396",
    "lng": "11.57762"
  },
  {
    "country": "DE",
    "name": "Künzing",
    "lat": "48.66667",
    "lng": "13.08333"
  },
  {
    "country": "DE",
    "name": "Künzelsau",
    "lat": "49.2818",
    "lng": "9.68352"
  },
  {
    "country": "DE",
    "name": "Künzell",
    "lat": "50.5442",
    "lng": "9.71792"
  },
  {
    "country": "DE",
    "name": "Kunreuth",
    "lat": "50.23321",
    "lng": "11.53119"
  },
  {
    "country": "DE",
    "name": "Kümmersbruck",
    "lat": "49.41917",
    "lng": "11.88833"
  },
  {
    "country": "DE",
    "name": "Kummerfeld",
    "lat": "53.69262",
    "lng": "9.79099"
  },
  {
    "country": "DE",
    "name": "Kumhausen",
    "lat": "48.50938",
    "lng": "12.15637"
  },
  {
    "country": "DE",
    "name": "Külsheim",
    "lat": "49.66942",
    "lng": "9.52361"
  },
  {
    "country": "DE",
    "name": "Kulmbach",
    "lat": "50.10068",
    "lng": "11.45032"
  },
  {
    "country": "DE",
    "name": "Kulmain",
    "lat": "49.9",
    "lng": "11.9"
  },
  {
    "country": "DE",
    "name": "Küllstedt",
    "lat": "51.27582",
    "lng": "10.2804"
  },
  {
    "country": "DE",
    "name": "Kührstedt",
    "lat": "53.57747",
    "lng": "8.80091"
  },
  {
    "country": "DE",
    "name": "Kühndorf",
    "lat": "50.60826",
    "lng": "10.49191"
  },
  {
    "country": "DE",
    "name": "Kühbach",
    "lat": "48.49101",
    "lng": "11.18691"
  },
  {
    "country": "DE",
    "name": "Kuhardt",
    "lat": "49.14583",
    "lng": "8.31444"
  },
  {
    "country": "DE",
    "name": "Kuddewörde",
    "lat": "53.58333",
    "lng": "10.4"
  },
  {
    "country": "DE",
    "name": "Kuchen",
    "lat": "48.63583",
    "lng": "9.79989"
  },
  {
    "country": "DE",
    "name": "Kubschütz",
    "lat": "51.16667",
    "lng": "14.5"
  },
  {
    "country": "DE",
    "name": "Krün",
    "lat": "47.50515",
    "lng": "11.27924"
  },
  {
    "country": "DE",
    "name": "Krumpa",
    "lat": "51.29724",
    "lng": "11.84412"
  },
  {
    "country": "DE",
    "name": "Krummesse",
    "lat": "53.78333",
    "lng": "10.65"
  },
  {
    "country": "DE",
    "name": "Krummennaab",
    "lat": "49.83333",
    "lng": "12.1"
  },
  {
    "country": "DE",
    "name": "Krumbach",
    "lat": "48.24182",
    "lng": "10.3632"
  },
  {
    "country": "DE",
    "name": "Kruft",
    "lat": "50.38333",
    "lng": "7.33333"
  },
  {
    "country": "DE",
    "name": "Kröv",
    "lat": "49.98333",
    "lng": "7.08333"
  },
  {
    "country": "DE",
    "name": "Krostitz",
    "lat": "51.46208",
    "lng": "12.4536"
  },
  {
    "country": "DE",
    "name": "Kröslin",
    "lat": "54.11662",
    "lng": "13.75067"
  },
  {
    "country": "DE",
    "name": "Kropstädt",
    "lat": "51.96307",
    "lng": "12.7455"
  },
  {
    "country": "DE",
    "name": "Kroppenstedt",
    "lat": "51.94211",
    "lng": "11.30841"
  },
  {
    "country": "DE",
    "name": "Kröppelshagen-Fahrendorf",
    "lat": "53.48979",
    "lng": "10.31697"
  },
  {
    "country": "DE",
    "name": "Kropp",
    "lat": "54.41667",
    "lng": "9.51667"
  },
  {
    "country": "DE",
    "name": "Kröpelin",
    "lat": "54.06963",
    "lng": "11.79473"
  },
  {
    "country": "DE",
    "name": "Kronshagen",
    "lat": "54.33333",
    "lng": "10.08333"
  },
  {
    "country": "DE",
    "name": "Kronburg",
    "lat": "47.90432",
    "lng": "10.1572"
  },
  {
    "country": "DE",
    "name": "Kronberg",
    "lat": "50.18424",
    "lng": "8.5232"
  },
  {
    "country": "DE",
    "name": "Kronau",
    "lat": "49.2225",
    "lng": "8.63111"
  },
  {
    "country": "DE",
    "name": "Kronach",
    "lat": "50.23963",
    "lng": "11.33308"
  },
  {
    "country": "DE",
    "name": "Krombach",
    "lat": "50.08319",
    "lng": "9.20609"
  },
  {
    "country": "DE",
    "name": "Krölpa",
    "lat": "50.67743",
    "lng": "11.53848"
  },
  {
    "country": "DE",
    "name": "Kritzmow",
    "lat": "54.05237",
    "lng": "12.05311"
  },
  {
    "country": "DE",
    "name": "Kriftel",
    "lat": "50.08408",
    "lng": "8.46977"
  },
  {
    "country": "DE",
    "name": "Kriegsfeld",
    "lat": "49.70992",
    "lng": "7.91687"
  },
  {
    "country": "DE",
    "name": "Kriebstein",
    "lat": "51.05",
    "lng": "13.01667"
  },
  {
    "country": "DE",
    "name": "Kriebitzsch",
    "lat": "51.02347",
    "lng": "12.33318"
  },
  {
    "country": "DE",
    "name": "Krickenbach",
    "lat": "49.36667",
    "lng": "7.66667"
  },
  {
    "country": "DE",
    "name": "Kreuzwertheim",
    "lat": "49.76818",
    "lng": "9.51819"
  },
  {
    "country": "DE",
    "name": "Kreuztal",
    "lat": "50.96775",
    "lng": "7.98848"
  },
  {
    "country": "DE",
    "name": "Kreuzberg",
    "lat": "52.49973",
    "lng": "13.40338"
  },
  {
    "country": "DE",
    "name": "Kreuzau",
    "lat": "50.74699",
    "lng": "6.49069"
  },
  {
    "country": "DE",
    "name": "Kreut",
    "lat": "47.79868",
    "lng": "11.48312"
  },
  {
    "country": "DE",
    "name": "Kretzschau",
    "lat": "51.05",
    "lng": "12.06667"
  },
  {
    "country": "DE",
    "name": "Kressbronn am Bodensee",
    "lat": "47.5976",
    "lng": "9.59707"
  },
  {
    "country": "DE",
    "name": "Kremperheide",
    "lat": "53.88721",
    "lng": "9.47809"
  },
  {
    "country": "DE",
    "name": "Krempe",
    "lat": "53.83694",
    "lng": "9.48831"
  },
  {
    "country": "DE",
    "name": "Kremmen",
    "lat": "52.76216",
    "lng": "13.02515"
  },
  {
    "country": "DE",
    "name": "Kreischa",
    "lat": "50.94534",
    "lng": "13.75514"
  },
  {
    "country": "DE",
    "name": "Kreiensen",
    "lat": "51.85363",
    "lng": "9.96481"
  },
  {
    "country": "DE",
    "name": "Krefeld",
    "lat": "51.33645",
    "lng": "6.55381"
  },
  {
    "country": "DE",
    "name": "Krebeck",
    "lat": "51.58333",
    "lng": "10.11667"
  },
  {
    "country": "DE",
    "name": "Krautheim",
    "lat": "49.38789",
    "lng": "9.63553"
  },
  {
    "country": "DE",
    "name": "Krauthausen",
    "lat": "51.01667",
    "lng": "10.26667"
  },
  {
    "country": "DE",
    "name": "Krauschwitz",
    "lat": "51.52153",
    "lng": "14.71211"
  },
  {
    "country": "DE",
    "name": "Krauchenwies",
    "lat": "48.01651",
    "lng": "9.24757"
  },
  {
    "country": "DE",
    "name": "Kranichfeld",
    "lat": "50.85446",
    "lng": "11.20057"
  },
  {
    "country": "DE",
    "name": "Kranenburg",
    "lat": "51.78333",
    "lng": "6.01667"
  },
  {
    "country": "DE",
    "name": "Kramerhof",
    "lat": "54.35366",
    "lng": "13.05412"
  },
  {
    "country": "DE",
    "name": "Krakow am See",
    "lat": "53.65163",
    "lng": "12.27034"
  },
  {
    "country": "DE",
    "name": "Krailling",
    "lat": "48.1",
    "lng": "11.4"
  },
  {
    "country": "DE",
    "name": "Kraiburg am Inn",
    "lat": "48.18191",
    "lng": "12.43073"
  },
  {
    "country": "DE",
    "name": "Kraftsdorf",
    "lat": "50.87574",
    "lng": "11.92944"
  },
  {
    "country": "DE",
    "name": "Kötzting",
    "lat": "49.17649",
    "lng": "12.85515"
  },
  {
    "country": "DE",
    "name": "Kötzschau",
    "lat": "51.31244",
    "lng": "12.13044"
  },
  {
    "country": "DE",
    "name": "Kottweiler-Schwanden",
    "lat": "49.48333",
    "lng": "7.53333"
  },
  {
    "country": "DE",
    "name": "Kottenheim",
    "lat": "50.35",
    "lng": "7.25"
  },
  {
    "country": "DE",
    "name": "Köthen",
    "lat": "51.75185",
    "lng": "11.97093"
  },
  {
    "country": "DE",
    "name": "Chostlarn",
    "lat": "48.37144",
    "lng": "13.12064"
  },
  {
    "country": "DE",
    "name": "Kossa",
    "lat": "51.61707",
    "lng": "12.68197"
  },
  {
    "country": "DE",
    "name": "Koserow",
    "lat": "54.05189",
    "lng": "14.00197"
  },
  {
    "country": "DE",
    "name": "Kosel",
    "lat": "54.5058",
    "lng": "9.75653"
  },
  {
    "country": "DE",
    "name": "Korschenbroich",
    "lat": "51.19139",
    "lng": "6.51352"
  },
  {
    "country": "DE",
    "name": "Körperich",
    "lat": "49.92449",
    "lng": "6.25973"
  },
  {
    "country": "DE",
    "name": "Kornwestheim",
    "lat": "48.86158",
    "lng": "9.18569"
  },
  {
    "country": "DE",
    "name": "Korntal",
    "lat": "48.83218",
    "lng": "9.1214"
  },
  {
    "country": "DE",
    "name": "Körner",
    "lat": "51.23333",
    "lng": "10.6"
  },
  {
    "country": "DE",
    "name": "Körle",
    "lat": "51.16667",
    "lng": "9.51667"
  },
  {
    "country": "DE",
    "name": "Kordel",
    "lat": "49.83333",
    "lng": "6.63333"
  },
  {
    "country": "DE",
    "name": "Korbach",
    "lat": "51.27561",
    "lng": "8.873"
  },
  {
    "country": "DE",
    "name": "Korb",
    "lat": "48.84303",
    "lng": "9.36258"
  },
  {
    "country": "DE",
    "name": "Köpenick",
    "lat": "52.4455",
    "lng": "13.57455"
  },
  {
    "country": "DE",
    "name": "Berlin Köpenick",
    "lat": "52.44254",
    "lng": "13.58228"
  },
  {
    "country": "DE",
    "name": "Konzell",
    "lat": "49.0724",
    "lng": "12.71114"
  },
  {
    "country": "DE",
    "name": "Konz",
    "lat": "49.70045",
    "lng": "6.57652"
  },
  {
    "country": "DE",
    "name": "Konstanz",
    "lat": "47.66033",
    "lng": "9.17582"
  },
  {
    "country": "DE",
    "name": "Konradsreuth",
    "lat": "50.26667",
    "lng": "11.85"
  },
  {
    "country": "DE",
    "name": "Konradshöhe",
    "lat": "52.58535",
    "lng": "13.22758"
  },
  {
    "country": "DE",
    "name": "Konradsreuth",
    "lat": "49.74179",
    "lng": "12.29628"
  },
  {
    "country": "DE",
    "name": "Könnern",
    "lat": "51.6712",
    "lng": "11.77068"
  },
  {
    "country": "DE",
    "name": "Könitz",
    "lat": "50.64979",
    "lng": "11.48809"
  },
  {
    "country": "DE",
    "name": "Königs Wusterhausen",
    "lat": "52.30141",
    "lng": "13.633"
  },
  {
    "country": "DE",
    "name": "Königswinter",
    "lat": "50.68376",
    "lng": "7.18675"
  },
  {
    "country": "DE",
    "name": "Königswartha",
    "lat": "51.31028",
    "lng": "14.32797"
  },
  {
    "country": "DE",
    "name": "Königswalde",
    "lat": "50.55",
    "lng": "13.05"
  },
  {
    "country": "DE",
    "name": "Königstein im Taunus",
    "lat": "50.17943",
    "lng": "8.47132"
  },
  {
    "country": "DE",
    "name": "Königstein",
    "lat": "50.9157",
    "lng": "14.07186"
  },
  {
    "country": "DE",
    "name": "Königstein",
    "lat": "49.60854",
    "lng": "11.63143"
  },
  {
    "country": "DE",
    "name": "Königslutter am Elm",
    "lat": "52.25116",
    "lng": "10.81683"
  },
  {
    "country": "DE",
    "name": "Bad Königshofen im Grabfeld",
    "lat": "50.30082",
    "lng": "10.46887"
  },
  {
    "country": "DE",
    "name": "Königshain",
    "lat": "51.18333",
    "lng": "14.86667"
  },
  {
    "country": "DE",
    "name": "Königsfeld",
    "lat": "51.06667",
    "lng": "12.75"
  },
  {
    "country": "DE",
    "name": "Königsfeld",
    "lat": "49.94603",
    "lng": "11.1652"
  },
  {
    "country": "DE",
    "name": "Königsfeld im Schwarzwald",
    "lat": "48.13814",
    "lng": "8.41973"
  },
  {
    "country": "DE",
    "name": "Königsee",
    "lat": "50.66143",
    "lng": "11.09748"
  },
  {
    "country": "DE",
    "name": "Königsdorf",
    "lat": "47.81546",
    "lng": "11.48063"
  },
  {
    "country": "DE",
    "name": "Königsbrunn",
    "lat": "48.27506",
    "lng": "10.89178"
  },
  {
    "country": "DE",
    "name": "Königsbrück",
    "lat": "51.26451",
    "lng": "13.9054"
  },
  {
    "country": "DE",
    "name": "Königsbronn",
    "lat": "48.74317",
    "lng": "10.11193"
  },
  {
    "country": "DE",
    "name": "Königheim",
    "lat": "49.62028",
    "lng": "9.59583"
  },
  {
    "country": "DE",
    "name": "Köngernheim",
    "lat": "49.84583",
    "lng": "8.24667"
  },
  {
    "country": "DE",
    "name": "Köngen",
    "lat": "48.68333",
    "lng": "9.36667"
  },
  {
    "country": "DE",
    "name": "Köln",
    "lat": "50.93333",
    "lng": "6.95"
  },
  {
    "country": "DE",
    "name": "Kölln-Reisiek",
    "lat": "53.75748",
    "lng": "9.69772"
  },
  {
    "country": "DE",
    "name": "Kollnburg",
    "lat": "49.04664",
    "lng": "12.86121"
  },
  {
    "country": "DE",
    "name": "Kollmar",
    "lat": "53.72936",
    "lng": "9.4788"
  },
  {
    "country": "DE",
    "name": "Kölleda",
    "lat": "51.18745",
    "lng": "11.24488"
  },
  {
    "country": "DE",
    "name": "Kolkwitz",
    "lat": "51.75",
    "lng": "14.25"
  },
  {
    "country": "DE",
    "name": "Kolitzheim",
    "lat": "49.91667",
    "lng": "10.23333"
  },
  {
    "country": "DE",
    "name": "Kölbingen",
    "lat": "50.55",
    "lng": "7.93333"
  },
  {
    "country": "DE",
    "name": "Kolbingen",
    "lat": "48.05227",
    "lng": "8.88957"
  },
  {
    "country": "DE",
    "name": "Kolbermoor",
    "lat": "47.84965",
    "lng": "12.06696"
  },
  {
    "country": "DE",
    "name": "Kohlberg",
    "lat": "49.59121",
    "lng": "12.01948"
  },
  {
    "country": "DE",
    "name": "Kohlberg",
    "lat": "48.55845",
    "lng": "9.33576"
  },
  {
    "country": "DE",
    "name": "Köfering",
    "lat": "48.93333",
    "lng": "12.2"
  },
  {
    "country": "DE",
    "name": "Ködnitz",
    "lat": "50.1",
    "lng": "11.53333"
  },
  {
    "country": "DE",
    "name": "Köditz",
    "lat": "50.33333",
    "lng": "11.85"
  },
  {
    "country": "DE",
    "name": "Kodersdorf",
    "lat": "51.24272",
    "lng": "14.89336"
  },
  {
    "country": "DE",
    "name": "Kochel",
    "lat": "47.65926",
    "lng": "11.36827"
  },
  {
    "country": "DE",
    "name": "Koblenz",
    "lat": "50.35357",
    "lng": "7.57883"
  },
  {
    "country": "DE",
    "name": "Knittlingen",
    "lat": "49.02487",
    "lng": "8.75606"
  },
  {
    "country": "DE",
    "name": "Knittelsheim",
    "lat": "49.19167",
    "lng": "8.25139"
  },
  {
    "country": "DE",
    "name": "Knetzgau",
    "lat": "49.98333",
    "lng": "10.55"
  },
  {
    "country": "DE",
    "name": "Klütz",
    "lat": "53.9647",
    "lng": "11.16367"
  },
  {
    "country": "DE",
    "name": "Klüsserath",
    "lat": "49.845",
    "lng": "6.85086"
  },
  {
    "country": "DE",
    "name": "Kluse",
    "lat": "52.93633",
    "lng": "7.34093"
  },
  {
    "country": "DE",
    "name": "Klötze",
    "lat": "52.62725",
    "lng": "11.16424"
  },
  {
    "country": "DE",
    "name": "Klotten",
    "lat": "50.16667",
    "lng": "7.2"
  },
  {
    "country": "DE",
    "name": "Klostermansfeld",
    "lat": "51.58333",
    "lng": "11.5"
  },
  {
    "country": "DE",
    "name": "Klosterlechfeld",
    "lat": "48.15586",
    "lng": "10.82986"
  },
  {
    "country": "DE",
    "name": "Klitten",
    "lat": "51.35109",
    "lng": "14.60526"
  },
  {
    "country": "DE",
    "name": "Klipphausen",
    "lat": "51.06841",
    "lng": "13.51374"
  },
  {
    "country": "DE",
    "name": "Klink",
    "lat": "53.47758",
    "lng": "12.62131"
  },
  {
    "country": "DE",
    "name": "Klingenthal",
    "lat": "50.35963",
    "lng": "12.46463"
  },
  {
    "country": "DE",
    "name": "Klingenstein",
    "lat": "48.41849",
    "lng": "9.90812"
  },
  {
    "country": "DE",
    "name": "Klingenmünster",
    "lat": "49.14056",
    "lng": "8.01861"
  },
  {
    "country": "DE",
    "name": "Klingenberg am Main",
    "lat": "49.78507",
    "lng": "9.18025"
  },
  {
    "country": "DE",
    "name": "Klietz",
    "lat": "52.66835",
    "lng": "12.06812"
  },
  {
    "country": "DE",
    "name": "Klieken",
    "lat": "51.88806",
    "lng": "12.3707"
  },
  {
    "country": "DE",
    "name": "Kleve",
    "lat": "51.78826",
    "lng": "6.13865"
  },
  {
    "country": "DE",
    "name": "Klettbach",
    "lat": "50.91667",
    "lng": "11.15"
  },
  {
    "country": "DE",
    "name": "Klein-Winternheim",
    "lat": "49.93833",
    "lng": "8.21194"
  },
  {
    "country": "DE",
    "name": "Kleinwenden",
    "lat": "51.41611",
    "lng": "10.65902"
  },
  {
    "country": "DE",
    "name": "Klein Wanzleben",
    "lat": "52.07005",
    "lng": "11.36594"
  },
  {
    "country": "DE",
    "name": "Kleinwallstadt",
    "lat": "49.87464",
    "lng": "9.16927"
  },
  {
    "country": "DE",
    "name": "Kleinsendelbach",
    "lat": "49.59558",
    "lng": "11.15773"
  },
  {
    "country": "DE",
    "name": "Klein Schwülper",
    "lat": "52.34153",
    "lng": "10.42903"
  },
  {
    "country": "DE",
    "name": "Klein Rönnau",
    "lat": "53.96667",
    "lng": "10.31667"
  },
  {
    "country": "DE",
    "name": "Klein Rogahn",
    "lat": "53.60534",
    "lng": "11.34579"
  },
  {
    "country": "DE",
    "name": "Kleinrinderfeld",
    "lat": "49.70028",
    "lng": "9.84472"
  },
  {
    "country": "DE",
    "name": "Klein Reken",
    "lat": "51.7871",
    "lng": "7.04367"
  },
  {
    "country": "DE",
    "name": "Kleinostheim",
    "lat": "50",
    "lng": "9.06667"
  },
  {
    "country": "DE",
    "name": "Klein Nordende",
    "lat": "53.72219",
    "lng": "9.65424"
  },
  {
    "country": "DE",
    "name": "Kleinmaischeid",
    "lat": "50.51345",
    "lng": "7.6083"
  },
  {
    "country": "DE",
    "name": "Kleinmachnow",
    "lat": "52.40786",
    "lng": "13.22514"
  },
  {
    "country": "DE",
    "name": "Kleinlangheim",
    "lat": "49.77087",
    "lng": "10.2843"
  },
  {
    "country": "DE",
    "name": "Kleinkahl",
    "lat": "50.11667",
    "lng": "9.26667"
  },
  {
    "country": "DE",
    "name": "Kleinheubach",
    "lat": "49.72109",
    "lng": "9.21346"
  },
  {
    "country": "DE",
    "name": "Klein Gusborn",
    "lat": "53.08331",
    "lng": "11.19323"
  },
  {
    "country": "DE",
    "name": "Kleinfurra",
    "lat": "51.41556",
    "lng": "10.76454"
  },
  {
    "country": "DE",
    "name": "Kleinblittersdorf",
    "lat": "49.1578",
    "lng": "7.03734"
  },
  {
    "country": "DE",
    "name": "Klein Berßen",
    "lat": "52.76797",
    "lng": "7.46182"
  },
  {
    "country": "DE",
    "name": "Kleinaitingen",
    "lat": "48.2185",
    "lng": "10.86923"
  },
  {
    "country": "DE",
    "name": "Klausen",
    "lat": "49.9",
    "lng": "6.88333"
  },
  {
    "country": "DE",
    "name": "Klausdorf",
    "lat": "54.30899",
    "lng": "10.21372"
  },
  {
    "country": "DE",
    "name": "Kladow",
    "lat": "52.45423",
    "lng": "13.14445"
  },
  {
    "country": "DE",
    "name": "Kitzscher",
    "lat": "51.16444",
    "lng": "12.5526"
  },
  {
    "country": "DE",
    "name": "Kitzingen",
    "lat": "49.73973",
    "lng": "10.15072"
  },
  {
    "country": "DE",
    "name": "Kitzen",
    "lat": "51.22172",
    "lng": "12.22349"
  },
  {
    "country": "DE",
    "name": "Kist",
    "lat": "49.74278",
    "lng": "9.84389"
  },
  {
    "country": "DE",
    "name": "Kißlegg",
    "lat": "47.78894",
    "lng": "9.88383"
  },
  {
    "country": "DE",
    "name": "Kissing",
    "lat": "48.30375",
    "lng": "10.97088"
  },
  {
    "country": "DE",
    "name": "Kissenbrück",
    "lat": "52.10956",
    "lng": "10.58996"
  },
  {
    "country": "DE",
    "name": "Kisdorf",
    "lat": "53.81667",
    "lng": "10.01667"
  },
  {
    "country": "DE",
    "name": "Kirtorf",
    "lat": "50.76942",
    "lng": "9.10389"
  },
  {
    "country": "DE",
    "name": "Kirschweiler",
    "lat": "49.75",
    "lng": "7.25"
  },
  {
    "country": "DE",
    "name": "Kirschau",
    "lat": "51.09317",
    "lng": "14.4284"
  },
  {
    "country": "DE",
    "name": "Kirrweiler",
    "lat": "49.30124",
    "lng": "8.16288"
  },
  {
    "country": "DE",
    "name": "Kirn",
    "lat": "49.78912",
    "lng": "7.45765"
  },
  {
    "country": "DE",
    "name": "Kirkel",
    "lat": "49.28333",
    "lng": "7.23333"
  },
  {
    "country": "DE",
    "name": "Kirchzell",
    "lat": "49.618",
    "lng": "9.17785"
  },
  {
    "country": "DE",
    "name": "Kirchzarten",
    "lat": "47.96667",
    "lng": "7.95"
  },
  {
    "country": "DE",
    "name": "Kirchworbis",
    "lat": "51.41122",
    "lng": "10.39625"
  },
  {
    "country": "DE",
    "name": "Kirchweidach",
    "lat": "48.08575",
    "lng": "12.6453"
  },
  {
    "country": "DE",
    "name": "Kirchwalsede",
    "lat": "53.01667",
    "lng": "9.4"
  },
  {
    "country": "DE",
    "name": "Kirchtimke",
    "lat": "53.25",
    "lng": "9.15"
  },
  {
    "country": "DE",
    "name": "Kirchseeon",
    "lat": "48.07143",
    "lng": "11.88875"
  },
  {
    "country": "DE",
    "name": "Kirchseelte",
    "lat": "52.95",
    "lng": "8.68333"
  },
  {
    "country": "DE",
    "name": "Kirchroth",
    "lat": "48.95",
    "lng": "12.55"
  },
  {
    "country": "DE",
    "name": "Kirchlinteln",
    "lat": "52.94236",
    "lng": "9.31811"
  },
  {
    "country": "DE",
    "name": "Kirchlengern",
    "lat": "52.2",
    "lng": "8.63333"
  },
  {
    "country": "DE",
    "name": "Kirchlauter",
    "lat": "50.0443",
    "lng": "10.71776"
  },
  {
    "country": "DE",
    "name": "Kirchhundem",
    "lat": "51.08556",
    "lng": "8.08893"
  },
  {
    "country": "DE",
    "name": "Kirchheim unter Teck",
    "lat": "48.64683",
    "lng": "9.45378"
  },
  {
    "country": "DE",
    "name": "Kirchheimbolanden",
    "lat": "49.66249",
    "lng": "8.01513"
  },
  {
    "country": "DE",
    "name": "Kirchheim bei München",
    "lat": "48.17656",
    "lng": "11.75563"
  },
  {
    "country": "DE",
    "name": "Kirchheim an der Weinstraße",
    "lat": "49.53722",
    "lng": "8.18083"
  },
  {
    "country": "DE",
    "name": "Kirchheim am Ries",
    "lat": "48.87922",
    "lng": "10.40028"
  },
  {
    "country": "DE",
    "name": "Kirchheim am Neckar",
    "lat": "49.045",
    "lng": "9.14222"
  },
  {
    "country": "DE",
    "name": "Kirchheim",
    "lat": "50.88333",
    "lng": "11.01667"
  },
  {
    "country": "DE",
    "name": "Kirchheim",
    "lat": "50.83333",
    "lng": "9.56667"
  },
  {
    "country": "DE",
    "name": "Kirchheim",
    "lat": "49.65607",
    "lng": "9.85783"
  },
  {
    "country": "DE",
    "name": "Kirchheim",
    "lat": "48.1749",
    "lng": "10.47461"
  },
  {
    "country": "DE",
    "name": "Kirchhaslach",
    "lat": "48.1504",
    "lng": "10.31015"
  },
  {
    "country": "DE",
    "name": "Kirchham",
    "lat": "48.34638",
    "lng": "13.26719"
  },
  {
    "country": "DE",
    "name": "Kirchhain",
    "lat": "50.8272",
    "lng": "8.92806"
  },
  {
    "country": "DE",
    "name": "Kirchgellersen",
    "lat": "53.23333",
    "lng": "10.3"
  },
  {
    "country": "DE",
    "name": "Kirchenthumbach",
    "lat": "49.74866",
    "lng": "11.72542"
  },
  {
    "country": "DE",
    "name": "Kirchentellinsfurt",
    "lat": "48.53315",
    "lng": "9.14732"
  },
  {
    "country": "DE",
    "name": "Kirchensittenbach",
    "lat": "49.55601",
    "lng": "11.42226"
  },
  {
    "country": "DE",
    "name": "Kirchenpingarten",
    "lat": "49.93333",
    "lng": "11.78333"
  },
  {
    "country": "DE",
    "name": "Kirchenlamitz",
    "lat": "50.1519",
    "lng": "11.94831"
  },
  {
    "country": "DE",
    "name": "Kirchen",
    "lat": "50.80849",
    "lng": "7.88634"
  },
  {
    "country": "DE",
    "name": "Eiselfing",
    "lat": "48.04114",
    "lng": "12.24272"
  },
  {
    "country": "DE",
    "name": "Kirchehrenbach",
    "lat": "49.73333",
    "lng": "11.15"
  },
  {
    "country": "DE",
    "name": "Kirchdorf im Wald",
    "lat": "48.91048",
    "lng": "13.26614"
  },
  {
    "country": "DE",
    "name": "Kirchdorf am Inn",
    "lat": "48.24755",
    "lng": "12.98453"
  },
  {
    "country": "DE",
    "name": "Kirchdorf",
    "lat": "52.59523",
    "lng": "8.8349"
  },
  {
    "country": "DE",
    "name": "Kirchdorf",
    "lat": "48.45942",
    "lng": "11.65438"
  },
  {
    "country": "DE",
    "name": "Kirchdorf",
    "lat": "48.17542",
    "lng": "12.19646"
  },
  {
    "country": "DE",
    "name": "Kirchdorf",
    "lat": "48.07667",
    "lng": "10.12629"
  },
  {
    "country": "DE",
    "name": "Kirchbrak",
    "lat": "51.96585",
    "lng": "9.5751"
  },
  {
    "country": "DE",
    "name": "Kirchberg an der Murr",
    "lat": "48.94297",
    "lng": "9.34083"
  },
  {
    "country": "DE",
    "name": "Kirchberg an der Jagst",
    "lat": "49.20056",
    "lng": "9.98226"
  },
  {
    "country": "DE",
    "name": "Kirchberg an der Iller",
    "lat": "48.13333",
    "lng": "10.08333"
  },
  {
    "country": "DE",
    "name": "Kirchberg",
    "lat": "50.76141",
    "lng": "12.76481"
  },
  {
    "country": "DE",
    "name": "Kirchberg",
    "lat": "50.6219",
    "lng": "12.52449"
  },
  {
    "country": "DE",
    "name": "Kirchberg",
    "lat": "49.94395",
    "lng": "7.407"
  },
  {
    "country": "DE",
    "name": "Kirchberg",
    "lat": "48.90006",
    "lng": "13.182"
  },
  {
    "country": "DE",
    "name": "Kirchardt",
    "lat": "49.205",
    "lng": "8.99167"
  },
  {
    "country": "DE",
    "name": "Kirchanschöring",
    "lat": "47.95303",
    "lng": "12.83435"
  },
  {
    "country": "DE",
    "name": "Kippenheim",
    "lat": "48.29564",
    "lng": "7.8251"
  },
  {
    "country": "DE",
    "name": "Kindsbach",
    "lat": "49.41667",
    "lng": "7.61667"
  },
  {
    "country": "DE",
    "name": "Kinderbeuern",
    "lat": "50.00935",
    "lng": "7.02355"
  },
  {
    "country": "DE",
    "name": "Kindenheim",
    "lat": "49.61111",
    "lng": "8.16417"
  },
  {
    "country": "DE",
    "name": "Kindelbrück",
    "lat": "51.26171",
    "lng": "11.08999"
  },
  {
    "country": "DE",
    "name": "Kieselbronn",
    "lat": "48.93333",
    "lng": "8.75"
  },
  {
    "country": "DE",
    "name": "Kierspe",
    "lat": "51.13403",
    "lng": "7.59075"
  },
  {
    "country": "DE",
    "name": "Kienberg",
    "lat": "48.03481",
    "lng": "12.4633"
  },
  {
    "country": "DE",
    "name": "Kiel",
    "lat": "54.32133",
    "lng": "10.13489"
  },
  {
    "country": "DE",
    "name": "Kiefersfelden",
    "lat": "47.61409",
    "lng": "12.19096"
  },
  {
    "country": "DE",
    "name": "Kiedrich",
    "lat": "50.03965",
    "lng": "8.08531"
  },
  {
    "country": "DE",
    "name": "Kiebitzreihe",
    "lat": "53.78333",
    "lng": "9.61667"
  },
  {
    "country": "DE",
    "name": "Kevelaer",
    "lat": "51.58243",
    "lng": "6.24603"
  },
  {
    "country": "DE",
    "name": "Ketzin",
    "lat": "52.47809",
    "lng": "12.8453"
  },
  {
    "country": "DE",
    "name": "Kettig",
    "lat": "50.4",
    "lng": "7.46667"
  },
  {
    "country": "DE",
    "name": "Kettershausen",
    "lat": "48.18333",
    "lng": "10.26667"
  },
  {
    "country": "DE",
    "name": "Kettenkamp",
    "lat": "52.58333",
    "lng": "7.83333"
  },
  {
    "country": "DE",
    "name": "Ketsch",
    "lat": "49.36778",
    "lng": "8.53111"
  },
  {
    "country": "DE",
    "name": "Kessin",
    "lat": "53.72928",
    "lng": "13.30773"
  },
  {
    "country": "DE",
    "name": "Kerzenheim",
    "lat": "49.57639",
    "lng": "8.05972"
  },
  {
    "country": "DE",
    "name": "Kerpen",
    "lat": "50.86991",
    "lng": "6.69691"
  },
  {
    "country": "DE",
    "name": "Kenzingen",
    "lat": "48.1963",
    "lng": "7.76974"
  },
  {
    "country": "DE",
    "name": "Kenn",
    "lat": "49.8",
    "lng": "6.71667"
  },
  {
    "country": "DE",
    "name": "Kempten (Allgäu)",
    "lat": "47.72674",
    "lng": "10.31389"
  },
  {
    "country": "DE",
    "name": "Kempenich",
    "lat": "50.42024",
    "lng": "7.11698"
  },
  {
    "country": "DE",
    "name": "Kempen",
    "lat": "51.36432",
    "lng": "6.41858"
  },
  {
    "country": "DE",
    "name": "Kemnitz",
    "lat": "54.07723",
    "lng": "13.53528"
  },
  {
    "country": "DE",
    "name": "Kemnath",
    "lat": "49.87007",
    "lng": "11.89077"
  },
  {
    "country": "DE",
    "name": "Kemmern",
    "lat": "49.95486",
    "lng": "10.87784"
  },
  {
    "country": "DE",
    "name": "Kemberg",
    "lat": "51.77189",
    "lng": "12.63227"
  },
  {
    "country": "DE",
    "name": "Kelsterbach",
    "lat": "50.06135",
    "lng": "8.52916"
  },
  {
    "country": "DE",
    "name": "Kellmünz",
    "lat": "48.12159",
    "lng": "10.12811"
  },
  {
    "country": "DE",
    "name": "Kellinghusen",
    "lat": "53.95202",
    "lng": "9.71959"
  },
  {
    "country": "DE",
    "name": "Kellenhusen",
    "lat": "54.19338",
    "lng": "11.06165"
  },
  {
    "country": "DE",
    "name": "Kell",
    "lat": "49.63425",
    "lng": "6.8239"
  },
  {
    "country": "DE",
    "name": "Kelkheim (Taunus)",
    "lat": "50.13703",
    "lng": "8.4502"
  },
  {
    "country": "DE",
    "name": "Kelheim",
    "lat": "48.91725",
    "lng": "11.88618"
  },
  {
    "country": "DE",
    "name": "Kelbra",
    "lat": "51.43528",
    "lng": "11.04143"
  },
  {
    "country": "DE",
    "name": "Kelberg",
    "lat": "50.29164",
    "lng": "6.9195"
  },
  {
    "country": "DE",
    "name": "Keitum",
    "lat": "54.89333",
    "lng": "8.37083"
  },
  {
    "country": "DE",
    "name": "Kehrig",
    "lat": "50.28333",
    "lng": "7.21667"
  },
  {
    "country": "DE",
    "name": "Kehl",
    "lat": "48.57297",
    "lng": "7.81523"
  },
  {
    "country": "DE",
    "name": "Kefenrod",
    "lat": "50.34475",
    "lng": "9.21141"
  },
  {
    "country": "DE",
    "name": "Kayna",
    "lat": "50.99414",
    "lng": "12.2371"
  },
  {
    "country": "DE",
    "name": "Kayhude",
    "lat": "53.75629",
    "lng": "10.13232"
  },
  {
    "country": "DE",
    "name": "Kavelstorf",
    "lat": "54.00596",
    "lng": "12.19082"
  },
  {
    "country": "DE",
    "name": "Kaulsdorf",
    "lat": "52.51732",
    "lng": "13.58871"
  },
  {
    "country": "DE",
    "name": "Kaulsdorf",
    "lat": "50.6167",
    "lng": "11.43295"
  },
  {
    "country": "DE",
    "name": "Kaufering",
    "lat": "48.09121",
    "lng": "10.87913"
  },
  {
    "country": "DE",
    "name": "Kaufbeuren",
    "lat": "47.88238",
    "lng": "10.62192"
  },
  {
    "country": "DE",
    "name": "Kaub",
    "lat": "50.08831",
    "lng": "7.76069"
  },
  {
    "country": "DE",
    "name": "Katzweiler",
    "lat": "49.5",
    "lng": "7.7"
  },
  {
    "country": "DE",
    "name": "Katzhütte",
    "lat": "50.55191",
    "lng": "11.05293"
  },
  {
    "country": "DE",
    "name": "Katzenelnbogen",
    "lat": "50.26745",
    "lng": "7.97322"
  },
  {
    "country": "DE",
    "name": "Katharinenberg",
    "lat": "51.18137",
    "lng": "10.26084"
  },
  {
    "country": "DE",
    "name": "Kastorf",
    "lat": "53.74569",
    "lng": "10.56723"
  },
  {
    "country": "DE",
    "name": "Kastl",
    "lat": "49.83333",
    "lng": "11.9"
  },
  {
    "country": "DE",
    "name": "Kastl",
    "lat": "49.3696",
    "lng": "11.68261"
  },
  {
    "country": "DE",
    "name": "Kastl",
    "lat": "48.2",
    "lng": "12.7"
  },
  {
    "country": "DE",
    "name": "Kastellaun",
    "lat": "50.06922",
    "lng": "7.44154"
  },
  {
    "country": "DE",
    "name": "Kassel",
    "lat": "51.31667",
    "lng": "9.5"
  },
  {
    "country": "DE",
    "name": "Kasseedorf",
    "lat": "54.16667",
    "lng": "10.71667"
  },
  {
    "country": "DE",
    "name": "Kasendorf",
    "lat": "50.03665",
    "lng": "11.35203"
  },
  {
    "country": "DE",
    "name": "Kasel",
    "lat": "49.7617",
    "lng": "6.73222"
  },
  {
    "country": "DE",
    "name": "Karstädt",
    "lat": "53.16215",
    "lng": "11.74242"
  },
  {
    "country": "DE",
    "name": "Karsdorf",
    "lat": "51.27134",
    "lng": "11.65775"
  },
  {
    "country": "DE",
    "name": "Karsbach",
    "lat": "50.04091",
    "lng": "9.78534"
  },
  {
    "country": "DE",
    "name": "Karow",
    "lat": "52.60904",
    "lng": "13.48117"
  },
  {
    "country": "DE",
    "name": "Karlstadt",
    "lat": "49.96034",
    "lng": "9.77239"
  },
  {
    "country": "DE",
    "name": "Karlsruhe",
    "lat": "49.00937",
    "lng": "8.40444"
  },
  {
    "country": "DE",
    "name": "Karlskron",
    "lat": "48.68333",
    "lng": "11.41667"
  },
  {
    "country": "DE",
    "name": "Karlshuld",
    "lat": "48.6819",
    "lng": "11.28503"
  },
  {
    "country": "DE",
    "name": "Karlshorst",
    "lat": "52.48419",
    "lng": "13.53185"
  },
  {
    "country": "DE",
    "name": "Karlshagen",
    "lat": "54.11107",
    "lng": "13.83193"
  },
  {
    "country": "DE",
    "name": "Bad Karlshafen",
    "lat": "51.64263",
    "lng": "9.45477"
  },
  {
    "country": "DE",
    "name": "Karlsfeld",
    "lat": "48.22697",
    "lng": "11.47573"
  },
  {
    "country": "DE",
    "name": "Karben",
    "lat": "50.23019",
    "lng": "8.77155"
  },
  {
    "country": "DE",
    "name": "Karbach",
    "lat": "49.86701",
    "lng": "9.63806"
  },
  {
    "country": "DE",
    "name": "Kapsweyer",
    "lat": "49.04389",
    "lng": "8.02167"
  },
  {
    "country": "DE",
    "name": "Kappelrodeck",
    "lat": "48.59182",
    "lng": "8.11692"
  },
  {
    "country": "DE",
    "name": "Kappeln",
    "lat": "54.66122",
    "lng": "9.9313"
  },
  {
    "country": "DE",
    "name": "Kannawurf",
    "lat": "51.26667",
    "lng": "11.13333"
  },
  {
    "country": "DE",
    "name": "Kandern",
    "lat": "47.71393",
    "lng": "7.66237"
  },
  {
    "country": "DE",
    "name": "Kandel",
    "lat": "49.08277",
    "lng": "8.1972"
  },
  {
    "country": "DE",
    "name": "Kamsdorf",
    "lat": "50.64312",
    "lng": "11.45401"
  },
  {
    "country": "DE",
    "name": "Kamp-Lintfort",
    "lat": "51.50467",
    "lng": "6.54587"
  },
  {
    "country": "DE",
    "name": "Kamp-Bornhofen",
    "lat": "50.22282",
    "lng": "7.62364"
  },
  {
    "country": "DE",
    "name": "Kammerstein",
    "lat": "49.29317",
    "lng": "10.97277"
  },
  {
    "country": "DE",
    "name": "Kamenz",
    "lat": "51.26798",
    "lng": "14.09374"
  },
  {
    "country": "DE",
    "name": "Kamen",
    "lat": "51.59231",
    "lng": "7.6638"
  },
  {
    "country": "DE",
    "name": "Kaltenwestheim",
    "lat": "50.60991",
    "lng": "10.11692"
  },
  {
    "country": "DE",
    "name": "Kaltennordheim",
    "lat": "50.62649",
    "lng": "10.15915"
  },
  {
    "country": "DE",
    "name": "Kaltenkirchen",
    "lat": "53.83292",
    "lng": "9.9581"
  },
  {
    "country": "DE",
    "name": "Kaltenengers",
    "lat": "50.41667",
    "lng": "7.55"
  },
  {
    "country": "DE",
    "name": "Kallstadt",
    "lat": "49.49083",
    "lng": "8.17611"
  },
  {
    "country": "DE",
    "name": "Kallmünz",
    "lat": "49.16094",
    "lng": "11.96051"
  },
  {
    "country": "DE",
    "name": "Kall",
    "lat": "50.54223",
    "lng": "6.56297"
  },
  {
    "country": "DE",
    "name": "Kalkhorst",
    "lat": "53.97012",
    "lng": "11.04469"
  },
  {
    "country": "DE",
    "name": "Kalkar",
    "lat": "51.73907",
    "lng": "6.29101"
  },
  {
    "country": "DE",
    "name": "Kalefeld",
    "lat": "51.8",
    "lng": "10.03333"
  },
  {
    "country": "DE",
    "name": "Kalchreuth",
    "lat": "49.55785",
    "lng": "11.1335"
  },
  {
    "country": "DE",
    "name": "Kalbe",
    "lat": "52.65656",
    "lng": "11.38456"
  },
  {
    "country": "DE",
    "name": "Kakenstorf",
    "lat": "53.30317",
    "lng": "9.76289"
  },
  {
    "country": "DE",
    "name": "Kaisheim",
    "lat": "48.76751",
    "lng": "10.79639"
  },
  {
    "country": "DE",
    "name": "Kaiserslautern",
    "lat": "49.443",
    "lng": "7.77161"
  },
  {
    "country": "DE",
    "name": "Kaisersesch",
    "lat": "50.23148",
    "lng": "7.13864"
  },
  {
    "country": "DE",
    "name": "Kaisersbach",
    "lat": "48.93023",
    "lng": "9.63898"
  },
  {
    "country": "DE",
    "name": "Kahl am Main",
    "lat": "50.06981",
    "lng": "9.00553"
  },
  {
    "country": "DE",
    "name": "Kahla",
    "lat": "50.80651",
    "lng": "11.58516"
  },
  {
    "country": "DE",
    "name": "Kadenbach",
    "lat": "50.38333",
    "lng": "7.73333"
  },
  {
    "country": "DE",
    "name": "Kaarst",
    "lat": "51.22929",
    "lng": "6.61883"
  },
  {
    "country": "DE",
    "name": "Jüterbog",
    "lat": "51.99607",
    "lng": "13.07979"
  },
  {
    "country": "DE",
    "name": "Jürgenshagen",
    "lat": "53.95417",
    "lng": "11.89665"
  },
  {
    "country": "DE",
    "name": "Jünkerath",
    "lat": "50.34412",
    "lng": "6.58138"
  },
  {
    "country": "DE",
    "name": "Jungingen",
    "lat": "48.32787",
    "lng": "9.04095"
  },
  {
    "country": "DE",
    "name": "Jülich",
    "lat": "50.92149",
    "lng": "6.36267"
  },
  {
    "country": "DE",
    "name": "Julbach",
    "lat": "48.2543",
    "lng": "12.95793"
  },
  {
    "country": "DE",
    "name": "Juist",
    "lat": "53.67787",
    "lng": "6.99575"
  },
  {
    "country": "DE",
    "name": "Jühnde",
    "lat": "51.46667",
    "lng": "9.8"
  },
  {
    "country": "DE",
    "name": "Jugenheim",
    "lat": "49.89362",
    "lng": "8.08468"
  },
  {
    "country": "DE",
    "name": "Judenbach",
    "lat": "50.39591",
    "lng": "11.22099"
  },
  {
    "country": "DE",
    "name": "Jüchsen",
    "lat": "50.47993",
    "lng": "10.50183"
  },
  {
    "country": "DE",
    "name": "Jüchen",
    "lat": "51.1",
    "lng": "6.5"
  },
  {
    "country": "DE",
    "name": "Jübek",
    "lat": "54.55709",
    "lng": "9.39773"
  },
  {
    "country": "DE",
    "name": "Jork",
    "lat": "53.53198",
    "lng": "9.68076"
  },
  {
    "country": "DE",
    "name": "Jördenstorf",
    "lat": "53.87823",
    "lng": "12.61619"
  },
  {
    "country": "DE",
    "name": "Jöhstadt",
    "lat": "50.51229",
    "lng": "13.0946"
  },
  {
    "country": "DE",
    "name": "Jöhlingen",
    "lat": "49.03218",
    "lng": "8.5735"
  },
  {
    "country": "DE",
    "name": "Johannisthal",
    "lat": "52.44653",
    "lng": "13.5066"
  },
  {
    "country": "DE",
    "name": "Johanniskirchen",
    "lat": "48.53333",
    "lng": "12.95"
  },
  {
    "country": "DE",
    "name": "Johanngeorgenstadt",
    "lat": "50.43254",
    "lng": "12.7114"
  },
  {
    "country": "DE",
    "name": "Johannesberg",
    "lat": "50.03159",
    "lng": "9.14252"
  },
  {
    "country": "DE",
    "name": "Jockgrim",
    "lat": "49.09288",
    "lng": "8.27468"
  },
  {
    "country": "DE",
    "name": "Joachimsthal",
    "lat": "52.97945",
    "lng": "13.74493"
  },
  {
    "country": "DE",
    "name": "Jever",
    "lat": "53.57368",
    "lng": "7.89806"
  },
  {
    "country": "DE",
    "name": "Jevenstedt",
    "lat": "54.23333",
    "lng": "9.66667"
  },
  {
    "country": "DE",
    "name": "Jetzendorf",
    "lat": "48.43333",
    "lng": "11.41667"
  },
  {
    "country": "DE",
    "name": "Jestetten",
    "lat": "47.65",
    "lng": "8.56667"
  },
  {
    "country": "DE",
    "name": "Jesteburg",
    "lat": "53.30966",
    "lng": "9.95262"
  },
  {
    "country": "DE",
    "name": "Jeßnitz",
    "lat": "51.68307",
    "lng": "12.29992"
  },
  {
    "country": "DE",
    "name": "Jessen",
    "lat": "51.79337",
    "lng": "12.95762"
  },
  {
    "country": "DE",
    "name": "Jesewitz",
    "lat": "51.42276",
    "lng": "12.56312"
  },
  {
    "country": "DE",
    "name": "Jesenwang",
    "lat": "48.16667",
    "lng": "11.13333"
  },
  {
    "country": "DE",
    "name": "Jesberg",
    "lat": "51",
    "lng": "9.15"
  },
  {
    "country": "DE",
    "name": "Jerxheim",
    "lat": "52.08172",
    "lng": "10.89844"
  },
  {
    "country": "DE",
    "name": "Jersbek",
    "lat": "53.73333",
    "lng": "10.21667"
  },
  {
    "country": "DE",
    "name": "Jerrishoe",
    "lat": "54.6567",
    "lng": "9.36918"
  },
  {
    "country": "DE",
    "name": "Jerichow",
    "lat": "52.50049",
    "lng": "12.02383"
  },
  {
    "country": "DE",
    "name": "Jengen",
    "lat": "47.99934",
    "lng": "10.72575"
  },
  {
    "country": "DE",
    "name": "Jena",
    "lat": "50.92878",
    "lng": "11.5899"
  },
  {
    "country": "DE",
    "name": "Jemgum",
    "lat": "53.26667",
    "lng": "7.38333"
  },
  {
    "country": "DE",
    "name": "Jembke",
    "lat": "52.5",
    "lng": "10.76667"
  },
  {
    "country": "DE",
    "name": "Jävenitz",
    "lat": "52.5241",
    "lng": "11.49909"
  },
  {
    "country": "DE",
    "name": "Jatznick",
    "lat": "53.57951",
    "lng": "13.93955"
  },
  {
    "country": "DE",
    "name": "Jarmen",
    "lat": "53.92385",
    "lng": "13.34032"
  },
  {
    "country": "DE",
    "name": "Jänschwalde",
    "lat": "51.86066",
    "lng": "14.49813"
  },
  {
    "country": "DE",
    "name": "Jandelsbrunn",
    "lat": "48.73333",
    "lng": "13.7"
  },
  {
    "country": "DE",
    "name": "Jameln",
    "lat": "53.05",
    "lng": "11.08333"
  },
  {
    "country": "DE",
    "name": "Jacobsdorf",
    "lat": "52.33333",
    "lng": "14.35"
  },
  {
    "country": "DE",
    "name": "Jahnsdorf",
    "lat": "50.74509",
    "lng": "12.85414"
  },
  {
    "country": "DE",
    "name": "Jagstzell",
    "lat": "49.03055",
    "lng": "10.09751"
  },
  {
    "country": "DE",
    "name": "Jagsthausen",
    "lat": "49.31056",
    "lng": "9.46833"
  },
  {
    "country": "DE",
    "name": "Itzstedt",
    "lat": "53.808",
    "lng": "10.15797"
  },
  {
    "country": "DE",
    "name": "Itzehoe",
    "lat": "53.92099",
    "lng": "9.51529"
  },
  {
    "country": "DE",
    "name": "Ittlingen",
    "lat": "49.19083",
    "lng": "8.93083"
  },
  {
    "country": "DE",
    "name": "Itterbeck",
    "lat": "52.50618",
    "lng": "6.80354"
  },
  {
    "country": "DE",
    "name": "Issum",
    "lat": "51.53333",
    "lng": "6.43333"
  },
  {
    "country": "DE",
    "name": "Isselburg",
    "lat": "51.83232",
    "lng": "6.46428"
  },
  {
    "country": "DE",
    "name": "Ispringen",
    "lat": "48.91667",
    "lng": "8.66667"
  },
  {
    "country": "DE",
    "name": "Isny im Allgäu",
    "lat": "47.6926",
    "lng": "10.03857"
  },
  {
    "country": "DE",
    "name": "Ismaning",
    "lat": "48.23333",
    "lng": "11.68333"
  },
  {
    "country": "DE",
    "name": "Isernhagen Farster Bauerschaft",
    "lat": "52.47093",
    "lng": "9.84179"
  },
  {
    "country": "DE",
    "name": "Iserlohn",
    "lat": "51.37547",
    "lng": "7.70281"
  },
  {
    "country": "DE",
    "name": "Isenbüttel",
    "lat": "52.43333",
    "lng": "10.58333"
  },
  {
    "country": "DE",
    "name": "Isen",
    "lat": "48.21203",
    "lng": "12.05672"
  },
  {
    "country": "DE",
    "name": "Irxleben",
    "lat": "52.16689",
    "lng": "11.48064"
  },
  {
    "country": "DE",
    "name": "Irsee",
    "lat": "47.90815",
    "lng": "10.57177"
  },
  {
    "country": "DE",
    "name": "Irschenberg",
    "lat": "47.83333",
    "lng": "11.91667"
  },
  {
    "country": "DE",
    "name": "Irsch",
    "lat": "49.7262",
    "lng": "6.69806"
  },
  {
    "country": "DE",
    "name": "Irsch",
    "lat": "49.60487",
    "lng": "6.59547"
  },
  {
    "country": "DE",
    "name": "Irrel",
    "lat": "49.84539",
    "lng": "6.45705"
  },
  {
    "country": "DE",
    "name": "Irlbach",
    "lat": "48.84128",
    "lng": "12.75135"
  },
  {
    "country": "DE",
    "name": "Irchenrieth",
    "lat": "49.62286",
    "lng": "12.22495"
  },
  {
    "country": "DE",
    "name": "Ipsheim",
    "lat": "49.5275",
    "lng": "10.48176"
  },
  {
    "country": "DE",
    "name": "Ippesheim",
    "lat": "49.60214",
    "lng": "10.22552"
  },
  {
    "country": "DE",
    "name": "Iphofen",
    "lat": "49.70239",
    "lng": "10.26037"
  },
  {
    "country": "DE",
    "name": "Inzlingen",
    "lat": "47.58851",
    "lng": "7.69094"
  },
  {
    "country": "DE",
    "name": "Inzigkofen",
    "lat": "48.07034",
    "lng": "9.17998"
  },
  {
    "country": "DE",
    "name": "Inzell",
    "lat": "47.76302",
    "lng": "12.75146"
  },
  {
    "country": "DE",
    "name": "Insingen",
    "lat": "49.3",
    "lng": "10.16667"
  },
  {
    "country": "DE",
    "name": "Insheim",
    "lat": "49.15806",
    "lng": "8.14722"
  },
  {
    "country": "DE",
    "name": "Inning am Holz",
    "lat": "48.34687",
    "lng": "12.07506"
  },
  {
    "country": "DE",
    "name": "Inning am Ammersee",
    "lat": "48.07636",
    "lng": "11.15232"
  },
  {
    "country": "DE",
    "name": "Innernzell",
    "lat": "48.8515",
    "lng": "13.27539"
  },
  {
    "country": "DE",
    "name": "Ingolstadt",
    "lat": "48.76508",
    "lng": "11.42372"
  },
  {
    "country": "DE",
    "name": "Ingoldingen",
    "lat": "48.02552",
    "lng": "9.74195"
  },
  {
    "country": "DE",
    "name": "Ingersleben",
    "lat": "50.92167",
    "lng": "10.93646"
  },
  {
    "country": "DE",
    "name": "Ingelheim am Rhein",
    "lat": "49.97078",
    "lng": "8.05883"
  },
  {
    "country": "DE",
    "name": "Ingelfingen",
    "lat": "49.30028",
    "lng": "9.65303"
  },
  {
    "country": "DE",
    "name": "Inden",
    "lat": "50.84306",
    "lng": "6.36004"
  },
  {
    "country": "DE",
    "name": "Inchenhofen",
    "lat": "48.51288",
    "lng": "11.11458"
  },
  {
    "country": "DE",
    "name": "Imsbach",
    "lat": "49.58333",
    "lng": "7.88333"
  },
  {
    "country": "DE",
    "name": "Immenstadt im Allgäu",
    "lat": "47.55996",
    "lng": "10.21394"
  },
  {
    "country": "DE",
    "name": "Immenstaad am Bodensee",
    "lat": "47.66667",
    "lng": "9.36667"
  },
  {
    "country": "DE",
    "name": "Immenreuth",
    "lat": "49.9",
    "lng": "11.86667"
  },
  {
    "country": "DE",
    "name": "Immenhausen",
    "lat": "51.42763",
    "lng": "9.48017"
  },
  {
    "country": "DE",
    "name": "Immendingen",
    "lat": "47.93333",
    "lng": "8.73333"
  },
  {
    "country": "DE",
    "name": "Immelborn",
    "lat": "50.79229",
    "lng": "10.27812"
  },
  {
    "country": "DE",
    "name": "Ilvesheim",
    "lat": "49.47404",
    "lng": "8.5674"
  },
  {
    "country": "DE",
    "name": "Ilshofen",
    "lat": "49.17015",
    "lng": "9.91825"
  },
  {
    "country": "DE",
    "name": "Ilsfeld",
    "lat": "49.05548",
    "lng": "9.24598"
  },
  {
    "country": "DE",
    "name": "Ilsenburg",
    "lat": "51.86695",
    "lng": "10.67817"
  },
  {
    "country": "DE",
    "name": "Ilmmünster",
    "lat": "48.48333",
    "lng": "11.5"
  },
  {
    "country": "DE",
    "name": "Ilmenau",
    "lat": "50.68322",
    "lng": "10.91858"
  },
  {
    "country": "DE",
    "name": "Illschwang",
    "lat": "49.45",
    "lng": "11.68333"
  },
  {
    "country": "DE",
    "name": "Illmensee",
    "lat": "47.86229",
    "lng": "9.37235"
  },
  {
    "country": "DE",
    "name": "Illingen",
    "lat": "49.37362",
    "lng": "7.04758"
  },
  {
    "country": "DE",
    "name": "Illingen",
    "lat": "48.95616",
    "lng": "8.92459"
  },
  {
    "country": "DE",
    "name": "Illertissen",
    "lat": "48.22336",
    "lng": "10.10347"
  },
  {
    "country": "DE",
    "name": "Illerrieden",
    "lat": "48.27017",
    "lng": "10.05155"
  },
  {
    "country": "DE",
    "name": "Ilfeld",
    "lat": "51.5757",
    "lng": "10.78469"
  },
  {
    "country": "DE",
    "name": "Ilbesheim",
    "lat": "49.18277",
    "lng": "8.05363"
  },
  {
    "country": "DE",
    "name": "Ilberstedt",
    "lat": "51.8",
    "lng": "11.66667"
  },
  {
    "country": "DE",
    "name": "Ihrlerstein",
    "lat": "48.93333",
    "lng": "11.86667"
  },
  {
    "country": "DE",
    "name": "Ihringen",
    "lat": "48.04303",
    "lng": "7.6476"
  },
  {
    "country": "DE",
    "name": "Ihlienworth",
    "lat": "53.73333",
    "lng": "8.91667"
  },
  {
    "country": "DE",
    "name": "Iggingen",
    "lat": "48.83167",
    "lng": "9.87894"
  },
  {
    "country": "DE",
    "name": "Iggensbach",
    "lat": "48.73014",
    "lng": "13.14229"
  },
  {
    "country": "DE",
    "name": "Igersheim",
    "lat": "49.49444",
    "lng": "9.81694"
  },
  {
    "country": "DE",
    "name": "Igensdorf",
    "lat": "49.62322",
    "lng": "11.23137"
  },
  {
    "country": "DE",
    "name": "Igel",
    "lat": "49.71033",
    "lng": "6.55498"
  },
  {
    "country": "DE",
    "name": "Ifta",
    "lat": "51.06667",
    "lng": "10.18333"
  },
  {
    "country": "DE",
    "name": "Iffezheim",
    "lat": "48.82167",
    "lng": "8.1431"
  },
  {
    "country": "DE",
    "name": "Iffeldorf",
    "lat": "47.76667",
    "lng": "11.31667"
  },
  {
    "country": "DE",
    "name": "Idstein",
    "lat": "50.21773",
    "lng": "8.26679"
  },
  {
    "country": "DE",
    "name": "Idar-Oberstein",
    "lat": "49.71443",
    "lng": "7.30776"
  },
  {
    "country": "DE",
    "name": "Icking",
    "lat": "47.95",
    "lng": "11.43333"
  },
  {
    "country": "DE",
    "name": "Ichtershausen",
    "lat": "50.87602",
    "lng": "10.97028"
  },
  {
    "country": "DE",
    "name": "Ichenhausen",
    "lat": "48.37119",
    "lng": "10.30706"
  },
  {
    "country": "DE",
    "name": "Ibbenbüren",
    "lat": "52.27964",
    "lng": "7.71457"
  },
  {
    "country": "DE",
    "name": "Huy-Neinstedt",
    "lat": "51.96585",
    "lng": "10.91457"
  },
  {
    "country": "DE",
    "name": "Hüttlingen",
    "lat": "48.89266",
    "lng": "10.10064"
  },
  {
    "country": "DE",
    "name": "Hüttisheim",
    "lat": "48.27965",
    "lng": "9.94246"
  },
  {
    "country": "DE",
    "name": "Hutthurm",
    "lat": "48.67276",
    "lng": "13.47146"
  },
  {
    "country": "DE",
    "name": "Hüttenrode",
    "lat": "51.7688",
    "lng": "10.90384"
  },
  {
    "country": "DE",
    "name": "Hütschenhausen",
    "lat": "49.41667",
    "lng": "7.48333"
  },
  {
    "country": "DE",
    "name": "Husum",
    "lat": "54.4858",
    "lng": "9.05239"
  },
  {
    "country": "DE",
    "name": "Husum",
    "lat": "52.56667",
    "lng": "9.25"
  },
  {
    "country": "DE",
    "name": "Hürup",
    "lat": "54.75",
    "lng": "9.53333"
  },
  {
    "country": "DE",
    "name": "Hürth",
    "lat": "50.87079",
    "lng": "6.86761"
  },
  {
    "country": "DE",
    "name": "Hürtgenwald",
    "lat": "50.71667",
    "lng": "6.36667"
  },
  {
    "country": "DE",
    "name": "Hurlach",
    "lat": "48.11838",
    "lng": "10.81115"
  },
  {
    "country": "DE",
    "name": "Hünxe",
    "lat": "51.63405",
    "lng": "6.69741"
  },
  {
    "country": "DE",
    "name": "Hungen",
    "lat": "50.47368",
    "lng": "8.89326"
  },
  {
    "country": "DE",
    "name": "Hünfeld",
    "lat": "50.67966",
    "lng": "9.76727"
  },
  {
    "country": "DE",
    "name": "Hundsangen",
    "lat": "50.45",
    "lng": "7.98333"
  },
  {
    "country": "DE",
    "name": "Hunding",
    "lat": "48.84227",
    "lng": "13.17681"
  },
  {
    "country": "DE",
    "name": "Hundeshagen",
    "lat": "51.43333",
    "lng": "10.28333"
  },
  {
    "country": "DE",
    "name": "Hunderdorf",
    "lat": "48.89162",
    "lng": "12.67382"
  },
  {
    "country": "DE",
    "name": "Hummelsbüttel",
    "lat": "53.64773",
    "lng": "10.04149"
  },
  {
    "country": "DE",
    "name": "Humboldtkolonie",
    "lat": "50.93182",
    "lng": "6.99469"
  },
  {
    "country": "DE",
    "name": "Hülsede",
    "lat": "52.24951",
    "lng": "9.36147"
  },
  {
    "country": "DE",
    "name": "Hüllhorst",
    "lat": "52.28333",
    "lng": "8.66667"
  },
  {
    "country": "DE",
    "name": "Hülben",
    "lat": "48.51982",
    "lng": "9.4079"
  },
  {
    "country": "DE",
    "name": "Huisheim",
    "lat": "48.8251",
    "lng": "10.70331"
  },
  {
    "country": "DE",
    "name": "Huglfing",
    "lat": "47.76667",
    "lng": "11.16667"
  },
  {
    "country": "DE",
    "name": "Hügelsheim",
    "lat": "48.8",
    "lng": "8.11667"
  },
  {
    "country": "DE",
    "name": "Hüfingen",
    "lat": "47.92543",
    "lng": "8.48831"
  },
  {
    "country": "DE",
    "name": "Hüffenhardt",
    "lat": "49.29194",
    "lng": "9.08167"
  },
  {
    "country": "DE",
    "name": "Hüffelsheim",
    "lat": "49.81667",
    "lng": "7.8"
  },
  {
    "country": "DE",
    "name": "Hude",
    "lat": "53.10766",
    "lng": "8.46322"
  },
  {
    "country": "DE",
    "name": "Huede",
    "lat": "52.49588",
    "lng": "8.35804"
  },
  {
    "country": "DE",
    "name": "Hückeswagen",
    "lat": "51.14979",
    "lng": "7.34471"
  },
  {
    "country": "DE",
    "name": "Hückelhoven",
    "lat": "51.0555",
    "lng": "6.22658"
  },
  {
    "country": "DE",
    "name": "Hoym",
    "lat": "51.78292",
    "lng": "11.31244"
  },
  {
    "country": "DE",
    "name": "Hoyerswerda",
    "lat": "51.43787",
    "lng": "14.23549"
  },
  {
    "country": "DE",
    "name": "Hoya",
    "lat": "52.80781",
    "lng": "9.14028"
  },
  {
    "country": "DE",
    "name": "Höxter",
    "lat": "51.77501",
    "lng": "9.38155"
  },
  {
    "country": "DE",
    "name": "Hövelhof",
    "lat": "51.81667",
    "lng": "8.65"
  },
  {
    "country": "DE",
    "name": "Höttingen",
    "lat": "49.06262",
    "lng": "11.0053"
  },
  {
    "country": "DE",
    "name": "Hötensleben",
    "lat": "52.11974",
    "lng": "11.02238"
  },
  {
    "country": "DE",
    "name": "Höslwang",
    "lat": "47.95378",
    "lng": "12.32915"
  },
  {
    "country": "DE",
    "name": "Hosenfeld",
    "lat": "50.50502",
    "lng": "9.47966"
  },
  {
    "country": "DE",
    "name": "Hösbach",
    "lat": "50.00646",
    "lng": "9.20765"
  },
  {
    "country": "DE",
    "name": "Horstmar",
    "lat": "52.08098",
    "lng": "7.30539"
  },
  {
    "country": "DE",
    "name": "Hörstel",
    "lat": "52.29763",
    "lng": "7.58382"
  },
  {
    "country": "DE",
    "name": "Horstedt",
    "lat": "53.18333",
    "lng": "9.23333"
  },
  {
    "country": "DE",
    "name": "Horst",
    "lat": "53.81195",
    "lng": "9.62307"
  },
  {
    "country": "DE",
    "name": "Hörselgau",
    "lat": "50.91988",
    "lng": "10.58444"
  },
  {
    "country": "DE",
    "name": "Horrenberg",
    "lat": "49.2804",
    "lng": "8.78087"
  },
  {
    "country": "DE",
    "name": "Hornstorf",
    "lat": "53.90994",
    "lng": "11.53214"
  },
  {
    "country": "DE",
    "name": "Hörnsheim",
    "lat": "50.51828",
    "lng": "8.62976"
  },
  {
    "country": "DE",
    "name": "Hornhausen",
    "lat": "52.0451",
    "lng": "11.17104"
  },
  {
    "country": "DE",
    "name": "Horneburg",
    "lat": "53.50672",
    "lng": "9.57546"
  },
  {
    "country": "DE",
    "name": "Hornburg",
    "lat": "52.03095",
    "lng": "10.6049"
  },
  {
    "country": "DE",
    "name": "Hornberg",
    "lat": "48.21068",
    "lng": "8.23275"
  },
  {
    "country": "DE",
    "name": "Hornbach",
    "lat": "49.18778",
    "lng": "7.36883"
  },
  {
    "country": "DE",
    "name": "Horn",
    "lat": "51.87151",
    "lng": "8.9451"
  },
  {
    "country": "DE",
    "name": "Hormersdorf",
    "lat": "50.67406",
    "lng": "12.88194"
  },
  {
    "country": "DE",
    "name": "Horka",
    "lat": "51.26342",
    "lng": "14.25523"
  },
  {
    "country": "DE",
    "name": "Horhausen",
    "lat": "50.58745",
    "lng": "7.53028"
  },
  {
    "country": "DE",
    "name": "Hörgertshausen",
    "lat": "48.55",
    "lng": "11.86667"
  },
  {
    "country": "DE",
    "name": "Horgenzell",
    "lat": "47.80534",
    "lng": "9.49727"
  },
  {
    "country": "DE",
    "name": "Horgau",
    "lat": "48.39507",
    "lng": "10.68283"
  },
  {
    "country": "DE",
    "name": "Hördt",
    "lat": "49.16583",
    "lng": "8.32639"
  },
  {
    "country": "DE",
    "name": "Hörden",
    "lat": "51.66835",
    "lng": "10.28372"
  },
  {
    "country": "DE",
    "name": "Horben",
    "lat": "47.93333",
    "lng": "7.86667"
  },
  {
    "country": "DE",
    "name": "Horb am Neckar",
    "lat": "48.44423",
    "lng": "8.6913"
  },
  {
    "country": "DE",
    "name": "Höpfingen",
    "lat": "49.6025",
    "lng": "9.42861"
  },
  {
    "country": "DE",
    "name": "Hopferau",
    "lat": "47.61667",
    "lng": "10.63333"
  },
  {
    "country": "DE",
    "name": "Hoogstede",
    "lat": "52.58333",
    "lng": "6.95"
  },
  {
    "country": "DE",
    "name": "Homburg",
    "lat": "49.32637",
    "lng": "7.33867"
  },
  {
    "country": "DE",
    "name": "Homberg",
    "lat": "51.02994",
    "lng": "9.40261"
  },
  {
    "country": "DE",
    "name": "Homberg",
    "lat": "50.73108",
    "lng": "8.99644"
  },
  {
    "country": "DE",
    "name": "Holzwickede",
    "lat": "51.5",
    "lng": "7.63333"
  },
  {
    "country": "DE",
    "name": "Holzweißig",
    "lat": "51.59819",
    "lng": "12.30842"
  },
  {
    "country": "DE",
    "name": "Holzminden",
    "lat": "51.82798",
    "lng": "9.4455"
  },
  {
    "country": "DE",
    "name": "Holzmaden",
    "lat": "48.63333",
    "lng": "9.51667"
  },
  {
    "country": "DE",
    "name": "Holzkirchen",
    "lat": "47.87663",
    "lng": "11.70181"
  },
  {
    "country": "DE",
    "name": "Holzheim",
    "lat": "48.51422",
    "lng": "10.53057"
  },
  {
    "country": "DE",
    "name": "Holzheim",
    "lat": "48.38333",
    "lng": "10.1"
  },
  {
    "country": "DE",
    "name": "Holzhausen an der Haide",
    "lat": "50.21855",
    "lng": "7.90973"
  },
  {
    "country": "DE",
    "name": "Bad Holzhausen",
    "lat": "52.28971",
    "lng": "8.53954"
  },
  {
    "country": "DE",
    "name": "Holzgünz",
    "lat": "48.02503",
    "lng": "10.25901"
  },
  {
    "country": "DE",
    "name": "Holzgerlingen",
    "lat": "48.63969",
    "lng": "9.01149"
  },
  {
    "country": "DE",
    "name": "Holzdorf",
    "lat": "51.77873",
    "lng": "13.12756"
  },
  {
    "country": "DE",
    "name": "Holzappel",
    "lat": "50.35",
    "lng": "7.9"
  },
  {
    "country": "DE",
    "name": "Holtsee",
    "lat": "54.4",
    "lng": "9.85"
  },
  {
    "country": "DE",
    "name": "Holtland",
    "lat": "53.28333",
    "lng": "7.58333"
  },
  {
    "country": "DE",
    "name": "Holm",
    "lat": "53.61667",
    "lng": "9.66667"
  },
  {
    "country": "DE",
    "name": "Hollstadt",
    "lat": "50.35",
    "lng": "10.3"
  },
  {
    "country": "DE",
    "name": "Hollingstedt",
    "lat": "54.45934",
    "lng": "9.33695"
  },
  {
    "country": "DE",
    "name": "Hollfeld",
    "lat": "49.93793",
    "lng": "11.29153"
  },
  {
    "country": "DE",
    "name": "Holler",
    "lat": "50.41667",
    "lng": "7.83333"
  },
  {
    "country": "DE",
    "name": "Hollenstedt",
    "lat": "53.36667",
    "lng": "9.71667"
  },
  {
    "country": "DE",
    "name": "Hollenbach",
    "lat": "48.48333",
    "lng": "11.06667"
  },
  {
    "country": "DE",
    "name": "Holleben",
    "lat": "51.44047",
    "lng": "11.89915"
  },
  {
    "country": "DE",
    "name": "Holle",
    "lat": "52.08721",
    "lng": "10.16012"
  },
  {
    "country": "DE",
    "name": "Holdorf",
    "lat": "52.58333",
    "lng": "8.11667"
  },
  {
    "country": "DE",
    "name": "Hoisdorf",
    "lat": "53.65",
    "lng": "10.31667"
  },
  {
    "country": "DE",
    "name": "Höingen",
    "lat": "50.7191",
    "lng": "8.91961"
  },
  {
    "country": "DE",
    "name": "Höhr-Grenzhausen",
    "lat": "50.43474",
    "lng": "7.66903"
  },
  {
    "country": "DE",
    "name": "Hohnstein",
    "lat": "50.97991",
    "lng": "14.11408"
  },
  {
    "country": "DE",
    "name": "Höhnstedt",
    "lat": "51.50268",
    "lng": "11.73844"
  },
  {
    "country": "DE",
    "name": "Hohnhorst",
    "lat": "52.36942",
    "lng": "9.37168"
  },
  {
    "country": "DE",
    "name": "Hohndorf",
    "lat": "50.74044",
    "lng": "12.68058"
  },
  {
    "country": "DE",
    "name": "Hohn",
    "lat": "54.3",
    "lng": "9.5"
  },
  {
    "country": "DE",
    "name": "Hohenwestedt",
    "lat": "54.08886",
    "lng": "9.65359"
  },
  {
    "country": "DE",
    "name": "Hohenwarthe",
    "lat": "52.22968",
    "lng": "11.71528"
  },
  {
    "country": "DE",
    "name": "Hohenwarth",
    "lat": "49.2",
    "lng": "12.93333"
  },
  {
    "country": "DE",
    "name": "Hohenwarsleben",
    "lat": "52.17898",
    "lng": "11.49994"
  },
  {
    "country": "DE",
    "name": "Hohenthurm",
    "lat": "51.51807",
    "lng": "12.09749"
  },
  {
    "country": "DE",
    "name": "Hohenthann",
    "lat": "48.66115",
    "lng": "12.09251"
  },
  {
    "country": "DE",
    "name": "Hohentengen",
    "lat": "48.02946",
    "lng": "9.37739"
  },
  {
    "country": "DE",
    "name": "Hohentengen am Hochrhein",
    "lat": "47.57005",
    "lng": "8.4325"
  },
  {
    "country": "DE",
    "name": "Hohenstein-Ernstthal",
    "lat": "50.80064",
    "lng": "12.71287"
  },
  {
    "country": "DE",
    "name": "Hohenpolding",
    "lat": "48.38333",
    "lng": "12.13333"
  },
  {
    "country": "DE",
    "name": "Hohenpeißenberg",
    "lat": "47.8",
    "lng": "11"
  },
  {
    "country": "DE",
    "name": "Hohen Neuendorf",
    "lat": "52.67631",
    "lng": "13.27775"
  },
  {
    "country": "DE",
    "name": "Hohenmölsen",
    "lat": "51.15769",
    "lng": "12.1"
  },
  {
    "country": "DE",
    "name": "Hohenlockstedt",
    "lat": "53.96667",
    "lng": "9.61667"
  },
  {
    "country": "DE",
    "name": "Hohenlinden",
    "lat": "48.15612",
    "lng": "11.99458"
  },
  {
    "country": "DE",
    "name": "Hohenleuben",
    "lat": "50.71128",
    "lng": "12.05427"
  },
  {
    "country": "DE",
    "name": "Hohenleipisch",
    "lat": "51.5",
    "lng": "13.55"
  },
  {
    "country": "DE",
    "name": "Hohenkammer",
    "lat": "48.42406",
    "lng": "11.52522"
  },
  {
    "country": "DE",
    "name": "Hohenhameln",
    "lat": "52.25755",
    "lng": "10.06416"
  },
  {
    "country": "DE",
    "name": "Hohenfurch",
    "lat": "47.85",
    "lng": "10.9"
  },
  {
    "country": "DE",
    "name": "Hohenfels",
    "lat": "49.20397",
    "lng": "11.84841"
  },
  {
    "country": "DE",
    "name": "Hohenfelde",
    "lat": "54.36667",
    "lng": "10.5"
  },
  {
    "country": "DE",
    "name": "Hohendodeleben",
    "lat": "52.10412",
    "lng": "11.50473"
  },
  {
    "country": "DE",
    "name": "Hohenburg",
    "lat": "49.29507",
    "lng": "11.79906"
  },
  {
    "country": "DE",
    "name": "Hohenbrunn",
    "lat": "48.04785",
    "lng": "11.70224"
  },
  {
    "country": "DE",
    "name": "Hohenbocka",
    "lat": "51.43099",
    "lng": "14.00982"
  },
  {
    "country": "DE",
    "name": "Hohenberg an der Eger",
    "lat": "50.09501",
    "lng": "12.22008"
  },
  {
    "country": "DE",
    "name": "Höhenberg",
    "lat": "50.93323",
    "lng": "7.04138"
  },
  {
    "country": "DE",
    "name": "Hohenaspe",
    "lat": "53.98898",
    "lng": "9.52774"
  },
  {
    "country": "DE",
    "name": "Höheischweiler",
    "lat": "49.23333",
    "lng": "7.55"
  },
  {
    "country": "DE",
    "name": "Höheinöd",
    "lat": "49.28966",
    "lng": "7.60673"
  },
  {
    "country": "DE",
    "name": "Hohburg",
    "lat": "51.41168",
    "lng": "12.80508"
  },
  {
    "country": "DE",
    "name": "Hohberg",
    "lat": "48.3227",
    "lng": "7.89972"
  },
  {
    "country": "DE",
    "name": "Hofstetten",
    "lat": "48.25846",
    "lng": "8.06595"
  },
  {
    "country": "DE",
    "name": "Hofstetten",
    "lat": "48.00847",
    "lng": "10.97114"
  },
  {
    "country": "DE",
    "name": "Hofkirchen",
    "lat": "48.67805",
    "lng": "13.11917"
  },
  {
    "country": "DE",
    "name": "Hofheim in Unterfranken",
    "lat": "50.13675",
    "lng": "10.52321"
  },
  {
    "country": "DE",
    "name": "Hofheim am Taunus",
    "lat": "50.09019",
    "lng": "8.4493"
  },
  {
    "country": "DE",
    "name": "Hofgeismar",
    "lat": "51.49607",
    "lng": "9.385"
  },
  {
    "country": "DE",
    "name": "Höfen an der Enz",
    "lat": "48.8",
    "lng": "8.58333"
  },
  {
    "country": "DE",
    "name": "Hofbieber",
    "lat": "50.58629",
    "lng": "9.83534"
  },
  {
    "country": "DE",
    "name": "Hof",
    "lat": "50.66667",
    "lng": "8.01667"
  },
  {
    "country": "DE",
    "name": "Hof",
    "lat": "50.31297",
    "lng": "11.91261"
  },
  {
    "country": "DE",
    "name": "Hodenhagen",
    "lat": "52.76506",
    "lng": "9.59495"
  },
  {
    "country": "DE",
    "name": "Hockenheim",
    "lat": "49.32334",
    "lng": "8.55194"
  },
  {
    "country": "DE",
    "name": "Höckendorf",
    "lat": "51.22423",
    "lng": "13.90935"
  },
  {
    "country": "DE",
    "name": "Höchst im Odenwald",
    "lat": "49.79972",
    "lng": "8.99944"
  },
  {
    "country": "DE",
    "name": "Höchstädt bei Thiersheim",
    "lat": "50.10157",
    "lng": "12.08711"
  },
  {
    "country": "DE",
    "name": "Höchstädt an der Donau",
    "lat": "48.61124",
    "lng": "10.56816"
  },
  {
    "country": "DE",
    "name": "Hochstadt am Main",
    "lat": "50.15009",
    "lng": "11.17116"
  },
  {
    "country": "DE",
    "name": "Höchstadt an der Aisch",
    "lat": "49.70617",
    "lng": "10.81329"
  },
  {
    "country": "DE",
    "name": "Hochspeyer",
    "lat": "49.44207",
    "lng": "7.89504"
  },
  {
    "country": "DE",
    "name": "Hochkirch",
    "lat": "51.14898",
    "lng": "14.57063"
  },
  {
    "country": "DE",
    "name": "Hochheim am Main",
    "lat": "50.01436",
    "lng": "8.35218"
  },
  {
    "country": "DE",
    "name": "Höchheim",
    "lat": "50.36667",
    "lng": "10.45"
  },
  {
    "country": "DE",
    "name": "Hochfeld",
    "lat": "51.41943",
    "lng": "6.75462"
  },
  {
    "country": "DE",
    "name": "Höchenschwand",
    "lat": "47.73333",
    "lng": "8.16667"
  },
  {
    "country": "DE",
    "name": "Hochdorf",
    "lat": "48.69283",
    "lng": "9.46494"
  },
  {
    "country": "DE",
    "name": "Hochdorf",
    "lat": "48.0256",
    "lng": "9.78778"
  },
  {
    "country": "DE",
    "name": "Hochdonn",
    "lat": "54.02663",
    "lng": "9.27624"
  },
  {
    "country": "DE",
    "name": "Höchberg",
    "lat": "49.78446",
    "lng": "9.88223"
  },
  {
    "country": "DE",
    "name": "Hitzhusen",
    "lat": "53.92397",
    "lng": "9.85262"
  },
  {
    "country": "DE",
    "name": "Hitzacker",
    "lat": "53.15254",
    "lng": "11.04418"
  },
  {
    "country": "DE",
    "name": "Hirzenhain",
    "lat": "50.4",
    "lng": "9.13333"
  },
  {
    "country": "DE",
    "name": "Hirschhorn",
    "lat": "49.44566",
    "lng": "8.89594"
  },
  {
    "country": "DE",
    "name": "Hirschfelde",
    "lat": "50.94437",
    "lng": "14.8851"
  },
  {
    "country": "DE",
    "name": "Hirschfeld",
    "lat": "51.38333",
    "lng": "13.61667"
  },
  {
    "country": "DE",
    "name": "Hirschfeld",
    "lat": "50.62453",
    "lng": "12.45722"
  },
  {
    "country": "DE",
    "name": "Hirschbach",
    "lat": "49.55",
    "lng": "11.53333"
  },
  {
    "country": "DE",
    "name": "Hirschau",
    "lat": "49.54396",
    "lng": "11.94617"
  },
  {
    "country": "DE",
    "name": "Hirschaid",
    "lat": "49.81789",
    "lng": "10.98918"
  },
  {
    "country": "DE",
    "name": "Hirrlingen",
    "lat": "48.41245",
    "lng": "8.88742"
  },
  {
    "country": "DE",
    "name": "Hipstedt",
    "lat": "53.48333",
    "lng": "8.96667"
  },
  {
    "country": "DE",
    "name": "Hinterzarten",
    "lat": "47.90276",
    "lng": "8.10701"
  },
  {
    "country": "DE",
    "name": "Hinterweidenthal",
    "lat": "49.2",
    "lng": "7.75"
  },
  {
    "country": "DE",
    "name": "Hinterschmiding",
    "lat": "48.82337",
    "lng": "13.60369"
  },
  {
    "country": "DE",
    "name": "Hinte",
    "lat": "53.41667",
    "lng": "7.18333"
  },
  {
    "country": "DE",
    "name": "Himmelstadt",
    "lat": "49.92389",
    "lng": "9.80167"
  },
  {
    "country": "DE",
    "name": "Himmelpforten",
    "lat": "53.61413",
    "lng": "9.30516"
  },
  {
    "country": "DE",
    "name": "Himmelkron",
    "lat": "50.06667",
    "lng": "11.6"
  },
  {
    "country": "DE",
    "name": "Himbergen",
    "lat": "53.09418",
    "lng": "10.72909"
  },
  {
    "country": "DE",
    "name": "Hilzingen",
    "lat": "47.76667",
    "lng": "8.78333"
  },
  {
    "country": "DE",
    "name": "Hiltpoltstein",
    "lat": "49.66075",
    "lng": "11.32272"
  },
  {
    "country": "DE",
    "name": "Hilter",
    "lat": "52.13573",
    "lng": "8.14715"
  },
  {
    "country": "DE",
    "name": "Hiltenfingen",
    "lat": "48.16085",
    "lng": "10.7175"
  },
  {
    "country": "DE",
    "name": "Hilpoltstein",
    "lat": "49.19047",
    "lng": "11.1906"
  },
  {
    "country": "DE",
    "name": "Hillscheid",
    "lat": "50.40639",
    "lng": "7.69861"
  },
  {
    "country": "DE",
    "name": "Hillesheim",
    "lat": "50.29177",
    "lng": "6.66963"
  },
  {
    "country": "DE",
    "name": "Hillerse",
    "lat": "51.68558",
    "lng": "9.94973"
  },
  {
    "country": "DE",
    "name": "Hille",
    "lat": "52.33333",
    "lng": "8.75"
  },
  {
    "country": "DE",
    "name": "Hilgertshausen-Tandern",
    "lat": "48.4296",
    "lng": "11.35428"
  },
  {
    "country": "DE",
    "name": "Hilgert",
    "lat": "50.45634",
    "lng": "7.68735"
  },
  {
    "country": "DE",
    "name": "Hilgermissen",
    "lat": "52.85",
    "lng": "9.16667"
  },
  {
    "country": "DE",
    "name": "Hildrizhausen",
    "lat": "48.62423",
    "lng": "8.96605"
  },
  {
    "country": "DE",
    "name": "Hildesheim",
    "lat": "52.15077",
    "lng": "9.95112"
  },
  {
    "country": "DE",
    "name": "Hilders",
    "lat": "50.5719",
    "lng": "10.00297"
  },
  {
    "country": "DE",
    "name": "Hilden",
    "lat": "51.16818",
    "lng": "6.93093"
  },
  {
    "country": "DE",
    "name": "Hildburghausen",
    "lat": "50.42553",
    "lng": "10.73184"
  },
  {
    "country": "DE",
    "name": "Hilchenbach",
    "lat": "50.99687",
    "lng": "8.11062"
  },
  {
    "country": "DE",
    "name": "Hilbersdorf",
    "lat": "50.854",
    "lng": "12.94776"
  },
  {
    "country": "DE",
    "name": "Hiddenhausen",
    "lat": "52.16667",
    "lng": "8.61667"
  },
  {
    "country": "DE",
    "name": "Heyersum",
    "lat": "52.15678",
    "lng": "9.81265"
  },
  {
    "country": "DE",
    "name": "Heyerode",
    "lat": "51.16439",
    "lng": "10.32009"
  },
  {
    "country": "DE",
    "name": "Heusweiler",
    "lat": "49.33632",
    "lng": "6.93036"
  },
  {
    "country": "DE",
    "name": "Heustreu",
    "lat": "50.35485",
    "lng": "10.26069"
  },
  {
    "country": "DE",
    "name": "Heusenstamm",
    "lat": "50.05553",
    "lng": "8.80076"
  },
  {
    "country": "DE",
    "name": "Heuerßen",
    "lat": "52.32946",
    "lng": "9.27718"
  },
  {
    "country": "DE",
    "name": "Heudeber",
    "lat": "51.90245",
    "lng": "10.84321"
  },
  {
    "country": "DE",
    "name": "Heuchlingen",
    "lat": "48.85215",
    "lng": "9.94391"
  },
  {
    "country": "DE",
    "name": "Heuchelheim bei Frankenthal",
    "lat": "49.56306",
    "lng": "8.29083"
  },
  {
    "country": "DE",
    "name": "Heuchelheim",
    "lat": "50.58333",
    "lng": "8.63333"
  },
  {
    "country": "DE",
    "name": "Heubach",
    "lat": "48.79267",
    "lng": "9.9337"
  },
  {
    "country": "DE",
    "name": "Hetzles",
    "lat": "49.63333",
    "lng": "11.13333"
  },
  {
    "country": "DE",
    "name": "Hetzerath",
    "lat": "49.88333",
    "lng": "6.81667"
  },
  {
    "country": "DE",
    "name": "Hettstedt",
    "lat": "51.6503",
    "lng": "11.51146"
  },
  {
    "country": "DE",
    "name": "Hettstadt",
    "lat": "49.79944",
    "lng": "9.815"
  },
  {
    "country": "DE",
    "name": "Hettingen",
    "lat": "48.21601",
    "lng": "9.23169"
  },
  {
    "country": "DE",
    "name": "Hettenshausen",
    "lat": "48.5",
    "lng": "11.5"
  },
  {
    "country": "DE",
    "name": "Hettenleidelheim",
    "lat": "49.53556",
    "lng": "8.07361"
  },
  {
    "country": "DE",
    "name": "Hetlingen",
    "lat": "53.60712",
    "lng": "9.63718"
  },
  {
    "country": "DE",
    "name": "Hessisch Oldendorf",
    "lat": "52.17269",
    "lng": "9.24913"
  },
  {
    "country": "DE",
    "name": "Hessisch Lichtenau",
    "lat": "51.19954",
    "lng": "9.71857"
  },
  {
    "country": "DE",
    "name": "Hessigheim",
    "lat": "48.99407",
    "lng": "9.18629"
  },
  {
    "country": "DE",
    "name": "Heßheim",
    "lat": "49.54583",
    "lng": "8.30778"
  },
  {
    "country": "DE",
    "name": "Heßdorf",
    "lat": "49.62728",
    "lng": "10.91002"
  },
  {
    "country": "DE",
    "name": "Hespe",
    "lat": "52.32999",
    "lng": "9.10818"
  },
  {
    "country": "DE",
    "name": "Hesel",
    "lat": "53.3",
    "lng": "7.6"
  },
  {
    "country": "DE",
    "name": "Herzogenrath",
    "lat": "50.86874",
    "lng": "6.09317"
  },
  {
    "country": "DE",
    "name": "Herzogenaurach",
    "lat": "49.56798",
    "lng": "10.88565"
  },
  {
    "country": "DE",
    "name": "Herzlake",
    "lat": "52.6853",
    "lng": "7.59946"
  },
  {
    "country": "DE",
    "name": "Herzhorn",
    "lat": "53.78333",
    "lng": "9.48333"
  },
  {
    "country": "DE",
    "name": "Herzberg am Harz",
    "lat": "51.65546",
    "lng": "10.33938"
  },
  {
    "country": "DE",
    "name": "Herzberg",
    "lat": "51.68692",
    "lng": "13.22016"
  },
  {
    "country": "DE",
    "name": "Herxheim am Berg",
    "lat": "49.50917",
    "lng": "8.17917"
  },
  {
    "country": "DE",
    "name": "Herten",
    "lat": "51.59638",
    "lng": "7.14387"
  },
  {
    "country": "DE",
    "name": "Herschweiler-Pettersheim",
    "lat": "49.48333",
    "lng": "7.35"
  },
  {
    "country": "DE",
    "name": "Herscheid",
    "lat": "51.17901",
    "lng": "7.74355"
  },
  {
    "country": "DE",
    "name": "Herschdorf",
    "lat": "50.71168",
    "lng": "11.53736"
  },
  {
    "country": "DE",
    "name": "Hersbruck",
    "lat": "49.51083",
    "lng": "11.43151"
  },
  {
    "country": "DE",
    "name": "Herrsching am Ammersee",
    "lat": "47.99888",
    "lng": "11.17679"
  },
  {
    "country": "DE",
    "name": "Herrnhut",
    "lat": "51.01624",
    "lng": "14.74381"
  },
  {
    "country": "DE",
    "name": "Herrngiersdorf",
    "lat": "48.78863",
    "lng": "12.072"
  },
  {
    "country": "DE",
    "name": "Herrischried",
    "lat": "47.66667",
    "lng": "8"
  },
  {
    "country": "DE",
    "name": "Herrieden",
    "lat": "49.23779",
    "lng": "10.5035"
  },
  {
    "country": "DE",
    "name": "Herrenberg",
    "lat": "48.59523",
    "lng": "8.86648"
  },
  {
    "country": "DE",
    "name": "Heroldsberg",
    "lat": "49.53247",
    "lng": "11.15551"
  },
  {
    "country": "DE",
    "name": "Heroldsbach",
    "lat": "49.69342",
    "lng": "10.99882"
  },
  {
    "country": "DE",
    "name": "Herne",
    "lat": "51.5388",
    "lng": "7.22572"
  },
  {
    "country": "DE",
    "name": "Hermsdorf",
    "lat": "52.61131",
    "lng": "13.31783"
  },
  {
    "country": "DE",
    "name": "Hermsdorf",
    "lat": "52.1874",
    "lng": "11.47556"
  },
  {
    "country": "DE",
    "name": "Hermsdorf",
    "lat": "50.92338",
    "lng": "13.7348"
  },
  {
    "country": "DE",
    "name": "Hermsdorf",
    "lat": "50.89694",
    "lng": "11.85549"
  },
  {
    "country": "DE",
    "name": "Hermeskeil",
    "lat": "49.65528",
    "lng": "6.94407"
  },
  {
    "country": "DE",
    "name": "Hermersberg",
    "lat": "49.31667",
    "lng": "7.63333"
  },
  {
    "country": "DE",
    "name": "Hermaringen",
    "lat": "48.59544",
    "lng": "10.26065"
  },
  {
    "country": "DE",
    "name": "Hermannsburg",
    "lat": "52.83254",
    "lng": "10.08957"
  },
  {
    "country": "DE",
    "name": "Herleshausen",
    "lat": "51.00629",
    "lng": "10.16731"
  },
  {
    "country": "DE",
    "name": "Heringsdorf",
    "lat": "54.301",
    "lng": "11.00658"
  },
  {
    "country": "DE",
    "name": "Heringen",
    "lat": "51.44705",
    "lng": "10.87612"
  },
  {
    "country": "DE",
    "name": "Heringen",
    "lat": "50.88798",
    "lng": "10.00717"
  },
  {
    "country": "DE",
    "name": "Hergisdorf",
    "lat": "51.53333",
    "lng": "11.48333"
  },
  {
    "country": "DE",
    "name": "Hergensweiler",
    "lat": "47.61667",
    "lng": "9.78333"
  },
  {
    "country": "DE",
    "name": "Herforst",
    "lat": "49.95",
    "lng": "6.7"
  },
  {
    "country": "DE",
    "name": "Herford",
    "lat": "52.11457",
    "lng": "8.67343"
  },
  {
    "country": "DE",
    "name": "Heretsried",
    "lat": "48.45972",
    "lng": "10.73601"
  },
  {
    "country": "DE",
    "name": "Herdorf",
    "lat": "50.77704",
    "lng": "7.95366"
  },
  {
    "country": "DE",
    "name": "Herdecke",
    "lat": "51.39999",
    "lng": "7.43584"
  },
  {
    "country": "DE",
    "name": "Herbstein",
    "lat": "50.56105",
    "lng": "9.34592"
  },
  {
    "country": "DE",
    "name": "Herbsleben",
    "lat": "51.11667",
    "lng": "10.83333"
  },
  {
    "country": "DE",
    "name": "Herbrechtingen",
    "lat": "48.62173",
    "lng": "10.176"
  },
  {
    "country": "DE",
    "name": "Herborn",
    "lat": "50.68135",
    "lng": "8.30369"
  },
  {
    "country": "DE",
    "name": "Herbolzheim",
    "lat": "48.21884",
    "lng": "7.77746"
  },
  {
    "country": "DE",
    "name": "Herbertingen",
    "lat": "48.06667",
    "lng": "9.43333"
  },
  {
    "country": "DE",
    "name": "Hepstedt",
    "lat": "53.25874",
    "lng": "9.08209"
  },
  {
    "country": "DE",
    "name": "Heppenheim an der Bergstrasse",
    "lat": "49.64145",
    "lng": "8.63206"
  },
  {
    "country": "DE",
    "name": "Hennweiler",
    "lat": "49.81667",
    "lng": "7.43333"
  },
  {
    "country": "DE",
    "name": "Hennstedt",
    "lat": "54.28333",
    "lng": "9.16667"
  },
  {
    "country": "DE",
    "name": "Hennigsdorf",
    "lat": "52.63598",
    "lng": "13.20419"
  },
  {
    "country": "DE",
    "name": "Hennef",
    "lat": "50.77555",
    "lng": "7.28308"
  },
  {
    "country": "DE",
    "name": "Hengersberg",
    "lat": "48.77255",
    "lng": "13.05485"
  },
  {
    "country": "DE",
    "name": "Henfenfeld",
    "lat": "49.49846",
    "lng": "11.39059"
  },
  {
    "country": "DE",
    "name": "Hendungen",
    "lat": "50.39462",
    "lng": "10.35204"
  },
  {
    "country": "DE",
    "name": "Hemslingen",
    "lat": "53.08333",
    "lng": "9.6"
  },
  {
    "country": "DE",
    "name": "Hemsbünde",
    "lat": "53.08998",
    "lng": "9.47261"
  },
  {
    "country": "DE",
    "name": "Hemsbach",
    "lat": "49.59075",
    "lng": "8.64779"
  },
  {
    "country": "DE",
    "name": "Hemmoor",
    "lat": "53.68702",
    "lng": "9.15492"
  },
  {
    "country": "DE",
    "name": "Hemmingstedt",
    "lat": "54.15",
    "lng": "9.06667"
  },
  {
    "country": "DE",
    "name": "Hemmingen",
    "lat": "52.31425",
    "lng": "9.72359"
  },
  {
    "country": "DE",
    "name": "Hemmingen",
    "lat": "48.86667",
    "lng": "9.03333"
  },
  {
    "country": "DE",
    "name": "Hemhofen",
    "lat": "49.68333",
    "lng": "10.93333"
  },
  {
    "country": "DE",
    "name": "Hemer",
    "lat": "51.38707",
    "lng": "7.77019"
  },
  {
    "country": "DE",
    "name": "Hemdingen",
    "lat": "53.76667",
    "lng": "9.83333"
  },
  {
    "country": "DE",
    "name": "Hemau",
    "lat": "49.05399",
    "lng": "11.78195"
  },
  {
    "country": "DE",
    "name": "Heltersberg",
    "lat": "49.31667",
    "lng": "7.71667"
  },
  {
    "country": "DE",
    "name": "Helsa",
    "lat": "51.25981",
    "lng": "9.68872"
  },
  {
    "country": "DE",
    "name": "Helpsen",
    "lat": "52.31131",
    "lng": "9.11676"
  },
  {
    "country": "DE",
    "name": "Helmstedt",
    "lat": "52.2279",
    "lng": "11.00985"
  },
  {
    "country": "DE",
    "name": "Helmstadt",
    "lat": "49.7618",
    "lng": "9.70803"
  },
  {
    "country": "DE",
    "name": "Helmbrechts",
    "lat": "50.23557",
    "lng": "11.71589"
  },
  {
    "country": "DE",
    "name": "Hellwege",
    "lat": "53.07346",
    "lng": "9.23566"
  },
  {
    "country": "DE",
    "name": "Hellingen",
    "lat": "50.25",
    "lng": "10.68333"
  },
  {
    "country": "DE",
    "name": "Hellersdorf",
    "lat": "52.53319",
    "lng": "13.6088"
  },
  {
    "country": "DE",
    "name": "Hellenthal",
    "lat": "50.48333",
    "lng": "6.43333"
  },
  {
    "country": "DE",
    "name": "Hellenhahn-Schellenberg",
    "lat": "50.61278",
    "lng": "8.02639"
  },
  {
    "country": "DE",
    "name": "Helferskirchen",
    "lat": "50.51028",
    "lng": "7.81184"
  },
  {
    "country": "DE",
    "name": "Heldrungen",
    "lat": "51.30208",
    "lng": "11.21816"
  },
  {
    "country": "DE",
    "name": "Helbra",
    "lat": "51.55",
    "lng": "11.5"
  },
  {
    "country": "DE",
    "name": "Heitersheim",
    "lat": "47.87468",
    "lng": "7.65721"
  },
  {
    "country": "DE",
    "name": "Heistenbach",
    "lat": "50.37933",
    "lng": "7.98629"
  },
  {
    "country": "DE",
    "name": "Heist",
    "lat": "53.65",
    "lng": "9.65"
  },
  {
    "country": "DE",
    "name": "Heinsen",
    "lat": "52.06257",
    "lng": "9.66316"
  },
  {
    "country": "DE",
    "name": "Heinsberg",
    "lat": "51.06358",
    "lng": "6.0998"
  },
  {
    "country": "DE",
    "name": "Heiningen",
    "lat": "48.66177",
    "lng": "9.64977"
  },
  {
    "country": "DE",
    "name": "Heinersdorf",
    "lat": "52.57173",
    "lng": "13.43757"
  },
  {
    "country": "DE",
    "name": "Heinböckel",
    "lat": "53.57457",
    "lng": "9.32644"
  },
  {
    "country": "DE",
    "name": "Heinade",
    "lat": "51.83333",
    "lng": "9.63333"
  },
  {
    "country": "DE",
    "name": "Heimsheim",
    "lat": "48.80656",
    "lng": "8.86744"
  },
  {
    "country": "DE",
    "name": "Heimertingen",
    "lat": "48.03333",
    "lng": "10.15"
  },
  {
    "country": "DE",
    "name": "Heimenkirch",
    "lat": "47.62959",
    "lng": "9.90304"
  },
  {
    "country": "DE",
    "name": "Heimbuchenthal",
    "lat": "49.88917",
    "lng": "9.29556"
  },
  {
    "country": "DE",
    "name": "Heimbach",
    "lat": "50.63693",
    "lng": "6.46896"
  },
  {
    "country": "DE",
    "name": "Heimbach",
    "lat": "50.45",
    "lng": "7.53333"
  },
  {
    "country": "DE",
    "name": "Heilsbronn",
    "lat": "49.33572",
    "lng": "10.78741"
  },
  {
    "country": "DE",
    "name": "Heiligkreuzsteinach",
    "lat": "49.48333",
    "lng": "8.795"
  },
  {
    "country": "DE",
    "name": "Heiligenstedten",
    "lat": "53.93264",
    "lng": "9.47462"
  },
  {
    "country": "DE",
    "name": "Heilbad Heiligenstadt",
    "lat": "51.37819",
    "lng": "10.13744"
  },
  {
    "country": "DE",
    "name": "Heiligenstadt",
    "lat": "49.86303",
    "lng": "11.17185"
  },
  {
    "country": "DE",
    "name": "Heiligensee",
    "lat": "52.61449",
    "lng": "13.24501"
  },
  {
    "country": "DE",
    "name": "Heiligenroth",
    "lat": "50.45",
    "lng": "7.86667"
  },
  {
    "country": "DE",
    "name": "Heiligenhaus",
    "lat": "51.32662",
    "lng": "6.97106"
  },
  {
    "country": "DE",
    "name": "Heiligenhafen",
    "lat": "54.36964",
    "lng": "10.98022"
  },
  {
    "country": "DE",
    "name": "Heiligengrabe",
    "lat": "53.14461",
    "lng": "12.36254"
  },
  {
    "country": "DE",
    "name": "Heiligenberg",
    "lat": "47.82094",
    "lng": "9.3128"
  },
  {
    "country": "DE",
    "name": "Heilbronn",
    "lat": "49.13995",
    "lng": "9.22054"
  },
  {
    "country": "DE",
    "name": "Heikendorf",
    "lat": "54.36667",
    "lng": "10.2"
  },
  {
    "country": "DE",
    "name": "Heigenbrücken",
    "lat": "50.0282",
    "lng": "9.37116"
  },
  {
    "country": "DE",
    "name": "Heidgraben",
    "lat": "53.70787",
    "lng": "9.68099"
  },
  {
    "country": "DE",
    "name": "Heidesheim",
    "lat": "49.58247",
    "lng": "8.19537"
  },
  {
    "country": "DE",
    "name": "Heidenheim an der Brenz",
    "lat": "48.67798",
    "lng": "10.15162"
  },
  {
    "country": "DE",
    "name": "Heidenheim",
    "lat": "49.01719",
    "lng": "10.74347"
  },
  {
    "country": "DE",
    "name": "Heidenau",
    "lat": "53.31667",
    "lng": "9.66667"
  },
  {
    "country": "DE",
    "name": "Heidenau",
    "lat": "50.97221",
    "lng": "13.86741"
  },
  {
    "country": "DE",
    "name": "Heiden",
    "lat": "51.83333",
    "lng": "6.93333"
  },
  {
    "country": "DE",
    "name": "Heidelberg",
    "lat": "49.40768",
    "lng": "8.69079"
  },
  {
    "country": "DE",
    "name": "Heideck",
    "lat": "49.13365",
    "lng": "11.12726"
  },
  {
    "country": "DE",
    "name": "Heide",
    "lat": "54.19579",
    "lng": "9.0988"
  },
  {
    "country": "DE",
    "name": "Hehlen",
    "lat": "51.98858",
    "lng": "9.47004"
  },
  {
    "country": "DE",
    "name": "Heeßen",
    "lat": "52.23211",
    "lng": "9.09642"
  },
  {
    "country": "DE",
    "name": "Heeslingen",
    "lat": "53.31667",
    "lng": "9.33333"
  },
  {
    "country": "DE",
    "name": "Heemsen",
    "lat": "52.7",
    "lng": "9.26667"
  },
  {
    "country": "DE",
    "name": "Heek",
    "lat": "52.11667",
    "lng": "7.1"
  },
  {
    "country": "DE",
    "name": "Heede",
    "lat": "52.99205",
    "lng": "7.2983"
  },
  {
    "country": "DE",
    "name": "Hedersleben",
    "lat": "51.85943",
    "lng": "11.25"
  },
  {
    "country": "DE",
    "name": "Hedersleben",
    "lat": "51.54891",
    "lng": "11.64983"
  },
  {
    "country": "DE",
    "name": "Heddesheim",
    "lat": "49.50556",
    "lng": "8.60361"
  },
  {
    "country": "DE",
    "name": "Hecklingen",
    "lat": "51.84705",
    "lng": "11.53416"
  },
  {
    "country": "DE",
    "name": "Hechthausen",
    "lat": "53.64041",
    "lng": "9.23942"
  },
  {
    "country": "DE",
    "name": "Hechingen",
    "lat": "48.35149",
    "lng": "8.96317"
  },
  {
    "country": "DE",
    "name": "Hebertshausen",
    "lat": "48.28959",
    "lng": "11.46526"
  },
  {
    "country": "DE",
    "name": "Hebertsfelden",
    "lat": "48.40596",
    "lng": "12.82259"
  },
  {
    "country": "DE",
    "name": "Hayingen",
    "lat": "48.27531",
    "lng": "9.4776"
  },
  {
    "country": "DE",
    "name": "Hawangen",
    "lat": "47.96667",
    "lng": "10.26667"
  },
  {
    "country": "DE",
    "name": "Havixbeck",
    "lat": "51.98333",
    "lng": "7.41667"
  },
  {
    "country": "DE",
    "name": "Haverlah",
    "lat": "52.06667",
    "lng": "10.16667"
  },
  {
    "country": "DE",
    "name": "Havelberg",
    "lat": "52.83088",
    "lng": "12.07552"
  },
  {
    "country": "DE",
    "name": "Hauzenberg",
    "lat": "48.64957",
    "lng": "13.62645"
  },
  {
    "country": "DE",
    "name": "Hauswalde",
    "lat": "51.15212",
    "lng": "14.0863"
  },
  {
    "country": "DE",
    "name": "Hausham",
    "lat": "47.7466",
    "lng": "11.84069"
  },
  {
    "country": "DE",
    "name": "Häusern",
    "lat": "47.75",
    "lng": "8.16667"
  },
  {
    "country": "DE",
    "name": "Hausen",
    "lat": "50.54242",
    "lng": "7.40703"
  },
  {
    "country": "DE",
    "name": "Hausen",
    "lat": "49.86972",
    "lng": "9.21028"
  },
  {
    "country": "DE",
    "name": "Hausen",
    "lat": "49.68945",
    "lng": "11.03216"
  },
  {
    "country": "DE",
    "name": "Hausen",
    "lat": "48.85953",
    "lng": "12.0063"
  },
  {
    "country": "DE",
    "name": "Hausen",
    "lat": "47.68128",
    "lng": "7.83986"
  },
  {
    "country": "DE",
    "name": "Hausach",
    "lat": "48.28426",
    "lng": "8.17602"
  },
  {
    "country": "DE",
    "name": "Hauptstuhl",
    "lat": "49.4",
    "lng": "7.48333"
  },
  {
    "country": "DE",
    "name": "Haunsheim",
    "lat": "48.59977",
    "lng": "10.37401"
  },
  {
    "country": "DE",
    "name": "Haundorf",
    "lat": "49.17598",
    "lng": "10.77124"
  },
  {
    "country": "DE",
    "name": "Hauenstein",
    "lat": "49.19211",
    "lng": "7.85492"
  },
  {
    "country": "DE",
    "name": "Hatzfeld",
    "lat": "50.99334",
    "lng": "8.5457"
  },
  {
    "country": "DE",
    "name": "Hatzenbühl",
    "lat": "49.11111",
    "lng": "8.24528"
  },
  {
    "country": "DE",
    "name": "Hattstedt",
    "lat": "54.53333",
    "lng": "9.03333"
  },
  {
    "country": "DE",
    "name": "Hattorf",
    "lat": "51.65035",
    "lng": "10.23681"
  },
  {
    "country": "DE",
    "name": "Hattingen",
    "lat": "51.39894",
    "lng": "7.18557"
  },
  {
    "country": "DE",
    "name": "Hattersheim",
    "lat": "50.07854",
    "lng": "8.47552"
  },
  {
    "country": "DE",
    "name": "Hattenhofen",
    "lat": "48.66648",
    "lng": "9.57456"
  },
  {
    "country": "DE",
    "name": "Hattenhofen",
    "lat": "48.22231",
    "lng": "11.11551"
  },
  {
    "country": "DE",
    "name": "Hatten",
    "lat": "53.05",
    "lng": "8.38333"
  },
  {
    "country": "DE",
    "name": "Haste",
    "lat": "52.38105",
    "lng": "9.3928"
  },
  {
    "country": "DE",
    "name": "Haßmersheim",
    "lat": "49.3",
    "lng": "9.15"
  },
  {
    "country": "DE",
    "name": "Haßloch",
    "lat": "49.36278",
    "lng": "8.25806"
  },
  {
    "country": "DE",
    "name": "Haßleben",
    "lat": "51.10878",
    "lng": "10.99637"
  },
  {
    "country": "DE",
    "name": "Haßfurt",
    "lat": "50.03521",
    "lng": "10.5156"
  },
  {
    "country": "DE",
    "name": "Hassendorf",
    "lat": "53.10859",
    "lng": "9.26482"
  },
  {
    "country": "DE",
    "name": "Hasselfelde",
    "lat": "51.69051",
    "lng": "10.85373"
  },
  {
    "country": "DE",
    "name": "Hassel",
    "lat": "52.69688",
    "lng": "8.83198"
  },
  {
    "country": "DE",
    "name": "Haßbergen",
    "lat": "52.73333",
    "lng": "9.23333"
  },
  {
    "country": "DE",
    "name": "Hasloh",
    "lat": "53.69471",
    "lng": "9.91682"
  },
  {
    "country": "DE",
    "name": "Hasloch",
    "lat": "49.79194",
    "lng": "9.49361"
  },
  {
    "country": "DE",
    "name": "Haslach",
    "lat": "48.56531",
    "lng": "8.05658"
  },
  {
    "country": "DE",
    "name": "Haselünne",
    "lat": "52.67412",
    "lng": "7.4846"
  },
  {
    "country": "DE",
    "name": "Haselhorst",
    "lat": "52.54409",
    "lng": "13.23743"
  },
  {
    "country": "DE",
    "name": "Haseldorf",
    "lat": "53.6378",
    "lng": "9.59151"
  },
  {
    "country": "DE",
    "name": "Haselbach",
    "lat": "48.64564",
    "lng": "13.38956"
  },
  {
    "country": "DE",
    "name": "Haselau",
    "lat": "53.66181",
    "lng": "9.6201"
  },
  {
    "country": "DE",
    "name": "Hasel",
    "lat": "47.65342",
    "lng": "7.8972"
  },
  {
    "country": "DE",
    "name": "Hasbergen",
    "lat": "52.23754",
    "lng": "7.96114"
  },
  {
    "country": "DE",
    "name": "Harzgerode",
    "lat": "51.64189",
    "lng": "11.1433"
  },
  {
    "country": "DE",
    "name": "Harxheim",
    "lat": "49.90528",
    "lng": "8.26417"
  },
  {
    "country": "DE",
    "name": "Hartmannsdorf",
    "lat": "50.9",
    "lng": "12.8"
  },
  {
    "country": "DE",
    "name": "Hartmannsdorf",
    "lat": "50.75804",
    "lng": "12.42687"
  },
  {
    "country": "DE",
    "name": "Hartheim",
    "lat": "47.93333",
    "lng": "7.63333"
  },
  {
    "country": "DE",
    "name": "Harthausen",
    "lat": "49.29417",
    "lng": "8.345"
  },
  {
    "country": "DE",
    "name": "Hartha",
    "lat": "51.09863",
    "lng": "12.97391"
  },
  {
    "country": "DE",
    "name": "Hartenstein",
    "lat": "50.66236",
    "lng": "12.66966"
  },
  {
    "country": "DE",
    "name": "Hartenstein",
    "lat": "49.6",
    "lng": "11.51667"
  },
  {
    "country": "DE",
    "name": "Hartenholm",
    "lat": "53.89856",
    "lng": "10.05953"
  },
  {
    "country": "DE",
    "name": "Harsum",
    "lat": "52.21045",
    "lng": "9.96486"
  },
  {
    "country": "DE",
    "name": "Harsleben",
    "lat": "51.86667",
    "lng": "11.1"
  },
  {
    "country": "DE",
    "name": "Harsewinkel",
    "lat": "51.96224",
    "lng": "8.22766"
  },
  {
    "country": "DE",
    "name": "Harsefeld",
    "lat": "53.45399",
    "lng": "9.50297"
  },
  {
    "country": "DE",
    "name": "Harsdorf",
    "lat": "50.03333",
    "lng": "11.56667"
  },
  {
    "country": "DE",
    "name": "Harrislee",
    "lat": "54.8",
    "lng": "9.38333"
  },
  {
    "country": "DE",
    "name": "Harpstedt",
    "lat": "52.90942",
    "lng": "8.58962"
  },
  {
    "country": "DE",
    "name": "Hargesheim",
    "lat": "49.8623",
    "lng": "7.82881"
  },
  {
    "country": "DE",
    "name": "Haren",
    "lat": "52.79262",
    "lng": "7.24142"
  },
  {
    "country": "DE",
    "name": "Hardt",
    "lat": "48.18333",
    "lng": "8.41667"
  },
  {
    "country": "DE",
    "name": "Hardheim",
    "lat": "49.61194",
    "lng": "9.47194"
  },
  {
    "country": "DE",
    "name": "Hardegsen",
    "lat": "51.65227",
    "lng": "9.8305"
  },
  {
    "country": "DE",
    "name": "Harburg",
    "lat": "53.46057",
    "lng": "9.98388"
  },
  {
    "country": "DE",
    "name": "Harburg",
    "lat": "48.78674",
    "lng": "10.68927"
  },
  {
    "country": "DE",
    "name": "Harbke",
    "lat": "52.18877",
    "lng": "11.04624"
  },
  {
    "country": "DE",
    "name": "Happurg",
    "lat": "49.49372",
    "lng": "11.47119"
  },
  {
    "country": "DE",
    "name": "Hanstedt Eins",
    "lat": "53.04642",
    "lng": "10.37444"
  },
  {
    "country": "DE",
    "name": "Hanstedt",
    "lat": "53.26667",
    "lng": "10.01667"
  },
  {
    "country": "DE",
    "name": "Hannover",
    "lat": "52.37052",
    "lng": "9.73322"
  },
  {
    "country": "DE",
    "name": "Hankensbüttel",
    "lat": "52.73333",
    "lng": "10.6"
  },
  {
    "country": "DE",
    "name": "Hänigsen",
    "lat": "52.48425",
    "lng": "10.09129"
  },
  {
    "country": "DE",
    "name": "Hanhofen",
    "lat": "49.31667",
    "lng": "8.34083"
  },
  {
    "country": "DE",
    "name": "Hangard",
    "lat": "49.3826",
    "lng": "7.21046"
  },
  {
    "country": "DE",
    "name": "Hanerau-Hademarschen",
    "lat": "54.13333",
    "lng": "9.41667"
  },
  {
    "country": "DE",
    "name": "Handorf",
    "lat": "53.34084",
    "lng": "10.34652"
  },
  {
    "country": "DE",
    "name": "Handewitt",
    "lat": "54.76667",
    "lng": "9.33333"
  },
  {
    "country": "DE",
    "name": "Handeloh",
    "lat": "53.24563",
    "lng": "9.83923"
  },
  {
    "country": "DE",
    "name": "Hanau am Main",
    "lat": "50.13423",
    "lng": "8.91418"
  },
  {
    "country": "DE",
    "name": "Hammoor",
    "lat": "53.71378",
    "lng": "10.322"
  },
  {
    "country": "DE",
    "name": "Hamminkeln",
    "lat": "51.73262",
    "lng": "6.59031"
  },
  {
    "country": "DE",
    "name": "Hammersbach",
    "lat": "50.21667",
    "lng": "8.98333"
  },
  {
    "country": "DE",
    "name": "Hammerbrücke",
    "lat": "50.43504",
    "lng": "12.415"
  },
  {
    "country": "DE",
    "name": "Hammelburg",
    "lat": "50.11633",
    "lng": "9.89143"
  },
  {
    "country": "DE",
    "name": "Hammah",
    "lat": "53.61667",
    "lng": "9.36667"
  },
  {
    "country": "DE",
    "name": "Hamm",
    "lat": "51.68033",
    "lng": "7.82089"
  },
  {
    "country": "DE",
    "name": "Hamm",
    "lat": "50.76531",
    "lng": "7.67761"
  },
  {
    "country": "DE",
    "name": "Hameln",
    "lat": "52.10397",
    "lng": "9.35623"
  },
  {
    "country": "DE",
    "name": "Hamdorf",
    "lat": "54.22522",
    "lng": "9.51866"
  },
  {
    "country": "DE",
    "name": "Wandsbek",
    "lat": "53.58334",
    "lng": "10.08305"
  },
  {
    "country": "DE",
    "name": "Marienthal",
    "lat": "53.56667",
    "lng": "10.08333"
  },
  {
    "country": "DE",
    "name": "Hamburg-Mitte",
    "lat": "53.55",
    "lng": "10.01667"
  },
  {
    "country": "DE",
    "name": "Eimsbüttel",
    "lat": "53.57416",
    "lng": "9.95679"
  },
  {
    "country": "DE",
    "name": "Altona",
    "lat": "53.55",
    "lng": "9.93333"
  },
  {
    "country": "DE",
    "name": "Hamburg",
    "lat": "53.57532",
    "lng": "10.01534"
  },
  {
    "country": "DE",
    "name": "Hambühren",
    "lat": "52.63333",
    "lng": "9.98333"
  },
  {
    "country": "DE",
    "name": "Hambrücken",
    "lat": "49.19",
    "lng": "8.54056"
  },
  {
    "country": "DE",
    "name": "Hambergen",
    "lat": "53.30826",
    "lng": "8.8252"
  },
  {
    "country": "DE",
    "name": "Hamberge",
    "lat": "53.83333",
    "lng": "10.58333"
  },
  {
    "country": "DE",
    "name": "Halver",
    "lat": "51.18612",
    "lng": "7.49817"
  },
  {
    "country": "DE",
    "name": "Haltern",
    "lat": "51.74297",
    "lng": "7.18163"
  },
  {
    "country": "DE",
    "name": "Halstenbek",
    "lat": "53.63333",
    "lng": "9.85"
  },
  {
    "country": "DE",
    "name": "Halsenbach",
    "lat": "50.17174",
    "lng": "7.55673"
  },
  {
    "country": "DE",
    "name": "Halsbrücke",
    "lat": "50.95",
    "lng": "13.35"
  },
  {
    "country": "DE",
    "name": "Hallstadt",
    "lat": "49.92901",
    "lng": "10.87539"
  },
  {
    "country": "DE",
    "name": "Hallerndorf",
    "lat": "49.75909",
    "lng": "10.97946"
  },
  {
    "country": "DE",
    "name": "Hallenberg",
    "lat": "51.11115",
    "lng": "8.62008"
  },
  {
    "country": "DE",
    "name": "Halle",
    "lat": "52.06007",
    "lng": "8.36083"
  },
  {
    "country": "DE",
    "name": "Halle",
    "lat": "51.99122",
    "lng": "9.56532"
  },
  {
    "country": "DE",
    "name": "Halle (Saale)",
    "lat": "51.48158",
    "lng": "11.97947"
  },
  {
    "country": "DE",
    "name": "Hallbergmoos",
    "lat": "48.32747",
    "lng": "11.75142"
  },
  {
    "country": "DE",
    "name": "Halfing",
    "lat": "47.95197",
    "lng": "12.27525"
  },
  {
    "country": "DE",
    "name": "Halensee",
    "lat": "52.49005",
    "lng": "13.29602"
  },
  {
    "country": "DE",
    "name": "Haldenwang",
    "lat": "48.43763",
    "lng": "10.44817"
  },
  {
    "country": "DE",
    "name": "Haldenwang",
    "lat": "47.8",
    "lng": "10.35"
  },
  {
    "country": "DE",
    "name": "Haldensleben I",
    "lat": "52.28906",
    "lng": "11.40982"
  },
  {
    "country": "DE",
    "name": "Halblech",
    "lat": "47.63155",
    "lng": "10.82024"
  },
  {
    "country": "DE",
    "name": "Halberstadt",
    "lat": "51.89562",
    "lng": "11.05622"
  },
  {
    "country": "DE",
    "name": "Halbemond",
    "lat": "53.5671",
    "lng": "7.29038"
  },
  {
    "country": "DE",
    "name": "Halbe",
    "lat": "52.11667",
    "lng": "13.7"
  },
  {
    "country": "DE",
    "name": "Hakenfelde",
    "lat": "52.55877",
    "lng": "13.20831"
  },
  {
    "country": "DE",
    "name": "Haiterbach",
    "lat": "48.52066",
    "lng": "8.64435"
  },
  {
    "country": "DE",
    "name": "Hainsfarth",
    "lat": "48.95839",
    "lng": "10.62491"
  },
  {
    "country": "DE",
    "name": "Hainichen",
    "lat": "50.97044",
    "lng": "13.12287"
  },
  {
    "country": "DE",
    "name": "Hain-Gründau",
    "lat": "50.24284",
    "lng": "9.14287"
  },
  {
    "country": "DE",
    "name": "Hainewalde",
    "lat": "50.91014",
    "lng": "14.70387"
  },
  {
    "country": "DE",
    "name": "Haina",
    "lat": "51.02774",
    "lng": "8.97441"
  },
  {
    "country": "DE",
    "name": "Haina",
    "lat": "50.98971",
    "lng": "10.51774"
  },
  {
    "country": "DE",
    "name": "Haiming",
    "lat": "48.21667",
    "lng": "12.9"
  },
  {
    "country": "DE",
    "name": "Haimhausen",
    "lat": "48.31545",
    "lng": "11.55453"
  },
  {
    "country": "DE",
    "name": "Haigerloch",
    "lat": "48.36614",
    "lng": "8.80357"
  },
  {
    "country": "DE",
    "name": "Haiger",
    "lat": "50.74162",
    "lng": "8.20778"
  },
  {
    "country": "DE",
    "name": "Haidmühle",
    "lat": "48.82565",
    "lng": "13.77649"
  },
  {
    "country": "DE",
    "name": "Haibach",
    "lat": "48.53646",
    "lng": "12.98685"
  },
  {
    "country": "DE",
    "name": "Haibach",
    "lat": "49.96444",
    "lng": "9.20722"
  },
  {
    "country": "DE",
    "name": "Hahnstätten",
    "lat": "50.3",
    "lng": "8.06667"
  },
  {
    "country": "DE",
    "name": "Hähnichen",
    "lat": "51.3654",
    "lng": "14.86098"
  },
  {
    "country": "DE",
    "name": "Hahnheim",
    "lat": "49.86083",
    "lng": "8.23694"
  },
  {
    "country": "DE",
    "name": "Hahnbach",
    "lat": "49.53389",
    "lng": "11.80302"
  },
  {
    "country": "DE",
    "name": "Hagnau",
    "lat": "47.67666",
    "lng": "9.31787"
  },
  {
    "country": "DE",
    "name": "Hagenow",
    "lat": "53.43134",
    "lng": "11.19159"
  },
  {
    "country": "DE",
    "name": "Hagen im Bremischen",
    "lat": "53.35707",
    "lng": "8.64341"
  },
  {
    "country": "DE",
    "name": "Hagenburg",
    "lat": "52.43367",
    "lng": "9.32473"
  },
  {
    "country": "DE",
    "name": "Hagenbüchach",
    "lat": "49.53333",
    "lng": "10.76667"
  },
  {
    "country": "DE",
    "name": "Hagenbach",
    "lat": "49.01734",
    "lng": "8.25024"
  },
  {
    "country": "DE",
    "name": "Hagen",
    "lat": "52.19629",
    "lng": "7.98041"
  },
  {
    "country": "DE",
    "name": "Hagen",
    "lat": "51.36081",
    "lng": "7.47168"
  },
  {
    "country": "DE",
    "name": "Hagelstadt",
    "lat": "48.9",
    "lng": "12.21667"
  },
  {
    "country": "DE",
    "name": "Hage",
    "lat": "53.60274",
    "lng": "7.28527"
  },
  {
    "country": "DE",
    "name": "Hafenlohr",
    "lat": "49.86944",
    "lng": "9.60222"
  },
  {
    "country": "DE",
    "name": "Hadmersleben",
    "lat": "51.99275",
    "lng": "11.30283"
  },
  {
    "country": "DE",
    "name": "Hadamar",
    "lat": "50.44593",
    "lng": "8.04253"
  },
  {
    "country": "DE",
    "name": "Hackenheim",
    "lat": "49.82524",
    "lng": "7.89907"
  },
  {
    "country": "DE",
    "name": "Hachenburg",
    "lat": "50.65998",
    "lng": "7.82276"
  },
  {
    "country": "DE",
    "name": "Habach",
    "lat": "47.73333",
    "lng": "11.28333"
  },
  {
    "country": "DE",
    "name": "Haarbach",
    "lat": "48.5",
    "lng": "13.15"
  },
  {
    "country": "DE",
    "name": "Haar",
    "lat": "48.10881",
    "lng": "11.72653"
  },
  {
    "country": "DE",
    "name": "Haan",
    "lat": "51.19382",
    "lng": "7.0133"
  },
  {
    "country": "DE",
    "name": "Haag in Oberbayern",
    "lat": "48.16196",
    "lng": "12.17942"
  },
  {
    "country": "DE",
    "name": "Haag an der Amper",
    "lat": "48.4584",
    "lng": "11.82796"
  },
  {
    "country": "DE",
    "name": "Gyhum",
    "lat": "53.21667",
    "lng": "9.31667"
  },
  {
    "country": "DE",
    "name": "Guxhagen",
    "lat": "51.2",
    "lng": "9.48333"
  },
  {
    "country": "DE",
    "name": "Gützkow",
    "lat": "53.72432",
    "lng": "13.10664"
  },
  {
    "country": "DE",
    "name": "Guttau",
    "lat": "51.25904",
    "lng": "14.56132"
  },
  {
    "country": "DE",
    "name": "Gütersloh",
    "lat": "51.90693",
    "lng": "8.37853"
  },
  {
    "country": "DE",
    "name": "Gutenstetten",
    "lat": "49.61667",
    "lng": "10.63333"
  },
  {
    "country": "DE",
    "name": "Gutenberg",
    "lat": "51.5471",
    "lng": "11.97181"
  },
  {
    "country": "DE",
    "name": "Gutenberg",
    "lat": "49.88333",
    "lng": "7.8"
  },
  {
    "country": "DE",
    "name": "Gütenbach",
    "lat": "48.05",
    "lng": "8.15"
  },
  {
    "country": "DE",
    "name": "Gutach im Breisgau",
    "lat": "48.11667",
    "lng": "7.98333"
  },
  {
    "country": "DE",
    "name": "Gutach (Schwarzwaldbahn)",
    "lat": "48.24844",
    "lng": "8.21293"
  },
  {
    "country": "DE",
    "name": "Güstrow",
    "lat": "53.7972",
    "lng": "12.17337"
  },
  {
    "country": "DE",
    "name": "Gusterath",
    "lat": "49.7",
    "lng": "6.71667"
  },
  {
    "country": "DE",
    "name": "Güster",
    "lat": "53.53851",
    "lng": "10.67607"
  },
  {
    "country": "DE",
    "name": "Güsten",
    "lat": "51.79637",
    "lng": "11.61246"
  },
  {
    "country": "DE",
    "name": "Gusenburg",
    "lat": "49.63333",
    "lng": "6.9"
  },
  {
    "country": "DE",
    "name": "Gunzenhausen",
    "lat": "49.11663",
    "lng": "10.75971"
  },
  {
    "country": "DE",
    "name": "Günzburg",
    "lat": "48.45599",
    "lng": "10.27695"
  },
  {
    "country": "DE",
    "name": "Günzach",
    "lat": "47.82491",
    "lng": "10.43547"
  },
  {
    "country": "DE",
    "name": "Günthersdorf",
    "lat": "51.3457",
    "lng": "12.17175"
  },
  {
    "country": "DE",
    "name": "Güntersleben",
    "lat": "49.86972",
    "lng": "9.905"
  },
  {
    "country": "DE",
    "name": "Guntersblum",
    "lat": "49.7975",
    "lng": "8.34556"
  },
  {
    "country": "DE",
    "name": "Gundremmingen",
    "lat": "48.5",
    "lng": "10.4"
  },
  {
    "country": "DE",
    "name": "Gundersheim",
    "lat": "49.69611",
    "lng": "8.2025"
  },
  {
    "country": "DE",
    "name": "Gundelsheim",
    "lat": "49.93708",
    "lng": "10.9199"
  },
  {
    "country": "DE",
    "name": "Gundelsheim",
    "lat": "49.2833",
    "lng": "9.16037"
  },
  {
    "country": "DE",
    "name": "Gundelfingen",
    "lat": "48.55347",
    "lng": "10.37223"
  },
  {
    "country": "DE",
    "name": "Gundelfingen",
    "lat": "48.04246",
    "lng": "7.8657"
  },
  {
    "country": "DE",
    "name": "Gumtow",
    "lat": "52.98333",
    "lng": "12.25"
  },
  {
    "country": "DE",
    "name": "Gummersbach",
    "lat": "51.02608",
    "lng": "7.56473"
  },
  {
    "country": "DE",
    "name": "Gülzow",
    "lat": "53.45",
    "lng": "10.5"
  },
  {
    "country": "DE",
    "name": "Güglingen",
    "lat": "49.06642",
    "lng": "9.00175"
  },
  {
    "country": "DE",
    "name": "Gudow",
    "lat": "53.55556",
    "lng": "10.77021"
  },
  {
    "country": "DE",
    "name": "Guderhandviertel",
    "lat": "53.54919",
    "lng": "9.6096"
  },
  {
    "country": "DE",
    "name": "Gudensberg",
    "lat": "51.17706",
    "lng": "9.36748"
  },
  {
    "country": "DE",
    "name": "Gückingen",
    "lat": "50.39091",
    "lng": "8.00726"
  },
  {
    "country": "DE",
    "name": "Guben",
    "lat": "51.94987",
    "lng": "14.71447"
  },
  {
    "country": "DE",
    "name": "Gstadt am Chiemsee",
    "lat": "47.88453",
    "lng": "12.41813"
  },
  {
    "country": "DE",
    "name": "Gschwend",
    "lat": "48.93333",
    "lng": "9.74436"
  },
  {
    "country": "DE",
    "name": "Grünwald",
    "lat": "48.03947",
    "lng": "11.5232"
  },
  {
    "country": "DE",
    "name": "Grünstadt",
    "lat": "49.56302",
    "lng": "8.16279"
  },
  {
    "country": "DE",
    "name": "Grünsfeld",
    "lat": "49.60949",
    "lng": "9.74725"
  },
  {
    "country": "DE",
    "name": "Grünkraut",
    "lat": "47.74417",
    "lng": "9.65588"
  },
  {
    "country": "DE",
    "name": "Grünheide",
    "lat": "52.42343",
    "lng": "13.81324"
  },
  {
    "country": "DE",
    "name": "Grünhainichen",
    "lat": "50.7672",
    "lng": "13.15366"
  },
  {
    "country": "DE",
    "name": "Grünhain",
    "lat": "50.58019",
    "lng": "12.80695"
  },
  {
    "country": "DE",
    "name": "Grunewald",
    "lat": "52.48338",
    "lng": "13.26586"
  },
  {
    "country": "DE",
    "name": "Grünendeich",
    "lat": "53.56952",
    "lng": "9.61218"
  },
  {
    "country": "DE",
    "name": "Grünenbach",
    "lat": "47.62864",
    "lng": "10.00843"
  },
  {
    "country": "DE",
    "name": "Grünberg",
    "lat": "50.59403",
    "lng": "8.95866"
  },
  {
    "country": "DE",
    "name": "Grünbach",
    "lat": "50.44995",
    "lng": "12.36186"
  },
  {
    "country": "DE",
    "name": "Grünau",
    "lat": "52.41642",
    "lng": "13.58039"
  },
  {
    "country": "DE",
    "name": "Gruibingen",
    "lat": "48.59483",
    "lng": "9.64389"
  },
  {
    "country": "DE",
    "name": "Grube",
    "lat": "54.23333",
    "lng": "11.03333"
  },
  {
    "country": "DE",
    "name": "Grub",
    "lat": "50.10285",
    "lng": "11.92904"
  },
  {
    "country": "DE",
    "name": "Groß-Zimmern",
    "lat": "49.87583",
    "lng": "8.83444"
  },
  {
    "country": "DE",
    "name": "Großwoltersdorf",
    "lat": "53.06667",
    "lng": "13.1"
  },
  {
    "country": "DE",
    "name": "Groß Wokern",
    "lat": "53.75135",
    "lng": "12.49249"
  },
  {
    "country": "DE",
    "name": "Groß Wittensee",
    "lat": "54.4",
    "lng": "9.76667"
  },
  {
    "country": "DE",
    "name": "Großweitzschen",
    "lat": "51.15845",
    "lng": "13.04517"
  },
  {
    "country": "DE",
    "name": "Großweil",
    "lat": "47.67598",
    "lng": "11.30108"
  },
  {
    "country": "DE",
    "name": "Großwallstadt",
    "lat": "49.87936",
    "lng": "9.15338"
  },
  {
    "country": "DE",
    "name": "Groß-Umstadt",
    "lat": "49.86899",
    "lng": "8.9321"
  },
  {
    "country": "DE",
    "name": "Groß Twülpstedt",
    "lat": "52.37361",
    "lng": "10.91929"
  },
  {
    "country": "DE",
    "name": "Großthiemig",
    "lat": "51.38333",
    "lng": "13.66667"
  },
  {
    "country": "DE",
    "name": "Großsolt",
    "lat": "54.7",
    "lng": "9.51667"
  },
  {
    "country": "DE",
    "name": "Großschweidnitz",
    "lat": "51.06939",
    "lng": "14.64297"
  },
  {
    "country": "DE",
    "name": "Großschönau",
    "lat": "50.9",
    "lng": "14.68333"
  },
  {
    "country": "DE",
    "name": "Großschirma",
    "lat": "50.96602",
    "lng": "13.2859"
  },
  {
    "country": "DE",
    "name": "Groß Santersleben",
    "lat": "52.19143",
    "lng": "11.45486"
  },
  {
    "country": "DE",
    "name": "Großrudestedt",
    "lat": "51.09305",
    "lng": "11.09977"
  },
  {
    "country": "DE",
    "name": "Großrückerswalde",
    "lat": "50.63333",
    "lng": "13.11667"
  },
  {
    "country": "DE",
    "name": "Großrosseln",
    "lat": "49.20296",
    "lng": "6.84148"
  },
  {
    "country": "DE",
    "name": "Groß Rosenburg",
    "lat": "51.91696",
    "lng": "11.89184"
  },
  {
    "country": "DE",
    "name": "Großröhrsdorf",
    "lat": "51.14528",
    "lng": "14.01917"
  },
  {
    "country": "DE",
    "name": "Groß-Rohrheim",
    "lat": "49.72111",
    "lng": "8.48278"
  },
  {
    "country": "DE",
    "name": "Groß Rodensleben",
    "lat": "52.12139",
    "lng": "11.38367"
  },
  {
    "country": "DE",
    "name": "Großrinderfeld",
    "lat": "49.66536",
    "lng": "9.73356"
  },
  {
    "country": "DE",
    "name": "Groß Rheide",
    "lat": "54.44154",
    "lng": "9.43508"
  },
  {
    "country": "DE",
    "name": "Großreuth bei Schweinau",
    "lat": "49.43449",
    "lng": "11.02273"
  },
  {
    "country": "DE",
    "name": "Großräschen",
    "lat": "51.5876",
    "lng": "14.01093"
  },
  {
    "country": "DE",
    "name": "Groß Quenstedt",
    "lat": "51.93333",
    "lng": "11.11667"
  },
  {
    "country": "DE",
    "name": "Großpostwitz",
    "lat": "51.12083",
    "lng": "14.44065"
  },
  {
    "country": "DE",
    "name": "Großpösna",
    "lat": "51.26667",
    "lng": "12.5"
  },
  {
    "country": "DE",
    "name": "Groß Pankow",
    "lat": "53.11952",
    "lng": "12.04975"
  },
  {
    "country": "DE",
    "name": "Großostheim",
    "lat": "49.91985",
    "lng": "9.07596"
  },
  {
    "country": "DE",
    "name": "Großörner",
    "lat": "51.61527",
    "lng": "11.4898"
  },
  {
    "country": "DE",
    "name": "Großolbersdorf",
    "lat": "50.7",
    "lng": "13.08333"
  },
  {
    "country": "DE",
    "name": "Groß Oesingen",
    "lat": "52.64761",
    "lng": "10.46366"
  },
  {
    "country": "DE",
    "name": "Großniedesheim",
    "lat": "49.57528",
    "lng": "8.31222"
  },
  {
    "country": "DE",
    "name": "Groß Nemerow",
    "lat": "53.47342",
    "lng": "13.22482"
  },
  {
    "country": "DE",
    "name": "Großnaundorf",
    "lat": "51.2",
    "lng": "13.93333"
  },
  {
    "country": "DE",
    "name": "Groß Munzel",
    "lat": "52.36554",
    "lng": "9.47828"
  },
  {
    "country": "DE",
    "name": "Großmonra",
    "lat": "51.21299",
    "lng": "11.29578"
  },
  {
    "country": "DE",
    "name": "Großmaischeid",
    "lat": "50.5",
    "lng": "7.63333"
  },
  {
    "country": "DE",
    "name": "Großlittgen",
    "lat": "50.02787",
    "lng": "6.79865"
  },
  {
    "country": "DE",
    "name": "Groß Lindow",
    "lat": "52.23333",
    "lng": "14.53333"
  },
  {
    "country": "DE",
    "name": "Großlehna",
    "lat": "51.30687",
    "lng": "12.1719"
  },
  {
    "country": "DE",
    "name": "Großlangheim",
    "lat": "49.7562",
    "lng": "10.24065"
  },
  {
    "country": "DE",
    "name": "Groß Laasch",
    "lat": "53.34646",
    "lng": "11.54919"
  },
  {
    "country": "DE",
    "name": "Groß Kummerfeld",
    "lat": "54.05",
    "lng": "10.08333"
  },
  {
    "country": "DE",
    "name": "Großkugel",
    "lat": "51.41728",
    "lng": "12.14641"
  },
  {
    "country": "DE",
    "name": "Großkrotzenburg",
    "lat": "50.08333",
    "lng": "8.98333"
  },
  {
    "country": "DE",
    "name": "Groß Kreutz",
    "lat": "52.40281",
    "lng": "12.7794"
  },
  {
    "country": "DE",
    "name": "Groß Köris",
    "lat": "52.16587",
    "lng": "13.65935"
  },
  {
    "country": "DE",
    "name": "Großkorbetha",
    "lat": "51.26002",
    "lng": "12.03012"
  },
  {
    "country": "DE",
    "name": "Großkmehlen",
    "lat": "51.37901",
    "lng": "13.72501"
  },
  {
    "country": "DE",
    "name": "Groß Kiesow",
    "lat": "54.01261",
    "lng": "13.47851"
  },
  {
    "country": "DE",
    "name": "Großkayna",
    "lat": "51.29068",
    "lng": "11.93269"
  },
  {
    "country": "DE",
    "name": "Großkarolinenfeld",
    "lat": "47.89102",
    "lng": "12.08101"
  },
  {
    "country": "DE",
    "name": "Großkarlbach",
    "lat": "49.53833",
    "lng": "8.22472"
  },
  {
    "country": "DE",
    "name": "Groß Ippener",
    "lat": "52.96667",
    "lng": "8.61667"
  },
  {
    "country": "DE",
    "name": "Großholbach",
    "lat": "50.45",
    "lng": "7.88333"
  },
  {
    "country": "DE",
    "name": "Großheubach",
    "lat": "49.72834",
    "lng": "9.2228"
  },
  {
    "country": "DE",
    "name": "Großhennersdorf",
    "lat": "50.98597",
    "lng": "14.78776"
  },
  {
    "country": "DE",
    "name": "Großheirath",
    "lat": "50.17603",
    "lng": "10.9505"
  },
  {
    "country": "DE",
    "name": "Großhartmannsdorf",
    "lat": "50.8",
    "lng": "13.33333"
  },
  {
    "country": "DE",
    "name": "Großharthau",
    "lat": "51.10694",
    "lng": "14.09911"
  },
  {
    "country": "DE",
    "name": "Großhansdorf",
    "lat": "53.66667",
    "lng": "10.28333"
  },
  {
    "country": "DE",
    "name": "Großhabersdorf",
    "lat": "49.4",
    "lng": "10.78333"
  },
  {
    "country": "DE",
    "name": "Groß Grönau",
    "lat": "53.8",
    "lng": "10.75"
  },
  {
    "country": "DE",
    "name": "Großgoltern",
    "lat": "52.33261",
    "lng": "9.50111"
  },
  {
    "country": "DE",
    "name": "Groß-Gerau",
    "lat": "49.92139",
    "lng": "8.48255"
  },
  {
    "country": "DE",
    "name": "Großerlach",
    "lat": "49.05368",
    "lng": "9.51356"
  },
  {
    "country": "DE",
    "name": "Großenwiehe",
    "lat": "54.7",
    "lng": "9.25"
  },
  {
    "country": "DE",
    "name": "Großenstein",
    "lat": "50.9",
    "lng": "12.2"
  },
  {
    "country": "DE",
    "name": "Großenseebach",
    "lat": "49.63251",
    "lng": "10.87483"
  },
  {
    "country": "DE",
    "name": "Großensee",
    "lat": "53.61263",
    "lng": "10.33961"
  },
  {
    "country": "DE",
    "name": "Großenlüder",
    "lat": "50.5925",
    "lng": "9.54231"
  },
  {
    "country": "DE",
    "name": "Großenkneten",
    "lat": "52.94377",
    "lng": "8.25323"
  },
  {
    "country": "DE",
    "name": "Großenhain",
    "lat": "51.28951",
    "lng": "13.5335"
  },
  {
    "country": "DE",
    "name": "Großengottern",
    "lat": "51.14821",
    "lng": "10.56232"
  },
  {
    "country": "DE",
    "name": "Großenehrich",
    "lat": "51.24838",
    "lng": "10.83458"
  },
  {
    "country": "DE",
    "name": "Grossenbrode",
    "lat": "54.38333",
    "lng": "11.08333"
  },
  {
    "country": "DE",
    "name": "Großenaspe",
    "lat": "53.98333",
    "lng": "9.96667"
  },
  {
    "country": "DE",
    "name": "Grosselfingen",
    "lat": "48.33229",
    "lng": "8.88704"
  },
  {
    "country": "DE",
    "name": "Großeibstadt",
    "lat": "50.30102",
    "lng": "10.4098"
  },
  {
    "country": "DE",
    "name": "Großdubrau",
    "lat": "51.25422",
    "lng": "14.45897"
  },
  {
    "country": "DE",
    "name": "Groß Düben",
    "lat": "51.56667",
    "lng": "14.56667"
  },
  {
    "country": "DE",
    "name": "Großbreitenbach",
    "lat": "50.58335",
    "lng": "11.00955"
  },
  {
    "country": "DE",
    "name": "Großbottwar",
    "lat": "49.00147",
    "lng": "9.29348"
  },
  {
    "country": "DE",
    "name": "Großbothen",
    "lat": "51.18784",
    "lng": "12.75101"
  },
  {
    "country": "DE",
    "name": "Groß Börnecke",
    "lat": "51.88468",
    "lng": "11.47032"
  },
  {
    "country": "DE",
    "name": "Großbodungen",
    "lat": "51.47572",
    "lng": "10.48104"
  },
  {
    "country": "DE",
    "name": "Groß-Bieberau",
    "lat": "49.80064",
    "lng": "8.8243"
  },
  {
    "country": "DE",
    "name": "Großbettlingen",
    "lat": "48.59052",
    "lng": "9.30782"
  },
  {
    "country": "DE",
    "name": "Großbeeren",
    "lat": "52.35862",
    "lng": "13.30994"
  },
  {
    "country": "DE",
    "name": "Großbartloff",
    "lat": "51.25",
    "lng": "10.21667"
  },
  {
    "country": "DE",
    "name": "Großbardorf",
    "lat": "50.26667",
    "lng": "10.36667"
  },
  {
    "country": "DE",
    "name": "Großbardau",
    "lat": "51.20419",
    "lng": "12.69848"
  },
  {
    "country": "DE",
    "name": "Groß Ammensleben",
    "lat": "52.23279",
    "lng": "11.52195"
  },
  {
    "country": "DE",
    "name": "Großalmerode",
    "lat": "51.25858",
    "lng": "9.7845"
  },
  {
    "country": "DE",
    "name": "Großaitingen",
    "lat": "48.22753",
    "lng": "10.77948"
  },
  {
    "country": "DE",
    "name": "Grönwohld",
    "lat": "53.64162",
    "lng": "10.40784"
  },
  {
    "country": "DE",
    "name": "Gröningen",
    "lat": "51.93744",
    "lng": "11.21601"
  },
  {
    "country": "DE",
    "name": "Gronau",
    "lat": "52.21099",
    "lng": "7.02238"
  },
  {
    "country": "DE",
    "name": "Gronau",
    "lat": "52.0846",
    "lng": "9.77678"
  },
  {
    "country": "DE",
    "name": "Grömitz",
    "lat": "54.15",
    "lng": "10.96667"
  },
  {
    "country": "DE",
    "name": "Grolsheim",
    "lat": "49.90834",
    "lng": "7.91599"
  },
  {
    "country": "DE",
    "name": "Groitzsch",
    "lat": "51.15536",
    "lng": "12.28279"
  },
  {
    "country": "DE",
    "name": "Gröden",
    "lat": "51.4",
    "lng": "13.56667"
  },
  {
    "country": "DE",
    "name": "Gröbzig",
    "lat": "51.68226",
    "lng": "11.87453"
  },
  {
    "country": "DE",
    "name": "Gröbers",
    "lat": "51.4305",
    "lng": "12.11623"
  },
  {
    "country": "DE",
    "name": "Gröbenzell",
    "lat": "48.2",
    "lng": "11.36667"
  },
  {
    "country": "DE",
    "name": "Grimmen",
    "lat": "54.11215",
    "lng": "13.04051"
  },
  {
    "country": "DE",
    "name": "Grimma",
    "lat": "51.23367",
    "lng": "12.71959"
  },
  {
    "country": "DE",
    "name": "Griesstätt",
    "lat": "47.99403",
    "lng": "12.17727"
  },
  {
    "country": "DE",
    "name": "Griesheim",
    "lat": "49.86085",
    "lng": "8.5725"
  },
  {
    "country": "DE",
    "name": "Bad Griesbach",
    "lat": "48.45181",
    "lng": "13.19329"
  },
  {
    "country": "DE",
    "name": "Gries",
    "lat": "49.41667",
    "lng": "7.4"
  },
  {
    "country": "DE",
    "name": "Grevesmühlen",
    "lat": "53.86337",
    "lng": "11.1916"
  },
  {
    "country": "DE",
    "name": "Grevenbroich",
    "lat": "51.09102",
    "lng": "6.5827"
  },
  {
    "country": "DE",
    "name": "Greven",
    "lat": "52.09364",
    "lng": "7.59396"
  },
  {
    "country": "DE",
    "name": "Greußenheim",
    "lat": "49.81667",
    "lng": "9.76667"
  },
  {
    "country": "DE",
    "name": "Greußen",
    "lat": "51.22964",
    "lng": "10.94422"
  },
  {
    "country": "DE",
    "name": "Grettstadt",
    "lat": "49.98333",
    "lng": "10.31667"
  },
  {
    "country": "DE",
    "name": "Greppin",
    "lat": "51.64682",
    "lng": "12.30066"
  },
  {
    "country": "DE",
    "name": "Grenzach-Wyhlen",
    "lat": "47.55",
    "lng": "7.68333"
  },
  {
    "country": "DE",
    "name": "Gremsdorf",
    "lat": "49.69506",
    "lng": "10.83218"
  },
  {
    "country": "DE",
    "name": "Gremersdorf",
    "lat": "54.33333",
    "lng": "10.93333"
  },
  {
    "country": "DE",
    "name": "Gremberghoven",
    "lat": "50.90152",
    "lng": "7.06129"
  },
  {
    "country": "DE",
    "name": "Greiz",
    "lat": "50.65778",
    "lng": "12.19918"
  },
  {
    "country": "DE",
    "name": "Greimerath",
    "lat": "49.56155",
    "lng": "6.68374"
  },
  {
    "country": "DE",
    "name": "Greiling",
    "lat": "47.76667",
    "lng": "11.61667"
  },
  {
    "country": "DE",
    "name": "Greifswald",
    "lat": "54.09311",
    "lng": "13.38786"
  },
  {
    "country": "DE",
    "name": "Greifenstein",
    "lat": "50.61667",
    "lng": "8.3"
  },
  {
    "country": "DE",
    "name": "Greifenberg",
    "lat": "48.07062",
    "lng": "11.08349"
  },
  {
    "country": "DE",
    "name": "Grefrath",
    "lat": "51.3363",
    "lng": "6.34072"
  },
  {
    "country": "DE",
    "name": "Greffern",
    "lat": "48.75205",
    "lng": "8.00515"
  },
  {
    "country": "DE",
    "name": "Greding",
    "lat": "49.04699",
    "lng": "11.35703"
  },
  {
    "country": "DE",
    "name": "Grebin",
    "lat": "54.2",
    "lng": "10.5"
  },
  {
    "country": "DE",
    "name": "Grebenstein",
    "lat": "51.44648",
    "lng": "9.4125"
  },
  {
    "country": "DE",
    "name": "Grebenhain",
    "lat": "50.48924",
    "lng": "9.33855"
  },
  {
    "country": "DE",
    "name": "Grebenau",
    "lat": "50.74242",
    "lng": "9.47307"
  },
  {
    "country": "DE",
    "name": "Grävenwiesbach",
    "lat": "50.39024",
    "lng": "8.4569"
  },
  {
    "country": "DE",
    "name": "Grattersdorf",
    "lat": "48.80364",
    "lng": "13.15372"
  },
  {
    "country": "DE",
    "name": "Grassau",
    "lat": "47.78099",
    "lng": "12.45359"
  },
  {
    "country": "DE",
    "name": "Grasleben",
    "lat": "52.30638",
    "lng": "11.01465"
  },
  {
    "country": "DE",
    "name": "Grasbrunn",
    "lat": "48.07905",
    "lng": "11.74361"
  },
  {
    "country": "DE",
    "name": "Grasberg",
    "lat": "53.18333",
    "lng": "8.98333"
  },
  {
    "country": "DE",
    "name": "Gransee",
    "lat": "53.00704",
    "lng": "13.1575"
  },
  {
    "country": "DE",
    "name": "Granschütz",
    "lat": "51.18431",
    "lng": "12.05149"
  },
  {
    "country": "DE",
    "name": "Gramzow",
    "lat": "53.21246",
    "lng": "14.00748"
  },
  {
    "country": "DE",
    "name": "Gramkow",
    "lat": "53.92092",
    "lng": "11.3174"
  },
  {
    "country": "DE",
    "name": "Grainet",
    "lat": "48.8",
    "lng": "13.65"
  },
  {
    "country": "DE",
    "name": "Grainau",
    "lat": "47.47614",
    "lng": "11.02405"
  },
  {
    "country": "DE",
    "name": "Grafrath",
    "lat": "48.11667",
    "lng": "11.16667"
  },
  {
    "country": "DE",
    "name": "Grafing bei München",
    "lat": "48.04596",
    "lng": "11.96797"
  },
  {
    "country": "DE",
    "name": "Grafhorst",
    "lat": "52.44482",
    "lng": "10.94513"
  },
  {
    "country": "DE",
    "name": "Grafenwöhr",
    "lat": "49.71728",
    "lng": "11.90645"
  },
  {
    "country": "DE",
    "name": "Grafenwiesen",
    "lat": "49.2",
    "lng": "12.88333"
  },
  {
    "country": "DE",
    "name": "Gräfenroda",
    "lat": "50.74781",
    "lng": "10.81063"
  },
  {
    "country": "DE",
    "name": "Grafenrheinfeld",
    "lat": "50",
    "lng": "10.2"
  },
  {
    "country": "DE",
    "name": "Grafenhausen",
    "lat": "48.28427",
    "lng": "7.76678"
  },
  {
    "country": "DE",
    "name": "Gräfenhainichen",
    "lat": "51.72892",
    "lng": "12.45651"
  },
  {
    "country": "DE",
    "name": "Gräfenhain",
    "lat": "50.81667",
    "lng": "10.7"
  },
  {
    "country": "DE",
    "name": "Grafengehaig",
    "lat": "50.2031",
    "lng": "11.59358"
  },
  {
    "country": "DE",
    "name": "Gräfendorf",
    "lat": "50.12267",
    "lng": "9.7405"
  },
  {
    "country": "DE",
    "name": "Gräfenberg",
    "lat": "49.64426",
    "lng": "11.24971"
  },
  {
    "country": "DE",
    "name": "Grafenau",
    "lat": "48.85768",
    "lng": "13.3974"
  },
  {
    "country": "DE",
    "name": "Gräfelfing",
    "lat": "48.11878",
    "lng": "11.42939"
  },
  {
    "country": "DE",
    "name": "Grabsleben",
    "lat": "50.93633",
    "lng": "10.83508"
  },
  {
    "country": "DE",
    "name": "Grabowhöfe",
    "lat": "53.56865",
    "lng": "12.59482"
  },
  {
    "country": "DE",
    "name": "Grabow",
    "lat": "53.27966",
    "lng": "11.56502"
  },
  {
    "country": "DE",
    "name": "Grabenstetten",
    "lat": "48.52397",
    "lng": "9.46155"
  },
  {
    "country": "DE",
    "name": "Grabenstätt",
    "lat": "47.84531",
    "lng": "12.5433"
  },
  {
    "country": "DE",
    "name": "Graben",
    "lat": "48.18732",
    "lng": "10.82222"
  },
  {
    "country": "DE",
    "name": "Gottmadingen",
    "lat": "47.73511",
    "lng": "8.77687"
  },
  {
    "country": "DE",
    "name": "Göttingen",
    "lat": "51.53443",
    "lng": "9.93228"
  },
  {
    "country": "DE",
    "name": "Gottfrieding",
    "lat": "48.63737",
    "lng": "12.53561"
  },
  {
    "country": "DE",
    "name": "Gotteszell",
    "lat": "48.96667",
    "lng": "12.96667"
  },
  {
    "country": "DE",
    "name": "Gottenheim",
    "lat": "48.05",
    "lng": "7.73333"
  },
  {
    "country": "DE",
    "name": "Gotha",
    "lat": "50.94823",
    "lng": "10.70193"
  },
  {
    "country": "DE",
    "name": "Goßwitz",
    "lat": "50.63536",
    "lng": "11.47737"
  },
  {
    "country": "DE",
    "name": "Gößweinstein",
    "lat": "49.76898",
    "lng": "11.33841"
  },
  {
    "country": "DE",
    "name": "Gößnitz",
    "lat": "50.88902",
    "lng": "12.43292"
  },
  {
    "country": "DE",
    "name": "Gössenheim",
    "lat": "50.01667",
    "lng": "9.78333"
  },
  {
    "country": "DE",
    "name": "Goslar",
    "lat": "51.90425",
    "lng": "10.42766"
  },
  {
    "country": "DE",
    "name": "Gosheim",
    "lat": "48.1343",
    "lng": "8.75426"
  },
  {
    "country": "DE",
    "name": "Goseck",
    "lat": "51.2",
    "lng": "11.86667"
  },
  {
    "country": "DE",
    "name": "Görzke",
    "lat": "52.17179",
    "lng": "12.37506"
  },
  {
    "country": "DE",
    "name": "Görzig",
    "lat": "51.66381",
    "lng": "11.99759"
  },
  {
    "country": "DE",
    "name": "Görwihl",
    "lat": "47.64275",
    "lng": "8.07482"
  },
  {
    "country": "DE",
    "name": "Görsbach",
    "lat": "51.46224",
    "lng": "10.93706"
  },
  {
    "country": "DE",
    "name": "Gornsdorf",
    "lat": "50.7",
    "lng": "12.88333"
  },
  {
    "country": "DE",
    "name": "Gornau",
    "lat": "50.75901",
    "lng": "13.03731"
  },
  {
    "country": "DE",
    "name": "Görmin",
    "lat": "53.99092",
    "lng": "13.27054"
  },
  {
    "country": "DE",
    "name": "Görlitz",
    "lat": "51.15518",
    "lng": "14.98853"
  },
  {
    "country": "DE",
    "name": "Görisried",
    "lat": "47.70668",
    "lng": "10.51015"
  },
  {
    "country": "DE",
    "name": "Göppingen",
    "lat": "48.70354",
    "lng": "9.65209"
  },
  {
    "country": "DE",
    "name": "Gönnheim",
    "lat": "49.44806",
    "lng": "8.23861"
  },
  {
    "country": "DE",
    "name": "Gondelsheim",
    "lat": "49.05917",
    "lng": "8.65833"
  },
  {
    "country": "DE",
    "name": "Gommersheim",
    "lat": "49.29111",
    "lng": "8.26583"
  },
  {
    "country": "DE",
    "name": "Gommern",
    "lat": "52.07391",
    "lng": "11.82297"
  },
  {
    "country": "DE",
    "name": "Gomaringen",
    "lat": "48.45349",
    "lng": "9.09582"
  },
  {
    "country": "DE",
    "name": "Gomadingen",
    "lat": "48.3998",
    "lng": "9.39065"
  },
  {
    "country": "DE",
    "name": "Golzow",
    "lat": "52.27617",
    "lng": "12.60052"
  },
  {
    "country": "DE",
    "name": "Golßen",
    "lat": "51.97204",
    "lng": "13.60115"
  },
  {
    "country": "DE",
    "name": "Golmbach",
    "lat": "51.9",
    "lng": "9.55"
  },
  {
    "country": "DE",
    "name": "Göllheim",
    "lat": "49.595",
    "lng": "8.05083"
  },
  {
    "country": "DE",
    "name": "Goldkronach",
    "lat": "50.01086",
    "lng": "11.6875"
  },
  {
    "country": "DE",
    "name": "Goldenstedt",
    "lat": "52.78833",
    "lng": "8.43201"
  },
  {
    "country": "DE",
    "name": "Goldberg",
    "lat": "53.58878",
    "lng": "12.08855"
  },
  {
    "country": "DE",
    "name": "Goldbeck",
    "lat": "52.71695",
    "lng": "11.8606"
  },
  {
    "country": "DE",
    "name": "Goldbach",
    "lat": "51.04566",
    "lng": "11.43289"
  },
  {
    "country": "DE",
    "name": "Goldbach",
    "lat": "49.99951",
    "lng": "9.1844"
  },
  {
    "country": "DE",
    "name": "Goel",
    "lat": "54.2835",
    "lng": "10.94036"
  },
  {
    "country": "DE",
    "name": "Göggingen",
    "lat": "48.86123",
    "lng": "9.88398"
  },
  {
    "country": "DE",
    "name": "Göda",
    "lat": "51.178",
    "lng": "14.31951"
  },
  {
    "country": "DE",
    "name": "Gochsheim",
    "lat": "50.01667",
    "lng": "10.28333"
  },
  {
    "country": "DE",
    "name": "Goch",
    "lat": "51.67873",
    "lng": "6.15895"
  },
  {
    "country": "DE",
    "name": "Gnutz",
    "lat": "54.13333",
    "lng": "9.81667"
  },
  {
    "country": "DE",
    "name": "Gnoien",
    "lat": "53.9687",
    "lng": "12.71099"
  },
  {
    "country": "DE",
    "name": "Gnarrenburg",
    "lat": "53.38333",
    "lng": "9"
  },
  {
    "country": "DE",
    "name": "Gmund am Tegernsee",
    "lat": "47.75119",
    "lng": "11.7381"
  },
  {
    "country": "DE",
    "name": "Glückstadt",
    "lat": "53.78893",
    "lng": "9.42576"
  },
  {
    "country": "DE",
    "name": "Glücksburg",
    "lat": "54.83522",
    "lng": "9.54853"
  },
  {
    "country": "DE",
    "name": "Glowe",
    "lat": "54.56911",
    "lng": "13.4655"
  },
  {
    "country": "DE",
    "name": "Glött",
    "lat": "48.5",
    "lng": "10.48333"
  },
  {
    "country": "DE",
    "name": "Glöthe",
    "lat": "51.91",
    "lng": "11.67471"
  },
  {
    "country": "DE",
    "name": "Glonn",
    "lat": "47.98751",
    "lng": "11.86721"
  },
  {
    "country": "DE",
    "name": "Glindenberg",
    "lat": "52.23857",
    "lng": "11.68361"
  },
  {
    "country": "DE",
    "name": "Glinde",
    "lat": "53.5441",
    "lng": "10.20048"
  },
  {
    "country": "DE",
    "name": "Glienicke",
    "lat": "52.63353",
    "lng": "13.32564"
  },
  {
    "country": "DE",
    "name": "Gleichamberg",
    "lat": "50.37068",
    "lng": "10.59822"
  },
  {
    "country": "DE",
    "name": "Glauchau",
    "lat": "50.81987",
    "lng": "12.54493"
  },
  {
    "country": "DE",
    "name": "Glauburg",
    "lat": "50.31667",
    "lng": "9"
  },
  {
    "country": "DE",
    "name": "Glaubitz",
    "lat": "51.32498",
    "lng": "13.37817"
  },
  {
    "country": "DE",
    "name": "Glatten",
    "lat": "48.44246",
    "lng": "8.51116"
  },
  {
    "country": "DE",
    "name": "Glattbach",
    "lat": "50",
    "lng": "9.15"
  },
  {
    "country": "DE",
    "name": "Glashütten",
    "lat": "50.21667",
    "lng": "8.4"
  },
  {
    "country": "DE",
    "name": "Glashütten",
    "lat": "49.88739",
    "lng": "11.4487"
  },
  {
    "country": "DE",
    "name": "Glashütte",
    "lat": "50.85196",
    "lng": "13.77977"
  },
  {
    "country": "DE",
    "name": "Glan-Münchweiler",
    "lat": "49.47222",
    "lng": "7.44204"
  },
  {
    "country": "DE",
    "name": "Glandorf",
    "lat": "52.08474",
    "lng": "7.99944"
  },
  {
    "country": "DE",
    "name": "Gladenbach",
    "lat": "50.76847",
    "lng": "8.58085"
  },
  {
    "country": "DE",
    "name": "Gladbeck",
    "lat": "51.57077",
    "lng": "6.98593"
  },
  {
    "country": "DE",
    "name": "Gittelde",
    "lat": "51.7984",
    "lng": "10.1878"
  },
  {
    "country": "DE",
    "name": "Girod",
    "lat": "50.45",
    "lng": "7.91667"
  },
  {
    "country": "DE",
    "name": "Ginsheim-Gustavsburg",
    "lat": "49.9711",
    "lng": "8.34532"
  },
  {
    "country": "DE",
    "name": "Gingst",
    "lat": "54.45654",
    "lng": "13.25737"
  },
  {
    "country": "DE",
    "name": "Gingen an der Fils",
    "lat": "48.65979",
    "lng": "9.78092"
  },
  {
    "country": "DE",
    "name": "Gimbsheim",
    "lat": "49.77778",
    "lng": "8.375"
  },
  {
    "country": "DE",
    "name": "Gilten",
    "lat": "52.7",
    "lng": "9.58333"
  },
  {
    "country": "DE",
    "name": "Gilserberg",
    "lat": "50.95",
    "lng": "9.06667"
  },
  {
    "country": "DE",
    "name": "Gillenfeld",
    "lat": "50.1279",
    "lng": "6.90383"
  },
  {
    "country": "DE",
    "name": "Gilching",
    "lat": "48.10755",
    "lng": "11.2936"
  },
  {
    "country": "DE",
    "name": "Gifhorn",
    "lat": "52.47774",
    "lng": "10.5511"
  },
  {
    "country": "DE",
    "name": "Gießen",
    "lat": "50.58727",
    "lng": "8.67554"
  },
  {
    "country": "DE",
    "name": "Giersleben",
    "lat": "51.76667",
    "lng": "11.56667"
  },
  {
    "country": "DE",
    "name": "Giengen an der Brenz",
    "lat": "48.62219",
    "lng": "10.24312"
  },
  {
    "country": "DE",
    "name": "Gielow",
    "lat": "53.69756",
    "lng": "12.74521"
  },
  {
    "country": "DE",
    "name": "Giekau",
    "lat": "54.31667",
    "lng": "10.51667"
  },
  {
    "country": "DE",
    "name": "Gieboldehausen",
    "lat": "51.60962",
    "lng": "10.21619"
  },
  {
    "country": "DE",
    "name": "Giebelstadt",
    "lat": "49.65308",
    "lng": "9.94441"
  },
  {
    "country": "DE",
    "name": "Geyer",
    "lat": "50.62632",
    "lng": "12.92074"
  },
  {
    "country": "DE",
    "name": "Gevelsberg",
    "lat": "51.31971",
    "lng": "7.3392"
  },
  {
    "country": "DE",
    "name": "Geusa",
    "lat": "51.33914",
    "lng": "11.94382"
  },
  {
    "country": "DE",
    "name": "Gettorf",
    "lat": "54.4",
    "lng": "9.98333"
  },
  {
    "country": "DE",
    "name": "Gesundbrunnen",
    "lat": "52.55035",
    "lng": "13.39139"
  },
  {
    "country": "DE",
    "name": "Gestratz",
    "lat": "47.65",
    "lng": "9.98333"
  },
  {
    "country": "DE",
    "name": "Gessertshausen",
    "lat": "48.32904",
    "lng": "10.73278"
  },
  {
    "country": "DE",
    "name": "Geslau",
    "lat": "49.36643",
    "lng": "10.31528"
  },
  {
    "country": "DE",
    "name": "Geseke",
    "lat": "51.64091",
    "lng": "8.5109"
  },
  {
    "country": "DE",
    "name": "Gesees",
    "lat": "50.03207",
    "lng": "11.66623"
  },
  {
    "country": "DE",
    "name": "Geschwenda",
    "lat": "50.73178",
    "lng": "10.8254"
  },
  {
    "country": "DE",
    "name": "Gescher",
    "lat": "51.954",
    "lng": "7.00481"
  },
  {
    "country": "DE",
    "name": "Gerzen",
    "lat": "48.50706",
    "lng": "12.42686"
  },
  {
    "country": "DE",
    "name": "Gerwisch",
    "lat": "52.17662",
    "lng": "11.73972"
  },
  {
    "country": "DE",
    "name": "Gerswalde",
    "lat": "53.16988",
    "lng": "13.74853"
  },
  {
    "country": "DE",
    "name": "Gerstungen",
    "lat": "50.96667",
    "lng": "10.06667"
  },
  {
    "country": "DE",
    "name": "Gersthofen",
    "lat": "48.42432",
    "lng": "10.87273"
  },
  {
    "country": "DE",
    "name": "Gerstetten",
    "lat": "48.62254",
    "lng": "10.01984"
  },
  {
    "country": "DE",
    "name": "Gersten",
    "lat": "52.58333",
    "lng": "7.51667"
  },
  {
    "country": "DE",
    "name": "Gersheim",
    "lat": "49.15",
    "lng": "7.2"
  },
  {
    "country": "DE",
    "name": "Gersfeld",
    "lat": "50.45138",
    "lng": "9.91422"
  },
  {
    "country": "DE",
    "name": "Gersdorf",
    "lat": "51.1122",
    "lng": "12.93889"
  },
  {
    "country": "DE",
    "name": "Gersdorf",
    "lat": "50.75",
    "lng": "12.71667"
  },
  {
    "country": "DE",
    "name": "Gerolzhofen",
    "lat": "49.90025",
    "lng": "10.34832"
  },
  {
    "country": "DE",
    "name": "Gerolstein",
    "lat": "50.22224",
    "lng": "6.65984"
  },
  {
    "country": "DE",
    "name": "Gerolsheim",
    "lat": "49.54778",
    "lng": "8.26389"
  },
  {
    "country": "DE",
    "name": "Gerolsbach",
    "lat": "48.49283",
    "lng": "11.36149"
  },
  {
    "country": "DE",
    "name": "Gerolfingen",
    "lat": "49.0534",
    "lng": "10.51151"
  },
  {
    "country": "DE",
    "name": "Geroldshausen",
    "lat": "49.68361",
    "lng": "9.90222"
  },
  {
    "country": "DE",
    "name": "Geroldsgrün",
    "lat": "50.33333",
    "lng": "11.6"
  },
  {
    "country": "DE",
    "name": "Gernsheim",
    "lat": "49.75305",
    "lng": "8.48859"
  },
  {
    "country": "DE",
    "name": "Gernsbach",
    "lat": "48.77034",
    "lng": "8.34306"
  },
  {
    "country": "DE",
    "name": "Gernrode",
    "lat": "51.72575",
    "lng": "11.13876"
  },
  {
    "country": "DE",
    "name": "Gernrode",
    "lat": "51.4",
    "lng": "10.4"
  },
  {
    "country": "DE",
    "name": "Germersheim",
    "lat": "49.22306",
    "lng": "8.36389"
  },
  {
    "country": "DE",
    "name": "Germering",
    "lat": "48.13392",
    "lng": "11.3765"
  },
  {
    "country": "DE",
    "name": "Gerlingen",
    "lat": "48.79954",
    "lng": "9.06316"
  },
  {
    "country": "DE",
    "name": "Geringswalde",
    "lat": "51.07677",
    "lng": "12.90725"
  },
  {
    "country": "DE",
    "name": "Gerhardshofen",
    "lat": "49.63123",
    "lng": "10.69133"
  },
  {
    "country": "DE",
    "name": "Geretsried",
    "lat": "47.85775",
    "lng": "11.48054"
  },
  {
    "country": "DE",
    "name": "Gerdau",
    "lat": "52.96667",
    "lng": "10.41667"
  },
  {
    "country": "DE",
    "name": "Gerbstedt",
    "lat": "51.63281",
    "lng": "11.62669"
  },
  {
    "country": "DE",
    "name": "Gerbrunn",
    "lat": "49.77528",
    "lng": "9.99361"
  },
  {
    "country": "DE",
    "name": "Gerach",
    "lat": "50.03333",
    "lng": "10.8"
  },
  {
    "country": "DE",
    "name": "Gerabronn",
    "lat": "48.97071",
    "lng": "9.91986"
  },
  {
    "country": "DE",
    "name": "Geraberg",
    "lat": "50.71594",
    "lng": "10.83737"
  },
  {
    "country": "DE",
    "name": "Gera",
    "lat": "50.88029",
    "lng": "12.08187"
  },
  {
    "country": "DE",
    "name": "Georgsmarienhütte",
    "lat": "52.20296",
    "lng": "8.0448"
  },
  {
    "country": "DE",
    "name": "Georgsdorf",
    "lat": "52.56667",
    "lng": "7.08333"
  },
  {
    "country": "DE",
    "name": "Georgenthal",
    "lat": "50.83205",
    "lng": "10.66266"
  },
  {
    "country": "DE",
    "name": "Georgensgmünd",
    "lat": "49.18972",
    "lng": "11.01667"
  },
  {
    "country": "DE",
    "name": "Georgenberg",
    "lat": "49.70297",
    "lng": "12.42082"
  },
  {
    "country": "DE",
    "name": "Genthin",
    "lat": "52.40668",
    "lng": "12.1592"
  },
  {
    "country": "DE",
    "name": "Gensingen",
    "lat": "49.9",
    "lng": "7.93333"
  },
  {
    "country": "DE",
    "name": "Gengenbach",
    "lat": "48.40476",
    "lng": "8.01433"
  },
  {
    "country": "DE",
    "name": "Genderkingen",
    "lat": "48.7",
    "lng": "10.88333"
  },
  {
    "country": "DE",
    "name": "Gemünden an der Wohra",
    "lat": "50.97401",
    "lng": "8.96946"
  },
  {
    "country": "DE",
    "name": "Gemünden am Main",
    "lat": "50.04946",
    "lng": "9.70593"
  },
  {
    "country": "DE",
    "name": "Gemünden",
    "lat": "49.89444",
    "lng": "7.4775"
  },
  {
    "country": "DE",
    "name": "Gemmrigheim",
    "lat": "49.02833",
    "lng": "9.15556"
  },
  {
    "country": "DE",
    "name": "Gemmingen",
    "lat": "49.15639",
    "lng": "8.98194"
  },
  {
    "country": "DE",
    "name": "Gelting",
    "lat": "54.75",
    "lng": "9.9"
  },
  {
    "country": "DE",
    "name": "Geltendorf",
    "lat": "48.11737",
    "lng": "11.03216"
  },
  {
    "country": "DE",
    "name": "Gelsenkirchen",
    "lat": "51.50508",
    "lng": "7.09654"
  },
  {
    "country": "DE",
    "name": "Gelnhausen",
    "lat": "50.20164",
    "lng": "9.18742"
  },
  {
    "country": "DE",
    "name": "Gelenau",
    "lat": "50.71151",
    "lng": "12.96666"
  },
  {
    "country": "DE",
    "name": "Geldersheim",
    "lat": "50.04286",
    "lng": "10.15609"
  },
  {
    "country": "DE",
    "name": "Geldern",
    "lat": "51.51908",
    "lng": "6.32363"
  },
  {
    "country": "DE",
    "name": "Gelbensande",
    "lat": "54.20272",
    "lng": "12.30168"
  },
  {
    "country": "DE",
    "name": "Geithain",
    "lat": "51.05528",
    "lng": "12.69674"
  },
  {
    "country": "DE",
    "name": "Geismar",
    "lat": "51.23169",
    "lng": "10.16548"
  },
  {
    "country": "DE",
    "name": "Geislingen an der Steige",
    "lat": "48.62423",
    "lng": "9.82736"
  },
  {
    "country": "DE",
    "name": "Geislingen",
    "lat": "48.28768",
    "lng": "8.81241"
  },
  {
    "country": "DE",
    "name": "Geisleden",
    "lat": "51.35",
    "lng": "10.2"
  },
  {
    "country": "DE",
    "name": "Geisingen",
    "lat": "47.92504",
    "lng": "8.65002"
  },
  {
    "country": "DE",
    "name": "Geising",
    "lat": "50.75742",
    "lng": "13.79278"
  },
  {
    "country": "DE",
    "name": "Geisenheim",
    "lat": "49.9847",
    "lng": "7.96835"
  },
  {
    "country": "DE",
    "name": "Geisenhausen",
    "lat": "48.47609",
    "lng": "12.25817"
  },
  {
    "country": "DE",
    "name": "Geisenfeld",
    "lat": "48.68426",
    "lng": "11.61233"
  },
  {
    "country": "DE",
    "name": "Geiselwind",
    "lat": "49.77356",
    "lng": "10.47063"
  },
  {
    "country": "DE",
    "name": "Geiselhöring",
    "lat": "48.82505",
    "lng": "12.39649"
  },
  {
    "country": "DE",
    "name": "Geiselbach",
    "lat": "50.12329",
    "lng": "9.19664"
  },
  {
    "country": "DE",
    "name": "Geisa",
    "lat": "50.71465",
    "lng": "9.95075"
  },
  {
    "country": "DE",
    "name": "Geilenkirchen",
    "lat": "50.96745",
    "lng": "6.11763"
  },
  {
    "country": "DE",
    "name": "Geiersthal",
    "lat": "49.04569",
    "lng": "12.98171"
  },
  {
    "country": "DE",
    "name": "Gehren",
    "lat": "50.64852",
    "lng": "11.00471"
  },
  {
    "country": "DE",
    "name": "Gehrden",
    "lat": "52.31362",
    "lng": "9.60033"
  },
  {
    "country": "DE",
    "name": "Gehrde",
    "lat": "52.57684",
    "lng": "8.00342"
  },
  {
    "country": "DE",
    "name": "Gefrees",
    "lat": "50.09538",
    "lng": "11.73772"
  },
  {
    "country": "DE",
    "name": "Geesthacht",
    "lat": "53.43575",
    "lng": "10.3779"
  },
  {
    "country": "DE",
    "name": "Geeste",
    "lat": "52.6",
    "lng": "7.26667"
  },
  {
    "country": "DE",
    "name": "Gedern",
    "lat": "50.42482",
    "lng": "9.1984"
  },
  {
    "country": "DE",
    "name": "Gechingen",
    "lat": "48.69527",
    "lng": "8.82915"
  },
  {
    "country": "DE",
    "name": "Gebsattel",
    "lat": "49.35",
    "lng": "10.2"
  },
  {
    "country": "DE",
    "name": "Gebhardshain",
    "lat": "50.75",
    "lng": "7.81667"
  },
  {
    "country": "DE",
    "name": "Gebesee",
    "lat": "51.11488",
    "lng": "10.93455"
  },
  {
    "country": "DE",
    "name": "Gauting",
    "lat": "48.06919",
    "lng": "11.37703"
  },
  {
    "country": "DE",
    "name": "Gau-Odernheim",
    "lat": "49.78472",
    "lng": "8.19417"
  },
  {
    "country": "DE",
    "name": "Gaukönigshofen",
    "lat": "49.63333",
    "lng": "10"
  },
  {
    "country": "DE",
    "name": "Gau-Bischofsheim",
    "lat": "49.91583",
    "lng": "8.27278"
  },
  {
    "country": "DE",
    "name": "Gau-Bickelheim",
    "lat": "49.83528",
    "lng": "8.02056"
  },
  {
    "country": "DE",
    "name": "Gau-Algesheim",
    "lat": "49.95669",
    "lng": "8.01569"
  },
  {
    "country": "DE",
    "name": "Gatow",
    "lat": "52.48324",
    "lng": "13.18285"
  },
  {
    "country": "DE",
    "name": "Gatersleben",
    "lat": "51.82215",
    "lng": "11.28661"
  },
  {
    "country": "DE",
    "name": "Garz",
    "lat": "54.31843",
    "lng": "13.35125"
  },
  {
    "country": "DE",
    "name": "Gartz",
    "lat": "53.20829",
    "lng": "14.39226"
  },
  {
    "country": "DE",
    "name": "Gärtringen",
    "lat": "48.64176",
    "lng": "8.90073"
  },
  {
    "country": "DE",
    "name": "Gartow",
    "lat": "53.0247",
    "lng": "11.462"
  },
  {
    "country": "DE",
    "name": "Garstedt",
    "lat": "53.28467",
    "lng": "10.16137"
  },
  {
    "country": "DE",
    "name": "Gars",
    "lat": "48.15386",
    "lng": "12.27767"
  },
  {
    "country": "DE",
    "name": "Garrel",
    "lat": "52.95",
    "lng": "8.01667"
  },
  {
    "country": "DE",
    "name": "Garmisch-Partenkirchen",
    "lat": "47.49209",
    "lng": "11.09576"
  },
  {
    "country": "DE",
    "name": "Garlstorf",
    "lat": "53.23728",
    "lng": "10.10137"
  },
  {
    "country": "DE",
    "name": "Garding",
    "lat": "54.33056",
    "lng": "8.78056"
  },
  {
    "country": "DE",
    "name": "Gardelegen",
    "lat": "52.5252",
    "lng": "11.39523"
  },
  {
    "country": "DE",
    "name": "Garching bei München",
    "lat": "48.24896",
    "lng": "11.65101"
  },
  {
    "country": "DE",
    "name": "Garching an der Alz",
    "lat": "48.13451",
    "lng": "12.58152"
  },
  {
    "country": "DE",
    "name": "Garbsen",
    "lat": "52.41371",
    "lng": "9.5899"
  },
  {
    "country": "DE",
    "name": "Gangloffsömmern",
    "lat": "51.1894",
    "lng": "10.94332"
  },
  {
    "country": "DE",
    "name": "Gangkofen",
    "lat": "48.43701",
    "lng": "12.56419"
  },
  {
    "country": "DE",
    "name": "Gangelt",
    "lat": "50.99247",
    "lng": "5.99802"
  },
  {
    "country": "DE",
    "name": "Ganderkesee",
    "lat": "53.03333",
    "lng": "8.53333"
  },
  {
    "country": "DE",
    "name": "Gammertingen",
    "lat": "48.2524",
    "lng": "9.22349"
  },
  {
    "country": "DE",
    "name": "Gammelshausen",
    "lat": "48.64023",
    "lng": "9.65072"
  },
  {
    "country": "DE",
    "name": "Gammelsdorf",
    "lat": "48.55",
    "lng": "11.95"
  },
  {
    "country": "DE",
    "name": "Gaißach",
    "lat": "47.75",
    "lng": "11.58333"
  },
  {
    "country": "DE",
    "name": "Gaimersheim",
    "lat": "48.80705",
    "lng": "11.36801"
  },
  {
    "country": "DE",
    "name": "Gailingen",
    "lat": "47.69711",
    "lng": "8.75567"
  },
  {
    "country": "DE",
    "name": "Gaildorf",
    "lat": "49.00027",
    "lng": "9.76953"
  },
  {
    "country": "DE",
    "name": "Gaienhofen",
    "lat": "47.68333",
    "lng": "8.98333"
  },
  {
    "country": "DE",
    "name": "Gaiberg",
    "lat": "49.36639",
    "lng": "8.74972"
  },
  {
    "country": "DE",
    "name": "Gaggenau",
    "lat": "48.8",
    "lng": "8.33333"
  },
  {
    "country": "DE",
    "name": "Gägelow",
    "lat": "53.68558",
    "lng": "11.89639"
  },
  {
    "country": "DE",
    "name": "Gadheim",
    "lat": "49.84584",
    "lng": "9.90566"
  },
  {
    "country": "DE",
    "name": "Gadebusch",
    "lat": "53.70137",
    "lng": "11.11676"
  },
  {
    "country": "DE",
    "name": "Gachenbach",
    "lat": "48.5",
    "lng": "11.23333"
  },
  {
    "country": "DE",
    "name": "Gablingen",
    "lat": "48.45",
    "lng": "10.81667"
  },
  {
    "country": "DE",
    "name": "Gablenz",
    "lat": "51.53333",
    "lng": "14.66667"
  },
  {
    "country": "DE",
    "name": "Bad Füssing",
    "lat": "48.351",
    "lng": "13.312"
  },
  {
    "country": "DE",
    "name": "Fußgönheim",
    "lat": "49.46111",
    "lng": "8.29222"
  },
  {
    "country": "DE",
    "name": "Füssen",
    "lat": "47.57143",
    "lng": "10.70171"
  },
  {
    "country": "DE",
    "name": "Furtwangen im Schwarzwald",
    "lat": "48.05156",
    "lng": "8.20715"
  },
  {
    "country": "DE",
    "name": "Furth im Wald",
    "lat": "49.30955",
    "lng": "12.84156"
  },
  {
    "country": "DE",
    "name": "Fürthen",
    "lat": "50.78333",
    "lng": "7.66667"
  },
  {
    "country": "DE",
    "name": "Fürth",
    "lat": "49.65083",
    "lng": "8.78472"
  },
  {
    "country": "DE",
    "name": "Fürth",
    "lat": "49.47593",
    "lng": "10.98856"
  },
  {
    "country": "DE",
    "name": "Furth",
    "lat": "48.40616",
    "lng": "12.38121"
  },
  {
    "country": "DE",
    "name": "Fürstenzell",
    "lat": "48.52163",
    "lng": "13.31749"
  },
  {
    "country": "DE",
    "name": "Fürstenwalde",
    "lat": "52.36067",
    "lng": "14.06185"
  },
  {
    "country": "DE",
    "name": "Fürstenstein",
    "lat": "48.71667",
    "lng": "13.33333"
  },
  {
    "country": "DE",
    "name": "Fürstenhausen",
    "lat": "49.24075",
    "lng": "6.86817"
  },
  {
    "country": "DE",
    "name": "Fürstenfeldbruck",
    "lat": "48.17904",
    "lng": "11.2547"
  },
  {
    "country": "DE",
    "name": "Fürsteneck",
    "lat": "48.71667",
    "lng": "13.46667"
  },
  {
    "country": "DE",
    "name": "Fürstenberg",
    "lat": "53.18427",
    "lng": "13.14442"
  },
  {
    "country": "DE",
    "name": "Fürstenberg",
    "lat": "51.73333",
    "lng": "9.4"
  },
  {
    "country": "DE",
    "name": "Fürstenau",
    "lat": "52.51667",
    "lng": "7.6767"
  },
  {
    "country": "DE",
    "name": "Fürfeld",
    "lat": "49.77737",
    "lng": "7.89264"
  },
  {
    "country": "DE",
    "name": "Fünfstetten",
    "lat": "48.83215",
    "lng": "10.7654"
  },
  {
    "country": "DE",
    "name": "Fuldatal",
    "lat": "51.38333",
    "lng": "9.56667"
  },
  {
    "country": "DE",
    "name": "Fulda",
    "lat": "50.55162",
    "lng": "9.67518"
  },
  {
    "country": "DE",
    "name": "Fuhlsbüttel",
    "lat": "53.63459",
    "lng": "10.01608"
  },
  {
    "country": "DE",
    "name": "Fuchsstadt",
    "lat": "50.10825",
    "lng": "9.9337"
  },
  {
    "country": "DE",
    "name": "Fuchsmühl",
    "lat": "49.92265",
    "lng": "12.14582"
  },
  {
    "country": "DE",
    "name": "Frose",
    "lat": "51.79581",
    "lng": "11.37914"
  },
  {
    "country": "DE",
    "name": "Frontenhausen",
    "lat": "48.54628",
    "lng": "12.53118"
  },
  {
    "country": "DE",
    "name": "Fronhausen",
    "lat": "50.7",
    "lng": "8.7"
  },
  {
    "country": "DE",
    "name": "Fröndenberg",
    "lat": "51.47563",
    "lng": "7.76946"
  },
  {
    "country": "DE",
    "name": "Frohnau",
    "lat": "52.63336",
    "lng": "13.29024"
  },
  {
    "country": "DE",
    "name": "Frohburg",
    "lat": "51.05719",
    "lng": "12.55746"
  },
  {
    "country": "DE",
    "name": "Fritzlar",
    "lat": "51.13181",
    "lng": "9.27557"
  },
  {
    "country": "DE",
    "name": "Frittlingen",
    "lat": "48.12709",
    "lng": "8.70774"
  },
  {
    "country": "DE",
    "name": "Friolzheim",
    "lat": "48.83333",
    "lng": "8.83333"
  },
  {
    "country": "DE",
    "name": "Friesoythe",
    "lat": "53.0226",
    "lng": "7.85764"
  },
  {
    "country": "DE",
    "name": "Friesenried",
    "lat": "47.87477",
    "lng": "10.53464"
  },
  {
    "country": "DE",
    "name": "Friesenhagen",
    "lat": "50.90377",
    "lng": "7.80961"
  },
  {
    "country": "DE",
    "name": "Friesack",
    "lat": "52.73764",
    "lng": "12.57969"
  },
  {
    "country": "DE",
    "name": "Friemar",
    "lat": "50.97702",
    "lng": "10.78851"
  },
  {
    "country": "DE",
    "name": "Frielendorf",
    "lat": "50.97073",
    "lng": "9.32269"
  },
  {
    "country": "DE",
    "name": "Friedrichsthal",
    "lat": "49.32786",
    "lng": "7.09622"
  },
  {
    "country": "DE",
    "name": "Friedrichstadt",
    "lat": "51.88751",
    "lng": "12.66947"
  },
  {
    "country": "DE",
    "name": "Friedrichstadt",
    "lat": "54.37566",
    "lng": "9.08672"
  },
  {
    "country": "DE",
    "name": "Friedrichskoog",
    "lat": "54.01667",
    "lng": "8.91667"
  },
  {
    "country": "DE",
    "name": "Friedrichshain",
    "lat": "52.51559",
    "lng": "13.45482"
  },
  {
    "country": "DE",
    "name": "Friedrichshagen",
    "lat": "52.45052",
    "lng": "13.62463"
  },
  {
    "country": "DE",
    "name": "Friedrichshafen",
    "lat": "47.65689",
    "lng": "9.47554"
  },
  {
    "country": "DE",
    "name": "Friedrichsfelde",
    "lat": "52.50575",
    "lng": "13.50812"
  },
  {
    "country": "DE",
    "name": "Friedrichsdorf",
    "lat": "50.24962",
    "lng": "8.64281"
  },
  {
    "country": "DE",
    "name": "Friedrichsbrunn",
    "lat": "51.69028",
    "lng": "11.03737"
  },
  {
    "country": "DE",
    "name": "Friedrichroda",
    "lat": "50.85754",
    "lng": "10.56507"
  },
  {
    "country": "DE",
    "name": "Friedland",
    "lat": "53.67028",
    "lng": "13.554"
  },
  {
    "country": "DE",
    "name": "Friedland",
    "lat": "52.10493",
    "lng": "14.26399"
  },
  {
    "country": "DE",
    "name": "Gemeinde Friedland",
    "lat": "51.41667",
    "lng": "9.93333"
  },
  {
    "country": "DE",
    "name": "Friedewald",
    "lat": "50.88333",
    "lng": "9.86667"
  },
  {
    "country": "DE",
    "name": "Friedewald",
    "lat": "50.71106",
    "lng": "7.9604"
  },
  {
    "country": "DE",
    "name": "Friedersdorf",
    "lat": "51.64809",
    "lng": "12.36555"
  },
  {
    "country": "DE",
    "name": "Friedersdorf",
    "lat": "51.02416",
    "lng": "14.56246"
  },
  {
    "country": "DE",
    "name": "Friedenweiler",
    "lat": "47.91778",
    "lng": "8.25627"
  },
  {
    "country": "DE",
    "name": "Friedenfels",
    "lat": "49.8826",
    "lng": "12.10124"
  },
  {
    "country": "DE",
    "name": "Friedenau",
    "lat": "52.47133",
    "lng": "13.32813"
  },
  {
    "country": "DE",
    "name": "Friedelsheim",
    "lat": "49.44694",
    "lng": "8.22306"
  },
  {
    "country": "DE",
    "name": "Friedeburg",
    "lat": "53.45",
    "lng": "7.83333"
  },
  {
    "country": "DE",
    "name": "Friedberg",
    "lat": "50.33739",
    "lng": "8.75591"
  },
  {
    "country": "DE",
    "name": "Friedberg",
    "lat": "48.35693",
    "lng": "10.98461"
  },
  {
    "country": "DE",
    "name": "Fridolfing",
    "lat": "47.99773",
    "lng": "12.82628"
  },
  {
    "country": "DE",
    "name": "Fridingen an der Donau",
    "lat": "48.01955",
    "lng": "8.92322"
  },
  {
    "country": "DE",
    "name": "Frickingen",
    "lat": "47.81438",
    "lng": "9.27349"
  },
  {
    "country": "DE",
    "name": "Frickenhausen",
    "lat": "49.67089",
    "lng": "10.09268"
  },
  {
    "country": "DE",
    "name": "Frickenhausen",
    "lat": "48.59353",
    "lng": "9.36005"
  },
  {
    "country": "DE",
    "name": "Freyung",
    "lat": "48.80952",
    "lng": "13.54768"
  },
  {
    "country": "DE",
    "name": "Freystadt",
    "lat": "49.20007",
    "lng": "11.33032"
  },
  {
    "country": "DE",
    "name": "Freyburg",
    "lat": "51.21362",
    "lng": "11.76804"
  },
  {
    "country": "DE",
    "name": "Freudental",
    "lat": "49.00972",
    "lng": "9.05917"
  },
  {
    "country": "DE",
    "name": "Freudenstadt",
    "lat": "48.46695",
    "lng": "8.41371"
  },
  {
    "country": "DE",
    "name": "Freudenburg",
    "lat": "49.54348",
    "lng": "6.53292"
  },
  {
    "country": "DE",
    "name": "Freudenberg",
    "lat": "50.89741",
    "lng": "7.87415"
  },
  {
    "country": "DE",
    "name": "Freudenberg",
    "lat": "49.75349",
    "lng": "9.32748"
  },
  {
    "country": "DE",
    "name": "Freudenberg",
    "lat": "49.48333",
    "lng": "11.98333"
  },
  {
    "country": "DE",
    "name": "Freren",
    "lat": "52.487",
    "lng": "7.54313"
  },
  {
    "country": "DE",
    "name": "Frensdorf",
    "lat": "49.81667",
    "lng": "10.86667"
  },
  {
    "country": "DE",
    "name": "Fremdingen",
    "lat": "48.97241",
    "lng": "10.45754"
  },
  {
    "country": "DE",
    "name": "Freital",
    "lat": "51.00166",
    "lng": "13.6488"
  },
  {
    "country": "DE",
    "name": "Freising",
    "lat": "48.40351",
    "lng": "11.74876"
  },
  {
    "country": "DE",
    "name": "Freisen",
    "lat": "49.55",
    "lng": "7.25"
  },
  {
    "country": "DE",
    "name": "Freisbach",
    "lat": "49.27167",
    "lng": "8.27194"
  },
  {
    "country": "DE",
    "name": "Freinsheim",
    "lat": "49.50649",
    "lng": "8.21186"
  },
  {
    "country": "DE",
    "name": "Frei-Laubersheim",
    "lat": "49.8",
    "lng": "7.9"
  },
  {
    "country": "DE",
    "name": "Freilassing",
    "lat": "47.84085",
    "lng": "12.98114"
  },
  {
    "country": "DE",
    "name": "Freihung",
    "lat": "49.62134",
    "lng": "11.90817"
  },
  {
    "country": "DE",
    "name": "Freienwill",
    "lat": "54.72752",
    "lng": "9.49414"
  },
  {
    "country": "DE",
    "name": "Freiensteinau",
    "lat": "50.42509",
    "lng": "9.40267"
  },
  {
    "country": "DE",
    "name": "Freienbessingen",
    "lat": "51.23333",
    "lng": "10.76667"
  },
  {
    "country": "DE",
    "name": "Freiburg",
    "lat": "47.9959",
    "lng": "7.85222"
  },
  {
    "country": "DE",
    "name": "Freiburg",
    "lat": "53.82529",
    "lng": "9.28803"
  },
  {
    "country": "DE",
    "name": "Freiberg am Neckar",
    "lat": "48.93196",
    "lng": "9.2024"
  },
  {
    "country": "DE",
    "name": "Freiberg",
    "lat": "50.91089",
    "lng": "13.33881"
  },
  {
    "country": "DE",
    "name": "Freden",
    "lat": "51.92771",
    "lng": "9.8935"
  },
  {
    "country": "DE",
    "name": "Bad Fredeburg",
    "lat": "51.1893",
    "lng": "8.30978"
  },
  {
    "country": "DE",
    "name": "Freckenfeld",
    "lat": "49.065",
    "lng": "8.11389"
  },
  {
    "country": "DE",
    "name": "Frechen",
    "lat": "50.91485",
    "lng": "6.8118"
  },
  {
    "country": "DE",
    "name": "Fraureuth",
    "lat": "50.7",
    "lng": "12.35"
  },
  {
    "country": "DE",
    "name": "Fraunberg",
    "lat": "48.36667",
    "lng": "12"
  },
  {
    "country": "DE",
    "name": "Frauenwald",
    "lat": "50.5843",
    "lng": "10.85841"
  },
  {
    "country": "DE",
    "name": "Frauenstein",
    "lat": "50.80279",
    "lng": "13.5379"
  },
  {
    "country": "DE",
    "name": "Frauenprießnitz",
    "lat": "51.01667",
    "lng": "11.73333"
  },
  {
    "country": "DE",
    "name": "Fraueneuharting",
    "lat": "48.03873",
    "lng": "12.0478"
  },
  {
    "country": "DE",
    "name": "Frauenau",
    "lat": "48.98895",
    "lng": "13.30067"
  },
  {
    "country": "DE",
    "name": "Frasdorf",
    "lat": "47.80376",
    "lng": "12.28512"
  },
  {
    "country": "DE",
    "name": "Franzburg",
    "lat": "54.18501",
    "lng": "12.8821"
  },
  {
    "country": "DE",
    "name": "Frankleben",
    "lat": "51.31144",
    "lng": "11.92932"
  },
  {
    "country": "DE",
    "name": "Fränkisch-Crumbach",
    "lat": "49.74611",
    "lng": "8.85861"
  },
  {
    "country": "DE",
    "name": "Frankfurt am Main",
    "lat": "50.11552",
    "lng": "8.68417"
  },
  {
    "country": "DE",
    "name": "Frankfurt (Oder)",
    "lat": "52.34714",
    "lng": "14.55062"
  },
  {
    "country": "DE",
    "name": "Frankenwinheim",
    "lat": "49.88733",
    "lng": "10.31432"
  },
  {
    "country": "DE",
    "name": "Frankenthal",
    "lat": "51.13129",
    "lng": "14.10893"
  },
  {
    "country": "DE",
    "name": "Frankenthal",
    "lat": "49.53414",
    "lng": "8.35357"
  },
  {
    "country": "DE",
    "name": "Frankenstein",
    "lat": "50.90064",
    "lng": "13.20933"
  },
  {
    "country": "DE",
    "name": "Frankenstein",
    "lat": "49.44015",
    "lng": "7.97744"
  },
  {
    "country": "DE",
    "name": "Frankenheim",
    "lat": "50.54452",
    "lng": "10.06828"
  },
  {
    "country": "DE",
    "name": "Frankenberg",
    "lat": "51.0589",
    "lng": "8.80077"
  },
  {
    "country": "DE",
    "name": "Frankenberg",
    "lat": "50.91297",
    "lng": "13.04011"
  },
  {
    "country": "DE",
    "name": "Frankenau",
    "lat": "51.09269",
    "lng": "8.93447"
  },
  {
    "country": "DE",
    "name": "Frammersbach",
    "lat": "50.06468",
    "lng": "9.46888"
  },
  {
    "country": "DE",
    "name": "Framersheim",
    "lat": "49.75806",
    "lng": "8.17417"
  },
  {
    "country": "DE",
    "name": "Forstinning",
    "lat": "48.16866",
    "lng": "11.91244"
  },
  {
    "country": "DE",
    "name": "Forst",
    "lat": "51.73544",
    "lng": "14.63971"
  },
  {
    "country": "DE",
    "name": "Forst",
    "lat": "49.15861",
    "lng": "8.58083"
  },
  {
    "country": "DE",
    "name": "Föritz",
    "lat": "50.34174",
    "lng": "11.2318"
  },
  {
    "country": "DE",
    "name": "Förderstedt",
    "lat": "51.89717",
    "lng": "11.63349"
  },
  {
    "country": "DE",
    "name": "Forchtenberg",
    "lat": "49.28867",
    "lng": "9.56026"
  },
  {
    "country": "DE",
    "name": "Forchheim",
    "lat": "49.71754",
    "lng": "11.05877"
  },
  {
    "country": "DE",
    "name": "Forchheim",
    "lat": "48.16667",
    "lng": "7.7"
  },
  {
    "country": "DE",
    "name": "Forbach",
    "lat": "48.68333",
    "lng": "8.35"
  },
  {
    "country": "DE",
    "name": "Föhren",
    "lat": "49.85929",
    "lng": "6.7648"
  },
  {
    "country": "DE",
    "name": "Fockbek",
    "lat": "54.3",
    "lng": "9.6"
  },
  {
    "country": "DE",
    "name": "Flossenbürg",
    "lat": "49.73333",
    "lng": "12.35"
  },
  {
    "country": "DE",
    "name": "Floß",
    "lat": "49.72395",
    "lng": "12.27593"
  },
  {
    "country": "DE",
    "name": "Flörsheim",
    "lat": "50.01311",
    "lng": "8.42779"
  },
  {
    "country": "DE",
    "name": "Flonheim",
    "lat": "49.785",
    "lng": "8.04"
  },
  {
    "country": "DE",
    "name": "Flomborn",
    "lat": "49.69056",
    "lng": "8.14917"
  },
  {
    "country": "DE",
    "name": "Flöha",
    "lat": "50.85613",
    "lng": "13.07407"
  },
  {
    "country": "DE",
    "name": "Flintsbach",
    "lat": "47.72576",
    "lng": "12.12419"
  },
  {
    "country": "DE",
    "name": "Flintbek",
    "lat": "54.25",
    "lng": "10.06667"
  },
  {
    "country": "DE",
    "name": "Flieden",
    "lat": "50.42389",
    "lng": "9.5666"
  },
  {
    "country": "DE",
    "name": "Flessau",
    "lat": "52.75996",
    "lng": "11.67093"
  },
  {
    "country": "DE",
    "name": "Flensburg",
    "lat": "54.78431",
    "lng": "9.43961"
  },
  {
    "country": "DE",
    "name": "Flein",
    "lat": "49.10306",
    "lng": "9.21083"
  },
  {
    "country": "DE",
    "name": "Fleckeby",
    "lat": "54.48333",
    "lng": "9.7"
  },
  {
    "country": "DE",
    "name": "Flechtingen",
    "lat": "52.33083",
    "lng": "11.24176"
  },
  {
    "country": "DE",
    "name": "Flammersfeld",
    "lat": "50.64711",
    "lng": "7.52713"
  },
  {
    "country": "DE",
    "name": "Fladungen",
    "lat": "50.52054",
    "lng": "10.14581"
  },
  {
    "country": "DE",
    "name": "Flacht",
    "lat": "50.34528",
    "lng": "8.05028"
  },
  {
    "country": "DE",
    "name": "Flachslanden",
    "lat": "49.39845",
    "lng": "10.51323"
  },
  {
    "country": "DE",
    "name": "Fischerbach",
    "lat": "48.28687",
    "lng": "8.10959"
  },
  {
    "country": "DE",
    "name": "Fischbachau",
    "lat": "47.71952",
    "lng": "11.95081"
  },
  {
    "country": "DE",
    "name": "Fischbach",
    "lat": "49.08771",
    "lng": "7.7116"
  },
  {
    "country": "DE",
    "name": "Fischach",
    "lat": "48.29047",
    "lng": "10.65592"
  },
  {
    "country": "DE",
    "name": "Fintel",
    "lat": "53.17188",
    "lng": "9.66969"
  },
  {
    "country": "DE",
    "name": "Finsterwalde",
    "lat": "51.63388",
    "lng": "13.70662"
  },
  {
    "country": "DE",
    "name": "Finsterbergen",
    "lat": "50.83464",
    "lng": "10.58916"
  },
  {
    "country": "DE",
    "name": "Finsing",
    "lat": "48.21615",
    "lng": "11.82412"
  },
  {
    "country": "DE",
    "name": "Finnentrop",
    "lat": "51.168",
    "lng": "7.973"
  },
  {
    "country": "DE",
    "name": "Filsum",
    "lat": "53.24213",
    "lng": "7.62785"
  },
  {
    "country": "DE",
    "name": "Fichtenwalde",
    "lat": "52.28038",
    "lng": "12.88349"
  },
  {
    "country": "DE",
    "name": "Fichtenberg",
    "lat": "48.98601",
    "lng": "9.71199"
  },
  {
    "country": "DE",
    "name": "Fichtelberg",
    "lat": "50.00288",
    "lng": "11.85425"
  },
  {
    "country": "DE",
    "name": "Stuttgart Feuerbach",
    "lat": "48.80867",
    "lng": "9.15719"
  },
  {
    "country": "DE",
    "name": "Feuchtwangen",
    "lat": "49.16287",
    "lng": "10.3385"
  },
  {
    "country": "DE",
    "name": "Feucht",
    "lat": "49.37597",
    "lng": "11.21433"
  },
  {
    "country": "DE",
    "name": "Ferdinandshof",
    "lat": "53.66124",
    "lng": "13.88724"
  },
  {
    "country": "DE",
    "name": "Felsberg",
    "lat": "51.13763",
    "lng": "9.42139"
  },
  {
    "country": "DE",
    "name": "Felm",
    "lat": "54.41667",
    "lng": "10.05"
  },
  {
    "country": "DE",
    "name": "Fellheim",
    "lat": "48.0728",
    "lng": "10.15224"
  },
  {
    "country": "DE",
    "name": "Fellbach",
    "lat": "48.80912",
    "lng": "9.27697"
  },
  {
    "country": "DE",
    "name": "Fell",
    "lat": "49.76667",
    "lng": "6.78333"
  },
  {
    "country": "DE",
    "name": "Feldkirchen-Westerham",
    "lat": "47.90748",
    "lng": "11.84266"
  },
  {
    "country": "DE",
    "name": "Feldkirchen",
    "lat": "48.14811",
    "lng": "11.731"
  },
  {
    "country": "DE",
    "name": "Felde",
    "lat": "54.3",
    "lng": "9.93333"
  },
  {
    "country": "DE",
    "name": "Feldberg",
    "lat": "47.77435",
    "lng": "7.64142"
  },
  {
    "country": "DE",
    "name": "Feldafing",
    "lat": "47.94602",
    "lng": "11.29326"
  },
  {
    "country": "DE",
    "name": "Feilitzsch",
    "lat": "50.36667",
    "lng": "11.93333"
  },
  {
    "country": "DE",
    "name": "Feilbingert",
    "lat": "49.76667",
    "lng": "7.8"
  },
  {
    "country": "DE",
    "name": "Fehrbellin",
    "lat": "52.8135",
    "lng": "12.7644"
  },
  {
    "country": "DE",
    "name": "Fedderwarden",
    "lat": "53.56142",
    "lng": "8.04371"
  },
  {
    "country": "DE",
    "name": "Faulbach",
    "lat": "49.78528",
    "lng": "9.44417"
  },
  {
    "country": "DE",
    "name": "Faßberg",
    "lat": "52.9",
    "lng": "10.16667"
  },
  {
    "country": "DE",
    "name": "Farnstädt",
    "lat": "51.43333",
    "lng": "11.56667"
  },
  {
    "country": "DE",
    "name": "Farchant",
    "lat": "47.53036",
    "lng": "11.11151"
  },
  {
    "country": "DE",
    "name": "Fambach",
    "lat": "50.73333",
    "lng": "10.36667"
  },
  {
    "country": "DE",
    "name": "Bad Fallingbostel",
    "lat": "52.86641",
    "lng": "9.69558"
  },
  {
    "country": "DE",
    "name": "Falkenstein",
    "lat": "50.47788",
    "lng": "12.37129"
  },
  {
    "country": "DE",
    "name": "Falkenstein",
    "lat": "49.0975",
    "lng": "12.48802"
  },
  {
    "country": "DE",
    "name": "Falkensee",
    "lat": "52.56014",
    "lng": "13.0927"
  },
  {
    "country": "DE",
    "name": "Falkenhain",
    "lat": "51.39888",
    "lng": "12.87083"
  },
  {
    "country": "DE",
    "name": "Falkenfels",
    "lat": "49.00415",
    "lng": "12.5948"
  },
  {
    "country": "DE",
    "name": "Falkenberg",
    "lat": "52.568",
    "lng": "13.54597"
  },
  {
    "country": "DE",
    "name": "Falkenberg",
    "lat": "52.8051",
    "lng": "13.95804"
  },
  {
    "country": "DE",
    "name": "Falkenberg",
    "lat": "51.58557",
    "lng": "13.24347"
  },
  {
    "country": "DE",
    "name": "Falkenberg",
    "lat": "48.46154",
    "lng": "12.73049"
  },
  {
    "country": "DE",
    "name": "Falkenau",
    "lat": "50.85559",
    "lng": "13.11718"
  },
  {
    "country": "DE",
    "name": "Faid",
    "lat": "50.14454",
    "lng": "7.11951"
  },
  {
    "country": "DE",
    "name": "Fahrenzhausen",
    "lat": "48.35317",
    "lng": "11.55521"
  },
  {
    "country": "DE",
    "name": "Fahrenkrug",
    "lat": "53.95",
    "lng": "10.25"
  },
  {
    "country": "DE",
    "name": "Fahrenbach",
    "lat": "49.43139",
    "lng": "9.15056"
  },
  {
    "country": "DE",
    "name": "Fahrdorf",
    "lat": "54.5",
    "lng": "9.6"
  },
  {
    "country": "DE",
    "name": "Fachbach",
    "lat": "50.33333",
    "lng": "7.68333"
  },
  {
    "country": "DE",
    "name": "Eystrup",
    "lat": "52.77935",
    "lng": "9.21315"
  },
  {
    "country": "DE",
    "name": "Eyendorf",
    "lat": "53.2",
    "lng": "10.15"
  },
  {
    "country": "DE",
    "name": "Eydelstedt",
    "lat": "52.69241",
    "lng": "8.54668"
  },
  {
    "country": "DE",
    "name": "Evessen",
    "lat": "52.18888",
    "lng": "10.71081"
  },
  {
    "country": "DE",
    "name": "Everswinkel",
    "lat": "51.92595",
    "lng": "7.8469"
  },
  {
    "country": "DE",
    "name": "Eutingen",
    "lat": "48.91246",
    "lng": "8.74898"
  },
  {
    "country": "DE",
    "name": "Eutin",
    "lat": "54.14054",
    "lng": "10.60751"
  },
  {
    "country": "DE",
    "name": "Eußenheim",
    "lat": "49.98589",
    "lng": "9.80899"
  },
  {
    "country": "DE",
    "name": "Euskirchen",
    "lat": "50.66057",
    "lng": "6.78722"
  },
  {
    "country": "DE",
    "name": "Eurasburg",
    "lat": "48.33333",
    "lng": "11.08333"
  },
  {
    "country": "DE",
    "name": "Eurasburg",
    "lat": "47.85389",
    "lng": "11.40587"
  },
  {
    "country": "DE",
    "name": "Euerdorf",
    "lat": "50.14853",
    "lng": "10.02331"
  },
  {
    "country": "DE",
    "name": "Euerbach",
    "lat": "50.06199",
    "lng": "10.13695"
  },
  {
    "country": "DE",
    "name": "Etzenricht",
    "lat": "49.63333",
    "lng": "12.1"
  },
  {
    "country": "DE",
    "name": "Etzelwang",
    "lat": "49.5276",
    "lng": "11.58603"
  },
  {
    "country": "DE",
    "name": "Etzbach",
    "lat": "50.77831",
    "lng": "7.688"
  },
  {
    "country": "DE",
    "name": "Ettringen",
    "lat": "50.35",
    "lng": "7.21667"
  },
  {
    "country": "DE",
    "name": "Ettlingen",
    "lat": "48.94094",
    "lng": "8.40763"
  },
  {
    "country": "DE",
    "name": "Ettenheim",
    "lat": "48.25696",
    "lng": "7.81247"
  },
  {
    "country": "DE",
    "name": "Estorf",
    "lat": "53.57601",
    "lng": "9.20271"
  },
  {
    "country": "DE",
    "name": "Estorf",
    "lat": "52.5885",
    "lng": "9.14147"
  },
  {
    "country": "DE",
    "name": "Esthal",
    "lat": "49.38333",
    "lng": "7.98333"
  },
  {
    "country": "DE",
    "name": "Esterwegen",
    "lat": "52.99288",
    "lng": "7.63327"
  },
  {
    "country": "DE",
    "name": "Estenfeld",
    "lat": "49.82896",
    "lng": "10.00588"
  },
  {
    "country": "DE",
    "name": "Esslingen",
    "lat": "48.73961",
    "lng": "9.30473"
  },
  {
    "country": "DE",
    "name": "Essingen",
    "lat": "49.23583",
    "lng": "8.17472"
  },
  {
    "country": "DE",
    "name": "Essingen",
    "lat": "48.80859",
    "lng": "10.02773"
  },
  {
    "country": "DE",
    "name": "Essing",
    "lat": "48.93467",
    "lng": "11.78972"
  },
  {
    "country": "DE",
    "name": "Essenheim",
    "lat": "49.93056",
    "lng": "8.15556"
  },
  {
    "country": "DE",
    "name": "Essenbach",
    "lat": "48.61332",
    "lng": "12.21833"
  },
  {
    "country": "DE",
    "name": "Essen",
    "lat": "52.72258",
    "lng": "7.9371"
  },
  {
    "country": "DE",
    "name": "Essen",
    "lat": "51.45657",
    "lng": "7.01228"
  },
  {
    "country": "DE",
    "name": "Esselbach",
    "lat": "49.85528",
    "lng": "9.52583"
  },
  {
    "country": "DE",
    "name": "Essel",
    "lat": "52.69131",
    "lng": "9.64141"
  },
  {
    "country": "DE",
    "name": "Espenhain",
    "lat": "51.18926",
    "lng": "12.47885"
  },
  {
    "country": "DE",
    "name": "Espenau",
    "lat": "51.39664",
    "lng": "9.47021"
  },
  {
    "country": "DE",
    "name": "Espelkamp",
    "lat": "52.38251",
    "lng": "8.62127"
  },
  {
    "country": "DE",
    "name": "Eslohe",
    "lat": "51.25369",
    "lng": "8.16949"
  },
  {
    "country": "DE",
    "name": "Eslarn",
    "lat": "49.58345",
    "lng": "12.52156"
  },
  {
    "country": "DE",
    "name": "Esens",
    "lat": "53.64866",
    "lng": "7.61267"
  },
  {
    "country": "DE",
    "name": "Eschweiler",
    "lat": "50.81854",
    "lng": "6.27184"
  },
  {
    "country": "DE",
    "name": "Eschwege",
    "lat": "51.18386",
    "lng": "10.05329"
  },
  {
    "country": "DE",
    "name": "Eschlkam",
    "lat": "49.29883",
    "lng": "12.91573"
  },
  {
    "country": "DE",
    "name": "Eschershausen",
    "lat": "51.92664",
    "lng": "9.64282"
  },
  {
    "country": "DE",
    "name": "Eschenlohe",
    "lat": "48.01731",
    "lng": "12.03012"
  },
  {
    "country": "DE",
    "name": "Eschenbach",
    "lat": "48.65264",
    "lng": "9.67037"
  },
  {
    "country": "DE",
    "name": "Eschelbronn",
    "lat": "49.31944",
    "lng": "8.86528"
  },
  {
    "country": "DE",
    "name": "Eschede",
    "lat": "52.73494",
    "lng": "10.2354"
  },
  {
    "country": "DE",
    "name": "Escheburg",
    "lat": "53.46667",
    "lng": "10.31667"
  },
  {
    "country": "DE",
    "name": "Eschborn",
    "lat": "50.14328",
    "lng": "8.57111"
  },
  {
    "country": "DE",
    "name": "Eschau",
    "lat": "49.81889",
    "lng": "9.2592"
  },
  {
    "country": "DE",
    "name": "Eschach",
    "lat": "48.88832",
    "lng": "9.86999"
  },
  {
    "country": "DE",
    "name": "Erzhausen",
    "lat": "49.95528",
    "lng": "8.6475"
  },
  {
    "country": "DE",
    "name": "Erxleben",
    "lat": "52.21812",
    "lng": "11.24245"
  },
  {
    "country": "DE",
    "name": "Erwitte",
    "lat": "51.6127",
    "lng": "8.3384"
  },
  {
    "country": "DE",
    "name": "Ertingen",
    "lat": "48.1",
    "lng": "9.46667"
  },
  {
    "country": "DE",
    "name": "Ersingen",
    "lat": "48.2926",
    "lng": "9.8551"
  },
  {
    "country": "DE",
    "name": "Erpolzheim",
    "lat": "49.48917",
    "lng": "8.22472"
  },
  {
    "country": "DE",
    "name": "Erpel",
    "lat": "50.58333",
    "lng": "7.23333"
  },
  {
    "country": "DE",
    "name": "Erolzheim",
    "lat": "48.09001",
    "lng": "10.073"
  },
  {
    "country": "DE",
    "name": "Ernstroda",
    "lat": "50.86484",
    "lng": "10.62056"
  },
  {
    "country": "DE",
    "name": "Ernsgaden",
    "lat": "48.73333",
    "lng": "11.58333"
  },
  {
    "country": "DE",
    "name": "Erndtebrück",
    "lat": "50.98927",
    "lng": "8.25288"
  },
  {
    "country": "DE",
    "name": "Ermlitz",
    "lat": "51.39182",
    "lng": "12.15946"
  },
  {
    "country": "DE",
    "name": "Erligheim",
    "lat": "49.0225",
    "lng": "9.09722"
  },
  {
    "country": "DE",
    "name": "Erlensee",
    "lat": "50.16304",
    "lng": "8.97823"
  },
  {
    "country": "DE",
    "name": "Erlenmoos",
    "lat": "48.0653",
    "lng": "9.97567"
  },
  {
    "country": "DE",
    "name": "Erlenbach am Main",
    "lat": "49.80341",
    "lng": "9.16311"
  },
  {
    "country": "DE",
    "name": "Erlenbach",
    "lat": "49.97857",
    "lng": "9.64459"
  },
  {
    "country": "DE",
    "name": "Erlenbach",
    "lat": "49.1725",
    "lng": "9.26833"
  },
  {
    "country": "DE",
    "name": "Erlbach",
    "lat": "50.31667",
    "lng": "12.36667"
  },
  {
    "country": "DE",
    "name": "Erlbach",
    "lat": "48.3",
    "lng": "12.78333"
  },
  {
    "country": "DE",
    "name": "Erlau",
    "lat": "51.00938",
    "lng": "12.94549"
  },
  {
    "country": "DE",
    "name": "Erlangen",
    "lat": "49.59099",
    "lng": "11.00783"
  },
  {
    "country": "DE",
    "name": "Erlabrunn",
    "lat": "49.85972",
    "lng": "9.84417"
  },
  {
    "country": "DE",
    "name": "Erkrath",
    "lat": "51.22235",
    "lng": "6.90831"
  },
  {
    "country": "DE",
    "name": "Erkner",
    "lat": "52.42",
    "lng": "13.75437"
  },
  {
    "country": "DE",
    "name": "Erkheim",
    "lat": "48.0373",
    "lng": "10.3357"
  },
  {
    "country": "DE",
    "name": "Erkerode",
    "lat": "52.20485",
    "lng": "10.70982"
  },
  {
    "country": "DE",
    "name": "Erkenbrechtsweiler",
    "lat": "48.55656",
    "lng": "9.43211"
  },
  {
    "country": "DE",
    "name": "Erkelenz",
    "lat": "51.07947",
    "lng": "6.31531"
  },
  {
    "country": "DE",
    "name": "Eriskirch",
    "lat": "47.62479",
    "lng": "9.54197"
  },
  {
    "country": "DE",
    "name": "Ering",
    "lat": "48.29921",
    "lng": "13.15029"
  },
  {
    "country": "DE",
    "name": "Ergoldsbach",
    "lat": "48.69263",
    "lng": "12.20442"
  },
  {
    "country": "DE",
    "name": "Ergolding",
    "lat": "48.57654",
    "lng": "12.17102"
  },
  {
    "country": "DE",
    "name": "Ergersheim",
    "lat": "49.51667",
    "lng": "10.33333"
  },
  {
    "country": "DE",
    "name": "Erfweiler",
    "lat": "49.15712",
    "lng": "7.81231"
  },
  {
    "country": "DE",
    "name": "Erfurt",
    "lat": "50.9787",
    "lng": "11.03283"
  },
  {
    "country": "DE",
    "name": "Erftstadt",
    "lat": "50.81481",
    "lng": "6.79387"
  },
  {
    "country": "DE",
    "name": "Erfde",
    "lat": "54.3",
    "lng": "9.31667"
  },
  {
    "country": "DE",
    "name": "Eresing",
    "lat": "48.087",
    "lng": "11.02388"
  },
  {
    "country": "DE",
    "name": "Erdweg",
    "lat": "48.3318",
    "lng": "11.30339"
  },
  {
    "country": "DE",
    "name": "Erdmannhausen",
    "lat": "48.94256",
    "lng": "9.29615"
  },
  {
    "country": "DE",
    "name": "Erding",
    "lat": "48.30603",
    "lng": "11.90686"
  },
  {
    "country": "DE",
    "name": "Erbes-Büdesheim",
    "lat": "49.75444",
    "lng": "8.03139"
  },
  {
    "country": "DE",
    "name": "Erbendorf",
    "lat": "49.83983",
    "lng": "12.04593"
  },
  {
    "country": "DE",
    "name": "Erbach",
    "lat": "49.66148",
    "lng": "8.99402"
  },
  {
    "country": "DE",
    "name": "Erbach",
    "lat": "48.32841",
    "lng": "9.88752"
  },
  {
    "country": "DE",
    "name": "Eppstein",
    "lat": "50.14277",
    "lng": "8.39231"
  },
  {
    "country": "DE",
    "name": "Eppishausen",
    "lat": "48.16667",
    "lng": "10.51667"
  },
  {
    "country": "DE",
    "name": "Eppingen",
    "lat": "49.13645",
    "lng": "8.91229"
  },
  {
    "country": "DE",
    "name": "Eppertshausen",
    "lat": "49.95056",
    "lng": "8.85389"
  },
  {
    "country": "DE",
    "name": "Eppendorf",
    "lat": "50.8",
    "lng": "13.23333"
  },
  {
    "country": "DE",
    "name": "Eppenbrunn",
    "lat": "49.11667",
    "lng": "7.56667"
  },
  {
    "country": "DE",
    "name": "Eppelsheim",
    "lat": "49.70556",
    "lng": "8.16528"
  },
  {
    "country": "DE",
    "name": "Eppelheim",
    "lat": "49.4019",
    "lng": "8.63644"
  },
  {
    "country": "DE",
    "name": "Eppelborn",
    "lat": "49.4",
    "lng": "6.96667"
  },
  {
    "country": "DE",
    "name": "Epfendorf",
    "lat": "48.25",
    "lng": "8.6"
  },
  {
    "country": "DE",
    "name": "Epfenbach",
    "lat": "49.33917",
    "lng": "8.90778"
  },
  {
    "country": "DE",
    "name": "Enzklösterle",
    "lat": "48.66638",
    "lng": "8.47083"
  },
  {
    "country": "DE",
    "name": "Ensdorf",
    "lat": "49.34062",
    "lng": "11.93587"
  },
  {
    "country": "DE",
    "name": "Ensdorf",
    "lat": "49.3",
    "lng": "6.78333"
  },
  {
    "country": "DE",
    "name": "Ennigerloh",
    "lat": "51.83843",
    "lng": "8.03093"
  },
  {
    "country": "DE",
    "name": "Ennetach",
    "lat": "48.05238",
    "lng": "9.3201"
  },
  {
    "country": "DE",
    "name": "Ennepetal",
    "lat": "51.29848",
    "lng": "7.3629"
  },
  {
    "country": "DE",
    "name": "Enkirch",
    "lat": "49.98434",
    "lng": "7.12997"
  },
  {
    "country": "DE",
    "name": "Enkenbach-Alsenborn",
    "lat": "49.48333",
    "lng": "7.9"
  },
  {
    "country": "DE",
    "name": "Eningen unter Achalm",
    "lat": "48.48686",
    "lng": "9.25946"
  },
  {
    "country": "DE",
    "name": "Sankt Englmar",
    "lat": "49.00298",
    "lng": "12.82658"
  },
  {
    "country": "DE",
    "name": "Enger",
    "lat": "52.14063",
    "lng": "8.55772"
  },
  {
    "country": "DE",
    "name": "Engen",
    "lat": "47.85534",
    "lng": "8.77342"
  },
  {
    "country": "DE",
    "name": "Engelthal",
    "lat": "49.47181",
    "lng": "11.39943"
  },
  {
    "country": "DE",
    "name": "Engelskirchen",
    "lat": "50.98854",
    "lng": "7.41391"
  },
  {
    "country": "DE",
    "name": "Engelsbrand",
    "lat": "48.83333",
    "lng": "8.65"
  },
  {
    "country": "DE",
    "name": "Engelsberg",
    "lat": "48.11631",
    "lng": "12.54267"
  },
  {
    "country": "DE",
    "name": "Engeln",
    "lat": "52.79363",
    "lng": "8.91815"
  },
  {
    "country": "DE",
    "name": "Bad Endorf",
    "lat": "47.90901",
    "lng": "12.29795"
  },
  {
    "country": "DE",
    "name": "Endingen",
    "lat": "48.14221",
    "lng": "7.70049"
  },
  {
    "country": "DE",
    "name": "Bad Endbach",
    "lat": "50.75",
    "lng": "8.5"
  },
  {
    "country": "DE",
    "name": "Emtmannsberg",
    "lat": "49.89231",
    "lng": "11.64466"
  },
  {
    "country": "DE",
    "name": "Emtinghausen",
    "lat": "52.93333",
    "lng": "8.96667"
  },
  {
    "country": "DE",
    "name": "Emstek",
    "lat": "52.83333",
    "lng": "8.15"
  },
  {
    "country": "DE",
    "name": "Emskirchen",
    "lat": "49.55282",
    "lng": "10.71278"
  },
  {
    "country": "DE",
    "name": "Emsdetten",
    "lat": "52.1734",
    "lng": "7.52781"
  },
  {
    "country": "DE",
    "name": "Emsbüren",
    "lat": "52.4",
    "lng": "7.3"
  },
  {
    "country": "DE",
    "name": "Empfingen",
    "lat": "48.39258",
    "lng": "8.71036"
  },
  {
    "country": "DE",
    "name": "Emmering",
    "lat": "48.18333",
    "lng": "11.28333"
  },
  {
    "country": "DE",
    "name": "Emmering",
    "lat": "47.99762",
    "lng": "12.05642"
  },
  {
    "country": "DE",
    "name": "Emmerich",
    "lat": "51.83933",
    "lng": "6.24792"
  },
  {
    "country": "DE",
    "name": "Emmendingen",
    "lat": "48.12096",
    "lng": "7.85359"
  },
  {
    "country": "DE",
    "name": "Emmelshausen",
    "lat": "50.15484",
    "lng": "7.55185"
  },
  {
    "country": "DE",
    "name": "Emlichheim",
    "lat": "52.61667",
    "lng": "6.85"
  },
  {
    "country": "DE",
    "name": "Emkendorf",
    "lat": "54.26667",
    "lng": "9.85"
  },
  {
    "country": "DE",
    "name": "Emersacker",
    "lat": "48.48965",
    "lng": "10.6738"
  },
  {
    "country": "DE",
    "name": "Emden",
    "lat": "53.36745",
    "lng": "7.20778"
  },
  {
    "country": "DE",
    "name": "Embsen",
    "lat": "53.17606",
    "lng": "10.34625"
  },
  {
    "country": "DE",
    "name": "Elze",
    "lat": "52.58157",
    "lng": "9.73492"
  },
  {
    "country": "DE",
    "name": "Elze",
    "lat": "52.12263",
    "lng": "9.73595"
  },
  {
    "country": "DE",
    "name": "Elzach",
    "lat": "48.17247",
    "lng": "8.06992"
  },
  {
    "country": "DE",
    "name": "Elz",
    "lat": "50.41667",
    "lng": "8.03333"
  },
  {
    "country": "DE",
    "name": "Elxleben",
    "lat": "51.05",
    "lng": "10.95"
  },
  {
    "country": "DE",
    "name": "Eltville",
    "lat": "50.02858",
    "lng": "8.11754"
  },
  {
    "country": "DE",
    "name": "Eltmann",
    "lat": "49.97148",
    "lng": "10.66712"
  },
  {
    "country": "DE",
    "name": "Elterlein",
    "lat": "50.57663",
    "lng": "12.86836"
  },
  {
    "country": "DE",
    "name": "Elstra",
    "lat": "51.22172",
    "lng": "14.13201"
  },
  {
    "country": "DE",
    "name": "Elsterwerda",
    "lat": "51.46043",
    "lng": "13.52001"
  },
  {
    "country": "DE",
    "name": "Elstertrebnitz",
    "lat": "51.15",
    "lng": "12.23333"
  },
  {
    "country": "DE",
    "name": "Elsterberg",
    "lat": "50.60841",
    "lng": "12.16787"
  },
  {
    "country": "DE",
    "name": "Elster",
    "lat": "51.83011",
    "lng": "12.82424"
  },
  {
    "country": "DE",
    "name": "Elsnig",
    "lat": "51.61024",
    "lng": "12.92833"
  },
  {
    "country": "DE",
    "name": "Elsfleth",
    "lat": "53.23748",
    "lng": "8.45664"
  },
  {
    "country": "DE",
    "name": "Elsenfeld",
    "lat": "49.84289",
    "lng": "9.16355"
  },
  {
    "country": "DE",
    "name": "Elsendorf",
    "lat": "48.70757",
    "lng": "11.80982"
  },
  {
    "country": "DE",
    "name": "Elsdorf-Westermühlen",
    "lat": "54.26667",
    "lng": "9.51667"
  },
  {
    "country": "DE",
    "name": "Elsdorf",
    "lat": "53.2412",
    "lng": "9.35056"
  },
  {
    "country": "DE",
    "name": "Elsdorf",
    "lat": "50.93739",
    "lng": "6.56828"
  },
  {
    "country": "DE",
    "name": "Elmstein",
    "lat": "49.36667",
    "lng": "7.93333"
  },
  {
    "country": "DE",
    "name": "Elmshorn",
    "lat": "53.75396",
    "lng": "9.65339"
  },
  {
    "country": "DE",
    "name": "Elmenhorst",
    "lat": "54.15583",
    "lng": "12.01084"
  },
  {
    "country": "DE",
    "name": "Elmenhorst",
    "lat": "53.76667",
    "lng": "10.26667"
  },
  {
    "country": "DE",
    "name": "Ellzee",
    "lat": "48.33971",
    "lng": "10.31891"
  },
  {
    "country": "DE",
    "name": "Ellwangen",
    "lat": "48.96164",
    "lng": "10.13173"
  },
  {
    "country": "DE",
    "name": "Ellrich",
    "lat": "51.58656",
    "lng": "10.66326"
  },
  {
    "country": "DE",
    "name": "Ellingen",
    "lat": "49.06076",
    "lng": "10.96783"
  },
  {
    "country": "DE",
    "name": "Ellhofen",
    "lat": "49.14667",
    "lng": "9.32194"
  },
  {
    "country": "DE",
    "name": "Ellgau",
    "lat": "48.6",
    "lng": "10.86667"
  },
  {
    "country": "DE",
    "name": "Ellerstadt",
    "lat": "49.46167",
    "lng": "8.25944"
  },
  {
    "country": "DE",
    "name": "Ellerhoop",
    "lat": "53.72603",
    "lng": "9.76933"
  },
  {
    "country": "DE",
    "name": "Ellerbek",
    "lat": "53.65817",
    "lng": "9.86991"
  },
  {
    "country": "DE",
    "name": "Ellerau",
    "lat": "53.75",
    "lng": "9.91667"
  },
  {
    "country": "DE",
    "name": "Ellenberg",
    "lat": "49.01667",
    "lng": "10.21667"
  },
  {
    "country": "DE",
    "name": "Ellefeld",
    "lat": "50.48367",
    "lng": "12.3888"
  },
  {
    "country": "DE",
    "name": "Elkenroth",
    "lat": "50.73333",
    "lng": "7.88333"
  },
  {
    "country": "DE",
    "name": "Elgersburg",
    "lat": "50.70603",
    "lng": "10.8531"
  },
  {
    "country": "DE",
    "name": "Elfershausen",
    "lat": "50.14743",
    "lng": "9.96151"
  },
  {
    "country": "DE",
    "name": "Eldingen",
    "lat": "52.68333",
    "lng": "10.33333"
  },
  {
    "country": "DE",
    "name": "Eldena",
    "lat": "53.23191",
    "lng": "11.41804"
  },
  {
    "country": "DE",
    "name": "Elbingerode",
    "lat": "51.77039",
    "lng": "10.80557"
  },
  {
    "country": "DE",
    "name": "Eitting",
    "lat": "48.35957",
    "lng": "11.8911"
  },
  {
    "country": "DE",
    "name": "Eitorf",
    "lat": "50.76667",
    "lng": "7.45"
  },
  {
    "country": "DE",
    "name": "Eiterfeld",
    "lat": "50.76667",
    "lng": "9.8"
  },
  {
    "country": "DE",
    "name": "Eitelborn",
    "lat": "50.37806",
    "lng": "7.72333"
  },
  {
    "country": "DE",
    "name": "Eislingen",
    "lat": "48.69515",
    "lng": "9.70676"
  },
  {
    "country": "DE",
    "name": "Eisingen",
    "lat": "49.75972",
    "lng": "9.83111"
  },
  {
    "country": "DE",
    "name": "Eisingen",
    "lat": "48.95",
    "lng": "8.66667"
  },
  {
    "country": "DE",
    "name": "Eisfeld",
    "lat": "50.42648",
    "lng": "10.90695"
  },
  {
    "country": "DE",
    "name": "Eisenhüttenstadt",
    "lat": "52.15",
    "lng": "14.65"
  },
  {
    "country": "DE",
    "name": "Eisenburg",
    "lat": "48.01404",
    "lng": "10.2087"
  },
  {
    "country": "DE",
    "name": "Eisenberg",
    "lat": "50.9686",
    "lng": "11.90207"
  },
  {
    "country": "DE",
    "name": "Eisenberg",
    "lat": "49.55859",
    "lng": "8.07199"
  },
  {
    "country": "DE",
    "name": "Eisenbach",
    "lat": "47.96117",
    "lng": "8.26802"
  },
  {
    "country": "DE",
    "name": "Eisenach",
    "lat": "50.9807",
    "lng": "10.31522"
  },
  {
    "country": "DE",
    "name": "Eisdorf am Harz",
    "lat": "51.76152",
    "lng": "10.17591"
  },
  {
    "country": "DE",
    "name": "Einhausen",
    "lat": "49.67667",
    "lng": "8.54833"
  },
  {
    "country": "DE",
    "name": "Markt Einersheim",
    "lat": "49.68663",
    "lng": "10.29155"
  },
  {
    "country": "DE",
    "name": "Einbeck",
    "lat": "51.82018",
    "lng": "9.86961"
  },
  {
    "country": "DE",
    "name": "Eimke",
    "lat": "52.96601",
    "lng": "10.31324"
  },
  {
    "country": "DE",
    "name": "Eimen",
    "lat": "51.88333",
    "lng": "9.78333"
  },
  {
    "country": "DE",
    "name": "Eimeldingen",
    "lat": "47.63333",
    "lng": "7.6"
  },
  {
    "country": "DE",
    "name": "Eime",
    "lat": "52.07449",
    "lng": "9.72118"
  },
  {
    "country": "DE",
    "name": "Eilsleben",
    "lat": "52.14708",
    "lng": "11.21035"
  },
  {
    "country": "DE",
    "name": "Eilenburg",
    "lat": "51.45984",
    "lng": "12.63338"
  },
  {
    "country": "DE",
    "name": "Eil",
    "lat": "50.89362",
    "lng": "7.07967"
  },
  {
    "country": "DE",
    "name": "Eigeltingen",
    "lat": "47.85802",
    "lng": "8.89784"
  },
  {
    "country": "DE",
    "name": "Eicklingen",
    "lat": "52.55037",
    "lng": "10.18439"
  },
  {
    "country": "DE",
    "name": "Eickendorf",
    "lat": "51.94765",
    "lng": "11.67538"
  },
  {
    "country": "DE",
    "name": "Eichwalde",
    "lat": "52.36667",
    "lng": "13.61667"
  },
  {
    "country": "DE",
    "name": "Eichstetten",
    "lat": "48.09427",
    "lng": "7.74244"
  },
  {
    "country": "DE",
    "name": "Eichstätt",
    "lat": "48.88854",
    "lng": "11.19675"
  },
  {
    "country": "DE",
    "name": "Eichigt",
    "lat": "50.35",
    "lng": "12.16667"
  },
  {
    "country": "DE",
    "name": "Eichenzell",
    "lat": "50.49536",
    "lng": "9.69672"
  },
  {
    "country": "DE",
    "name": "Eichenried",
    "lat": "48.27748",
    "lng": "11.78206"
  },
  {
    "country": "DE",
    "name": "Eichendorf",
    "lat": "48.63266",
    "lng": "12.85586"
  },
  {
    "country": "DE",
    "name": "Eichenbühl",
    "lat": "49.70556",
    "lng": "9.32917"
  },
  {
    "country": "DE",
    "name": "Eichenbarleben",
    "lat": "52.16688",
    "lng": "11.40125"
  },
  {
    "country": "DE",
    "name": "Eichenau",
    "lat": "48.16667",
    "lng": "11.31667"
  },
  {
    "country": "DE",
    "name": "Eibenstock",
    "lat": "50.49431",
    "lng": "12.59978"
  },
  {
    "country": "DE",
    "name": "Eibelstadt",
    "lat": "49.72392",
    "lng": "9.99962"
  },
  {
    "country": "DE",
    "name": "Eibau",
    "lat": "50.98272",
    "lng": "14.66214"
  },
  {
    "country": "DE",
    "name": "Ehringshausen",
    "lat": "50.6",
    "lng": "8.38333"
  },
  {
    "country": "DE",
    "name": "Ehrenfriedersdorf",
    "lat": "50.64934",
    "lng": "12.97009"
  },
  {
    "country": "DE",
    "name": "Ehrenburg",
    "lat": "52.75",
    "lng": "8.7"
  },
  {
    "country": "DE",
    "name": "Ehningen",
    "lat": "48.65882",
    "lng": "8.94124"
  },
  {
    "country": "DE",
    "name": "Ehlscheid",
    "lat": "50.51448",
    "lng": "7.46655"
  },
  {
    "country": "DE",
    "name": "Ehingen",
    "lat": "48.6",
    "lng": "10.8"
  },
  {
    "country": "DE",
    "name": "Ehingen",
    "lat": "48.28259",
    "lng": "9.72749"
  },
  {
    "country": "DE",
    "name": "Ehekirchen",
    "lat": "48.63333",
    "lng": "11.1"
  },
  {
    "country": "DE",
    "name": "Egmating",
    "lat": "48.00405",
    "lng": "11.79528"
  },
  {
    "country": "DE",
    "name": "Egloffstein",
    "lat": "49.70182",
    "lng": "11.25749"
  },
  {
    "country": "DE",
    "name": "Egling",
    "lat": "48.18626",
    "lng": "10.97669"
  },
  {
    "country": "DE",
    "name": "Egling",
    "lat": "47.92316",
    "lng": "11.50517"
  },
  {
    "country": "DE",
    "name": "Eging",
    "lat": "48.46328",
    "lng": "12.18957"
  },
  {
    "country": "DE",
    "name": "Eggstätt",
    "lat": "47.92698",
    "lng": "12.37919"
  },
  {
    "country": "DE",
    "name": "Eggolsheim",
    "lat": "49.76961",
    "lng": "11.05701"
  },
  {
    "country": "DE",
    "name": "Egglkofen",
    "lat": "48.4",
    "lng": "12.45"
  },
  {
    "country": "DE",
    "name": "Egglham",
    "lat": "48.52902",
    "lng": "13.05402"
  },
  {
    "country": "DE",
    "name": "Eggesin",
    "lat": "53.67973",
    "lng": "14.07992"
  },
  {
    "country": "DE",
    "name": "Eggersdorf",
    "lat": "51.97621",
    "lng": "11.70971"
  },
  {
    "country": "DE",
    "name": "Eggenthal",
    "lat": "47.91667",
    "lng": "10.51667"
  },
  {
    "country": "DE",
    "name": "Eggenstein-Leopoldshafen",
    "lat": "49.09006",
    "lng": "8.39879"
  },
  {
    "country": "DE",
    "name": "Eggenfelden",
    "lat": "48.40509",
    "lng": "12.75752"
  },
  {
    "country": "DE",
    "name": "Eggebek",
    "lat": "54.61667",
    "lng": "9.36667"
  },
  {
    "country": "DE",
    "name": "Egg an der Günz",
    "lat": "48.08714",
    "lng": "10.28495"
  },
  {
    "country": "DE",
    "name": "Egestorf",
    "lat": "53.193",
    "lng": "10.063"
  },
  {
    "country": "DE",
    "name": "Egestorf",
    "lat": "52.28568",
    "lng": "9.51676"
  },
  {
    "country": "DE",
    "name": "Egenhofen",
    "lat": "48.28333",
    "lng": "11.16667"
  },
  {
    "country": "DE",
    "name": "Egenhausen",
    "lat": "48.56667",
    "lng": "8.61667"
  },
  {
    "country": "DE",
    "name": "Egelsbach",
    "lat": "49.96792",
    "lng": "8.66341"
  },
  {
    "country": "DE",
    "name": "Egeln",
    "lat": "51.94384",
    "lng": "11.43265"
  },
  {
    "country": "DE",
    "name": "Efringen-Kirchen",
    "lat": "47.65",
    "lng": "7.56667"
  },
  {
    "country": "DE",
    "name": "Effeltrich",
    "lat": "49.65929",
    "lng": "11.09319"
  },
  {
    "country": "DE",
    "name": "Effelder",
    "lat": "51.23948",
    "lng": "10.24778"
  },
  {
    "country": "DE",
    "name": "Edingen-Neckarhausen",
    "lat": "49.45722",
    "lng": "8.60639"
  },
  {
    "country": "DE",
    "name": "Edewecht",
    "lat": "53.12699",
    "lng": "7.98406"
  },
  {
    "country": "DE",
    "name": "Edesheim",
    "lat": "49.26333",
    "lng": "8.135"
  },
  {
    "country": "DE",
    "name": "Edersleben",
    "lat": "51.41667",
    "lng": "11.28333"
  },
  {
    "country": "DE",
    "name": "Ederheim",
    "lat": "48.80827",
    "lng": "10.46609"
  },
  {
    "country": "DE",
    "name": "Edenkoben",
    "lat": "49.28393",
    "lng": "8.12714"
  },
  {
    "country": "DE",
    "name": "Edemissen",
    "lat": "52.38702",
    "lng": "10.2614"
  },
  {
    "country": "DE",
    "name": "Edelsfeld",
    "lat": "49.57644",
    "lng": "11.69589"
  },
  {
    "country": "DE",
    "name": "Edderitz",
    "lat": "51.69933",
    "lng": "11.93712"
  },
  {
    "country": "DE",
    "name": "Eddelak",
    "lat": "53.95",
    "lng": "9.15"
  },
  {
    "country": "DE",
    "name": "Eckersdorf",
    "lat": "50.02874",
    "lng": "11.39611"
  },
  {
    "country": "DE",
    "name": "Eckernförde",
    "lat": "54.46854",
    "lng": "9.83824"
  },
  {
    "country": "DE",
    "name": "Eckartsberga",
    "lat": "51.1238",
    "lng": "11.56045"
  },
  {
    "country": "DE",
    "name": "Echzell",
    "lat": "50.38888",
    "lng": "8.88605"
  },
  {
    "country": "DE",
    "name": "Eching",
    "lat": "48.5",
    "lng": "12.06667"
  },
  {
    "country": "DE",
    "name": "Eching",
    "lat": "48.3",
    "lng": "11.61667"
  },
  {
    "country": "DE",
    "name": "Eching",
    "lat": "48.07991",
    "lng": "11.11336"
  },
  {
    "country": "DE",
    "name": "Echem",
    "lat": "53.33333",
    "lng": "10.53333"
  },
  {
    "country": "DE",
    "name": "Ebstorf",
    "lat": "53.02785",
    "lng": "10.41839"
  },
  {
    "country": "DE",
    "name": "Ebringen",
    "lat": "47.9578",
    "lng": "7.77652"
  },
  {
    "country": "DE",
    "name": "Ebnath",
    "lat": "49.95",
    "lng": "11.93333"
  },
  {
    "country": "DE",
    "name": "Ebhausen",
    "lat": "48.58333",
    "lng": "8.68333"
  },
  {
    "country": "DE",
    "name": "Ebertsheim",
    "lat": "49.56833",
    "lng": "8.10861"
  },
  {
    "country": "DE",
    "name": "Eberswalde",
    "lat": "52.83492",
    "lng": "13.81951"
  },
  {
    "country": "DE",
    "name": "Eberstadt",
    "lat": "49.18028",
    "lng": "9.32111"
  },
  {
    "country": "DE",
    "name": "Ebersdorf",
    "lat": "53.52514",
    "lng": "9.04897"
  },
  {
    "country": "DE",
    "name": "Ebersdorf",
    "lat": "50.32898",
    "lng": "11.15266"
  },
  {
    "country": "DE",
    "name": "Ebersberg",
    "lat": "48.0771",
    "lng": "11.97063"
  },
  {
    "country": "DE",
    "name": "Ebersbach an der Fils",
    "lat": "48.716",
    "lng": "9.5236"
  },
  {
    "country": "DE",
    "name": "Ebersbach",
    "lat": "51.099",
    "lng": "13.1135"
  },
  {
    "country": "DE",
    "name": "Ebersbach",
    "lat": "51.00762",
    "lng": "14.58621"
  },
  {
    "country": "DE",
    "name": "Ebernhahn",
    "lat": "50.47278",
    "lng": "7.77"
  },
  {
    "country": "DE",
    "name": "Ebermannstadt",
    "lat": "49.78154",
    "lng": "11.18168"
  },
  {
    "country": "DE",
    "name": "Ebermannsdorf",
    "lat": "49.39375",
    "lng": "11.93582"
  },
  {
    "country": "DE",
    "name": "Eberhardzell",
    "lat": "48",
    "lng": "9.81667"
  },
  {
    "country": "DE",
    "name": "Ebergötzen",
    "lat": "51.57096",
    "lng": "10.10632"
  },
  {
    "country": "DE",
    "name": "Eberdingen",
    "lat": "48.87942",
    "lng": "8.96502"
  },
  {
    "country": "DE",
    "name": "Eberbach",
    "lat": "49.4668",
    "lng": "8.99016"
  },
  {
    "country": "DE",
    "name": "Ebenweiler",
    "lat": "47.9",
    "lng": "9.51667"
  },
  {
    "country": "DE",
    "name": "Ebensfeld",
    "lat": "50.0664",
    "lng": "10.95835"
  },
  {
    "country": "DE",
    "name": "Ebendorf",
    "lat": "52.18551",
    "lng": "11.57478"
  },
  {
    "country": "DE",
    "name": "Ebelsbach",
    "lat": "49.98572",
    "lng": "10.67442"
  },
  {
    "country": "DE",
    "name": "Ebeleben",
    "lat": "51.28283",
    "lng": "10.72999"
  },
  {
    "country": "DE",
    "name": "Duvenstedt",
    "lat": "53.70806",
    "lng": "10.10444"
  },
  {
    "country": "DE",
    "name": "Dußlingen",
    "lat": "48.45357",
    "lng": "9.05552"
  },
  {
    "country": "DE",
    "name": "Düsseldorf",
    "lat": "51.22172",
    "lng": "6.77616"
  },
  {
    "country": "DE",
    "name": "Dürrwangen",
    "lat": "49.10778",
    "lng": "10.385"
  },
  {
    "country": "DE",
    "name": "Dürrröhrsdorf",
    "lat": "51.03395",
    "lng": "13.99718"
  },
  {
    "country": "DE",
    "name": "Dürrlauingen",
    "lat": "48.46666",
    "lng": "10.4286"
  },
  {
    "country": "DE",
    "name": "Dürrhennersdorf",
    "lat": "51.04863",
    "lng": "14.60383"
  },
  {
    "country": "DE",
    "name": "Dürnau",
    "lat": "48.64079",
    "lng": "9.63544"
  },
  {
    "country": "DE",
    "name": "Durmersheim",
    "lat": "48.93333",
    "lng": "8.26667"
  },
  {
    "country": "DE",
    "name": "Dürmentingen",
    "lat": "48.11667",
    "lng": "9.53333"
  },
  {
    "country": "DE",
    "name": "Durlangen",
    "lat": "48.85632",
    "lng": "9.79654"
  },
  {
    "country": "DE",
    "name": "Düren",
    "lat": "50.80434",
    "lng": "6.49299"
  },
  {
    "country": "DE",
    "name": "Dürbheim",
    "lat": "48.05623",
    "lng": "8.79344"
  },
  {
    "country": "DE",
    "name": "Durbach",
    "lat": "48.49352",
    "lng": "8.01736"
  },
  {
    "country": "DE",
    "name": "Durach",
    "lat": "47.6944",
    "lng": "10.34449"
  },
  {
    "country": "DE",
    "name": "Dunum",
    "lat": "53.6",
    "lng": "7.65"
  },
  {
    "country": "DE",
    "name": "Dünsen",
    "lat": "52.92749",
    "lng": "8.64191"
  },
  {
    "country": "DE",
    "name": "Dunningen",
    "lat": "48.21242",
    "lng": "8.50619"
  },
  {
    "country": "DE",
    "name": "Düngenheim",
    "lat": "50.26062",
    "lng": "7.16523"
  },
  {
    "country": "DE",
    "name": "Dummerstorf",
    "lat": "54.01484",
    "lng": "12.22821"
  },
  {
    "country": "DE",
    "name": "Dümmer",
    "lat": "53.57629",
    "lng": "11.20497"
  },
  {
    "country": "DE",
    "name": "Dülmen",
    "lat": "51.83149",
    "lng": "7.28075"
  },
  {
    "country": "DE",
    "name": "Duisburg",
    "lat": "51.43247",
    "lng": "6.76516"
  },
  {
    "country": "DE",
    "name": "Duingen",
    "lat": "52.00449",
    "lng": "9.69578"
  },
  {
    "country": "DE",
    "name": "Duggendorf",
    "lat": "49.11667",
    "lng": "11.91667"
  },
  {
    "country": "DE",
    "name": "Duderstadt",
    "lat": "51.51312",
    "lng": "10.25951"
  },
  {
    "country": "DE",
    "name": "Dudenhofen",
    "lat": "49.31861",
    "lng": "8.38861"
  },
  {
    "country": "DE",
    "name": "Dudeldorf",
    "lat": "49.97494",
    "lng": "6.63724"
  },
  {
    "country": "DE",
    "name": "Ducherow",
    "lat": "53.76436",
    "lng": "13.78216"
  },
  {
    "country": "DE",
    "name": "Drübeck",
    "lat": "51.8582",
    "lng": "10.71839"
  },
  {
    "country": "DE",
    "name": "Droyßig",
    "lat": "51.04247",
    "lng": "12.0259"
  },
  {
    "country": "DE",
    "name": "Drolshagen",
    "lat": "51.02358",
    "lng": "7.77355"
  },
  {
    "country": "DE",
    "name": "Drochtersen",
    "lat": "53.71015",
    "lng": "9.38463"
  },
  {
    "country": "DE",
    "name": "Driedorf",
    "lat": "50.63333",
    "lng": "8.18333"
  },
  {
    "country": "DE",
    "name": "Dresden",
    "lat": "51.05089",
    "lng": "13.73832"
  },
  {
    "country": "DE",
    "name": "Drentwede",
    "lat": "52.74388",
    "lng": "8.56504"
  },
  {
    "country": "DE",
    "name": "Drensteinfurt",
    "lat": "51.79535",
    "lng": "7.73815"
  },
  {
    "country": "DE",
    "name": "Drelsdorf",
    "lat": "54.60548",
    "lng": "9.04449"
  },
  {
    "country": "DE",
    "name": "Dreisen",
    "lat": "49.60333",
    "lng": "8.01056"
  },
  {
    "country": "DE",
    "name": "Dreis",
    "lat": "49.9409",
    "lng": "6.81845"
  },
  {
    "country": "DE",
    "name": "Dreierwalde",
    "lat": "52.33194",
    "lng": "7.50333"
  },
  {
    "country": "DE",
    "name": "Dreieich",
    "lat": "50.01997",
    "lng": "8.69611"
  },
  {
    "country": "DE",
    "name": "Dreetz",
    "lat": "52.80297",
    "lng": "12.45961"
  },
  {
    "country": "DE",
    "name": "Drebkau",
    "lat": "51.65412",
    "lng": "14.22316"
  },
  {
    "country": "DE",
    "name": "Drebach",
    "lat": "50.67583",
    "lng": "13.0162"
  },
  {
    "country": "DE",
    "name": "Dranske",
    "lat": "54.63118",
    "lng": "13.22831"
  },
  {
    "country": "DE",
    "name": "Dransfeld",
    "lat": "51.4991",
    "lng": "9.76179"
  },
  {
    "country": "DE",
    "name": "Drangstedt",
    "lat": "53.61359",
    "lng": "8.75576"
  },
  {
    "country": "DE",
    "name": "Drakenburg",
    "lat": "52.68689",
    "lng": "9.21083"
  },
  {
    "country": "DE",
    "name": "Drage",
    "lat": "53.41667",
    "lng": "10.26667"
  },
  {
    "country": "DE",
    "name": "Drachselsried",
    "lat": "49.10759",
    "lng": "13.01185"
  },
  {
    "country": "DE",
    "name": "Dotternhausen",
    "lat": "48.22848",
    "lng": "8.79228"
  },
  {
    "country": "DE",
    "name": "Dötlingen",
    "lat": "52.93333",
    "lng": "8.38333"
  },
  {
    "country": "DE",
    "name": "Dossenheim",
    "lat": "49.45028",
    "lng": "8.67472"
  },
  {
    "country": "DE",
    "name": "Dörzbach",
    "lat": "49.38355",
    "lng": "9.70732"
  },
  {
    "country": "DE",
    "name": "Dörverden",
    "lat": "52.85",
    "lng": "9.23333"
  },
  {
    "country": "DE",
    "name": "Dorum",
    "lat": "53.6879",
    "lng": "8.56734"
  },
  {
    "country": "DE",
    "name": "Dortmund",
    "lat": "51.51494",
    "lng": "7.466"
  },
  {
    "country": "DE",
    "name": "Dorsten",
    "lat": "51.66166",
    "lng": "6.96514"
  },
  {
    "country": "DE",
    "name": "Dörrenbach",
    "lat": "49.08972",
    "lng": "7.9614"
  },
  {
    "country": "DE",
    "name": "Dörpen",
    "lat": "52.96469",
    "lng": "7.32273"
  },
  {
    "country": "DE",
    "name": "Dornum",
    "lat": "53.64648",
    "lng": "7.42957"
  },
  {
    "country": "DE",
    "name": "Dornstetten",
    "lat": "48.47198",
    "lng": "8.49817"
  },
  {
    "country": "DE",
    "name": "Dornstadt",
    "lat": "48.46697",
    "lng": "9.94434"
  },
  {
    "country": "DE",
    "name": "Dornhan",
    "lat": "48.35008",
    "lng": "8.50901"
  },
  {
    "country": "DE",
    "name": "Dorndorf",
    "lat": "50.83472",
    "lng": "10.08921"
  },
  {
    "country": "DE",
    "name": "Dormitz",
    "lat": "49.59786",
    "lng": "11.11765"
  },
  {
    "country": "DE",
    "name": "Dormettingen",
    "lat": "48.23688",
    "lng": "8.77327"
  },
  {
    "country": "DE",
    "name": "Dormagen",
    "lat": "51.09683",
    "lng": "6.83167"
  },
  {
    "country": "DE",
    "name": "Dorfprozelten",
    "lat": "49.78056",
    "lng": "9.38028"
  },
  {
    "country": "DE",
    "name": "Dorfhain",
    "lat": "50.93333",
    "lng": "13.56667"
  },
  {
    "country": "DE",
    "name": "Dorfen",
    "lat": "48.27037",
    "lng": "12.16056"
  },
  {
    "country": "DE",
    "name": "Dorfchemnitz",
    "lat": "50.66363",
    "lng": "12.83651"
  },
  {
    "country": "DE",
    "name": "Dörentrup",
    "lat": "52.04109",
    "lng": "9.00278"
  },
  {
    "country": "DE",
    "name": "Donzdorf",
    "lat": "48.68544",
    "lng": "9.81053"
  },
  {
    "country": "DE",
    "name": "Donnersdorf",
    "lat": "49.96667",
    "lng": "10.41667"
  },
  {
    "country": "DE",
    "name": "Donauwörth",
    "lat": "48.71804",
    "lng": "10.7793"
  },
  {
    "country": "DE",
    "name": "Donaustauf",
    "lat": "49.03258",
    "lng": "12.20459"
  },
  {
    "country": "DE",
    "name": "Donaueschingen",
    "lat": "47.95514",
    "lng": "8.49707"
  },
  {
    "country": "DE",
    "name": "Domsühl",
    "lat": "53.48723",
    "lng": "11.77099"
  },
  {
    "country": "DE",
    "name": "Dommitzsch",
    "lat": "51.64071",
    "lng": "12.8794"
  },
  {
    "country": "DE",
    "name": "Dommershausen",
    "lat": "50.15",
    "lng": "7.4"
  },
  {
    "country": "DE",
    "name": "Dömitz",
    "lat": "53.1408",
    "lng": "11.25017"
  },
  {
    "country": "DE",
    "name": "Domersleben",
    "lat": "52.09199",
    "lng": "11.43757"
  },
  {
    "country": "DE",
    "name": "Dombühl",
    "lat": "49.25349",
    "lng": "10.28542"
  },
  {
    "country": "DE",
    "name": "Döllstädt",
    "lat": "51.08333",
    "lng": "10.81667"
  },
  {
    "country": "DE",
    "name": "Döllnitz",
    "lat": "51.40777",
    "lng": "12.02831"
  },
  {
    "country": "DE",
    "name": "Dollerup",
    "lat": "54.77798",
    "lng": "9.67981"
  },
  {
    "country": "DE",
    "name": "Dollern",
    "lat": "53.53333",
    "lng": "9.55"
  },
  {
    "country": "DE",
    "name": "Dollbergen",
    "lat": "52.40671",
    "lng": "10.18098"
  },
  {
    "country": "DE",
    "name": "Dölbau",
    "lat": "51.46701",
    "lng": "12.05735"
  },
  {
    "country": "DE",
    "name": "Dohna",
    "lat": "50.95621",
    "lng": "13.85839"
  },
  {
    "country": "DE",
    "name": "Dohma",
    "lat": "50.91667",
    "lng": "13.93333"
  },
  {
    "country": "DE",
    "name": "Döhlau",
    "lat": "50.28333",
    "lng": "11.95"
  },
  {
    "country": "DE",
    "name": "Dogern",
    "lat": "47.60952",
    "lng": "8.16713"
  },
  {
    "country": "DE",
    "name": "Dobien",
    "lat": "51.90519",
    "lng": "12.61068"
  },
  {
    "country": "DE",
    "name": "Dobersdorf",
    "lat": "54.31893",
    "lng": "10.28011"
  },
  {
    "country": "DE",
    "name": "Doberschütz",
    "lat": "51.4987",
    "lng": "12.74792"
  },
  {
    "country": "DE",
    "name": "Döbernitz",
    "lat": "51.51241",
    "lng": "12.34753"
  },
  {
    "country": "DE",
    "name": "Doberlug-Kirchhain",
    "lat": "51.62578",
    "lng": "13.56232"
  },
  {
    "country": "DE",
    "name": "Döbeln",
    "lat": "51.1221",
    "lng": "13.11027"
  },
  {
    "country": "DE",
    "name": "Dobel",
    "lat": "48.8",
    "lng": "8.5"
  },
  {
    "country": "DE",
    "name": "Dobbertin",
    "lat": "53.62306",
    "lng": "12.07466"
  },
  {
    "country": "DE",
    "name": "Ditzingen",
    "lat": "48.82672",
    "lng": "9.06703"
  },
  {
    "country": "DE",
    "name": "Dittenheim",
    "lat": "49.05536",
    "lng": "10.79201"
  },
  {
    "country": "DE",
    "name": "Dittelbrunn",
    "lat": "50.07212",
    "lng": "10.21974"
  },
  {
    "country": "DE",
    "name": "Ditfurt",
    "lat": "51.83333",
    "lng": "11.2"
  },
  {
    "country": "DE",
    "name": "Dissen",
    "lat": "52.11591",
    "lng": "8.19956"
  },
  {
    "country": "DE",
    "name": "Dischingen",
    "lat": "48.7",
    "lng": "10.36667"
  },
  {
    "country": "DE",
    "name": "Dirmstein",
    "lat": "49.56333",
    "lng": "8.24472"
  },
  {
    "country": "DE",
    "name": "Dirlewang",
    "lat": "48.00195",
    "lng": "10.50306"
  },
  {
    "country": "DE",
    "name": "Dippoldiswalde",
    "lat": "50.89621",
    "lng": "13.66905"
  },
  {
    "country": "DE",
    "name": "Dipperz",
    "lat": "50.54333",
    "lng": "9.79586"
  },
  {
    "country": "DE",
    "name": "Dippach",
    "lat": "50.91959",
    "lng": "10.04236"
  },
  {
    "country": "DE",
    "name": "Dinslaken",
    "lat": "51.56227",
    "lng": "6.7434"
  },
  {
    "country": "DE",
    "name": "Dinklage",
    "lat": "52.66223",
    "lng": "8.1244"
  },
  {
    "country": "DE",
    "name": "Dinkelscherben",
    "lat": "48.34826",
    "lng": "10.58893"
  },
  {
    "country": "DE",
    "name": "Dinkelsbühl",
    "lat": "49.06942",
    "lng": "10.31985"
  },
  {
    "country": "DE",
    "name": "Dingolshausen",
    "lat": "49.9071",
    "lng": "10.39032"
  },
  {
    "country": "DE",
    "name": "Dingolfing",
    "lat": "48.64244",
    "lng": "12.49283"
  },
  {
    "country": "DE",
    "name": "Dingelstädt",
    "lat": "51.31529",
    "lng": "10.3174"
  },
  {
    "country": "DE",
    "name": "Dillingen an der Donau",
    "lat": "48.58153",
    "lng": "10.49527"
  },
  {
    "country": "DE",
    "name": "Dillingen",
    "lat": "49.35557",
    "lng": "6.72781"
  },
  {
    "country": "DE",
    "name": "Dillenburg",
    "lat": "50.74114",
    "lng": "8.28699"
  },
  {
    "country": "DE",
    "name": "Diez",
    "lat": "50.37419",
    "lng": "8.00735"
  },
  {
    "country": "DE",
    "name": "Dietzenbach",
    "lat": "50.00976",
    "lng": "8.77783"
  },
  {
    "country": "DE",
    "name": "Dietramszell",
    "lat": "47.84871",
    "lng": "11.5953"
  },
  {
    "country": "DE",
    "name": "Dietmannsried",
    "lat": "47.80787",
    "lng": "10.28948"
  },
  {
    "country": "DE",
    "name": "Dietingen",
    "lat": "48.2048",
    "lng": "8.64864"
  },
  {
    "country": "DE",
    "name": "Dietfurt",
    "lat": "49.03578",
    "lng": "11.58624"
  },
  {
    "country": "DE",
    "name": "Dieterskirchen",
    "lat": "49.41667",
    "lng": "12.41667"
  },
  {
    "country": "DE",
    "name": "Dietersheim",
    "lat": "49.55631",
    "lng": "10.54074"
  },
  {
    "country": "DE",
    "name": "Dietersburg",
    "lat": "48.49249",
    "lng": "12.92499"
  },
  {
    "country": "DE",
    "name": "Dietenhofen",
    "lat": "49.39997",
    "lng": "10.68975"
  },
  {
    "country": "DE",
    "name": "Dietenheim",
    "lat": "48.21072",
    "lng": "10.07163"
  },
  {
    "country": "DE",
    "name": "Dießen am Ammersee",
    "lat": "47.95085",
    "lng": "11.10306"
  },
  {
    "country": "DE",
    "name": "Diespeck",
    "lat": "49.6",
    "lng": "10.63333"
  },
  {
    "country": "DE",
    "name": "Dieskau",
    "lat": "51.43553",
    "lng": "12.04035"
  },
  {
    "country": "DE",
    "name": "Diesdorf",
    "lat": "52.13075",
    "lng": "11.56483"
  },
  {
    "country": "DE",
    "name": "Dierdorf",
    "lat": "50.54647",
    "lng": "7.65271"
  },
  {
    "country": "DE",
    "name": "Diepholz",
    "lat": "52.60783",
    "lng": "8.37005"
  },
  {
    "country": "DE",
    "name": "Dienheim",
    "lat": "49.83722",
    "lng": "8.34972"
  },
  {
    "country": "DE",
    "name": "Dielheim",
    "lat": "49.28417",
    "lng": "8.73806"
  },
  {
    "country": "DE",
    "name": "Diekholzen",
    "lat": "52.09617",
    "lng": "9.91945"
  },
  {
    "country": "DE",
    "name": "Diedorf",
    "lat": "48.3532",
    "lng": "10.78206"
  },
  {
    "country": "DE",
    "name": "Dieburg",
    "lat": "49.89738",
    "lng": "8.84613"
  },
  {
    "country": "DE",
    "name": "Dieblich",
    "lat": "50.31396",
    "lng": "7.47185"
  },
  {
    "country": "DE",
    "name": "Diebach",
    "lat": "49.30912",
    "lng": "10.19188"
  },
  {
    "country": "DE",
    "name": "Didderse",
    "lat": "52.38042",
    "lng": "10.40294"
  },
  {
    "country": "DE",
    "name": "Dexheim",
    "lat": "49.84722",
    "lng": "8.31667"
  },
  {
    "country": "DE",
    "name": "Deutzen",
    "lat": "51.11217",
    "lng": "12.42541"
  },
  {
    "country": "DE",
    "name": "Deutz",
    "lat": "50.93463",
    "lng": "6.97495"
  },
  {
    "country": "DE",
    "name": "Deutsch Evern",
    "lat": "53.2",
    "lng": "10.43333"
  },
  {
    "country": "DE",
    "name": "Deuna",
    "lat": "51.3545",
    "lng": "10.47439"
  },
  {
    "country": "DE",
    "name": "Deuerling",
    "lat": "49.0372",
    "lng": "11.91045"
  },
  {
    "country": "DE",
    "name": "Deuben",
    "lat": "51.10968",
    "lng": "12.07259"
  },
  {
    "country": "DE",
    "name": "Dettum",
    "lat": "52.17246",
    "lng": "10.66807"
  },
  {
    "country": "DE",
    "name": "Dettingen unter Teck",
    "lat": "48.61667",
    "lng": "9.45"
  },
  {
    "country": "DE",
    "name": "Dettingen an der Erms",
    "lat": "48.53077",
    "lng": "9.34458"
  },
  {
    "country": "DE",
    "name": "Dettingen",
    "lat": "48.26246",
    "lng": "9.72161"
  },
  {
    "country": "DE",
    "name": "Dettighofen",
    "lat": "47.62333",
    "lng": "8.48512"
  },
  {
    "country": "DE",
    "name": "Dettenhausen",
    "lat": "48.60758",
    "lng": "9.10041"
  },
  {
    "country": "DE",
    "name": "Dettelbach",
    "lat": "49.80295",
    "lng": "10.16519"
  },
  {
    "country": "DE",
    "name": "Detmold",
    "lat": "51.93855",
    "lng": "8.87318"
  },
  {
    "country": "DE",
    "name": "Detmerode",
    "lat": "52.39016",
    "lng": "10.7448"
  },
  {
    "country": "DE",
    "name": "Detern",
    "lat": "53.20927",
    "lng": "7.67395"
  },
  {
    "country": "DE",
    "name": "Dessau",
    "lat": "51.83864",
    "lng": "12.24555"
  },
  {
    "country": "DE",
    "name": "Dersum",
    "lat": "52.96112",
    "lng": "7.27394"
  },
  {
    "country": "DE",
    "name": "Dersekow",
    "lat": "54.04583",
    "lng": "13.29243"
  },
  {
    "country": "DE",
    "name": "Derschen",
    "lat": "50.71667",
    "lng": "7.98333"
  },
  {
    "country": "DE",
    "name": "Dernbach",
    "lat": "50.55",
    "lng": "7.6"
  },
  {
    "country": "DE",
    "name": "Dernbach",
    "lat": "50.45551",
    "lng": "7.79003"
  },
  {
    "country": "DE",
    "name": "Dernau",
    "lat": "50.53333",
    "lng": "7.05"
  },
  {
    "country": "DE",
    "name": "Dermbach",
    "lat": "50.71383",
    "lng": "10.11839"
  },
  {
    "country": "DE",
    "name": "Derenburg",
    "lat": "51.87086",
    "lng": "10.91029"
  },
  {
    "country": "DE",
    "name": "Denzlingen",
    "lat": "48.06667",
    "lng": "7.88333"
  },
  {
    "country": "DE",
    "name": "Dentlein am Forst",
    "lat": "49.14772",
    "lng": "10.42309"
  },
  {
    "country": "DE",
    "name": "Dennheritz",
    "lat": "50.81412",
    "lng": "12.46519"
  },
  {
    "country": "DE",
    "name": "Denklingen",
    "lat": "47.91667",
    "lng": "10.85"
  },
  {
    "country": "DE",
    "name": "Denkingen",
    "lat": "48.1111",
    "lng": "8.7382"
  },
  {
    "country": "DE",
    "name": "Denkendorf",
    "lat": "48.69555",
    "lng": "9.31675"
  },
  {
    "country": "DE",
    "name": "Demmin",
    "lat": "53.90762",
    "lng": "13.03142"
  },
  {
    "country": "DE",
    "name": "Demitz-Thumitz",
    "lat": "51.14149",
    "lng": "14.24719"
  },
  {
    "country": "DE",
    "name": "Demen",
    "lat": "53.62967",
    "lng": "11.76639"
  },
  {
    "country": "DE",
    "name": "Delmenhorst",
    "lat": "53.0511",
    "lng": "8.63091"
  },
  {
    "country": "DE",
    "name": "Delligsen",
    "lat": "51.9412",
    "lng": "9.80272"
  },
  {
    "country": "DE",
    "name": "Dellfeld",
    "lat": "49.23397",
    "lng": "7.47399"
  },
  {
    "country": "DE",
    "name": "Delitzsch",
    "lat": "51.52546",
    "lng": "12.34284"
  },
  {
    "country": "DE",
    "name": "Delingsdorf",
    "lat": "53.7",
    "lng": "10.25"
  },
  {
    "country": "DE",
    "name": "Delbrück",
    "lat": "51.76503",
    "lng": "8.56223"
  },
  {
    "country": "DE",
    "name": "Deizisau",
    "lat": "48.7122",
    "lng": "9.3861"
  },
  {
    "country": "DE",
    "name": "Deißlingen",
    "lat": "48.1123",
    "lng": "8.60736"
  },
  {
    "country": "DE",
    "name": "Deisenhausen",
    "lat": "48.25554",
    "lng": "10.32698"
  },
  {
    "country": "DE",
    "name": "Deinste",
    "lat": "53.52903",
    "lng": "9.44376"
  },
  {
    "country": "DE",
    "name": "Deiningen",
    "lat": "48.86667",
    "lng": "10.56667"
  },
  {
    "country": "DE",
    "name": "Deining",
    "lat": "49.22556",
    "lng": "11.53968"
  },
  {
    "country": "DE",
    "name": "Deilingen",
    "lat": "48.1741",
    "lng": "8.78533"
  },
  {
    "country": "DE",
    "name": "Deidesheim",
    "lat": "49.40782",
    "lng": "8.18445"
  },
  {
    "country": "DE",
    "name": "Dehrn",
    "lat": "50.42049",
    "lng": "8.09846"
  },
  {
    "country": "DE",
    "name": "Deggingen",
    "lat": "48.5971",
    "lng": "9.71891"
  },
  {
    "country": "DE",
    "name": "Deggendorf",
    "lat": "48.84085",
    "lng": "12.96068"
  },
  {
    "country": "DE",
    "name": "Deensen",
    "lat": "51.86053",
    "lng": "9.59322"
  },
  {
    "country": "DE",
    "name": "Dedelstorf",
    "lat": "52.7",
    "lng": "10.5"
  },
  {
    "country": "DE",
    "name": "Deckenpfronn",
    "lat": "48.65128",
    "lng": "8.82417"
  },
  {
    "country": "DE",
    "name": "Dausenau",
    "lat": "50.33333",
    "lng": "7.76667"
  },
  {
    "country": "DE",
    "name": "Daun",
    "lat": "50.19716",
    "lng": "6.82942"
  },
  {
    "country": "DE",
    "name": "Dauchingen",
    "lat": "48.08993",
    "lng": "8.55011"
  },
  {
    "country": "DE",
    "name": "Dattenberg",
    "lat": "50.55362",
    "lng": "7.29393"
  },
  {
    "country": "DE",
    "name": "Datteln",
    "lat": "51.65598",
    "lng": "7.3453"
  },
  {
    "country": "DE",
    "name": "Dassow",
    "lat": "53.91096",
    "lng": "10.97551"
  },
  {
    "country": "DE",
    "name": "Dassendorf",
    "lat": "53.49532",
    "lng": "10.35987"
  },
  {
    "country": "DE",
    "name": "Dassel",
    "lat": "51.80179",
    "lng": "9.68904"
  },
  {
    "country": "DE",
    "name": "Dasing",
    "lat": "48.38482",
    "lng": "11.04667"
  },
  {
    "country": "DE",
    "name": "Darmstadt",
    "lat": "49.87167",
    "lng": "8.65027"
  },
  {
    "country": "DE",
    "name": "Darlingerode",
    "lat": "51.84712",
    "lng": "10.73097"
  },
  {
    "country": "DE",
    "name": "Dargun",
    "lat": "53.9009",
    "lng": "12.85014"
  },
  {
    "country": "DE",
    "name": "Dannewerk",
    "lat": "54.48333",
    "lng": "9.5"
  },
  {
    "country": "DE",
    "name": "Dannenberg",
    "lat": "53.0967",
    "lng": "11.09001"
  },
  {
    "country": "DE",
    "name": "Danndorf",
    "lat": "52.42472",
    "lng": "10.91286"
  },
  {
    "country": "DE",
    "name": "Dankmarshausen",
    "lat": "50.92527",
    "lng": "10.01601"
  },
  {
    "country": "DE",
    "name": "Dänischenhagen",
    "lat": "54.42775",
    "lng": "10.12596"
  },
  {
    "country": "DE",
    "name": "Damp",
    "lat": "54.58469",
    "lng": "10.01785"
  },
  {
    "country": "DE",
    "name": "Damme",
    "lat": "52.52157",
    "lng": "8.19793"
  },
  {
    "country": "DE",
    "name": "Dalheim",
    "lat": "49.82667",
    "lng": "8.29528"
  },
  {
    "country": "DE",
    "name": "Daisendorf",
    "lat": "47.71265",
    "lng": "9.26783"
  },
  {
    "country": "DE",
    "name": "Dahn",
    "lat": "49.15098",
    "lng": "7.77843"
  },
  {
    "country": "DE",
    "name": "Dahme",
    "lat": "54.21667",
    "lng": "11.08333"
  },
  {
    "country": "DE",
    "name": "Dahme",
    "lat": "51.87008",
    "lng": "13.42743"
  },
  {
    "country": "DE",
    "name": "Dahlenwarsleben",
    "lat": "52.19519",
    "lng": "11.53736"
  },
  {
    "country": "DE",
    "name": "Dahlenburg",
    "lat": "53.18767",
    "lng": "10.7365"
  },
  {
    "country": "DE",
    "name": "Dahlen",
    "lat": "51.36495",
    "lng": "12.99881"
  },
  {
    "country": "DE",
    "name": "Dahlem",
    "lat": "52.4581",
    "lng": "13.28702"
  },
  {
    "country": "DE",
    "name": "Dahlem",
    "lat": "50.38607",
    "lng": "6.54768"
  },
  {
    "country": "DE",
    "name": "Dägeling",
    "lat": "53.88333",
    "lng": "9.53333"
  },
  {
    "country": "DE",
    "name": "Dachwig",
    "lat": "51.0777",
    "lng": "10.85479"
  },
  {
    "country": "DE",
    "name": "Dachsenhausen",
    "lat": "50.25415",
    "lng": "7.72725"
  },
  {
    "country": "DE",
    "name": "Dachau",
    "lat": "48.26",
    "lng": "11.43402"
  },
  {
    "country": "DE",
    "name": "Dabel",
    "lat": "53.66112",
    "lng": "11.90025"
  },
  {
    "country": "DE",
    "name": "Daaden",
    "lat": "50.73333",
    "lng": "7.96667"
  },
  {
    "country": "DE",
    "name": "Cuxhaven",
    "lat": "53.87176",
    "lng": "8.69087"
  },
  {
    "country": "DE",
    "name": "Cunewalde",
    "lat": "51.1",
    "lng": "14.51667"
  },
  {
    "country": "DE",
    "name": "Crottendorf",
    "lat": "50.51667",
    "lng": "12.95"
  },
  {
    "country": "DE",
    "name": "Crostwitz",
    "lat": "51.23832",
    "lng": "14.24338"
  },
  {
    "country": "DE",
    "name": "Crostau",
    "lat": "51.08462",
    "lng": "14.45589"
  },
  {
    "country": "DE",
    "name": "Crivitz",
    "lat": "53.57316",
    "lng": "11.65194"
  },
  {
    "country": "DE",
    "name": "Crinitz",
    "lat": "51.73333",
    "lng": "13.76667"
  },
  {
    "country": "DE",
    "name": "Crimmitschau",
    "lat": "50.81644",
    "lng": "12.39045"
  },
  {
    "country": "DE",
    "name": "Creuzburg",
    "lat": "51.05288",
    "lng": "10.2475"
  },
  {
    "country": "DE",
    "name": "Creußen",
    "lat": "49.84495",
    "lng": "11.62683"
  },
  {
    "country": "DE",
    "name": "Cremlingen",
    "lat": "52.25",
    "lng": "10.65"
  },
  {
    "country": "DE",
    "name": "Creglingen",
    "lat": "49.46937",
    "lng": "10.03119"
  },
  {
    "country": "DE",
    "name": "Crawinkel",
    "lat": "50.78333",
    "lng": "10.78333"
  },
  {
    "country": "DE",
    "name": "Crailsheim",
    "lat": "49.13444",
    "lng": "10.07193"
  },
  {
    "country": "DE",
    "name": "Cottbus",
    "lat": "51.75769",
    "lng": "14.32888"
  },
  {
    "country": "DE",
    "name": "Coswig",
    "lat": "51.88618",
    "lng": "12.45009"
  },
  {
    "country": "DE",
    "name": "Coswig",
    "lat": "51.13204",
    "lng": "13.58312"
  },
  {
    "country": "DE",
    "name": "Cornberg",
    "lat": "51.0416",
    "lng": "9.86051"
  },
  {
    "country": "DE",
    "name": "Coppenbrügge",
    "lat": "52.11852",
    "lng": "9.5487"
  },
  {
    "country": "DE",
    "name": "Contwig",
    "lat": "49.25",
    "lng": "7.43333"
  },
  {
    "country": "DE",
    "name": "Colmberg",
    "lat": "49.3548",
    "lng": "10.41157"
  },
  {
    "country": "DE",
    "name": "Colditz",
    "lat": "51.12821",
    "lng": "12.80295"
  },
  {
    "country": "DE",
    "name": "Colbitz",
    "lat": "52.31708",
    "lng": "11.60534"
  },
  {
    "country": "DE",
    "name": "Cölbe",
    "lat": "50.85098",
    "lng": "8.78092"
  },
  {
    "country": "DE",
    "name": "Coesfeld",
    "lat": "51.94349",
    "lng": "7.16809"
  },
  {
    "country": "DE",
    "name": "Cochstedt",
    "lat": "51.88247",
    "lng": "11.41085"
  },
  {
    "country": "DE",
    "name": "Cochem",
    "lat": "50.14511",
    "lng": "7.16379"
  },
  {
    "country": "DE",
    "name": "Coburg",
    "lat": "50.25937",
    "lng": "10.96384"
  },
  {
    "country": "DE",
    "name": "Cloppenburg",
    "lat": "52.84754",
    "lng": "8.045"
  },
  {
    "country": "DE",
    "name": "Clingen",
    "lat": "51.23206",
    "lng": "10.93281"
  },
  {
    "country": "DE",
    "name": "Clenze",
    "lat": "52.93729",
    "lng": "10.9575"
  },
  {
    "country": "DE",
    "name": "Cleebronn",
    "lat": "49.045",
    "lng": "9.03694"
  },
  {
    "country": "DE",
    "name": "Clausthal-Zellerfeld",
    "lat": "51.80949",
    "lng": "10.33821"
  },
  {
    "country": "DE",
    "name": "Claußnitz",
    "lat": "50.93333",
    "lng": "12.88333"
  },
  {
    "country": "DE",
    "name": "Clausen",
    "lat": "49.26075",
    "lng": "7.6773"
  },
  {
    "country": "DE",
    "name": "Chorin",
    "lat": "52.90197",
    "lng": "13.87153"
  },
  {
    "country": "DE",
    "name": "Chieming",
    "lat": "47.89258",
    "lng": "12.54012"
  },
  {
    "country": "DE",
    "name": "Chemnitz",
    "lat": "50.8357",
    "lng": "12.92922"
  },
  {
    "country": "DE",
    "name": "Charlottenburg",
    "lat": "52.51667",
    "lng": "13.28333"
  },
  {
    "country": "DE",
    "name": "Chamerau",
    "lat": "49.2",
    "lng": "12.75"
  },
  {
    "country": "DE",
    "name": "Cham",
    "lat": "49.22565",
    "lng": "12.65501"
  },
  {
    "country": "DE",
    "name": "Celle",
    "lat": "52.62264",
    "lng": "10.08047"
  },
  {
    "country": "DE",
    "name": "Cavertitz",
    "lat": "51.38333",
    "lng": "13.13333"
  },
  {
    "country": "DE",
    "name": "Castrop-Rauxel",
    "lat": "51.55657",
    "lng": "7.31155"
  },
  {
    "country": "DE",
    "name": "Casekow",
    "lat": "53.21117",
    "lng": "14.20824"
  },
  {
    "country": "DE",
    "name": "Carpin",
    "lat": "53.35691",
    "lng": "13.24328"
  },
  {
    "country": "DE",
    "name": "Carlsberg",
    "lat": "49.50389",
    "lng": "8.04167"
  },
  {
    "country": "DE",
    "name": "Carlow",
    "lat": "53.75861",
    "lng": "10.93789"
  },
  {
    "country": "DE",
    "name": "Cappeln",
    "lat": "52.81085",
    "lng": "8.11474"
  },
  {
    "country": "DE",
    "name": "Camburg",
    "lat": "51.05524",
    "lng": "11.70967"
  },
  {
    "country": "DE",
    "name": "Bad Camberg",
    "lat": "50.29695",
    "lng": "8.26896"
  },
  {
    "country": "DE",
    "name": "Calw",
    "lat": "48.71419",
    "lng": "8.74031"
  },
  {
    "country": "DE",
    "name": "Calvörde",
    "lat": "52.39551",
    "lng": "11.29463"
  },
  {
    "country": "DE",
    "name": "Callenberg",
    "lat": "50.85",
    "lng": "12.63333"
  },
  {
    "country": "DE",
    "name": "Calden",
    "lat": "51.40943",
    "lng": "9.40189"
  },
  {
    "country": "DE",
    "name": "Calberlah",
    "lat": "52.42074",
    "lng": "10.62326"
  },
  {
    "country": "DE",
    "name": "Calbe",
    "lat": "51.90668",
    "lng": "11.77478"
  },
  {
    "country": "DE",
    "name": "Calau",
    "lat": "51.74402",
    "lng": "13.95329"
  },
  {
    "country": "DE",
    "name": "Cadolzburg",
    "lat": "49.4573",
    "lng": "10.85329"
  },
  {
    "country": "DE",
    "name": "Cadenberge",
    "lat": "53.76926",
    "lng": "9.06269"
  },
  {
    "country": "DE",
    "name": "Buxtehude",
    "lat": "53.46716",
    "lng": "9.68636"
  },
  {
    "country": "DE",
    "name": "Buxheim",
    "lat": "48",
    "lng": "10.13333"
  },
  {
    "country": "DE",
    "name": "Bützow",
    "lat": "53.84832",
    "lng": "11.98256"
  },
  {
    "country": "DE",
    "name": "Butzbach",
    "lat": "50.43395",
    "lng": "8.67122"
  },
  {
    "country": "DE",
    "name": "Büttstedt",
    "lat": "51.25972",
    "lng": "10.30636"
  },
  {
    "country": "DE",
    "name": "Buttstädt",
    "lat": "51.12227",
    "lng": "11.41721"
  },
  {
    "country": "DE",
    "name": "Buttlar",
    "lat": "50.7577",
    "lng": "9.95277"
  },
  {
    "country": "DE",
    "name": "Bütthard",
    "lat": "49.59913",
    "lng": "9.87987"
  },
  {
    "country": "DE",
    "name": "Buttenwiesen",
    "lat": "48.6",
    "lng": "10.71667"
  },
  {
    "country": "DE",
    "name": "Buttenheim",
    "lat": "49.80365",
    "lng": "11.03002"
  },
  {
    "country": "DE",
    "name": "Buttelstedt",
    "lat": "51.0765",
    "lng": "11.34353"
  },
  {
    "country": "DE",
    "name": "Büttelborn",
    "lat": "49.90333",
    "lng": "8.52333"
  },
  {
    "country": "DE",
    "name": "Büsum",
    "lat": "54.13398",
    "lng": "8.85756"
  },
  {
    "country": "DE",
    "name": "Büsingen",
    "lat": "47.69638",
    "lng": "8.68759"
  },
  {
    "country": "DE",
    "name": "Busenberg",
    "lat": "49.13024",
    "lng": "7.8293"
  },
  {
    "country": "DE",
    "name": "Busdorf",
    "lat": "54.10345",
    "lng": "10.08242"
  },
  {
    "country": "DE",
    "name": "Burtenbach",
    "lat": "48.34051",
    "lng": "10.4528"
  },
  {
    "country": "DE",
    "name": "Bürstadt",
    "lat": "49.64266",
    "lng": "8.45936"
  },
  {
    "country": "DE",
    "name": "Burscheid",
    "lat": "51.08468",
    "lng": "7.11393"
  },
  {
    "country": "DE",
    "name": "Burow",
    "lat": "53.77372",
    "lng": "13.27318"
  },
  {
    "country": "DE",
    "name": "Burladingen",
    "lat": "48.29111",
    "lng": "9.11286"
  },
  {
    "country": "DE",
    "name": "Burkhardtsdorf",
    "lat": "50.73333",
    "lng": "12.91667"
  },
  {
    "country": "DE",
    "name": "Burkau",
    "lat": "51.17579",
    "lng": "14.17329"
  },
  {
    "country": "DE",
    "name": "Burkardroth",
    "lat": "50.27125",
    "lng": "9.99162"
  },
  {
    "country": "DE",
    "name": "Burk",
    "lat": "49.13318",
    "lng": "10.47891"
  },
  {
    "country": "DE",
    "name": "Burgwindheim",
    "lat": "49.82733",
    "lng": "10.59631"
  },
  {
    "country": "DE",
    "name": "Burgwerben",
    "lat": "51.2227",
    "lng": "11.98396"
  },
  {
    "country": "DE",
    "name": "Burgthann",
    "lat": "49.35202",
    "lng": "11.31154"
  },
  {
    "country": "DE",
    "name": "Burg Stargard",
    "lat": "53.49582",
    "lng": "13.31122"
  },
  {
    "country": "DE",
    "name": "Burgstädt",
    "lat": "50.91333",
    "lng": "12.806"
  },
  {
    "country": "DE",
    "name": "Bürgstadt",
    "lat": "49.71476",
    "lng": "9.26916"
  },
  {
    "country": "DE",
    "name": "Burgsolms",
    "lat": "50.54191",
    "lng": "8.40411"
  },
  {
    "country": "DE",
    "name": "Burgsinn",
    "lat": "50.14968",
    "lng": "9.65119"
  },
  {
    "country": "DE",
    "name": "Burgschwalbach",
    "lat": "50.28333",
    "lng": "8.08333"
  },
  {
    "country": "DE",
    "name": "Burgsalach",
    "lat": "49.03316",
    "lng": "11.09766"
  },
  {
    "country": "DE",
    "name": "Burgrieden",
    "lat": "48.23333",
    "lng": "9.93333"
  },
  {
    "country": "DE",
    "name": "Burgpreppach",
    "lat": "50.14149",
    "lng": "10.64977"
  },
  {
    "country": "DE",
    "name": "Burgoberbach",
    "lat": "49.23333",
    "lng": "10.58333"
  },
  {
    "country": "DE",
    "name": "Burglengenfeld",
    "lat": "49.20379",
    "lng": "12.04452"
  },
  {
    "country": "DE",
    "name": "Burglauer",
    "lat": "50.27645",
    "lng": "10.17939"
  },
  {
    "country": "DE",
    "name": "Burgkunstadt",
    "lat": "50.14093",
    "lng": "11.25205"
  },
  {
    "country": "DE",
    "name": "Burgkirchen an der Alz",
    "lat": "48.16753",
    "lng": "12.7325"
  },
  {
    "country": "DE",
    "name": "Burgheim",
    "lat": "48.70035",
    "lng": "11.01599"
  },
  {
    "country": "DE",
    "name": "Burghausen",
    "lat": "48.16925",
    "lng": "12.83139"
  },
  {
    "country": "DE",
    "name": "Burghaun",
    "lat": "50.69684",
    "lng": "9.72453"
  },
  {
    "country": "DE",
    "name": "Burghaslach",
    "lat": "49.73313",
    "lng": "10.6007"
  },
  {
    "country": "DE",
    "name": "Burggen",
    "lat": "47.77689",
    "lng": "10.81724"
  },
  {
    "country": "DE",
    "name": "Bürgel",
    "lat": "50.94217",
    "lng": "11.75635"
  },
  {
    "country": "DE",
    "name": "Burgebrach",
    "lat": "49.82832",
    "lng": "10.74338"
  },
  {
    "country": "DE",
    "name": "Burgdorf",
    "lat": "52.44628",
    "lng": "10.0064"
  },
  {
    "country": "DE",
    "name": "Burgbrohl",
    "lat": "50.45463",
    "lng": "7.2772"
  },
  {
    "country": "DE",
    "name": "Burgbernheim",
    "lat": "49.45103",
    "lng": "10.32385"
  },
  {
    "country": "DE",
    "name": "Burgberg",
    "lat": "47.53657",
    "lng": "10.28883"
  },
  {
    "country": "DE",
    "name": "Burgau",
    "lat": "48.43159",
    "lng": "10.40989"
  },
  {
    "country": "DE",
    "name": "Burg auf Fehmarn",
    "lat": "54.43333",
    "lng": "11.2"
  },
  {
    "country": "DE",
    "name": "Burg",
    "lat": "53.99708",
    "lng": "9.25891"
  },
  {
    "country": "DE",
    "name": "Burg bei Magdeburg",
    "lat": "52.27152",
    "lng": "11.85493"
  },
  {
    "country": "DE",
    "name": "Burg",
    "lat": "51.83448",
    "lng": "14.14856"
  },
  {
    "country": "DE",
    "name": "Büren",
    "lat": "51.55109",
    "lng": "8.55956"
  },
  {
    "country": "DE",
    "name": "Burbach",
    "lat": "50.75105",
    "lng": "8.07939"
  },
  {
    "country": "DE",
    "name": "Bundenthal",
    "lat": "49.09549",
    "lng": "7.80839"
  },
  {
    "country": "DE",
    "name": "Bundenbach",
    "lat": "49.8428",
    "lng": "7.37826"
  },
  {
    "country": "DE",
    "name": "Bunde",
    "lat": "53.18333",
    "lng": "7.26667"
  },
  {
    "country": "DE",
    "name": "Bünde",
    "lat": "52.19837",
    "lng": "8.58644"
  },
  {
    "country": "DE",
    "name": "Bullay",
    "lat": "50.05448",
    "lng": "7.1373"
  },
  {
    "country": "DE",
    "name": "Bühren",
    "lat": "52.80629",
    "lng": "8.2188"
  },
  {
    "country": "DE",
    "name": "Bühlerzell",
    "lat": "49.00333",
    "lng": "9.92056"
  },
  {
    "country": "DE",
    "name": "Bühlertann",
    "lat": "49.04167",
    "lng": "9.90861"
  },
  {
    "country": "DE",
    "name": "Bühlertal",
    "lat": "48.68569",
    "lng": "8.18876"
  },
  {
    "country": "DE",
    "name": "Bühl",
    "lat": "48.69676",
    "lng": "8.13523"
  },
  {
    "country": "DE",
    "name": "Buggingen",
    "lat": "47.8475",
    "lng": "7.63799"
  },
  {
    "country": "DE",
    "name": "Bufleben",
    "lat": "51",
    "lng": "10.73333"
  },
  {
    "country": "DE",
    "name": "Büdingen",
    "lat": "50.29013",
    "lng": "9.1114"
  },
  {
    "country": "DE",
    "name": "Budenheim",
    "lat": "50.01667",
    "lng": "8.16667"
  },
  {
    "country": "DE",
    "name": "Büdelsdorf",
    "lat": "54.31844",
    "lng": "9.67295"
  },
  {
    "country": "DE",
    "name": "Buckow",
    "lat": "52.432",
    "lng": "13.46018"
  },
  {
    "country": "DE",
    "name": "Buckow",
    "lat": "52.5661",
    "lng": "14.07429"
  },
  {
    "country": "DE",
    "name": "Buckenhof",
    "lat": "49.59324",
    "lng": "11.05044"
  },
  {
    "country": "DE",
    "name": "Bücken",
    "lat": "52.77876",
    "lng": "9.13371"
  },
  {
    "country": "DE",
    "name": "Bückeburg",
    "lat": "52.26065",
    "lng": "9.04939"
  },
  {
    "country": "DE",
    "name": "Buchloe",
    "lat": "48.03719",
    "lng": "10.72548"
  },
  {
    "country": "DE",
    "name": "Büchlberg",
    "lat": "48.67112",
    "lng": "13.521"
  },
  {
    "country": "DE",
    "name": "Buchholz in der Nordheide",
    "lat": "53.32641",
    "lng": "9.86812"
  },
  {
    "country": "DE",
    "name": "Französisch Buchholz",
    "lat": "52.60242",
    "lng": "13.43019"
  },
  {
    "country": "DE",
    "name": "Buchholz",
    "lat": "53.98829",
    "lng": "9.22362"
  },
  {
    "country": "DE",
    "name": "Buchholz",
    "lat": "53.00884",
    "lng": "9.56287"
  },
  {
    "country": "DE",
    "name": "Buchheim",
    "lat": "50.95152",
    "lng": "7.02093"
  },
  {
    "country": "DE",
    "name": "Büchenbeuren",
    "lat": "49.92097",
    "lng": "7.27999"
  },
  {
    "country": "DE",
    "name": "Buchenberg",
    "lat": "47.69593",
    "lng": "10.23927"
  },
  {
    "country": "DE",
    "name": "Büchenbach",
    "lat": "49.26778",
    "lng": "11.05889"
  },
  {
    "country": "DE",
    "name": "Buchenbach",
    "lat": "47.96138",
    "lng": "8.00909"
  },
  {
    "country": "DE",
    "name": "Büchen",
    "lat": "53.48008",
    "lng": "10.6176"
  },
  {
    "country": "DE",
    "name": "Buchen",
    "lat": "49.52416",
    "lng": "9.32293"
  },
  {
    "country": "DE",
    "name": "Büchel",
    "lat": "50.17289",
    "lng": "7.08318"
  },
  {
    "country": "DE",
    "name": "Buchdorf",
    "lat": "48.78333",
    "lng": "10.83333"
  },
  {
    "country": "DE",
    "name": "Buchbrunn",
    "lat": "49.75981",
    "lng": "10.13686"
  },
  {
    "country": "DE",
    "name": "Buchbach",
    "lat": "48.31231",
    "lng": "12.27343"
  },
  {
    "country": "DE",
    "name": "Buch am Buchrain",
    "lat": "48.2151",
    "lng": "11.99509"
  },
  {
    "country": "DE",
    "name": "Buch am Ahorn",
    "lat": "49.53909",
    "lng": "9.5556"
  },
  {
    "country": "DE",
    "name": "Bucha",
    "lat": "50.88333",
    "lng": "11.51667"
  },
  {
    "country": "DE",
    "name": "Buch",
    "lat": "52.6347",
    "lng": "13.49679"
  },
  {
    "country": "DE",
    "name": "Buch",
    "lat": "48.65234",
    "lng": "12.16311"
  },
  {
    "country": "DE",
    "name": "Buch",
    "lat": "48.22479",
    "lng": "10.18055"
  },
  {
    "country": "DE",
    "name": "Bubsheim",
    "lat": "48.11667",
    "lng": "8.83333"
  },
  {
    "country": "DE",
    "name": "Bubesheim",
    "lat": "48.43333",
    "lng": "10.25"
  },
  {
    "country": "DE",
    "name": "Bubenreuth",
    "lat": "49.62745",
    "lng": "11.01723"
  },
  {
    "country": "DE",
    "name": "Brüssow",
    "lat": "53.39971",
    "lng": "14.12533"
  },
  {
    "country": "DE",
    "name": "Brüsewitz",
    "lat": "53.67588",
    "lng": "11.24379"
  },
  {
    "country": "DE",
    "name": "Brunsbüttel",
    "lat": "53.89504",
    "lng": "9.10484"
  },
  {
    "country": "DE",
    "name": "Brunnthal",
    "lat": "48.00652",
    "lng": "11.68405"
  },
  {
    "country": "DE",
    "name": "Brunnen",
    "lat": "48.22956",
    "lng": "10.97332"
  },
  {
    "country": "DE",
    "name": "Brunn",
    "lat": "53.67076",
    "lng": "13.37032"
  },
  {
    "country": "DE",
    "name": "Brunn",
    "lat": "49.23632",
    "lng": "12.19156"
  },
  {
    "country": "DE",
    "name": "Brumby",
    "lat": "51.89635",
    "lng": "11.71751"
  },
  {
    "country": "DE",
    "name": "Brühl",
    "lat": "50.82928",
    "lng": "6.90499"
  },
  {
    "country": "DE",
    "name": "Brühl",
    "lat": "49.39722",
    "lng": "8.53361"
  },
  {
    "country": "DE",
    "name": "Brüggen",
    "lat": "52.0425",
    "lng": "9.7745"
  },
  {
    "country": "DE",
    "name": "Brüggen",
    "lat": "51.24053",
    "lng": "6.18376"
  },
  {
    "country": "DE",
    "name": "Brügge",
    "lat": "54.17578",
    "lng": "10.06913"
  },
  {
    "country": "DE",
    "name": "Brüel",
    "lat": "53.73719",
    "lng": "11.71471"
  },
  {
    "country": "DE",
    "name": "Bruckmühl",
    "lat": "47.87859",
    "lng": "11.91098"
  },
  {
    "country": "DE",
    "name": "Bruck in der Oberpfalz",
    "lat": "49.24927",
    "lng": "12.3071"
  },
  {
    "country": "DE",
    "name": "Brücken",
    "lat": "49.63333",
    "lng": "7.11667"
  },
  {
    "country": "DE",
    "name": "Brücken",
    "lat": "49.43174",
    "lng": "7.35998"
  },
  {
    "country": "DE",
    "name": "Bruckberg",
    "lat": "49.35991",
    "lng": "10.69924"
  },
  {
    "country": "DE",
    "name": "Bruckberg",
    "lat": "48.52244",
    "lng": "11.99448"
  },
  {
    "country": "DE",
    "name": "Brück",
    "lat": "52.19766",
    "lng": "12.76868"
  },
  {
    "country": "DE",
    "name": "Bruck",
    "lat": "48.02116",
    "lng": "11.90781"
  },
  {
    "country": "DE",
    "name": "Bruchweiler-Bärenbach",
    "lat": "49.11667",
    "lng": "7.8"
  },
  {
    "country": "DE",
    "name": "Bruchsal",
    "lat": "49.12426",
    "lng": "8.59804"
  },
  {
    "country": "DE",
    "name": "Bruchköbel",
    "lat": "50.17853",
    "lng": "8.92315"
  },
  {
    "country": "DE",
    "name": "Bruchhausen-Vilsen",
    "lat": "52.82931",
    "lng": "8.99066"
  },
  {
    "country": "DE",
    "name": "Brotterode",
    "lat": "50.82412",
    "lng": "10.44446"
  },
  {
    "country": "DE",
    "name": "Bromskirchen",
    "lat": "51.09363",
    "lng": "8.6264"
  },
  {
    "country": "DE",
    "name": "Brome",
    "lat": "52.60019",
    "lng": "10.93754"
  },
  {
    "country": "DE",
    "name": "Brokstedt",
    "lat": "53.98333",
    "lng": "9.81667"
  },
  {
    "country": "DE",
    "name": "Brokdorf",
    "lat": "53.8638",
    "lng": "9.32314"
  },
  {
    "country": "DE",
    "name": "Broderstorf",
    "lat": "54.08114",
    "lng": "12.2635"
  },
  {
    "country": "DE",
    "name": "Brockum",
    "lat": "52.46667",
    "lng": "8.41667"
  },
  {
    "country": "DE",
    "name": "Brockel",
    "lat": "53.1",
    "lng": "9.51667"
  },
  {
    "country": "DE",
    "name": "Britz",
    "lat": "52.44293",
    "lng": "13.43388"
  },
  {
    "country": "DE",
    "name": "Britz",
    "lat": "52.88726",
    "lng": "13.81119"
  },
  {
    "country": "DE",
    "name": "Britten",
    "lat": "49.52061",
    "lng": "6.67651"
  },
  {
    "country": "DE",
    "name": "Brilon",
    "lat": "51.39462",
    "lng": "8.57146"
  },
  {
    "country": "DE",
    "name": "Brietlingen",
    "lat": "53.33333",
    "lng": "10.45"
  },
  {
    "country": "DE",
    "name": "Brieskow-Finkenheerd",
    "lat": "52.25387",
    "lng": "14.57285"
  },
  {
    "country": "DE",
    "name": "Briesen",
    "lat": "52.34383",
    "lng": "14.27804"
  },
  {
    "country": "DE",
    "name": "Brieselang",
    "lat": "52.58333",
    "lng": "13"
  },
  {
    "country": "DE",
    "name": "Briedel",
    "lat": "50.01667",
    "lng": "7.15"
  },
  {
    "country": "DE",
    "name": "Brey",
    "lat": "50.27253",
    "lng": "7.62645"
  },
  {
    "country": "DE",
    "name": "Breuna",
    "lat": "51.41575",
    "lng": "9.185"
  },
  {
    "country": "DE",
    "name": "Bretzfeld",
    "lat": "49.17944",
    "lng": "9.43833"
  },
  {
    "country": "DE",
    "name": "Bretzenheim",
    "lat": "49.87796",
    "lng": "7.89653"
  },
  {
    "country": "DE",
    "name": "Bretten",
    "lat": "49.03685",
    "lng": "8.70745"
  },
  {
    "country": "DE",
    "name": "Brensbach",
    "lat": "49.77389",
    "lng": "8.88444"
  },
  {
    "country": "DE",
    "name": "Brennberg",
    "lat": "49.06667",
    "lng": "12.4"
  },
  {
    "country": "DE",
    "name": "Bremervörde",
    "lat": "53.48458",
    "lng": "9.14306"
  },
  {
    "country": "DE",
    "name": "Bremerhaven",
    "lat": "53.55021",
    "lng": "8.57673"
  },
  {
    "country": "DE",
    "name": "Bremen",
    "lat": "53.07516",
    "lng": "8.80777"
  },
  {
    "country": "DE",
    "name": "Breklum",
    "lat": "54.6",
    "lng": "8.98333"
  },
  {
    "country": "DE",
    "name": "Brekendorf",
    "lat": "54.4212",
    "lng": "9.6335"
  },
  {
    "country": "DE",
    "name": "Breitungen",
    "lat": "50.76355",
    "lng": "10.32724"
  },
  {
    "country": "DE",
    "name": "Breitscheidt",
    "lat": "50.75",
    "lng": "7.65"
  },
  {
    "country": "DE",
    "name": "Breitscheid",
    "lat": "50.68507",
    "lng": "8.1912"
  },
  {
    "country": "DE",
    "name": "Breitnau",
    "lat": "47.93333",
    "lng": "8.08333"
  },
  {
    "country": "DE",
    "name": "Breitenworbis",
    "lat": "51.41267",
    "lng": "10.4282"
  },
  {
    "country": "DE",
    "name": "Breitenthal",
    "lat": "48.23782",
    "lng": "10.29951"
  },
  {
    "country": "DE",
    "name": "Breitengüßbach",
    "lat": "49.97209",
    "lng": "10.88591"
  },
  {
    "country": "DE",
    "name": "Breitenfelde",
    "lat": "53.60592",
    "lng": "10.63339"
  },
  {
    "country": "DE",
    "name": "Breitenburg",
    "lat": "53.90572",
    "lng": "9.57041"
  },
  {
    "country": "DE",
    "name": "Breitenbrunn",
    "lat": "50.47553",
    "lng": "12.76649"
  },
  {
    "country": "DE",
    "name": "Breitenbrunn",
    "lat": "49.36388",
    "lng": "12.02013"
  },
  {
    "country": "DE",
    "name": "Breitenbrunn",
    "lat": "48.13333",
    "lng": "10.4"
  },
  {
    "country": "DE",
    "name": "Breitenberg",
    "lat": "48.70439",
    "lng": "13.79333"
  },
  {
    "country": "DE",
    "name": "Breitenbach",
    "lat": "50.95655",
    "lng": "9.78285"
  },
  {
    "country": "DE",
    "name": "Breitenbach",
    "lat": "50.68895",
    "lng": "10.49148"
  },
  {
    "country": "DE",
    "name": "Breitbrunn",
    "lat": "50.01667",
    "lng": "10.7"
  },
  {
    "country": "DE",
    "name": "Breitbrunn",
    "lat": "48.0432",
    "lng": "12.15431"
  },
  {
    "country": "DE",
    "name": "Breisach am Rhein",
    "lat": "48.03279",
    "lng": "7.58294"
  },
  {
    "country": "DE",
    "name": "Breiholz",
    "lat": "54.20554",
    "lng": "9.52371"
  },
  {
    "country": "DE",
    "name": "Breidenbach",
    "lat": "50.88734",
    "lng": "8.45748"
  },
  {
    "country": "DE",
    "name": "Brehna",
    "lat": "51.5579",
    "lng": "12.21276"
  },
  {
    "country": "DE",
    "name": "Brehme",
    "lat": "51.49421",
    "lng": "10.35908"
  },
  {
    "country": "DE",
    "name": "Breese",
    "lat": "53",
    "lng": "11.8"
  },
  {
    "country": "DE",
    "name": "Bredstedt",
    "lat": "54.61868",
    "lng": "8.96441"
  },
  {
    "country": "DE",
    "name": "Bredenbek",
    "lat": "54.32247",
    "lng": "9.87293"
  },
  {
    "country": "DE",
    "name": "Breddorf",
    "lat": "53.29262",
    "lng": "9.08089"
  },
  {
    "country": "DE",
    "name": "Breddin",
    "lat": "52.8856",
    "lng": "12.22366"
  },
  {
    "country": "DE",
    "name": "Breckerfeld",
    "lat": "51.25926",
    "lng": "7.46807"
  },
  {
    "country": "DE",
    "name": "Braunschweig",
    "lat": "52.26594",
    "lng": "10.52673"
  },
  {
    "country": "DE",
    "name": "Braunsbedra",
    "lat": "51.28602",
    "lng": "11.88987"
  },
  {
    "country": "DE",
    "name": "Braunsbach",
    "lat": "49.19917",
    "lng": "9.79056"
  },
  {
    "country": "DE",
    "name": "Bräunlingen",
    "lat": "47.92957",
    "lng": "8.44806"
  },
  {
    "country": "DE",
    "name": "Braunlage",
    "lat": "51.72651",
    "lng": "10.6109"
  },
  {
    "country": "DE",
    "name": "Braunfels",
    "lat": "50.51545",
    "lng": "8.38918"
  },
  {
    "country": "DE",
    "name": "Brauneberg",
    "lat": "49.90583",
    "lng": "6.98127"
  },
  {
    "country": "DE",
    "name": "Braubach",
    "lat": "50.2736",
    "lng": "7.64508"
  },
  {
    "country": "DE",
    "name": "Braschwitz",
    "lat": "51.52284",
    "lng": "12.05867"
  },
  {
    "country": "DE",
    "name": "Brannenburg",
    "lat": "47.73996",
    "lng": "12.09166"
  },
  {
    "country": "DE",
    "name": "Brandshagen",
    "lat": "54.23945",
    "lng": "13.16917"
  },
  {
    "country": "DE",
    "name": "Brandis",
    "lat": "51.33597",
    "lng": "12.61024"
  },
  {
    "country": "DE",
    "name": "Brand-Erbisdorf",
    "lat": "50.86643",
    "lng": "13.32285"
  },
  {
    "country": "DE",
    "name": "Brandenburg an der Havel",
    "lat": "52.41667",
    "lng": "12.55"
  },
  {
    "country": "DE",
    "name": "Brande-Hörnerkirchen",
    "lat": "53.85",
    "lng": "9.71667"
  },
  {
    "country": "DE",
    "name": "Brand",
    "lat": "49.95972",
    "lng": "11.91072"
  },
  {
    "country": "DE",
    "name": "Bramstedt",
    "lat": "53.36603",
    "lng": "8.69005"
  },
  {
    "country": "DE",
    "name": "Bramsche",
    "lat": "52.40881",
    "lng": "7.97288"
  },
  {
    "country": "DE",
    "name": "Brakel",
    "lat": "51.7175",
    "lng": "9.18596"
  },
  {
    "country": "DE",
    "name": "Brake (Unterweser)",
    "lat": "53.33333",
    "lng": "8.48333"
  },
  {
    "country": "DE",
    "name": "Brahmenau",
    "lat": "50.92359",
    "lng": "12.15886"
  },
  {
    "country": "DE",
    "name": "Brackenheim",
    "lat": "49.07787",
    "lng": "9.06601"
  },
  {
    "country": "DE",
    "name": "Brackel",
    "lat": "53.29974",
    "lng": "10.0486"
  },
  {
    "country": "DE",
    "name": "Brachbach",
    "lat": "50.81667",
    "lng": "7.93333"
  },
  {
    "country": "DE",
    "name": "Boxberg",
    "lat": "51.40373",
    "lng": "14.57598"
  },
  {
    "country": "DE",
    "name": "Boxberg",
    "lat": "49.47965",
    "lng": "9.64006"
  },
  {
    "country": "DE",
    "name": "Bovenden",
    "lat": "51.58836",
    "lng": "9.9222"
  },
  {
    "country": "DE",
    "name": "Bovenau",
    "lat": "54.33333",
    "lng": "9.83333"
  },
  {
    "country": "DE",
    "name": "Bous",
    "lat": "49.27732",
    "lng": "6.80131"
  },
  {
    "country": "DE",
    "name": "Bötzingen",
    "lat": "48.07642",
    "lng": "7.72485"
  },
  {
    "country": "DE",
    "name": "Bottrop",
    "lat": "51.52392",
    "lng": "6.9285"
  },
  {
    "country": "DE",
    "name": "Böttingen",
    "lat": "48.1",
    "lng": "8.8"
  },
  {
    "country": "DE",
    "name": "Bothel",
    "lat": "53.06667",
    "lng": "9.5"
  },
  {
    "country": "DE",
    "name": "Bötersen",
    "lat": "53.13333",
    "lng": "9.31667"
  },
  {
    "country": "DE",
    "name": "Bösingen",
    "lat": "48.23333",
    "lng": "8.55"
  },
  {
    "country": "DE",
    "name": "Bösenbrunn",
    "lat": "50.39703",
    "lng": "12.09998"
  },
  {
    "country": "DE",
    "name": "Bösel",
    "lat": "53",
    "lng": "7.95"
  },
  {
    "country": "DE",
    "name": "Bösdorf",
    "lat": "54.15",
    "lng": "10.48333"
  },
  {
    "country": "DE",
    "name": "Bosau",
    "lat": "54.09787",
    "lng": "10.4357"
  },
  {
    "country": "DE",
    "name": "Börtlingen",
    "lat": "48.75376",
    "lng": "9.63181"
  },
  {
    "country": "DE",
    "name": "Borstendorf",
    "lat": "50.77323",
    "lng": "13.17918"
  },
  {
    "country": "DE",
    "name": "Borstel-Hohenraden",
    "lat": "53.68333",
    "lng": "9.81667"
  },
  {
    "country": "DE",
    "name": "Borstel",
    "lat": "52.67034",
    "lng": "8.96896"
  },
  {
    "country": "DE",
    "name": "Börßum",
    "lat": "52.06921",
    "lng": "10.58431"
  },
  {
    "country": "DE",
    "name": "Borsdorf",
    "lat": "51.35",
    "lng": "12.53333"
  },
  {
    "country": "DE",
    "name": "Borrentin",
    "lat": "53.80968",
    "lng": "12.96718"
  },
  {
    "country": "DE",
    "name": "Börnsen",
    "lat": "53.4762",
    "lng": "10.2816"
  },
  {
    "country": "DE",
    "name": "Börnichen",
    "lat": "50.7501",
    "lng": "13.14075"
  },
  {
    "country": "DE",
    "name": "Bornich",
    "lat": "50.12687",
    "lng": "7.7658"
  },
  {
    "country": "DE",
    "name": "Bornhöved",
    "lat": "54.06667",
    "lng": "10.23333"
  },
  {
    "country": "DE",
    "name": "Bornheim",
    "lat": "50.76313",
    "lng": "6.99089"
  },
  {
    "country": "DE",
    "name": "Bornheim",
    "lat": "49.2225",
    "lng": "8.16333"
  },
  {
    "country": "DE",
    "name": "Borne",
    "lat": "51.94881",
    "lng": "11.55865"
  },
  {
    "country": "DE",
    "name": "Borna",
    "lat": "51.12416",
    "lng": "12.49639"
  },
  {
    "country": "DE",
    "name": "Born",
    "lat": "54.38536",
    "lng": "12.53051"
  },
  {
    "country": "DE",
    "name": "Borkwalde",
    "lat": "52.25",
    "lng": "12.83333"
  },
  {
    "country": "DE",
    "name": "Borkum",
    "lat": "53.58094",
    "lng": "6.69153"
  },
  {
    "country": "DE",
    "name": "Borkheide",
    "lat": "52.21667",
    "lng": "12.85"
  },
  {
    "country": "DE",
    "name": "Borken",
    "lat": "51.84382",
    "lng": "6.85774"
  },
  {
    "country": "DE",
    "name": "Borken",
    "lat": "51.04501",
    "lng": "9.2844"
  },
  {
    "country": "DE",
    "name": "Borgstedt",
    "lat": "54.33268",
    "lng": "9.70954"
  },
  {
    "country": "DE",
    "name": "Borgholzhausen",
    "lat": "52.10343",
    "lng": "8.30211"
  },
  {
    "country": "DE",
    "name": "Borgfelde",
    "lat": "53.55475",
    "lng": "10.03447"
  },
  {
    "country": "DE",
    "name": "Börger",
    "lat": "52.91211",
    "lng": "7.53576"
  },
  {
    "country": "DE",
    "name": "Borgentreich",
    "lat": "51.56917",
    "lng": "9.24113"
  },
  {
    "country": "DE",
    "name": "Bordesholm",
    "lat": "54.17611",
    "lng": "10.03146"
  },
  {
    "country": "DE",
    "name": "Boppard",
    "lat": "50.23085",
    "lng": "7.58992"
  },
  {
    "country": "DE",
    "name": "Bopfingen",
    "lat": "48.85847",
    "lng": "10.35417"
  },
  {
    "country": "DE",
    "name": "Boostedt",
    "lat": "54.01667",
    "lng": "10.03333"
  },
  {
    "country": "DE",
    "name": "Boos",
    "lat": "48.07521",
    "lng": "10.19523"
  },
  {
    "country": "DE",
    "name": "Bonstetten",
    "lat": "48.44002",
    "lng": "10.70532"
  },
  {
    "country": "DE",
    "name": "Bönningstedt",
    "lat": "53.66667",
    "lng": "9.91667"
  },
  {
    "country": "DE",
    "name": "Bönnigheim",
    "lat": "49.04018",
    "lng": "9.09386"
  },
  {
    "country": "DE",
    "name": "Bonndorf im Schwarzwald",
    "lat": "47.81863",
    "lng": "8.34139"
  },
  {
    "country": "DE",
    "name": "Bonn",
    "lat": "50.73438",
    "lng": "7.09549"
  },
  {
    "country": "DE",
    "name": "Bönen",
    "lat": "51.6",
    "lng": "7.76667"
  },
  {
    "country": "DE",
    "name": "Bonefeld",
    "lat": "50.52388",
    "lng": "7.48932"
  },
  {
    "country": "DE",
    "name": "Bönebüttel",
    "lat": "54.08333",
    "lng": "10.06667"
  },
  {
    "country": "DE",
    "name": "Bondorf",
    "lat": "48.52064",
    "lng": "8.83704"
  },
  {
    "country": "DE",
    "name": "Bomlitz",
    "lat": "52.9",
    "lng": "9.65"
  },
  {
    "country": "DE",
    "name": "Bolsterlang",
    "lat": "47.46667",
    "lng": "10.23333"
  },
  {
    "country": "DE",
    "name": "Bollschweil",
    "lat": "47.92143",
    "lng": "7.78986"
  },
  {
    "country": "DE",
    "name": "Bollingstedt",
    "lat": "54.59229",
    "lng": "9.41738"
  },
  {
    "country": "DE",
    "name": "Bollendorf",
    "lat": "49.85268",
    "lng": "6.35795"
  },
  {
    "country": "DE",
    "name": "Boll",
    "lat": "48.64357",
    "lng": "9.61295"
  },
  {
    "country": "DE",
    "name": "Bolheim",
    "lat": "48.63141",
    "lng": "10.14995"
  },
  {
    "country": "DE",
    "name": "Bolanden",
    "lat": "49.63917",
    "lng": "8.01194"
  },
  {
    "country": "DE",
    "name": "Bokholt-Hanredder",
    "lat": "53.78808",
    "lng": "9.73586"
  },
  {
    "country": "DE",
    "name": "Bokel",
    "lat": "53.39326",
    "lng": "8.76803"
  },
  {
    "country": "DE",
    "name": "Boizenburg",
    "lat": "53.38153",
    "lng": "10.72375"
  },
  {
    "country": "DE",
    "name": "Bohnsdorf",
    "lat": "52.39434",
    "lng": "13.57339"
  },
  {
    "country": "DE",
    "name": "Bohmte",
    "lat": "52.36667",
    "lng": "8.31667"
  },
  {
    "country": "DE",
    "name": "Böhmenkirch",
    "lat": "48.68333",
    "lng": "9.93333"
  },
  {
    "country": "DE",
    "name": "Böhlen",
    "lat": "51.20061",
    "lng": "12.38622"
  },
  {
    "country": "DE",
    "name": "Bogenhausen",
    "lat": "48.15221",
    "lng": "11.61585"
  },
  {
    "country": "DE",
    "name": "Bogen",
    "lat": "48.91122",
    "lng": "12.68955"
  },
  {
    "country": "DE",
    "name": "Boffzen",
    "lat": "51.75",
    "lng": "9.38333"
  },
  {
    "country": "DE",
    "name": "Bodolz",
    "lat": "47.56667",
    "lng": "9.66667"
  },
  {
    "country": "DE",
    "name": "Bodnegg",
    "lat": "47.71014",
    "lng": "9.68841"
  },
  {
    "country": "DE",
    "name": "Bodenwöhr",
    "lat": "49.27082",
    "lng": "12.30146"
  },
  {
    "country": "DE",
    "name": "Bodenwerder",
    "lat": "51.97156",
    "lng": "9.51931"
  },
  {
    "country": "DE",
    "name": "Bodenmais",
    "lat": "49.06667",
    "lng": "13.1"
  },
  {
    "country": "DE",
    "name": "Bodenkirchen",
    "lat": "48.38333",
    "lng": "12.38333"
  },
  {
    "country": "DE",
    "name": "Bodenheim",
    "lat": "49.93528",
    "lng": "8.32"
  },
  {
    "country": "DE",
    "name": "Bodenfelde",
    "lat": "51.64044",
    "lng": "9.55569"
  },
  {
    "country": "DE",
    "name": "Bodelshausen",
    "lat": "48.38886",
    "lng": "8.97703"
  },
  {
    "country": "DE",
    "name": "Bockhorst",
    "lat": "53.03296",
    "lng": "7.57576"
  },
  {
    "country": "DE",
    "name": "Bockhorn",
    "lat": "53.4",
    "lng": "8.01667"
  },
  {
    "country": "DE",
    "name": "Bockhorn",
    "lat": "48.31471",
    "lng": "11.98694"
  },
  {
    "country": "DE",
    "name": "Bockenheim",
    "lat": "49.60669",
    "lng": "8.18486"
  },
  {
    "country": "DE",
    "name": "Bockenem",
    "lat": "52.00993",
    "lng": "10.13197"
  },
  {
    "country": "DE",
    "name": "Bockenau",
    "lat": "49.83333",
    "lng": "7.68333"
  },
  {
    "country": "DE",
    "name": "Bockelwitz",
    "lat": "51.19942",
    "lng": "12.95618"
  },
  {
    "country": "DE",
    "name": "Bockau",
    "lat": "50.54209",
    "lng": "12.68639"
  },
  {
    "country": "DE",
    "name": "Bochum",
    "lat": "51.48165",
    "lng": "7.21648"
  },
  {
    "country": "DE",
    "name": "Bocholt",
    "lat": "51.83879",
    "lng": "6.61531"
  },
  {
    "country": "DE",
    "name": "Böbrach",
    "lat": "48.93322",
    "lng": "12.88304"
  },
  {
    "country": "DE",
    "name": "Böblingen",
    "lat": "48.68212",
    "lng": "9.01171"
  },
  {
    "country": "DE",
    "name": "Bobitz",
    "lat": "53.8045",
    "lng": "11.35914"
  },
  {
    "country": "DE",
    "name": "Bobingen",
    "lat": "48.27091",
    "lng": "10.8339"
  },
  {
    "country": "DE",
    "name": "Böbing",
    "lat": "47.75562",
    "lng": "10.98877"
  },
  {
    "country": "DE",
    "name": "Bobenheim-Roxheim",
    "lat": "49.5875",
    "lng": "8.35778"
  },
  {
    "country": "DE",
    "name": "Bobbau",
    "lat": "51.68747",
    "lng": "12.27253"
  },
  {
    "country": "DE",
    "name": "Blumberg",
    "lat": "47.84058",
    "lng": "8.53329"
  },
  {
    "country": "DE",
    "name": "Blowatz",
    "lat": "53.98972",
    "lng": "11.5336"
  },
  {
    "country": "DE",
    "name": "Blomberg",
    "lat": "51.94331",
    "lng": "9.09067"
  },
  {
    "country": "DE",
    "name": "Blomberg",
    "lat": "53.57678",
    "lng": "7.55824"
  },
  {
    "country": "DE",
    "name": "Blindheim",
    "lat": "48.63138",
    "lng": "10.61992"
  },
  {
    "country": "DE",
    "name": "Blieskastel",
    "lat": "49.23724",
    "lng": "7.25617"
  },
  {
    "country": "DE",
    "name": "Bliesdorf",
    "lat": "52.69298",
    "lng": "14.15949"
  },
  {
    "country": "DE",
    "name": "Bliedersdorf",
    "lat": "53.48333",
    "lng": "9.56667"
  },
  {
    "country": "DE",
    "name": "Blender",
    "lat": "52.91667",
    "lng": "9.13333"
  },
  {
    "country": "DE",
    "name": "Blekendorf",
    "lat": "54.28211",
    "lng": "10.6582"
  },
  {
    "country": "DE",
    "name": "Bleicherode",
    "lat": "51.44026",
    "lng": "10.57202"
  },
  {
    "country": "DE",
    "name": "Bleialf",
    "lat": "50.23333",
    "lng": "6.28333"
  },
  {
    "country": "DE",
    "name": "Bleckede",
    "lat": "53.28972",
    "lng": "10.73372"
  },
  {
    "country": "DE",
    "name": "Blaufelden",
    "lat": "49.29778",
    "lng": "9.97389"
  },
  {
    "country": "DE",
    "name": "Blaubeuren",
    "lat": "48.41215",
    "lng": "9.78427"
  },
  {
    "country": "DE",
    "name": "Blankensee",
    "lat": "53.4039",
    "lng": "13.26836"
  },
  {
    "country": "DE",
    "name": "Blankenrath",
    "lat": "50.03898",
    "lng": "7.30214"
  },
  {
    "country": "DE",
    "name": "Blankenheim",
    "lat": "51.50717",
    "lng": "11.42878"
  },
  {
    "country": "DE",
    "name": "Blankenheim",
    "lat": "50.43333",
    "lng": "6.65"
  },
  {
    "country": "DE",
    "name": "Blankenhain",
    "lat": "50.85993",
    "lng": "11.3439"
  },
  {
    "country": "DE",
    "name": "Blankenfelde",
    "lat": "52.61863",
    "lng": "13.39057"
  },
  {
    "country": "DE",
    "name": "Blankenburg",
    "lat": "52.59293",
    "lng": "13.45516"
  },
  {
    "country": "DE",
    "name": "Blankenburg",
    "lat": "51.79025",
    "lng": "10.95509"
  },
  {
    "country": "DE",
    "name": "Blaichach",
    "lat": "47.54208",
    "lng": "10.25846"
  },
  {
    "country": "DE",
    "name": "Blaibach",
    "lat": "49.16667",
    "lng": "12.81667"
  },
  {
    "country": "DE",
    "name": "Bitz",
    "lat": "48.244",
    "lng": "9.09144"
  },
  {
    "country": "DE",
    "name": "Bitterfeld-Wolfen",
    "lat": "51.62355",
    "lng": "12.32395"
  },
  {
    "country": "DE",
    "name": "Bitburg",
    "lat": "49.96794",
    "lng": "6.52734"
  },
  {
    "country": "DE",
    "name": "Bissingen an der Teck",
    "lat": "48.59915",
    "lng": "9.49146"
  },
  {
    "country": "DE",
    "name": "Bissingen",
    "lat": "48.71694",
    "lng": "10.61766"
  },
  {
    "country": "DE",
    "name": "Bissendorf",
    "lat": "52.23333",
    "lng": "8.16667"
  },
  {
    "country": "DE",
    "name": "Bispingen",
    "lat": "53.08312",
    "lng": "9.99772"
  },
  {
    "country": "DE",
    "name": "Bismark",
    "lat": "52.66195",
    "lng": "11.55638"
  },
  {
    "country": "DE",
    "name": "Bisingen",
    "lat": "48.31012",
    "lng": "8.91738"
  },
  {
    "country": "DE",
    "name": "Bischweier",
    "lat": "48.83766",
    "lng": "8.28412"
  },
  {
    "country": "DE",
    "name": "Bischofswiesen",
    "lat": "47.63115",
    "lng": "12.98305"
  },
  {
    "country": "DE",
    "name": "Bischofswerda",
    "lat": "51.12771",
    "lng": "14.17974"
  },
  {
    "country": "DE",
    "name": "Bischofsmais",
    "lat": "48.91796",
    "lng": "13.08184"
  },
  {
    "country": "DE",
    "name": "Bischofsheim an der Rhön",
    "lat": "50.40239",
    "lng": "10.00751"
  },
  {
    "country": "DE",
    "name": "Bischofsheim",
    "lat": "49.99389",
    "lng": "8.36722"
  },
  {
    "country": "DE",
    "name": "Bischofsgrün",
    "lat": "50.05122",
    "lng": "11.79997"
  },
  {
    "country": "DE",
    "name": "Bischofferode",
    "lat": "51.49656",
    "lng": "10.44396"
  },
  {
    "country": "DE",
    "name": "Bischoffen",
    "lat": "50.7",
    "lng": "8.45"
  },
  {
    "country": "DE",
    "name": "Bischbrunn",
    "lat": "49.87028",
    "lng": "9.48917"
  },
  {
    "country": "DE",
    "name": "Bischberg",
    "lat": "49.91087",
    "lng": "10.83212"
  },
  {
    "country": "DE",
    "name": "Birstein",
    "lat": "50.35",
    "lng": "9.3"
  },
  {
    "country": "DE",
    "name": "Birresborn",
    "lat": "50.18333",
    "lng": "6.63333"
  },
  {
    "country": "DE",
    "name": "Bad Birnbach",
    "lat": "48.44489",
    "lng": "13.09103"
  },
  {
    "country": "DE",
    "name": "Birlenbach",
    "lat": "50.35815",
    "lng": "8.00273"
  },
  {
    "country": "DE",
    "name": "Birkenwerder",
    "lat": "52.68333",
    "lng": "13.28333"
  },
  {
    "country": "DE",
    "name": "Birkenheide",
    "lat": "49.48139",
    "lng": "8.26194"
  },
  {
    "country": "DE",
    "name": "Birkenfeld",
    "lat": "49.85861",
    "lng": "9.69556"
  },
  {
    "country": "DE",
    "name": "Birkenfeld",
    "lat": "49.65245",
    "lng": "7.16668"
  },
  {
    "country": "DE",
    "name": "Birkenfeld",
    "lat": "48.86667",
    "lng": "8.63333"
  },
  {
    "country": "DE",
    "name": "Birkenau",
    "lat": "49.5625",
    "lng": "8.70694"
  },
  {
    "country": "DE",
    "name": "Birgte",
    "lat": "52.2479",
    "lng": "7.64833"
  },
  {
    "country": "DE",
    "name": "Birenbach",
    "lat": "48.74732",
    "lng": "9.66115"
  },
  {
    "country": "DE",
    "name": "Bippen",
    "lat": "52.58333",
    "lng": "7.73333"
  },
  {
    "country": "DE",
    "name": "Binzen",
    "lat": "47.63333",
    "lng": "7.61667"
  },
  {
    "country": "DE",
    "name": "Binswangen",
    "lat": "48.55798",
    "lng": "10.64249"
  },
  {
    "country": "DE",
    "name": "Binsfeld",
    "lat": "49.96667",
    "lng": "6.71667"
  },
  {
    "country": "DE",
    "name": "Binnen",
    "lat": "52.61667",
    "lng": "9.13333"
  },
  {
    "country": "DE",
    "name": "Bingen am Rhein",
    "lat": "49.96675",
    "lng": "7.8992"
  },
  {
    "country": "DE",
    "name": "Bingen",
    "lat": "48.11127",
    "lng": "9.27238"
  },
  {
    "country": "DE",
    "name": "Bindlach",
    "lat": "49.98167",
    "lng": "11.61389"
  },
  {
    "country": "DE",
    "name": "Binau",
    "lat": "49.36833",
    "lng": "9.05806"
  },
  {
    "country": "DE",
    "name": "Bilshausen",
    "lat": "51.62974",
    "lng": "10.15859"
  },
  {
    "country": "DE",
    "name": "Billigheim",
    "lat": "49.34861",
    "lng": "9.25389"
  },
  {
    "country": "DE",
    "name": "Billerbeck",
    "lat": "51.97829",
    "lng": "7.29261"
  },
  {
    "country": "DE",
    "name": "Bietigheim-Bissingen",
    "lat": "48.94407",
    "lng": "9.11755"
  },
  {
    "country": "DE",
    "name": "Bietigheim",
    "lat": "48.90919",
    "lng": "8.25202"
  },
  {
    "country": "DE",
    "name": "Biessenhofen",
    "lat": "47.83057",
    "lng": "10.64022"
  },
  {
    "country": "DE",
    "name": "Biesenthal",
    "lat": "52.76616",
    "lng": "13.64416"
  },
  {
    "country": "DE",
    "name": "Biesdorf",
    "lat": "52.50906",
    "lng": "13.5534"
  },
  {
    "country": "DE",
    "name": "Biere",
    "lat": "51.97431",
    "lng": "11.65443"
  },
  {
    "country": "DE",
    "name": "Bienenbüttel",
    "lat": "53.14157",
    "lng": "10.48679"
  },
  {
    "country": "DE",
    "name": "Biendorf",
    "lat": "54.0752",
    "lng": "11.70127"
  },
  {
    "country": "DE",
    "name": "Bielefeld",
    "lat": "52.03333",
    "lng": "8.53333"
  },
  {
    "country": "DE",
    "name": "Biederitz",
    "lat": "52.15",
    "lng": "11.71667"
  },
  {
    "country": "DE",
    "name": "Biedenkopf",
    "lat": "50.91125",
    "lng": "8.53016"
  },
  {
    "country": "DE",
    "name": "Biebesheim",
    "lat": "49.78088",
    "lng": "8.46696"
  },
  {
    "country": "DE",
    "name": "Biebelried",
    "lat": "49.76667",
    "lng": "10.08333"
  },
  {
    "country": "DE",
    "name": "Bidingen",
    "lat": "47.82974",
    "lng": "10.72623"
  },
  {
    "country": "DE",
    "name": "Bickenbach",
    "lat": "49.75917",
    "lng": "8.6175"
  },
  {
    "country": "DE",
    "name": "Bichl",
    "lat": "47.7201",
    "lng": "11.41231"
  },
  {
    "country": "DE",
    "name": "Biburg",
    "lat": "48.79066",
    "lng": "11.85726"
  },
  {
    "country": "DE",
    "name": "Biblis",
    "lat": "49.69167",
    "lng": "8.45861"
  },
  {
    "country": "DE",
    "name": "Biberbach",
    "lat": "48.51778",
    "lng": "10.81139"
  },
  {
    "country": "DE",
    "name": "Biberach an der Riß",
    "lat": "48.09345",
    "lng": "9.79053"
  },
  {
    "country": "DE",
    "name": "Biberach",
    "lat": "48.61008",
    "lng": "8.27704"
  },
  {
    "country": "DE",
    "name": "Bexbach",
    "lat": "49.34615",
    "lng": "7.25527"
  },
  {
    "country": "DE",
    "name": "Beverungen",
    "lat": "51.66801",
    "lng": "9.37417"
  },
  {
    "country": "DE",
    "name": "Beverstedt",
    "lat": "53.43413",
    "lng": "8.81915"
  },
  {
    "country": "DE",
    "name": "Bevern",
    "lat": "51.85826",
    "lng": "9.49408"
  },
  {
    "country": "DE",
    "name": "Bad Bevensen",
    "lat": "53.07923",
    "lng": "10.58129"
  },
  {
    "country": "DE",
    "name": "Bevenrode",
    "lat": "52.34026",
    "lng": "10.57743"
  },
  {
    "country": "DE",
    "name": "Beutelsbach",
    "lat": "48.55",
    "lng": "13.11667"
  },
  {
    "country": "DE",
    "name": "Beuren",
    "lat": "48.56927",
    "lng": "9.40406"
  },
  {
    "country": "DE",
    "name": "Beuna",
    "lat": "51.31667",
    "lng": "11.95"
  },
  {
    "country": "DE",
    "name": "Beuern",
    "lat": "50.62745",
    "lng": "8.82108"
  },
  {
    "country": "DE",
    "name": "Betzigau",
    "lat": "47.73333",
    "lng": "10.38333"
  },
  {
    "country": "DE",
    "name": "Betzendorf",
    "lat": "53.1375",
    "lng": "10.31273"
  },
  {
    "country": "DE",
    "name": "Betzdorf",
    "lat": "50.79094",
    "lng": "7.87189"
  },
  {
    "country": "DE",
    "name": "Bettingen",
    "lat": "49.94211",
    "lng": "6.4016"
  },
  {
    "country": "DE",
    "name": "Betheln",
    "lat": "52.11431",
    "lng": "9.79397"
  },
  {
    "country": "DE",
    "name": "Bestwig",
    "lat": "51.36081",
    "lng": "8.40082"
  },
  {
    "country": "DE",
    "name": "Bestensee",
    "lat": "52.23978",
    "lng": "13.63732"
  },
  {
    "country": "DE",
    "name": "Besigheim",
    "lat": "48.99797",
    "lng": "9.14268"
  },
  {
    "country": "DE",
    "name": "Berumbur",
    "lat": "53.6",
    "lng": "7.31667"
  },
  {
    "country": "DE",
    "name": "Berthelsdorf",
    "lat": "51.04679",
    "lng": "14.22197"
  },
  {
    "country": "DE",
    "name": "Berstadt",
    "lat": "50.42606",
    "lng": "8.86621"
  },
  {
    "country": "DE",
    "name": "Bersenbrück",
    "lat": "52.5516",
    "lng": "7.94836"
  },
  {
    "country": "DE",
    "name": "Bernstadt",
    "lat": "51.04736",
    "lng": "14.82784"
  },
  {
    "country": "DE",
    "name": "Bernstadt",
    "lat": "48.49957",
    "lng": "10.02575"
  },
  {
    "country": "DE",
    "name": "Bernsdorf",
    "lat": "51.3735",
    "lng": "14.06886"
  },
  {
    "country": "DE",
    "name": "Bernsdorf",
    "lat": "50.76667",
    "lng": "12.66667"
  },
  {
    "country": "DE",
    "name": "Bernsbach",
    "lat": "50.57624",
    "lng": "12.76751"
  },
  {
    "country": "DE",
    "name": "Bernried",
    "lat": "48.91667",
    "lng": "12.88333"
  },
  {
    "country": "DE",
    "name": "Bernkastel-Kues",
    "lat": "49.91602",
    "lng": "7.07664"
  },
  {
    "country": "DE",
    "name": "Bernitt",
    "lat": "53.90403",
    "lng": "11.88669"
  },
  {
    "country": "DE",
    "name": "Bernhardswald",
    "lat": "49.09123",
    "lng": "12.24744"
  },
  {
    "country": "DE",
    "name": "Berngau",
    "lat": "49.25",
    "lng": "11.4"
  },
  {
    "country": "DE",
    "name": "Bernburg",
    "lat": "51.79464",
    "lng": "11.7401"
  },
  {
    "country": "DE",
    "name": "Bernbeuren",
    "lat": "47.73696",
    "lng": "10.77707"
  },
  {
    "country": "DE",
    "name": "Bernau am Chiemsee",
    "lat": "47.81167",
    "lng": "12.37566"
  },
  {
    "country": "DE",
    "name": "Bernau bei Berlin",
    "lat": "52.67982",
    "lng": "13.58708"
  },
  {
    "country": "DE",
    "name": "Bernau",
    "lat": "47.80018",
    "lng": "8.0383"
  },
  {
    "country": "DE",
    "name": "Bermatingen",
    "lat": "47.73333",
    "lng": "9.35"
  },
  {
    "country": "DE",
    "name": "Berlstedt",
    "lat": "51.06142",
    "lng": "11.24288"
  },
  {
    "country": "DE",
    "name": "Berlingerode",
    "lat": "51.45775",
    "lng": "10.2384"
  },
  {
    "country": "DE",
    "name": "Berlin",
    "lat": "52.52437",
    "lng": "13.41053"
  },
  {
    "country": "DE",
    "name": "Berkheim",
    "lat": "48.04263",
    "lng": "10.08227"
  },
  {
    "country": "DE",
    "name": "Berkenthin",
    "lat": "53.73333",
    "lng": "10.65"
  },
  {
    "country": "DE",
    "name": "Berkenbrück",
    "lat": "52.35",
    "lng": "14.15"
  },
  {
    "country": "DE",
    "name": "Bergwitz",
    "lat": "51.79479",
    "lng": "12.58954"
  },
  {
    "country": "DE",
    "name": "Bergtheim",
    "lat": "49.9",
    "lng": "10.06667"
  },
  {
    "country": "DE",
    "name": "Bergstedt",
    "lat": "53.67111",
    "lng": "10.12694"
  },
  {
    "country": "DE",
    "name": "Bergrheinfeld",
    "lat": "50.01028",
    "lng": "10.18089"
  },
  {
    "country": "DE",
    "name": "Bergneustadt",
    "lat": "51.02496",
    "lng": "7.65599"
  },
  {
    "country": "DE",
    "name": "Berglern",
    "lat": "48.38407",
    "lng": "11.93012"
  },
  {
    "country": "DE",
    "name": "Bergkirchen",
    "lat": "48.25671",
    "lng": "11.36488"
  },
  {
    "country": "DE",
    "name": "Bergkamen",
    "lat": "51.61633",
    "lng": "7.64451"
  },
  {
    "country": "DE",
    "name": "Bergisch Gladbach",
    "lat": "50.9856",
    "lng": "7.13298"
  },
  {
    "country": "DE",
    "name": "Berg im Gau",
    "lat": "48.63333",
    "lng": "11.25"
  },
  {
    "country": "DE",
    "name": "Berghülen",
    "lat": "48.46399",
    "lng": "9.7611"
  },
  {
    "country": "DE",
    "name": "Bergheim",
    "lat": "50.95572",
    "lng": "6.63986"
  },
  {
    "country": "DE",
    "name": "Berghaupten",
    "lat": "48.40602",
    "lng": "7.98672"
  },
  {
    "country": "DE",
    "name": "Bergen auf Rügen",
    "lat": "54.41823",
    "lng": "13.43349"
  },
  {
    "country": "DE",
    "name": "Bergen an der Dumme",
    "lat": "52.89109",
    "lng": "10.95629"
  },
  {
    "country": "DE",
    "name": "Bergen",
    "lat": "52.80837",
    "lng": "9.96374"
  },
  {
    "country": "DE",
    "name": "Bergen",
    "lat": "50.471",
    "lng": "12.27448"
  },
  {
    "country": "DE",
    "name": "Bergen",
    "lat": "49.07347",
    "lng": "11.114"
  },
  {
    "country": "DE",
    "name": "Bergen",
    "lat": "47.80837",
    "lng": "12.58982"
  },
  {
    "country": "DE",
    "name": "Berge",
    "lat": "52.62326",
    "lng": "7.7455"
  },
  {
    "country": "DE",
    "name": "Bergatreute",
    "lat": "47.85",
    "lng": "9.75"
  },
  {
    "country": "DE",
    "name": "Berga",
    "lat": "51.45561",
    "lng": "11.0071"
  },
  {
    "country": "DE",
    "name": "Berga",
    "lat": "50.75184",
    "lng": "12.16445"
  },
  {
    "country": "DE",
    "name": "Berg",
    "lat": "50.55523",
    "lng": "6.94886"
  },
  {
    "country": "DE",
    "name": "Berg",
    "lat": "50.37473",
    "lng": "11.7785"
  },
  {
    "country": "DE",
    "name": "Berg",
    "lat": "49.81417",
    "lng": "12.14161"
  },
  {
    "country": "DE",
    "name": "Berg",
    "lat": "48.98403",
    "lng": "8.20232"
  },
  {
    "country": "DE",
    "name": "Berchtesgaden",
    "lat": "47.63236",
    "lng": "13.00187"
  },
  {
    "country": "DE",
    "name": "Berching",
    "lat": "49.10695",
    "lng": "11.44138"
  },
  {
    "country": "DE",
    "name": "Beratzhausen",
    "lat": "49.09517",
    "lng": "11.8097"
  },
  {
    "country": "DE",
    "name": "Bentzin",
    "lat": "53.94608",
    "lng": "13.2732"
  },
  {
    "country": "DE",
    "name": "Bentwisch",
    "lat": "54.11503",
    "lng": "12.20465"
  },
  {
    "country": "DE",
    "name": "Bensheim",
    "lat": "49.68369",
    "lng": "8.61839"
  },
  {
    "country": "DE",
    "name": "Benshausen",
    "lat": "50.65",
    "lng": "10.6"
  },
  {
    "country": "DE",
    "name": "Bennungen",
    "lat": "51.46085",
    "lng": "11.11816"
  },
  {
    "country": "DE",
    "name": "Bennstedt",
    "lat": "51.48201",
    "lng": "11.8262"
  },
  {
    "country": "DE",
    "name": "Benningen am Neckar",
    "lat": "48.94672",
    "lng": "9.24212"
  },
  {
    "country": "DE",
    "name": "Benningen",
    "lat": "47.96667",
    "lng": "10.21667"
  },
  {
    "country": "DE",
    "name": "Bennewitz",
    "lat": "51.36074",
    "lng": "12.71376"
  },
  {
    "country": "DE",
    "name": "Benneckenstein",
    "lat": "51.66823",
    "lng": "10.71716"
  },
  {
    "country": "DE",
    "name": "Benndorf",
    "lat": "51.57035",
    "lng": "11.4929"
  },
  {
    "country": "DE",
    "name": "Benediktbeuern",
    "lat": "47.70624",
    "lng": "11.41522"
  },
  {
    "country": "DE",
    "name": "Bendorf",
    "lat": "50.42289",
    "lng": "7.57924"
  },
  {
    "country": "DE",
    "name": "Bendestorf",
    "lat": "53.33583",
    "lng": "9.96154"
  },
  {
    "country": "DE",
    "name": "Bempflingen",
    "lat": "48.57178",
    "lng": "9.26834"
  },
  {
    "country": "DE",
    "name": "Bad Belzig",
    "lat": "52.14184",
    "lng": "12.59272"
  },
  {
    "country": "DE",
    "name": "Beltheim",
    "lat": "50.10606",
    "lng": "7.46208"
  },
  {
    "country": "DE",
    "name": "Belm",
    "lat": "52.3",
    "lng": "8.13333"
  },
  {
    "country": "DE",
    "name": "Bellheim",
    "lat": "49.19833",
    "lng": "8.27944"
  },
  {
    "country": "DE",
    "name": "Bellenberg",
    "lat": "48.25726",
    "lng": "10.09094"
  },
  {
    "country": "DE",
    "name": "Belleben",
    "lat": "51.67499",
    "lng": "11.6342"
  },
  {
    "country": "DE",
    "name": "Bell",
    "lat": "50.38333",
    "lng": "7.23333"
  },
  {
    "country": "DE",
    "name": "Bell",
    "lat": "50.06139",
    "lng": "7.41515"
  },
  {
    "country": "DE",
    "name": "Belgershain",
    "lat": "51.23333",
    "lng": "12.55"
  },
  {
    "country": "DE",
    "name": "Belgern",
    "lat": "51.48263",
    "lng": "13.12382"
  },
  {
    "country": "DE",
    "name": "Beindersheim",
    "lat": "49.56056",
    "lng": "8.31944"
  },
  {
    "country": "DE",
    "name": "Beimerstetten",
    "lat": "48.48333",
    "lng": "9.98333"
  },
  {
    "country": "DE",
    "name": "Beilstein",
    "lat": "49.0414",
    "lng": "9.3137"
  },
  {
    "country": "DE",
    "name": "Beilrode",
    "lat": "51.56667",
    "lng": "13.06667"
  },
  {
    "country": "DE",
    "name": "Beiersdorf",
    "lat": "51.07405",
    "lng": "14.53828"
  },
  {
    "country": "DE",
    "name": "Beierfeld",
    "lat": "50.56529",
    "lng": "12.79049"
  },
  {
    "country": "DE",
    "name": "Bei der Höhne",
    "lat": "53.51351",
    "lng": "9.11191"
  },
  {
    "country": "DE",
    "name": "Behringen",
    "lat": "50.77283",
    "lng": "11.01403"
  },
  {
    "country": "DE",
    "name": "Beetzendorf",
    "lat": "52.70226",
    "lng": "11.0889"
  },
  {
    "country": "DE",
    "name": "Beesten",
    "lat": "52.43333",
    "lng": "7.5"
  },
  {
    "country": "DE",
    "name": "Beeskow",
    "lat": "52.17291",
    "lng": "14.24597"
  },
  {
    "country": "DE",
    "name": "Beesenstedt",
    "lat": "51.56828",
    "lng": "11.73323"
  },
  {
    "country": "DE",
    "name": "Beesenlaublingen",
    "lat": "51.71274",
    "lng": "11.69729"
  },
  {
    "country": "DE",
    "name": "Beerfelden",
    "lat": "49.56858",
    "lng": "8.97444"
  },
  {
    "country": "DE",
    "name": "Beelitz",
    "lat": "52.23812",
    "lng": "12.9714"
  },
  {
    "country": "DE",
    "name": "Beelen",
    "lat": "51.92906",
    "lng": "8.11117"
  },
  {
    "country": "DE",
    "name": "Beedenbostel",
    "lat": "52.64288",
    "lng": "10.25907"
  },
  {
    "country": "DE",
    "name": "Bedburg",
    "lat": "50.99258",
    "lng": "6.57128"
  },
  {
    "country": "DE",
    "name": "Beckum",
    "lat": "51.75571",
    "lng": "8.04075"
  },
  {
    "country": "DE",
    "name": "Beckingen",
    "lat": "49.4",
    "lng": "6.7"
  },
  {
    "country": "DE",
    "name": "Beckedorf",
    "lat": "52.35",
    "lng": "9.31667"
  },
  {
    "country": "DE",
    "name": "Beckdorf",
    "lat": "53.41667",
    "lng": "9.61667"
  },
  {
    "country": "DE",
    "name": "Bechtsrieth",
    "lat": "49.64487",
    "lng": "12.20997"
  },
  {
    "country": "DE",
    "name": "Bechtolsheim",
    "lat": "49.80417",
    "lng": "8.19389"
  },
  {
    "country": "DE",
    "name": "Bechtheim",
    "lat": "49.72778",
    "lng": "8.29222"
  },
  {
    "country": "DE",
    "name": "Bechhofen",
    "lat": "49.35",
    "lng": "7.4"
  },
  {
    "country": "DE",
    "name": "Bebra",
    "lat": "50.97445",
    "lng": "9.79562"
  },
  {
    "country": "DE",
    "name": "Bayrischzell",
    "lat": "47.6744",
    "lng": "12.01449"
  },
  {
    "country": "DE",
    "name": "Bayreuth",
    "lat": "49.94782",
    "lng": "11.57893"
  },
  {
    "country": "DE",
    "name": "Bayerisch Gmain",
    "lat": "47.71667",
    "lng": "12.9"
  },
  {
    "country": "DE",
    "name": "Bayerisch Eisenstein",
    "lat": "49.11667",
    "lng": "13.2"
  },
  {
    "country": "DE",
    "name": "Bayerbach",
    "lat": "48.7045",
    "lng": "12.2975"
  },
  {
    "country": "DE",
    "name": "Bayerbach",
    "lat": "48.41017",
    "lng": "13.14411"
  },
  {
    "country": "DE",
    "name": "Bayenthal",
    "lat": "50.91218",
    "lng": "6.96799"
  },
  {
    "country": "DE",
    "name": "Bawinkel",
    "lat": "52.6",
    "lng": "7.4"
  },
  {
    "country": "DE",
    "name": "Bautzen",
    "lat": "51.18035",
    "lng": "14.43494"
  },
  {
    "country": "DE",
    "name": "Bausendorf",
    "lat": "50.01667",
    "lng": "7"
  },
  {
    "country": "DE",
    "name": "Baunatal",
    "lat": "51.25182",
    "lng": "9.40747"
  },
  {
    "country": "DE",
    "name": "Baunach",
    "lat": "49.98592",
    "lng": "10.85179"
  },
  {
    "country": "DE",
    "name": "Baumschulenweg",
    "lat": "52.46583",
    "lng": "13.48523"
  },
  {
    "country": "DE",
    "name": "Baumholder",
    "lat": "49.61738",
    "lng": "7.33381"
  },
  {
    "country": "DE",
    "name": "Baudenbach",
    "lat": "49.62512",
    "lng": "10.53598"
  },
  {
    "country": "DE",
    "name": "Battenberg",
    "lat": "51.01391",
    "lng": "8.64603"
  },
  {
    "country": "DE",
    "name": "Bastorf",
    "lat": "54.12566",
    "lng": "11.69695"
  },
  {
    "country": "DE",
    "name": "Bastheim",
    "lat": "50.4008",
    "lng": "10.20372"
  },
  {
    "country": "DE",
    "name": "Bassum",
    "lat": "52.85059",
    "lng": "8.72791"
  },
  {
    "country": "DE",
    "name": "Bassenheim",
    "lat": "50.3582",
    "lng": "7.45961"
  },
  {
    "country": "DE",
    "name": "Basdahl",
    "lat": "53.44502",
    "lng": "9.00025"
  },
  {
    "country": "DE",
    "name": "Barwedel",
    "lat": "52.52192",
    "lng": "10.77488"
  },
  {
    "country": "DE",
    "name": "Barver",
    "lat": "52.62066",
    "lng": "8.59251"
  },
  {
    "country": "DE",
    "name": "Baruth",
    "lat": "52.04468",
    "lng": "13.5027"
  },
  {
    "country": "DE",
    "name": "Barum",
    "lat": "53.35",
    "lng": "10.4"
  },
  {
    "country": "DE",
    "name": "Bartholomä",
    "lat": "48.7535",
    "lng": "9.98752"
  },
  {
    "country": "DE",
    "name": "Barth",
    "lat": "54.36346",
    "lng": "12.72491"
  },
  {
    "country": "DE",
    "name": "Barßel",
    "lat": "53.16981",
    "lng": "7.75012"
  },
  {
    "country": "DE",
    "name": "Barsinghausen",
    "lat": "52.3",
    "lng": "9.45"
  },
  {
    "country": "DE",
    "name": "Barsbüttel",
    "lat": "53.56667",
    "lng": "10.16667"
  },
  {
    "country": "DE",
    "name": "Barntrup",
    "lat": "51.99038",
    "lng": "9.11642"
  },
  {
    "country": "DE",
    "name": "Barnstorf",
    "lat": "52.71009",
    "lng": "8.50256"
  },
  {
    "country": "DE",
    "name": "Barnstädt",
    "lat": "51.34401",
    "lng": "11.63735"
  },
  {
    "country": "DE",
    "name": "Bärnau",
    "lat": "49.81079",
    "lng": "12.43318"
  },
  {
    "country": "DE",
    "name": "Barmstedt",
    "lat": "53.79209",
    "lng": "9.76739"
  },
  {
    "country": "DE",
    "name": "Barleben",
    "lat": "52.20193",
    "lng": "11.6177"
  },
  {
    "country": "DE",
    "name": "Barkelsby",
    "lat": "54.5",
    "lng": "9.83333"
  },
  {
    "country": "DE",
    "name": "Bark",
    "lat": "53.91146",
    "lng": "10.17949"
  },
  {
    "country": "DE",
    "name": "Bargteheide",
    "lat": "53.72856",
    "lng": "10.26695"
  },
  {
    "country": "DE",
    "name": "Bargstedt",
    "lat": "53.46667",
    "lng": "9.45"
  },
  {
    "country": "DE",
    "name": "Bargfeld-Stegen",
    "lat": "53.76778",
    "lng": "10.1875"
  },
  {
    "country": "DE",
    "name": "Bärenstein",
    "lat": "50.80125",
    "lng": "13.79771"
  },
  {
    "country": "DE",
    "name": "Bärenstein",
    "lat": "50.5",
    "lng": "13.03333"
  },
  {
    "country": "DE",
    "name": "Barendorf",
    "lat": "53.22896",
    "lng": "10.52158"
  },
  {
    "country": "DE",
    "name": "Barenburg",
    "lat": "52.61953",
    "lng": "8.79999"
  },
  {
    "country": "DE",
    "name": "Bardowick",
    "lat": "53.29354",
    "lng": "10.38811"
  },
  {
    "country": "DE",
    "name": "Barchfeld",
    "lat": "50.82872",
    "lng": "11.17955"
  },
  {
    "country": "DE",
    "name": "Barbing",
    "lat": "49",
    "lng": "12.2"
  },
  {
    "country": "DE",
    "name": "Banzkow",
    "lat": "53.52497",
    "lng": "11.52306"
  },
  {
    "country": "DE",
    "name": "Banteln",
    "lat": "52.06667",
    "lng": "9.75"
  },
  {
    "country": "DE",
    "name": "Bannewitz",
    "lat": "50.99291",
    "lng": "13.71712"
  },
  {
    "country": "DE",
    "name": "Bann",
    "lat": "49.38333",
    "lng": "7.61667"
  },
  {
    "country": "DE",
    "name": "Bammental",
    "lat": "49.35611",
    "lng": "8.77944"
  },
  {
    "country": "DE",
    "name": "Bamberg",
    "lat": "49.89873",
    "lng": "10.90067"
  },
  {
    "country": "DE",
    "name": "Balzhausen",
    "lat": "48.24228",
    "lng": "10.49366"
  },
  {
    "country": "DE",
    "name": "Balzfeld",
    "lat": "49.26892",
    "lng": "8.78919"
  },
  {
    "country": "DE",
    "name": "Balve",
    "lat": "51.3315",
    "lng": "7.86424"
  },
  {
    "country": "DE",
    "name": "Baltmannsweiler",
    "lat": "48.74215",
    "lng": "9.4494"
  },
  {
    "country": "DE",
    "name": "Ballenstedt",
    "lat": "51.719",
    "lng": "11.23265"
  },
  {
    "country": "DE",
    "name": "Balje",
    "lat": "53.83333",
    "lng": "9.13333"
  },
  {
    "country": "DE",
    "name": "Balingen",
    "lat": "48.27525",
    "lng": "8.85464"
  },
  {
    "country": "DE",
    "name": "Balge",
    "lat": "52.71667",
    "lng": "9.16667"
  },
  {
    "country": "DE",
    "name": "Bakum",
    "lat": "52.74118",
    "lng": "8.19546"
  },
  {
    "country": "DE",
    "name": "Baisweil",
    "lat": "47.94439",
    "lng": "10.54007"
  },
  {
    "country": "DE",
    "name": "Baindt",
    "lat": "47.85",
    "lng": "9.66667"
  },
  {
    "country": "DE",
    "name": "Baiersdorf",
    "lat": "49.65807",
    "lng": "11.03594"
  },
  {
    "country": "DE",
    "name": "Baiersbronn",
    "lat": "48.50318",
    "lng": "8.37699"
  },
  {
    "country": "DE",
    "name": "Baierbrunn",
    "lat": "48.0203",
    "lng": "11.48689"
  },
  {
    "country": "DE",
    "name": "Baienfurt",
    "lat": "47.82857",
    "lng": "9.65157"
  },
  {
    "country": "DE",
    "name": "Bahrenborstel",
    "lat": "52.57009",
    "lng": "8.80863"
  },
  {
    "country": "DE",
    "name": "Bahrdorf",
    "lat": "52.38587",
    "lng": "11.0004"
  },
  {
    "country": "DE",
    "name": "Bahlingen",
    "lat": "48.12064",
    "lng": "7.73982"
  },
  {
    "country": "DE",
    "name": "Baesweiler",
    "lat": "50.90964",
    "lng": "6.18874"
  },
  {
    "country": "DE",
    "name": "Bad Zwischenahn",
    "lat": "53.18333",
    "lng": "8"
  },
  {
    "country": "DE",
    "name": "Bad Wurzach",
    "lat": "47.90799",
    "lng": "9.89686"
  },
  {
    "country": "DE",
    "name": "Bad Wörishofen",
    "lat": "48.00674",
    "lng": "10.59666"
  },
  {
    "country": "DE",
    "name": "Bad Windsheim",
    "lat": "49.50274",
    "lng": "10.41539"
  },
  {
    "country": "DE",
    "name": "Bad Wimpfen",
    "lat": "49.22971",
    "lng": "9.15648"
  },
  {
    "country": "DE",
    "name": "Bad Wilsnack",
    "lat": "52.95607",
    "lng": "11.94903"
  },
  {
    "country": "DE",
    "name": "Bad Wildungen",
    "lat": "51.11963",
    "lng": "9.12475"
  },
  {
    "country": "DE",
    "name": "Bad Wiessee",
    "lat": "47.71667",
    "lng": "11.71667"
  },
  {
    "country": "DE",
    "name": "Bad Waldsee",
    "lat": "47.92027",
    "lng": "9.7549"
  },
  {
    "country": "DE",
    "name": "Bad Vilbel",
    "lat": "50.17866",
    "lng": "8.73756"
  },
  {
    "country": "DE",
    "name": "Bad Überkingen",
    "lat": "48.59991",
    "lng": "9.79586"
  },
  {
    "country": "DE",
    "name": "Bad Tölz",
    "lat": "47.76111",
    "lng": "11.5589"
  },
  {
    "country": "DE",
    "name": "Bad Tennstedt",
    "lat": "51.15447",
    "lng": "10.83873"
  },
  {
    "country": "DE",
    "name": "Bad Sülze",
    "lat": "54.11084",
    "lng": "12.66054"
  },
  {
    "country": "DE",
    "name": "Bad Sulza",
    "lat": "51.08929",
    "lng": "11.62474"
  },
  {
    "country": "DE",
    "name": "Bad Suderode",
    "lat": "51.73333",
    "lng": "11.11667"
  },
  {
    "country": "DE",
    "name": "Bad Steben",
    "lat": "50.36648",
    "lng": "11.64438"
  },
  {
    "country": "DE",
    "name": "Bad Sooden-Allendorf",
    "lat": "51.27092",
    "lng": "9.97483"
  },
  {
    "country": "DE",
    "name": "Bad Soden-Salmünster",
    "lat": "50.27574",
    "lng": "9.36705"
  },
  {
    "country": "DE",
    "name": "Bad Soden am Taunus",
    "lat": "50.1408",
    "lng": "8.50449"
  },
  {
    "country": "DE",
    "name": "Bad Segeberg",
    "lat": "53.94313",
    "lng": "10.30215"
  },
  {
    "country": "DE",
    "name": "Bad Schwartau",
    "lat": "53.91887",
    "lng": "10.69691"
  },
  {
    "country": "DE",
    "name": "Bad Schwalbach",
    "lat": "50.14196",
    "lng": "8.06964"
  },
  {
    "country": "DE",
    "name": "Bad Schmiedeberg",
    "lat": "51.68516",
    "lng": "12.73483"
  },
  {
    "country": "DE",
    "name": "Bad Schandau",
    "lat": "50.91743",
    "lng": "14.15494"
  },
  {
    "country": "DE",
    "name": "Bad Sassendorf",
    "lat": "51.58333",
    "lng": "8.16667"
  },
  {
    "country": "DE",
    "name": "Bad Salzungen",
    "lat": "50.81342",
    "lng": "10.2361"
  },
  {
    "country": "DE",
    "name": "Bad Salzuflen",
    "lat": "52.0862",
    "lng": "8.74434"
  },
  {
    "country": "DE",
    "name": "Bad Salzschlirf",
    "lat": "50.62388",
    "lng": "9.50815"
  },
  {
    "country": "DE",
    "name": "Bad Salzdetfurth",
    "lat": "52.05777",
    "lng": "10.0058"
  },
  {
    "country": "DE",
    "name": "Bad Säckingen",
    "lat": "47.55371",
    "lng": "7.94612"
  },
  {
    "country": "DE",
    "name": "Bad Sachsa",
    "lat": "51.59499",
    "lng": "10.55546"
  },
  {
    "country": "DE",
    "name": "Bad Saarow",
    "lat": "52.28333",
    "lng": "14.06667"
  },
  {
    "country": "DE",
    "name": "Bad Rothenfelde",
    "lat": "52.11667",
    "lng": "8.16667"
  },
  {
    "country": "DE",
    "name": "Bad Reichenhall",
    "lat": "47.72947",
    "lng": "12.87819"
  },
  {
    "country": "DE",
    "name": "Bad Rappenau",
    "lat": "49.23848",
    "lng": "9.1018"
  },
  {
    "country": "DE",
    "name": "Bad Pyrmont",
    "lat": "51.98589",
    "lng": "9.25246"
  },
  {
    "country": "DE",
    "name": "Bad Orb",
    "lat": "50.22788",
    "lng": "9.34782"
  },
  {
    "country": "DE",
    "name": "Bad Oldesloe",
    "lat": "53.81167",
    "lng": "10.37417"
  },
  {
    "country": "DE",
    "name": "Bad Oeynhausen",
    "lat": "52.20699",
    "lng": "8.80365"
  },
  {
    "country": "DE",
    "name": "Bad Neustadt an der Saale",
    "lat": "50.32174",
    "lng": "10.20673"
  },
  {
    "country": "DE",
    "name": "Bad Neuenahr-Ahrweiler",
    "lat": "50.54322",
    "lng": "7.1113"
  },
  {
    "country": "DE",
    "name": "Bad Nenndorf",
    "lat": "52.33703",
    "lng": "9.37904"
  },
  {
    "country": "DE",
    "name": "Bad Nauheim",
    "lat": "50.36463",
    "lng": "8.73859"
  },
  {
    "country": "DE",
    "name": "Bad Muskau",
    "lat": "51.55051",
    "lng": "14.7124"
  },
  {
    "country": "DE",
    "name": "Bad Münstereifel",
    "lat": "50.55667",
    "lng": "6.76424"
  },
  {
    "country": "DE",
    "name": "Bad Münster am Stein-Ebernburg",
    "lat": "49.81159",
    "lng": "7.84523"
  },
  {
    "country": "DE",
    "name": "Bad Münder am Deister",
    "lat": "52.19551",
    "lng": "9.46421"
  },
  {
    "country": "DE",
    "name": "Bad Mergentheim",
    "lat": "49.4925",
    "lng": "9.77361"
  },
  {
    "country": "DE",
    "name": "Bad Meinberg",
    "lat": "51.89588",
    "lng": "8.98313"
  },
  {
    "country": "DE",
    "name": "Bad Marienberg",
    "lat": "50.64947",
    "lng": "7.94958"
  },
  {
    "country": "DE",
    "name": "Bad Lippspringe",
    "lat": "51.78333",
    "lng": "8.81683"
  },
  {
    "country": "DE",
    "name": "Bad Liebenzell",
    "lat": "48.77427",
    "lng": "8.72971"
  },
  {
    "country": "DE",
    "name": "Bad Liebenwerda",
    "lat": "51.51826",
    "lng": "13.39459"
  },
  {
    "country": "DE",
    "name": "Bad Liebenstein",
    "lat": "50.81569",
    "lng": "10.35123"
  },
  {
    "country": "DE",
    "name": "Bad Lauterberg im Harz",
    "lat": "51.63272",
    "lng": "10.47031"
  },
  {
    "country": "DE",
    "name": "Bad Lausick",
    "lat": "51.14495",
    "lng": "12.64449"
  },
  {
    "country": "DE",
    "name": "Bad Lauchstädt",
    "lat": "51.38652",
    "lng": "11.86956"
  },
  {
    "country": "DE",
    "name": "Bad Langensalza",
    "lat": "51.10771",
    "lng": "10.646"
  },
  {
    "country": "DE",
    "name": "Bad Kreuznach",
    "lat": "49.8414",
    "lng": "7.86713"
  },
  {
    "country": "DE",
    "name": "Bad Köstritz",
    "lat": "50.93032",
    "lng": "12.01005"
  },
  {
    "country": "DE",
    "name": "Bad Kösen",
    "lat": "51.13431",
    "lng": "11.72203"
  },
  {
    "country": "DE",
    "name": "Bad König",
    "lat": "49.7432",
    "lng": "9.0075"
  },
  {
    "country": "DE",
    "name": "Bad Kohlgrub",
    "lat": "47.66667",
    "lng": "11.05"
  },
  {
    "country": "DE",
    "name": "Bad Klosterlausnitz",
    "lat": "50.91667",
    "lng": "11.86667"
  },
  {
    "country": "DE",
    "name": "Bad Kleinen",
    "lat": "53.77134",
    "lng": "11.47165"
  },
  {
    "country": "DE",
    "name": "Bad Kissingen",
    "lat": "50.20228",
    "lng": "10.07784"
  },
  {
    "country": "DE",
    "name": "Bad Iburg",
    "lat": "52.1549",
    "lng": "8.04216"
  },
  {
    "country": "DE",
    "name": "Bad Hönningen",
    "lat": "50.51689",
    "lng": "7.31195"
  },
  {
    "country": "DE",
    "name": "Bad Honnef",
    "lat": "50.64336",
    "lng": "7.2278"
  },
  {
    "country": "DE",
    "name": "Bad Homburg vor der Höhe",
    "lat": "50.22683",
    "lng": "8.61816"
  },
  {
    "country": "DE",
    "name": "Bad Hersfeld",
    "lat": "50.87197",
    "lng": "9.70891"
  },
  {
    "country": "DE",
    "name": "Bad Herrenalb",
    "lat": "48.79787",
    "lng": "8.43617"
  },
  {
    "country": "DE",
    "name": "Bad Heilbrunn",
    "lat": "47.74671",
    "lng": "11.45934"
  },
  {
    "country": "DE",
    "name": "Bad Harzburg",
    "lat": "51.88268",
    "lng": "10.56157"
  },
  {
    "country": "DE",
    "name": "Bad Grund",
    "lat": "51.81021",
    "lng": "10.23694"
  },
  {
    "country": "DE",
    "name": "Bad Gandersheim",
    "lat": "51.87167",
    "lng": "10.02537"
  },
  {
    "country": "DE",
    "name": "Bad Freienwalde",
    "lat": "52.7873",
    "lng": "14.0304"
  },
  {
    "country": "DE",
    "name": "Bad Frankenhausen",
    "lat": "51.35609",
    "lng": "11.09977"
  },
  {
    "country": "DE",
    "name": "Bad Feilnbach",
    "lat": "47.77331",
    "lng": "12.00973"
  },
  {
    "country": "DE",
    "name": "Bad Essen",
    "lat": "52.31667",
    "lng": "8.33333"
  },
  {
    "country": "DE",
    "name": "Badenweiler",
    "lat": "47.80223",
    "lng": "7.67236"
  },
  {
    "country": "DE",
    "name": "Badenhausen",
    "lat": "51.76996",
    "lng": "10.20493"
  },
  {
    "country": "DE",
    "name": "Baden-Baden",
    "lat": "48.7606",
    "lng": "8.23975"
  },
  {
    "country": "DE",
    "name": "Bad Ems",
    "lat": "50.33544",
    "lng": "7.71369"
  },
  {
    "country": "DE",
    "name": "Badem",
    "lat": "50",
    "lng": "6.61667"
  },
  {
    "country": "DE",
    "name": "Bad Elster",
    "lat": "50.28192",
    "lng": "12.2343"
  },
  {
    "country": "DE",
    "name": "Bad Eilsen",
    "lat": "52.24215",
    "lng": "9.09822"
  },
  {
    "country": "DE",
    "name": "Bad Dürrheim",
    "lat": "48.02093",
    "lng": "8.53056"
  },
  {
    "country": "DE",
    "name": "Bad Dürrenberg",
    "lat": "51.29545",
    "lng": "12.06583"
  },
  {
    "country": "DE",
    "name": "Bad Dürkheim",
    "lat": "49.4618",
    "lng": "8.17236"
  },
  {
    "country": "DE",
    "name": "Bad Düben",
    "lat": "51.59174",
    "lng": "12.58492"
  },
  {
    "country": "DE",
    "name": "Bad Driburg",
    "lat": "51.73297",
    "lng": "9.01969"
  },
  {
    "country": "DE",
    "name": "Bad Doberan",
    "lat": "54.10712",
    "lng": "11.90051"
  },
  {
    "country": "DE",
    "name": "Bad Ditzenbach",
    "lat": "48.5883",
    "lng": "9.70393"
  },
  {
    "country": "DE",
    "name": "Baddeckenstedt",
    "lat": "52.08333",
    "lng": "10.23333"
  },
  {
    "country": "DE",
    "name": "Bad Buchau",
    "lat": "48.06231",
    "lng": "9.61244"
  },
  {
    "country": "DE",
    "name": "Bad Brückenau",
    "lat": "50.30853",
    "lng": "9.78985"
  },
  {
    "country": "DE",
    "name": "Bad Breisig",
    "lat": "50.50523",
    "lng": "7.28861"
  },
  {
    "country": "DE",
    "name": "Bad Bramstedt",
    "lat": "53.9183",
    "lng": "9.88424"
  },
  {
    "country": "DE",
    "name": "Bad Brambach",
    "lat": "50.21667",
    "lng": "12.31667"
  },
  {
    "country": "DE",
    "name": "Bad Bocklet",
    "lat": "50.26648",
    "lng": "10.07902"
  },
  {
    "country": "DE",
    "name": "Bad Blankenburg",
    "lat": "50.68189",
    "lng": "11.27369"
  },
  {
    "country": "DE",
    "name": "Bad Bibra",
    "lat": "51.20796",
    "lng": "11.58517"
  },
  {
    "country": "DE",
    "name": "Bad Berneck im Fichtelgebirge",
    "lat": "50.04564",
    "lng": "11.67238"
  },
  {
    "country": "DE",
    "name": "Bad Berleburg",
    "lat": "51.05224",
    "lng": "8.39227"
  },
  {
    "country": "DE",
    "name": "Bad Berka",
    "lat": "50.89982",
    "lng": "11.28245"
  },
  {
    "country": "DE",
    "name": "Bad Bergzabern",
    "lat": "49.10245",
    "lng": "8.00092"
  },
  {
    "country": "DE",
    "name": "Badbergen",
    "lat": "52.63333",
    "lng": "7.98333"
  },
  {
    "country": "DE",
    "name": "Bad Bentheim",
    "lat": "52.30066",
    "lng": "7.15763"
  },
  {
    "country": "DE",
    "name": "Bad Bellingen",
    "lat": "47.73147",
    "lng": "7.55756"
  },
  {
    "country": "DE",
    "name": "Bad Aibling",
    "lat": "47.8638",
    "lng": "12.01055"
  },
  {
    "country": "DE",
    "name": "Bad Abbach",
    "lat": "48.93754",
    "lng": "12.04494"
  },
  {
    "country": "DE",
    "name": "Backnang",
    "lat": "48.94743",
    "lng": "9.43718"
  },
  {
    "country": "DE",
    "name": "Bächingen an der Brenz",
    "lat": "48.54627",
    "lng": "10.31281"
  },
  {
    "country": "DE",
    "name": "Bachhagel",
    "lat": "48.63217",
    "lng": "10.32045"
  },
  {
    "country": "DE",
    "name": "Bacharach",
    "lat": "50.05725",
    "lng": "7.76948"
  },
  {
    "country": "DE",
    "name": "Bach",
    "lat": "49.4",
    "lng": "12.38333"
  },
  {
    "country": "DE",
    "name": "Babensham",
    "lat": "48.08333",
    "lng": "12.26667"
  },
  {
    "country": "DE",
    "name": "Babenhausen",
    "lat": "49.96519",
    "lng": "8.95129"
  },
  {
    "country": "DE",
    "name": "Babenhausen",
    "lat": "48.14497",
    "lng": "10.25325"
  },
  {
    "country": "DE",
    "name": "Baalberge",
    "lat": "51.76469",
    "lng": "11.7988"
  },
  {
    "country": "DE",
    "name": "Aystetten",
    "lat": "48.40556",
    "lng": "10.77742"
  },
  {
    "country": "DE",
    "name": "Ayl",
    "lat": "49.63333",
    "lng": "6.55"
  },
  {
    "country": "DE",
    "name": "Aying",
    "lat": "47.9701",
    "lng": "11.77752"
  },
  {
    "country": "DE",
    "name": "Axstedt",
    "lat": "53.35466",
    "lng": "8.77485"
  },
  {
    "country": "DE",
    "name": "Außernzell",
    "lat": "48.72409",
    "lng": "13.20291"
  },
  {
    "country": "DE",
    "name": "Ausleben",
    "lat": "52.09049",
    "lng": "11.11192"
  },
  {
    "country": "DE",
    "name": "Aurich",
    "lat": "53.46919",
    "lng": "7.48232"
  },
  {
    "country": "DE",
    "name": "Aura im Sinngrund",
    "lat": "50.17819",
    "lng": "9.57547"
  },
  {
    "country": "DE",
    "name": "Auma",
    "lat": "50.70044",
    "lng": "11.89958"
  },
  {
    "country": "DE",
    "name": "Aulendorf",
    "lat": "47.95083",
    "lng": "9.63745"
  },
  {
    "country": "DE",
    "name": "Auleben",
    "lat": "51.4264",
    "lng": "10.92968"
  },
  {
    "country": "DE",
    "name": "Au in der Hallertau",
    "lat": "48.55838",
    "lng": "11.74138"
  },
  {
    "country": "DE",
    "name": "Auhausen",
    "lat": "49.0079",
    "lng": "10.6224"
  },
  {
    "country": "DE",
    "name": "Auhagen",
    "lat": "52.39828",
    "lng": "9.29194"
  },
  {
    "country": "DE",
    "name": "Augustusburg",
    "lat": "50.81192",
    "lng": "13.10197"
  },
  {
    "country": "DE",
    "name": "Augustdorf",
    "lat": "51.90944",
    "lng": "8.73173"
  },
  {
    "country": "DE",
    "name": "Augsburg",
    "lat": "48.37154",
    "lng": "10.89851"
  },
  {
    "country": "DE",
    "name": "Auggen",
    "lat": "47.78333",
    "lng": "7.6"
  },
  {
    "country": "DE",
    "name": "Aufseß",
    "lat": "49.8837",
    "lng": "11.22692"
  },
  {
    "country": "DE",
    "name": "Aufhausen",
    "lat": "48.87205",
    "lng": "12.2821"
  },
  {
    "country": "DE",
    "name": "Auerbach",
    "lat": "50.51155",
    "lng": "12.40083"
  },
  {
    "country": "DE",
    "name": "Auerbach",
    "lat": "49.69201",
    "lng": "11.63327"
  },
  {
    "country": "DE",
    "name": "Auerbach",
    "lat": "48.80353",
    "lng": "13.09952"
  },
  {
    "country": "DE",
    "name": "Aue",
    "lat": "50.59034",
    "lng": "12.70657"
  },
  {
    "country": "DE",
    "name": "Aub",
    "lat": "49.55267",
    "lng": "10.0653"
  },
  {
    "country": "DE",
    "name": "Au am Rhein",
    "lat": "48.95",
    "lng": "8.23333"
  },
  {
    "country": "DE",
    "name": "Au",
    "lat": "47.95",
    "lng": "7.83333"
  },
  {
    "country": "DE",
    "name": "Atzendorf",
    "lat": "51.91954",
    "lng": "11.59906"
  },
  {
    "country": "DE",
    "name": "Atting",
    "lat": "48.89412",
    "lng": "12.48776"
  },
  {
    "country": "DE",
    "name": "Attenweiler",
    "lat": "48.13333",
    "lng": "9.7"
  },
  {
    "country": "DE",
    "name": "Attenkirchen",
    "lat": "48.50526",
    "lng": "11.76011"
  },
  {
    "country": "DE",
    "name": "Attenhofen",
    "lat": "48.65072",
    "lng": "11.8485"
  },
  {
    "country": "DE",
    "name": "Attendorn",
    "lat": "51.12645",
    "lng": "7.90333"
  },
  {
    "country": "DE",
    "name": "Aßling",
    "lat": "47.99297",
    "lng": "12.00643"
  },
  {
    "country": "DE",
    "name": "Aßlar",
    "lat": "50.59163",
    "lng": "8.46273"
  },
  {
    "country": "DE",
    "name": "Asselfingen",
    "lat": "48.52959",
    "lng": "10.19166"
  },
  {
    "country": "DE",
    "name": "Assamstadt",
    "lat": "49.42806",
    "lng": "9.68611"
  },
  {
    "country": "DE",
    "name": "Asperg",
    "lat": "48.90525",
    "lng": "9.13502"
  },
  {
    "country": "DE",
    "name": "Asendorf",
    "lat": "53.29266",
    "lng": "9.97905"
  },
  {
    "country": "DE",
    "name": "Asendorf",
    "lat": "52.77219",
    "lng": "9.00489"
  },
  {
    "country": "DE",
    "name": "Aschheim",
    "lat": "48.17112",
    "lng": "11.71675"
  },
  {
    "country": "DE",
    "name": "Aschersleben",
    "lat": "51.75742",
    "lng": "11.46084"
  },
  {
    "country": "DE",
    "name": "Ascheberg",
    "lat": "54.15027",
    "lng": "10.34552"
  },
  {
    "country": "DE",
    "name": "Ascheberg",
    "lat": "51.78333",
    "lng": "7.61667"
  },
  {
    "country": "DE",
    "name": "Aschau am Inn",
    "lat": "48.19845",
    "lng": "12.35003"
  },
  {
    "country": "DE",
    "name": "Aschaffenburg",
    "lat": "49.97704",
    "lng": "9.15214"
  },
  {
    "country": "DE",
    "name": "Ascha",
    "lat": "49",
    "lng": "12.63333"
  },
  {
    "country": "DE",
    "name": "Asbach",
    "lat": "50.66667",
    "lng": "7.41667"
  },
  {
    "country": "DE",
    "name": "Arzfeld",
    "lat": "50.08957",
    "lng": "6.27069"
  },
  {
    "country": "DE",
    "name": "Arzberg",
    "lat": "51.52887",
    "lng": "13.12565"
  },
  {
    "country": "DE",
    "name": "Arzberg",
    "lat": "50.05774",
    "lng": "12.18676"
  },
  {
    "country": "DE",
    "name": "Arzbach",
    "lat": "50.37902",
    "lng": "7.74948"
  },
  {
    "country": "DE",
    "name": "Artlenburg",
    "lat": "53.37182",
    "lng": "10.48793"
  },
  {
    "country": "DE",
    "name": "Artern",
    "lat": "51.36431",
    "lng": "11.29167"
  },
  {
    "country": "DE",
    "name": "Arrach",
    "lat": "49.19149",
    "lng": "12.99387"
  },
  {
    "country": "DE",
    "name": "Arpke",
    "lat": "52.38597",
    "lng": "10.10047"
  },
  {
    "country": "DE",
    "name": "Bad Arolsen",
    "lat": "51.37982",
    "lng": "9.01445"
  },
  {
    "country": "DE",
    "name": "Arnstorf",
    "lat": "48.5584",
    "lng": "12.81674"
  },
  {
    "country": "DE",
    "name": "Arnstein",
    "lat": "49.97767",
    "lng": "9.96983"
  },
  {
    "country": "DE",
    "name": "Arnstadt",
    "lat": "50.84048",
    "lng": "10.95198"
  },
  {
    "country": "DE",
    "name": "Arnschwang",
    "lat": "49.27663",
    "lng": "12.81595"
  },
  {
    "country": "DE",
    "name": "Arnsberg",
    "lat": "51.38333",
    "lng": "8.08333"
  },
  {
    "country": "DE",
    "name": "Arneburg",
    "lat": "52.67565",
    "lng": "12.00514"
  },
  {
    "country": "DE",
    "name": "Arnbruck",
    "lat": "49.13012",
    "lng": "12.9982"
  },
  {
    "country": "DE",
    "name": "Armsheim",
    "lat": "49.80972",
    "lng": "8.05667"
  },
  {
    "country": "DE",
    "name": "Argenthal",
    "lat": "49.96667",
    "lng": "7.6"
  },
  {
    "country": "DE",
    "name": "Aresing",
    "lat": "48.27704",
    "lng": "12.60538"
  },
  {
    "country": "DE",
    "name": "Arenshausen",
    "lat": "51.37613",
    "lng": "9.9687"
  },
  {
    "country": "DE",
    "name": "Luftkurort Arendsee",
    "lat": "52.88073",
    "lng": "11.48621"
  },
  {
    "country": "DE",
    "name": "Arberg",
    "lat": "49.14428",
    "lng": "10.61722"
  },
  {
    "country": "DE",
    "name": "Appenheim",
    "lat": "49.93",
    "lng": "8.03333"
  },
  {
    "country": "DE",
    "name": "Appen",
    "lat": "53.65813",
    "lng": "9.74582"
  },
  {
    "country": "DE",
    "name": "Appel",
    "lat": "53.3906",
    "lng": "9.74565"
  },
  {
    "country": "DE",
    "name": "Apollensdorf",
    "lat": "51.87634",
    "lng": "12.55012"
  },
  {
    "country": "DE",
    "name": "Apolda",
    "lat": "51.02624",
    "lng": "11.51638"
  },
  {
    "country": "DE",
    "name": "Apfelstädt",
    "lat": "50.90157",
    "lng": "10.88977"
  },
  {
    "country": "DE",
    "name": "Apensen",
    "lat": "53.43333",
    "lng": "9.61667"
  },
  {
    "country": "DE",
    "name": "Apen",
    "lat": "53.21667",
    "lng": "7.8"
  },
  {
    "country": "DE",
    "name": "Apelern",
    "lat": "52.28979",
    "lng": "9.3358"
  },
  {
    "country": "DE",
    "name": "Anzing",
    "lat": "48.15171",
    "lng": "11.8533"
  },
  {
    "country": "DE",
    "name": "Antdorf",
    "lat": "47.75133",
    "lng": "11.30845"
  },
  {
    "country": "DE",
    "name": "Ansbach",
    "lat": "49.30481",
    "lng": "10.5931"
  },
  {
    "country": "DE",
    "name": "Anrode",
    "lat": "51.26667",
    "lng": "10.33333"
  },
  {
    "country": "DE",
    "name": "Anröchte",
    "lat": "51.56667",
    "lng": "8.33333"
  },
  {
    "country": "DE",
    "name": "Annweiler am Trifels",
    "lat": "49.20613",
    "lng": "7.97527"
  },
  {
    "country": "DE",
    "name": "Annaburg",
    "lat": "51.73298",
    "lng": "13.04729"
  },
  {
    "country": "DE",
    "name": "Annaberg-Buchholz",
    "lat": "50.57953",
    "lng": "13.00627"
  },
  {
    "country": "DE",
    "name": "Ankum",
    "lat": "52.55",
    "lng": "7.88333"
  },
  {
    "country": "DE",
    "name": "Anklam",
    "lat": "53.85637",
    "lng": "13.68965"
  },
  {
    "country": "DE",
    "name": "Anhausen",
    "lat": "50.5",
    "lng": "7.55"
  },
  {
    "country": "DE",
    "name": "Angersdorf",
    "lat": "51.46025",
    "lng": "11.90705"
  },
  {
    "country": "DE",
    "name": "Angern",
    "lat": "52.35",
    "lng": "11.73333"
  },
  {
    "country": "DE",
    "name": "Angermünde",
    "lat": "53.01499",
    "lng": "13.99924"
  },
  {
    "country": "DE",
    "name": "Andernach",
    "lat": "50.43109",
    "lng": "7.40425"
  },
  {
    "country": "DE",
    "name": "Andechs",
    "lat": "47.97464",
    "lng": "11.18279"
  },
  {
    "country": "DE",
    "name": "Amtzell",
    "lat": "47.7",
    "lng": "9.75"
  },
  {
    "country": "DE",
    "name": "Amstetten",
    "lat": "48.57876",
    "lng": "9.87388"
  },
  {
    "country": "DE",
    "name": "Ampfing",
    "lat": "48.254",
    "lng": "12.41515"
  },
  {
    "country": "DE",
    "name": "Amöneburg",
    "lat": "50.79595",
    "lng": "8.9233"
  },
  {
    "country": "DE",
    "name": "Ammerndorf",
    "lat": "49.42335",
    "lng": "10.85011"
  },
  {
    "country": "DE",
    "name": "Amerang",
    "lat": "47.99139",
    "lng": "12.30795"
  },
  {
    "country": "DE",
    "name": "Amendingen",
    "lat": "48.00302",
    "lng": "10.17918"
  },
  {
    "country": "DE",
    "name": "Amelinghausen",
    "lat": "53.12397",
    "lng": "10.21274"
  },
  {
    "country": "DE",
    "name": "Amberg",
    "lat": "49.44287",
    "lng": "11.86267"
  },
  {
    "country": "DE",
    "name": "Amberg",
    "lat": "48.06667",
    "lng": "10.68333"
  },
  {
    "country": "DE",
    "name": "Alzey",
    "lat": "49.74657",
    "lng": "8.11513"
  },
  {
    "country": "DE",
    "name": "Alzenau in Unterfranken",
    "lat": "50.0888",
    "lng": "9.06455"
  },
  {
    "country": "DE",
    "name": "Alveslohe",
    "lat": "53.78333",
    "lng": "9.91667"
  },
  {
    "country": "DE",
    "name": "Alt Wallmoden",
    "lat": "52.01933",
    "lng": "10.30294"
  },
  {
    "country": "DE",
    "name": "Altusried",
    "lat": "47.8041",
    "lng": "10.21429"
  },
  {
    "country": "DE",
    "name": "Alt Tucheband",
    "lat": "52.53732",
    "lng": "14.51225"
  },
  {
    "country": "DE",
    "name": "Hamburg-Altstadt",
    "lat": "53.55",
    "lng": "10"
  },
  {
    "country": "DE",
    "name": "Altshausen",
    "lat": "47.93333",
    "lng": "9.53333"
  },
  {
    "country": "DE",
    "name": "Altrip",
    "lat": "49.43556",
    "lng": "8.49472"
  },
  {
    "country": "DE",
    "name": "Altrich",
    "lat": "49.95701",
    "lng": "6.91217"
  },
  {
    "country": "DE",
    "name": "Altötting",
    "lat": "48.22533",
    "lng": "12.67665"
  },
  {
    "country": "DE",
    "name": "Altomünster",
    "lat": "48.38767",
    "lng": "11.25691"
  },
  {
    "country": "DE",
    "name": "Altmittweida",
    "lat": "50.96667",
    "lng": "12.95"
  },
  {
    "country": "DE",
    "name": "Alt Meteln",
    "lat": "53.74709",
    "lng": "11.34056"
  },
  {
    "country": "DE",
    "name": "Altlußheim",
    "lat": "49.30167",
    "lng": "8.49917"
  },
  {
    "country": "DE",
    "name": "Altleiningen",
    "lat": "49.5075",
    "lng": "8.07333"
  },
  {
    "country": "DE",
    "name": "Altlandsberg",
    "lat": "52.56503",
    "lng": "13.72815"
  },
  {
    "country": "DE",
    "name": "Altkirchen",
    "lat": "50.93333",
    "lng": "12.35"
  },
  {
    "country": "DE",
    "name": "Althütte",
    "lat": "48.91565",
    "lng": "9.56984"
  },
  {
    "country": "DE",
    "name": "Althengstett",
    "lat": "48.72325",
    "lng": "8.79434"
  },
  {
    "country": "DE",
    "name": "Althegnenberg",
    "lat": "48.23333",
    "lng": "11.06667"
  },
  {
    "country": "DE",
    "name": "Altglienicke",
    "lat": "52.41116",
    "lng": "13.5355"
  },
  {
    "country": "DE",
    "name": "Altfraunhofen",
    "lat": "48.45",
    "lng": "12.16667"
  },
  {
    "country": "DE",
    "name": "Altentreptow",
    "lat": "53.69416",
    "lng": "13.26504"
  },
  {
    "country": "DE",
    "name": "Altenthann",
    "lat": "49.1",
    "lng": "12.3"
  },
  {
    "country": "DE",
    "name": "Altensteig",
    "lat": "48.58649",
    "lng": "8.60395"
  },
  {
    "country": "DE",
    "name": "Altenstadt",
    "lat": "50.28747",
    "lng": "8.94373"
  },
  {
    "country": "DE",
    "name": "Altenstadt",
    "lat": "48.1603",
    "lng": "10.11437"
  },
  {
    "country": "DE",
    "name": "Altenstadt",
    "lat": "47.82359",
    "lng": "10.87475"
  },
  {
    "country": "DE",
    "name": "Altenriet",
    "lat": "48.5914",
    "lng": "9.22186"
  },
  {
    "country": "DE",
    "name": "Altenpleen",
    "lat": "54.35456",
    "lng": "12.9564"
  },
  {
    "country": "DE",
    "name": "Altenmünster",
    "lat": "48.46495",
    "lng": "10.59065"
  },
  {
    "country": "DE",
    "name": "Altenmedingen",
    "lat": "53.1305",
    "lng": "10.60163"
  },
  {
    "country": "DE",
    "name": "Altenmarkt",
    "lat": "47.7796",
    "lng": "12.1356"
  },
  {
    "country": "DE",
    "name": "Altenkunstadt",
    "lat": "50.12504",
    "lng": "11.2503"
  },
  {
    "country": "DE",
    "name": "Altenkrempe",
    "lat": "54.13333",
    "lng": "10.83333"
  },
  {
    "country": "DE",
    "name": "Altenkirchen",
    "lat": "54.63624",
    "lng": "13.34332"
  },
  {
    "country": "DE",
    "name": "Altenkirchen",
    "lat": "50.68594",
    "lng": "7.64176"
  },
  {
    "country": "DE",
    "name": "Altenkirchen",
    "lat": "49.44313",
    "lng": "7.32084"
  },
  {
    "country": "DE",
    "name": "Altenholz",
    "lat": "54.4",
    "lng": "10.13333"
  },
  {
    "country": "DE",
    "name": "Altengottern",
    "lat": "51.16395",
    "lng": "10.58093"
  },
  {
    "country": "DE",
    "name": "Altenglan",
    "lat": "49.55",
    "lng": "7.46667"
  },
  {
    "country": "DE",
    "name": "Altenfeld",
    "lat": "50.56667",
    "lng": "10.96667"
  },
  {
    "country": "DE",
    "name": "Altendorf",
    "lat": "50.08424",
    "lng": "11.16786"
  },
  {
    "country": "DE",
    "name": "Altendiez",
    "lat": "50.36667",
    "lng": "7.98333"
  },
  {
    "country": "DE",
    "name": "Alten Buseck",
    "lat": "50.62218",
    "lng": "8.75322"
  },
  {
    "country": "DE",
    "name": "Altenburg",
    "lat": "50.98763",
    "lng": "12.43684"
  },
  {
    "country": "DE",
    "name": "Altenbüren",
    "lat": "51.38634",
    "lng": "8.50584"
  },
  {
    "country": "DE",
    "name": "Altenberge",
    "lat": "52.05",
    "lng": "7.46667"
  },
  {
    "country": "DE",
    "name": "Altenberg",
    "lat": "50.76556",
    "lng": "13.75334"
  },
  {
    "country": "DE",
    "name": "Altenbeken",
    "lat": "51.76455",
    "lng": "8.94201"
  },
  {
    "country": "DE",
    "name": "Altenau",
    "lat": "51.80113",
    "lng": "10.44148"
  },
  {
    "country": "DE",
    "name": "Altenahr",
    "lat": "50.51694",
    "lng": "6.99206"
  },
  {
    "country": "DE",
    "name": "Altena",
    "lat": "51.29472",
    "lng": "7.67337"
  },
  {
    "country": "DE",
    "name": "Alteglofsheim",
    "lat": "48.91667",
    "lng": "12.2"
  },
  {
    "country": "DE",
    "name": "Altefähr",
    "lat": "54.32994",
    "lng": "13.12643"
  },
  {
    "country": "DE",
    "name": "Alt Duvenstedt",
    "lat": "54.36667",
    "lng": "9.65"
  },
  {
    "country": "DE",
    "name": "Altdorf",
    "lat": "49.3856",
    "lng": "11.3573"
  },
  {
    "country": "DE",
    "name": "Altdorf",
    "lat": "48.63112",
    "lng": "8.99626"
  },
  {
    "country": "DE",
    "name": "Altdorf",
    "lat": "48.59421",
    "lng": "9.27165"
  },
  {
    "country": "DE",
    "name": "Altdorf",
    "lat": "48.15374",
    "lng": "12.18419"
  },
  {
    "country": "DE",
    "name": "Altdöbern",
    "lat": "51.65",
    "lng": "14.03333"
  },
  {
    "country": "DE",
    "name": "Altbach",
    "lat": "48.72268",
    "lng": "9.38078"
  },
  {
    "country": "DE",
    "name": "Ammerthal",
    "lat": "49.44123",
    "lng": "11.76181"
  },
  {
    "country": "DE",
    "name": "Alsterdorf",
    "lat": "53.61083",
    "lng": "10.01306"
  },
  {
    "country": "DE",
    "name": "Alsleben",
    "lat": "51.70161",
    "lng": "11.67648"
  },
  {
    "country": "DE",
    "name": "Alsheim",
    "lat": "49.76806",
    "lng": "8.34028"
  },
  {
    "country": "DE",
    "name": "Alsfeld",
    "lat": "50.75185",
    "lng": "9.27082"
  },
  {
    "country": "DE",
    "name": "Alsenz",
    "lat": "49.71667",
    "lng": "7.81667"
  },
  {
    "country": "DE",
    "name": "Alsdorf",
    "lat": "50.87673",
    "lng": "6.16399"
  },
  {
    "country": "DE",
    "name": "Alsdorf",
    "lat": "50.77736",
    "lng": "7.88562"
  },
  {
    "country": "DE",
    "name": "Alpirsbach",
    "lat": "48.34507",
    "lng": "8.40197"
  },
  {
    "country": "DE",
    "name": "Alpenrod",
    "lat": "50.63333",
    "lng": "7.86667"
  },
  {
    "country": "DE",
    "name": "Alpen",
    "lat": "51.58333",
    "lng": "6.51667"
  },
  {
    "country": "DE",
    "name": "Allstedt",
    "lat": "51.40379",
    "lng": "11.38689"
  },
  {
    "country": "DE",
    "name": "Allmersbach im Tal",
    "lat": "48.90659",
    "lng": "9.46815"
  },
  {
    "country": "DE",
    "name": "Allmendingen",
    "lat": "48.33052",
    "lng": "9.72419"
  },
  {
    "country": "DE",
    "name": "Alling",
    "lat": "48.14034",
    "lng": "11.30144"
  },
  {
    "country": "DE",
    "name": "Allershausen",
    "lat": "48.43333",
    "lng": "11.6"
  },
  {
    "country": "DE",
    "name": "Allersberg",
    "lat": "49.25132",
    "lng": "11.23659"
  },
  {
    "country": "DE",
    "name": "Allensbach",
    "lat": "47.71536",
    "lng": "9.07145"
  },
  {
    "country": "DE",
    "name": "Allendorf an der Lahn",
    "lat": "50.55109",
    "lng": "8.62008"
  },
  {
    "country": "DE",
    "name": "Allendorf",
    "lat": "51.02995",
    "lng": "8.67232"
  },
  {
    "country": "DE",
    "name": "Alheim",
    "lat": "51.03333",
    "lng": "9.66667"
  },
  {
    "country": "DE",
    "name": "Algermissen",
    "lat": "52.25332",
    "lng": "9.96915"
  },
  {
    "country": "DE",
    "name": "Alfter",
    "lat": "50.73333",
    "lng": "7.01667"
  },
  {
    "country": "DE",
    "name": "Alfhausen",
    "lat": "52.5",
    "lng": "7.95"
  },
  {
    "country": "DE",
    "name": "Alfeld",
    "lat": "51.98382",
    "lng": "9.81989"
  },
  {
    "country": "DE",
    "name": "Alfeld",
    "lat": "49.43333",
    "lng": "11.55"
  },
  {
    "country": "DE",
    "name": "Alfdorf",
    "lat": "48.84385",
    "lng": "9.71857"
  },
  {
    "country": "DE",
    "name": "Bad Alexandersbad",
    "lat": "50.01667",
    "lng": "12.01667"
  },
  {
    "country": "DE",
    "name": "Aletshausen",
    "lat": "48.19859",
    "lng": "10.38877"
  },
  {
    "country": "DE",
    "name": "Alesheim",
    "lat": "49.04648",
    "lng": "10.86496"
  },
  {
    "country": "DE",
    "name": "Alerheim",
    "lat": "48.85",
    "lng": "10.61667"
  },
  {
    "country": "DE",
    "name": "Aldingen",
    "lat": "48.1",
    "lng": "8.7"
  },
  {
    "country": "DE",
    "name": "Aldersbach",
    "lat": "48.58972",
    "lng": "13.08971"
  },
  {
    "country": "DE",
    "name": "Aldenhoven",
    "lat": "50.9",
    "lng": "6.28333"
  },
  {
    "country": "DE",
    "name": "Albstadt",
    "lat": "48.21644",
    "lng": "9.02596"
  },
  {
    "country": "DE",
    "name": "Albshausen",
    "lat": "50.54431",
    "lng": "8.43784"
  },
  {
    "country": "DE",
    "name": "Albisheim",
    "lat": "49.64941",
    "lng": "8.09442"
  },
  {
    "country": "DE",
    "name": "Albig",
    "lat": "49.77361",
    "lng": "8.12139"
  },
  {
    "country": "DE",
    "name": "Albertstadt",
    "lat": "51.08333",
    "lng": "13.76667"
  },
  {
    "country": "DE",
    "name": "Albertshofen",
    "lat": "49.76667",
    "lng": "10.16667"
  },
  {
    "country": "DE",
    "name": "Albersweiler",
    "lat": "49.21917",
    "lng": "8.03"
  },
  {
    "country": "DE",
    "name": "Albershausen",
    "lat": "48.69136",
    "lng": "9.56493"
  },
  {
    "country": "DE",
    "name": "Albersdorf",
    "lat": "54.15",
    "lng": "9.28333"
  },
  {
    "country": "DE",
    "name": "Albbruck",
    "lat": "47.59077",
    "lng": "8.12954"
  },
  {
    "country": "DE",
    "name": "Albaching",
    "lat": "48.11011",
    "lng": "12.11074"
  },
  {
    "country": "DE",
    "name": "Aken",
    "lat": "51.85274",
    "lng": "12.04461"
  },
  {
    "country": "DE",
    "name": "Aitrang",
    "lat": "47.81667",
    "lng": "10.53333"
  },
  {
    "country": "DE",
    "name": "Aitrach",
    "lat": "47.93333",
    "lng": "10.08333"
  },
  {
    "country": "DE",
    "name": "Alterhofen",
    "lat": "48.84659",
    "lng": "12.62012"
  },
  {
    "country": "DE",
    "name": "Aislingen",
    "lat": "48.50648",
    "lng": "10.45778"
  },
  {
    "country": "DE",
    "name": "Ainring",
    "lat": "47.81311",
    "lng": "12.94048"
  },
  {
    "country": "DE",
    "name": "Aindling",
    "lat": "48.5136",
    "lng": "10.95315"
  },
  {
    "country": "DE",
    "name": "Aiglsbach",
    "lat": "48.69211",
    "lng": "11.70831"
  },
  {
    "country": "DE",
    "name": "Aidlingen",
    "lat": "48.67849",
    "lng": "8.89524"
  },
  {
    "country": "DE",
    "name": "Aidhausen",
    "lat": "50.15",
    "lng": "10.43333"
  },
  {
    "country": "DE",
    "name": "Aidenbach",
    "lat": "48.57028",
    "lng": "13.09"
  },
  {
    "country": "DE",
    "name": "Aichstetten",
    "lat": "47.89295",
    "lng": "10.07837"
  },
  {
    "country": "DE",
    "name": "Aichhalden",
    "lat": "48.26719",
    "lng": "8.40233"
  },
  {
    "country": "DE",
    "name": "Aichen",
    "lat": "48.22898",
    "lng": "10.53949"
  },
  {
    "country": "DE",
    "name": "Aichelberg",
    "lat": "48.63557",
    "lng": "9.56373"
  },
  {
    "country": "DE",
    "name": "Aichach",
    "lat": "48.45755",
    "lng": "11.13413"
  },
  {
    "country": "DE",
    "name": "Ahsen-Oetzen",
    "lat": "52.95868",
    "lng": "9.07933"
  },
  {
    "country": "DE",
    "name": "Ahrensburg",
    "lat": "53.67515",
    "lng": "10.22593"
  },
  {
    "country": "DE",
    "name": "Ahrensbök",
    "lat": "54.00862",
    "lng": "10.57434"
  },
  {
    "country": "DE",
    "name": "Ahorn",
    "lat": "50.23762",
    "lng": "10.95417"
  },
  {
    "country": "DE",
    "name": "Aholming",
    "lat": "48.73542",
    "lng": "12.90997"
  },
  {
    "country": "DE",
    "name": "Aholfing",
    "lat": "48.94283",
    "lng": "12.46857"
  },
  {
    "country": "DE",
    "name": "Ahnsen",
    "lat": "52.25466",
    "lng": "9.10089"
  },
  {
    "country": "DE",
    "name": "Ahnsbeck",
    "lat": "52.61071",
    "lng": "10.28534"
  },
  {
    "country": "DE",
    "name": "Ahlsdorf",
    "lat": "51.54543",
    "lng": "11.46655"
  },
  {
    "country": "DE",
    "name": "Ahlerstedt",
    "lat": "53.4",
    "lng": "9.45"
  },
  {
    "country": "DE",
    "name": "Ahlen",
    "lat": "51.76338",
    "lng": "7.8887"
  },
  {
    "country": "DE",
    "name": "Ahlden",
    "lat": "52.75968",
    "lng": "9.55115"
  },
  {
    "country": "DE",
    "name": "Ahlbeck",
    "lat": "53.66972",
    "lng": "14.18622"
  },
  {
    "country": "DE",
    "name": "Ahausen",
    "lat": "53.06667",
    "lng": "9.31667"
  },
  {
    "country": "DE",
    "name": "Ahaus",
    "lat": "52.07936",
    "lng": "7.01344"
  },
  {
    "country": "DE",
    "name": "Aham",
    "lat": "48.34821",
    "lng": "12.16156"
  },
  {
    "country": "DE",
    "name": "Aglasterhausen",
    "lat": "49.35694",
    "lng": "8.98694"
  },
  {
    "country": "DE",
    "name": "Agathenburg",
    "lat": "53.56065",
    "lng": "9.5318"
  },
  {
    "country": "DE",
    "name": "Affing",
    "lat": "48.46667",
    "lng": "10.98333"
  },
  {
    "country": "DE",
    "name": "Affalterbach",
    "lat": "48.92267",
    "lng": "9.32362"
  },
  {
    "country": "DE",
    "name": "Aerzen",
    "lat": "52.04953",
    "lng": "9.25856"
  },
  {
    "country": "DE",
    "name": "Adorf",
    "lat": "50.32011",
    "lng": "12.25986"
  },
  {
    "country": "DE",
    "name": "Adlkofen",
    "lat": "48.55",
    "lng": "12.26667"
  },
  {
    "country": "DE",
    "name": "Adlershof",
    "lat": "52.43548",
    "lng": "13.54825"
  },
  {
    "country": "DE",
    "name": "Adenstedt",
    "lat": "51.99852",
    "lng": "9.93516"
  },
  {
    "country": "DE",
    "name": "Adendorf",
    "lat": "53.28189",
    "lng": "10.43787"
  },
  {
    "country": "DE",
    "name": "Adenbüttel",
    "lat": "52.37984",
    "lng": "10.45079"
  },
  {
    "country": "DE",
    "name": "Adenau",
    "lat": "50.38238",
    "lng": "6.93291"
  },
  {
    "country": "DE",
    "name": "Adelzhausen",
    "lat": "48.35671",
    "lng": "11.13851"
  },
  {
    "country": "DE",
    "name": "Adelsried",
    "lat": "48.42465",
    "lng": "10.71828"
  },
  {
    "country": "DE",
    "name": "Adelshofen",
    "lat": "48.18333",
    "lng": "11.11667"
  },
  {
    "country": "DE",
    "name": "Adelsheim",
    "lat": "49.4015",
    "lng": "9.3925"
  },
  {
    "country": "DE",
    "name": "Adelsdorf",
    "lat": "49.47022",
    "lng": "10.68522"
  },
  {
    "country": "DE",
    "name": "Adelmannsfelden",
    "lat": "48.95476",
    "lng": "10.00466"
  },
  {
    "country": "DE",
    "name": "Adelheidsdorf",
    "lat": "52.56404",
    "lng": "10.06039"
  },
  {
    "country": "DE",
    "name": "Adelebsen",
    "lat": "51.58272",
    "lng": "9.75461"
  },
  {
    "country": "DE",
    "name": "Adelberg",
    "lat": "48.76227",
    "lng": "9.59991"
  },
  {
    "country": "DE",
    "name": "Achtrup",
    "lat": "54.79053",
    "lng": "9.02848"
  },
  {
    "country": "DE",
    "name": "Achstetten",
    "lat": "48.25886",
    "lng": "9.89748"
  },
  {
    "country": "DE",
    "name": "Achslach",
    "lat": "48.97171",
    "lng": "12.93511"
  },
  {
    "country": "DE",
    "name": "Achim",
    "lat": "53.01416",
    "lng": "9.0263"
  },
  {
    "country": "DE",
    "name": "Achern",
    "lat": "48.63115",
    "lng": "8.07607"
  },
  {
    "country": "DE",
    "name": "Abtsgmünd",
    "lat": "48.89503",
    "lng": "10.00172"
  },
  {
    "country": "DE",
    "name": "Abtsdorf",
    "lat": "51.88984",
    "lng": "12.72526"
  },
  {
    "country": "DE",
    "name": "Abstatt",
    "lat": "49.0682",
    "lng": "9.2907"
  },
  {
    "country": "DE",
    "name": "Absberg",
    "lat": "49.14438",
    "lng": "10.88101"
  },
  {
    "country": "DE",
    "name": "Abensberg",
    "lat": "48.81684",
    "lng": "11.8498"
  },
  {
    "country": "DE",
    "name": "Abenberg",
    "lat": "49.24282",
    "lng": "10.96401"
  },
  {
    "country": "DE",
    "name": "Abbesbüttel",
    "lat": "52.35233",
    "lng": "10.55649"
  },
  {
    "country": "DE",
    "name": "Aalen",
    "lat": "48.83777",
    "lng": "10.0933"
  },
  {
    "country": "DE",
    "name": "Aach",
    "lat": "49.78333",
    "lng": "6.6"
  },
  {
    "country": "DE",
    "name": "Aach",
    "lat": "47.8424",
    "lng": "8.85384"
  },
  {
    "country": "DE",
    "name": "Eggermühlen",
    "lat": "52.56667",
    "lng": "7.81667"
  },
  {
    "country": "DE",
    "name": "Thalfang",
    "lat": "49.75",
    "lng": "7"
  },
  {
    "country": "DE",
    "name": "Erdeborn",
    "lat": "51.47554",
    "lng": "11.63487"
  },
  {
    "country": "DE",
    "name": "Barby",
    "lat": "51.96711",
    "lng": "11.88261"
  },
  {
    "country": "DE",
    "name": "Hohenau",
    "lat": "48.84983",
    "lng": "13.48825"
  },
  {
    "country": "DE",
    "name": "Apfeldorf",
    "lat": "47.9",
    "lng": "10.93333"
  },
  {
    "country": "DE",
    "name": "Höhenkirchen-Siegertsbrunn",
    "lat": "48.01932",
    "lng": "11.71906"
  },
  {
    "country": "DE",
    "name": "Missen-Wilhams",
    "lat": "47.6",
    "lng": "10.11667"
  },
  {
    "country": "DE",
    "name": "Oy-Mittelberg",
    "lat": "47.63333",
    "lng": "10.43333"
  },
  {
    "country": "DE",
    "name": "Straßlach-Dingharting",
    "lat": "48.00491",
    "lng": "11.5141"
  },
  {
    "country": "DE",
    "name": "Sankt Leonhard am Wonneberg",
    "lat": "47.91533",
    "lng": "12.71926"
  },
  {
    "country": "DE",
    "name": "Seeon-Seebruck",
    "lat": "47.96667",
    "lng": "12.46667"
  },
  {
    "country": "DE",
    "name": "Weiler-Simmerberg",
    "lat": "47.58261",
    "lng": "9.91352"
  },
  {
    "country": "DE",
    "name": "Bodman-Ludwigshafen",
    "lat": "47.81817",
    "lng": "9.0554"
  },
  {
    "country": "DE",
    "name": "Eggingen",
    "lat": "47.7",
    "lng": "8.4"
  },
  {
    "country": "DE",
    "name": "Emmingen-Liptingen",
    "lat": "47.93333",
    "lng": "8.88333"
  },
  {
    "country": "DE",
    "name": "Herdwangen-Schönach",
    "lat": "47.85",
    "lng": "9.2"
  },
  {
    "country": "DE",
    "name": "Lauchringen",
    "lat": "47.62699",
    "lng": "8.31442"
  },
  {
    "country": "DE",
    "name": "Mühlhausen-Ehingen",
    "lat": "47.81102",
    "lng": "8.81224"
  },
  {
    "country": "DE",
    "name": "Uhldingen-Mühlhofen",
    "lat": "47.73333",
    "lng": "9.25"
  },
  {
    "country": "DE",
    "name": "Ühlingen-Birkendorf",
    "lat": "47.71667",
    "lng": "8.31667"
  },
  {
    "country": "DE",
    "name": "Altes Lager",
    "lat": "48.41755",
    "lng": "9.53606"
  },
  {
    "country": "DE",
    "name": "Aspach",
    "lat": "48.96667",
    "lng": "9.4"
  },
  {
    "country": "DE",
    "name": "Bad Peterstal-Griesbach",
    "lat": "48.43333",
    "lng": "8.21667"
  },
  {
    "country": "DE",
    "name": "Bad Rippoldsau-Schapbach",
    "lat": "48.42883",
    "lng": "8.32584"
  },
  {
    "country": "DE",
    "name": "Bad Teinach-Zavelstein",
    "lat": "48.69051",
    "lng": "8.69285"
  },
  {
    "country": "DE",
    "name": "Böbingen an der Rems",
    "lat": "48.81955",
    "lng": "9.9213"
  },
  {
    "country": "DE",
    "name": "Burgstetten",
    "lat": "48.92805",
    "lng": "9.37239"
  },
  {
    "country": "DE",
    "name": "Gutenzell-Hürbel",
    "lat": "48.11667",
    "lng": "9.98333"
  },
  {
    "country": "DE",
    "name": "Königsbach-Stein",
    "lat": "48.96585",
    "lng": "8.60573"
  },
  {
    "country": "DE",
    "name": "Niefern-Öschelbronn",
    "lat": "48.91667",
    "lng": "8.78333"
  },
  {
    "country": "DE",
    "name": "Ölbronn-Dürrn",
    "lat": "48.96667",
    "lng": "8.75"
  },
  {
    "country": "DE",
    "name": "Rietheim-Weilheim",
    "lat": "48.01667",
    "lng": "8.76667"
  },
  {
    "country": "DE",
    "name": "Seitingen-Oberflacht",
    "lat": "48.01667",
    "lng": "8.71667"
  },
  {
    "country": "DE",
    "name": "Urbach",
    "lat": "48.8168",
    "lng": "9.5769"
  },
  {
    "country": "DE",
    "name": "Giesen",
    "lat": "52.19716",
    "lng": "9.8989"
  },
  {
    "country": "DE",
    "name": "Mallersdorf-Pfaffenberg",
    "lat": "48.76637",
    "lng": "12.23096"
  },
  {
    "country": "DE",
    "name": "Muhr am See",
    "lat": "49.15445",
    "lng": "10.71845"
  },
  {
    "country": "DE",
    "name": "Postbauer-Heng",
    "lat": "49.30528",
    "lng": "11.35722"
  },
  {
    "country": "DE",
    "name": "Viereth-Trunstadt",
    "lat": "49.92222",
    "lng": "10.77716"
  },
  {
    "country": "DE",
    "name": "Weilersbach",
    "lat": "49.75",
    "lng": "11.11667"
  },
  {
    "country": "DE",
    "name": "Katlenburg-Lindau",
    "lat": "51.68333",
    "lng": "10.1"
  },
  {
    "country": "DE",
    "name": "Kromsdorf",
    "lat": "51",
    "lng": "11.36667"
  },
  {
    "country": "DE",
    "name": "Schönstedt",
    "lat": "51.12",
    "lng": "10.57743"
  },
  {
    "country": "DE",
    "name": "Vellmar",
    "lat": "51.35806",
    "lng": "9.47974"
  },
  {
    "country": "DE",
    "name": "Scheden",
    "lat": "51.45",
    "lng": "9.73333"
  },
  {
    "country": "DE",
    "name": "Möhnesee",
    "lat": "51.5",
    "lng": "8.13333"
  },
  {
    "country": "DE",
    "name": "Schieder-Schwalenberg",
    "lat": "51.87713",
    "lng": "9.19538"
  },
  {
    "country": "DE",
    "name": "Lautertal",
    "lat": "50.33333",
    "lng": "10.96667"
  },
  {
    "country": "DE",
    "name": "Rödental",
    "lat": "50.29516",
    "lng": "11.04122"
  },
  {
    "country": "DE",
    "name": "Röslau",
    "lat": "50.08333",
    "lng": "11.98333"
  },
  {
    "country": "DE",
    "name": "Bruchmühlbach-Miesau",
    "lat": "49.38333",
    "lng": "7.43333"
  },
  {
    "country": "DE",
    "name": "Gossersweiler-Stein",
    "lat": "49.15",
    "lng": "7.93333"
  },
  {
    "country": "DE",
    "name": "Hochstetten-Dhaun",
    "lat": "49.8",
    "lng": "7.5"
  },
  {
    "country": "DE",
    "name": "Hoppstädten-Weiersbach",
    "lat": "49.61667",
    "lng": "7.2"
  },
  {
    "country": "DE",
    "name": "Neumagen-Dhron",
    "lat": "49.85553",
    "lng": "6.89777"
  },
  {
    "country": "DE",
    "name": "Offenbach-Hundheim",
    "lat": "49.61729",
    "lng": "7.55117"
  },
  {
    "country": "DE",
    "name": "Osann-Monzel",
    "lat": "49.91667",
    "lng": "6.95"
  },
  {
    "country": "DE",
    "name": "Rieschweiler-Mühlbach",
    "lat": "49.23333",
    "lng": "7.5"
  },
  {
    "country": "DE",
    "name": "Salmtal",
    "lat": "49.93333",
    "lng": "6.85"
  },
  {
    "country": "DE",
    "name": "Schönenberg-Kübelberg",
    "lat": "49.4074",
    "lng": "7.37233"
  },
  {
    "country": "DE",
    "name": "Schweigen-Rechtenbach",
    "lat": "49.05314",
    "lng": "7.95638"
  },
  {
    "country": "DE",
    "name": "Zeltingen-Rachtig",
    "lat": "49.95",
    "lng": "7.01667"
  },
  {
    "country": "DE",
    "name": "Ahrbrück",
    "lat": "50.48225",
    "lng": "6.98804"
  },
  {
    "country": "DE",
    "name": "Birken-Honigsessen",
    "lat": "50.81667",
    "lng": "7.73333"
  },
  {
    "country": "DE",
    "name": "Bruttig-Fankel",
    "lat": "50.13333",
    "lng": "7.23333"
  },
  {
    "country": "DE",
    "name": "Dreikirchen",
    "lat": "50.43333",
    "lng": "7.95"
  },
  {
    "country": "DE",
    "name": "Ediger-Eller",
    "lat": "50.11667",
    "lng": "7.15"
  },
  {
    "country": "DE",
    "name": "Gondershausen",
    "lat": "50.15",
    "lng": "7.5"
  },
  {
    "country": "DE",
    "name": "Hattert",
    "lat": "50.66667",
    "lng": "7.76667"
  },
  {
    "country": "DE",
    "name": "Höhn",
    "lat": "50.61667",
    "lng": "7.98333"
  },
  {
    "country": "DE",
    "name": "Kasbach-Ohlenberg",
    "lat": "50.58333",
    "lng": "7.26667"
  },
  {
    "country": "DE",
    "name": "Katzwinkel",
    "lat": "50.8147",
    "lng": "7.82236"
  },
  {
    "country": "DE",
    "name": "Kirchwald",
    "lat": "50.36667",
    "lng": "7.15"
  },
  {
    "country": "DE",
    "name": "Kobern-Gondorf",
    "lat": "50.3023",
    "lng": "7.45612"
  },
  {
    "country": "DE",
    "name": "Mülheim-Kärlich",
    "lat": "50.3851",
    "lng": "7.4989"
  },
  {
    "country": "DE",
    "name": "Ruppach-Goldhausen",
    "lat": "50.46667",
    "lng": "7.88333"
  },
  {
    "country": "DE",
    "name": "Sankt Katharinen",
    "lat": "50.58333",
    "lng": "7.38333"
  },
  {
    "country": "DE",
    "name": "Spay",
    "lat": "50.25881",
    "lng": "7.64839"
  },
  {
    "country": "DE",
    "name": "Blankenbach",
    "lat": "50.06667",
    "lng": "9.23333"
  },
  {
    "country": "DE",
    "name": "Riedenberg",
    "lat": "50.31993",
    "lng": "9.861"
  },
  {
    "country": "DE",
    "name": "Sailauf",
    "lat": "50.02461",
    "lng": "9.25932"
  },
  {
    "country": "DE",
    "name": "Florstadt",
    "lat": "50.31667",
    "lng": "8.86667"
  },
  {
    "country": "DE",
    "name": "Liederbach",
    "lat": "50.12221",
    "lng": "8.49397"
  },
  {
    "country": "DE",
    "name": "Schöffengrund",
    "lat": "50.49345",
    "lng": "8.47183"
  },
  {
    "country": "DE",
    "name": "Waldbrunn",
    "lat": "50.51875",
    "lng": "8.10812"
  },
  {
    "country": "DE",
    "name": "Waldems",
    "lat": "50.25",
    "lng": "8.33333"
  },
  {
    "country": "DE",
    "name": "Walluf",
    "lat": "50.04003",
    "lng": "8.15545"
  },
  {
    "country": "DE",
    "name": "Klein Offenseth-Sparrieshoop",
    "lat": "53.79748",
    "lng": "9.68653"
  },
  {
    "country": "DE",
    "name": "Asbach-Bäumenheim",
    "lat": "48.68333",
    "lng": "10.81667"
  },
  {
    "country": "DE",
    "name": "Baar-Ebenhausen",
    "lat": "48.67065",
    "lng": "11.46983"
  },
  {
    "country": "DE",
    "name": "Ettringen",
    "lat": "48.1",
    "lng": "10.65"
  },
  {
    "country": "DE",
    "name": "Finningen",
    "lat": "48.65452",
    "lng": "10.49864"
  },
  {
    "country": "DE",
    "name": "Kottgeisering",
    "lat": "48.11667",
    "lng": "11.13333"
  },
  {
    "country": "DE",
    "name": "Medlingen",
    "lat": "48.57027",
    "lng": "10.31608"
  },
  {
    "country": "DE",
    "name": "Schondorf am Ammersee",
    "lat": "48.05296",
    "lng": "11.09138"
  },
  {
    "country": "DE",
    "name": "Wörth",
    "lat": "48.24531",
    "lng": "11.90214"
  },
  {
    "country": "DE",
    "name": "Dohren",
    "lat": "52.65",
    "lng": "7.58333"
  },
  {
    "country": "DE",
    "name": "Lünne",
    "lat": "52.42958",
    "lng": "7.42653"
  },
  {
    "country": "DE",
    "name": "Neukamperfehn",
    "lat": "53.33642",
    "lng": "7.56189"
  },
  {
    "country": "DE",
    "name": "Aukrug",
    "lat": "54.08333",
    "lng": "9.78333"
  },
  {
    "country": "DE",
    "name": "Bordelum",
    "lat": "54.63333",
    "lng": "8.93333"
  },
  {
    "country": "DE",
    "name": "Emmelsbüll-Horsbüll",
    "lat": "54.81667",
    "lng": "8.7"
  },
  {
    "country": "DE",
    "name": "Helgoland",
    "lat": "54.18143",
    "lng": "7.8863"
  },
  {
    "country": "DE",
    "name": "Jarplund-Weding",
    "lat": "54.73714",
    "lng": "9.41813"
  },
  {
    "country": "DE",
    "name": "Lohe-Rickelshof",
    "lat": "54.18803",
    "lng": "9.07066"
  },
  {
    "country": "DE",
    "name": "Mohrkirch",
    "lat": "54.66667",
    "lng": "9.71667"
  },
  {
    "country": "DE",
    "name": "Risum-Lindholm",
    "lat": "54.75802",
    "lng": "8.86906"
  },
  {
    "country": "DE",
    "name": "Sylt-Ost",
    "lat": "54.8611",
    "lng": "8.41141"
  },
  {
    "country": "DE",
    "name": "Büddenstedt",
    "lat": "52.17035",
    "lng": "11.01877"
  },
  {
    "country": "DE",
    "name": "Elbe",
    "lat": "52.08333",
    "lng": "10.28333"
  },
  {
    "country": "DE",
    "name": "Flöthe",
    "lat": "52.08333",
    "lng": "10.48333"
  },
  {
    "country": "DE",
    "name": "Heere",
    "lat": "52.06667",
    "lng": "10.25"
  },
  {
    "country": "DE",
    "name": "Ilsede",
    "lat": "52.2634",
    "lng": "10.19922"
  },
  {
    "country": "DE",
    "name": "Sassenburg",
    "lat": "52.51667",
    "lng": "10.63333"
  },
  {
    "country": "DE",
    "name": "Sickte",
    "lat": "52.21847",
    "lng": "10.6424"
  },
  {
    "country": "DE",
    "name": "Bensdorf",
    "lat": "52.41667",
    "lng": "12.33333"
  },
  {
    "country": "DE",
    "name": "Ebersbach",
    "lat": "51.23333",
    "lng": "13.65"
  },
  {
    "country": "DE",
    "name": "Mühlanger",
    "lat": "51.85",
    "lng": "12.75"
  },
  {
    "country": "DE",
    "name": "Nessa",
    "lat": "51.14565",
    "lng": "12.00874"
  },
  {
    "country": "DE",
    "name": "Marschacht",
    "lat": "53.4152",
    "lng": "10.37524"
  },
  {
    "country": "DE",
    "name": "Henstedt-Ulzburg",
    "lat": "53.805",
    "lng": "9.97452"
  },
  {
    "country": "DE",
    "name": "Admannshagen-Bargeshagen",
    "lat": "54.13038",
    "lng": "11.99915"
  },
  {
    "country": "DE",
    "name": "Bartenshagen-Parkentin",
    "lat": "54.08116",
    "lng": "11.97849"
  },
  {
    "country": "DE",
    "name": "Börgerende-Rethwisch",
    "lat": "54.14177",
    "lng": "11.92528"
  },
  {
    "country": "DE",
    "name": "Gattendorf",
    "lat": "50.32207",
    "lng": "11.99776"
  },
  {
    "country": "DE",
    "name": "Rossau",
    "lat": "51",
    "lng": "13.06667"
  },
  {
    "country": "DE",
    "name": "Kappel-Grafenhausen",
    "lat": "48.28382",
    "lng": "7.76605"
  },
  {
    "country": "DE",
    "name": "Rheinau",
    "lat": "48.66602",
    "lng": "7.93659"
  },
  {
    "country": "DE",
    "name": "Hiddensee",
    "lat": "54.56689",
    "lng": "13.10411"
  },
  {
    "country": "DE",
    "name": "Ebersbach-Musbach",
    "lat": "47.96667",
    "lng": "9.58333"
  },
  {
    "country": "DE",
    "name": "Reichenau",
    "lat": "47.68885",
    "lng": "9.06355"
  },
  {
    "country": "DE",
    "name": "Vogtsburg",
    "lat": "48.09688",
    "lng": "7.64185"
  },
  {
    "country": "DE",
    "name": "Brohl-Lützing",
    "lat": "50.48296",
    "lng": "7.32908"
  },
  {
    "country": "DE",
    "name": "Burg Hohenstein",
    "lat": "50.19192",
    "lng": "8.05732"
  },
  {
    "country": "DE",
    "name": "Marktrodach",
    "lat": "50.25",
    "lng": "11.38333"
  },
  {
    "country": "DE",
    "name": "Triebel",
    "lat": "50.37153",
    "lng": "12.12118"
  },
  {
    "country": "DE",
    "name": "Ransbach-Baumbach",
    "lat": "50.46496",
    "lng": "7.7283"
  },
  {
    "country": "DE",
    "name": "Ludweiler-Warndt",
    "lat": "49.22074",
    "lng": "6.81195"
  },
  {
    "country": "DE",
    "name": "Aachen",
    "lat": "50.77664",
    "lng": "6.08342"
  },
  {
    "country": "DE",
    "name": "Ubstadt-Weiher",
    "lat": "49.16296",
    "lng": "8.63165"
  },
  {
    "country": "DE",
    "name": "Stadecken-Elsheim",
    "lat": "49.91222",
    "lng": "8.12528"
  },
  {
    "country": "DE",
    "name": "Dannstadt-Schauernheim",
    "lat": "49.44028",
    "lng": "8.30861"
  },
  {
    "country": "DE",
    "name": "Sankt Leon-Rot",
    "lat": "49.26593",
    "lng": "8.61803"
  },
  {
    "country": "DE",
    "name": "Rödersheim-Gronau",
    "lat": "49.43",
    "lng": "8.26139"
  },
  {
    "country": "DE",
    "name": "Karlsdorf-Neuthard",
    "lat": "49.13472",
    "lng": "8.53028"
  },
  {
    "country": "DE",
    "name": "Graben-Neudorf",
    "lat": "49.16695",
    "lng": "8.49243"
  },
  {
    "country": "DE",
    "name": "Mörfelden-Walldorf",
    "lat": "49.99472",
    "lng": "8.58361"
  },
  {
    "country": "DE",
    "name": "Linkenheim-Hochstetten",
    "lat": "49.13197",
    "lng": "8.41244"
  },
  {
    "country": "DE",
    "name": "Billigheim-Ingenheim",
    "lat": "49.13667",
    "lng": "8.09056"
  },
  {
    "country": "DE",
    "name": "Böhl-Iggelheim",
    "lat": "49.38056",
    "lng": "8.30389"
  },
  {
    "country": "DE",
    "name": "Hochdorf-Assenheim",
    "lat": "49.41944",
    "lng": "8.28167"
  },
  {
    "country": "DE",
    "name": "Alsbach-Hähnlein",
    "lat": "49.73861",
    "lng": "8.59583"
  },
  {
    "country": "DE",
    "name": "Dittelsheim-Heßloch",
    "lat": "49.74389",
    "lng": "8.23694"
  },
  {
    "country": "DE",
    "name": "Riedstadt",
    "lat": "49.83411",
    "lng": "8.49621"
  },
  {
    "country": "DE",
    "name": "Hochstadt",
    "lat": "49.2475",
    "lng": "8.20889"
  },
  {
    "country": "DE",
    "name": "Leingarten",
    "lat": "49.14639",
    "lng": "9.11694"
  },
  {
    "country": "DE",
    "name": "Lauda-Königshofen",
    "lat": "49.56526",
    "lng": "9.70816"
  },
  {
    "country": "DE",
    "name": "Altenbuch",
    "lat": "49.82861",
    "lng": "9.40139"
  },
  {
    "country": "DE",
    "name": "Mespelbrunn",
    "lat": "49.91444",
    "lng": "9.29194"
  },
  {
    "country": "DE",
    "name": "Filderstadt",
    "lat": "48.65698",
    "lng": "9.22049"
  },
  {
    "country": "DE",
    "name": "Ostfildern",
    "lat": "48.72704",
    "lng": "9.24954"
  },
  {
    "country": "DE",
    "name": "Rodgau",
    "lat": "50.02627",
    "lng": "8.88588"
  },
  {
    "country": "DE",
    "name": "Butjadingen",
    "lat": "53.54722",
    "lng": "8.335"
  },
  {
    "country": "DE",
    "name": "Kaufungen",
    "lat": "51.28111",
    "lng": "9.61861"
  },
  {
    "country": "DE",
    "name": "Jettingen-Scheppach",
    "lat": "48.3896",
    "lng": "10.4381"
  },
  {
    "country": "DE",
    "name": "Gropiusstadt",
    "lat": "52.425",
    "lng": "13.46667"
  },
  {
    "country": "DE",
    "name": "Seeheim-Jugenheim",
    "lat": "49.765",
    "lng": "8.65194"
  },
  {
    "country": "DE",
    "name": "Charlottenburg-Nord",
    "lat": "52.53048",
    "lng": "13.29371"
  },
  {
    "country": "DE",
    "name": "Mitte",
    "lat": "52.52003",
    "lng": "13.40489"
  },
  {
    "country": "DE",
    "name": "Plänterwald",
    "lat": "52.48106",
    "lng": "13.47276"
  },
  {
    "country": "DE",
    "name": "Dallgow-Döberitz",
    "lat": "52.54269",
    "lng": "13.05837"
  },
  {
    "country": "DE",
    "name": "Bertsdorf-Hörnitz",
    "lat": "50.88593",
    "lng": "14.73696"
  },
  {
    "country": "DE",
    "name": "Rheinstetten",
    "lat": "48.9685",
    "lng": "8.30704"
  },
  {
    "country": "DE",
    "name": "Münstertal/Schwarzwald",
    "lat": "47.85472",
    "lng": "7.78417"
  },
  {
    "country": "DE",
    "name": "Salem",
    "lat": "47.76258",
    "lng": "9.29031"
  },
  {
    "country": "DE",
    "name": "Altstadt Sud",
    "lat": "50.93331",
    "lng": "6.95954"
  },
  {
    "country": "DE",
    "name": "Altstadt Nord",
    "lat": "50.93893",
    "lng": "6.95752"
  },
  {
    "country": "DE",
    "name": "Neuehrenfeld",
    "lat": "50.95753",
    "lng": "6.93611"
  },
  {
    "country": "DE",
    "name": "Bilderstoeckchen",
    "lat": "50.96983",
    "lng": "6.92997"
  },
  {
    "country": "DE",
    "name": "Kloster Lehnin",
    "lat": "52.32039",
    "lng": "12.7432"
  },
  {
    "country": "DE",
    "name": "Neunkirchen am Brand",
    "lat": "49.61204",
    "lng": "11.12967"
  },
  {
    "country": "DE",
    "name": "Rothenburgsort",
    "lat": "53.535",
    "lng": "10.04082"
  },
  {
    "country": "DE",
    "name": "Stuttgart-Ost",
    "lat": "48.78363",
    "lng": "9.21032"
  },
  {
    "country": "DE",
    "name": "Bochum-Hordel",
    "lat": "51.50168",
    "lng": "7.1756"
  },
  {
    "country": "DE",
    "name": "St. Pauli",
    "lat": "53.557",
    "lng": "9.964"
  },
  {
    "country": "DE",
    "name": "Schwanau",
    "lat": "48.36669",
    "lng": "7.76244"
  },
  {
    "country": "DE",
    "name": "Eidelstedt",
    "lat": "53.60697",
    "lng": "9.90538"
  },
  {
    "country": "DE",
    "name": "Schelfstadt",
    "lat": "53.63382",
    "lng": "11.41711"
  },
  {
    "country": "DE",
    "name": "Werdervorstadt",
    "lat": "53.63909",
    "lng": "11.42767"
  },
  {
    "country": "DE",
    "name": "Altstadt",
    "lat": "53.62805",
    "lng": "11.41582"
  },
  {
    "country": "DE",
    "name": "Feldstadt",
    "lat": "53.62331",
    "lng": "11.40673"
  },
  {
    "country": "DE",
    "name": "Paulsstadt",
    "lat": "53.63283",
    "lng": "11.40372"
  },
  {
    "country": "DE",
    "name": "Weststadt",
    "lat": "53.63472",
    "lng": "11.39565"
  },
  {
    "country": "DE",
    "name": "Lewenberg",
    "lat": "53.64591",
    "lng": "11.40767"
  },
  {
    "country": "DE",
    "name": "Eisleben Lutherstadt",
    "lat": "51.52754",
    "lng": "11.54835"
  },
  {
    "country": "DE",
    "name": "Halle Neustadt",
    "lat": "51.47924",
    "lng": "11.91605"
  },
  {
    "country": "DE",
    "name": "Bergedorf",
    "lat": "53.48462",
    "lng": "10.22904"
  },
  {
    "country": "DE",
    "name": "Spandau",
    "lat": "52.5511",
    "lng": "13.19921"
  },
  {
    "country": "DE",
    "name": "Berlin Schöneberg",
    "lat": "52.48388",
    "lng": "13.3477"
  },
  {
    "country": "DE",
    "name": "Berlin Treptow",
    "lat": "52.49376",
    "lng": "13.44469"
  },
  {
    "country": "DE",
    "name": "Niederrad",
    "lat": "50.08309",
    "lng": "8.62852"
  },
  {
    "country": "DE",
    "name": "Haselbachtal",
    "lat": "51.2357",
    "lng": "14.02576"
  },
  {
    "country": "DE",
    "name": "Wittenberg",
    "lat": "51.8661",
    "lng": "12.64973"
  },
  {
    "country": "DE",
    "name": "Rabenau",
    "lat": "50.67753",
    "lng": "8.86425"
  },
  {
    "country": "DE",
    "name": "Garbsen-Mitte",
    "lat": "52.42659",
    "lng": "9.60383"
  },
  {
    "country": "DE",
    "name": "Barmbek-Nord",
    "lat": "53.6052",
    "lng": "10.03988"
  },
  {
    "country": "DE",
    "name": "Hammerbrook",
    "lat": "53.54527",
    "lng": "10.03042"
  },
  {
    "country": "DE",
    "name": "Farmsen-Berne",
    "lat": "53.60639",
    "lng": "10.11972"
  },
  {
    "country": "DE",
    "name": "Kleiner Grasbrook",
    "lat": "53.53111",
    "lng": "9.99361"
  },
  {
    "country": "DE",
    "name": "Fehmarn",
    "lat": "54.4378",
    "lng": "11.19352"
  },
  {
    "country": "DE",
    "name": "Stadtrandsiedlung Malchow",
    "lat": "52.58295",
    "lng": "13.47811"
  },
  {
    "country": "DE",
    "name": "Hansaviertel",
    "lat": "52.51853",
    "lng": "13.34178"
  },
  {
    "country": "DE",
    "name": "Falkenhagener Feld",
    "lat": "52.55191",
    "lng": "13.16802"
  },
  {
    "country": "DE",
    "name": "Neu-Hohenschönhausen",
    "lat": "52.56681",
    "lng": "13.51255"
  },
  {
    "country": "DE",
    "name": "Waidmannslust",
    "lat": "52.60691",
    "lng": "13.31968"
  },
  {
    "country": "DE",
    "name": "Alt-Hohenschönhausen",
    "lat": "52.54608",
    "lng": "13.5013"
  },
  {
    "country": "DE",
    "name": "Fennpfuhl",
    "lat": "52.52921",
    "lng": "13.47267"
  },
  {
    "country": "DE",
    "name": "Neustadt an der Orla",
    "lat": "50.7364",
    "lng": "11.74619"
  },
  {
    "country": "DE",
    "name": "Hamburg-Nord",
    "lat": "53.58935",
    "lng": "9.984"
  },
  {
    "country": "DE",
    "name": "Burg Unter-Falkenstein",
    "lat": "47.7044",
    "lng": "12.10466"
  },
  {
    "country": "DE",
    "name": "Neu-Pattern",
    "lat": "50.88854",
    "lng": "6.27688"
  },
  {
    "country": "DE",
    "name": "Neustadt/Nord",
    "lat": "50.949",
    "lng": "6.9479"
  },
  {
    "country": "DE",
    "name": "Neustadt/Süd",
    "lat": "50.92509",
    "lng": "6.94762"
  },
  {
    "country": "DE",
    "name": "Buchforst",
    "lat": "50.95093",
    "lng": "7.00579"
  },
  {
    "country": "DE",
    "name": "Kalk",
    "lat": "50.94013",
    "lng": "7.00605"
  },
  {
    "country": "DE",
    "name": "Mülheim",
    "lat": "50.96639",
    "lng": "7.00384"
  },
  {
    "country": "DE",
    "name": "Gartenstadt",
    "lat": "49.45937",
    "lng": "8.40377"
  },
  {
    "country": "DE",
    "name": "Lachen-Speyerdorf",
    "lat": "49.33049",
    "lng": "8.19983"
  },
  {
    "country": "DE",
    "name": "Osternienburger Land",
    "lat": "51.8",
    "lng": "12.01667"
  },
  {
    "country": "DE",
    "name": "Auf der Horst",
    "lat": "52.41943",
    "lng": "9.60248"
  },
  {
    "country": "DE",
    "name": "Dierkow-Neu",
    "lat": "54.10571",
    "lng": "12.16753"
  },
  {
    "country": "DE",
    "name": "Dierkow-West",
    "lat": "54.10608",
    "lng": "12.15041"
  },
  {
    "country": "DE",
    "name": "Solms",
    "lat": "50.5362",
    "lng": "8.40704"
  },
  {
    "country": "DE",
    "name": "Röchling-Höhe",
    "lat": "49.27102",
    "lng": "6.83457"
  },
  {
    "country": "DE",
    "name": "Luisenthal",
    "lat": "49.24932",
    "lng": "6.90057"
  },
  {
    "country": "DE",
    "name": "Westhagen",
    "lat": "52.40425",
    "lng": "10.73939"
  },
  {
    "country": "DE",
    "name": "Düsseldorf-Pempelfort",
    "lat": "51.23812",
    "lng": "6.78678"
  },
  {
    "country": "DE",
    "name": "Burglesum",
    "lat": "53.16532",
    "lng": "8.68873"
  },
  {
    "country": "DE",
    "name": "Helmstadt-Bargen",
    "lat": "49.31427",
    "lng": "8.99712"
  },
  {
    "country": "DE",
    "name": "Fronreute",
    "lat": "47.87053",
    "lng": "9.56944"
  },
  {
    "country": "DE",
    "name": "Grafenau",
    "lat": "48.71427",
    "lng": "8.91219"
  },
  {
    "country": "DE",
    "name": "Hirschberg an der Bergstraße",
    "lat": "49.5071",
    "lng": "8.65693"
  },
  {
    "country": "DE",
    "name": "Kraichtal",
    "lat": "49.14623",
    "lng": "8.73276"
  },
  {
    "country": "DE",
    "name": "Langenbrettach",
    "lat": "49.22601",
    "lng": "9.41842"
  },
  {
    "country": "DE",
    "name": "Lenningen",
    "lat": "48.55048",
    "lng": "9.47674"
  },
  {
    "country": "DE",
    "name": "Lobbach",
    "lat": "49.37519",
    "lng": "8.88884"
  },
  {
    "country": "DE",
    "name": "Sachsenheim",
    "lat": "48.96",
    "lng": "9.06472"
  },
  {
    "country": "DJ",
    "name": "Tadjourah",
    "lat": "11.78778",
    "lng": "42.88222"
  },
  {
    "country": "DJ",
    "name": "Obock",
    "lat": "11.96693",
    "lng": "43.28835"
  },
  {
    "country": "DJ",
    "name": "Loyada",
    "lat": "11.46111",
    "lng": "43.25278"
  },
  {
    "country": "DJ",
    "name": "Holhol",
    "lat": "11.31028",
    "lng": "42.92944"
  },
  {
    "country": "DJ",
    "name": "Dorra",
    "lat": "12.15028",
    "lng": "42.47624"
  },
  {
    "country": "DJ",
    "name": "Djibouti",
    "lat": "11.58901",
    "lng": "43.14503"
  },
  {
    "country": "DJ",
    "name": "Dikhil",
    "lat": "11.10454",
    "lng": "42.36971"
  },
  {
    "country": "DJ",
    "name": "Ḏânan",
    "lat": "11.18333",
    "lng": "42.93333"
  },
  {
    "country": "DJ",
    "name": "Arta",
    "lat": "11.52639",
    "lng": "42.85194"
  },
  {
    "country": "DJ",
    "name": "'Ali Sabieh",
    "lat": "11.15583",
    "lng": "42.7125"
  },
  {
    "country": "DJ",
    "name": "Alaïli Ḏaḏḏa‘",
    "lat": "12.42167",
    "lng": "42.89556"
  },
  {
    "country": "DJ",
    "name": "Goubétto",
    "lat": "11.42389",
    "lng": "43.00028"
  },
  {
    "country": "DJ",
    "name": "Gâlâfi",
    "lat": "11.71583",
    "lng": "41.83611"
  },
  {
    "country": "DK",
    "name": "Vrå",
    "lat": "57.3537",
    "lng": "9.94176"
  },
  {
    "country": "DK",
    "name": "Vordingborg",
    "lat": "55.00801",
    "lng": "11.91057"
  },
  {
    "country": "DK",
    "name": "Vojens",
    "lat": "55.24639",
    "lng": "9.30603"
  },
  {
    "country": "DK",
    "name": "Vodskov",
    "lat": "57.10854",
    "lng": "10.02215"
  },
  {
    "country": "DK",
    "name": "Vissenbjerg",
    "lat": "55.38482",
    "lng": "10.13784"
  },
  {
    "country": "DK",
    "name": "Virklund",
    "lat": "56.13218",
    "lng": "9.55582"
  },
  {
    "country": "DK",
    "name": "Vipperød",
    "lat": "55.66768",
    "lng": "11.73967"
  },
  {
    "country": "DK",
    "name": "Vindinge",
    "lat": "55.62298",
    "lng": "12.1387"
  },
  {
    "country": "DK",
    "name": "Vinderup",
    "lat": "56.48176",
    "lng": "8.77991"
  },
  {
    "country": "DK",
    "name": "Vindeby",
    "lat": "55.04489",
    "lng": "10.61309"
  },
  {
    "country": "DK",
    "name": "Vildbjerg",
    "lat": "56.2",
    "lng": "8.76667"
  },
  {
    "country": "DK",
    "name": "Videbæk",
    "lat": "56.0876",
    "lng": "8.62852"
  },
  {
    "country": "DK",
    "name": "Viby",
    "lat": "55.54872",
    "lng": "12.02391"
  },
  {
    "country": "DK",
    "name": "Viborg",
    "lat": "56.45319",
    "lng": "9.40201"
  },
  {
    "country": "DK",
    "name": "Vester Hassing",
    "lat": "57.06767",
    "lng": "10.12558"
  },
  {
    "country": "DK",
    "name": "Vestbjerg",
    "lat": "57.13166",
    "lng": "9.95942"
  },
  {
    "country": "DK",
    "name": "Veksø",
    "lat": "55.75473",
    "lng": "12.23837"
  },
  {
    "country": "DK",
    "name": "Vejle",
    "lat": "55.70927",
    "lng": "9.5357"
  },
  {
    "country": "DK",
    "name": "Vejen",
    "lat": "55.48117",
    "lng": "9.13795"
  },
  {
    "country": "DK",
    "name": "Varde",
    "lat": "55.62112",
    "lng": "8.48069"
  },
  {
    "country": "DK",
    "name": "Vanløse",
    "lat": "55.68361",
    "lng": "12.48713"
  },
  {
    "country": "DK",
    "name": "Vamdrup",
    "lat": "55.42764",
    "lng": "9.28435"
  },
  {
    "country": "DK",
    "name": "Vallensbæk",
    "lat": "55.62199",
    "lng": "12.38511"
  },
  {
    "country": "DK",
    "name": "Vadum",
    "lat": "57.1179",
    "lng": "9.857"
  },
  {
    "country": "DK",
    "name": "Ulstrup",
    "lat": "56.38994",
    "lng": "9.79354"
  },
  {
    "country": "DK",
    "name": "Ullerslev",
    "lat": "55.36172",
    "lng": "10.6519"
  },
  {
    "country": "DK",
    "name": "Ulfborg",
    "lat": "56.26725",
    "lng": "8.32167"
  },
  {
    "country": "DK",
    "name": "Tune",
    "lat": "55.59287",
    "lng": "12.16968"
  },
  {
    "country": "DK",
    "name": "Trørød",
    "lat": "55.83946",
    "lng": "12.54432"
  },
  {
    "country": "DK",
    "name": "Trige",
    "lat": "56.25291",
    "lng": "10.1484"
  },
  {
    "country": "DK",
    "name": "Tranebjerg",
    "lat": "55.8326",
    "lng": "10.59723"
  },
  {
    "country": "DK",
    "name": "Tranbjerg",
    "lat": "56.09519",
    "lng": "10.13605"
  },
  {
    "country": "DK",
    "name": "Tørring",
    "lat": "55.85",
    "lng": "9.48333"
  },
  {
    "country": "DK",
    "name": "Tønder",
    "lat": "54.93306",
    "lng": "8.86674"
  },
  {
    "country": "DK",
    "name": "Tølløse",
    "lat": "55.6125",
    "lng": "11.77034"
  },
  {
    "country": "DK",
    "name": "Tommerup Stationsby",
    "lat": "55.34535",
    "lng": "10.17594"
  },
  {
    "country": "DK",
    "name": "Tommerup",
    "lat": "55.31952",
    "lng": "10.20659"
  },
  {
    "country": "DK",
    "name": "Toftlund",
    "lat": "55.18858",
    "lng": "9.06925"
  },
  {
    "country": "DK",
    "name": "Tjæreborg",
    "lat": "55.46457",
    "lng": "8.57968"
  },
  {
    "country": "DK",
    "name": "Tinglev",
    "lat": "54.93788",
    "lng": "9.25547"
  },
  {
    "country": "DK",
    "name": "Thyborøn",
    "lat": "56.69846",
    "lng": "8.21238"
  },
  {
    "country": "DK",
    "name": "Thurø By",
    "lat": "55.0474",
    "lng": "10.66385"
  },
  {
    "country": "DK",
    "name": "Thisted",
    "lat": "56.95523",
    "lng": "8.69491"
  },
  {
    "country": "DK",
    "name": "Taulov",
    "lat": "55.54582",
    "lng": "9.61553"
  },
  {
    "country": "DK",
    "name": "Taastrup",
    "lat": "55.65006",
    "lng": "12.3016"
  },
  {
    "country": "DK",
    "name": "Tårs",
    "lat": "57.38333",
    "lng": "10.11667"
  },
  {
    "country": "DK",
    "name": "Tårnby",
    "lat": "55.6303",
    "lng": "12.60035"
  },
  {
    "country": "DK",
    "name": "Tarm",
    "lat": "55.90861",
    "lng": "8.53041"
  },
  {
    "country": "DK",
    "name": "Svogerslev",
    "lat": "55.63423",
    "lng": "12.01465"
  },
  {
    "country": "DK",
    "name": "Svinninge",
    "lat": "55.72111",
    "lng": "11.46547"
  },
  {
    "country": "DK",
    "name": "Svenstrup",
    "lat": "56.9723",
    "lng": "9.84806"
  },
  {
    "country": "DK",
    "name": "Svendborg",
    "lat": "55.05982",
    "lng": "10.60677"
  },
  {
    "country": "DK",
    "name": "Svejbæk",
    "lat": "56.13255",
    "lng": "9.63289"
  },
  {
    "country": "DK",
    "name": "Svebølle",
    "lat": "55.65183",
    "lng": "11.28658"
  },
  {
    "country": "DK",
    "name": "Sunds",
    "lat": "56.20743",
    "lng": "9.01386"
  },
  {
    "country": "DK",
    "name": "Stubbekøbing",
    "lat": "54.88875",
    "lng": "12.04102"
  },
  {
    "country": "DK",
    "name": "Struer",
    "lat": "56.49205",
    "lng": "8.59397"
  },
  {
    "country": "DK",
    "name": "Strøby Egede",
    "lat": "55.41382",
    "lng": "12.24502"
  },
  {
    "country": "DK",
    "name": "Strib",
    "lat": "55.54021",
    "lng": "9.76748"
  },
  {
    "country": "DK",
    "name": "Strandby",
    "lat": "57.4915",
    "lng": "10.49609"
  },
  {
    "country": "DK",
    "name": "Storvorde",
    "lat": "57.00392",
    "lng": "10.10125"
  },
  {
    "country": "DK",
    "name": "Store Heddinge",
    "lat": "55.30965",
    "lng": "12.38885"
  },
  {
    "country": "DK",
    "name": "Støvring",
    "lat": "56.88536",
    "lng": "9.83839"
  },
  {
    "country": "DK",
    "name": "Stoholm",
    "lat": "56.48454",
    "lng": "9.14617"
  },
  {
    "country": "DK",
    "name": "Stilling",
    "lat": "56.06224",
    "lng": "9.98822"
  },
  {
    "country": "DK",
    "name": "Stige",
    "lat": "55.43941",
    "lng": "10.4094"
  },
  {
    "country": "DK",
    "name": "Stenløse",
    "lat": "55.76828",
    "lng": "12.19723"
  },
  {
    "country": "DK",
    "name": "Stenlille",
    "lat": "55.53888",
    "lng": "11.5912"
  },
  {
    "country": "DK",
    "name": "Stege",
    "lat": "54.98704",
    "lng": "12.28461"
  },
  {
    "country": "DK",
    "name": "Stavtrup",
    "lat": "56.13124",
    "lng": "10.11987"
  },
  {
    "country": "DK",
    "name": "Stavnsholt",
    "lat": "55.81479",
    "lng": "12.40545"
  },
  {
    "country": "DK",
    "name": "Starup",
    "lat": "55.24097",
    "lng": "9.53503"
  },
  {
    "country": "DK",
    "name": "Spentrup",
    "lat": "56.53703",
    "lng": "10.03792"
  },
  {
    "country": "DK",
    "name": "Sorø",
    "lat": "55.43184",
    "lng": "11.55547"
  },
  {
    "country": "DK",
    "name": "Søndersø",
    "lat": "55.48526",
    "lng": "10.2554"
  },
  {
    "country": "DK",
    "name": "Sønderborg",
    "lat": "54.90896",
    "lng": "9.78917"
  },
  {
    "country": "DK",
    "name": "Sønder Bjert",
    "lat": "55.45272",
    "lng": "9.56741"
  },
  {
    "country": "DK",
    "name": "Søften",
    "lat": "56.23801",
    "lng": "10.0851"
  },
  {
    "country": "DK",
    "name": "Solrød Strand",
    "lat": "55.53285",
    "lng": "12.22227"
  },
  {
    "country": "DK",
    "name": "Solrød",
    "lat": "55.53628",
    "lng": "12.1827"
  },
  {
    "country": "DK",
    "name": "Solbjerg",
    "lat": "56.04271",
    "lng": "10.08631"
  },
  {
    "country": "DK",
    "name": "Snoghøj",
    "lat": "55.52253",
    "lng": "9.72125"
  },
  {
    "country": "DK",
    "name": "Snejbjerg",
    "lat": "56.13291",
    "lng": "8.90353"
  },
  {
    "country": "DK",
    "name": "Smørumnedre",
    "lat": "55.74232",
    "lng": "12.30276"
  },
  {
    "country": "DK",
    "name": "Slangerup",
    "lat": "55.85",
    "lng": "12.18333"
  },
  {
    "country": "DK",
    "name": "Slagelse",
    "lat": "55.40276",
    "lng": "11.35459"
  },
  {
    "country": "DK",
    "name": "Skævinge",
    "lat": "55.90785",
    "lng": "12.15036"
  },
  {
    "country": "DK",
    "name": "Sherrebek",
    "lat": "55.15735",
    "lng": "8.76901"
  },
  {
    "country": "DK",
    "name": "Skovby",
    "lat": "56.15672",
    "lng": "9.94523"
  },
  {
    "country": "DK",
    "name": "Skørping",
    "lat": "56.83626",
    "lng": "9.89255"
  },
  {
    "country": "DK",
    "name": "Skælskør",
    "lat": "55.25058",
    "lng": "11.29352"
  },
  {
    "country": "DK",
    "name": "Skjern",
    "lat": "55.95",
    "lng": "8.5"
  },
  {
    "country": "DK",
    "name": "Skive",
    "lat": "56.56699",
    "lng": "9.02707"
  },
  {
    "country": "DK",
    "name": "Skibby",
    "lat": "55.75122",
    "lng": "11.96083"
  },
  {
    "country": "DK",
    "name": "Skanderborg",
    "lat": "56.03434",
    "lng": "9.93177"
  },
  {
    "country": "DK",
    "name": "Skagen",
    "lat": "57.72093",
    "lng": "10.58394"
  },
  {
    "country": "DK",
    "name": "Sindal",
    "lat": "57.47117",
    "lng": "10.20312"
  },
  {
    "country": "DK",
    "name": "Silkeborg",
    "lat": "56.1697",
    "lng": "9.54508"
  },
  {
    "country": "DK",
    "name": "Seden",
    "lat": "55.42648",
    "lng": "10.44265"
  },
  {
    "country": "DK",
    "name": "Sæby",
    "lat": "57.33188",
    "lng": "10.52251"
  },
  {
    "country": "DK",
    "name": "Sakskøbing",
    "lat": "54.7997",
    "lng": "11.62599"
  },
  {
    "country": "DK",
    "name": "Sabro",
    "lat": "56.21333",
    "lng": "10.03441"
  },
  {
    "country": "DK",
    "name": "Ryomgård",
    "lat": "56.3843",
    "lng": "10.50295"
  },
  {
    "country": "DK",
    "name": "Ry",
    "lat": "56.09038",
    "lng": "9.76505"
  },
  {
    "country": "DK",
    "name": "Rudkøbing",
    "lat": "54.93639",
    "lng": "10.71019"
  },
  {
    "country": "DK",
    "name": "Roskilde",
    "lat": "55.64152",
    "lng": "12.08035"
  },
  {
    "country": "DK",
    "name": "Rønnede",
    "lat": "55.2571",
    "lng": "12.02125"
  },
  {
    "country": "DK",
    "name": "Rønne",
    "lat": "55.10091",
    "lng": "14.70664"
  },
  {
    "country": "DK",
    "name": "Rønde",
    "lat": "56.30145",
    "lng": "10.47505"
  },
  {
    "country": "DK",
    "name": "Rødvig",
    "lat": "55.2554",
    "lng": "12.37936"
  },
  {
    "country": "DK",
    "name": "Rødovre",
    "lat": "55.68062",
    "lng": "12.45373"
  },
  {
    "country": "DK",
    "name": "Rødekro",
    "lat": "55.07076",
    "lng": "9.33531"
  },
  {
    "country": "DK",
    "name": "Rødding",
    "lat": "55.36569",
    "lng": "9.06316"
  },
  {
    "country": "DK",
    "name": "Rødbyhavn",
    "lat": "54.65944",
    "lng": "11.35504"
  },
  {
    "country": "DK",
    "name": "Rødby",
    "lat": "54.69495",
    "lng": "11.38885"
  },
  {
    "country": "DK",
    "name": "Ringsted",
    "lat": "55.4426",
    "lng": "11.79011"
  },
  {
    "country": "DK",
    "name": "Ringkøbing",
    "lat": "56.09006",
    "lng": "8.24402"
  },
  {
    "country": "DK",
    "name": "Ringe",
    "lat": "55.23828",
    "lng": "10.4786"
  },
  {
    "country": "DK",
    "name": "Ribe",
    "lat": "55.33051",
    "lng": "8.76966"
  },
  {
    "country": "DK",
    "name": "Randers",
    "lat": "56.4607",
    "lng": "10.03639"
  },
  {
    "country": "DK",
    "name": "Præstø",
    "lat": "55.12374",
    "lng": "12.04477"
  },
  {
    "country": "DK",
    "name": "Pandrup",
    "lat": "57.22147",
    "lng": "9.67569"
  },
  {
    "country": "DK",
    "name": "Padborg",
    "lat": "54.82657",
    "lng": "9.36247"
  },
  {
    "country": "DK",
    "name": "Otterup",
    "lat": "55.51527",
    "lng": "10.39756"
  },
  {
    "country": "DK",
    "name": "Osted",
    "lat": "55.56228",
    "lng": "11.95786"
  },
  {
    "country": "DK",
    "name": "Ørslev",
    "lat": "55.04356",
    "lng": "11.96792"
  },
  {
    "country": "DK",
    "name": "Ølstykke",
    "lat": "55.79567",
    "lng": "12.15509"
  },
  {
    "country": "DK",
    "name": "Ølgod",
    "lat": "55.80682",
    "lng": "8.62859"
  },
  {
    "country": "DK",
    "name": "Oksbøl",
    "lat": "55.6268",
    "lng": "8.28757"
  },
  {
    "country": "DK",
    "name": "Odense",
    "lat": "55.39594",
    "lng": "10.38831"
  },
  {
    "country": "DK",
    "name": "Odder",
    "lat": "55.97313",
    "lng": "10.153"
  },
  {
    "country": "DK",
    "name": "Nyråd",
    "lat": "55.00511",
    "lng": "11.9606"
  },
  {
    "country": "DK",
    "name": "Nykøbing Falster",
    "lat": "54.76906",
    "lng": "11.87425"
  },
  {
    "country": "DK",
    "name": "Nykøbing Sjælland",
    "lat": "55.92491",
    "lng": "11.67109"
  },
  {
    "country": "DK",
    "name": "Nykøbing Mors",
    "lat": "56.79334",
    "lng": "8.85282"
  },
  {
    "country": "DK",
    "name": "Nyborg",
    "lat": "55.31274",
    "lng": "10.78964"
  },
  {
    "country": "DK",
    "name": "Næstved",
    "lat": "55.22992",
    "lng": "11.76092"
  },
  {
    "country": "DK",
    "name": "Nordby",
    "lat": "55.44603",
    "lng": "8.39786"
  },
  {
    "country": "DK",
    "name": "Nordborg",
    "lat": "55.05732",
    "lng": "9.7408"
  },
  {
    "country": "DK",
    "name": "Nørresundby",
    "lat": "57.05877",
    "lng": "9.92284"
  },
  {
    "country": "DK",
    "name": "Nørre Alslev",
    "lat": "54.89784",
    "lng": "11.88414"
  },
  {
    "country": "DK",
    "name": "Nørre Åby",
    "lat": "55.46107",
    "lng": "9.8794"
  },
  {
    "country": "DK",
    "name": "Nødebo",
    "lat": "55.97877",
    "lng": "12.34685"
  },
  {
    "country": "DK",
    "name": "Nivå",
    "lat": "55.93405",
    "lng": "12.50485"
  },
  {
    "country": "DK",
    "name": "Nibe",
    "lat": "56.9815",
    "lng": "9.63917"
  },
  {
    "country": "DK",
    "name": "Nexø",
    "lat": "55.06067",
    "lng": "15.13058"
  },
  {
    "country": "DK",
    "name": "Neder Vindinge",
    "lat": "55.03211",
    "lng": "11.88356"
  },
  {
    "country": "DK",
    "name": "Neder Holluf",
    "lat": "55.36451",
    "lng": "10.44824"
  },
  {
    "country": "DK",
    "name": "Nakskov",
    "lat": "54.83038",
    "lng": "11.13567"
  },
  {
    "country": "DK",
    "name": "Munkebo",
    "lat": "55.45553",
    "lng": "10.55433"
  },
  {
    "country": "DK",
    "name": "Middelfart",
    "lat": "55.50591",
    "lng": "9.73054"
  },
  {
    "country": "DK",
    "name": "Marstal",
    "lat": "54.85621",
    "lng": "10.51726"
  },
  {
    "country": "DK",
    "name": "Mårslet",
    "lat": "56.0669",
    "lng": "10.16112"
  },
  {
    "country": "DK",
    "name": "Maribo",
    "lat": "54.77662",
    "lng": "11.50017"
  },
  {
    "country": "DK",
    "name": "Mariager",
    "lat": "56.64985",
    "lng": "9.97515"
  },
  {
    "country": "DK",
    "name": "Måløv",
    "lat": "55.75528",
    "lng": "12.32327"
  },
  {
    "country": "DK",
    "name": "Malling",
    "lat": "56.03632",
    "lng": "10.19632"
  },
  {
    "country": "DK",
    "name": "Lystrup",
    "lat": "56.2375",
    "lng": "10.23778"
  },
  {
    "country": "DK",
    "name": "Lynge",
    "lat": "55.83941",
    "lng": "12.27725"
  },
  {
    "country": "DK",
    "name": "Lunderskov",
    "lat": "55.48375",
    "lng": "9.29917"
  },
  {
    "country": "DK",
    "name": "Løkken",
    "lat": "57.37047",
    "lng": "9.71466"
  },
  {
    "country": "DK",
    "name": "Løjt Kirkeby",
    "lat": "55.08959",
    "lng": "9.46084"
  },
  {
    "country": "DK",
    "name": "Løgumkloster",
    "lat": "55.05941",
    "lng": "8.95508"
  },
  {
    "country": "DK",
    "name": "Løgten",
    "lat": "56.27459",
    "lng": "10.31181"
  },
  {
    "country": "DK",
    "name": "Løgstør",
    "lat": "56.96245",
    "lng": "9.2583"
  },
  {
    "country": "DK",
    "name": "Liseleje",
    "lat": "56.01295",
    "lng": "11.96544"
  },
  {
    "country": "DK",
    "name": "Lind",
    "lat": "56.106",
    "lng": "8.97915"
  },
  {
    "country": "DK",
    "name": "Værløse",
    "lat": "55.78251",
    "lng": "12.36856"
  },
  {
    "country": "DK",
    "name": "Lillerød",
    "lat": "55.87496",
    "lng": "12.34579"
  },
  {
    "country": "DK",
    "name": "Lemvig",
    "lat": "56.54856",
    "lng": "8.31019"
  },
  {
    "country": "DK",
    "name": "Lejre",
    "lat": "55.60461",
    "lng": "11.97477"
  },
  {
    "country": "DK",
    "name": "Langeskov",
    "lat": "55.35655",
    "lng": "10.58447"
  },
  {
    "country": "DK",
    "name": "Langå",
    "lat": "56.39026",
    "lng": "9.89486"
  },
  {
    "country": "DK",
    "name": "Kruså",
    "lat": "54.85097",
    "lng": "9.40129"
  },
  {
    "country": "DK",
    "name": "Korsør",
    "lat": "55.32993",
    "lng": "11.13857"
  },
  {
    "country": "DK",
    "name": "Køge",
    "lat": "55.45802",
    "lng": "12.18214"
  },
  {
    "country": "DK",
    "name": "Copenhagen",
    "lat": "55.67594",
    "lng": "12.56553"
  },
  {
    "country": "DK",
    "name": "Kongens Lyngby",
    "lat": "55.77044",
    "lng": "12.50378"
  },
  {
    "country": "DK",
    "name": "Kolt",
    "lat": "56.10845",
    "lng": "10.06986"
  },
  {
    "country": "DK",
    "name": "Kolding",
    "lat": "55.4904",
    "lng": "9.47216"
  },
  {
    "country": "DK",
    "name": "Kokkedal",
    "lat": "55.91179",
    "lng": "12.49952"
  },
  {
    "country": "DK",
    "name": "Klarup",
    "lat": "57.01194",
    "lng": "10.05617"
  },
  {
    "country": "DK",
    "name": "Kjellerup",
    "lat": "56.28581",
    "lng": "9.43528"
  },
  {
    "country": "DK",
    "name": "Kirke Hvalsø",
    "lat": "55.5917",
    "lng": "11.86253"
  },
  {
    "country": "DK",
    "name": "Kibæk",
    "lat": "56.0317",
    "lng": "8.85697"
  },
  {
    "country": "DK",
    "name": "Kerteminde",
    "lat": "55.44903",
    "lng": "10.65769"
  },
  {
    "country": "DK",
    "name": "Kås",
    "lat": "57.19774",
    "lng": "9.67173"
  },
  {
    "country": "DK",
    "name": "Karup",
    "lat": "56.30673",
    "lng": "9.16835"
  },
  {
    "country": "DK",
    "name": "Kalundborg",
    "lat": "55.67954",
    "lng": "11.08864"
  },
  {
    "country": "DK",
    "name": "Jyllinge",
    "lat": "55.75295",
    "lng": "12.10315"
  },
  {
    "country": "DK",
    "name": "Jyderup",
    "lat": "55.66399",
    "lng": "11.42029"
  },
  {
    "country": "DK",
    "name": "Juelsminde",
    "lat": "55.70876",
    "lng": "10.01668"
  },
  {
    "country": "DK",
    "name": "Jægerspris",
    "lat": "55.85248",
    "lng": "11.98565"
  },
  {
    "country": "DK",
    "name": "Jelling",
    "lat": "55.75588",
    "lng": "9.4258"
  },
  {
    "country": "DK",
    "name": "Ishøj",
    "lat": "55.61543",
    "lng": "12.35182"
  },
  {
    "country": "DK",
    "name": "Ikast",
    "lat": "56.13883",
    "lng": "9.15768"
  },
  {
    "country": "DK",
    "name": "Hvidovre",
    "lat": "55.65719",
    "lng": "12.47364"
  },
  {
    "country": "DK",
    "name": "Hvide Sande",
    "lat": "55.99866",
    "lng": "8.12605"
  },
  {
    "country": "DK",
    "name": "Hurup",
    "lat": "56.74944",
    "lng": "8.41953"
  },
  {
    "country": "DK",
    "name": "Hundested",
    "lat": "55.96397",
    "lng": "11.85044"
  },
  {
    "country": "DK",
    "name": "Humlebæk",
    "lat": "55.9618",
    "lng": "12.5341"
  },
  {
    "country": "DK",
    "name": "Horsens",
    "lat": "55.86066",
    "lng": "9.85034"
  },
  {
    "country": "DK",
    "name": "Hornsyld",
    "lat": "55.75621",
    "lng": "9.85643"
  },
  {
    "country": "DK",
    "name": "Hornslet",
    "lat": "56.3155",
    "lng": "10.32041"
  },
  {
    "country": "DK",
    "name": "Hornbæk",
    "lat": "56.09027",
    "lng": "12.45693"
  },
  {
    "country": "DK",
    "name": "Hørve",
    "lat": "55.75292",
    "lng": "11.45298"
  },
  {
    "country": "DK",
    "name": "Høruphav",
    "lat": "54.91017",
    "lng": "9.89872"
  },
  {
    "country": "DK",
    "name": "Hørsholm",
    "lat": "55.88098",
    "lng": "12.50111"
  },
  {
    "country": "DK",
    "name": "Hørning",
    "lat": "56.08701",
    "lng": "10.03716"
  },
  {
    "country": "DK",
    "name": "Høng",
    "lat": "55.50736",
    "lng": "11.28873"
  },
  {
    "country": "DK",
    "name": "Højby",
    "lat": "55.91148",
    "lng": "11.59756"
  },
  {
    "country": "DK",
    "name": "Højby",
    "lat": "55.33177",
    "lng": "10.43725"
  },
  {
    "country": "DK",
    "name": "Holte",
    "lat": "55.81667",
    "lng": "12.46667"
  },
  {
    "country": "DK",
    "name": "Holsted",
    "lat": "55.51086",
    "lng": "8.91872"
  },
  {
    "country": "DK",
    "name": "Holstebro",
    "lat": "56.36009",
    "lng": "8.61607"
  },
  {
    "country": "DK",
    "name": "Holeby",
    "lat": "54.71148",
    "lng": "11.46416"
  },
  {
    "country": "DK",
    "name": "Holbæk",
    "lat": "55.7175",
    "lng": "11.71279"
  },
  {
    "country": "DK",
    "name": "Hobro",
    "lat": "56.64306",
    "lng": "9.79029"
  },
  {
    "country": "DK",
    "name": "Hjortshøj",
    "lat": "56.24811",
    "lng": "10.26533"
  },
  {
    "country": "DK",
    "name": "Hjørring",
    "lat": "57.46417",
    "lng": "9.98229"
  },
  {
    "country": "DK",
    "name": "Hjallerup",
    "lat": "57.16466",
    "lng": "10.14571"
  },
  {
    "country": "DK",
    "name": "Hirtshals",
    "lat": "57.58812",
    "lng": "9.95922"
  },
  {
    "country": "DK",
    "name": "Hinnerup",
    "lat": "56.26608",
    "lng": "10.06299"
  },
  {
    "country": "DK",
    "name": "Hillerød",
    "lat": "55.92791",
    "lng": "12.30081"
  },
  {
    "country": "DK",
    "name": "Herning",
    "lat": "56.13615",
    "lng": "8.97662"
  },
  {
    "country": "DK",
    "name": "Herlev",
    "lat": "55.72366",
    "lng": "12.43998"
  },
  {
    "country": "DK",
    "name": "Helsingør",
    "lat": "56.03606",
    "lng": "12.6136"
  },
  {
    "country": "DK",
    "name": "Helsinge",
    "lat": "56.02283",
    "lng": "12.19752"
  },
  {
    "country": "DK",
    "name": "Hellebæk",
    "lat": "56.06823",
    "lng": "12.55782"
  },
  {
    "country": "DK",
    "name": "Hedensted",
    "lat": "55.77043",
    "lng": "9.7011"
  },
  {
    "country": "DK",
    "name": "Havdrup",
    "lat": "55.54481",
    "lng": "12.12392"
  },
  {
    "country": "DK",
    "name": "Haslev",
    "lat": "55.32346",
    "lng": "11.96389"
  },
  {
    "country": "DK",
    "name": "Hårlev",
    "lat": "55.34936",
    "lng": "12.23382"
  },
  {
    "country": "DK",
    "name": "Hårby",
    "lat": "55.22357",
    "lng": "10.12268"
  },
  {
    "country": "DK",
    "name": "Harboøre",
    "lat": "56.61752",
    "lng": "8.18069"
  },
  {
    "country": "DK",
    "name": "Hanstholm",
    "lat": "57.11667",
    "lng": "8.61667"
  },
  {
    "country": "DK",
    "name": "Hammerum",
    "lat": "56.13361",
    "lng": "9.06121"
  },
  {
    "country": "DK",
    "name": "Hammel",
    "lat": "56.25762",
    "lng": "9.86316"
  },
  {
    "country": "DK",
    "name": "Hals",
    "lat": "56.99609",
    "lng": "10.30807"
  },
  {
    "country": "DK",
    "name": "Hadsund",
    "lat": "56.71482",
    "lng": "10.11682"
  },
  {
    "country": "DK",
    "name": "Hadsten",
    "lat": "56.32819",
    "lng": "10.04931"
  },
  {
    "country": "DK",
    "name": "Haderslev",
    "lat": "55.24943",
    "lng": "9.48771"
  },
  {
    "country": "DK",
    "name": "Gundsømagle",
    "lat": "55.73565",
    "lng": "12.15158"
  },
  {
    "country": "DK",
    "name": "Guderup",
    "lat": "54.98978",
    "lng": "9.87174"
  },
  {
    "country": "DK",
    "name": "Græsted",
    "lat": "56.06558",
    "lng": "12.28512"
  },
  {
    "country": "DK",
    "name": "Grindsted",
    "lat": "55.75726",
    "lng": "8.9275"
  },
  {
    "country": "DK",
    "name": "Greve",
    "lat": "55.58333",
    "lng": "12.3"
  },
  {
    "country": "DK",
    "name": "Grenaa",
    "lat": "56.41578",
    "lng": "10.87825"
  },
  {
    "country": "DK",
    "name": "Gråsten",
    "lat": "54.91918",
    "lng": "9.59523"
  },
  {
    "country": "DK",
    "name": "Gram",
    "lat": "55.28948",
    "lng": "9.04913"
  },
  {
    "country": "DK",
    "name": "Gørlev",
    "lat": "55.53926",
    "lng": "11.22708"
  },
  {
    "country": "DK",
    "name": "Glostrup",
    "lat": "55.6666",
    "lng": "12.40377"
  },
  {
    "country": "DK",
    "name": "Glamsbjerg",
    "lat": "55.27237",
    "lng": "10.10483"
  },
  {
    "country": "DK",
    "name": "Gjellerup",
    "lat": "56.14616",
    "lng": "9.05467"
  },
  {
    "country": "DK",
    "name": "Give",
    "lat": "55.84523",
    "lng": "9.23769"
  },
  {
    "country": "DK",
    "name": "Gistrup",
    "lat": "56.9943",
    "lng": "9.99085"
  },
  {
    "country": "DK",
    "name": "Gilleleje",
    "lat": "56.12196",
    "lng": "12.31056"
  },
  {
    "country": "DK",
    "name": "Ganløse",
    "lat": "55.79124",
    "lng": "12.26421"
  },
  {
    "country": "DK",
    "name": "Galten",
    "lat": "56.15902",
    "lng": "9.91691"
  },
  {
    "country": "DK",
    "name": "Fuglebjerg",
    "lat": "55.30604",
    "lng": "11.54766"
  },
  {
    "country": "DK",
    "name": "Frejlev",
    "lat": "57.00623",
    "lng": "9.81711"
  },
  {
    "country": "DK",
    "name": "Frederiksværk",
    "lat": "55.97073",
    "lng": "12.0225"
  },
  {
    "country": "DK",
    "name": "Frederikssund",
    "lat": "55.83956",
    "lng": "12.06896"
  },
  {
    "country": "DK",
    "name": "Frederikshavn",
    "lat": "57.44073",
    "lng": "10.53661"
  },
  {
    "country": "DK",
    "name": "Frederiksberg",
    "lat": "55.67938",
    "lng": "12.53463"
  },
  {
    "country": "DK",
    "name": "Frederiksberg",
    "lat": "55.41618",
    "lng": "11.56934"
  },
  {
    "country": "DK",
    "name": "Fredericia",
    "lat": "55.56568",
    "lng": "9.75257"
  },
  {
    "country": "DK",
    "name": "Fredensborg",
    "lat": "55.97558",
    "lng": "12.40314"
  },
  {
    "country": "DK",
    "name": "Framlev",
    "lat": "56.15664",
    "lng": "10.01318"
  },
  {
    "country": "DK",
    "name": "Forlev",
    "lat": "55.37445",
    "lng": "11.25966"
  },
  {
    "country": "DK",
    "name": "Fløng",
    "lat": "55.66212",
    "lng": "12.18698"
  },
  {
    "country": "DK",
    "name": "Fjerritslev",
    "lat": "57.08822",
    "lng": "9.26622"
  },
  {
    "country": "DK",
    "name": "Fensmark",
    "lat": "55.27919",
    "lng": "11.80382"
  },
  {
    "country": "DK",
    "name": "Farum",
    "lat": "55.80858",
    "lng": "12.36066"
  },
  {
    "country": "DK",
    "name": "Farsø",
    "lat": "56.77276",
    "lng": "9.33925"
  },
  {
    "country": "DK",
    "name": "Faxe Ladeplads",
    "lat": "55.21981",
    "lng": "12.17013"
  },
  {
    "country": "DK",
    "name": "Faxe",
    "lat": "55.25561",
    "lng": "12.11926"
  },
  {
    "country": "DK",
    "name": "Faaborg",
    "lat": "55.0951",
    "lng": "10.24226"
  },
  {
    "country": "DK",
    "name": "Espergærde",
    "lat": "55.99464",
    "lng": "12.54733"
  },
  {
    "country": "DK",
    "name": "Esbjerg",
    "lat": "55.47028",
    "lng": "8.45187"
  },
  {
    "country": "DK",
    "name": "Ejby",
    "lat": "55.68923",
    "lng": "11.84725"
  },
  {
    "country": "DK",
    "name": "Ejby",
    "lat": "55.4858",
    "lng": "12.08171"
  },
  {
    "country": "DK",
    "name": "Ejby",
    "lat": "55.4301",
    "lng": "9.92973"
  },
  {
    "country": "DK",
    "name": "Egtved",
    "lat": "55.61613",
    "lng": "9.30763"
  },
  {
    "country": "DK",
    "name": "Ebeltoft",
    "lat": "56.19442",
    "lng": "10.6821"
  },
  {
    "country": "DK",
    "name": "Dybbøl",
    "lat": "54.91079",
    "lng": "9.73601"
  },
  {
    "country": "DK",
    "name": "Dronninglund",
    "lat": "57.16035",
    "lng": "10.29287"
  },
  {
    "country": "DK",
    "name": "Dragør",
    "lat": "55.5928",
    "lng": "12.67221"
  },
  {
    "country": "DK",
    "name": "Dianalund",
    "lat": "55.53133",
    "lng": "11.4925"
  },
  {
    "country": "DK",
    "name": "Christianshavn",
    "lat": "55.67383",
    "lng": "12.59541"
  },
  {
    "country": "DK",
    "name": "Christiansfeld",
    "lat": "55.35817",
    "lng": "9.48701"
  },
  {
    "country": "DK",
    "name": "Charlottenlund",
    "lat": "55.75238",
    "lng": "12.5745"
  },
  {
    "country": "DK",
    "name": "Byrum",
    "lat": "57.25679",
    "lng": "10.99738"
  },
  {
    "country": "DK",
    "name": "Bullerup",
    "lat": "55.42686",
    "lng": "10.47137"
  },
  {
    "country": "DK",
    "name": "Buddinge",
    "lat": "55.74818",
    "lng": "12.49532"
  },
  {
    "country": "DK",
    "name": "Brovst",
    "lat": "57.0975",
    "lng": "9.52264"
  },
  {
    "country": "DK",
    "name": "Brørup",
    "lat": "55.48194",
    "lng": "9.01756"
  },
  {
    "country": "DK",
    "name": "Brønderslev",
    "lat": "57.27021",
    "lng": "9.94102"
  },
  {
    "country": "DK",
    "name": "Brøndbyvester",
    "lat": "55.6455",
    "lng": "12.41008"
  },
  {
    "country": "DK",
    "name": "Broager",
    "lat": "54.8894",
    "lng": "9.67465"
  },
  {
    "country": "DK",
    "name": "Brenderup",
    "lat": "55.48407",
    "lng": "9.97908"
  },
  {
    "country": "DK",
    "name": "Brejning",
    "lat": "55.66594",
    "lng": "9.67217"
  },
  {
    "country": "DK",
    "name": "Brædstrup",
    "lat": "55.97153",
    "lng": "9.61129"
  },
  {
    "country": "DK",
    "name": "Brande",
    "lat": "55.94316",
    "lng": "9.12798"
  },
  {
    "country": "DK",
    "name": "Bramming",
    "lat": "55.46946",
    "lng": "8.70007"
  },
  {
    "country": "DK",
    "name": "Borup",
    "lat": "55.49472",
    "lng": "11.97584"
  },
  {
    "country": "DK",
    "name": "Bording Kirkeby",
    "lat": "56.16871",
    "lng": "9.24384"
  },
  {
    "country": "DK",
    "name": "Børkop",
    "lat": "55.64195",
    "lng": "9.64958"
  },
  {
    "country": "DK",
    "name": "Bogense",
    "lat": "55.56691",
    "lng": "10.08863"
  },
  {
    "country": "DK",
    "name": "Blovstrød",
    "lat": "55.87038",
    "lng": "12.3864"
  },
  {
    "country": "DK",
    "name": "Bjæverskov",
    "lat": "55.45756",
    "lng": "12.03651"
  },
  {
    "country": "DK",
    "name": "Bjerringbro",
    "lat": "56.37797",
    "lng": "9.66065"
  },
  {
    "country": "DK",
    "name": "Birkerød",
    "lat": "55.84759",
    "lng": "12.42791"
  },
  {
    "country": "DK",
    "name": "Billund",
    "lat": "55.73349",
    "lng": "9.10785"
  },
  {
    "country": "DK",
    "name": "Bellinge",
    "lat": "55.33535",
    "lng": "10.32045"
  },
  {
    "country": "DK",
    "name": "Beder",
    "lat": "56.06025",
    "lng": "10.21179"
  },
  {
    "country": "DK",
    "name": "Ballerup",
    "lat": "55.73165",
    "lng": "12.36328"
  },
  {
    "country": "DK",
    "name": "Avlum",
    "lat": "56.26539",
    "lng": "8.79256"
  },
  {
    "country": "DK",
    "name": "Auning",
    "lat": "56.43079",
    "lng": "10.37818"
  },
  {
    "country": "DK",
    "name": "Augustenborg",
    "lat": "54.95201",
    "lng": "9.87216"
  },
  {
    "country": "DK",
    "name": "Assentoft",
    "lat": "56.4421",
    "lng": "10.1517"
  },
  {
    "country": "DK",
    "name": "Assens",
    "lat": "55.27023",
    "lng": "9.90081"
  },
  {
    "country": "DK",
    "name": "Asnæs",
    "lat": "55.81229",
    "lng": "11.50129"
  },
  {
    "country": "DK",
    "name": "Årup",
    "lat": "55.37315",
    "lng": "10.04131"
  },
  {
    "country": "DK",
    "name": "Årslev",
    "lat": "55.30353",
    "lng": "10.46428"
  },
  {
    "country": "DK",
    "name": "Aars",
    "lat": "56.80399",
    "lng": "9.51441"
  },
  {
    "country": "DK",
    "name": "Århus",
    "lat": "56.15674",
    "lng": "10.21076"
  },
  {
    "country": "DK",
    "name": "Arden",
    "lat": "56.76899",
    "lng": "9.86184"
  },
  {
    "country": "DK",
    "name": "Allingåbro",
    "lat": "56.46432",
    "lng": "10.31957"
  },
  {
    "country": "DK",
    "name": "Ålestrup",
    "lat": "56.6947",
    "lng": "9.49336"
  },
  {
    "country": "DK",
    "name": "Aalborg",
    "lat": "57.048",
    "lng": "9.9187"
  },
  {
    "country": "DK",
    "name": "Albertslund",
    "lat": "55.65691",
    "lng": "12.36381"
  },
  {
    "country": "DK",
    "name": "Åkirkeby",
    "lat": "55.0708",
    "lng": "14.91978"
  },
  {
    "country": "DK",
    "name": "Ærøskøbing",
    "lat": "54.88803",
    "lng": "10.41117"
  },
  {
    "country": "DK",
    "name": "Åbybro",
    "lat": "57.16249",
    "lng": "9.72996"
  },
  {
    "country": "DK",
    "name": "Aabenraa",
    "lat": "55.04434",
    "lng": "9.41741"
  },
  {
    "country": "DK",
    "name": "Sundby",
    "lat": "54.76711",
    "lng": "11.84979"
  },
  {
    "country": "DK",
    "name": "Christiansø",
    "lat": "55.32006",
    "lng": "15.18662"
  },
  {
    "country": "DM",
    "name": "Woodford Hill",
    "lat": "15.58093",
    "lng": "-61.33149"
  },
  {
    "country": "DM",
    "name": "Wesley",
    "lat": "15.56667",
    "lng": "-61.31667"
  },
  {
    "country": "DM",
    "name": "Soufrière",
    "lat": "15.23374",
    "lng": "-61.35881"
  },
  {
    "country": "DM",
    "name": "Salisbury",
    "lat": "15.43689",
    "lng": "-61.43637"
  },
  {
    "country": "DM",
    "name": "Saint Joseph",
    "lat": "15.4",
    "lng": "-61.43333"
  },
  {
    "country": "DM",
    "name": "Roseau",
    "lat": "15.30174",
    "lng": "-61.38808"
  },
  {
    "country": "DM",
    "name": "Rosalie",
    "lat": "15.36667",
    "lng": "-61.26667"
  },
  {
    "country": "DM",
    "name": "Portsmouth",
    "lat": "15.58333",
    "lng": "-61.46667"
  },
  {
    "country": "DM",
    "name": "Pont Cassé",
    "lat": "15.36667",
    "lng": "-61.35"
  },
  {
    "country": "DM",
    "name": "Pointe Michel",
    "lat": "15.25976",
    "lng": "-61.37452"
  },
  {
    "country": "DM",
    "name": "Marigot",
    "lat": "15.53886",
    "lng": "-61.28375"
  },
  {
    "country": "DM",
    "name": "Mahaut",
    "lat": "15.36357",
    "lng": "-61.39701"
  },
  {
    "country": "DM",
    "name": "La Plaine",
    "lat": "15.32768",
    "lng": "-61.24753"
  },
  {
    "country": "DM",
    "name": "Colihaut",
    "lat": "15.48478",
    "lng": "-61.46215"
  },
  {
    "country": "DM",
    "name": "Castle Bruce",
    "lat": "15.44397",
    "lng": "-61.25723"
  },
  {
    "country": "DM",
    "name": "Calibishie",
    "lat": "15.59297",
    "lng": "-61.34901"
  },
  {
    "country": "DM",
    "name": "Berekua",
    "lat": "15.23333",
    "lng": "-61.31667"
  },
  {
    "country": "DO",
    "name": "Yayas de Viajama",
    "lat": "18.6071",
    "lng": "-70.92753"
  },
  {
    "country": "DO",
    "name": "Yamasá",
    "lat": "18.77315",
    "lng": "-70.02583"
  },
  {
    "country": "DO",
    "name": "Yaguate",
    "lat": "18.3353",
    "lng": "-70.18113"
  },
  {
    "country": "DO",
    "name": "Villa Vásquez",
    "lat": "19.7411",
    "lng": "-71.4464"
  },
  {
    "country": "DO",
    "name": "Villa Tapia",
    "lat": "19.30084",
    "lng": "-70.42199"
  },
  {
    "country": "DO",
    "name": "Villarpando",
    "lat": "18.6586",
    "lng": "-71.03916"
  },
  {
    "country": "DO",
    "name": "Villa Riva",
    "lat": "19.18069",
    "lng": "-69.91319"
  },
  {
    "country": "DO",
    "name": "Villa Jaragua",
    "lat": "18.49077",
    "lng": "-71.48377"
  },
  {
    "country": "DO",
    "name": "Villa Isabela",
    "lat": "19.81564",
    "lng": "-71.06056"
  },
  {
    "country": "DO",
    "name": "Villa González",
    "lat": "19.54057",
    "lng": "-70.78853"
  },
  {
    "country": "DO",
    "name": "Villa Francisca",
    "lat": "18.48278",
    "lng": "-69.88914"
  },
  {
    "country": "DO",
    "name": "Villa Elisa",
    "lat": "19.6856",
    "lng": "-71.27007"
  },
  {
    "country": "DO",
    "name": "Villa Consuelo",
    "lat": "18.48333",
    "lng": "-69.9"
  },
  {
    "country": "DO",
    "name": "Villa Bisonó",
    "lat": "19.56378",
    "lng": "-70.87582"
  },
  {
    "country": "DO",
    "name": "Villa Altagracia",
    "lat": "18.67297",
    "lng": "-70.17095"
  },
  {
    "country": "DO",
    "name": "Vicente Noble",
    "lat": "18.38443",
    "lng": "-71.18009"
  },
  {
    "country": "DO",
    "name": "Veragua Arriba",
    "lat": "19.58333",
    "lng": "-70.33333"
  },
  {
    "country": "DO",
    "name": "Vallejuelo",
    "lat": "18.65354",
    "lng": "-71.33431"
  },
  {
    "country": "DO",
    "name": "Tireo Arriba",
    "lat": "18.93537",
    "lng": "-70.6885"
  },
  {
    "country": "DO",
    "name": "Tenares",
    "lat": "19.37439",
    "lng": "-70.35087"
  },
  {
    "country": "DO",
    "name": "Tamboril",
    "lat": "19.48538",
    "lng": "-70.61104"
  },
  {
    "country": "DO",
    "name": "Tamayo",
    "lat": "18.3947",
    "lng": "-71.2029"
  },
  {
    "country": "DO",
    "name": "Tábara Arriba",
    "lat": "18.56999",
    "lng": "-70.87978"
  },
  {
    "country": "DO",
    "name": "Sosúa",
    "lat": "19.7522",
    "lng": "-70.51995"
  },
  {
    "country": "DO",
    "name": "San Víctor Arriba",
    "lat": "19.47741",
    "lng": "-70.53585"
  },
  {
    "country": "DO",
    "name": "Santo Domingo",
    "lat": "18.47186",
    "lng": "-69.89232"
  },
  {
    "country": "DO",
    "name": "Santiago de los Caballeros",
    "lat": "19.4517",
    "lng": "-70.69703"
  },
  {
    "country": "DO",
    "name": "Santa Cruz de El Seibo",
    "lat": "18.76559",
    "lng": "-69.03886"
  },
  {
    "country": "DO",
    "name": "Santa Cruz de Barahona",
    "lat": "18.20854",
    "lng": "-71.10077"
  },
  {
    "country": "DO",
    "name": "Samaná",
    "lat": "19.20561",
    "lng": "-69.33685"
  },
  {
    "country": "DO",
    "name": "San Rafael del Yuma",
    "lat": "18.42993",
    "lng": "-68.6739"
  },
  {
    "country": "DO",
    "name": "San Pedro de Macorís",
    "lat": "18.4539",
    "lng": "-69.30864"
  },
  {
    "country": "DO",
    "name": "San Juan de la Maguana",
    "lat": "18.80588",
    "lng": "-71.22991"
  },
  {
    "country": "DO",
    "name": "San José de Ocoa",
    "lat": "18.54661",
    "lng": "-70.50631"
  },
  {
    "country": "DO",
    "name": "San José de Las Matas",
    "lat": "19.33915",
    "lng": "-70.93819"
  },
  {
    "country": "DO",
    "name": "San Gregorio de Nigua",
    "lat": "18.38333",
    "lng": "-70.08333"
  },
  {
    "country": "DO",
    "name": "San Francisco de Macorís",
    "lat": "19.30099",
    "lng": "-70.25259"
  },
  {
    "country": "DO",
    "name": "San Fernando de Monte Cristi",
    "lat": "19.84826",
    "lng": "-71.64597"
  },
  {
    "country": "DO",
    "name": "Puerto Plata",
    "lat": "19.79344",
    "lng": "-70.6884"
  },
  {
    "country": "DO",
    "name": "Sánchez",
    "lat": "19.2281",
    "lng": "-69.6137"
  },
  {
    "country": "DO",
    "name": "San Carlos",
    "lat": "18.48333",
    "lng": "-69.9"
  },
  {
    "country": "DO",
    "name": "Salvaleón de Higüey",
    "lat": "18.61501",
    "lng": "-68.70798"
  },
  {
    "country": "DO",
    "name": "Salsipuedes",
    "lat": "19.40552",
    "lng": "-70.37985"
  },
  {
    "country": "DO",
    "name": "Salcedo",
    "lat": "19.37762",
    "lng": "-70.41762"
  },
  {
    "country": "DO",
    "name": "Sabaneta",
    "lat": "19.47793",
    "lng": "-71.34125"
  },
  {
    "country": "DO",
    "name": "Sabana Yegua",
    "lat": "18.71667",
    "lng": "-71.01667"
  },
  {
    "country": "DO",
    "name": "Sabana Iglesia",
    "lat": "19.32114",
    "lng": "-70.75992"
  },
  {
    "country": "DO",
    "name": "Sabana Grande de Palenque",
    "lat": "18.26256",
    "lng": "-70.14821"
  },
  {
    "country": "DO",
    "name": "Sabana Grande de Boyá",
    "lat": "18.94498",
    "lng": "-69.79331"
  },
  {
    "country": "DO",
    "name": "Sabana del Puerto",
    "lat": "19.06667",
    "lng": "-70.41667"
  },
  {
    "country": "DO",
    "name": "Sabana de La Mar",
    "lat": "19.05934",
    "lng": "-69.38843"
  },
  {
    "country": "DO",
    "name": "Sabana Buey",
    "lat": "18.27351",
    "lng": "-70.52352"
  },
  {
    "country": "DO",
    "name": "Río Verde Arriba",
    "lat": "19.31583",
    "lng": "-70.56643"
  },
  {
    "country": "DO",
    "name": "Río San Juan",
    "lat": "19.64385",
    "lng": "-70.07635"
  },
  {
    "country": "DO",
    "name": "Río Limpio",
    "lat": "19.24513",
    "lng": "-71.53077"
  },
  {
    "country": "DO",
    "name": "Río Grande",
    "lat": "19.66667",
    "lng": "-70.76667"
  },
  {
    "country": "DO",
    "name": "Rincón",
    "lat": "19.11938",
    "lng": "-70.40632"
  },
  {
    "country": "DO",
    "name": "Restauración",
    "lat": "19.31532",
    "lng": "-71.69239"
  },
  {
    "country": "DO",
    "name": "Ramón Santana",
    "lat": "18.54224",
    "lng": "-69.17979"
  },
  {
    "country": "DO",
    "name": "Quisqueya",
    "lat": "18.55542",
    "lng": "-69.40814"
  },
  {
    "country": "DO",
    "name": "Punta Cana",
    "lat": "18.58182",
    "lng": "-68.40431"
  },
  {
    "country": "DO",
    "name": "Pueblo Viejo",
    "lat": "18.4",
    "lng": "-70.76765"
  },
  {
    "country": "DO",
    "name": "Postrer Río",
    "lat": "18.54374",
    "lng": "-71.63561"
  },
  {
    "country": "DO",
    "name": "Polo",
    "lat": "18.07873",
    "lng": "-71.28723"
  },
  {
    "country": "DO",
    "name": "Pizarrete",
    "lat": "18.29935",
    "lng": "-70.22648"
  },
  {
    "country": "DO",
    "name": "Pimentel",
    "lat": "19.18416",
    "lng": "-70.10884"
  },
  {
    "country": "DO",
    "name": "Piedra Blanca",
    "lat": "18.84431",
    "lng": "-70.31688"
  },
  {
    "country": "DO",
    "name": "Pescadería",
    "lat": "18.26766",
    "lng": "-71.16612"
  },
  {
    "country": "DO",
    "name": "Peralta",
    "lat": "18.58164",
    "lng": "-70.77029"
  },
  {
    "country": "DO",
    "name": "Pepillo Salcedo",
    "lat": "19.69841",
    "lng": "-71.74513"
  },
  {
    "country": "DO",
    "name": "Pedro Santana",
    "lat": "19.10515",
    "lng": "-71.69498"
  },
  {
    "country": "DO",
    "name": "Pedro Sánchez",
    "lat": "18.86375",
    "lng": "-69.10868"
  },
  {
    "country": "DO",
    "name": "Pedro García",
    "lat": "19.59202",
    "lng": "-70.65256"
  },
  {
    "country": "DO",
    "name": "Pedro Corto",
    "lat": "18.84856",
    "lng": "-71.41041"
  },
  {
    "country": "DO",
    "name": "Pedernales",
    "lat": "18.03838",
    "lng": "-71.74403"
  },
  {
    "country": "DO",
    "name": "Paya",
    "lat": "18.26196",
    "lng": "-70.2956"
  },
  {
    "country": "DO",
    "name": "Partido",
    "lat": "19.48403",
    "lng": "-71.5473"
  },
  {
    "country": "DO",
    "name": "Paraíso",
    "lat": "17.99172",
    "lng": "-71.16526"
  },
  {
    "country": "DO",
    "name": "Palmar de Ocoa",
    "lat": "18.29656",
    "lng": "-70.58635"
  },
  {
    "country": "DO",
    "name": "Palmar Arriba",
    "lat": "19.53957",
    "lng": "-70.73826"
  },
  {
    "country": "DO",
    "name": "Padre Las Casas",
    "lat": "18.73172",
    "lng": "-70.93917"
  },
  {
    "country": "DO",
    "name": "Oviedo",
    "lat": "17.80136",
    "lng": "-71.401"
  },
  {
    "country": "DO",
    "name": "Otra Banda",
    "lat": "18.65017",
    "lng": "-68.66281"
  },
  {
    "country": "DO",
    "name": "Nizao",
    "lat": "18.24697",
    "lng": "-70.21053"
  },
  {
    "country": "DO",
    "name": "Neiba",
    "lat": "18.48137",
    "lng": "-71.41965"
  },
  {
    "country": "DO",
    "name": "Nagua",
    "lat": "19.3832",
    "lng": "-69.8474"
  },
  {
    "country": "DO",
    "name": "Monte Plata",
    "lat": "18.807",
    "lng": "-69.78399"
  },
  {
    "country": "DO",
    "name": "Monte Llano",
    "lat": "19.7346",
    "lng": "-70.59915"
  },
  {
    "country": "DO",
    "name": "Monción",
    "lat": "19.41083",
    "lng": "-71.15257"
  },
  {
    "country": "DO",
    "name": "Moca",
    "lat": "19.39352",
    "lng": "-70.52598"
  },
  {
    "country": "DO",
    "name": "Miches",
    "lat": "18.98364",
    "lng": "-69.0476"
  },
  {
    "country": "DO",
    "name": "Mella",
    "lat": "18.35871",
    "lng": "-71.41716"
  },
  {
    "country": "DO",
    "name": "Matayaya",
    "lat": "18.89036",
    "lng": "-71.59459"
  },
  {
    "country": "DO",
    "name": "Matanzas",
    "lat": "18.24297",
    "lng": "-70.41768"
  },
  {
    "country": "DO",
    "name": "Mao",
    "lat": "19.55186",
    "lng": "-71.07813"
  },
  {
    "country": "DO",
    "name": "Majagual",
    "lat": "19.04134",
    "lng": "-69.83616"
  },
  {
    "country": "DO",
    "name": "Maizal",
    "lat": "19.63655",
    "lng": "-71.02734"
  },
  {
    "country": "DO",
    "name": "Luperón",
    "lat": "19.89131",
    "lng": "-70.96204"
  },
  {
    "country": "DO",
    "name": "Los Ríos",
    "lat": "18.52131",
    "lng": "-71.59106"
  },
  {
    "country": "DO",
    "name": "Los Llanos",
    "lat": "18.62035",
    "lng": "-69.49581"
  },
  {
    "country": "DO",
    "name": "Los Hidalgos",
    "lat": "19.73333",
    "lng": "-71.03333"
  },
  {
    "country": "DO",
    "name": "Los Botados",
    "lat": "18.73226",
    "lng": "-69.99536"
  },
  {
    "country": "DO",
    "name": "Loma de Cabrera",
    "lat": "19.43333",
    "lng": "-71.6"
  },
  {
    "country": "DO",
    "name": "Licey al Medio",
    "lat": "19.43333",
    "lng": "-70.6"
  },
  {
    "country": "DO",
    "name": "La Uvilla",
    "lat": "18.36186",
    "lng": "-71.21046"
  },
  {
    "country": "DO",
    "name": "Las Terrenas",
    "lat": "19.31102",
    "lng": "-69.5428"
  },
  {
    "country": "DO",
    "name": "Las Salinas",
    "lat": "18.27485",
    "lng": "-71.31596"
  },
  {
    "country": "DO",
    "name": "Las Matas de Santa Cruz",
    "lat": "19.67119",
    "lng": "-71.50471"
  },
  {
    "country": "DO",
    "name": "Las Matas de Farfán",
    "lat": "18.87309",
    "lng": "-71.51656"
  },
  {
    "country": "DO",
    "name": "Las Guáranas",
    "lat": "19.1931",
    "lng": "-70.20835"
  },
  {
    "country": "DO",
    "name": "Las Charcas",
    "lat": "18.45026",
    "lng": "-70.61724"
  },
  {
    "country": "DO",
    "name": "La Romana",
    "lat": "18.42733",
    "lng": "-68.97285"
  },
  {
    "country": "DO",
    "name": "La Julia",
    "lat": "18.46667",
    "lng": "-69.93333"
  },
  {
    "country": "DO",
    "name": "Laguna Salada",
    "lat": "19.65043",
    "lng": "-71.08429"
  },
  {
    "country": "DO",
    "name": "La Entrada",
    "lat": "19.55367",
    "lng": "-69.90762"
  },
  {
    "country": "DO",
    "name": "La Descubierta",
    "lat": "18.57053",
    "lng": "-71.72967"
  },
  {
    "country": "DO",
    "name": "La Ciénaga",
    "lat": "18.06858",
    "lng": "-71.10651"
  },
  {
    "country": "DO",
    "name": "La Caya",
    "lat": "19.69981",
    "lng": "-71.12084"
  },
  {
    "country": "DO",
    "name": "La Canela",
    "lat": "19.47341",
    "lng": "-70.81629"
  },
  {
    "country": "DO",
    "name": "La Agustina",
    "lat": "18.5",
    "lng": "-69.93333"
  },
  {
    "country": "DO",
    "name": "Juncalito Abajo",
    "lat": "19.2199",
    "lng": "-70.81905"
  },
  {
    "country": "DO",
    "name": "Juan Santiago",
    "lat": "18.70342",
    "lng": "-71.58971"
  },
  {
    "country": "DO",
    "name": "Juan López Abajo",
    "lat": "19.43333",
    "lng": "-70.5"
  },
  {
    "country": "DO",
    "name": "Juan de Herrera",
    "lat": "18.87402",
    "lng": "-71.2383"
  },
  {
    "country": "DO",
    "name": "Juancho",
    "lat": "17.85782",
    "lng": "-71.29311"
  },
  {
    "country": "DO",
    "name": "Juan Adrián",
    "lat": "18.76365",
    "lng": "-70.33732"
  },
  {
    "country": "DO",
    "name": "Joba Arriba",
    "lat": "19.56667",
    "lng": "-70.26667"
  },
  {
    "country": "DO",
    "name": "Jimaní",
    "lat": "18.49169",
    "lng": "-71.85022"
  },
  {
    "country": "DO",
    "name": "Jima Abajo",
    "lat": "19.13292",
    "lng": "-70.37607"
  },
  {
    "country": "DO",
    "name": "Jicomé",
    "lat": "19.64955",
    "lng": "-70.94927"
  },
  {
    "country": "DO",
    "name": "Jarabacoa",
    "lat": "19.11683",
    "lng": "-70.63595"
  },
  {
    "country": "DO",
    "name": "Jaquimeyes",
    "lat": "18.31173",
    "lng": "-71.16145"
  },
  {
    "country": "DO",
    "name": "Jamao al Norte",
    "lat": "19.63552",
    "lng": "-70.44664"
  },
  {
    "country": "DO",
    "name": "Jaibón",
    "lat": "19.61169",
    "lng": "-71.14847"
  },
  {
    "country": "DO",
    "name": "Imbert",
    "lat": "19.75371",
    "lng": "-70.82906"
  },
  {
    "country": "DO",
    "name": "Hostos",
    "lat": "19.18043",
    "lng": "-70.02046"
  },
  {
    "country": "DO",
    "name": "Hondo Valle",
    "lat": "18.71599",
    "lng": "-71.69511"
  },
  {
    "country": "DO",
    "name": "Hato Mayor del Rey",
    "lat": "18.76278",
    "lng": "-69.25681"
  },
  {
    "country": "DO",
    "name": "Hatillo Palma",
    "lat": "19.66256",
    "lng": "-71.19406"
  },
  {
    "country": "DO",
    "name": "Guerra",
    "lat": "18.55892",
    "lng": "-69.70103"
  },
  {
    "country": "DO",
    "name": "Guaymate",
    "lat": "18.58793",
    "lng": "-68.97867"
  },
  {
    "country": "DO",
    "name": "Guayabo Dulce",
    "lat": "18.65",
    "lng": "-69.28333"
  },
  {
    "country": "DO",
    "name": "Guayabal",
    "lat": "18.5981",
    "lng": "-71.64184"
  },
  {
    "country": "DO",
    "name": "Guatapanal",
    "lat": "19.50705",
    "lng": "-70.91713"
  },
  {
    "country": "DO",
    "name": "Guananico",
    "lat": "19.72693",
    "lng": "-70.92294"
  },
  {
    "country": "DO",
    "name": "Gonzalo",
    "lat": "18.95147",
    "lng": "-69.75114"
  },
  {
    "country": "DO",
    "name": "Gaspar Hernández",
    "lat": "19.62748",
    "lng": "-70.27772"
  },
  {
    "country": "DO",
    "name": "Galván",
    "lat": "18.50228",
    "lng": "-71.34271"
  },
  {
    "country": "DO",
    "name": "Fundación",
    "lat": "18.28668",
    "lng": "-71.18147"
  },
  {
    "country": "DO",
    "name": "Fantino",
    "lat": "19.12148",
    "lng": "-70.29972"
  },
  {
    "country": "DO",
    "name": "Estero Hondo",
    "lat": "19.82712",
    "lng": "-71.17411"
  },
  {
    "country": "DO",
    "name": "Estebanía",
    "lat": "18.4577",
    "lng": "-70.6435"
  },
  {
    "country": "DO",
    "name": "Esperanza",
    "lat": "19.58469",
    "lng": "-70.98489"
  },
  {
    "country": "DO",
    "name": "Esperalvillo",
    "lat": "18.81509",
    "lng": "-70.03557"
  },
  {
    "country": "DO",
    "name": "Ensanche Luperón",
    "lat": "18.5",
    "lng": "-69.9"
  },
  {
    "country": "DO",
    "name": "Enriquillo",
    "lat": "17.9",
    "lng": "-71.23333"
  },
  {
    "country": "DO",
    "name": "El Valle",
    "lat": "18.97567",
    "lng": "-69.37827"
  },
  {
    "country": "DO",
    "name": "El Puerto",
    "lat": "18.78333",
    "lng": "-69.46667"
  },
  {
    "country": "DO",
    "name": "El Pino",
    "lat": "19.43537",
    "lng": "-71.4754"
  },
  {
    "country": "DO",
    "name": "El Peñón",
    "lat": "18.29643",
    "lng": "-71.1841"
  },
  {
    "country": "DO",
    "name": "El Palmar",
    "lat": "18.41139",
    "lng": "-71.24558"
  },
  {
    "country": "DO",
    "name": "El Llano",
    "lat": "18.81667",
    "lng": "-71.63333"
  },
  {
    "country": "DO",
    "name": "El Guayabal",
    "lat": "18.7496",
    "lng": "-70.8369"
  },
  {
    "country": "DO",
    "name": "El Factor",
    "lat": "19.31834",
    "lng": "-69.88827"
  },
  {
    "country": "DO",
    "name": "El Carril",
    "lat": "18.44905",
    "lng": "-70.02785"
  },
  {
    "country": "DO",
    "name": "El Cacao",
    "lat": "18.52719",
    "lng": "-70.29585"
  },
  {
    "country": "DO",
    "name": "Duvergé",
    "lat": "18.37839",
    "lng": "-71.52469"
  },
  {
    "country": "DO",
    "name": "Don Juan",
    "lat": "18.82774",
    "lng": "-69.94629"
  },
  {
    "country": "DO",
    "name": "Dajabón",
    "lat": "19.54878",
    "lng": "-71.70829"
  },
  {
    "country": "DO",
    "name": "Cristo Rey",
    "lat": "18.5",
    "lng": "-69.93333"
  },
  {
    "country": "DO",
    "name": "Cristóbal",
    "lat": "18.29405",
    "lng": "-71.29298"
  },
  {
    "country": "DO",
    "name": "Cotuí",
    "lat": "19.05272",
    "lng": "-70.14939"
  },
  {
    "country": "DO",
    "name": "Constanza",
    "lat": "18.90919",
    "lng": "-70.74499"
  },
  {
    "country": "DO",
    "name": "Concepción de La Vega",
    "lat": "19.22207",
    "lng": "-70.52956"
  },
  {
    "country": "DO",
    "name": "Comendador",
    "lat": "18.8775",
    "lng": "-71.70278"
  },
  {
    "country": "DO",
    "name": "Ciudad Nueva",
    "lat": "18.46707",
    "lng": "-69.89339"
  },
  {
    "country": "DO",
    "name": "Cevicos",
    "lat": "19.00449",
    "lng": "-69.97896"
  },
  {
    "country": "DO",
    "name": "Cercado Abajo",
    "lat": "18.72681",
    "lng": "-71.51742"
  },
  {
    "country": "DO",
    "name": "Cayetano Germosén",
    "lat": "19.34413",
    "lng": "-70.48342"
  },
  {
    "country": "DO",
    "name": "Castillo",
    "lat": "19.20824",
    "lng": "-70.02726"
  },
  {
    "country": "DO",
    "name": "Castañuelas",
    "lat": "19.71387",
    "lng": "-71.49876"
  },
  {
    "country": "DO",
    "name": "Canoa",
    "lat": "18.35499",
    "lng": "-71.15851"
  },
  {
    "country": "DO",
    "name": "Cana Chapetón",
    "lat": "19.60703",
    "lng": "-71.25734"
  },
  {
    "country": "DO",
    "name": "Cambita Garabitos",
    "lat": "18.45458",
    "lng": "-70.19907"
  },
  {
    "country": "DO",
    "name": "Cachón",
    "lat": "18.24833",
    "lng": "-71.18912"
  },
  {
    "country": "DO",
    "name": "Cabrera",
    "lat": "19.6426",
    "lng": "-69.90489"
  },
  {
    "country": "DO",
    "name": "Cabral",
    "lat": "18.25",
    "lng": "-71.21667"
  },
  {
    "country": "DO",
    "name": "Cabarete",
    "lat": "19.74982",
    "lng": "-70.40829"
  },
  {
    "country": "DO",
    "name": "Bonao",
    "lat": "18.93687",
    "lng": "-70.40923"
  },
  {
    "country": "DO",
    "name": "Bohechío",
    "lat": "18.77515",
    "lng": "-70.98889"
  },
  {
    "country": "DO",
    "name": "Boca de Yuma",
    "lat": "18.37825",
    "lng": "-68.609"
  },
  {
    "country": "DO",
    "name": "Boca Chica",
    "lat": "18.45",
    "lng": "-69.6"
  },
  {
    "country": "DO",
    "name": "San Cristóbal",
    "lat": "18.41667",
    "lng": "-70.1"
  },
  {
    "country": "DO",
    "name": "Bella Vista",
    "lat": "18.45539",
    "lng": "-69.9454"
  },
  {
    "country": "DO",
    "name": "Bayaguana",
    "lat": "18.75031",
    "lng": "-69.63525"
  },
  {
    "country": "DO",
    "name": "Bánica",
    "lat": "19.08239",
    "lng": "-71.7054"
  },
  {
    "country": "DO",
    "name": "Baní",
    "lat": "18.27964",
    "lng": "-70.33185"
  },
  {
    "country": "DO",
    "name": "Bajos de Haina",
    "lat": "18.41538",
    "lng": "-70.03317"
  },
  {
    "country": "DO",
    "name": "Baitoa",
    "lat": "19.32512",
    "lng": "-70.70357"
  },
  {
    "country": "DO",
    "name": "Azua",
    "lat": "18.45319",
    "lng": "-70.7349"
  },
  {
    "country": "DO",
    "name": "Arroyo Salado",
    "lat": "19.5",
    "lng": "-69.9"
  },
  {
    "country": "DO",
    "name": "Arenoso",
    "lat": "19.18732",
    "lng": "-69.85917"
  },
  {
    "country": "DO",
    "name": "Amina",
    "lat": "19.54813",
    "lng": "-70.99599"
  },
  {
    "country": "DO",
    "name": "Altamira",
    "lat": "19.6773",
    "lng": "-70.84428"
  },
  {
    "country": "DO",
    "name": "Agua Santa del Yuna",
    "lat": "19.15072",
    "lng": "-69.80069"
  },
  {
    "country": "DO",
    "name": "Santo Domingo Oeste",
    "lat": "18.5",
    "lng": "-70"
  },
  {
    "country": "DO",
    "name": "Santo Domingo Este",
    "lat": "18.48847",
    "lng": "-69.85707"
  },
  {
    "country": "DO",
    "name": "Villa La Mata",
    "lat": "19.01667",
    "lng": "-70.26661"
  },
  {
    "country": "DZ",
    "name": "Boumerdas",
    "lat": "36.76639",
    "lng": "3.47717"
  },
  {
    "country": "DZ",
    "name": "Zeribet el Oued",
    "lat": "34.68284",
    "lng": "6.51109"
  },
  {
    "country": "DZ",
    "name": "Zeralda",
    "lat": "36.71169",
    "lng": "2.84244"
  },
  {
    "country": "DZ",
    "name": "Zemoura",
    "lat": "35.72251",
    "lng": "0.75509"
  },
  {
    "country": "DZ",
    "name": "Touggourt",
    "lat": "33.10527",
    "lng": "6.05796"
  },
  {
    "country": "DZ",
    "name": "Tolga",
    "lat": "34.72224",
    "lng": "5.37845"
  },
  {
    "country": "DZ",
    "name": "Tlemcen",
    "lat": "34.87833",
    "lng": "-1.315"
  },
  {
    "country": "DZ",
    "name": "Tizi Rached",
    "lat": "36.67176",
    "lng": "4.19176"
  },
  {
    "country": "DZ",
    "name": "Tizi Ouzou",
    "lat": "36.71182",
    "lng": "4.04591"
  },
  {
    "country": "DZ",
    "name": "Tizi-n-Tleta",
    "lat": "36.54569",
    "lng": "4.05712"
  },
  {
    "country": "DZ",
    "name": "Tizi Gheniff",
    "lat": "36.58839",
    "lng": "3.77445"
  },
  {
    "country": "DZ",
    "name": "Tissemsilt",
    "lat": "35.60722",
    "lng": "1.81081"
  },
  {
    "country": "DZ",
    "name": "Tirmitine",
    "lat": "36.65393",
    "lng": "3.98143"
  },
  {
    "country": "DZ",
    "name": "Tipasa",
    "lat": "36.58972",
    "lng": "2.4475"
  },
  {
    "country": "DZ",
    "name": "Tindouf",
    "lat": "27.67111",
    "lng": "-8.14743"
  },
  {
    "country": "DZ",
    "name": "Timizart",
    "lat": "36.8",
    "lng": "4.26667"
  },
  {
    "country": "DZ",
    "name": "Timimoun",
    "lat": "29.26388",
    "lng": "0.23098"
  },
  {
    "country": "DZ",
    "name": "el hed",
    "lat": "36.65",
    "lng": "4.77361"
  },
  {
    "country": "DZ",
    "name": "Tiaret",
    "lat": "35.37103",
    "lng": "1.31699"
  },
  {
    "country": "DZ",
    "name": "Theniet el Had",
    "lat": "35.87111",
    "lng": "2.02806"
  },
  {
    "country": "DZ",
    "name": "Thenia",
    "lat": "36.72544",
    "lng": "3.55665"
  },
  {
    "country": "DZ",
    "name": "Telerghma",
    "lat": "36.11653",
    "lng": "6.35434"
  },
  {
    "country": "DZ",
    "name": "Tébessa",
    "lat": "35.40417",
    "lng": "8.12417"
  },
  {
    "country": "DZ",
    "name": "Tebesbest",
    "lat": "33.11667",
    "lng": "6.08333"
  },
  {
    "country": "DZ",
    "name": "Tazoult-Lambese",
    "lat": "35.48171",
    "lng": "6.26074"
  },
  {
    "country": "DZ",
    "name": "Tamanrasset",
    "lat": "22.785",
    "lng": "5.52278"
  },
  {
    "country": "DZ",
    "name": "Tamalous",
    "lat": "36.83763",
    "lng": "6.64018"
  },
  {
    "country": "DZ",
    "name": "Tadmaït",
    "lat": "36.74413",
    "lng": "3.90045"
  },
  {
    "country": "DZ",
    "name": "Sour el Ghozlane",
    "lat": "36.14766",
    "lng": "3.69123"
  },
  {
    "country": "DZ",
    "name": "Souma",
    "lat": "36.51833",
    "lng": "2.90528"
  },
  {
    "country": "DZ",
    "name": "Lardjem",
    "lat": "35.74922",
    "lng": "1.54778"
  },
  {
    "country": "DZ",
    "name": "Souk Ahras",
    "lat": "36.28639",
    "lng": "7.95111"
  },
  {
    "country": "DZ",
    "name": "Sougueur",
    "lat": "35.18568",
    "lng": "1.49612"
  },
  {
    "country": "DZ",
    "name": "Skikda",
    "lat": "36.87617",
    "lng": "6.90921"
  },
  {
    "country": "DZ",
    "name": "Sig",
    "lat": "35.52832",
    "lng": "-0.19369"
  },
  {
    "country": "DZ",
    "name": "Sidi Okba",
    "lat": "34.74512",
    "lng": "5.89833"
  },
  {
    "country": "DZ",
    "name": "Sidi Moussa",
    "lat": "36.60637",
    "lng": "3.08783"
  },
  {
    "country": "DZ",
    "name": "Sidi Mérouane",
    "lat": "36.52056",
    "lng": "6.26111"
  },
  {
    "country": "DZ",
    "name": "Sidi Khaled",
    "lat": "34.387",
    "lng": "4.98785"
  },
  {
    "country": "DZ",
    "name": "Sidi ech Chahmi",
    "lat": "35.65903",
    "lng": "-0.52168"
  },
  {
    "country": "DZ",
    "name": "Sidi Bel Abbès",
    "lat": "35.18994",
    "lng": "-0.63085"
  },
  {
    "country": "DZ",
    "name": "Sidi Amrane",
    "lat": "33.49885",
    "lng": "6.00803"
  },
  {
    "country": "DZ",
    "name": "Sidi Akkacha",
    "lat": "36.46472",
    "lng": "1.30258"
  },
  {
    "country": "DZ",
    "name": "Sidi Aïssa",
    "lat": "35.88548",
    "lng": "3.77236"
  },
  {
    "country": "DZ",
    "name": "Sidi Abdelli",
    "lat": "35.06937",
    "lng": "-1.13706"
  },
  {
    "country": "DZ",
    "name": "Sfizef",
    "lat": "35.23464",
    "lng": "-0.24435"
  },
  {
    "country": "DZ",
    "name": "Sétif",
    "lat": "36.19112",
    "lng": "5.41373"
  },
  {
    "country": "DZ",
    "name": "Sedrata",
    "lat": "36.12868",
    "lng": "7.53376"
  },
  {
    "country": "DZ",
    "name": "Seddouk",
    "lat": "36.54722",
    "lng": "4.68611"
  },
  {
    "country": "DZ",
    "name": "Sebdou",
    "lat": "34.63703",
    "lng": "-1.33143"
  },
  {
    "country": "DZ",
    "name": "Saoula",
    "lat": "36.70456",
    "lng": "3.02462"
  },
  {
    "country": "DZ",
    "name": "Salah Bey",
    "lat": "35.85451",
    "lng": "5.29053"
  },
  {
    "country": "DZ",
    "name": "Saïda",
    "lat": "34.83033",
    "lng": "0.15171"
  },
  {
    "country": "DZ",
    "name": "Rouissat",
    "lat": "31.92427",
    "lng": "5.35018"
  },
  {
    "country": "DZ",
    "name": "Rouiba",
    "lat": "36.73829",
    "lng": "3.28079"
  },
  {
    "country": "DZ",
    "name": "Rouached",
    "lat": "36.45774",
    "lng": "6.04267"
  },
  {
    "country": "DZ",
    "name": "Robbah",
    "lat": "33.27967",
    "lng": "6.90984"
  },
  {
    "country": "DZ",
    "name": "Remchi",
    "lat": "35.06196",
    "lng": "-1.43362"
  },
  {
    "country": "DZ",
    "name": "Relizane",
    "lat": "35.73734",
    "lng": "0.55599"
  },
  {
    "country": "DZ",
    "name": "Reguiba",
    "lat": "33.56391",
    "lng": "6.70326"
  },
  {
    "country": "DZ",
    "name": "Reghaïa",
    "lat": "36.73587",
    "lng": "3.34018"
  },
  {
    "country": "DZ",
    "name": "Reggane",
    "lat": "26.71576",
    "lng": "0.1714"
  },
  {
    "country": "DZ",
    "name": "Râs el Oued",
    "lat": "35.9441",
    "lng": "5.03107"
  },
  {
    "country": "DZ",
    "name": "Râs el Aïoun",
    "lat": "35.67384",
    "lng": "5.6453"
  },
  {
    "country": "DZ",
    "name": "Oum el Bouaghi",
    "lat": "35.87541",
    "lng": "7.11353"
  },
  {
    "country": "DZ",
    "name": "Oumache",
    "lat": "34.69292",
    "lng": "5.68092"
  },
  {
    "country": "DZ",
    "name": "Ouled Moussa",
    "lat": "36.68394",
    "lng": "3.36661"
  },
  {
    "country": "DZ",
    "name": "Ouled Mimoun",
    "lat": "34.90472",
    "lng": "-1.03394"
  },
  {
    "country": "DZ",
    "name": "Oued Sly",
    "lat": "36.10124",
    "lng": "1.19949"
  },
  {
    "country": "DZ",
    "name": "Oued Rhiou",
    "lat": "35.96124",
    "lng": "0.91896"
  },
  {
    "country": "DZ",
    "name": "Oued Fodda",
    "lat": "36.18503",
    "lng": "1.53299"
  },
  {
    "country": "DZ",
    "name": "Oued el Alleug",
    "lat": "36.55528",
    "lng": "2.79028"
  },
  {
    "country": "DZ",
    "name": "Oued el Abtal",
    "lat": "35.45595",
    "lng": "0.68778"
  },
  {
    "country": "DZ",
    "name": "Ouargla",
    "lat": "31.94932",
    "lng": "5.32502"
  },
  {
    "country": "DZ",
    "name": "Oran",
    "lat": "35.69906",
    "lng": "-0.63588"
  },
  {
    "country": "DZ",
    "name": "Nedroma",
    "lat": "35.01361",
    "lng": "-1.74799"
  },
  {
    "country": "DZ",
    "name": "Naciria",
    "lat": "36.74625",
    "lng": "3.83163"
  },
  {
    "country": "DZ",
    "name": "Naama",
    "lat": "33.26667",
    "lng": "-0.31667"
  },
  {
    "country": "DZ",
    "name": "M’Sila",
    "lat": "35.70583",
    "lng": "4.54194"
  },
  {
    "country": "DZ",
    "name": "Mouzaïa",
    "lat": "36.46695",
    "lng": "2.68991"
  },
  {
    "country": "DZ",
    "name": "Mostaganem",
    "lat": "35.93115",
    "lng": "0.08918"
  },
  {
    "country": "DZ",
    "name": "Mila",
    "lat": "36.45028",
    "lng": "6.26444"
  },
  {
    "country": "DZ",
    "name": "Metlili Chaamba",
    "lat": "32.26667",
    "lng": "3.63333"
  },
  {
    "country": "DZ",
    "name": "Messaad",
    "lat": "34.15429",
    "lng": "3.50309"
  },
  {
    "country": "DZ",
    "name": "Meskiana",
    "lat": "35.63058",
    "lng": "7.66606"
  },
  {
    "country": "DZ",
    "name": "Mers el Kebir",
    "lat": "35.7279",
    "lng": "-0.7081"
  },
  {
    "country": "DZ",
    "name": "Merouana",
    "lat": "35.63106",
    "lng": "5.91186"
  },
  {
    "country": "DZ",
    "name": "Melouza",
    "lat": "35.97999",
    "lng": "4.18665"
  },
  {
    "country": "DZ",
    "name": "Mekla",
    "lat": "36.68178",
    "lng": "4.26378"
  },
  {
    "country": "DZ",
    "name": "Mehdia daira de meghila",
    "lat": "35.43058",
    "lng": "1.75714"
  },
  {
    "country": "DZ",
    "name": "Megarine",
    "lat": "33.19195",
    "lng": "6.08695"
  },
  {
    "country": "DZ",
    "name": "Meftah",
    "lat": "36.6204",
    "lng": "3.22248"
  },
  {
    "country": "DZ",
    "name": "Médéa",
    "lat": "36.26417",
    "lng": "2.75393"
  },
  {
    "country": "DZ",
    "name": "Mazouna",
    "lat": "36.12232",
    "lng": "0.89865"
  },
  {
    "country": "DZ",
    "name": "Mascara",
    "lat": "35.39664",
    "lng": "0.14027"
  },
  {
    "country": "DZ",
    "name": "Mansourah",
    "lat": "36.08725",
    "lng": "4.45192"
  },
  {
    "country": "DZ",
    "name": "Mansoûra",
    "lat": "34.86158",
    "lng": "-1.33935"
  },
  {
    "country": "DZ",
    "name": "Makouda",
    "lat": "36.78567",
    "lng": "4.06273"
  },
  {
    "country": "DZ",
    "name": "L’Arbaa Naït Irathen",
    "lat": "36.63112",
    "lng": "4.19864"
  },
  {
    "country": "DZ",
    "name": "Larbaâ",
    "lat": "36.56471",
    "lng": "3.15434"
  },
  {
    "country": "DZ",
    "name": "Lakhdaria",
    "lat": "36.56463",
    "lng": "3.5933"
  },
  {
    "country": "DZ",
    "name": "Laghouat",
    "lat": "33.8",
    "lng": "2.86514"
  },
  {
    "country": "DZ",
    "name": "Ksar el Boukhari",
    "lat": "35.88889",
    "lng": "2.74905"
  },
  {
    "country": "DZ",
    "name": "Ksar Chellala",
    "lat": "35.21222",
    "lng": "2.31889"
  },
  {
    "country": "DZ",
    "name": "Kolea",
    "lat": "36.63888",
    "lng": "2.76845"
  },
  {
    "country": "DZ",
    "name": "Khenchela",
    "lat": "35.43583",
    "lng": "7.14333"
  },
  {
    "country": "DZ",
    "name": "Khemis Miliana",
    "lat": "36.26104",
    "lng": "2.22015"
  },
  {
    "country": "DZ",
    "name": "Khemis el Khechna",
    "lat": "36.64997",
    "lng": "3.3308"
  },
  {
    "country": "DZ",
    "name": "Kerkera",
    "lat": "36.92917",
    "lng": "6.58556"
  },
  {
    "country": "DZ",
    "name": "Jijel",
    "lat": "36.82055",
    "lng": "5.76671"
  },
  {
    "country": "DZ",
    "name": "Djidiouia",
    "lat": "35.92989",
    "lng": "0.82871"
  },
  {
    "country": "DZ",
    "name": "Isser",
    "lat": "36.71859",
    "lng": "3.66924"
  },
  {
    "country": "DZ",
    "name": "I-n-Salah",
    "lat": "27.19351",
    "lng": "2.46069"
  },
  {
    "country": "DZ",
    "name": "Illizi",
    "lat": "26.48333",
    "lng": "8.46667"
  },
  {
    "country": "DZ",
    "name": "Ighram",
    "lat": "36.46295",
    "lng": "4.50532"
  },
  {
    "country": "DZ",
    "name": "Hennaya",
    "lat": "34.95139",
    "lng": "-1.36806"
  },
  {
    "country": "DZ",
    "name": "Héliopolis",
    "lat": "36.50361",
    "lng": "7.44278"
  },
  {
    "country": "DZ",
    "name": "Hassi Messaoud",
    "lat": "31.68041",
    "lng": "6.07286"
  },
  {
    "country": "DZ",
    "name": "Hammamet",
    "lat": "35.44862",
    "lng": "7.95184"
  },
  {
    "country": "DZ",
    "name": "Hammam Bou Hadjar",
    "lat": "35.37889",
    "lng": "-0.96778"
  },
  {
    "country": "DZ",
    "name": "Hamma Bouziane",
    "lat": "36.41205",
    "lng": "6.59603"
  },
  {
    "country": "DZ",
    "name": "Hadjout",
    "lat": "36.51257",
    "lng": "2.41382"
  },
  {
    "country": "DZ",
    "name": "Guelma",
    "lat": "36.46214",
    "lng": "7.42608"
  },
  {
    "country": "DZ",
    "name": "Ghardaïa",
    "lat": "32.49094",
    "lng": "3.67347"
  },
  {
    "country": "DZ",
    "name": "Frenda",
    "lat": "35.06544",
    "lng": "1.04945"
  },
  {
    "country": "DZ",
    "name": "Freha",
    "lat": "36.75234",
    "lng": "4.3155"
  },
  {
    "country": "DZ",
    "name": "Feraoun",
    "lat": "36.56041",
    "lng": "4.85454"
  },
  {
    "country": "DZ",
    "name": "Es Senia",
    "lat": "35.64779",
    "lng": "-0.62397"
  },
  {
    "country": "DZ",
    "name": "El Tarf",
    "lat": "36.7672",
    "lng": "8.31377"
  },
  {
    "country": "DZ",
    "name": "El Oued",
    "lat": "33.35608",
    "lng": "6.86319"
  },
  {
    "country": "DZ",
    "name": "El Malah",
    "lat": "35.39137",
    "lng": "-1.09238"
  },
  {
    "country": "DZ",
    "name": "El Kseur",
    "lat": "36.67942",
    "lng": "4.8555"
  },
  {
    "country": "DZ",
    "name": "El Khroub",
    "lat": "36.26333",
    "lng": "6.69361"
  },
  {
    "country": "DZ",
    "name": "El Kala",
    "lat": "36.89556",
    "lng": "8.44333"
  },
  {
    "country": "DZ",
    "name": "El Idrissia",
    "lat": "34.44542",
    "lng": "2.52749"
  },
  {
    "country": "DZ",
    "name": "El Hadjira",
    "lat": "32.61336",
    "lng": "5.51259"
  },
  {
    "country": "DZ",
    "name": "El Hadjar",
    "lat": "36.80377",
    "lng": "7.73684"
  },
  {
    "country": "DZ",
    "name": "El Eulma",
    "lat": "36.15281",
    "lng": "5.69016"
  },
  {
    "country": "DZ",
    "name": "El Bayadh",
    "lat": "33.68318",
    "lng": "1.01927"
  },
  {
    "country": "DZ",
    "name": "El Attaf",
    "lat": "36.22393",
    "lng": "1.67187"
  },
  {
    "country": "DZ",
    "name": "Chlef",
    "lat": "36.16525",
    "lng": "1.33452"
  },
  {
    "country": "DZ",
    "name": "El Aouinet",
    "lat": "35.86691",
    "lng": "7.88673"
  },
  {
    "country": "DZ",
    "name": "El Amria",
    "lat": "35.52439",
    "lng": "-1.01577"
  },
  {
    "country": "DZ",
    "name": "El Affroun",
    "lat": "36.4701",
    "lng": "2.62528"
  },
  {
    "country": "DZ",
    "name": "El Achir",
    "lat": "36.06386",
    "lng": "4.62744"
  },
  {
    "country": "DZ",
    "name": "El Abiodh Sidi Cheikh",
    "lat": "32.893",
    "lng": "0.54839"
  },
  {
    "country": "DZ",
    "name": "El Abadia",
    "lat": "36.26951",
    "lng": "1.68609"
  },
  {
    "country": "DZ",
    "name": "Ech Chettia",
    "lat": "36.19591",
    "lng": "1.25537"
  },
  {
    "country": "DZ",
    "name": "Drean",
    "lat": "36.68482",
    "lng": "7.75111"
  },
  {
    "country": "DZ",
    "name": "Draa el Mizan",
    "lat": "36.53628",
    "lng": "3.8334"
  },
  {
    "country": "DZ",
    "name": "Draa Ben Khedda",
    "lat": "36.73436",
    "lng": "3.96223"
  },
  {
    "country": "DZ",
    "name": "Douera",
    "lat": "36.67",
    "lng": "2.94444"
  },
  {
    "country": "DZ",
    "name": "Djelfa",
    "lat": "34.67279",
    "lng": "3.263"
  },
  {
    "country": "DZ",
    "name": "Djamaa",
    "lat": "33.53388",
    "lng": "5.99306"
  },
  {
    "country": "DZ",
    "name": "Didouche Mourad",
    "lat": "36.4525",
    "lng": "6.63639"
  },
  {
    "country": "DZ",
    "name": "Dellys",
    "lat": "36.91716",
    "lng": "3.91311"
  },
  {
    "country": "DZ",
    "name": "Debila",
    "lat": "33.51667",
    "lng": "6.95"
  },
  {
    "country": "DZ",
    "name": "Dar el Beïda",
    "lat": "36.71333",
    "lng": "3.2125"
  },
  {
    "country": "DZ",
    "name": "Dar Chioukh",
    "lat": "34.89638",
    "lng": "3.48543"
  },
  {
    "country": "DZ",
    "name": "Constantine",
    "lat": "36.365",
    "lng": "6.61472"
  },
  {
    "country": "DZ",
    "name": "Chorfa",
    "lat": "36.36505",
    "lng": "4.32636"
  },
  {
    "country": "DZ",
    "name": "Chiffa",
    "lat": "36.46293",
    "lng": "2.73873"
  },
  {
    "country": "DZ",
    "name": "Chetouane",
    "lat": "34.92129",
    "lng": "-1.29512"
  },
  {
    "country": "DZ",
    "name": "Cheria",
    "lat": "35.27306",
    "lng": "7.75194"
  },
  {
    "country": "DZ",
    "name": "Cheraga",
    "lat": "36.76775",
    "lng": "2.95924"
  },
  {
    "country": "DZ",
    "name": "Chemini",
    "lat": "36.6",
    "lng": "4.61667"
  },
  {
    "country": "DZ",
    "name": "Chelghoum el Aïd",
    "lat": "36.16286",
    "lng": "6.16651"
  },
  {
    "country": "DZ",
    "name": "Chebli",
    "lat": "36.57722",
    "lng": "3.00917"
  },
  {
    "country": "DZ",
    "name": "Charef",
    "lat": "34.62098",
    "lng": "2.79503"
  },
  {
    "country": "DZ",
    "name": "Chabet el Ameur",
    "lat": "36.63709",
    "lng": "3.69474"
  },
  {
    "country": "DZ",
    "name": "Brezina",
    "lat": "33.09892",
    "lng": "1.26082"
  },
  {
    "country": "DZ",
    "name": "Bou Tlelis",
    "lat": "35.57272",
    "lng": "-0.8996"
  },
  {
    "country": "DZ",
    "name": "Boumagueur",
    "lat": "35.5052",
    "lng": "5.5525"
  },
  {
    "country": "DZ",
    "name": "Boumahra Ahmed",
    "lat": "36.45833",
    "lng": "7.51389"
  },
  {
    "country": "DZ",
    "name": "Boukadir",
    "lat": "36.06629",
    "lng": "1.12602"
  },
  {
    "country": "DZ",
    "name": "Bou Ismaïl",
    "lat": "36.64262",
    "lng": "2.69007"
  },
  {
    "country": "DZ",
    "name": "Bouïra",
    "lat": "36.37489",
    "lng": "3.902"
  },
  {
    "country": "DZ",
    "name": "Bouinan",
    "lat": "36.53167",
    "lng": "2.99194"
  },
  {
    "country": "DZ",
    "name": "Bou Hanifia el Hamamat",
    "lat": "35.31473",
    "lng": "-0.05037"
  },
  {
    "country": "DZ",
    "name": "Bougara",
    "lat": "36.54178",
    "lng": "3.081"
  },
  {
    "country": "DZ",
    "name": "Bougaa",
    "lat": "36.33293",
    "lng": "5.08843"
  },
  {
    "country": "DZ",
    "name": "Boufarik",
    "lat": "36.57413",
    "lng": "2.91214"
  },
  {
    "country": "DZ",
    "name": "Boudouaou",
    "lat": "36.72735",
    "lng": "3.40995"
  },
  {
    "country": "DZ",
    "name": "Boudjima",
    "lat": "36.80218",
    "lng": "4.15187"
  },
  {
    "country": "DZ",
    "name": "Boû Arfa",
    "lat": "36.46298",
    "lng": "2.81464"
  },
  {
    "country": "DZ",
    "name": "Bordj Zemoura",
    "lat": "36.27462",
    "lng": "4.85668"
  },
  {
    "country": "DZ",
    "name": "Bordj Ghdir",
    "lat": "35.90111",
    "lng": "4.89806"
  },
  {
    "country": "DZ",
    "name": "Bordj el Kiffan",
    "lat": "36.74871",
    "lng": "3.19249"
  },
  {
    "country": "DZ",
    "name": "Bordj Bou Arreridj",
    "lat": "36.07321",
    "lng": "4.76108"
  },
  {
    "country": "DZ",
    "name": "Boghni",
    "lat": "36.54222",
    "lng": "3.95306"
  },
  {
    "country": "DZ",
    "name": "Blida",
    "lat": "36.47004",
    "lng": "2.8277"
  },
  {
    "country": "DZ",
    "name": "Biskra",
    "lat": "34.85038",
    "lng": "5.72805"
  },
  {
    "country": "DZ",
    "name": "Birkhadem",
    "lat": "36.71499",
    "lng": "3.05002"
  },
  {
    "country": "DZ",
    "name": "Birine",
    "lat": "35.635",
    "lng": "3.225"
  },
  {
    "country": "DZ",
    "name": "Bir el Djir",
    "lat": "35.72",
    "lng": "-0.545"
  },
  {
    "country": "DZ",
    "name": "Bir el Ater",
    "lat": "34.74488",
    "lng": "8.06024"
  },
  {
    "country": "DZ",
    "name": "Besbes",
    "lat": "36.70222",
    "lng": "7.84722"
  },
  {
    "country": "DZ",
    "name": "Berrouaghia",
    "lat": "36.13516",
    "lng": "2.91085"
  },
  {
    "country": "DZ",
    "name": "Berriane",
    "lat": "32.82648",
    "lng": "3.76689"
  },
  {
    "country": "DZ",
    "name": "Berrahal",
    "lat": "36.83528",
    "lng": "7.45333"
  },
  {
    "country": "DZ",
    "name": "Bensekrane",
    "lat": "35.07465",
    "lng": "-1.22431"
  },
  {
    "country": "DZ",
    "name": "Ben Mehidi",
    "lat": "36.76967",
    "lng": "7.90641"
  },
  {
    "country": "DZ",
    "name": "Beni Saf",
    "lat": "35.30099",
    "lng": "-1.38226"
  },
  {
    "country": "DZ",
    "name": "Beni Mester",
    "lat": "34.87045",
    "lng": "-1.42319"
  },
  {
    "country": "DZ",
    "name": "Beni Mered",
    "lat": "36.52389",
    "lng": "2.86131"
  },
  {
    "country": "DZ",
    "name": "Beni Douala",
    "lat": "36.61954",
    "lng": "4.08282"
  },
  {
    "country": "DZ",
    "name": "Beni Amrane",
    "lat": "36.66774",
    "lng": "3.59115"
  },
  {
    "country": "DZ",
    "name": "Bejaïa",
    "lat": "36.75587",
    "lng": "5.08433"
  },
  {
    "country": "DZ",
    "name": "Béchar",
    "lat": "31.61667",
    "lng": "-2.21667"
  },
  {
    "country": "DZ",
    "name": "Batna",
    "lat": "35.55597",
    "lng": "6.17414"
  },
  {
    "country": "DZ",
    "name": "Barika",
    "lat": "35.38901",
    "lng": "5.36584"
  },
  {
    "country": "DZ",
    "name": "Barbacha",
    "lat": "36.56667",
    "lng": "4.96667"
  },
  {
    "country": "DZ",
    "name": "Baraki",
    "lat": "36.66655",
    "lng": "3.09606"
  },
  {
    "country": "DZ",
    "name": "Bab Ezzouar",
    "lat": "36.72615",
    "lng": "3.18291"
  },
  {
    "country": "DZ",
    "name": "Azzaba",
    "lat": "36.73944",
    "lng": "7.10528"
  },
  {
    "country": "DZ",
    "name": "Azazga",
    "lat": "36.74472",
    "lng": "4.37222"
  },
  {
    "country": "DZ",
    "name": "Arris",
    "lat": "35.25881",
    "lng": "6.34706"
  },
  {
    "country": "DZ",
    "name": "Arhribs",
    "lat": "36.79361",
    "lng": "4.31158"
  },
  {
    "country": "DZ",
    "name": "Arbatache",
    "lat": "36.63773",
    "lng": "3.37127"
  },
  {
    "country": "DZ",
    "name": "Aoulef",
    "lat": "26.96667",
    "lng": "1.08333"
  },
  {
    "country": "DZ",
    "name": "Annaba",
    "lat": "36.9",
    "lng": "7.76667"
  },
  {
    "country": "DZ",
    "name": "Ammi Moussa",
    "lat": "35.86781",
    "lng": "1.11143"
  },
  {
    "country": "DZ",
    "name": "Amizour",
    "lat": "36.64022",
    "lng": "4.90131"
  },
  {
    "country": "DZ",
    "name": "Algiers",
    "lat": "36.73225",
    "lng": "3.08746"
  },
  {
    "country": "DZ",
    "name": "Akbou",
    "lat": "36.4575",
    "lng": "4.53494"
  },
  {
    "country": "DZ",
    "name": "Aïn Touta",
    "lat": "35.37675",
    "lng": "5.90001"
  },
  {
    "country": "DZ",
    "name": "Aïn Temouchent",
    "lat": "35.29749",
    "lng": "-1.14037"
  },
  {
    "country": "DZ",
    "name": "Aïn Taya",
    "lat": "36.79333",
    "lng": "3.28694"
  },
  {
    "country": "DZ",
    "name": "Aïn Smara",
    "lat": "36.2674",
    "lng": "6.50135"
  },
  {
    "country": "DZ",
    "name": "Aïn Sefra",
    "lat": "32.75",
    "lng": "-0.58333"
  },
  {
    "country": "DZ",
    "name": "Aïn Oussera",
    "lat": "35.45139",
    "lng": "2.90583"
  },
  {
    "country": "DZ",
    "name": "’Aïn Merane",
    "lat": "36.16277",
    "lng": "0.97037"
  },
  {
    "country": "DZ",
    "name": "Aïn Kercha",
    "lat": "35.92472",
    "lng": "6.69528"
  },
  {
    "country": "DZ",
    "name": "Aïn Fakroun",
    "lat": "35.97108",
    "lng": "6.87374"
  },
  {
    "country": "DZ",
    "name": "’Aïn el Turk",
    "lat": "35.74381",
    "lng": "-0.7693"
  },
  {
    "country": "DZ",
    "name": "’Aïn el Melh",
    "lat": "34.84146",
    "lng": "4.16383"
  },
  {
    "country": "DZ",
    "name": "’Aïn el Hammam",
    "lat": "36.56471",
    "lng": "4.30619"
  },
  {
    "country": "DZ",
    "name": "‘Aïn el Hadjel",
    "lat": "35.67003",
    "lng": "3.88153"
  },
  {
    "country": "DZ",
    "name": "’Aïn el Hadjar",
    "lat": "34.75846",
    "lng": "0.14528"
  },
  {
    "country": "DZ",
    "name": "Aïn el Bya",
    "lat": "35.80389",
    "lng": "-0.30178"
  },
  {
    "country": "DZ",
    "name": "’Aïn el Berd",
    "lat": "35.36395",
    "lng": "-0.51279"
  },
  {
    "country": "DZ",
    "name": "’Aïn el Bell",
    "lat": "34.34381",
    "lng": "3.22475"
  },
  {
    "country": "DZ",
    "name": "’Aïn Deheb",
    "lat": "34.84218",
    "lng": "1.54697"
  },
  {
    "country": "DZ",
    "name": "Aïn Defla",
    "lat": "36.26405",
    "lng": "1.9679"
  },
  {
    "country": "DZ",
    "name": "’Aïn Boucif",
    "lat": "35.89123",
    "lng": "3.1585"
  },
  {
    "country": "DZ",
    "name": "Aïn Bessem",
    "lat": "36.29333",
    "lng": "3.67319"
  },
  {
    "country": "DZ",
    "name": "’Aïn Benian",
    "lat": "36.80277",
    "lng": "2.92185"
  },
  {
    "country": "DZ",
    "name": "Aïn Beïda",
    "lat": "35.79639",
    "lng": "7.39278"
  },
  {
    "country": "DZ",
    "name": "Aïn Arnat",
    "lat": "36.18683",
    "lng": "5.31347"
  },
  {
    "country": "DZ",
    "name": "’Aïn Abid",
    "lat": "36.23194",
    "lng": "6.94333"
  },
  {
    "country": "DZ",
    "name": "Aflou",
    "lat": "34.11279",
    "lng": "2.10228"
  },
  {
    "country": "DZ",
    "name": "Adrar",
    "lat": "27.87429",
    "lng": "-0.29388"
  },
  {
    "country": "DZ",
    "name": "Abou el Hassan",
    "lat": "36.41657",
    "lng": "1.19616"
  },
  {
    "country": "DZ",
    "name": "BABOR - VILLE",
    "lat": "36.48994",
    "lng": "5.5393"
  },
  {
    "country": "DZ",
    "name": "Smala",
    "lat": "35.71652",
    "lng": "0.75437"
  },
  {
    "country": "DZ",
    "name": "Djebilet Rosfa",
    "lat": "34.86375",
    "lng": "0.83496"
  },
  {
    "country": "DZ",
    "name": "Ait Yahia",
    "lat": "36.58907",
    "lng": "4.33505"
  },
  {
    "country": "DZ",
    "name": "Sidi Senoussi سيدي سنوسي",
    "lat": "34.99691",
    "lng": "-1.09449"
  },
  {
    "country": "EC",
    "name": "Zaruma",
    "lat": "-3.69132",
    "lng": "-79.61174"
  },
  {
    "country": "EC",
    "name": "Zamora",
    "lat": "-4.06685",
    "lng": "-78.95488"
  },
  {
    "country": "EC",
    "name": "Yantzaza",
    "lat": "-3.83261",
    "lng": "-78.76076"
  },
  {
    "country": "EC",
    "name": "Yaguachi Nuevo",
    "lat": "-2.0968",
    "lng": "-79.69485"
  },
  {
    "country": "EC",
    "name": "Vinces",
    "lat": "-1.55611",
    "lng": "-79.75191"
  },
  {
    "country": "EC",
    "name": "Ventanas",
    "lat": "-1.44158",
    "lng": "-79.45943"
  },
  {
    "country": "EC",
    "name": "Velasco Ibarra",
    "lat": "-1.04376",
    "lng": "-79.63837"
  },
  {
    "country": "EC",
    "name": "Valdez",
    "lat": "1.24917",
    "lng": "-78.98306"
  },
  {
    "country": "EC",
    "name": "Tulcán",
    "lat": "0.81187",
    "lng": "-77.71727"
  },
  {
    "country": "EC",
    "name": "Tosagua",
    "lat": "-0.78679",
    "lng": "-80.23473"
  },
  {
    "country": "EC",
    "name": "Tena",
    "lat": "-0.9938",
    "lng": "-77.81286"
  },
  {
    "country": "EC",
    "name": "Taisha",
    "lat": "-2.33965",
    "lng": "-77.46031"
  },
  {
    "country": "EC",
    "name": "Sucúa",
    "lat": "-2.45866",
    "lng": "-78.17171"
  },
  {
    "country": "EC",
    "name": "Sucre",
    "lat": "-1.27974",
    "lng": "-80.41885"
  },
  {
    "country": "EC",
    "name": "Saquisilí",
    "lat": "-0.8399",
    "lng": "-78.667"
  },
  {
    "country": "EC",
    "name": "San Vicente",
    "lat": "-0.58986",
    "lng": "-80.40806"
  },
  {
    "country": "EC",
    "name": "Santo Domingo de los Colorados",
    "lat": "-0.25305",
    "lng": "-79.17536"
  },
  {
    "country": "EC",
    "name": "Santa Rosa",
    "lat": "-3.44882",
    "lng": "-79.95952"
  },
  {
    "country": "EC",
    "name": "Santa Lucía",
    "lat": "-2.18333",
    "lng": "-80"
  },
  {
    "country": "EC",
    "name": "Santa Elena",
    "lat": "-2.22622",
    "lng": "-80.85873"
  },
  {
    "country": "EC",
    "name": "Santa Clara",
    "lat": "-1.26399",
    "lng": "-77.88739"
  },
  {
    "country": "EC",
    "name": "Santa Ana",
    "lat": "-1.20726",
    "lng": "-80.37132"
  },
  {
    "country": "EC",
    "name": "San Miguel de Salcedo",
    "lat": "-1.04547",
    "lng": "-78.59063"
  },
  {
    "country": "EC",
    "name": "San Miguel",
    "lat": "-1.70884",
    "lng": "-79.04311"
  },
  {
    "country": "EC",
    "name": "San Lorenzo de Esmeraldas",
    "lat": "1.28626",
    "lng": "-78.83514"
  },
  {
    "country": "EC",
    "name": "Sangolquí",
    "lat": "-0.33405",
    "lng": "-78.45217"
  },
  {
    "country": "EC",
    "name": "San Gabriel",
    "lat": "0.59318",
    "lng": "-77.83078"
  },
  {
    "country": "EC",
    "name": "Samborondón",
    "lat": "-1.96276",
    "lng": "-79.72402"
  },
  {
    "country": "EC",
    "name": "Salinas",
    "lat": "-2.21452",
    "lng": "-80.95151"
  },
  {
    "country": "EC",
    "name": "Rosa Zarate",
    "lat": "0.32779",
    "lng": "-79.47407"
  },
  {
    "country": "EC",
    "name": "Rocafuerte",
    "lat": "-0.9236",
    "lng": "-80.44946"
  },
  {
    "country": "EC",
    "name": "Riobamba",
    "lat": "-1.67098",
    "lng": "-78.64712"
  },
  {
    "country": "EC",
    "name": "Quito",
    "lat": "-0.22985",
    "lng": "-78.52495"
  },
  {
    "country": "EC",
    "name": "Quevedo",
    "lat": "-1.02863",
    "lng": "-79.46352"
  },
  {
    "country": "EC",
    "name": "Quero",
    "lat": "-1.38122",
    "lng": "-78.60812"
  },
  {
    "country": "EC",
    "name": "Puyo",
    "lat": "-1.48369",
    "lng": "-78.00257"
  },
  {
    "country": "EC",
    "name": "Pujilí",
    "lat": "-0.95759",
    "lng": "-78.69636"
  },
  {
    "country": "EC",
    "name": "Puerto Villamil",
    "lat": "-0.95542",
    "lng": "-90.96654"
  },
  {
    "country": "EC",
    "name": "Puerto Francisco de Orellana",
    "lat": "-0.46645",
    "lng": "-76.98719"
  },
  {
    "country": "EC",
    "name": "Puerto Bolívar",
    "lat": "-3.26649",
    "lng": "-79.99749"
  },
  {
    "country": "EC",
    "name": "Puerto Baquerizo Moreno",
    "lat": "-0.90172",
    "lng": "-89.61021"
  },
  {
    "country": "EC",
    "name": "Puerto Ayora",
    "lat": "-0.74018",
    "lng": "-90.3138"
  },
  {
    "country": "EC",
    "name": "Portoviejo",
    "lat": "-1.05458",
    "lng": "-80.45445"
  },
  {
    "country": "EC",
    "name": "Portovelo",
    "lat": "-3.72145",
    "lng": "-79.62187"
  },
  {
    "country": "EC",
    "name": "Playas",
    "lat": "-2.63199",
    "lng": "-80.38808"
  },
  {
    "country": "EC",
    "name": "Piñas",
    "lat": "-3.68107",
    "lng": "-79.68083"
  },
  {
    "country": "EC",
    "name": "Pimampiro",
    "lat": "0.39116",
    "lng": "-77.94068"
  },
  {
    "country": "EC",
    "name": "Píllaro",
    "lat": "-1.17414",
    "lng": "-78.54676"
  },
  {
    "country": "EC",
    "name": "Pelileo",
    "lat": "-1.3299",
    "lng": "-78.54341"
  },
  {
    "country": "EC",
    "name": "Pedro Carbo",
    "lat": "-1.81563",
    "lng": "-80.23309"
  },
  {
    "country": "EC",
    "name": "Pedernales",
    "lat": "0.07167",
    "lng": "-80.0525"
  },
  {
    "country": "EC",
    "name": "Pasaje",
    "lat": "-3.32561",
    "lng": "-79.80697"
  },
  {
    "country": "EC",
    "name": "Palora",
    "lat": "-1.70131",
    "lng": "-77.96516"
  },
  {
    "country": "EC",
    "name": "Palestina",
    "lat": "-1.93709",
    "lng": "-79.71396"
  },
  {
    "country": "EC",
    "name": "Palenque",
    "lat": "-1.43795",
    "lng": "-79.75647"
  },
  {
    "country": "EC",
    "name": "Paján",
    "lat": "-1.55238",
    "lng": "-80.42958"
  },
  {
    "country": "EC",
    "name": "Otavalo",
    "lat": "0.23457",
    "lng": "-78.26248"
  },
  {
    "country": "EC",
    "name": "Nulti",
    "lat": "-2.91667",
    "lng": "-78.85"
  },
  {
    "country": "EC",
    "name": "Naranjito",
    "lat": "-2.16671",
    "lng": "-79.4654"
  },
  {
    "country": "EC",
    "name": "Naranjal",
    "lat": "-2.67364",
    "lng": "-79.6183"
  },
  {
    "country": "EC",
    "name": "Muisne",
    "lat": "0.61129",
    "lng": "-80.01863"
  },
  {
    "country": "EC",
    "name": "Montecristi",
    "lat": "-1.04576",
    "lng": "-80.65889"
  },
  {
    "country": "EC",
    "name": "Montalvo",
    "lat": "-2.04934",
    "lng": "-77.00856"
  },
  {
    "country": "EC",
    "name": "Montalvo",
    "lat": "-1.79008",
    "lng": "-79.28759"
  },
  {
    "country": "EC",
    "name": "Milagro",
    "lat": "-2.13404",
    "lng": "-79.59415"
  },
  {
    "country": "EC",
    "name": "Manta",
    "lat": "-0.96212",
    "lng": "-80.71271"
  },
  {
    "country": "EC",
    "name": "Machala",
    "lat": "-3.25861",
    "lng": "-79.96053"
  },
  {
    "country": "EC",
    "name": "Machachi",
    "lat": "-0.51011",
    "lng": "-78.56712"
  },
  {
    "country": "EC",
    "name": "Macas",
    "lat": "-2.30868",
    "lng": "-78.11135"
  },
  {
    "country": "EC",
    "name": "Macará",
    "lat": "-4.38181",
    "lng": "-79.9437"
  },
  {
    "country": "EC",
    "name": "Lomas de Sargentillo",
    "lat": "-1.88333",
    "lng": "-80.08333"
  },
  {
    "country": "EC",
    "name": "Loja",
    "lat": "-3.99313",
    "lng": "-79.20422"
  },
  {
    "country": "EC",
    "name": "Llacao",
    "lat": "-2.86667",
    "lng": "-78.88333"
  },
  {
    "country": "EC",
    "name": "La Unión",
    "lat": "-2.85",
    "lng": "-78.78333"
  },
  {
    "country": "EC",
    "name": "La Troncal",
    "lat": "-2.42355",
    "lng": "-79.33977"
  },
  {
    "country": "EC",
    "name": "Latacunga",
    "lat": "-0.93521",
    "lng": "-78.61554"
  },
  {
    "country": "EC",
    "name": "La Maná",
    "lat": "-0.94094",
    "lng": "-79.22506"
  },
  {
    "country": "EC",
    "name": "La Libertad",
    "lat": "-2.233",
    "lng": "-80.91039"
  },
  {
    "country": "EC",
    "name": "Nueva Loja",
    "lat": "0.086",
    "lng": "-76.89528"
  },
  {
    "country": "EC",
    "name": "Junín",
    "lat": "-0.92777",
    "lng": "-80.20583"
  },
  {
    "country": "EC",
    "name": "Jipijapa",
    "lat": "-1.34872",
    "lng": "-80.57875"
  },
  {
    "country": "EC",
    "name": "Ibarra",
    "lat": "0.35171",
    "lng": "-78.12233"
  },
  {
    "country": "EC",
    "name": "Huaquillas",
    "lat": "-3.47523",
    "lng": "-80.23084"
  },
  {
    "country": "EC",
    "name": "Guayaquil",
    "lat": "-2.19616",
    "lng": "-79.88621"
  },
  {
    "country": "EC",
    "name": "Guaranda",
    "lat": "-1.59263",
    "lng": "-79.00098"
  },
  {
    "country": "EC",
    "name": "Guano",
    "lat": "-1.60789",
    "lng": "-78.63105"
  },
  {
    "country": "EC",
    "name": "Gualaquiza",
    "lat": "-3.40359",
    "lng": "-78.58166"
  },
  {
    "country": "EC",
    "name": "Gualaceo",
    "lat": "-2.89264",
    "lng": "-78.77814"
  },
  {
    "country": "EC",
    "name": "Esmeraldas",
    "lat": "0.9592",
    "lng": "-79.65397"
  },
  {
    "country": "EC",
    "name": "El Triunfo",
    "lat": "-1.93333",
    "lng": "-79.96667"
  },
  {
    "country": "EC",
    "name": "Eloy Alfaro",
    "lat": "-2.17579",
    "lng": "-79.85519"
  },
  {
    "country": "EC",
    "name": "El Ángel",
    "lat": "0.62279",
    "lng": "-77.94003"
  },
  {
    "country": "EC",
    "name": "Cuenca",
    "lat": "-2.90055",
    "lng": "-79.00453"
  },
  {
    "country": "EC",
    "name": "Cube",
    "lat": "0.57364",
    "lng": "-79.64418"
  },
  {
    "country": "EC",
    "name": "Cotacachi",
    "lat": "0.30107",
    "lng": "-78.26428"
  },
  {
    "country": "EC",
    "name": "Coronel Marcelino Maridueña",
    "lat": "-2.20924",
    "lng": "-79.43248"
  },
  {
    "country": "EC",
    "name": "Colimes",
    "lat": "-1.54553",
    "lng": "-80.01165"
  },
  {
    "country": "EC",
    "name": "Chone",
    "lat": "-0.69819",
    "lng": "-80.09361"
  },
  {
    "country": "EC",
    "name": "Celica",
    "lat": "-4.10266",
    "lng": "-79.95665"
  },
  {
    "country": "EC",
    "name": "Cayambe",
    "lat": "0.04084",
    "lng": "-78.14524"
  },
  {
    "country": "EC",
    "name": "Catarama",
    "lat": "-1.57504",
    "lng": "-79.45998"
  },
  {
    "country": "EC",
    "name": "Catamayo",
    "lat": "-3.98652",
    "lng": "-79.35912"
  },
  {
    "country": "EC",
    "name": "Catacocha",
    "lat": "-4.04974",
    "lng": "-79.64944"
  },
  {
    "country": "EC",
    "name": "Cariamanga",
    "lat": "-4.32796",
    "lng": "-79.55554"
  },
  {
    "country": "EC",
    "name": "Cañar",
    "lat": "-2.56062",
    "lng": "-78.9394"
  },
  {
    "country": "EC",
    "name": "Calceta",
    "lat": "-0.84582",
    "lng": "-80.16389"
  },
  {
    "country": "EC",
    "name": "Pampanal de Bolívar",
    "lat": "1.35251",
    "lng": "-78.8936"
  },
  {
    "country": "EC",
    "name": "Boca Suno",
    "lat": "-0.69832",
    "lng": "-77.14083"
  },
  {
    "country": "EC",
    "name": "Baños",
    "lat": "-1.39699",
    "lng": "-78.42289"
  },
  {
    "country": "EC",
    "name": "Balzar",
    "lat": "-1.36501",
    "lng": "-79.90494"
  },
  {
    "country": "EC",
    "name": "Baláo",
    "lat": "-2.911",
    "lng": "-79.81441"
  },
  {
    "country": "EC",
    "name": "Bahía de Caráquez",
    "lat": "-0.59792",
    "lng": "-80.42367"
  },
  {
    "country": "EC",
    "name": "Babahoyo",
    "lat": "-1.80217",
    "lng": "-79.53443"
  },
  {
    "country": "EC",
    "name": "Azogues",
    "lat": "-2.73969",
    "lng": "-78.8486"
  },
  {
    "country": "EC",
    "name": "Atuntaqui",
    "lat": "0.33247",
    "lng": "-78.21371"
  },
  {
    "country": "EC",
    "name": "Archidona",
    "lat": "-0.9095",
    "lng": "-77.80772"
  },
  {
    "country": "EC",
    "name": "Ambato",
    "lat": "-1.24908",
    "lng": "-78.61675"
  },
  {
    "country": "EC",
    "name": "Alfredo Baquerizo Moreno",
    "lat": "-1.91667",
    "lng": "-79.51667"
  },
  {
    "country": "EC",
    "name": "Alausí",
    "lat": "-2.20329",
    "lng": "-78.84714"
  },
  {
    "country": "EC",
    "name": "Gonzalo Pizarro",
    "lat": "0.01674",
    "lng": "-77.37924"
  },
  {
    "country": "EC",
    "name": "Wilfrido Loor Moreira",
    "lat": "-0.35294",
    "lng": "-79.66033"
  },
  {
    "country": "EC",
    "name": "Tutamandahostel",
    "lat": "-0.19727",
    "lng": "-78.4975"
  },
  {
    "country": "EE",
    "name": "Vändra",
    "lat": "58.64806",
    "lng": "25.03611"
  },
  {
    "country": "EE",
    "name": "Võru",
    "lat": "57.83389",
    "lng": "27.01944"
  },
  {
    "country": "EE",
    "name": "Voka",
    "lat": "59.40776",
    "lng": "27.58263"
  },
  {
    "country": "EE",
    "name": "Võhma",
    "lat": "58.62833",
    "lng": "25.54833"
  },
  {
    "country": "EE",
    "name": "Vinni",
    "lat": "59.29583",
    "lng": "26.43222"
  },
  {
    "country": "EE",
    "name": "Viljandi",
    "lat": "58.36389",
    "lng": "25.59"
  },
  {
    "country": "EE",
    "name": "Viiratsi",
    "lat": "58.36",
    "lng": "25.63722"
  },
  {
    "country": "EE",
    "name": "Viimsi",
    "lat": "59.50502",
    "lng": "24.84807"
  },
  {
    "country": "EE",
    "name": "Värska",
    "lat": "57.95806",
    "lng": "27.63806"
  },
  {
    "country": "EE",
    "name": "Vana-Antsla",
    "lat": "57.86611",
    "lng": "26.53222"
  },
  {
    "country": "EE",
    "name": "Valga",
    "lat": "57.77781",
    "lng": "26.0473"
  },
  {
    "country": "EE",
    "name": "Väike-Maarja",
    "lat": "59.12639",
    "lng": "26.25"
  },
  {
    "country": "EE",
    "name": "Vaida",
    "lat": "59.28546",
    "lng": "24.97897"
  },
  {
    "country": "EE",
    "name": "Uulu",
    "lat": "58.28361",
    "lng": "24.58722"
  },
  {
    "country": "EE",
    "name": "Uuemõisa",
    "lat": "58.93944",
    "lng": "23.58944"
  },
  {
    "country": "EE",
    "name": "Ülenurme",
    "lat": "58.3162",
    "lng": "26.72517"
  },
  {
    "country": "EE",
    "name": "Türi",
    "lat": "58.80861",
    "lng": "25.4325"
  },
  {
    "country": "EE",
    "name": "Turba",
    "lat": "59.08306",
    "lng": "24.225"
  },
  {
    "country": "EE",
    "name": "Tõrva",
    "lat": "58.00278",
    "lng": "25.935"
  },
  {
    "country": "EE",
    "name": "Tootsi",
    "lat": "58.57806",
    "lng": "24.7925"
  },
  {
    "country": "EE",
    "name": "Toila",
    "lat": "59.42127",
    "lng": "27.50807"
  },
  {
    "country": "EE",
    "name": "Tehumardi",
    "lat": "58.18027",
    "lng": "22.24646"
  },
  {
    "country": "EE",
    "name": "Tartu",
    "lat": "58.38062",
    "lng": "26.72509"
  },
  {
    "country": "EE",
    "name": "Tapa",
    "lat": "59.26056",
    "lng": "25.95861"
  },
  {
    "country": "EE",
    "name": "Tamsalu",
    "lat": "59.15861",
    "lng": "26.11528"
  },
  {
    "country": "EE",
    "name": "Tallinn",
    "lat": "59.43696",
    "lng": "24.75353"
  },
  {
    "country": "EE",
    "name": "Taebla",
    "lat": "58.95389",
    "lng": "23.75222"
  },
  {
    "country": "EE",
    "name": "Tabasalu",
    "lat": "59.42607",
    "lng": "24.5533"
  },
  {
    "country": "EE",
    "name": "Suure-Jaani",
    "lat": "58.53611",
    "lng": "25.47056"
  },
  {
    "country": "EE",
    "name": "Sindi",
    "lat": "58.40056",
    "lng": "24.6675"
  },
  {
    "country": "EE",
    "name": "Sillamäe",
    "lat": "59.39697",
    "lng": "27.76331"
  },
  {
    "country": "EE",
    "name": "Sauga",
    "lat": "58.4272",
    "lng": "24.49496"
  },
  {
    "country": "EE",
    "name": "Saue",
    "lat": "59.32258",
    "lng": "24.54967"
  },
  {
    "country": "EE",
    "name": "Särevere",
    "lat": "58.79",
    "lng": "25.42806"
  },
  {
    "country": "EE",
    "name": "Saku",
    "lat": "59.30354",
    "lng": "24.66382"
  },
  {
    "country": "EE",
    "name": "Rummu",
    "lat": "59.53528",
    "lng": "24.79972"
  },
  {
    "country": "EE",
    "name": "Ruhnu",
    "lat": "57.80028",
    "lng": "23.24833"
  },
  {
    "country": "EE",
    "name": "Rõuge",
    "lat": "57.72778",
    "lng": "26.90972"
  },
  {
    "country": "EE",
    "name": "Riisipere",
    "lat": "59.11417",
    "lng": "24.31056"
  },
  {
    "country": "EE",
    "name": "Rapla",
    "lat": "59.00722",
    "lng": "24.79278"
  },
  {
    "country": "EE",
    "name": "Räpina",
    "lat": "58.09806",
    "lng": "27.46361"
  },
  {
    "country": "EE",
    "name": "Rakvere",
    "lat": "59.34639",
    "lng": "26.35583"
  },
  {
    "country": "EE",
    "name": "Rakke",
    "lat": "58.98167",
    "lng": "26.25444"
  },
  {
    "country": "EE",
    "name": "Raasiku",
    "lat": "59.36639",
    "lng": "25.18306"
  },
  {
    "country": "EE",
    "name": "Püssi",
    "lat": "59.36",
    "lng": "27.04972"
  },
  {
    "country": "EE",
    "name": "Puhja",
    "lat": "58.34194",
    "lng": "26.31472"
  },
  {
    "country": "EE",
    "name": "Pringi",
    "lat": "59.53459",
    "lng": "24.79726"
  },
  {
    "country": "EE",
    "name": "Põlva",
    "lat": "58.06028",
    "lng": "27.06944"
  },
  {
    "country": "EE",
    "name": "Põltsamaa",
    "lat": "58.6525",
    "lng": "25.97056"
  },
  {
    "country": "EE",
    "name": "Pärnu-Jaagupi",
    "lat": "58.61052",
    "lng": "24.50689"
  },
  {
    "country": "EE",
    "name": "Pärnu",
    "lat": "58.38588",
    "lng": "24.49711"
  },
  {
    "country": "EE",
    "name": "Paldiski",
    "lat": "59.35667",
    "lng": "24.05306"
  },
  {
    "country": "EE",
    "name": "Pajusti",
    "lat": "59.27444",
    "lng": "26.42333"
  },
  {
    "country": "EE",
    "name": "Paikuse",
    "lat": "58.37917",
    "lng": "24.63444"
  },
  {
    "country": "EE",
    "name": "Paide",
    "lat": "58.88556",
    "lng": "25.55722"
  },
  {
    "country": "EE",
    "name": "Orissaare",
    "lat": "58.55917",
    "lng": "23.08262"
  },
  {
    "country": "EE",
    "name": "Karksi-Nuia",
    "lat": "58.10333",
    "lng": "25.56278"
  },
  {
    "country": "EE",
    "name": "Nõo",
    "lat": "58.27556",
    "lng": "26.5375"
  },
  {
    "country": "EE",
    "name": "Narva-Jõesuu",
    "lat": "59.45889",
    "lng": "28.04083"
  },
  {
    "country": "EE",
    "name": "Narva",
    "lat": "59.37722",
    "lng": "28.19028"
  },
  {
    "country": "EE",
    "name": "Mustvee",
    "lat": "58.84861",
    "lng": "26.93972"
  },
  {
    "country": "EE",
    "name": "Mõisaküla",
    "lat": "58.09222",
    "lng": "25.18639"
  },
  {
    "country": "EE",
    "name": "Märjamaa",
    "lat": "58.90389",
    "lng": "24.43056"
  },
  {
    "country": "EE",
    "name": "Maardu",
    "lat": "59.46529",
    "lng": "24.98215"
  },
  {
    "country": "EE",
    "name": "Luunja",
    "lat": "58.35583",
    "lng": "26.88083"
  },
  {
    "country": "EE",
    "name": "Loo",
    "lat": "59.43123",
    "lng": "24.94949"
  },
  {
    "country": "EE",
    "name": "Loksa",
    "lat": "59.57639",
    "lng": "25.72139"
  },
  {
    "country": "EE",
    "name": "Linaküla",
    "lat": "58.13722",
    "lng": "23.97444"
  },
  {
    "country": "EE",
    "name": "Liiva",
    "lat": "58.60194",
    "lng": "23.24694"
  },
  {
    "country": "EE",
    "name": "Lihula",
    "lat": "58.68139",
    "lng": "23.84528"
  },
  {
    "country": "EE",
    "name": "Kuusalu",
    "lat": "59.44389",
    "lng": "25.44139"
  },
  {
    "country": "EE",
    "name": "Kuressaare",
    "lat": "58.24806",
    "lng": "22.50389"
  },
  {
    "country": "EE",
    "name": "Kurepalu",
    "lat": "58.31861",
    "lng": "26.84083"
  },
  {
    "country": "EE",
    "name": "Kunda",
    "lat": "59.49861",
    "lng": "26.52611"
  },
  {
    "country": "EE",
    "name": "Kunda",
    "lat": "59.48333",
    "lng": "26.53333"
  },
  {
    "country": "EE",
    "name": "Kose",
    "lat": "59.46001",
    "lng": "24.87824"
  },
  {
    "country": "EE",
    "name": "Kose",
    "lat": "59.17889",
    "lng": "25.17306"
  },
  {
    "country": "EE",
    "name": "Kõrveküla",
    "lat": "58.42417",
    "lng": "26.78222"
  },
  {
    "country": "EE",
    "name": "Kohtla-Järve",
    "lat": "59.39861",
    "lng": "27.27306"
  },
  {
    "country": "EE",
    "name": "Kohtla-Nõmme",
    "lat": "59.35167",
    "lng": "27.175"
  },
  {
    "country": "EE",
    "name": "Kohila",
    "lat": "59.16806",
    "lng": "24.7575"
  },
  {
    "country": "EE",
    "name": "Koeru",
    "lat": "58.96306",
    "lng": "26.03083"
  },
  {
    "country": "EE",
    "name": "Kiviõli",
    "lat": "59.35306",
    "lng": "26.97111"
  },
  {
    "country": "EE",
    "name": "Kilingi-Nõmme",
    "lat": "58.15028",
    "lng": "24.96417"
  },
  {
    "country": "EE",
    "name": "Kiili",
    "lat": "59.30775",
    "lng": "24.83776"
  },
  {
    "country": "EE",
    "name": "Keila",
    "lat": "59.30361",
    "lng": "24.41306"
  },
  {
    "country": "EE",
    "name": "Kehtna",
    "lat": "58.93028",
    "lng": "24.87806"
  },
  {
    "country": "EE",
    "name": "Kehra",
    "lat": "59.33611",
    "lng": "25.32111"
  },
  {
    "country": "EE",
    "name": "Kärdla",
    "lat": "58.99778",
    "lng": "22.74917"
  },
  {
    "country": "EE",
    "name": "Kanepi",
    "lat": "57.98306",
    "lng": "26.75639"
  },
  {
    "country": "EE",
    "name": "Kallaste",
    "lat": "58.66312",
    "lng": "27.16164"
  },
  {
    "country": "EE",
    "name": "Kadrina",
    "lat": "59.33472",
    "lng": "26.145"
  },
  {
    "country": "EE",
    "name": "Jüri",
    "lat": "59.35417",
    "lng": "24.89417"
  },
  {
    "country": "EE",
    "name": "Jõhvi",
    "lat": "59.35917",
    "lng": "27.42111"
  },
  {
    "country": "EE",
    "name": "Jõgeva",
    "lat": "58.74667",
    "lng": "26.39389"
  },
  {
    "country": "EE",
    "name": "Järvakandi",
    "lat": "58.77889",
    "lng": "24.82583"
  },
  {
    "country": "EE",
    "name": "Järva-Jaani",
    "lat": "59.03861",
    "lng": "25.88639"
  },
  {
    "country": "EE",
    "name": "Iisaku",
    "lat": "59.10139",
    "lng": "27.30806"
  },
  {
    "country": "EE",
    "name": "Hullo",
    "lat": "58.99004",
    "lng": "23.24441"
  },
  {
    "country": "EE",
    "name": "Haljala",
    "lat": "59.43361",
    "lng": "26.26139"
  },
  {
    "country": "EE",
    "name": "Haapsalu",
    "lat": "58.94306",
    "lng": "23.54139"
  },
  {
    "country": "EE",
    "name": "Haabneeme",
    "lat": "59.51358",
    "lng": "24.82225"
  },
  {
    "country": "EE",
    "name": "Elva",
    "lat": "58.2225",
    "lng": "26.42111"
  },
  {
    "country": "EE",
    "name": "Audru",
    "lat": "58.40861",
    "lng": "24.37389"
  },
  {
    "country": "EE",
    "name": "Aseri",
    "lat": "59.45056",
    "lng": "26.8675"
  },
  {
    "country": "EE",
    "name": "Aruküla",
    "lat": "59.36686",
    "lng": "25.07618"
  },
  {
    "country": "EE",
    "name": "Antsla",
    "lat": "57.82556",
    "lng": "26.54056"
  },
  {
    "country": "EE",
    "name": "Alatskivi",
    "lat": "58.59806",
    "lng": "27.13361"
  },
  {
    "country": "EE",
    "name": "Abja-Paluoja",
    "lat": "58.12528",
    "lng": "25.34972"
  },
  {
    "country": "EE",
    "name": "Vaiatu",
    "lat": "59.35556",
    "lng": "25.99528"
  },
  {
    "country": "EE",
    "name": "Sõmeru",
    "lat": "59.36111",
    "lng": "26.4375"
  },
  {
    "country": "EE",
    "name": "Harku",
    "lat": "59.38641",
    "lng": "24.57176"
  },
  {
    "country": "EE",
    "name": "Laagri",
    "lat": "59.35083",
    "lng": "24.61418"
  },
  {
    "country": "EE",
    "name": "Viimsi",
    "lat": "59.50086",
    "lng": "24.86254"
  },
  {
    "country": "EG",
    "name": "Zefta",
    "lat": "30.7142",
    "lng": "31.24425"
  },
  {
    "country": "EG",
    "name": "Toukh",
    "lat": "30.35394",
    "lng": "31.20071"
  },
  {
    "country": "EG",
    "name": "Tanda",
    "lat": "30.78847",
    "lng": "31.00192"
  },
  {
    "country": "EG",
    "name": "Ţāmiyah",
    "lat": "29.47639",
    "lng": "30.96119"
  },
  {
    "country": "EG",
    "name": "Ţalkhā",
    "lat": "31.0539",
    "lng": "31.37787"
  },
  {
    "country": "EG",
    "name": "Talā",
    "lat": "30.68025",
    "lng": "30.94292"
  },
  {
    "country": "EG",
    "name": "Ţahţā",
    "lat": "26.7693",
    "lng": "31.50214"
  },
  {
    "country": "EG",
    "name": "Sumusţā as Sulţānī",
    "lat": "28.91667",
    "lng": "30.85"
  },
  {
    "country": "EG",
    "name": "Sohag",
    "lat": "26.55695",
    "lng": "31.69478"
  },
  {
    "country": "EG",
    "name": "Siwa Oasis",
    "lat": "29.2032",
    "lng": "25.51965"
  },
  {
    "country": "EG",
    "name": "Sīdī Sālim",
    "lat": "31.27133",
    "lng": "30.78617"
  },
  {
    "country": "EG",
    "name": "Shirbīn",
    "lat": "31.19688",
    "lng": "31.5243"
  },
  {
    "country": "EG",
    "name": "Shibīn al Qanāṭir",
    "lat": "30.31269",
    "lng": "31.32018"
  },
  {
    "country": "EG",
    "name": "Shibīn al Kawm",
    "lat": "30.55258",
    "lng": "31.00904"
  },
  {
    "country": "EG",
    "name": "Sharm el-Sheikh",
    "lat": "27.91582",
    "lng": "34.32995"
  },
  {
    "country": "EG",
    "name": "Samannūd",
    "lat": "30.9616",
    "lng": "31.24069"
  },
  {
    "country": "EG",
    "name": "Samālūţ",
    "lat": "28.31214",
    "lng": "30.71007"
  },
  {
    "country": "EG",
    "name": "Rosetta",
    "lat": "31.39951",
    "lng": "30.41718"
  },
  {
    "country": "EG",
    "name": "Ras Gharib",
    "lat": "28.35831",
    "lng": "33.07829"
  },
  {
    "country": "EG",
    "name": "Rafaḩ",
    "lat": "31.28204",
    "lng": "34.23869"
  },
  {
    "country": "EG",
    "name": "Quwaysinā",
    "lat": "30.56482",
    "lng": "31.15777"
  },
  {
    "country": "EG",
    "name": "Quţūr",
    "lat": "30.97225",
    "lng": "30.95614"
  },
  {
    "country": "EG",
    "name": "Kousa",
    "lat": "25.91407",
    "lng": "32.76362"
  },
  {
    "country": "EG",
    "name": "Qinā",
    "lat": "26.16418",
    "lng": "32.72671"
  },
  {
    "country": "EG",
    "name": "Qaşr al Farāfirah",
    "lat": "27.0568",
    "lng": "27.96979"
  },
  {
    "country": "EG",
    "name": "Qalyūb",
    "lat": "30.17922",
    "lng": "31.2056"
  },
  {
    "country": "EG",
    "name": "Nuwaybi‘a",
    "lat": "29.04681",
    "lng": "34.6634"
  },
  {
    "country": "EG",
    "name": "Naja' Ḥammādī",
    "lat": "26.04949",
    "lng": "32.24142"
  },
  {
    "country": "EG",
    "name": "Minyat an Naşr",
    "lat": "31.12624",
    "lng": "31.64313"
  },
  {
    "country": "EG",
    "name": "Munūf",
    "lat": "30.46597",
    "lng": "30.93199"
  },
  {
    "country": "EG",
    "name": "Maţāy",
    "lat": "28.41899",
    "lng": "30.77924"
  },
  {
    "country": "EG",
    "name": "Mashtūl as Sūq",
    "lat": "30.36056",
    "lng": "31.3776"
  },
  {
    "country": "EG",
    "name": "Mersa Matruh",
    "lat": "31.3529",
    "lng": "27.23725"
  },
  {
    "country": "EG",
    "name": "Marsa Alam",
    "lat": "25.06305",
    "lng": "34.89005"
  },
  {
    "country": "EG",
    "name": "Manfalūţ",
    "lat": "27.3104",
    "lng": "30.97004"
  },
  {
    "country": "EG",
    "name": "Mallawī",
    "lat": "27.7314",
    "lng": "30.84165"
  },
  {
    "country": "EG",
    "name": "Madīnat Sittah Uktūbar",
    "lat": "29.81667",
    "lng": "31.05"
  },
  {
    "country": "EG",
    "name": "Ash Shaykh Zuwayd",
    "lat": "31.2163",
    "lng": "34.11074"
  },
  {
    "country": "EG",
    "name": "Kawm Umbū",
    "lat": "24.47669",
    "lng": "32.94626"
  },
  {
    "country": "EG",
    "name": "Kawm Ḩamādah",
    "lat": "30.76095",
    "lng": "30.69733"
  },
  {
    "country": "EG",
    "name": "Kafr Şaqr",
    "lat": "30.79336",
    "lng": "31.62575"
  },
  {
    "country": "EG",
    "name": "Kafr az Zayyāt",
    "lat": "30.8248",
    "lng": "30.81805"
  },
  {
    "country": "EG",
    "name": "Kafr ash Shaykh",
    "lat": "31.11174",
    "lng": "30.93991"
  },
  {
    "country": "EG",
    "name": "Kafr ad Dawwār",
    "lat": "31.13379",
    "lng": "30.12969"
  },
  {
    "country": "EG",
    "name": "Juhaynah",
    "lat": "26.67319",
    "lng": "31.4976"
  },
  {
    "country": "EG",
    "name": "Jirjā",
    "lat": "26.33826",
    "lng": "31.89161"
  },
  {
    "country": "EG",
    "name": "‘Izbat al Burj",
    "lat": "31.5084",
    "lng": "31.84106"
  },
  {
    "country": "EG",
    "name": "Iţsā",
    "lat": "29.2376",
    "lng": "30.78944"
  },
  {
    "country": "EG",
    "name": "Isnā",
    "lat": "25.29336",
    "lng": "32.55402"
  },
  {
    "country": "EG",
    "name": "Idkū",
    "lat": "31.3073",
    "lng": "30.2981"
  },
  {
    "country": "EG",
    "name": "Idfū",
    "lat": "24.97916",
    "lng": "32.87722"
  },
  {
    "country": "EG",
    "name": "Ibshawāy",
    "lat": "29.35805",
    "lng": "30.68142"
  },
  {
    "country": "EG",
    "name": "Ḩalwān",
    "lat": "29.84144",
    "lng": "31.30084"
  },
  {
    "country": "EG",
    "name": "Hihyā",
    "lat": "30.6713",
    "lng": "31.58801"
  },
  {
    "country": "EG",
    "name": "Ḩawsh ‘Īsá",
    "lat": "30.9128",
    "lng": "30.29019"
  },
  {
    "country": "EG",
    "name": "Fuwwah",
    "lat": "31.20365",
    "lng": "30.54908"
  },
  {
    "country": "EG",
    "name": "Farshūţ",
    "lat": "26.05494",
    "lng": "32.16329"
  },
  {
    "country": "EG",
    "name": "Fāraskūr",
    "lat": "31.32977",
    "lng": "31.71507"
  },
  {
    "country": "EG",
    "name": "Fāqūs",
    "lat": "30.72816",
    "lng": "31.79697"
  },
  {
    "country": "EG",
    "name": "Damietta",
    "lat": "31.41648",
    "lng": "31.81332"
  },
  {
    "country": "EG",
    "name": "Diyarb Najm",
    "lat": "30.75438",
    "lng": "31.44016"
  },
  {
    "country": "EG",
    "name": "Disūq",
    "lat": "31.13259",
    "lng": "30.64784"
  },
  {
    "country": "EG",
    "name": "Dishnā",
    "lat": "26.12467",
    "lng": "32.47598"
  },
  {
    "country": "EG",
    "name": "Dikirnis",
    "lat": "31.08898",
    "lng": "31.59478"
  },
  {
    "country": "EG",
    "name": "Dahab",
    "lat": "28.48208",
    "lng": "34.49505"
  },
  {
    "country": "EG",
    "name": "Dayrūţ",
    "lat": "27.55602",
    "lng": "30.80764"
  },
  {
    "country": "EG",
    "name": "Dayr Mawās",
    "lat": "27.64176",
    "lng": "30.84662"
  },
  {
    "country": "EG",
    "name": "Damanhūr",
    "lat": "31.03408",
    "lng": "30.46823"
  },
  {
    "country": "EG",
    "name": "Būsh",
    "lat": "29.14816",
    "lng": "31.12733"
  },
  {
    "country": "EG",
    "name": "Port Said",
    "lat": "31.25654",
    "lng": "32.28411"
  },
  {
    "country": "EG",
    "name": "Safaga",
    "lat": "26.74906",
    "lng": "33.93891"
  },
  {
    "country": "EG",
    "name": "Bilqās",
    "lat": "31.21452",
    "lng": "31.35798"
  },
  {
    "country": "EG",
    "name": "Bilbays",
    "lat": "30.42039",
    "lng": "31.56223"
  },
  {
    "country": "EG",
    "name": "Basyūn",
    "lat": "30.93976",
    "lng": "30.81338"
  },
  {
    "country": "EG",
    "name": "Banī Suwayf",
    "lat": "29.07441",
    "lng": "31.09785"
  },
  {
    "country": "EG",
    "name": "Banī Mazār",
    "lat": "28.5036",
    "lng": "30.8004"
  },
  {
    "country": "EG",
    "name": "Banhā",
    "lat": "30.45906",
    "lng": "31.17858"
  },
  {
    "country": "EG",
    "name": "Zagazig",
    "lat": "30.58768",
    "lng": "31.502"
  },
  {
    "country": "EG",
    "name": "Awsīm",
    "lat": "30.12303",
    "lng": "31.13571"
  },
  {
    "country": "EG",
    "name": "El-Tor",
    "lat": "28.24168",
    "lng": "33.6222"
  },
  {
    "country": "EG",
    "name": "At Tall al Kabīr",
    "lat": "30.54323",
    "lng": "31.78504"
  },
  {
    "country": "EG",
    "name": "Asyūţ",
    "lat": "27.18096",
    "lng": "31.18368"
  },
  {
    "country": "EG",
    "name": "Aswan",
    "lat": "24.09082",
    "lng": "32.89942"
  },
  {
    "country": "EG",
    "name": "Suez",
    "lat": "29.97371",
    "lng": "32.52627"
  },
  {
    "country": "EG",
    "name": "Aş Şaff",
    "lat": "29.56472",
    "lng": "31.28111"
  },
  {
    "country": "EG",
    "name": "Ash Shuhadā’",
    "lat": "30.59618",
    "lng": "30.89875"
  },
  {
    "country": "EG",
    "name": "Ashmūn",
    "lat": "30.29735",
    "lng": "30.97641"
  },
  {
    "country": "EG",
    "name": "Al Wāsiţah",
    "lat": "29.33778",
    "lng": "31.20556"
  },
  {
    "country": "EG",
    "name": "Luxor",
    "lat": "25.69893",
    "lng": "32.6421"
  },
  {
    "country": "EG",
    "name": "Al Qūşīyah",
    "lat": "27.4402",
    "lng": "30.81841"
  },
  {
    "country": "EG",
    "name": "Al Quşayr",
    "lat": "26.10426",
    "lng": "34.27793"
  },
  {
    "country": "EG",
    "name": "Al Qurayn",
    "lat": "30.61618",
    "lng": "31.73514"
  },
  {
    "country": "EG",
    "name": "Al Qanāyāt",
    "lat": "30.6188",
    "lng": "31.46099"
  },
  {
    "country": "EG",
    "name": "Al Qanāţir al Khayrīyah",
    "lat": "30.19327",
    "lng": "31.13703"
  },
  {
    "country": "EG",
    "name": "Cairo",
    "lat": "30.06263",
    "lng": "31.24967"
  },
  {
    "country": "EG",
    "name": "Al Minyā",
    "lat": "28.10988",
    "lng": "30.7503"
  },
  {
    "country": "EG",
    "name": "Al Maţarīyah",
    "lat": "31.18287",
    "lng": "32.03108"
  },
  {
    "country": "EG",
    "name": "Al Manzalah",
    "lat": "31.15823",
    "lng": "31.936"
  },
  {
    "country": "EG",
    "name": "Al Manşūrah",
    "lat": "31.03637",
    "lng": "31.38069"
  },
  {
    "country": "EG",
    "name": "Al Manshāh",
    "lat": "26.47686",
    "lng": "31.8035"
  },
  {
    "country": "EG",
    "name": "Al Maḩallah al Kubrá",
    "lat": "30.97063",
    "lng": "31.1669"
  },
  {
    "country": "EG",
    "name": "Al Khārijah",
    "lat": "25.45141",
    "lng": "30.54635"
  },
  {
    "country": "EG",
    "name": "Al Khānkah",
    "lat": "30.21035",
    "lng": "31.36812"
  },
  {
    "country": "EG",
    "name": "Giza",
    "lat": "30.00808",
    "lng": "31.21093"
  },
  {
    "country": "EG",
    "name": "Al Jammālīyah",
    "lat": "31.18065",
    "lng": "31.86497"
  },
  {
    "country": "EG",
    "name": "Ismailia",
    "lat": "30.60427",
    "lng": "32.27225"
  },
  {
    "country": "EG",
    "name": "Alexandria",
    "lat": "31.20176",
    "lng": "29.91582"
  },
  {
    "country": "EG",
    "name": "Al Ibrāhīmīyah",
    "lat": "30.71877",
    "lng": "31.56299"
  },
  {
    "country": "EG",
    "name": "Al Ḩawāmidīyah",
    "lat": "29.9",
    "lng": "31.25"
  },
  {
    "country": "EG",
    "name": "Al Ḩāmūl",
    "lat": "31.31146",
    "lng": "31.14766"
  },
  {
    "country": "EG",
    "name": "Hurghada",
    "lat": "27.25738",
    "lng": "33.81291"
  },
  {
    "country": "EG",
    "name": "Al Fayyūm",
    "lat": "29.30995",
    "lng": "30.8418"
  },
  {
    "country": "EG",
    "name": "Al Fashn",
    "lat": "28.82431",
    "lng": "30.89948"
  },
  {
    "country": "EG",
    "name": "Al Bawīţī",
    "lat": "28.34919",
    "lng": "28.86591"
  },
  {
    "country": "EG",
    "name": "Al Balyanā",
    "lat": "26.23568",
    "lng": "32.00347"
  },
  {
    "country": "EG",
    "name": "Al Bājūr",
    "lat": "30.43026",
    "lng": "31.03681"
  },
  {
    "country": "EG",
    "name": "Al Badārī",
    "lat": "26.99257",
    "lng": "31.41554"
  },
  {
    "country": "EG",
    "name": "Al ‘Ayyāţ",
    "lat": "29.61972",
    "lng": "31.2575"
  },
  {
    "country": "EG",
    "name": "Arish",
    "lat": "31.13159",
    "lng": "33.79844"
  },
  {
    "country": "EG",
    "name": "Al ‘Alamayn",
    "lat": "30.83007",
    "lng": "28.95502"
  },
  {
    "country": "EG",
    "name": "Akhmīm",
    "lat": "26.56217",
    "lng": "31.74503"
  },
  {
    "country": "EG",
    "name": "Ajā",
    "lat": "30.94162",
    "lng": "31.29039"
  },
  {
    "country": "EG",
    "name": "Ad Dilinjāt",
    "lat": "30.82791",
    "lng": "30.53633"
  },
  {
    "country": "EG",
    "name": "Abū Tīj",
    "lat": "27.04411",
    "lng": "31.31897"
  },
  {
    "country": "EG",
    "name": "Abu Simbel",
    "lat": "22.3457",
    "lng": "31.61624"
  },
  {
    "country": "EG",
    "name": "Abū Qurqāş",
    "lat": "27.9312",
    "lng": "30.83841"
  },
  {
    "country": "EG",
    "name": "Abū Kabīr",
    "lat": "30.72508",
    "lng": "31.67148"
  },
  {
    "country": "EG",
    "name": "Abū al Maţāmīr",
    "lat": "30.91018",
    "lng": "30.17438"
  },
  {
    "country": "EG",
    "name": "Abnūb",
    "lat": "27.2696",
    "lng": "31.15105"
  },
  {
    "country": "EG",
    "name": "Bi’r al ‘Abd",
    "lat": "31.01887",
    "lng": "33.0098"
  },
  {
    "country": "EG",
    "name": "Az Zarqā",
    "lat": "31.20864",
    "lng": "31.63528"
  },
  {
    "country": "EG",
    "name": "El Gouna",
    "lat": "27.39417",
    "lng": "33.67825"
  },
  {
    "country": "EG",
    "name": "Makadi Bay",
    "lat": "26.99123",
    "lng": "33.89952"
  },
  {
    "country": "EG",
    "name": "Ain Sukhna",
    "lat": "29.60018",
    "lng": "32.31671"
  },
  {
    "country": "EG",
    "name": "New Cairo",
    "lat": "30.03",
    "lng": "31.47"
  },
  {
    "country": "EG",
    "name": "Beheira",
    "lat": "30.51478",
    "lng": "30.34355"
  },
  {
    "country": "EG",
    "name": "Saint Catherine",
    "lat": "28.56191",
    "lng": "33.94934"
  },
  {
    "country": "EG",
    "name": "Munshāt ‘Alī Āghā",
    "lat": "31.15791",
    "lng": "30.70177"
  },
  {
    "country": "EH",
    "name": "Laayoune Plage",
    "lat": "27.09611",
    "lng": "-13.41583"
  },
  {
    "country": "EH",
    "name": "Laayoune",
    "lat": "27.1418",
    "lng": "-13.18797"
  },
  {
    "country": "EH",
    "name": "Dakhla",
    "lat": "23.68477",
    "lng": "-15.95798"
  },
  {
    "country": "ER",
    "name": "Teseney",
    "lat": "15.11",
    "lng": "36.6575"
  },
  {
    "country": "ER",
    "name": "Massawa",
    "lat": "15.60811",
    "lng": "39.47455"
  },
  {
    "country": "ER",
    "name": "Keren",
    "lat": "15.77792",
    "lng": "38.45107"
  },
  {
    "country": "ER",
    "name": "Edd",
    "lat": "13.93088",
    "lng": "41.6938"
  },
  {
    "country": "ER",
    "name": "Dek’emhāre",
    "lat": "15.07",
    "lng": "39.0475"
  },
  {
    "country": "ER",
    "name": "Barentu",
    "lat": "15.10582",
    "lng": "37.59067"
  },
  {
    "country": "ER",
    "name": "Asmara",
    "lat": "15.33805",
    "lng": "38.93184"
  },
  {
    "country": "ER",
    "name": "Assab",
    "lat": "13.00917",
    "lng": "42.73944"
  },
  {
    "country": "ER",
    "name": "Ak’ordat",
    "lat": "15.54798",
    "lng": "37.88291"
  },
  {
    "country": "ER",
    "name": "Mendefera",
    "lat": "14.88722",
    "lng": "38.81528"
  },
  {
    "country": "ER",
    "name": "Adi Keyh",
    "lat": "14.84444",
    "lng": "39.37722"
  },
  {
    "country": "ER",
    "name": "Mai-Mne",
    "lat": "14.55438",
    "lng": "38.50292"
  },
  {
    "country": "ES",
    "name": "Zurgena",
    "lat": "37.34218",
    "lng": "-2.03985"
  },
  {
    "country": "ES",
    "name": "Zújar",
    "lat": "37.54285",
    "lng": "-2.84197"
  },
  {
    "country": "ES",
    "name": "Zuheros",
    "lat": "37.54332",
    "lng": "-4.31531"
  },
  {
    "country": "ES",
    "name": "Zufre",
    "lat": "37.83333",
    "lng": "-6.33333"
  },
  {
    "country": "ES",
    "name": "Zubia",
    "lat": "37.11906",
    "lng": "-3.584"
  },
  {
    "country": "ES",
    "name": "Zorita",
    "lat": "39.28522",
    "lng": "-5.69973"
  },
  {
    "country": "ES",
    "name": "Zarza la Mayor",
    "lat": "39.87692",
    "lng": "-6.86211"
  },
  {
    "country": "ES",
    "name": "Zarza de Montánchez",
    "lat": "39.25756",
    "lng": "-6.03248"
  },
  {
    "country": "ES",
    "name": "Zarza de Alange",
    "lat": "38.81814",
    "lng": "-6.21756"
  },
  {
    "country": "ES",
    "name": "Zarra",
    "lat": "39.09175",
    "lng": "-1.07532"
  },
  {
    "country": "ES",
    "name": "Zalamea la Real",
    "lat": "37.68012",
    "lng": "-6.65977"
  },
  {
    "country": "ES",
    "name": "Zalamea de la Serena",
    "lat": "38.65131",
    "lng": "-5.66063"
  },
  {
    "country": "ES",
    "name": "Zahinos",
    "lat": "38.33135",
    "lng": "-6.95533"
  },
  {
    "country": "ES",
    "name": "Zahara de los Atunes",
    "lat": "36.1369",
    "lng": "-5.84591"
  },
  {
    "country": "ES",
    "name": "Zahara",
    "lat": "36.84055",
    "lng": "-5.39128"
  },
  {
    "country": "ES",
    "name": "Zagra",
    "lat": "37.25561",
    "lng": "-4.16905"
  },
  {
    "country": "ES",
    "name": "Zafra de Záncara",
    "lat": "39.89203",
    "lng": "-2.55786"
  },
  {
    "country": "ES",
    "name": "Zafra",
    "lat": "38.41667",
    "lng": "-6.41667"
  },
  {
    "country": "ES",
    "name": "Zafarraya",
    "lat": "36.97554",
    "lng": "-4.14442"
  },
  {
    "country": "ES",
    "name": "Yunquera",
    "lat": "36.73252",
    "lng": "-4.92122"
  },
  {
    "country": "ES",
    "name": "Yeste",
    "lat": "38.36852",
    "lng": "-2.31756"
  },
  {
    "country": "ES",
    "name": "Yepes",
    "lat": "39.90199",
    "lng": "-3.62517"
  },
  {
    "country": "ES",
    "name": "Yémeda",
    "lat": "39.76667",
    "lng": "-1.71667"
  },
  {
    "country": "ES",
    "name": "Yecla",
    "lat": "38.61365",
    "lng": "-1.11468"
  },
  {
    "country": "ES",
    "name": "Yátova",
    "lat": "39.38333",
    "lng": "-0.8"
  },
  {
    "country": "ES",
    "name": "Yaiza",
    "lat": "28.95678",
    "lng": "-13.76535"
  },
  {
    "country": "ES",
    "name": "Víznar",
    "lat": "37.23149",
    "lng": "-3.55382"
  },
  {
    "country": "ES",
    "name": "Viveros",
    "lat": "38.7726",
    "lng": "-2.57449"
  },
  {
    "country": "ES",
    "name": "Viver",
    "lat": "39.91667",
    "lng": "-0.6"
  },
  {
    "country": "ES",
    "name": "Viso del Marqués",
    "lat": "38.52208",
    "lng": "-3.56348"
  },
  {
    "country": "ES",
    "name": "Viñuela",
    "lat": "36.86307",
    "lng": "-4.14124"
  },
  {
    "country": "ES",
    "name": "Vinalesa",
    "lat": "39.53333",
    "lng": "-0.36667"
  },
  {
    "country": "ES",
    "name": "Villena",
    "lat": "38.6373",
    "lng": "-0.86568"
  },
  {
    "country": "ES",
    "name": "Villavieja",
    "lat": "39.85",
    "lng": "-0.18333"
  },
  {
    "country": "ES",
    "name": "Villaviciosa de Córdoba",
    "lat": "38.08333",
    "lng": "-5.01667"
  },
  {
    "country": "ES",
    "name": "Villaverde y Pasaconsol",
    "lat": "39.77099",
    "lng": "-2.26552"
  },
  {
    "country": "ES",
    "name": "Villaverde del Río",
    "lat": "37.58919",
    "lng": "-5.87443"
  },
  {
    "country": "ES",
    "name": "Villaverde de Guadalimar",
    "lat": "38.45525",
    "lng": "-2.51782"
  },
  {
    "country": "ES",
    "name": "Villavaliente",
    "lat": "39.12646",
    "lng": "-1.45712"
  },
  {
    "country": "ES",
    "name": "Villatoya",
    "lat": "39.33333",
    "lng": "-1.3"
  },
  {
    "country": "ES",
    "name": "Villatobas",
    "lat": "39.90187",
    "lng": "-3.32386"
  },
  {
    "country": "ES",
    "name": "Villasequilla de Yepes",
    "lat": "39.87582",
    "lng": "-3.7311"
  },
  {
    "country": "ES",
    "name": "Villaseca de la Sagra",
    "lat": "39.96185",
    "lng": "-3.88291"
  },
  {
    "country": "ES",
    "name": "Villarta de San Juan",
    "lat": "39.23785",
    "lng": "-3.42333"
  },
  {
    "country": "ES",
    "name": "Villarta de los Montes",
    "lat": "39.21386",
    "lng": "-4.79227"
  },
  {
    "country": "ES",
    "name": "Villarta",
    "lat": "39.45",
    "lng": "-1.65"
  },
  {
    "country": "ES",
    "name": "Villarrubio",
    "lat": "39.94511",
    "lng": "-2.89431"
  },
  {
    "country": "ES",
    "name": "Villarrubia de Santiago",
    "lat": "39.98555",
    "lng": "-3.36898"
  },
  {
    "country": "ES",
    "name": "Villarrubia de los Ojos",
    "lat": "39.22085",
    "lng": "-3.60802"
  },
  {
    "country": "ES",
    "name": "Villarrubia",
    "lat": "37.85",
    "lng": "-4.9"
  },
  {
    "country": "ES",
    "name": "Villarrobledo",
    "lat": "39.26992",
    "lng": "-2.60119"
  },
  {
    "country": "ES",
    "name": "Villarrasa",
    "lat": "37.38849",
    "lng": "-6.60641"
  },
  {
    "country": "ES",
    "name": "Villargordo del Cabriel",
    "lat": "39.53333",
    "lng": "-1.43333"
  },
  {
    "country": "ES",
    "name": "Villares del Saz",
    "lat": "39.84109",
    "lng": "-2.50427"
  },
  {
    "country": "ES",
    "name": "Villarejo-Periesteban",
    "lat": "39.87231",
    "lng": "-2.44145"
  },
  {
    "country": "ES",
    "name": "Villarejo de Montalbán",
    "lat": "39.76913",
    "lng": "-4.57314"
  },
  {
    "country": "ES",
    "name": "Villarejo de Fuentes",
    "lat": "39.78809",
    "lng": "-2.6968"
  },
  {
    "country": "ES",
    "name": "Vila-real",
    "lat": "39.9383",
    "lng": "-0.10087"
  },
  {
    "country": "ES",
    "name": "Villardompardo",
    "lat": "37.83735",
    "lng": "-4.00051"
  },
  {
    "country": "ES",
    "name": "Villar de Rena",
    "lat": "39.07651",
    "lng": "-5.81074"
  },
  {
    "country": "ES",
    "name": "Villar del Rey",
    "lat": "39.1331",
    "lng": "-6.84762"
  },
  {
    "country": "ES",
    "name": "Villar del Pozo",
    "lat": "38.8501",
    "lng": "-3.96405"
  },
  {
    "country": "ES",
    "name": "Villar del Pedroso",
    "lat": "39.70631",
    "lng": "-5.19583"
  },
  {
    "country": "ES",
    "name": "Villar del Humo",
    "lat": "39.86667",
    "lng": "-1.63333"
  },
  {
    "country": "ES",
    "name": "Villar del Arzobispo",
    "lat": "39.73333",
    "lng": "-0.81667"
  },
  {
    "country": "ES",
    "name": "Villar de la Encina",
    "lat": "39.63725",
    "lng": "-2.52155"
  },
  {
    "country": "ES",
    "name": "Villar de Cañas",
    "lat": "39.7786",
    "lng": "-2.56428"
  },
  {
    "country": "ES",
    "name": "Villaralto",
    "lat": "38.45",
    "lng": "-4.98333"
  },
  {
    "country": "ES",
    "name": "Villapalacios",
    "lat": "38.575",
    "lng": "-2.63384"
  },
  {
    "country": "ES",
    "name": "Villanueva de Tapia",
    "lat": "37.18276",
    "lng": "-4.33383"
  },
  {
    "country": "ES",
    "name": "Villanueva de San Juan",
    "lat": "37.04955",
    "lng": "-5.1754"
  },
  {
    "country": "ES",
    "name": "Villanueva de San Carlos",
    "lat": "38.62173",
    "lng": "-3.90903"
  },
  {
    "country": "ES",
    "name": "Villanueva de Mesía",
    "lat": "37.21454",
    "lng": "-4.01404"
  },
  {
    "country": "ES",
    "name": "Villanueva del Trabuco",
    "lat": "37.02832",
    "lng": "-4.33891"
  },
  {
    "country": "ES",
    "name": "Villanueva del Rosario",
    "lat": "36.99679",
    "lng": "-4.36535"
  },
  {
    "country": "ES",
    "name": "Villanueva del Río y Minas",
    "lat": "37.65502",
    "lng": "-5.71369"
  },
  {
    "country": "ES",
    "name": "Villanueva de los Castillejos",
    "lat": "37.4994",
    "lng": "-7.29118"
  },
  {
    "country": "ES",
    "name": "Villanueva del Fresno",
    "lat": "38.376",
    "lng": "-7.16753"
  },
  {
    "country": "ES",
    "name": "Villanueva del Duque",
    "lat": "38.38333",
    "lng": "-5"
  },
  {
    "country": "ES",
    "name": "Villanueva de las Torres",
    "lat": "37.55719",
    "lng": "-3.08868"
  },
  {
    "country": "ES",
    "name": "Villanueva de la Serena",
    "lat": "38.97655",
    "lng": "-5.7974"
  },
  {
    "country": "ES",
    "name": "Villanueva de las Cruces",
    "lat": "37.62783",
    "lng": "-7.02359"
  },
  {
    "country": "ES",
    "name": "Villanueva del Arzobispo",
    "lat": "38.16842",
    "lng": "-3.00742"
  },
  {
    "country": "ES",
    "name": "Villanueva del Ariscal",
    "lat": "37.39623",
    "lng": "-6.14077"
  },
  {
    "country": "ES",
    "name": "Villanueva de la Reina",
    "lat": "38.00432",
    "lng": "-3.91603"
  },
  {
    "country": "ES",
    "name": "Villanueva de la Jara",
    "lat": "39.43333",
    "lng": "-1.93333"
  },
  {
    "country": "ES",
    "name": "Villanueva de la Fuente",
    "lat": "38.69463",
    "lng": "-2.69637"
  },
  {
    "country": "ES",
    "name": "Villanueva de Córdoba",
    "lat": "38.32277",
    "lng": "-4.62873"
  },
  {
    "country": "ES",
    "name": "Villanueva de Castellón",
    "lat": "39.07741",
    "lng": "-0.51167"
  },
  {
    "country": "ES",
    "name": "Villanueva de Bogas",
    "lat": "39.72347",
    "lng": "-3.65743"
  },
  {
    "country": "ES",
    "name": "Villanueva de Algaidas",
    "lat": "37.1835",
    "lng": "-4.45032"
  },
  {
    "country": "ES",
    "name": "Villanueva de Alcardete",
    "lat": "39.67321",
    "lng": "-3.01445"
  },
  {
    "country": "ES",
    "name": "Villamuelas",
    "lat": "39.81784",
    "lng": "-3.73461"
  },
  {
    "country": "ES",
    "name": "Villaminaya",
    "lat": "39.71197",
    "lng": "-3.87055"
  },
  {
    "country": "ES",
    "name": "Villamiel de Toledo",
    "lat": "39.96482",
    "lng": "-4.12627"
  },
  {
    "country": "ES",
    "name": "Villamesías",
    "lat": "39.24568",
    "lng": "-5.87307"
  },
  {
    "country": "ES",
    "name": "Villamayor de Santiago",
    "lat": "39.73072",
    "lng": "-2.92357"
  },
  {
    "country": "ES",
    "name": "Villamayor de Calatrava",
    "lat": "38.78763",
    "lng": "-4.13774"
  },
  {
    "country": "ES",
    "name": "Villamartín",
    "lat": "36.85979",
    "lng": "-5.64485"
  },
  {
    "country": "ES",
    "name": "Vilamarxant",
    "lat": "39.56916",
    "lng": "-0.62453"
  },
  {
    "country": "ES",
    "name": "Villamanrique de la Condesa",
    "lat": "37.24481",
    "lng": "-6.30665"
  },
  {
    "country": "ES",
    "name": "Villamanrique",
    "lat": "38.54636",
    "lng": "-2.99729"
  },
  {
    "country": "ES",
    "name": "Villamalur",
    "lat": "39.96667",
    "lng": "-0.4"
  },
  {
    "country": "ES",
    "name": "Villamalea",
    "lat": "39.36667",
    "lng": "-1.58333"
  },
  {
    "country": "ES",
    "name": "Villaluenga del Rosario",
    "lat": "36.69644",
    "lng": "-5.38601"
  },
  {
    "country": "ES",
    "name": "Villalpardo",
    "lat": "39.46667",
    "lng": "-1.63333"
  },
  {
    "country": "ES",
    "name": "Villalonga",
    "lat": "38.88566",
    "lng": "-0.20795"
  },
  {
    "country": "ES",
    "name": "Villalgordo del Marquesado",
    "lat": "39.68245",
    "lng": "-2.50885"
  },
  {
    "country": "ES",
    "name": "Villalba de los Barros",
    "lat": "38.61294",
    "lng": "-6.50914"
  },
  {
    "country": "ES",
    "name": "Villalba del Alcor",
    "lat": "37.39731",
    "lng": "-6.47461"
  },
  {
    "country": "ES",
    "name": "Villajoyosa",
    "lat": "38.50754",
    "lng": "-0.23346"
  },
  {
    "country": "ES",
    "name": "Villahermosa",
    "lat": "38.75023",
    "lng": "-2.87066"
  },
  {
    "country": "ES",
    "name": "Villaharta",
    "lat": "38.13333",
    "lng": "-4.9"
  },
  {
    "country": "ES",
    "name": "Villagonzalo",
    "lat": "38.86329",
    "lng": "-6.19665"
  },
  {
    "country": "ES",
    "name": "Villagarcía del Llano",
    "lat": "39.31667",
    "lng": "-1.83333"
  },
  {
    "country": "ES",
    "name": "Villagarcía de la Torre",
    "lat": "38.3",
    "lng": "-6.08333"
  },
  {
    "country": "ES",
    "name": "Villafranca de los Caballeros",
    "lat": "39.42824",
    "lng": "-3.36079"
  },
  {
    "country": "ES",
    "name": "Villafranca de los Barros",
    "lat": "38.56144",
    "lng": "-6.3381"
  },
  {
    "country": "ES",
    "name": "Villafranca de Córdoba",
    "lat": "37.96257",
    "lng": "-4.54547"
  },
  {
    "country": "ES",
    "name": "Vilafranca de Bonany",
    "lat": "39.56894",
    "lng": "3.08815"
  },
  {
    "country": "ES",
    "name": "Villa de Ves",
    "lat": "39.2",
    "lng": "-1.23333"
  },
  {
    "country": "ES",
    "name": "Villa del Río",
    "lat": "37.98108",
    "lng": "-4.29003"
  },
  {
    "country": "ES",
    "name": "Villa del Rey",
    "lat": "39.65955",
    "lng": "-6.82122"
  },
  {
    "country": "ES",
    "name": "Villa de Don Fadrique",
    "lat": "39.61505",
    "lng": "-3.21915"
  },
  {
    "country": "ES",
    "name": "Villacarrillo",
    "lat": "38.1156",
    "lng": "-3.0848"
  },
  {
    "country": "ES",
    "name": "Es Castell",
    "lat": "39.8776",
    "lng": "4.2899"
  },
  {
    "country": "ES",
    "name": "Villacañas",
    "lat": "39.62367",
    "lng": "-3.33813"
  },
  {
    "country": "ES",
    "name": "Villablanca",
    "lat": "37.30239",
    "lng": "-7.34413"
  },
  {
    "country": "ES",
    "name": "Vilches",
    "lat": "38.20695",
    "lng": "-3.51025"
  },
  {
    "country": "ES",
    "name": "Vilaflor",
    "lat": "28.15623",
    "lng": "-16.63592"
  },
  {
    "country": "ES",
    "name": "Vícar",
    "lat": "36.83155",
    "lng": "-2.64273"
  },
  {
    "country": "ES",
    "name": "Viator",
    "lat": "36.89006",
    "lng": "-2.42695"
  },
  {
    "country": "ES",
    "name": "Vergel",
    "lat": "38.84709",
    "lng": "0.01034"
  },
  {
    "country": "ES",
    "name": "Vera",
    "lat": "37.24345",
    "lng": "-1.85905"
  },
  {
    "country": "ES",
    "name": "Ventas de Huelma",
    "lat": "37.0684",
    "lng": "-3.81983"
  },
  {
    "country": "ES",
    "name": "Ventas con Peña Aguilera",
    "lat": "39.61033",
    "lng": "-4.23128"
  },
  {
    "country": "ES",
    "name": "Venta del Moro",
    "lat": "39.48333",
    "lng": "-1.35"
  },
  {
    "country": "ES",
    "name": "Velez Rubio",
    "lat": "37.64844",
    "lng": "-2.07686"
  },
  {
    "country": "ES",
    "name": "Vélez-Málaga",
    "lat": "36.78107",
    "lng": "-4.10266"
  },
  {
    "country": "ES",
    "name": "Vélez de Benaudalla",
    "lat": "36.83244",
    "lng": "-3.51539"
  },
  {
    "country": "ES",
    "name": "Vélez-Blanco",
    "lat": "37.69178",
    "lng": "-2.09587"
  },
  {
    "country": "ES",
    "name": "Velefique",
    "lat": "37.19407",
    "lng": "-2.40155"
  },
  {
    "country": "ES",
    "name": "Velada",
    "lat": "39.97687",
    "lng": "-4.97641"
  },
  {
    "country": "ES",
    "name": "Vejer de la Frontera",
    "lat": "36.24456",
    "lng": "-5.96953"
  },
  {
    "country": "ES",
    "name": "Vega de San Mateo",
    "lat": "28.00892",
    "lng": "-15.5333"
  },
  {
    "country": "ES",
    "name": "Vara de Rey",
    "lat": "39.42595",
    "lng": "-2.29404"
  },
  {
    "country": "ES",
    "name": "Valverdejo",
    "lat": "39.61667",
    "lng": "-2.01667"
  },
  {
    "country": "ES",
    "name": "Valverde de Mérida",
    "lat": "38.91122",
    "lng": "-6.21999"
  },
  {
    "country": "ES",
    "name": "Valverde de Llerena",
    "lat": "38.21667",
    "lng": "-5.81667"
  },
  {
    "country": "ES",
    "name": "Valverde de Leganés",
    "lat": "38.67059",
    "lng": "-6.98036"
  },
  {
    "country": "ES",
    "name": "Valverde del Camino",
    "lat": "37.57511",
    "lng": "-6.75432"
  },
  {
    "country": "ES",
    "name": "Valverde de Júcar",
    "lat": "39.71866",
    "lng": "-2.22135"
  },
  {
    "country": "ES",
    "name": "Valverde de Burguillos",
    "lat": "38.3271",
    "lng": "-6.53648"
  },
  {
    "country": "ES",
    "name": "Valverde",
    "lat": "27.80628",
    "lng": "-17.91578"
  },
  {
    "country": "ES",
    "name": "Valsequillo de Gran Canaria",
    "lat": "27.98562",
    "lng": "-15.49725"
  },
  {
    "country": "ES",
    "name": "Válor",
    "lat": "36.99618",
    "lng": "-3.08287"
  },
  {
    "country": "ES",
    "name": "Valleseco",
    "lat": "28.0433",
    "lng": "-15.57623"
  },
  {
    "country": "ES",
    "name": "Vallés",
    "lat": "38.98518",
    "lng": "-0.55696"
  },
  {
    "country": "ES",
    "name": "Vallehermosa",
    "lat": "28.17944",
    "lng": "-17.26664"
  },
  {
    "country": "ES",
    "name": "Valle de Santa Ana",
    "lat": "38.36637",
    "lng": "-6.7886"
  },
  {
    "country": "ES",
    "name": "Valle de Matamoros",
    "lat": "38.37889",
    "lng": "-6.80371"
  },
  {
    "country": "ES",
    "name": "Valle de la Serena",
    "lat": "38.7101",
    "lng": "-5.79847"
  },
  {
    "country": "ES",
    "name": "Valldemossa",
    "lat": "39.71042",
    "lng": "2.6223"
  },
  {
    "country": "ES",
    "name": "Vall de Ebo",
    "lat": "38.80561",
    "lng": "-0.1589"
  },
  {
    "country": "ES",
    "name": "Vall de Almonacid",
    "lat": "39.9",
    "lng": "-0.45"
  },
  {
    "country": "ES",
    "name": "Vallada",
    "lat": "38.89575",
    "lng": "-0.69104"
  },
  {
    "country": "ES",
    "name": "Valhermoso de la Fuente",
    "lat": "39.56667",
    "lng": "-2.01667"
  },
  {
    "country": "ES",
    "name": "Valenzuela de Calatrava",
    "lat": "38.85254",
    "lng": "-3.7721"
  },
  {
    "country": "ES",
    "name": "Valenzuela",
    "lat": "37.7756",
    "lng": "-4.22038"
  },
  {
    "country": "ES",
    "name": "Valencina de la Concepción",
    "lat": "37.41618",
    "lng": "-6.07422"
  },
  {
    "country": "ES",
    "name": "Valencia del Ventoso",
    "lat": "38.26667",
    "lng": "-6.46667"
  },
  {
    "country": "ES",
    "name": "Valencia del Mombuey",
    "lat": "38.24243",
    "lng": "-7.11965"
  },
  {
    "country": "ES",
    "name": "Valencia de las Torres",
    "lat": "38.40518",
    "lng": "-6.00403"
  },
  {
    "country": "ES",
    "name": "Valencia de Alcántara",
    "lat": "39.41148",
    "lng": "-7.24435"
  },
  {
    "country": "ES",
    "name": "Valencia",
    "lat": "39.46975",
    "lng": "-0.37739"
  },
  {
    "country": "ES",
    "name": "Valdeverdeja",
    "lat": "39.79635",
    "lng": "-5.24544"
  },
  {
    "country": "ES",
    "name": "Valdetorres",
    "lat": "38.91542",
    "lng": "-6.06765"
  },
  {
    "country": "ES",
    "name": "Valdés",
    "lat": "36.75835",
    "lng": "-4.24235"
  },
  {
    "country": "ES",
    "name": "Valderrubio",
    "lat": "37.23378",
    "lng": "-3.82005"
  },
  {
    "country": "ES",
    "name": "Valdepeñas de Jaén",
    "lat": "37.58903",
    "lng": "-3.8145"
  },
  {
    "country": "ES",
    "name": "Valdepeñas",
    "lat": "38.76211",
    "lng": "-3.38483"
  },
  {
    "country": "ES",
    "name": "Valdemorales",
    "lat": "39.20588",
    "lng": "-6.06622"
  },
  {
    "country": "ES",
    "name": "Valdemanco del Esteras",
    "lat": "38.93858",
    "lng": "-4.8292"
  },
  {
    "country": "ES",
    "name": "Valdelarco",
    "lat": "37.94877",
    "lng": "-6.68202"
  },
  {
    "country": "ES",
    "name": "Valdelacasa de Tajo",
    "lat": "39.72588",
    "lng": "-5.28296"
  },
  {
    "country": "ES",
    "name": "Valdehúncar",
    "lat": "39.83659",
    "lng": "-5.52307"
  },
  {
    "country": "ES",
    "name": "Valdeganga",
    "lat": "39.13514",
    "lng": "-1.67703"
  },
  {
    "country": "ES",
    "name": "Valdefuentes",
    "lat": "39.27433",
    "lng": "-6.12183"
  },
  {
    "country": "ES",
    "name": "Valdecañas de Tajo",
    "lat": "39.75919",
    "lng": "-5.61951"
  },
  {
    "country": "ES",
    "name": "Valdecaballeros",
    "lat": "39.24289",
    "lng": "-5.19"
  },
  {
    "country": "ES",
    "name": "Utrera",
    "lat": "37.18516",
    "lng": "-5.78093"
  },
  {
    "country": "ES",
    "name": "Utiel",
    "lat": "39.56667",
    "lng": "-1.2"
  },
  {
    "country": "ES",
    "name": "Usagre",
    "lat": "38.35",
    "lng": "-6.16667"
  },
  {
    "country": "ES",
    "name": "Urrácal",
    "lat": "37.3974",
    "lng": "-2.36485"
  },
  {
    "country": "ES",
    "name": "Urda",
    "lat": "39.41179",
    "lng": "-3.71493"
  },
  {
    "country": "ES",
    "name": "Umbrete",
    "lat": "37.36881",
    "lng": "-6.15847"
  },
  {
    "country": "ES",
    "name": "Uleila del Campo",
    "lat": "37.1846",
    "lng": "-2.20491"
  },
  {
    "country": "ES",
    "name": "Ulea",
    "lat": "38.14045",
    "lng": "-1.33007"
  },
  {
    "country": "ES",
    "name": "Ugíjar",
    "lat": "36.96087",
    "lng": "-3.05523"
  },
  {
    "country": "ES",
    "name": "Uclés",
    "lat": "39.97938",
    "lng": "-2.86143"
  },
  {
    "country": "ES",
    "name": "Ubrique",
    "lat": "36.67777",
    "lng": "-5.446"
  },
  {
    "country": "ES",
    "name": "Úbeda",
    "lat": "38.01328",
    "lng": "-3.3705"
  },
  {
    "country": "ES",
    "name": "Turrillas",
    "lat": "37.02948",
    "lng": "-2.26607"
  },
  {
    "country": "ES",
    "name": "Turre",
    "lat": "37.15224",
    "lng": "-1.89497"
  },
  {
    "country": "ES",
    "name": "Turleque",
    "lat": "39.60138",
    "lng": "-3.61404"
  },
  {
    "country": "ES",
    "name": "Turís",
    "lat": "39.38333",
    "lng": "-0.7"
  },
  {
    "country": "ES",
    "name": "Tuineje",
    "lat": "28.32372",
    "lng": "-14.04722"
  },
  {
    "country": "ES",
    "name": "Tuéjar",
    "lat": "39.76667",
    "lng": "-1.03333"
  },
  {
    "country": "ES",
    "name": "Trujillo",
    "lat": "39.45786",
    "lng": "-5.88203"
  },
  {
    "country": "ES",
    "name": "Trujillanos",
    "lat": "38.95233",
    "lng": "-6.25759"
  },
  {
    "country": "ES",
    "name": "Trigueros",
    "lat": "37.38606",
    "lng": "-6.8268"
  },
  {
    "country": "ES",
    "name": "Tribaldos",
    "lat": "39.97264",
    "lng": "-2.89809"
  },
  {
    "country": "ES",
    "name": "Trevélez",
    "lat": "37.00037",
    "lng": "-3.26545"
  },
  {
    "country": "ES",
    "name": "Tresjuncos",
    "lat": "39.70087",
    "lng": "-2.75502"
  },
  {
    "country": "ES",
    "name": "Trebujena",
    "lat": "36.87075",
    "lng": "-6.17586"
  },
  {
    "country": "ES",
    "name": "Trasierra",
    "lat": "38.18333",
    "lng": "-6"
  },
  {
    "country": "ES",
    "name": "Tous",
    "lat": "39.13951",
    "lng": "-0.58777"
  },
  {
    "country": "ES",
    "name": "Totanés",
    "lat": "39.71057",
    "lng": "-4.22655"
  },
  {
    "country": "ES",
    "name": "Totana",
    "lat": "37.7688",
    "lng": "-1.50229"
  },
  {
    "country": "ES",
    "name": "Torrubia del Castillo",
    "lat": "39.65852",
    "lng": "-2.31171"
  },
  {
    "country": "ES",
    "name": "Torrubia del Campo",
    "lat": "39.89749",
    "lng": "-2.96133"
  },
  {
    "country": "ES",
    "name": "Torrox",
    "lat": "36.75793",
    "lng": "-3.95233"
  },
  {
    "country": "ES",
    "name": "Torrijos",
    "lat": "39.98195",
    "lng": "-4.28349"
  },
  {
    "country": "ES",
    "name": "Torrico",
    "lat": "39.82918",
    "lng": "-5.22581"
  },
  {
    "country": "ES",
    "name": "Torrevieja",
    "lat": "37.97872",
    "lng": "-0.68222"
  },
  {
    "country": "ES",
    "name": "Torres",
    "lat": "37.78537",
    "lng": "-3.50902"
  },
  {
    "country": "ES",
    "name": "Torrequemada",
    "lat": "39.36664",
    "lng": "-6.22052"
  },
  {
    "country": "ES",
    "name": "Torreperogil",
    "lat": "38.0354",
    "lng": "-3.28998"
  },
  {
    "country": "ES",
    "name": "Torre-Pacheco",
    "lat": "37.74293",
    "lng": "-0.95396"
  },
  {
    "country": "ES",
    "name": "Torreorgaz",
    "lat": "39.3831",
    "lng": "-6.24941"
  },
  {
    "country": "ES",
    "name": "Torrenueva",
    "lat": "38.6396",
    "lng": "-3.36259"
  },
  {
    "country": "ES",
    "name": "Torrent",
    "lat": "39.43705",
    "lng": "-0.46546"
  },
  {
    "country": "ES",
    "name": "Torremolinos",
    "lat": "36.62035",
    "lng": "-4.49976"
  },
  {
    "country": "ES",
    "name": "Torremocha",
    "lat": "39.34565",
    "lng": "-6.17335"
  },
  {
    "country": "ES",
    "name": "Torremayor",
    "lat": "38.9014",
    "lng": "-6.53858"
  },
  {
    "country": "ES",
    "name": "Torrella",
    "lat": "38.98446",
    "lng": "-0.56727"
  },
  {
    "country": "ES",
    "name": "Torrejón el Rubio",
    "lat": "39.77068",
    "lng": "-6.0126"
  },
  {
    "country": "ES",
    "name": "Torrejoncillo del Rey",
    "lat": "40.0084",
    "lng": "-2.57107"
  },
  {
    "country": "ES",
    "name": "Torrejoncillo",
    "lat": "39.89675",
    "lng": "-6.46712"
  },
  {
    "country": "ES",
    "name": "Torredonjimeno",
    "lat": "37.76748",
    "lng": "-3.95776"
  },
  {
    "country": "ES",
    "name": "Torre de Santa María",
    "lat": "39.25441",
    "lng": "-6.1161"
  },
  {
    "country": "ES",
    "name": "Torre de Miguel Sesmero",
    "lat": "38.61913",
    "lng": "-6.7958"
  },
  {
    "country": "ES",
    "name": "Torre del Campo",
    "lat": "37.77051",
    "lng": "-3.89731"
  },
  {
    "country": "ES",
    "name": "Torre de la Horadada",
    "lat": "37.8697",
    "lng": "-0.7584"
  },
  {
    "country": "ES",
    "name": "Torre de Juan Abad",
    "lat": "38.58417",
    "lng": "-3.05994"
  },
  {
    "country": "ES",
    "name": "Torrecillas de la Tiesa",
    "lat": "39.56837",
    "lng": "-5.74238"
  },
  {
    "country": "ES",
    "name": "Torrecilla de la Jara",
    "lat": "39.70425",
    "lng": "-4.77186"
  },
  {
    "country": "ES",
    "name": "Torre-Cardela",
    "lat": "37.50456",
    "lng": "-3.35609"
  },
  {
    "country": "ES",
    "name": "Torrecampo",
    "lat": "38.46667",
    "lng": "-4.66667"
  },
  {
    "country": "ES",
    "name": "Torreblascopedro",
    "lat": "37.9975",
    "lng": "-3.6378"
  },
  {
    "country": "ES",
    "name": "Torre Alháquime",
    "lat": "36.91588",
    "lng": "-5.23381"
  },
  {
    "country": "ES",
    "name": "Torralba de Oropesa",
    "lat": "39.93384",
    "lng": "-5.15404"
  },
  {
    "country": "ES",
    "name": "Torralba del Pinar",
    "lat": "39.98333",
    "lng": "-0.43333"
  },
  {
    "country": "ES",
    "name": "Torralba de Calatrava",
    "lat": "39.01785",
    "lng": "-3.75105"
  },
  {
    "country": "ES",
    "name": "Tormos",
    "lat": "38.80143",
    "lng": "-0.0716"
  },
  {
    "country": "ES",
    "name": "Toril",
    "lat": "39.89749",
    "lng": "-5.7795"
  },
  {
    "country": "ES",
    "name": "Torás",
    "lat": "39.91667",
    "lng": "-0.68333"
  },
  {
    "country": "ES",
    "name": "Tomelloso",
    "lat": "39.15759",
    "lng": "-3.02156"
  },
  {
    "country": "ES",
    "name": "Tomares",
    "lat": "37.37281",
    "lng": "-6.04589"
  },
  {
    "country": "ES",
    "name": "Tolox",
    "lat": "36.68721",
    "lng": "-4.90511"
  },
  {
    "country": "ES",
    "name": "Tollos",
    "lat": "38.75629",
    "lng": "-0.27466"
  },
  {
    "country": "ES",
    "name": "Toledo",
    "lat": "39.8581",
    "lng": "-4.02263"
  },
  {
    "country": "ES",
    "name": "Tocina",
    "lat": "37.60904",
    "lng": "-5.73403"
  },
  {
    "country": "ES",
    "name": "Tobarra",
    "lat": "38.59213",
    "lng": "-1.69191"
  },
  {
    "country": "ES",
    "name": "Titaguas",
    "lat": "39.86667",
    "lng": "-1.08333"
  },
  {
    "country": "ES",
    "name": "Tinajo",
    "lat": "29.06326",
    "lng": "-13.67647"
  },
  {
    "country": "ES",
    "name": "Tíjola",
    "lat": "37.34606",
    "lng": "-2.43326"
  },
  {
    "country": "ES",
    "name": "Tijarafe",
    "lat": "28.7",
    "lng": "-17.95"
  },
  {
    "country": "ES",
    "name": "Tibi",
    "lat": "38.53072",
    "lng": "-0.57776"
  },
  {
    "country": "ES",
    "name": "Tías",
    "lat": "28.96108",
    "lng": "-13.64502"
  },
  {
    "country": "ES",
    "name": "Teulada",
    "lat": "38.7294",
    "lng": "0.10383"
  },
  {
    "country": "ES",
    "name": "Terrinches",
    "lat": "38.61057",
    "lng": "-2.84215"
  },
  {
    "country": "ES",
    "name": "Terrateig",
    "lat": "38.89453",
    "lng": "-0.31993"
  },
  {
    "country": "ES",
    "name": "Terque",
    "lat": "36.98393",
    "lng": "-2.59679"
  },
  {
    "country": "ES",
    "name": "Teror",
    "lat": "28.06062",
    "lng": "-15.54909"
  },
  {
    "country": "ES",
    "name": "Tembleque",
    "lat": "39.69541",
    "lng": "-3.50429"
  },
  {
    "country": "ES",
    "name": "Telde",
    "lat": "27.99243",
    "lng": "-15.41915"
  },
  {
    "country": "ES",
    "name": "Tejeda",
    "lat": "27.99508",
    "lng": "-15.61543"
  },
  {
    "country": "ES",
    "name": "Teguise",
    "lat": "29.06049",
    "lng": "-13.56397"
  },
  {
    "country": "ES",
    "name": "Tegueste",
    "lat": "28.51667",
    "lng": "-16.31667"
  },
  {
    "country": "ES",
    "name": "Tébar",
    "lat": "39.5",
    "lng": "-2.16667"
  },
  {
    "country": "ES",
    "name": "Teba",
    "lat": "36.98358",
    "lng": "-4.91913"
  },
  {
    "country": "ES",
    "name": "Tazacorte",
    "lat": "28.64186",
    "lng": "-17.93394"
  },
  {
    "country": "ES",
    "name": "Tarifa",
    "lat": "36.01393",
    "lng": "-5.60695"
  },
  {
    "country": "ES",
    "name": "Tarazona de la Mancha",
    "lat": "39.25",
    "lng": "-1.91667"
  },
  {
    "country": "ES",
    "name": "Tanque",
    "lat": "28.36667",
    "lng": "-16.83333"
  },
  {
    "country": "ES",
    "name": "Tamurejo",
    "lat": "38.98333",
    "lng": "-4.93333"
  },
  {
    "country": "ES",
    "name": "Táliga",
    "lat": "38.52861",
    "lng": "-7.01713"
  },
  {
    "country": "ES",
    "name": "Tales",
    "lat": "39.94844",
    "lng": "-0.30719"
  },
  {
    "country": "ES",
    "name": "Talayuelas",
    "lat": "39.85",
    "lng": "-1.28333"
  },
  {
    "country": "ES",
    "name": "Talayuela",
    "lat": "39.98701",
    "lng": "-5.60982"
  },
  {
    "country": "ES",
    "name": "Talavera La Real",
    "lat": "38.87794",
    "lng": "-6.76856"
  },
  {
    "country": "ES",
    "name": "Talavera de la Reina",
    "lat": "39.96348",
    "lng": "-4.83076"
  },
  {
    "country": "ES",
    "name": "Talaván",
    "lat": "39.71715",
    "lng": "-6.28146"
  },
  {
    "country": "ES",
    "name": "Talarrubias",
    "lat": "39.03697",
    "lng": "-5.23423"
  },
  {
    "country": "ES",
    "name": "Tahal",
    "lat": "37.22797",
    "lng": "-2.2847"
  },
  {
    "country": "ES",
    "name": "Tacoronte",
    "lat": "28.47688",
    "lng": "-16.41016"
  },
  {
    "country": "ES",
    "name": "Tavernes de la Valldigna",
    "lat": "39.07195",
    "lng": "-0.26623"
  },
  {
    "country": "ES",
    "name": "Tavernes Blanques",
    "lat": "39.5",
    "lng": "-0.36667"
  },
  {
    "country": "ES",
    "name": "Tabernas",
    "lat": "37.04992",
    "lng": "-2.39084"
  },
  {
    "country": "ES",
    "name": "Sumacàrcer",
    "lat": "39.1",
    "lng": "-0.63333"
  },
  {
    "country": "ES",
    "name": "Suflí",
    "lat": "37.33866",
    "lng": "-2.38817"
  },
  {
    "country": "ES",
    "name": "Sueca",
    "lat": "39.2026",
    "lng": "-0.31114"
  },
  {
    "country": "ES",
    "name": "Sot de Ferrer",
    "lat": "39.8",
    "lng": "-0.4"
  },
  {
    "country": "ES",
    "name": "Sot de Chera",
    "lat": "39.63333",
    "lng": "-0.9"
  },
  {
    "country": "ES",
    "name": "Sorvilán",
    "lat": "36.79505",
    "lng": "-3.26769"
  },
  {
    "country": "ES",
    "name": "Sorihuela del Guadalimar",
    "lat": "38.24062",
    "lng": "-3.0536"
  },
  {
    "country": "ES",
    "name": "Sorbas",
    "lat": "37.09761",
    "lng": "-2.12349"
  },
  {
    "country": "ES",
    "name": "Soportújar",
    "lat": "36.92863",
    "lng": "-3.40542"
  },
  {
    "country": "ES",
    "name": "Son Servera",
    "lat": "39.62073",
    "lng": "3.36008"
  },
  {
    "country": "ES",
    "name": "Sonseca",
    "lat": "39.67747",
    "lng": "-3.97448"
  },
  {
    "country": "ES",
    "name": "Soneja",
    "lat": "39.81667",
    "lng": "-0.41667"
  },
  {
    "country": "ES",
    "name": "Somontín",
    "lat": "37.39176",
    "lng": "-2.38828"
  },
  {
    "country": "ES",
    "name": "Sóller",
    "lat": "39.76623",
    "lng": "2.71521"
  },
  {
    "country": "ES",
    "name": "Sollana",
    "lat": "39.28333",
    "lng": "-0.36667"
  },
  {
    "country": "ES",
    "name": "Solana de los Barros",
    "lat": "38.72527",
    "lng": "-6.53899"
  },
  {
    "country": "ES",
    "name": "Socuéllamos",
    "lat": "39.28581",
    "lng": "-2.79205"
  },
  {
    "country": "ES",
    "name": "Socovos",
    "lat": "38.33232",
    "lng": "-1.98485"
  },
  {
    "country": "ES",
    "name": "Sisante",
    "lat": "39.40849",
    "lng": "-2.20173"
  },
  {
    "country": "ES",
    "name": "Siruela",
    "lat": "38.97718",
    "lng": "-5.04969"
  },
  {
    "country": "ES",
    "name": "Sineu",
    "lat": "39.64254",
    "lng": "3.01034"
  },
  {
    "country": "ES",
    "name": "Sinarcas",
    "lat": "39.73333",
    "lng": "-1.23333"
  },
  {
    "country": "ES",
    "name": "Simat de la Valldigna",
    "lat": "39.03333",
    "lng": "-0.31667"
  },
  {
    "country": "ES",
    "name": "Silla",
    "lat": "39.36257",
    "lng": "-0.41169"
  },
  {
    "country": "ES",
    "name": "Siles",
    "lat": "38.38983",
    "lng": "-2.5819"
  },
  {
    "country": "ES",
    "name": "Siete Aguas",
    "lat": "39.46667",
    "lng": "-0.91667"
  },
  {
    "country": "ES",
    "name": "Sierro",
    "lat": "37.32237",
    "lng": "-2.39844"
  },
  {
    "country": "ES",
    "name": "Sierra de Yeguas",
    "lat": "37.1242",
    "lng": "-4.86773"
  },
  {
    "country": "ES",
    "name": "Sierra de Fuentes",
    "lat": "39.43997",
    "lng": "-6.27242"
  },
  {
    "country": "ES",
    "name": "Sevilleja de la Jara",
    "lat": "39.57488",
    "lng": "-4.96387"
  },
  {
    "country": "ES",
    "name": "Sevilla",
    "lat": "37.38283",
    "lng": "-5.97317"
  },
  {
    "country": "ES",
    "name": "Setenil de las Bodegas",
    "lat": "36.86397",
    "lng": "-5.18177"
  },
  {
    "country": "ES",
    "name": "Ses Salines",
    "lat": "39.33831",
    "lng": "3.05274"
  },
  {
    "country": "ES",
    "name": "Serrejón",
    "lat": "39.81735",
    "lng": "-5.80263"
  },
  {
    "country": "ES",
    "name": "Serrato",
    "lat": "36.88541",
    "lng": "-4.98147"
  },
  {
    "country": "ES",
    "name": "Serradilla",
    "lat": "39.8292",
    "lng": "-6.14034"
  },
  {
    "country": "ES",
    "name": "Serra",
    "lat": "39.68333",
    "lng": "-0.43333"
  },
  {
    "country": "ES",
    "name": "Serón",
    "lat": "37.34485",
    "lng": "-2.50913"
  },
  {
    "country": "ES",
    "name": "Senija",
    "lat": "38.72804",
    "lng": "0.04176"
  },
  {
    "country": "ES",
    "name": "Senyera",
    "lat": "39.06667",
    "lng": "-0.5"
  },
  {
    "country": "ES",
    "name": "Sempere",
    "lat": "38.92014",
    "lng": "-0.4814"
  },
  {
    "country": "ES",
    "name": "Selva",
    "lat": "39.75504",
    "lng": "2.90069"
  },
  {
    "country": "ES",
    "name": "Sellent",
    "lat": "39.03221",
    "lng": "-0.58784"
  },
  {
    "country": "ES",
    "name": "Sella",
    "lat": "38.60926",
    "lng": "-0.27305"
  },
  {
    "country": "ES",
    "name": "Segura de León",
    "lat": "38.11667",
    "lng": "-6.51667"
  },
  {
    "country": "ES",
    "name": "Segura de la Sierra",
    "lat": "38.29777",
    "lng": "-2.65229"
  },
  {
    "country": "ES",
    "name": "Segorbe",
    "lat": "39.85",
    "lng": "-0.48333"
  },
  {
    "country": "ES",
    "name": "Segart",
    "lat": "39.68333",
    "lng": "-0.36667"
  },
  {
    "country": "ES",
    "name": "Sedaví",
    "lat": "39.43333",
    "lng": "-0.38333"
  },
  {
    "country": "ES",
    "name": "Sayalonga",
    "lat": "36.79819",
    "lng": "-4.01325"
  },
  {
    "country": "ES",
    "name": "Sax",
    "lat": "38.53729",
    "lng": "-0.81779"
  },
  {
    "country": "ES",
    "name": "Sauzal",
    "lat": "28.46667",
    "lng": "-16.41667"
  },
  {
    "country": "ES",
    "name": "Saucedilla",
    "lat": "39.85284",
    "lng": "-5.67781"
  },
  {
    "country": "ES",
    "name": "San Vicent del Raspeig",
    "lat": "38.3964",
    "lng": "-0.5255"
  },
  {
    "country": "ES",
    "name": "San Vicente de Alcántara",
    "lat": "39.36132",
    "lng": "-7.13766"
  },
  {
    "country": "ES",
    "name": "Santo Tomé",
    "lat": "38.02861",
    "lng": "-3.10092"
  },
  {
    "country": "ES",
    "name": "Santomera",
    "lat": "38.06147",
    "lng": "-1.04877"
  },
  {
    "country": "ES",
    "name": "Santisteban del Puerto",
    "lat": "38.24829",
    "lng": "-3.20762"
  },
  {
    "country": "ES",
    "name": "Santiponce",
    "lat": "37.43553",
    "lng": "-6.04106"
  },
  {
    "country": "ES",
    "name": "Santiago del Teide",
    "lat": "28.294",
    "lng": "-16.81618"
  },
  {
    "country": "ES",
    "name": "Santiago del Campo",
    "lat": "39.6284",
    "lng": "-6.36362"
  },
  {
    "country": "ES",
    "name": "Santiago de la Ribera",
    "lat": "37.79681",
    "lng": "-0.80544"
  },
  {
    "country": "ES",
    "name": "Santiago de Calatrava",
    "lat": "37.75382",
    "lng": "-4.17093"
  },
  {
    "country": "ES",
    "name": "Es Migjorn Gran",
    "lat": "39.94657",
    "lng": "4.05121"
  },
  {
    "country": "ES",
    "name": "Santa Úrsula",
    "lat": "28.42613",
    "lng": "-16.48876"
  },
  {
    "country": "ES",
    "name": "Santa Pola",
    "lat": "38.19165",
    "lng": "-0.5658"
  },
  {
    "country": "ES",
    "name": "Santa Olalla del Cala",
    "lat": "37.9",
    "lng": "-6.21667"
  },
  {
    "country": "ES",
    "name": "Santanyí",
    "lat": "39.35461",
    "lng": "3.12907"
  },
  {
    "country": "ES",
    "name": "Santa Marta de Magasca",
    "lat": "39.5115",
    "lng": "-6.09881"
  },
  {
    "country": "ES",
    "name": "Santa Marta",
    "lat": "38.61421",
    "lng": "-6.62799"
  },
  {
    "country": "ES",
    "name": "Santa María del Campo Rus",
    "lat": "39.55942",
    "lng": "-2.42306"
  },
  {
    "country": "ES",
    "name": "Santa Maria del Camí",
    "lat": "39.65111",
    "lng": "2.77317"
  },
  {
    "country": "ES",
    "name": "Santa Margalida",
    "lat": "39.70143",
    "lng": "3.10215"
  },
  {
    "country": "ES",
    "name": "Santa Lucía",
    "lat": "27.91174",
    "lng": "-15.54071"
  },
  {
    "country": "ES",
    "name": "Santa Fe de Mondújar",
    "lat": "36.97479",
    "lng": "-2.53126"
  },
  {
    "country": "ES",
    "name": "Santafé",
    "lat": "37.18856",
    "lng": "-3.71887"
  },
  {
    "country": "ES",
    "name": "Santa Eulària des Riu",
    "lat": "38.98457",
    "lng": "1.53409"
  },
  {
    "country": "ES",
    "name": "Santa Eugènia",
    "lat": "39.62361",
    "lng": "2.83864"
  },
  {
    "country": "ES",
    "name": "Santa Eufemia",
    "lat": "38.6",
    "lng": "-4.9"
  },
  {
    "country": "ES",
    "name": "Santaella",
    "lat": "37.56294",
    "lng": "-4.84362"
  },
  {
    "country": "ES",
    "name": "Santa Elena",
    "lat": "38.34162",
    "lng": "-3.53953"
  },
  {
    "country": "ES",
    "name": "Santa Cruz de Tenerife",
    "lat": "28.46824",
    "lng": "-16.25462"
  },
  {
    "country": "ES",
    "name": "Santa Cruz de Mudela",
    "lat": "38.64241",
    "lng": "-3.4665"
  },
  {
    "country": "ES",
    "name": "Santa Cruz de Moya",
    "lat": "39.95",
    "lng": "-1.26667"
  },
  {
    "country": "ES",
    "name": "Santa Cruz de los Cáñamos",
    "lat": "38.63759",
    "lng": "-2.86618"
  },
  {
    "country": "ES",
    "name": "Santa Cruz de la Zarza",
    "lat": "39.98104",
    "lng": "-3.18787"
  },
  {
    "country": "ES",
    "name": "Santa Cruz de la Sierra",
    "lat": "39.33635",
    "lng": "-5.84561"
  },
  {
    "country": "ES",
    "name": "Santa Cruz de la Palma",
    "lat": "28.68351",
    "lng": "-17.76421"
  },
  {
    "country": "ES",
    "name": "Santa Brígida",
    "lat": "28.03197",
    "lng": "-15.50425"
  },
  {
    "country": "ES",
    "name": "Santa Bárbara de Casa",
    "lat": "37.79665",
    "lng": "-7.18735"
  },
  {
    "country": "ES",
    "name": "Santa Ana la Real",
    "lat": "37.86245",
    "lng": "-6.72385"
  },
  {
    "country": "ES",
    "name": "Santa Ana de Pusa",
    "lat": "39.76238",
    "lng": "-4.70904"
  },
  {
    "country": "ES",
    "name": "Santa Ana",
    "lat": "39.30823",
    "lng": "-5.99027"
  },
  {
    "country": "ES",
    "name": "Santa Amalia",
    "lat": "39.01118",
    "lng": "-6.01158"
  },
  {
    "country": "ES",
    "name": "San Silvestre de Guzmán",
    "lat": "37.3877",
    "lng": "-7.34908"
  },
  {
    "country": "ES",
    "name": "San Sebastián de los Ballesteros",
    "lat": "37.65376",
    "lng": "-4.82409"
  },
  {
    "country": "ES",
    "name": "San Sebastián de la Gomera",
    "lat": "28.09163",
    "lng": "-17.11331"
  },
  {
    "country": "ES",
    "name": "San Roque",
    "lat": "36.21067",
    "lng": "-5.38415"
  },
  {
    "country": "ES",
    "name": "San Pedro de Mérida",
    "lat": "38.95007",
    "lng": "-6.18645"
  },
  {
    "country": "ES",
    "name": "San Pedro del Pinatar",
    "lat": "37.83568",
    "lng": "-0.79102"
  },
  {
    "country": "ES",
    "name": "San Pedro de Alcántara",
    "lat": "36.48839",
    "lng": "-4.99123"
  },
  {
    "country": "ES",
    "name": "San Pedro",
    "lat": "38.82493",
    "lng": "-2.18276"
  },
  {
    "country": "ES",
    "name": "San Nicolás del Puerto",
    "lat": "38",
    "lng": "-5.65"
  },
  {
    "country": "ES",
    "name": "San Nicolás",
    "lat": "27.9891",
    "lng": "-15.78126"
  },
  {
    "country": "ES",
    "name": "San Miguel de Salinas",
    "lat": "37.97972",
    "lng": "-0.78904"
  },
  {
    "country": "ES",
    "name": "San Miguel De Abona",
    "lat": "28.09826",
    "lng": "-16.61708"
  },
  {
    "country": "ES",
    "name": "San Martín de Pusa",
    "lat": "39.78404",
    "lng": "-4.63252"
  },
  {
    "country": "ES",
    "name": "San Martín de Montalbán",
    "lat": "39.70186",
    "lng": "-4.38796"
  },
  {
    "country": "ES",
    "name": "San Martín de Boniches",
    "lat": "39.9",
    "lng": "-1.56667"
  },
  {
    "country": "ES",
    "name": "Sant Lluís",
    "lat": "39.84939",
    "lng": "4.25819"
  },
  {
    "country": "ES",
    "name": "Sanlúcar la Mayor",
    "lat": "37.38758",
    "lng": "-6.20346"
  },
  {
    "country": "ES",
    "name": "Sanlúcar de Guadiana",
    "lat": "37.47268",
    "lng": "-7.46546"
  },
  {
    "country": "ES",
    "name": "Sanlúcar de Barrameda",
    "lat": "36.77808",
    "lng": "-6.3515"
  },
  {
    "country": "ES",
    "name": "San Lorenzo de la Parrilla",
    "lat": "39.85129",
    "lng": "-2.36079"
  },
  {
    "country": "ES",
    "name": "Sant Llorenç des Cardassar",
    "lat": "39.61009",
    "lng": "3.2838"
  },
  {
    "country": "ES",
    "name": "San Lorenzo de Calatrava",
    "lat": "38.47681",
    "lng": "-3.82605"
  },
  {
    "country": "ES",
    "name": "San Juan del Puerto",
    "lat": "37.31667",
    "lng": "-6.84139"
  },
  {
    "country": "ES",
    "name": "San Juan de la Rambla",
    "lat": "28.39276",
    "lng": "-16.65015"
  },
  {
    "country": "ES",
    "name": "San Juan de Énova",
    "lat": "39.07104",
    "lng": "-0.48705"
  },
  {
    "country": "ES",
    "name": "San Juan de Aznalfarache",
    "lat": "37.35813",
    "lng": "-6.03731"
  },
  {
    "country": "ES",
    "name": "San Juan de Alicante",
    "lat": "38.40148",
    "lng": "-0.43623"
  },
  {
    "country": "ES",
    "name": "Sant Joan de Labritja",
    "lat": "39.07891",
    "lng": "1.51397"
  },
  {
    "country": "ES",
    "name": "Sant Joan",
    "lat": "39.59621",
    "lng": "3.0392"
  },
  {
    "country": "ES",
    "name": "Sant Josep de sa Talaia",
    "lat": "38.92239",
    "lng": "1.29437"
  },
  {
    "country": "ES",
    "name": "San José",
    "lat": "36.76048",
    "lng": "-2.10912"
  },
  {
    "country": "ES",
    "name": "San Javier",
    "lat": "37.80626",
    "lng": "-0.83736"
  },
  {
    "country": "ES",
    "name": "San Isidro",
    "lat": "28.07617",
    "lng": "-16.558"
  },
  {
    "country": "ES",
    "name": "Sant Francesc de Formentera",
    "lat": "38.70566",
    "lng": "1.42893"
  },
  {
    "country": "ES",
    "name": "San Fernando",
    "lat": "36.4759",
    "lng": "-6.19817"
  },
  {
    "country": "ES",
    "name": "Sanet y Negrals",
    "lat": "38.81967",
    "lng": "-0.03406"
  },
  {
    "country": "ES",
    "name": "La Laguna",
    "lat": "28.4853",
    "lng": "-16.32014"
  },
  {
    "country": "ES",
    "name": "San Clemente",
    "lat": "39.4041",
    "lng": "-2.42819"
  },
  {
    "country": "ES",
    "name": "Sencelles",
    "lat": "39.64598",
    "lng": "2.89769"
  },
  {
    "country": "ES",
    "name": "San Carlos del Valle",
    "lat": "38.84399",
    "lng": "-3.24148"
  },
  {
    "country": "ES",
    "name": "San Bartolomé de Tirajana",
    "lat": "27.92481",
    "lng": "-15.57329"
  },
  {
    "country": "ES",
    "name": "San Bartolomé de la Torre",
    "lat": "37.44515",
    "lng": "-7.10597"
  },
  {
    "country": "ES",
    "name": "San Bartolomé de las Abiertas",
    "lat": "39.82972",
    "lng": "-4.71901"
  },
  {
    "country": "ES",
    "name": "San Bartolomé",
    "lat": "29.00093",
    "lng": "-13.613"
  },
  {
    "country": "ES",
    "name": "Sant Antoni de Portmany",
    "lat": "38.98068",
    "lng": "1.30362"
  },
  {
    "country": "ES",
    "name": "Salvatierra de Santiago",
    "lat": "39.30363",
    "lng": "-6.03206"
  },
  {
    "country": "ES",
    "name": "Salvatierra de los Barros",
    "lat": "38.49091",
    "lng": "-6.68423"
  },
  {
    "country": "ES",
    "name": "Salvaleón",
    "lat": "38.5102",
    "lng": "-6.78627"
  },
  {
    "country": "ES",
    "name": "Salteras",
    "lat": "37.4206",
    "lng": "-6.11049"
  },
  {
    "country": "ES",
    "name": "Salorino",
    "lat": "39.48018",
    "lng": "-7.00758"
  },
  {
    "country": "ES",
    "name": "Salobreña",
    "lat": "36.74277",
    "lng": "-3.58717"
  },
  {
    "country": "ES",
    "name": "Salobre",
    "lat": "38.59297",
    "lng": "-2.55038"
  },
  {
    "country": "ES",
    "name": "Salinas",
    "lat": "38.52025",
    "lng": "-0.91202"
  },
  {
    "country": "ES",
    "name": "Salares",
    "lat": "36.85463",
    "lng": "-4.02434"
  },
  {
    "country": "ES",
    "name": "Salar",
    "lat": "37.15036",
    "lng": "-4.06576"
  },
  {
    "country": "ES",
    "name": "Sagunto",
    "lat": "39.68333",
    "lng": "-0.26667"
  },
  {
    "country": "ES",
    "name": "Sagra",
    "lat": "38.81102",
    "lng": "-0.06559"
  },
  {
    "country": "ES",
    "name": "Saelices",
    "lat": "39.92061",
    "lng": "-2.80502"
  },
  {
    "country": "ES",
    "name": "Saceruela",
    "lat": "38.94382",
    "lng": "-4.60768"
  },
  {
    "country": "ES",
    "name": "Sacañet",
    "lat": "39.86667",
    "lng": "-0.71667"
  },
  {
    "country": "ES",
    "name": "Sabiote",
    "lat": "38.06916",
    "lng": "-3.31448"
  },
  {
    "country": "ES",
    "name": "Rute",
    "lat": "37.3269",
    "lng": "-4.36827"
  },
  {
    "country": "ES",
    "name": "Rus",
    "lat": "38.04759",
    "lng": "-3.46254"
  },
  {
    "country": "ES",
    "name": "Ruidera",
    "lat": "38.97775",
    "lng": "-2.88321"
  },
  {
    "country": "ES",
    "name": "Rugat",
    "lat": "38.87933",
    "lng": "-0.36115"
  },
  {
    "country": "ES",
    "name": "Rubite",
    "lat": "36.80947",
    "lng": "-3.34816"
  },
  {
    "country": "ES",
    "name": "Ruanes",
    "lat": "39.32814",
    "lng": "-6.01347"
  },
  {
    "country": "ES",
    "name": "Rozalén del Monte",
    "lat": "39.99083",
    "lng": "-2.80525"
  },
  {
    "country": "ES",
    "name": "Rótova",
    "lat": "38.93205",
    "lng": "-0.25765"
  },
  {
    "country": "ES",
    "name": "Rotglá y Corbera",
    "lat": "39.00465",
    "lng": "-0.56482"
  },
  {
    "country": "ES",
    "name": "Rota",
    "lat": "36.62545",
    "lng": "-6.3622"
  },
  {
    "country": "ES",
    "name": "Rosalejo",
    "lat": "39.4366",
    "lng": "-4.90821"
  },
  {
    "country": "ES",
    "name": "Rosal de la Frontera",
    "lat": "37.96754",
    "lng": "-7.21889"
  },
  {
    "country": "ES",
    "name": "Roquetas de Mar",
    "lat": "36.76419",
    "lng": "-2.61475"
  },
  {
    "country": "ES",
    "name": "Ronda",
    "lat": "36.74231",
    "lng": "-5.16709"
  },
  {
    "country": "ES",
    "name": "Romangordo",
    "lat": "39.74199",
    "lng": "-5.70081"
  },
  {
    "country": "ES",
    "name": "Rojales",
    "lat": "38.08799",
    "lng": "-0.72544"
  },
  {
    "country": "ES",
    "name": "Rocafort",
    "lat": "39.53333",
    "lng": "-0.4"
  },
  {
    "country": "ES",
    "name": "Robledollano",
    "lat": "39.60962",
    "lng": "-5.50855"
  },
  {
    "country": "ES",
    "name": "Robledo",
    "lat": "38.75807",
    "lng": "-2.45042"
  },
  {
    "country": "ES",
    "name": "Robledillo de Trujillo",
    "lat": "39.26956",
    "lng": "-5.98001"
  },
  {
    "country": "ES",
    "name": "Riópar",
    "lat": "38.5",
    "lng": "-2.45"
  },
  {
    "country": "ES",
    "name": "Ríolobos",
    "lat": "39.92074",
    "lng": "-6.30397"
  },
  {
    "country": "ES",
    "name": "Riola",
    "lat": "39.2",
    "lng": "-0.33333"
  },
  {
    "country": "ES",
    "name": "Rioja",
    "lat": "36.94508",
    "lng": "-2.46302"
  },
  {
    "country": "ES",
    "name": "Ríogordo",
    "lat": "36.91727",
    "lng": "-4.29318"
  },
  {
    "country": "ES",
    "name": "Rincón de la Victoria",
    "lat": "36.71715",
    "lng": "-4.27583"
  },
  {
    "country": "ES",
    "name": "Rielves",
    "lat": "39.96206",
    "lng": "-4.193"
  },
  {
    "country": "ES",
    "name": "Ricote",
    "lat": "38.15338",
    "lng": "-1.36557"
  },
  {
    "country": "ES",
    "name": "Ribera del Fresno",
    "lat": "38.55177",
    "lng": "-6.23768"
  },
  {
    "country": "ES",
    "name": "Ribarroja del Turia",
    "lat": "39.54595",
    "lng": "-0.57069"
  },
  {
    "country": "ES",
    "name": "Retuerta de Bullaque",
    "lat": "39.46363",
    "lng": "-4.41363"
  },
  {
    "country": "ES",
    "name": "Requena",
    "lat": "39.48834",
    "lng": "-1.10044"
  },
  {
    "country": "ES",
    "name": "Rena",
    "lat": "39.05252",
    "lng": "-5.80868"
  },
  {
    "country": "ES",
    "name": "Relleu",
    "lat": "38.58725",
    "lng": "-0.31157"
  },
  {
    "country": "ES",
    "name": "Reina",
    "lat": "38.18333",
    "lng": "-5.95"
  },
  {
    "country": "ES",
    "name": "Reíllo",
    "lat": "39.9",
    "lng": "-1.86667"
  },
  {
    "country": "ES",
    "name": "Redován",
    "lat": "38.11619",
    "lng": "-0.90981"
  },
  {
    "country": "ES",
    "name": "Realejo Alto",
    "lat": "28.37645",
    "lng": "-16.58575"
  },
  {
    "country": "ES",
    "name": "Real de Montroi",
    "lat": "39.33333",
    "lng": "-0.6"
  },
  {
    "country": "ES",
    "name": "Real de Gandía",
    "lat": "38.94817",
    "lng": "-0.19239"
  },
  {
    "country": "ES",
    "name": "Rágol",
    "lat": "36.99523",
    "lng": "-2.68178"
  },
  {
    "country": "ES",
    "name": "Ráfol de Salem",
    "lat": "38.86651",
    "lng": "-0.39991"
  },
  {
    "country": "ES",
    "name": "Rafelguaraf",
    "lat": "39.05126",
    "lng": "-0.45543"
  },
  {
    "country": "ES",
    "name": "Rafelcofer",
    "lat": "38.93248",
    "lng": "-0.16772"
  },
  {
    "country": "ES",
    "name": "Rafal",
    "lat": "38.10458",
    "lng": "-0.84904"
  },
  {
    "country": "ES",
    "name": "Rada de Haro",
    "lat": "39.57002",
    "lng": "-2.62086"
  },
  {
    "country": "ES",
    "name": "Quintanar del Rey",
    "lat": "39.33333",
    "lng": "-1.93333"
  },
  {
    "country": "ES",
    "name": "Quintanar de la Orden",
    "lat": "39.59369",
    "lng": "-3.04165"
  },
  {
    "country": "ES",
    "name": "Quintana de la Serena",
    "lat": "38.74595",
    "lng": "-5.67233"
  },
  {
    "country": "ES",
    "name": "Quesada",
    "lat": "37.84338",
    "lng": "-3.06561"
  },
  {
    "country": "ES",
    "name": "Quesa",
    "lat": "39.1197",
    "lng": "-0.74"
  },
  {
    "country": "ES",
    "name": "Quero",
    "lat": "39.51111",
    "lng": "-3.24741"
  },
  {
    "country": "ES",
    "name": "Quéntar",
    "lat": "37.19253",
    "lng": "-3.46653"
  },
  {
    "country": "ES",
    "name": "Puçol",
    "lat": "39.61667",
    "lng": "-0.3"
  },
  {
    "country": "ES",
    "name": "Purullena",
    "lat": "37.31763",
    "lng": "-3.19056"
  },
  {
    "country": "ES",
    "name": "Purchena",
    "lat": "37.34744",
    "lng": "-2.3608"
  },
  {
    "country": "ES",
    "name": "Puntallana",
    "lat": "28.73333",
    "lng": "-17.73333"
  },
  {
    "country": "ES",
    "name": "Puntagorda",
    "lat": "28.7749",
    "lng": "-17.97741"
  },
  {
    "country": "ES",
    "name": "Pulpí",
    "lat": "37.41154",
    "lng": "-1.74496"
  },
  {
    "country": "ES",
    "name": "Pulianas",
    "lat": "37.22302",
    "lng": "-3.60832"
  },
  {
    "country": "ES",
    "name": "Pulgar",
    "lat": "39.69383",
    "lng": "-4.15233"
  },
  {
    "country": "ES",
    "name": "Pujerra",
    "lat": "36.61274",
    "lng": "-5.14979"
  },
  {
    "country": "ES",
    "name": "Puigpunyent",
    "lat": "39.62514",
    "lng": "2.52759"
  },
  {
    "country": "ES",
    "name": "Puig",
    "lat": "39.58869",
    "lng": "-0.30333"
  },
  {
    "country": "ES",
    "name": "Puerto Serrano",
    "lat": "36.92209",
    "lng": "-5.54304"
  },
  {
    "country": "ES",
    "name": "Puerto Real",
    "lat": "36.52819",
    "lng": "-6.19011"
  },
  {
    "country": "ES",
    "name": "Puertollano",
    "lat": "38.68712",
    "lng": "-4.10734"
  },
  {
    "country": "ES",
    "name": "Puerto Lápice",
    "lat": "39.3236",
    "lng": "-3.48148"
  },
  {
    "country": "ES",
    "name": "Puerto de San Vicente",
    "lat": "39.52283",
    "lng": "-5.11407"
  },
  {
    "country": "ES",
    "name": "Puerto de Santa Cruz",
    "lat": "39.31631",
    "lng": "-5.85875"
  },
  {
    "country": "ES",
    "name": "Puerto del Rosario",
    "lat": "28.50038",
    "lng": "-13.86272"
  },
  {
    "country": "ES",
    "name": "Puerto de la Cruz",
    "lat": "28.41397",
    "lng": "-16.54867"
  },
  {
    "country": "ES",
    "name": "Puente-Genil",
    "lat": "37.38943",
    "lng": "-4.76686"
  },
  {
    "country": "ES",
    "name": "Puente de Génave",
    "lat": "38.35544",
    "lng": "-2.8032"
  },
  {
    "country": "ES",
    "name": "La Pobla Llarga",
    "lat": "39.08333",
    "lng": "-0.46667"
  },
  {
    "country": "ES",
    "name": "La Pobla de Vallbona",
    "lat": "39.59747",
    "lng": "-0.55468"
  },
  {
    "country": "ES",
    "name": "Puebla de Sancho Pérez",
    "lat": "38.4",
    "lng": "-6.4"
  },
  {
    "country": "ES",
    "name": "Puebla de Obando",
    "lat": "39.1763",
    "lng": "-6.62764"
  },
  {
    "country": "ES",
    "name": "Puebla del Salvador",
    "lat": "39.56667",
    "lng": "-1.66667"
  },
  {
    "country": "ES",
    "name": "Puebla del Prior",
    "lat": "38.57032",
    "lng": "-6.19584"
  },
  {
    "country": "ES",
    "name": "Puebla del Príncipe",
    "lat": "38.56766",
    "lng": "-2.92605"
  },
  {
    "country": "ES",
    "name": "Puebla del Maestre",
    "lat": "38.08333",
    "lng": "-6.08333"
  },
  {
    "country": "ES",
    "name": "Puebla de la Reina",
    "lat": "38.66455",
    "lng": "-6.10216"
  },
  {
    "country": "ES",
    "name": "Puebla de la Calzada",
    "lat": "38.89441",
    "lng": "-6.62592"
  },
  {
    "country": "ES",
    "name": "Puebla de Guzmán",
    "lat": "37.61427",
    "lng": "-7.24878"
  },
  {
    "country": "ES",
    "name": "Puebla de Don Rodrigo",
    "lat": "39.08564",
    "lng": "-4.61966"
  },
  {
    "country": "ES",
    "name": "Puebla de Don Fadrique",
    "lat": "37.96156",
    "lng": "-2.43961"
  },
  {
    "country": "ES",
    "name": "Puebla de Almenara",
    "lat": "39.7844",
    "lng": "-2.81435"
  },
  {
    "country": "ES",
    "name": "Puebla de Alcocer",
    "lat": "38.98648",
    "lng": "-5.25633"
  },
  {
    "country": "ES",
    "name": "Pruna",
    "lat": "36.97226",
    "lng": "-5.2223"
  },
  {
    "country": "ES",
    "name": "Priego de Córdoba",
    "lat": "37.43807",
    "lng": "-4.19523"
  },
  {
    "country": "ES",
    "name": "Prado del Rey",
    "lat": "36.78756",
    "lng": "-5.55589"
  },
  {
    "country": "ES",
    "name": "Pozuelo de Calatrava",
    "lat": "38.58333",
    "lng": "-3.83333"
  },
  {
    "country": "ES",
    "name": "Pozuelo",
    "lat": "38.80989",
    "lng": "-2.10101"
  },
  {
    "country": "ES",
    "name": "Pozorrubio",
    "lat": "39.81645",
    "lng": "-2.94936"
  },
  {
    "country": "ES",
    "name": "Pozohondo",
    "lat": "38.72095",
    "lng": "-1.91192"
  },
  {
    "country": "ES",
    "name": "Pozo-Cañada",
    "lat": "38.80333",
    "lng": "-1.73532"
  },
  {
    "country": "ES",
    "name": "Pozoblanco",
    "lat": "38.37906",
    "lng": "-4.84827"
  },
  {
    "country": "ES",
    "name": "Pozoamargo",
    "lat": "39.36558",
    "lng": "-2.19617"
  },
  {
    "country": "ES",
    "name": "Pozo Alcón",
    "lat": "37.70256",
    "lng": "-2.93367"
  },
  {
    "country": "ES",
    "name": "Povedilla",
    "lat": "38.70022",
    "lng": "-2.60212"
  },
  {
    "country": "ES",
    "name": "Potríes",
    "lat": "38.91617",
    "lng": "-0.19594"
  },
  {
    "country": "ES",
    "name": "Posadas",
    "lat": "37.80205",
    "lng": "-5.10726"
  },
  {
    "country": "ES",
    "name": "Porzuna",
    "lat": "39.14618",
    "lng": "-4.15407"
  },
  {
    "country": "ES",
    "name": "Pórtugos",
    "lat": "36.94193",
    "lng": "-3.31066"
  },
  {
    "country": "ES",
    "name": "Porto Cristo",
    "lat": "39.53953",
    "lng": "3.33302"
  },
  {
    "country": "ES",
    "name": "Portezuelo",
    "lat": "39.81233",
    "lng": "-6.47433"
  },
  {
    "country": "ES",
    "name": "Portaje",
    "lat": "39.91757",
    "lng": "-6.56218"
  },
  {
    "country": "ES",
    "name": "Porreres",
    "lat": "39.51434",
    "lng": "3.02197"
  },
  {
    "country": "ES",
    "name": "Porcuna",
    "lat": "37.87102",
    "lng": "-4.18501"
  },
  {
    "country": "ES",
    "name": "Polopos",
    "lat": "36.79466",
    "lng": "-3.29816"
  },
  {
    "country": "ES",
    "name": "Polop",
    "lat": "38.62258",
    "lng": "-0.1309"
  },
  {
    "country": "ES",
    "name": "Pollença",
    "lat": "39.87678",
    "lng": "3.01626"
  },
  {
    "country": "ES",
    "name": "Polinyà de Xúquer",
    "lat": "39.2",
    "lng": "-0.36667"
  },
  {
    "country": "ES",
    "name": "Polícar",
    "lat": "37.25759",
    "lng": "-3.23375"
  },
  {
    "country": "ES",
    "name": "Polán",
    "lat": "39.78765",
    "lng": "-4.16792"
  },
  {
    "country": "ES",
    "name": "Poblete",
    "lat": "38.9355",
    "lng": "-3.98137"
  },
  {
    "country": "ES",
    "name": "Pliego",
    "lat": "37.98946",
    "lng": "-1.50444"
  },
  {
    "country": "ES",
    "name": "Playa Blanca",
    "lat": "28.86426",
    "lng": "-13.82814"
  },
  {
    "country": "ES",
    "name": "Plasenzuela",
    "lat": "39.38194",
    "lng": "-6.04786"
  },
  {
    "country": "ES",
    "name": "Planes",
    "lat": "38.78524",
    "lng": "-0.34271"
  },
  {
    "country": "ES",
    "name": "Pizarra",
    "lat": "36.76543",
    "lng": "-4.70833"
  },
  {
    "country": "ES",
    "name": "Piqueras del Castillo",
    "lat": "39.71667",
    "lng": "-2.06667"
  },
  {
    "country": "ES",
    "name": "Pinos Puente",
    "lat": "37.25109",
    "lng": "-3.74967"
  },
  {
    "country": "ES",
    "name": "Pinoso",
    "lat": "38.40164",
    "lng": "-1.04196"
  },
  {
    "country": "ES",
    "name": "Pinos Genil",
    "lat": "37.16346",
    "lng": "-3.50215"
  },
  {
    "country": "ES",
    "name": "Pinet",
    "lat": "38.98176",
    "lng": "-0.3387"
  },
  {
    "country": "ES",
    "name": "Pinarejo",
    "lat": "39.61639",
    "lng": "-2.42592"
  },
  {
    "country": "ES",
    "name": "Piñar",
    "lat": "37.44457",
    "lng": "-3.43861"
  },
  {
    "country": "ES",
    "name": "Piles",
    "lat": "38.94143",
    "lng": "-0.13286"
  },
  {
    "country": "ES",
    "name": "Pilas",
    "lat": "37.30337",
    "lng": "-6.30097"
  },
  {
    "country": "ES",
    "name": "Pilar de la Horadada",
    "lat": "37.86591",
    "lng": "-0.79256"
  },
  {
    "country": "ES",
    "name": "Piedras Albas",
    "lat": "39.78417",
    "lng": "-6.92588"
  },
  {
    "country": "ES",
    "name": "Piedrabuena",
    "lat": "39.03536",
    "lng": "-4.17512"
  },
  {
    "country": "ES",
    "name": "Picón",
    "lat": "39.05074",
    "lng": "-4.06084"
  },
  {
    "country": "ES",
    "name": "Picassent",
    "lat": "39.3635",
    "lng": "-0.45949"
  },
  {
    "country": "ES",
    "name": "Picanya",
    "lat": "39.43333",
    "lng": "-0.43333"
  },
  {
    "country": "ES",
    "name": "Pétrola",
    "lat": "38.82628",
    "lng": "-1.55662"
  },
  {
    "country": "ES",
    "name": "Petrés",
    "lat": "39.68333",
    "lng": "-0.3"
  },
  {
    "country": "ES",
    "name": "Petra",
    "lat": "39.61351",
    "lng": "3.11312"
  },
  {
    "country": "ES",
    "name": "Pescueza",
    "lat": "39.91807",
    "lng": "-6.64589"
  },
  {
    "country": "ES",
    "name": "Periana",
    "lat": "36.92931",
    "lng": "-4.19163"
  },
  {
    "country": "ES",
    "name": "Peraleda de San Román",
    "lat": "39.7413",
    "lng": "-5.38726"
  },
  {
    "country": "ES",
    "name": "Peraleda de la Mata",
    "lat": "39.85288",
    "lng": "-5.46065"
  },
  {
    "country": "ES",
    "name": "Peñas de San Pedro",
    "lat": "38.7288",
    "lng": "-2.005"
  },
  {
    "country": "ES",
    "name": "Peñarroya-Pueblonuevo",
    "lat": "38.3",
    "lng": "-5.26667"
  },
  {
    "country": "ES",
    "name": "Peñalsordo",
    "lat": "38.82019",
    "lng": "-5.11405"
  },
  {
    "country": "ES",
    "name": "Peñaflor",
    "lat": "37.70892",
    "lng": "-5.34504"
  },
  {
    "country": "ES",
    "name": "Peligros",
    "lat": "37.23231",
    "lng": "-3.62901"
  },
  {
    "country": "ES",
    "name": "Pegalajar",
    "lat": "37.74008",
    "lng": "-3.64946"
  },
  {
    "country": "ES",
    "name": "Pedroso de Acim",
    "lat": "39.82522",
    "lng": "-6.41251"
  },
  {
    "country": "ES",
    "name": "Pedro Muñoz",
    "lat": "39.40285",
    "lng": "-2.94664"
  },
  {
    "country": "ES",
    "name": "Pedro Martínez",
    "lat": "37.5029",
    "lng": "-3.23134"
  },
  {
    "country": "ES",
    "name": "Pedroche",
    "lat": "38.42848",
    "lng": "-4.76325"
  },
  {
    "country": "ES",
    "name": "Pedro Abad",
    "lat": "37.96686",
    "lng": "-4.4556"
  },
  {
    "country": "ES",
    "name": "Pedrera",
    "lat": "37.22604",
    "lng": "-4.8942"
  },
  {
    "country": "ES",
    "name": "Pedreguer",
    "lat": "38.79312",
    "lng": "0.03411"
  },
  {
    "country": "ES",
    "name": "Pedralba",
    "lat": "39.6",
    "lng": "-0.71667"
  },
  {
    "country": "ES",
    "name": "Pechina",
    "lat": "36.91619",
    "lng": "-2.43689"
  },
  {
    "country": "ES",
    "name": "Peal de Becerro",
    "lat": "37.91338",
    "lng": "-3.12148"
  },
  {
    "country": "ES",
    "name": "Paymogo",
    "lat": "37.73999",
    "lng": "-7.34499"
  },
  {
    "country": "ES",
    "name": "Pavías",
    "lat": "39.96667",
    "lng": "-0.48333"
  },
  {
    "country": "ES",
    "name": "Paterna de Rivera",
    "lat": "36.52246",
    "lng": "-5.86578"
  },
  {
    "country": "ES",
    "name": "Paterna del Río",
    "lat": "37.02222",
    "lng": "-2.95343"
  },
  {
    "country": "ES",
    "name": "Paterna del Madera",
    "lat": "38.59751",
    "lng": "-2.34421"
  },
  {
    "country": "ES",
    "name": "Paterna del Campo",
    "lat": "37.41948",
    "lng": "-6.40248"
  },
  {
    "country": "ES",
    "name": "Paterna",
    "lat": "39.5",
    "lng": "-0.43333"
  },
  {
    "country": "ES",
    "name": "Partaloa",
    "lat": "37.40764",
    "lng": "-2.22526"
  },
  {
    "country": "ES",
    "name": "Parcent",
    "lat": "38.74502",
    "lng": "-0.06446"
  },
  {
    "country": "ES",
    "name": "Parauta",
    "lat": "36.65629",
    "lng": "-5.12916"
  },
  {
    "country": "ES",
    "name": "Paradas",
    "lat": "37.29047",
    "lng": "-5.49703"
  },
  {
    "country": "ES",
    "name": "Paracuellos",
    "lat": "39.71667",
    "lng": "-1.78333"
  },
  {
    "country": "ES",
    "name": "Pampaneira",
    "lat": "36.94015",
    "lng": "-3.36096"
  },
  {
    "country": "ES",
    "name": "Palos de la Frontera",
    "lat": "37.23457",
    "lng": "-6.89471"
  },
  {
    "country": "ES",
    "name": "Palomas",
    "lat": "38.69277",
    "lng": "-6.1349"
  },
  {
    "country": "ES",
    "name": "Palomares del Río",
    "lat": "37.32225",
    "lng": "-6.05863"
  },
  {
    "country": "ES",
    "name": "Palomares del Campo",
    "lat": "39.94664",
    "lng": "-2.59776"
  },
  {
    "country": "ES",
    "name": "Palmera",
    "lat": "38.93927",
    "lng": "-0.15411"
  },
  {
    "country": "ES",
    "name": "Palma",
    "lat": "39.56939",
    "lng": "2.65024"
  },
  {
    "country": "ES",
    "name": "Palma del Río",
    "lat": "37.70024",
    "lng": "-5.28121"
  },
  {
    "country": "ES",
    "name": "Palma de Gandía",
    "lat": "38.92672",
    "lng": "-0.22028"
  },
  {
    "country": "ES",
    "name": "Palenciana",
    "lat": "37.24851",
    "lng": "-4.58261"
  },
  {
    "country": "ES",
    "name": "Pajaroncillo",
    "lat": "39.95",
    "lng": "-1.73333"
  },
  {
    "country": "ES",
    "name": "Pajarón",
    "lat": "39.95",
    "lng": "-1.78333"
  },
  {
    "country": "ES",
    "name": "Pájara",
    "lat": "28.35039",
    "lng": "-14.1076"
  },
  {
    "country": "ES",
    "name": "Paiporta",
    "lat": "39.42814",
    "lng": "-0.41765"
  },
  {
    "country": "ES",
    "name": "Padules",
    "lat": "36.99813",
    "lng": "-2.77367"
  },
  {
    "country": "ES",
    "name": "Padul",
    "lat": "37.02462",
    "lng": "-3.62678"
  },
  {
    "country": "ES",
    "name": "Otura",
    "lat": "37.08846",
    "lng": "-3.63321"
  },
  {
    "country": "ES",
    "name": "Otos",
    "lat": "38.85427",
    "lng": "-0.44399"
  },
  {
    "country": "ES",
    "name": "Otívar",
    "lat": "36.81582",
    "lng": "-3.67979"
  },
  {
    "country": "ES",
    "name": "Otero",
    "lat": "40.00096",
    "lng": "-4.51539"
  },
  {
    "country": "ES",
    "name": "Osuna",
    "lat": "37.2376",
    "lng": "-5.10311"
  },
  {
    "country": "ES",
    "name": "Ossa de Montiel",
    "lat": "38.96398",
    "lng": "-2.74553"
  },
  {
    "country": "ES",
    "name": "Osa de la Vega",
    "lat": "39.65977",
    "lng": "-2.75998"
  },
  {
    "country": "ES",
    "name": "Oropesa",
    "lat": "39.91726",
    "lng": "-5.17371"
  },
  {
    "country": "ES",
    "name": "Órjiva",
    "lat": "36.90259",
    "lng": "-3.42379"
  },
  {
    "country": "ES",
    "name": "Orihuela",
    "lat": "38.08483",
    "lng": "-0.94401"
  },
  {
    "country": "ES",
    "name": "Oria",
    "lat": "37.4853",
    "lng": "-2.29292"
  },
  {
    "country": "ES",
    "name": "Orgaz",
    "lat": "39.64826",
    "lng": "-3.87577"
  },
  {
    "country": "ES",
    "name": "Orellana la Vieja",
    "lat": "39.00617",
    "lng": "-5.53441"
  },
  {
    "country": "ES",
    "name": "Orcheta",
    "lat": "38.56397",
    "lng": "-0.26299"
  },
  {
    "country": "ES",
    "name": "Orcera",
    "lat": "38.31742",
    "lng": "-2.66487"
  },
  {
    "country": "ES",
    "name": "Orce",
    "lat": "37.7212",
    "lng": "-2.47752"
  },
  {
    "country": "ES",
    "name": "Orba",
    "lat": "38.78041",
    "lng": "-0.06278"
  },
  {
    "country": "ES",
    "name": "Ontur",
    "lat": "38.61509",
    "lng": "-1.49724"
  },
  {
    "country": "ES",
    "name": "Ontígola",
    "lat": "40.00421",
    "lng": "-3.57227"
  },
  {
    "country": "ES",
    "name": "Ontinyent",
    "lat": "38.82191",
    "lng": "-0.60603"
  },
  {
    "country": "ES",
    "name": "Onil",
    "lat": "38.62606",
    "lng": "-0.67313"
  },
  {
    "country": "ES",
    "name": "Ondara",
    "lat": "38.82817",
    "lng": "0.0172"
  },
  {
    "country": "ES",
    "name": "Onda",
    "lat": "39.96495",
    "lng": "-0.26041"
  },
  {
    "country": "ES",
    "name": "Olvera",
    "lat": "36.93418",
    "lng": "-5.26678"
  },
  {
    "country": "ES",
    "name": "Olula del Río",
    "lat": "37.35445",
    "lng": "-2.29754"
  },
  {
    "country": "ES",
    "name": "Olula de Castro",
    "lat": "37.17475",
    "lng": "-2.4743"
  },
  {
    "country": "ES",
    "name": "Olocau",
    "lat": "39.7",
    "lng": "-0.53333"
  },
  {
    "country": "ES",
    "name": "Olmedilla de Alarcón",
    "lat": "39.61667",
    "lng": "-2.1"
  },
  {
    "country": "ES",
    "name": "Olmeda del Rey",
    "lat": "39.8",
    "lng": "-2.08333"
  },
  {
    "country": "ES",
    "name": "L'Olleria",
    "lat": "38.91667",
    "lng": "-0.55"
  },
  {
    "country": "ES",
    "name": "Olivares de Júcar",
    "lat": "39.76101",
    "lng": "-2.35589"
  },
  {
    "country": "ES",
    "name": "Olivares",
    "lat": "37.41802",
    "lng": "-6.15603"
  },
  {
    "country": "ES",
    "name": "Oliva de Mérida",
    "lat": "38.79051",
    "lng": "-6.12402"
  },
  {
    "country": "ES",
    "name": "Oliva de la Frontera",
    "lat": "38.27595",
    "lng": "-6.91873"
  },
  {
    "country": "ES",
    "name": "Oliva",
    "lat": "38.91971",
    "lng": "-0.11935"
  },
  {
    "country": "ES",
    "name": "Olías del Rey",
    "lat": "39.94436",
    "lng": "-3.98684"
  },
  {
    "country": "ES",
    "name": "Ojós",
    "lat": "38.147",
    "lng": "-1.34261"
  },
  {
    "country": "ES",
    "name": "Ojén",
    "lat": "36.56486",
    "lng": "-4.85561"
  },
  {
    "country": "ES",
    "name": "Ohanes",
    "lat": "37.03861",
    "lng": "-2.74524"
  },
  {
    "country": "ES",
    "name": "Ogíjares",
    "lat": "37.11913",
    "lng": "-3.60772"
  },
  {
    "country": "ES",
    "name": "Ocaña",
    "lat": "39.95785",
    "lng": "-3.4982"
  },
  {
    "country": "ES",
    "name": "Obejo",
    "lat": "38.13265",
    "lng": "-4.80018"
  },
  {
    "country": "ES",
    "name": "Nules",
    "lat": "39.85362",
    "lng": "-0.15643"
  },
  {
    "country": "ES",
    "name": "Nueva-Carteya",
    "lat": "37.5863",
    "lng": "-4.46759"
  },
  {
    "country": "ES",
    "name": "Novelda",
    "lat": "38.38479",
    "lng": "-0.76773"
  },
  {
    "country": "ES",
    "name": "Nogales",
    "lat": "38.58629",
    "lng": "-6.74901"
  },
  {
    "country": "ES",
    "name": "Noez",
    "lat": "39.74094",
    "lng": "-4.18408"
  },
  {
    "country": "ES",
    "name": "Noblejas",
    "lat": "39.98061",
    "lng": "-3.44001"
  },
  {
    "country": "ES",
    "name": "Noalejo",
    "lat": "37.53017",
    "lng": "-3.65615"
  },
  {
    "country": "ES",
    "name": "Nívar",
    "lat": "37.25909",
    "lng": "-3.57768"
  },
  {
    "country": "ES",
    "name": "Níjar",
    "lat": "36.96655",
    "lng": "-2.20595"
  },
  {
    "country": "ES",
    "name": "Nigüelas",
    "lat": "36.9776",
    "lng": "-3.53949"
  },
  {
    "country": "ES",
    "name": "Niebla",
    "lat": "37.36213",
    "lng": "-6.67894"
  },
  {
    "country": "ES",
    "name": "Nerva",
    "lat": "37.69627",
    "lng": "-6.54967"
  },
  {
    "country": "ES",
    "name": "Nerpio",
    "lat": "38.14751",
    "lng": "-2.30202"
  },
  {
    "country": "ES",
    "name": "Nerja",
    "lat": "36.75278",
    "lng": "-3.8744"
  },
  {
    "country": "ES",
    "name": "Nazaret",
    "lat": "29.03818",
    "lng": "-13.56386"
  },
  {
    "country": "ES",
    "name": "Navezuelas",
    "lat": "39.50918",
    "lng": "-5.43766"
  },
  {
    "country": "ES",
    "name": "Navas del Madroño",
    "lat": "39.6229",
    "lng": "-6.6526"
  },
  {
    "country": "ES",
    "name": "Navas de Jorquera",
    "lat": "39.28333",
    "lng": "-1.71667"
  },
  {
    "country": "ES",
    "name": "Navas de Estena",
    "lat": "39.49481",
    "lng": "-4.52155"
  },
  {
    "country": "ES",
    "name": "Navarrés",
    "lat": "39.10198",
    "lng": "-0.69469"
  },
  {
    "country": "ES",
    "name": "Navalvillar de Pela",
    "lat": "39.09436",
    "lng": "-5.4681"
  },
  {
    "country": "ES",
    "name": "Navalvillar de Ibor",
    "lat": "39.58389",
    "lng": "-5.41328"
  },
  {
    "country": "ES",
    "name": "Navalpino",
    "lat": "39.22573",
    "lng": "-4.59133"
  },
  {
    "country": "ES",
    "name": "Navalmoralejo",
    "lat": "39.73929",
    "lng": "-5.14359"
  },
  {
    "country": "ES",
    "name": "Navalmoral de la Mata",
    "lat": "39.89158",
    "lng": "-5.54064"
  },
  {
    "country": "ES",
    "name": "Navajas",
    "lat": "39.88333",
    "lng": "-0.5"
  },
  {
    "country": "ES",
    "name": "Navahermosa",
    "lat": "39.63526",
    "lng": "-4.47012"
  },
  {
    "country": "ES",
    "name": "Narboneta",
    "lat": "39.75",
    "lng": "-1.46667"
  },
  {
    "country": "ES",
    "name": "Náquera",
    "lat": "39.65",
    "lng": "-0.41667"
  },
  {
    "country": "ES",
    "name": "Nambroca",
    "lat": "39.79771",
    "lng": "-3.94434"
  },
  {
    "country": "ES",
    "name": "Museros",
    "lat": "39.56667",
    "lng": "-0.35"
  },
  {
    "country": "ES",
    "name": "Murtas",
    "lat": "36.88504",
    "lng": "-3.10945"
  },
  {
    "country": "ES",
    "name": "Muro del Alcoy",
    "lat": "38.7812",
    "lng": "-0.43608"
  },
  {
    "country": "ES",
    "name": "Muro",
    "lat": "39.73661",
    "lng": "3.05559"
  },
  {
    "country": "ES",
    "name": "Murla",
    "lat": "38.76037",
    "lng": "-0.08208"
  },
  {
    "country": "ES",
    "name": "Murcia",
    "lat": "37.98704",
    "lng": "-1.13004"
  },
  {
    "country": "ES",
    "name": "Munera",
    "lat": "39.04217",
    "lng": "-2.48068"
  },
  {
    "country": "ES",
    "name": "Mula",
    "lat": "38.04095",
    "lng": "-1.49014"
  },
  {
    "country": "ES",
    "name": "Mutxamel",
    "lat": "38.4158",
    "lng": "-0.44529"
  },
  {
    "country": "ES",
    "name": "Moya",
    "lat": "39.95",
    "lng": "-1.36667"
  },
  {
    "country": "ES",
    "name": "Moya",
    "lat": "28.10136",
    "lng": "-15.58917"
  },
  {
    "country": "ES",
    "name": "Motril",
    "lat": "36.75066",
    "lng": "-3.5179"
  },
  {
    "country": "ES",
    "name": "Motilleja",
    "lat": "39.18333",
    "lng": "-1.78333"
  },
  {
    "country": "ES",
    "name": "Motilla del Palancar",
    "lat": "39.56667",
    "lng": "-1.88333"
  },
  {
    "country": "ES",
    "name": "Mota del Cuervo",
    "lat": "39.50189",
    "lng": "-2.86994"
  },
  {
    "country": "ES",
    "name": "Mota de Altarejos",
    "lat": "39.88201",
    "lng": "-2.30958"
  },
  {
    "country": "ES",
    "name": "Morón de la Frontera",
    "lat": "37.12084",
    "lng": "-5.45403"
  },
  {
    "country": "ES",
    "name": "Moraira",
    "lat": "38.68866",
    "lng": "0.13484"
  },
  {
    "country": "ES",
    "name": "Moratalla",
    "lat": "38.18928",
    "lng": "-1.89183"
  },
  {
    "country": "ES",
    "name": "Moraleda de Zafayona",
    "lat": "37.16723",
    "lng": "-3.96505"
  },
  {
    "country": "ES",
    "name": "Moral de Calatrava",
    "lat": "38.82989",
    "lng": "-3.57813"
  },
  {
    "country": "ES",
    "name": "Mora",
    "lat": "39.68492",
    "lng": "-3.77394"
  },
  {
    "country": "ES",
    "name": "Monturque",
    "lat": "37.47186",
    "lng": "-4.58164"
  },
  {
    "country": "ES",
    "name": "Montuïri",
    "lat": "39.56742",
    "lng": "2.98189"
  },
  {
    "country": "ES",
    "name": "Montroy",
    "lat": "39.33333",
    "lng": "-0.61667"
  },
  {
    "country": "ES",
    "name": "Montoro",
    "lat": "38.02409",
    "lng": "-4.3834"
  },
  {
    "country": "ES",
    "name": "Montizón",
    "lat": "38.34249",
    "lng": "-3.10404"
  },
  {
    "country": "ES",
    "name": "Montillana",
    "lat": "37.50168",
    "lng": "-3.67368"
  },
  {
    "country": "ES",
    "name": "Montilla",
    "lat": "37.58627",
    "lng": "-4.63805"
  },
  {
    "country": "ES",
    "name": "Montijo",
    "lat": "38.90839",
    "lng": "-6.61785"
  },
  {
    "country": "ES",
    "name": "Montiel",
    "lat": "38.69802",
    "lng": "-2.86441"
  },
  {
    "country": "ES",
    "name": "Montichelvo",
    "lat": "38.89129",
    "lng": "-0.34123"
  },
  {
    "country": "ES",
    "name": "Montesa",
    "lat": "38.9503",
    "lng": "-0.652"
  },
  {
    "country": "ES",
    "name": "Monterrubio de la Serena",
    "lat": "38.58876",
    "lng": "-5.44569"
  },
  {
    "country": "ES",
    "name": "Montemolín",
    "lat": "38.15",
    "lng": "-6.2"
  },
  {
    "country": "ES",
    "name": "Montemayor",
    "lat": "37.6479",
    "lng": "-4.69779"
  },
  {
    "country": "ES",
    "name": "Montellano",
    "lat": "36.99531",
    "lng": "-5.57145"
  },
  {
    "country": "ES",
    "name": "Montejicar",
    "lat": "37.57223",
    "lng": "-3.50527"
  },
  {
    "country": "ES",
    "name": "Montejaque",
    "lat": "36.73684",
    "lng": "-5.2499"
  },
  {
    "country": "ES",
    "name": "Montefrío",
    "lat": "37.32308",
    "lng": "-4.00898"
  },
  {
    "country": "ES",
    "name": "Montecorto",
    "lat": "36.8158",
    "lng": "-5.29803"
  },
  {
    "country": "ES",
    "name": "Montearagón",
    "lat": "39.96425",
    "lng": "-4.63214"
  },
  {
    "country": "ES",
    "name": "Montealegre del Castillo",
    "lat": "38.78856",
    "lng": "-1.32722"
  },
  {
    "country": "ES",
    "name": "Monteagudo de las Salinas",
    "lat": "39.8",
    "lng": "-1.9"
  },
  {
    "country": "ES",
    "name": "Montánchez",
    "lat": "39.22548",
    "lng": "-6.14914"
  },
  {
    "country": "ES",
    "name": "Montalvos",
    "lat": "39.16667",
    "lng": "-2.01667"
  },
  {
    "country": "ES",
    "name": "Montalbo",
    "lat": "39.87994",
    "lng": "-2.67038"
  },
  {
    "country": "ES",
    "name": "Montalbanejo",
    "lat": "39.73369",
    "lng": "-2.49911"
  },
  {
    "country": "ES",
    "name": "Montalbán de Córdoba",
    "lat": "37.57996",
    "lng": "-4.74935"
  },
  {
    "country": "ES",
    "name": "Montaberner",
    "lat": "38.89021",
    "lng": "-0.49582"
  },
  {
    "country": "ES",
    "name": "Monserrat",
    "lat": "39.36667",
    "lng": "-0.6"
  },
  {
    "country": "ES",
    "name": "Monreal del Llano",
    "lat": "39.56888",
    "lng": "-2.76046"
  },
  {
    "country": "ES",
    "name": "Monóvar",
    "lat": "38.43809",
    "lng": "-0.84062"
  },
  {
    "country": "ES",
    "name": "Monforte del Cid",
    "lat": "38.38027",
    "lng": "-0.7285"
  },
  {
    "country": "ES",
    "name": "Monesterio",
    "lat": "38.08333",
    "lng": "-6.26667"
  },
  {
    "country": "ES",
    "name": "Monda",
    "lat": "36.63027",
    "lng": "-4.83192"
  },
  {
    "country": "ES",
    "name": "Moncofa",
    "lat": "39.80907",
    "lng": "-0.14701"
  },
  {
    "country": "ES",
    "name": "Moncada",
    "lat": "39.54555",
    "lng": "-0.39551"
  },
  {
    "country": "ES",
    "name": "Monachil",
    "lat": "37.1332",
    "lng": "-3.53724"
  },
  {
    "country": "ES",
    "name": "Molvízar",
    "lat": "36.78592",
    "lng": "-3.60783"
  },
  {
    "country": "ES",
    "name": "Mollina",
    "lat": "37.12534",
    "lng": "-4.65686"
  },
  {
    "country": "ES",
    "name": "Molinicos",
    "lat": "38.46717",
    "lng": "-2.23939"
  },
  {
    "country": "ES",
    "name": "Es Molinar",
    "lat": "39.5614",
    "lng": "2.67517"
  },
  {
    "country": "ES",
    "name": "Molina de Segura",
    "lat": "38.05456",
    "lng": "-1.20763"
  },
  {
    "country": "ES",
    "name": "Mojacar",
    "lat": "37.1402",
    "lng": "-1.85102"
  },
  {
    "country": "ES",
    "name": "Mohedas de la Jara",
    "lat": "39.60417",
    "lng": "-5.14247"
  },
  {
    "country": "ES",
    "name": "Moguer",
    "lat": "37.27559",
    "lng": "-6.83851"
  },
  {
    "country": "ES",
    "name": "Mogente",
    "lat": "38.87598",
    "lng": "-0.7515"
  },
  {
    "country": "ES",
    "name": "Mogán",
    "lat": "27.88385",
    "lng": "-15.72538"
  },
  {
    "country": "ES",
    "name": "Moclinejo",
    "lat": "36.77134",
    "lng": "-4.25514"
  },
  {
    "country": "ES",
    "name": "Moclín",
    "lat": "37.33959",
    "lng": "-3.78651"
  },
  {
    "country": "ES",
    "name": "Mocejón",
    "lat": "39.93934",
    "lng": "-3.91716"
  },
  {
    "country": "ES",
    "name": "Mislata",
    "lat": "39.47523",
    "lng": "-0.41825"
  },
  {
    "country": "ES",
    "name": "Mirandilla",
    "lat": "39.002",
    "lng": "-6.28893"
  },
  {
    "country": "ES",
    "name": "Miramar",
    "lat": "38.95036",
    "lng": "-0.14007"
  },
  {
    "country": "ES",
    "name": "Mirabel",
    "lat": "39.8623",
    "lng": "-6.23274"
  },
  {
    "country": "ES",
    "name": "Mira",
    "lat": "39.71667",
    "lng": "-1.43333"
  },
  {
    "country": "ES",
    "name": "Minglanilla",
    "lat": "39.53333",
    "lng": "-1.6"
  },
  {
    "country": "ES",
    "name": "Minaya",
    "lat": "39.27052",
    "lng": "-2.32176"
  },
  {
    "country": "ES",
    "name": "Millena",
    "lat": "38.73082",
    "lng": "-0.36274"
  },
  {
    "country": "ES",
    "name": "Millares",
    "lat": "39.25",
    "lng": "-0.76667"
  },
  {
    "country": "ES",
    "name": "Millanes",
    "lat": "39.84917",
    "lng": "-5.58079"
  },
  {
    "country": "ES",
    "name": "Mijas",
    "lat": "36.59575",
    "lng": "-4.63728"
  },
  {
    "country": "ES",
    "name": "Miguelturra",
    "lat": "38.96442",
    "lng": "-3.89047"
  },
  {
    "country": "ES",
    "name": "Miguel Esteban",
    "lat": "39.52448",
    "lng": "-3.07618"
  },
  {
    "country": "ES",
    "name": "Miajadas",
    "lat": "39.15127",
    "lng": "-5.90841"
  },
  {
    "country": "ES",
    "name": "Mestanza",
    "lat": "38.57616",
    "lng": "-4.07096"
  },
  {
    "country": "ES",
    "name": "Mesas de Ibor",
    "lat": "39.75587",
    "lng": "-5.54637"
  },
  {
    "country": "ES",
    "name": "Mérida",
    "lat": "38.91611",
    "lng": "-6.34366"
  },
  {
    "country": "ES",
    "name": "Mercadal",
    "lat": "39.99014",
    "lng": "4.09387"
  },
  {
    "country": "ES",
    "name": "Mengibar",
    "lat": "37.96978",
    "lng": "-3.80884"
  },
  {
    "country": "ES",
    "name": "Mengabril",
    "lat": "38.93554",
    "lng": "-5.93335"
  },
  {
    "country": "ES",
    "name": "Menasalbas",
    "lat": "39.63954",
    "lng": "-4.28418"
  },
  {
    "country": "ES",
    "name": "Membrilla",
    "lat": "38.97198",
    "lng": "-3.3433"
  },
  {
    "country": "ES",
    "name": "Melilla",
    "lat": "35.29369",
    "lng": "-2.93833"
  },
  {
    "country": "ES",
    "name": "Meliana",
    "lat": "39.53333",
    "lng": "-0.33333"
  },
  {
    "country": "ES",
    "name": "Medina Sidonia",
    "lat": "36.45695",
    "lng": "-5.92717"
  },
  {
    "country": "ES",
    "name": "Medina de las Torres",
    "lat": "38.33333",
    "lng": "-6.4"
  },
  {
    "country": "ES",
    "name": "Medellín",
    "lat": "38.96265",
    "lng": "-5.95785"
  },
  {
    "country": "ES",
    "name": "Mazo",
    "lat": "28.60906",
    "lng": "-17.77801"
  },
  {
    "country": "ES",
    "name": "Mazarrón",
    "lat": "37.5992",
    "lng": "-1.31493"
  },
  {
    "country": "ES",
    "name": "Mazarambroz",
    "lat": "39.69411",
    "lng": "-4.01962"
  },
  {
    "country": "ES",
    "name": "Mazagón",
    "lat": "37.11417",
    "lng": "-6.76444"
  },
  {
    "country": "ES",
    "name": "Matet",
    "lat": "39.93333",
    "lng": "-0.46667"
  },
  {
    "country": "ES",
    "name": "Mata de Alcántara",
    "lat": "39.71738",
    "lng": "-6.81825"
  },
  {
    "country": "ES",
    "name": "Maspalomas",
    "lat": "27.76056",
    "lng": "-15.58602"
  },
  {
    "country": "ES",
    "name": "Masegoso",
    "lat": "38.71833",
    "lng": "-2.3161"
  },
  {
    "country": "ES",
    "name": "Mascaraque",
    "lat": "39.71643",
    "lng": "-3.81254"
  },
  {
    "country": "ES",
    "name": "Massamagrell",
    "lat": "39.56667",
    "lng": "-0.33333"
  },
  {
    "country": "ES",
    "name": "Masalavés",
    "lat": "39.14377",
    "lng": "-0.5226"
  },
  {
    "country": "ES",
    "name": "Martos",
    "lat": "37.72107",
    "lng": "-3.97264"
  },
  {
    "country": "ES",
    "name": "Martín de la Jara",
    "lat": "37.10867",
    "lng": "-4.96347"
  },
  {
    "country": "ES",
    "name": "Marratxí",
    "lat": "39.62142",
    "lng": "2.7253"
  },
  {
    "country": "ES",
    "name": "Marmolejo",
    "lat": "38.04549",
    "lng": "-4.17029"
  },
  {
    "country": "ES",
    "name": "Marjaliza",
    "lat": "39.56329",
    "lng": "-3.93499"
  },
  {
    "country": "ES",
    "name": "Marines",
    "lat": "39.74165",
    "lng": "-0.53103"
  },
  {
    "country": "ES",
    "name": "Marinaleda",
    "lat": "37.3712",
    "lng": "-4.95949"
  },
  {
    "country": "ES",
    "name": "Maria de la Salut",
    "lat": "39.66306",
    "lng": "3.073"
  },
  {
    "country": "ES",
    "name": "María",
    "lat": "37.71023",
    "lng": "-2.16454"
  },
  {
    "country": "ES",
    "name": "Marchena",
    "lat": "37.329",
    "lng": "-5.41681"
  },
  {
    "country": "ES",
    "name": "Marchal",
    "lat": "37.29639",
    "lng": "-3.20353"
  },
  {
    "country": "ES",
    "name": "Marbella",
    "lat": "36.51543",
    "lng": "-4.88583"
  },
  {
    "country": "ES",
    "name": "Maracena",
    "lat": "37.20764",
    "lng": "-3.63493"
  },
  {
    "country": "ES",
    "name": "Manzanilla",
    "lat": "37.38987",
    "lng": "-6.43295"
  },
  {
    "country": "ES",
    "name": "Manzaneque",
    "lat": "39.63549",
    "lng": "-3.79249"
  },
  {
    "country": "ES",
    "name": "Manzanares",
    "lat": "38.99915",
    "lng": "-3.36991"
  },
  {
    "country": "ES",
    "name": "Manuel",
    "lat": "39.05059",
    "lng": "-0.48978"
  },
  {
    "country": "ES",
    "name": "Manises",
    "lat": "39.49139",
    "lng": "-0.46349"
  },
  {
    "country": "ES",
    "name": "Manilva",
    "lat": "36.37645",
    "lng": "-5.25026"
  },
  {
    "country": "ES",
    "name": "Mancor de la Vall",
    "lat": "39.74966",
    "lng": "2.87284"
  },
  {
    "country": "ES",
    "name": "Manchita",
    "lat": "38.81404",
    "lng": "-6.02041"
  },
  {
    "country": "ES",
    "name": "Mancha Real",
    "lat": "37.78627",
    "lng": "-3.61226"
  },
  {
    "country": "ES",
    "name": "Manacor",
    "lat": "39.56964",
    "lng": "3.20955"
  },
  {
    "country": "ES",
    "name": "Malpica",
    "lat": "39.89746",
    "lng": "-4.54988"
  },
  {
    "country": "ES",
    "name": "Malpartida de Plasencia",
    "lat": "39.97962",
    "lng": "-6.04609"
  },
  {
    "country": "ES",
    "name": "Malpartida de la Serena",
    "lat": "38.6747",
    "lng": "-5.64054"
  },
  {
    "country": "ES",
    "name": "Malpartida de Cáceres",
    "lat": "39.44664",
    "lng": "-6.5076"
  },
  {
    "country": "ES",
    "name": "Malcocinado",
    "lat": "38.11667",
    "lng": "-5.68333"
  },
  {
    "country": "ES",
    "name": "Malagón",
    "lat": "39.16668",
    "lng": "-3.85419"
  },
  {
    "country": "ES",
    "name": "Málaga",
    "lat": "36.72016",
    "lng": "-4.42034"
  },
  {
    "country": "ES",
    "name": "Majadas",
    "lat": "39.94291",
    "lng": "-5.74589"
  },
  {
    "country": "ES",
    "name": "Mairena del Aljarafe",
    "lat": "37.34461",
    "lng": "-6.06391"
  },
  {
    "country": "ES",
    "name": "Mairena del Alcor",
    "lat": "37.37301",
    "lng": "-5.74951"
  },
  {
    "country": "ES",
    "name": "Mahora",
    "lat": "39.21667",
    "lng": "-1.73333"
  },
  {
    "country": "ES",
    "name": "Maó",
    "lat": "39.88853",
    "lng": "4.26583"
  },
  {
    "country": "ES",
    "name": "Maguilla",
    "lat": "38.36667",
    "lng": "-5.83333"
  },
  {
    "country": "ES",
    "name": "Magán",
    "lat": "39.96138",
    "lng": "-3.93164"
  },
  {
    "country": "ES",
    "name": "Magacela",
    "lat": "38.89648",
    "lng": "-5.73437"
  },
  {
    "country": "ES",
    "name": "Madroñera",
    "lat": "39.42526",
    "lng": "-5.75568"
  },
  {
    "country": "ES",
    "name": "Madrigueras",
    "lat": "39.23333",
    "lng": "-1.8"
  },
  {
    "country": "ES",
    "name": "Madrigalejo",
    "lat": "39.13858",
    "lng": "-5.6274"
  },
  {
    "country": "ES",
    "name": "Madridejos",
    "lat": "39.46823",
    "lng": "-3.53196"
  },
  {
    "country": "ES",
    "name": "Macastre",
    "lat": "39.38333",
    "lng": "-0.78333"
  },
  {
    "country": "ES",
    "name": "Macael",
    "lat": "37.33318",
    "lng": "-2.30087"
  },
  {
    "country": "ES",
    "name": "Luque",
    "lat": "37.55797",
    "lng": "-4.27974"
  },
  {
    "country": "ES",
    "name": "Lupión",
    "lat": "37.99653",
    "lng": "-3.54699"
  },
  {
    "country": "ES",
    "name": "Puerto Lumbreras",
    "lat": "37.56329",
    "lng": "-1.80974"
  },
  {
    "country": "ES",
    "name": "Lújar",
    "lat": "36.78831",
    "lng": "-3.404"
  },
  {
    "country": "ES",
    "name": "Lugros",
    "lat": "37.22942",
    "lng": "-3.2415"
  },
  {
    "country": "ES",
    "name": "Llocnou de Sant Jeroni",
    "lat": "38.91667",
    "lng": "-0.28333"
  },
  {
    "country": "ES",
    "name": "Lucillos",
    "lat": "39.9851",
    "lng": "-4.61279"
  },
  {
    "country": "ES",
    "name": "Llutxent",
    "lat": "38.93333",
    "lng": "-0.35"
  },
  {
    "country": "ES",
    "name": "Lucena del Puerto",
    "lat": "37.30396",
    "lng": "-6.72926"
  },
  {
    "country": "ES",
    "name": "Lucena",
    "lat": "37.40881",
    "lng": "-4.48522"
  },
  {
    "country": "ES",
    "name": "Lúcar",
    "lat": "37.40035",
    "lng": "-2.42496"
  },
  {
    "country": "ES",
    "name": "Lucainena de las Torres",
    "lat": "37.04037",
    "lng": "-2.20095"
  },
  {
    "country": "ES",
    "name": "Lubrín",
    "lat": "37.21538",
    "lng": "-2.06677"
  },
  {
    "country": "ES",
    "name": "Los Yébenes",
    "lat": "39.58158",
    "lng": "-3.87058"
  },
  {
    "country": "ES",
    "name": "Los Silos",
    "lat": "28.3661",
    "lng": "-16.81552"
  },
  {
    "country": "ES",
    "name": "Los Santos de Maimona",
    "lat": "38.45",
    "lng": "-6.38333"
  },
  {
    "country": "ES",
    "name": "Los Palacios y Villafranca",
    "lat": "37.16181",
    "lng": "-5.92433"
  },
  {
    "country": "ES",
    "name": "Los Navalucillos",
    "lat": "39.66665",
    "lng": "-4.64205"
  },
  {
    "country": "ES",
    "name": "Los Navalmorales",
    "lat": "39.72526",
    "lng": "-4.64227"
  },
  {
    "country": "ES",
    "name": "Los Montesinos",
    "lat": "38.02822",
    "lng": "-0.74501"
  },
  {
    "country": "ES",
    "name": "Los Molares",
    "lat": "37.15704",
    "lng": "-5.71802"
  },
  {
    "country": "ES",
    "name": "Los Llanos de Aridane",
    "lat": "28.65851",
    "lng": "-17.91821"
  },
  {
    "country": "ES",
    "name": "Los Hinojosos",
    "lat": "39.60417",
    "lng": "-2.82572"
  },
  {
    "country": "ES",
    "name": "Los Corrales",
    "lat": "37.09918",
    "lng": "-4.98429"
  },
  {
    "country": "ES",
    "name": "Los Barrios",
    "lat": "36.18482",
    "lng": "-5.49213"
  },
  {
    "country": "ES",
    "name": "Los Alcázares",
    "lat": "37.74425",
    "lng": "-0.85041"
  },
  {
    "country": "ES",
    "name": "Losa del Obispo",
    "lat": "39.7",
    "lng": "-0.86667"
  },
  {
    "country": "ES",
    "name": "Lorquí",
    "lat": "38.08261",
    "lng": "-1.25103"
  },
  {
    "country": "ES",
    "name": "Loriguilla",
    "lat": "39.68333",
    "lng": "-0.91667"
  },
  {
    "country": "ES",
    "name": "Lorca",
    "lat": "37.67119",
    "lng": "-1.7017"
  },
  {
    "country": "ES",
    "name": "Lora del Río",
    "lat": "37.65896",
    "lng": "-5.52751"
  },
  {
    "country": "ES",
    "name": "Lora de Estepa",
    "lat": "37.26926",
    "lng": "-4.82759"
  },
  {
    "country": "ES",
    "name": "Lopera",
    "lat": "37.94542",
    "lng": "-4.21463"
  },
  {
    "country": "ES",
    "name": "Lomo de Arico",
    "lat": "28.16667",
    "lng": "-16.48333"
  },
  {
    "country": "ES",
    "name": "Loja",
    "lat": "37.16887",
    "lng": "-4.15129"
  },
  {
    "country": "ES",
    "name": "Logrosán",
    "lat": "39.33641",
    "lng": "-5.49281"
  },
  {
    "country": "ES",
    "name": "Lobras",
    "lat": "36.92849",
    "lng": "-3.2123"
  },
  {
    "country": "ES",
    "name": "Lobón",
    "lat": "38.84876",
    "lng": "-6.62365"
  },
  {
    "country": "ES",
    "name": "Llucmajor",
    "lat": "39.49093",
    "lng": "2.89108"
  },
  {
    "country": "ES",
    "name": "Llubí",
    "lat": "39.69933",
    "lng": "3.00681"
  },
  {
    "country": "ES",
    "name": "Lloseta",
    "lat": "39.71849",
    "lng": "2.8669"
  },
  {
    "country": "ES",
    "name": "Llosa de Ranes",
    "lat": "39.02163",
    "lng": "-0.53803"
  },
  {
    "country": "ES",
    "name": "Lloret de Vistalegre",
    "lat": "39.61835",
    "lng": "2.97493"
  },
  {
    "country": "ES",
    "name": "Llombai",
    "lat": "39.28333",
    "lng": "-0.56667"
  },
  {
    "country": "ES",
    "name": "Llerena",
    "lat": "38.23333",
    "lng": "-6.01667"
  },
  {
    "country": "ES",
    "name": "Llera",
    "lat": "38.45",
    "lng": "-6.05"
  },
  {
    "country": "ES",
    "name": "Llaurí",
    "lat": "39.14671",
    "lng": "-0.32944"
  },
  {
    "country": "ES",
    "name": "Llanera de Ranes",
    "lat": "38.99507",
    "lng": "-0.57534"
  },
  {
    "country": "ES",
    "name": "Llíria",
    "lat": "39.62894",
    "lng": "-0.59783"
  },
  {
    "country": "ES",
    "name": "Linares de la Sierra",
    "lat": "37.87963",
    "lng": "-6.62321"
  },
  {
    "country": "ES",
    "name": "Linares",
    "lat": "38.09519",
    "lng": "-3.63602"
  },
  {
    "country": "ES",
    "name": "Lillo",
    "lat": "39.72331",
    "lng": "-3.30618"
  },
  {
    "country": "ES",
    "name": "Liétor",
    "lat": "38.54267",
    "lng": "-1.95367"
  },
  {
    "country": "ES",
    "name": "Librilla",
    "lat": "37.88642",
    "lng": "-1.35557"
  },
  {
    "country": "ES",
    "name": "Lezuza",
    "lat": "38.9497",
    "lng": "-2.35419"
  },
  {
    "country": "ES",
    "name": "Letur",
    "lat": "38.36626",
    "lng": "-2.10206"
  },
  {
    "country": "ES",
    "name": "Lepe",
    "lat": "37.25482",
    "lng": "-7.20433"
  },
  {
    "country": "ES",
    "name": "Lentegí",
    "lat": "36.83613",
    "lng": "-3.67426"
  },
  {
    "country": "ES",
    "name": "Ledaña",
    "lat": "39.36667",
    "lng": "-1.7"
  },
  {
    "country": "ES",
    "name": "Lebrija",
    "lat": "36.92077",
    "lng": "-6.07529"
  },
  {
    "country": "ES",
    "name": "Layos",
    "lat": "39.77703",
    "lng": "-4.06448"
  },
  {
    "country": "ES",
    "name": "La Yesa",
    "lat": "39.88333",
    "lng": "-0.95"
  },
  {
    "country": "ES",
    "name": "La Victoria de Acentejo",
    "lat": "28.43231",
    "lng": "-16.46232"
  },
  {
    "country": "ES",
    "name": "La Victoria",
    "lat": "37.68126",
    "lng": "-4.85199"
  },
  {
    "country": "ES",
    "name": "La Unión",
    "lat": "37.61915",
    "lng": "-0.87799"
  },
  {
    "country": "ES",
    "name": "Laujar de Andarax",
    "lat": "36.99516",
    "lng": "-2.89033"
  },
  {
    "country": "ES",
    "name": "Las Torres de Cotillas",
    "lat": "38.02822",
    "lng": "-1.24188"
  },
  {
    "country": "ES",
    "name": "Las Pedroñeras",
    "lat": "39.44997",
    "lng": "-2.67394"
  },
  {
    "country": "ES",
    "name": "Las Palmas de Gran Canaria",
    "lat": "28.09973",
    "lng": "-15.41343"
  },
  {
    "country": "ES",
    "name": "La Solana",
    "lat": "38.94422",
    "lng": "-3.2381"
  },
  {
    "country": "ES",
    "name": "Las Mesas",
    "lat": "39.38871",
    "lng": "-2.76524"
  },
  {
    "country": "ES",
    "name": "Las Cabezas de San Juan",
    "lat": "36.9838",
    "lng": "-5.93933"
  },
  {
    "country": "ES",
    "name": "Larva",
    "lat": "37.76069",
    "lng": "-3.20269"
  },
  {
    "country": "ES",
    "name": "Laroya",
    "lat": "37.29771",
    "lng": "-2.33419"
  },
  {
    "country": "ES",
    "name": "La Romana",
    "lat": "38.36753",
    "lng": "-0.89862"
  },
  {
    "country": "ES",
    "name": "La Roda de Andalucía",
    "lat": "37.20381",
    "lng": "-4.77802"
  },
  {
    "country": "ES",
    "name": "La Roda",
    "lat": "39.20735",
    "lng": "-2.15723"
  },
  {
    "country": "ES",
    "name": "La Roca de la Sierra",
    "lat": "39.10966",
    "lng": "-6.68916"
  },
  {
    "country": "ES",
    "name": "La Rinconada",
    "lat": "37.48613",
    "lng": "-5.98091"
  },
  {
    "country": "ES",
    "name": "La Rambla",
    "lat": "37.6076",
    "lng": "-4.73962"
  },
  {
    "country": "ES",
    "name": "La Puerta de Segura",
    "lat": "38.35293",
    "lng": "-2.73956"
  },
  {
    "country": "ES",
    "name": "La Pueblanueva",
    "lat": "39.91208",
    "lng": "-4.67933"
  },
  {
    "country": "ES",
    "name": "La Puebla de Montalbán",
    "lat": "39.86297",
    "lng": "-4.35917"
  },
  {
    "country": "ES",
    "name": "La Puebla del Río",
    "lat": "37.26787",
    "lng": "-6.06264"
  },
  {
    "country": "ES",
    "name": "La Puebla de los Infantes",
    "lat": "37.7809",
    "lng": "-5.38837"
  },
  {
    "country": "ES",
    "name": "La Puebla de Cazalla",
    "lat": "37.22155",
    "lng": "-5.31153"
  },
  {
    "country": "ES",
    "name": "La Puebla de Almoradiel",
    "lat": "39.59862",
    "lng": "-3.11782"
  },
  {
    "country": "ES",
    "name": "sa Pobla",
    "lat": "39.7692",
    "lng": "3.02394"
  },
  {
    "country": "ES",
    "name": "La Parra",
    "lat": "38.5212",
    "lng": "-6.6226"
  },
  {
    "country": "ES",
    "name": "La Palma del Condado",
    "lat": "37.38605",
    "lng": "-6.55231"
  },
  {
    "country": "ES",
    "name": "La Orotava",
    "lat": "28.39076",
    "lng": "-16.52309"
  },
  {
    "country": "ES",
    "name": "La Oliva",
    "lat": "28.61052",
    "lng": "-13.92912"
  },
  {
    "country": "ES",
    "name": "la Nucia",
    "lat": "38.61372",
    "lng": "-0.1269"
  },
  {
    "country": "ES",
    "name": "Lanteira",
    "lat": "37.16871",
    "lng": "-3.13823"
  },
  {
    "country": "ES",
    "name": "Lanjarón",
    "lat": "36.91853",
    "lng": "-3.4818"
  },
  {
    "country": "ES",
    "name": "Landete",
    "lat": "39.9",
    "lng": "-1.36667"
  },
  {
    "country": "ES",
    "name": "La Nava de Santiago",
    "lat": "39.06328",
    "lng": "-6.50525"
  },
  {
    "country": "ES",
    "name": "La Mojonera",
    "lat": "37.29233",
    "lng": "-2.4373"
  },
  {
    "country": "ES",
    "name": "La Matanza de Acentejo",
    "lat": "28.45242",
    "lng": "-16.4472"
  },
  {
    "country": "ES",
    "name": "La Luisiana",
    "lat": "37.52602",
    "lng": "-5.24883"
  },
  {
    "country": "ES",
    "name": "La Línea de la Concepción",
    "lat": "36.16809",
    "lng": "-5.34777"
  },
  {
    "country": "ES",
    "name": "La Lantejuela",
    "lat": "37.3535",
    "lng": "-5.22477"
  },
  {
    "country": "ES",
    "name": "La Iruela",
    "lat": "37.91986",
    "lng": "-2.99659"
  },
  {
    "country": "ES",
    "name": "La Herradura",
    "lat": "36.73491",
    "lng": "-3.7376"
  },
  {
    "country": "ES",
    "name": "La Haba",
    "lat": "38.91929",
    "lng": "-5.80034"
  },
  {
    "country": "ES",
    "name": "La Guardia de Jaén",
    "lat": "37.74303",
    "lng": "-3.69312"
  },
  {
    "country": "ES",
    "name": "La Guardia",
    "lat": "39.78795",
    "lng": "-3.47604"
  },
  {
    "country": "ES",
    "name": "La Guancha",
    "lat": "28.3732",
    "lng": "-16.65158"
  },
  {
    "country": "ES",
    "name": "La Gineta",
    "lat": "39.11452",
    "lng": "-1.99603"
  },
  {
    "country": "ES",
    "name": "Lagartera",
    "lat": "39.90557",
    "lng": "-5.20143"
  },
  {
    "country": "ES",
    "name": "La Garrovilla",
    "lat": "38.91961",
    "lng": "-6.47747"
  },
  {
    "country": "ES",
    "name": "L'Eliana",
    "lat": "39.56667",
    "lng": "-0.53333"
  },
  {
    "country": "ES",
    "name": "La Cumbre",
    "lat": "39.4046",
    "lng": "-5.97635"
  },
  {
    "country": "ES",
    "name": "La Coronada",
    "lat": "38.92045",
    "lng": "-5.66978"
  },
  {
    "country": "ES",
    "name": "La Codosera",
    "lat": "39.20878",
    "lng": "-7.1733"
  },
  {
    "country": "ES",
    "name": "Láchar",
    "lat": "37.19519",
    "lng": "-3.83277"
  },
  {
    "country": "ES",
    "name": "La Carolina",
    "lat": "38.27559",
    "lng": "-3.61535"
  },
  {
    "country": "ES",
    "name": "La Carlota",
    "lat": "37.67359",
    "lng": "-4.93122"
  },
  {
    "country": "ES",
    "name": "La Campana",
    "lat": "37.56891",
    "lng": "-5.4267"
  },
  {
    "country": "ES",
    "name": "La Calzada de Calatrava",
    "lat": "38.70339",
    "lng": "-3.77561"
  },
  {
    "country": "ES",
    "name": "La Antilla",
    "lat": "37.20709",
    "lng": "-7.20909"
  },
  {
    "country": "ES",
    "name": "La Algaba",
    "lat": "37.46325",
    "lng": "-6.01113"
  },
  {
    "country": "ES",
    "name": "La Albuera",
    "lat": "38.71779",
    "lng": "-6.82326"
  },
  {
    "country": "ES",
    "name": "La Alberca de Záncara",
    "lat": "39.51458",
    "lng": "-2.49272"
  },
  {
    "country": "ES",
    "name": "Júzcar",
    "lat": "36.62442",
    "lng": "-5.16971"
  },
  {
    "country": "ES",
    "name": "Juviles",
    "lat": "36.94879",
    "lng": "-3.22586"
  },
  {
    "country": "ES",
    "name": "Jun",
    "lat": "37.22083",
    "lng": "-3.59407"
  },
  {
    "country": "ES",
    "name": "Jumilla",
    "lat": "38.47917",
    "lng": "-1.325"
  },
  {
    "country": "ES",
    "name": "Jubrique",
    "lat": "36.56475",
    "lng": "-5.2156"
  },
  {
    "country": "ES",
    "name": "Jorquera",
    "lat": "39.16667",
    "lng": "-1.51667"
  },
  {
    "country": "ES",
    "name": "Jódar",
    "lat": "37.84064",
    "lng": "-3.35262"
  },
  {
    "country": "ES",
    "name": "Jimera de Líbar",
    "lat": "36.65119",
    "lng": "-5.27412"
  },
  {
    "country": "ES",
    "name": "Jimena de la Frontera",
    "lat": "36.43517",
    "lng": "-5.45387"
  },
  {
    "country": "ES",
    "name": "Jimena",
    "lat": "37.84157",
    "lng": "-3.4771"
  },
  {
    "country": "ES",
    "name": "Jijona",
    "lat": "38.54086",
    "lng": "-0.50263"
  },
  {
    "country": "ES",
    "name": "Jérica",
    "lat": "39.91667",
    "lng": "-0.56667"
  },
  {
    "country": "ES",
    "name": "Jerez de los Caballeros",
    "lat": "38.32063",
    "lng": "-6.7726"
  },
  {
    "country": "ES",
    "name": "Jerez de la Frontera",
    "lat": "36.68645",
    "lng": "-6.13606"
  },
  {
    "country": "ES",
    "name": "Jérez del Marquesado",
    "lat": "37.18382",
    "lng": "-3.15961"
  },
  {
    "country": "ES",
    "name": "Xeresa",
    "lat": "39.01667",
    "lng": "-0.21667"
  },
  {
    "country": "ES",
    "name": "Jayena",
    "lat": "36.9492",
    "lng": "-3.82313"
  },
  {
    "country": "ES",
    "name": "Javea",
    "lat": "38.78333",
    "lng": "0.16667"
  },
  {
    "country": "ES",
    "name": "Xàtiva",
    "lat": "38.99042",
    "lng": "-0.51852"
  },
  {
    "country": "ES",
    "name": "Jaraicejo",
    "lat": "39.66624",
    "lng": "-5.81308"
  },
  {
    "country": "ES",
    "name": "Jarafuel",
    "lat": "39.14013",
    "lng": "-1.07306"
  },
  {
    "country": "ES",
    "name": "Xeraco,Jaraco",
    "lat": "39.03333",
    "lng": "-0.21667"
  },
  {
    "country": "ES",
    "name": "Jamilena",
    "lat": "37.74717",
    "lng": "-3.91433"
  },
  {
    "country": "ES",
    "name": "Jalón",
    "lat": "38.74063",
    "lng": "-0.01129"
  },
  {
    "country": "ES",
    "name": "Jalance",
    "lat": "39.2",
    "lng": "-1.06667"
  },
  {
    "country": "ES",
    "name": "Jaén",
    "lat": "37.76922",
    "lng": "-3.79028"
  },
  {
    "country": "ES",
    "name": "Jacarilla",
    "lat": "38.06247",
    "lng": "-0.86822"
  },
  {
    "country": "ES",
    "name": "Jabugo",
    "lat": "37.91622",
    "lng": "-6.72968"
  },
  {
    "country": "ES",
    "name": "Jabalquinto",
    "lat": "38.01935",
    "lng": "-3.72512"
  },
  {
    "country": "ES",
    "name": "Iznatoraf",
    "lat": "38.15706",
    "lng": "-3.03242"
  },
  {
    "country": "ES",
    "name": "Iznate",
    "lat": "36.78333",
    "lng": "-4.18333"
  },
  {
    "country": "ES",
    "name": "Iznalloz",
    "lat": "37.39258",
    "lng": "-3.52762"
  },
  {
    "country": "ES",
    "name": "Iznájar",
    "lat": "37.25766",
    "lng": "-4.30836"
  },
  {
    "country": "ES",
    "name": "Ítrabo",
    "lat": "36.79998",
    "lng": "-3.63899"
  },
  {
    "country": "ES",
    "name": "Istán",
    "lat": "36.58273",
    "lng": "-4.94956"
  },
  {
    "country": "ES",
    "name": "Isla Cristina",
    "lat": "37.2",
    "lng": "-7.31667"
  },
  {
    "country": "ES",
    "name": "Instinción",
    "lat": "36.99344",
    "lng": "-2.66046"
  },
  {
    "country": "ES",
    "name": "Iniesta",
    "lat": "39.43333",
    "lng": "-1.75"
  },
  {
    "country": "ES",
    "name": "Ingenio",
    "lat": "27.91855",
    "lng": "-15.43433"
  },
  {
    "country": "ES",
    "name": "Infantes",
    "lat": "38.73669",
    "lng": "-3.01219"
  },
  {
    "country": "ES",
    "name": "Inca",
    "lat": "39.7211",
    "lng": "2.91093"
  },
  {
    "country": "ES",
    "name": "Illora",
    "lat": "37.28771",
    "lng": "-3.88109"
  },
  {
    "country": "ES",
    "name": "Illar",
    "lat": "36.98562",
    "lng": "-2.63871"
  },
  {
    "country": "ES",
    "name": "Illán de Vacas",
    "lat": "39.97079",
    "lng": "-4.55743"
  },
  {
    "country": "ES",
    "name": "Igualeja",
    "lat": "36.63208",
    "lng": "-5.12188"
  },
  {
    "country": "ES",
    "name": "Icod de los Vinos",
    "lat": "28.37241",
    "lng": "-16.71188"
  },
  {
    "country": "ES",
    "name": "Ibros",
    "lat": "38.02106",
    "lng": "-3.50313"
  },
  {
    "country": "ES",
    "name": "Ibiza",
    "lat": "38.90883",
    "lng": "1.43296"
  },
  {
    "country": "ES",
    "name": "Ibi",
    "lat": "38.62533",
    "lng": "-0.57225"
  },
  {
    "country": "ES",
    "name": "Ibahernando",
    "lat": "39.32538",
    "lng": "-5.91833"
  },
  {
    "country": "ES",
    "name": "Humilladero",
    "lat": "37.1139",
    "lng": "-4.70298"
  },
  {
    "country": "ES",
    "name": "Huétor Vega",
    "lat": "37.14529",
    "lng": "-3.56963"
  },
  {
    "country": "ES",
    "name": "Huétor-Tájar",
    "lat": "37.19834",
    "lng": "-4.04692"
  },
  {
    "country": "ES",
    "name": "Huétor Santillán",
    "lat": "37.22091",
    "lng": "-3.51634"
  },
  {
    "country": "ES",
    "name": "Huéscar",
    "lat": "37.81104",
    "lng": "-2.54116"
  },
  {
    "country": "ES",
    "name": "Huesa",
    "lat": "37.76434",
    "lng": "-3.07639"
  },
  {
    "country": "ES",
    "name": "Huerta de Valdecarábanos",
    "lat": "39.86319",
    "lng": "-3.61275"
  },
  {
    "country": "ES",
    "name": "Huerta de la Obispalía",
    "lat": "39.98901",
    "lng": "-2.47875"
  },
  {
    "country": "ES",
    "name": "Huércal-Overa",
    "lat": "37.38918",
    "lng": "-1.943"
  },
  {
    "country": "ES",
    "name": "Huércal de Almería",
    "lat": "36.88507",
    "lng": "-2.4376"
  },
  {
    "country": "ES",
    "name": "Huéneja",
    "lat": "37.1766",
    "lng": "-2.95024"
  },
  {
    "country": "ES",
    "name": "Huelva",
    "lat": "37.26638",
    "lng": "-6.94004"
  },
  {
    "country": "ES",
    "name": "Huelma",
    "lat": "37.64784",
    "lng": "-3.45985"
  },
  {
    "country": "ES",
    "name": "Huélago",
    "lat": "37.41972",
    "lng": "-3.26226"
  },
  {
    "country": "ES",
    "name": "Huécija",
    "lat": "36.96804",
    "lng": "-2.60941"
  },
  {
    "country": "ES",
    "name": "Hoya-Gonzalo",
    "lat": "38.9579",
    "lng": "-1.55679"
  },
  {
    "country": "ES",
    "name": "Hornachuelos",
    "lat": "37.83333",
    "lng": "-5.23333"
  },
  {
    "country": "ES",
    "name": "Hornachos",
    "lat": "38.55428",
    "lng": "-6.06829"
  },
  {
    "country": "ES",
    "name": "Horcajo de Santiago",
    "lat": "39.84221",
    "lng": "-2.99724"
  },
  {
    "country": "ES",
    "name": "Hontecillas",
    "lat": "39.7",
    "lng": "-2.18333"
  },
  {
    "country": "ES",
    "name": "Hontanaya",
    "lat": "39.71553",
    "lng": "-2.83516"
  },
  {
    "country": "ES",
    "name": "Hontanar",
    "lat": "39.61297",
    "lng": "-4.49663"
  },
  {
    "country": "ES",
    "name": "Honrubia",
    "lat": "39.61358",
    "lng": "-2.28077"
  },
  {
    "country": "ES",
    "name": "Hondón de los Frailes",
    "lat": "38.2739",
    "lng": "-0.92938"
  },
  {
    "country": "ES",
    "name": "Hondón de las Nieves",
    "lat": "38.30844",
    "lng": "-0.8533"
  },
  {
    "country": "ES",
    "name": "Holguera",
    "lat": "39.89916",
    "lng": "-6.34999"
  },
  {
    "country": "ES",
    "name": "Hinojosas de Calatrava",
    "lat": "38.61446",
    "lng": "-4.13979"
  },
  {
    "country": "ES",
    "name": "Hinojosa del Valle",
    "lat": "38.48333",
    "lng": "-6.18333"
  },
  {
    "country": "ES",
    "name": "Hinojosa del Duque",
    "lat": "38.50057",
    "lng": "-5.14651"
  },
  {
    "country": "ES",
    "name": "Hinojos",
    "lat": "37.29173",
    "lng": "-6.37872"
  },
  {
    "country": "ES",
    "name": "Hinojares",
    "lat": "37.71586",
    "lng": "-2.99769"
  },
  {
    "country": "ES",
    "name": "Hinojales",
    "lat": "38",
    "lng": "-6.58333"
  },
  {
    "country": "ES",
    "name": "Hinojal",
    "lat": "39.709",
    "lng": "-6.35567"
  },
  {
    "country": "ES",
    "name": "Higueruelas",
    "lat": "39.78333",
    "lng": "-0.85"
  },
  {
    "country": "ES",
    "name": "Higueruela",
    "lat": "38.96371",
    "lng": "-1.4437"
  },
  {
    "country": "ES",
    "name": "Higueras",
    "lat": "39.98333",
    "lng": "-0.5"
  },
  {
    "country": "ES",
    "name": "Higuera la Real",
    "lat": "38.14088",
    "lng": "-6.68922"
  },
  {
    "country": "ES",
    "name": "Higuera de Vargas",
    "lat": "38.447",
    "lng": "-6.97517"
  },
  {
    "country": "ES",
    "name": "Higuera de la Sierra",
    "lat": "37.83333",
    "lng": "-6.45"
  },
  {
    "country": "ES",
    "name": "Higuera de la Serena",
    "lat": "38.64616",
    "lng": "-5.74129"
  },
  {
    "country": "ES",
    "name": "Higuera de Calatrava",
    "lat": "37.79848",
    "lng": "-4.15737"
  },
  {
    "country": "ES",
    "name": "Higuera de Arjona",
    "lat": "37.97064",
    "lng": "-3.99061"
  },
  {
    "country": "ES",
    "name": "Higuera",
    "lat": "39.72551",
    "lng": "-5.66692"
  },
  {
    "country": "ES",
    "name": "Herreruela de Oropesa",
    "lat": "39.88928",
    "lng": "-5.24279"
  },
  {
    "country": "ES",
    "name": "Herrera del Duque",
    "lat": "39.1684",
    "lng": "-5.05049"
  },
  {
    "country": "ES",
    "name": "Herrera de Alcántara",
    "lat": "39.63865",
    "lng": "-7.40619"
  },
  {
    "country": "ES",
    "name": "Herrera",
    "lat": "37.36396",
    "lng": "-4.84979"
  },
  {
    "country": "ES",
    "name": "Hermigua",
    "lat": "28.16766",
    "lng": "-17.19051"
  },
  {
    "country": "ES",
    "name": "Herguijuela",
    "lat": "39.37452",
    "lng": "-5.76001"
  },
  {
    "country": "ES",
    "name": "Herencia",
    "lat": "39.36616",
    "lng": "-3.35735"
  },
  {
    "country": "ES",
    "name": "Henarejos",
    "lat": "39.86667",
    "lng": "-1.48333"
  },
  {
    "country": "ES",
    "name": "Hellín",
    "lat": "38.5106",
    "lng": "-1.70096"
  },
  {
    "country": "ES",
    "name": "Haría",
    "lat": "29.14553",
    "lng": "-13.49986"
  },
  {
    "country": "ES",
    "name": "Güimar",
    "lat": "28.31122",
    "lng": "-16.41276"
  },
  {
    "country": "ES",
    "name": "Guillena",
    "lat": "37.54262",
    "lng": "-6.05626"
  },
  {
    "country": "ES",
    "name": "Guía de Isora",
    "lat": "28.21154",
    "lng": "-16.77947"
  },
  {
    "country": "ES",
    "name": "Guia",
    "lat": "28.13974",
    "lng": "-15.63294"
  },
  {
    "country": "ES",
    "name": "Güevéjar",
    "lat": "37.25759",
    "lng": "-3.59691"
  },
  {
    "country": "ES",
    "name": "Güéjar-Sierra",
    "lat": "37.15994",
    "lng": "-3.43863"
  },
  {
    "country": "ES",
    "name": "Guarromán",
    "lat": "38.18282",
    "lng": "-3.68697"
  },
  {
    "country": "ES",
    "name": "Guaro",
    "lat": "36.6563",
    "lng": "-4.83433"
  },
  {
    "country": "ES",
    "name": "Guareña",
    "lat": "38.85952",
    "lng": "-6.09987"
  },
  {
    "country": "ES",
    "name": "Guardamar del Segura",
    "lat": "38.09031",
    "lng": "-0.65556"
  },
  {
    "country": "ES",
    "name": "Gualchos",
    "lat": "36.74467",
    "lng": "-3.39079"
  },
  {
    "country": "ES",
    "name": "Guadix",
    "lat": "37.29932",
    "lng": "-3.13922"
  },
  {
    "country": "ES",
    "name": "Guadassuar",
    "lat": "39.18663",
    "lng": "-0.47859"
  },
  {
    "country": "ES",
    "name": "Guadasequies",
    "lat": "38.92539",
    "lng": "-0.48585"
  },
  {
    "country": "ES",
    "name": "Guadamur",
    "lat": "39.81178",
    "lng": "-4.14885"
  },
  {
    "country": "ES",
    "name": "Guadalupe",
    "lat": "39.4508",
    "lng": "-5.32588"
  },
  {
    "country": "ES",
    "name": "Guadalmez",
    "lat": "38.72665",
    "lng": "-4.97104"
  },
  {
    "country": "ES",
    "name": "Guadalcázar",
    "lat": "37.75738",
    "lng": "-4.94387"
  },
  {
    "country": "ES",
    "name": "Guadalcanal",
    "lat": "38.1",
    "lng": "-5.81667"
  },
  {
    "country": "ES",
    "name": "Guadahortuna",
    "lat": "37.55711",
    "lng": "-3.39859"
  },
  {
    "country": "ES",
    "name": "Grazalema",
    "lat": "36.76018",
    "lng": "-5.36839"
  },
  {
    "country": "ES",
    "name": "Granja de Torrehermosa",
    "lat": "38.31667",
    "lng": "-5.58333"
  },
  {
    "country": "ES",
    "name": "Granja de Rocamora",
    "lat": "38.15157",
    "lng": "-0.8917"
  },
  {
    "country": "ES",
    "name": "Granadilla de Abona",
    "lat": "28.11882",
    "lng": "-16.57599"
  },
  {
    "country": "ES",
    "name": "Granada",
    "lat": "37.18817",
    "lng": "-3.60667"
  },
  {
    "country": "ES",
    "name": "Graja de Iniesta",
    "lat": "39.51667",
    "lng": "-1.66667"
  },
  {
    "country": "ES",
    "name": "Graja de Campalbo",
    "lat": "39.9",
    "lng": "-1.26667"
  },
  {
    "country": "ES",
    "name": "Gorga",
    "lat": "38.71896",
    "lng": "-0.35589"
  },
  {
    "country": "ES",
    "name": "Gor",
    "lat": "37.36937",
    "lng": "-2.97016"
  },
  {
    "country": "ES",
    "name": "Golosalvo",
    "lat": "39.23333",
    "lng": "-1.63333"
  },
  {
    "country": "ES",
    "name": "Gójar",
    "lat": "37.10456",
    "lng": "-3.60565"
  },
  {
    "country": "ES",
    "name": "Godelleta",
    "lat": "39.41667",
    "lng": "-0.68333"
  },
  {
    "country": "ES",
    "name": "Godella",
    "lat": "39.53333",
    "lng": "-0.41667"
  },
  {
    "country": "ES",
    "name": "Gobernador",
    "lat": "37.47845",
    "lng": "-3.32119"
  },
  {
    "country": "ES",
    "name": "Gines",
    "lat": "37.38647",
    "lng": "-6.07729"
  },
  {
    "country": "ES",
    "name": "Gilet",
    "lat": "39.68333",
    "lng": "-0.31667"
  },
  {
    "country": "ES",
    "name": "Gilena",
    "lat": "37.2515",
    "lng": "-4.91442"
  },
  {
    "country": "ES",
    "name": "Gibraleón",
    "lat": "37.37628",
    "lng": "-6.96895"
  },
  {
    "country": "ES",
    "name": "Gestalgar",
    "lat": "39.6",
    "lng": "-0.83333"
  },
  {
    "country": "ES",
    "name": "Gerindote",
    "lat": "39.96594",
    "lng": "-4.30278"
  },
  {
    "country": "ES",
    "name": "Gérgal",
    "lat": "37.11886",
    "lng": "-2.54012"
  },
  {
    "country": "ES",
    "name": "Gerena",
    "lat": "37.52957",
    "lng": "-6.15479"
  },
  {
    "country": "ES",
    "name": "Genovés",
    "lat": "38.98915",
    "lng": "-0.46992"
  },
  {
    "country": "ES",
    "name": "Génave",
    "lat": "38.43062",
    "lng": "-2.7331"
  },
  {
    "country": "ES",
    "name": "Genalguacil",
    "lat": "36.54546",
    "lng": "-5.23572"
  },
  {
    "country": "ES",
    "name": "Gelves",
    "lat": "37.33481",
    "lng": "-6.02601"
  },
  {
    "country": "ES",
    "name": "Geldo",
    "lat": "39.83333",
    "lng": "-0.46667"
  },
  {
    "country": "ES",
    "name": "Gaucín",
    "lat": "36.51784",
    "lng": "-5.31581"
  },
  {
    "country": "ES",
    "name": "Gata de Gorgos",
    "lat": "38.77443",
    "lng": "0.08538"
  },
  {
    "country": "ES",
    "name": "Garvín",
    "lat": "39.71984",
    "lng": "-5.34678"
  },
  {
    "country": "ES",
    "name": "Garrucha",
    "lat": "37.18141",
    "lng": "-1.82252"
  },
  {
    "country": "ES",
    "name": "Garrovillas",
    "lat": "39.71082",
    "lng": "-6.55034"
  },
  {
    "country": "ES",
    "name": "Garlitos",
    "lat": "38.88022",
    "lng": "-5.04759"
  },
  {
    "country": "ES",
    "name": "Garbayuela",
    "lat": "39.04956",
    "lng": "-4.99856"
  },
  {
    "country": "ES",
    "name": "Garafía",
    "lat": "28.81667",
    "lng": "-17.93333"
  },
  {
    "country": "ES",
    "name": "Garachico",
    "lat": "28.77807",
    "lng": "-17.76459"
  },
  {
    "country": "ES",
    "name": "Garachico",
    "lat": "28.37365",
    "lng": "-16.76342"
  },
  {
    "country": "ES",
    "name": "Garaballa",
    "lat": "39.81667",
    "lng": "-1.36667"
  },
  {
    "country": "ES",
    "name": "Gandia",
    "lat": "38.96667",
    "lng": "-0.18333"
  },
  {
    "country": "ES",
    "name": "Gálvez",
    "lat": "39.70208",
    "lng": "-4.27239"
  },
  {
    "country": "ES",
    "name": "Galisteo",
    "lat": "39.97642",
    "lng": "-6.26782"
  },
  {
    "country": "ES",
    "name": "Galera",
    "lat": "37.74262",
    "lng": "-2.55175"
  },
  {
    "country": "ES",
    "name": "Gáldar",
    "lat": "28.14701",
    "lng": "-15.6502"
  },
  {
    "country": "ES",
    "name": "Galaroza",
    "lat": "37.92864",
    "lng": "-6.7073"
  },
  {
    "country": "ES",
    "name": "Gaibiel",
    "lat": "39.93333",
    "lng": "-0.48333"
  },
  {
    "country": "ES",
    "name": "Gádor",
    "lat": "36.95322",
    "lng": "-2.49254"
  },
  {
    "country": "ES",
    "name": "Gavarda",
    "lat": "39.08333",
    "lng": "-0.55"
  },
  {
    "country": "ES",
    "name": "Gabaldón",
    "lat": "39.61667",
    "lng": "-1.93333"
  },
  {
    "country": "ES",
    "name": "Fuerte del Rey",
    "lat": "37.87492",
    "lng": "-3.88389"
  },
  {
    "country": "ES",
    "name": "Fuente Vaqueros",
    "lat": "37.22019",
    "lng": "-3.78294"
  },
  {
    "country": "ES",
    "name": "Fuente-Tójar",
    "lat": "37.51095",
    "lng": "-4.14631"
  },
  {
    "country": "ES",
    "name": "Fuentes de León",
    "lat": "38.06866",
    "lng": "-6.53884"
  },
  {
    "country": "ES",
    "name": "Fuentes de Andalucía",
    "lat": "37.46409",
    "lng": "-5.34615"
  },
  {
    "country": "ES",
    "name": "Fuentes",
    "lat": "39.96667",
    "lng": "-2.01667"
  },
  {
    "country": "ES",
    "name": "Fuenterrobles",
    "lat": "39.58333",
    "lng": "-1.35"
  },
  {
    "country": "ES",
    "name": "Fuente Palmera",
    "lat": "37.70494",
    "lng": "-5.09965"
  },
  {
    "country": "ES",
    "name": "Fuente Obejuna",
    "lat": "38.26667",
    "lng": "-5.41667"
  },
  {
    "country": "ES",
    "name": "Fuentelespino de Moya",
    "lat": "39.91667",
    "lng": "-1.46667"
  },
  {
    "country": "ES",
    "name": "Fuentelespino de Haro",
    "lat": "39.68934",
    "lng": "-2.66869"
  },
  {
    "country": "ES",
    "name": "Fuente la Lancha",
    "lat": "38.41667",
    "lng": "-5.03333"
  },
  {
    "country": "ES",
    "name": "La Font de la Figuera",
    "lat": "38.8",
    "lng": "-0.88333"
  },
  {
    "country": "ES",
    "name": "Fuenteheridos",
    "lat": "37.90545",
    "lng": "-6.66108"
  },
  {
    "country": "ES",
    "name": "Fuente el Fresno",
    "lat": "39.22839",
    "lng": "-3.77487"
  },
  {
    "country": "ES",
    "name": "Fuente de Piedra",
    "lat": "37.13526",
    "lng": "-4.73"
  },
  {
    "country": "ES",
    "name": "Fuente de Pedro Naharro",
    "lat": "39.92438",
    "lng": "-3.00916"
  },
  {
    "country": "ES",
    "name": "Fuente del Maestre",
    "lat": "38.52656",
    "lng": "-6.44782"
  },
  {
    "country": "ES",
    "name": "Fuente de Cantos",
    "lat": "38.25",
    "lng": "-6.3"
  },
  {
    "country": "ES",
    "name": "Fuentealbilla",
    "lat": "39.26667",
    "lng": "-1.55"
  },
  {
    "country": "ES",
    "name": "Fuente-Álamo de Murcia",
    "lat": "37.7",
    "lng": "-1.1"
  },
  {
    "country": "ES",
    "name": "Fuente-Álamo",
    "lat": "38.69288",
    "lng": "-1.43158"
  },
  {
    "country": "ES",
    "name": "Fuensanta de Martos",
    "lat": "37.64756",
    "lng": "-3.90846"
  },
  {
    "country": "ES",
    "name": "Fuensanta",
    "lat": "39.23333",
    "lng": "-2.06667"
  },
  {
    "country": "ES",
    "name": "Fuenllana",
    "lat": "38.7559",
    "lng": "-2.95814"
  },
  {
    "country": "ES",
    "name": "Fuenlabrada de los Montes",
    "lat": "39.13288",
    "lng": "-4.93513"
  },
  {
    "country": "ES",
    "name": "Fuengirola",
    "lat": "36.53998",
    "lng": "-4.62473"
  },
  {
    "country": "ES",
    "name": "Fuencaliente de la Palma",
    "lat": "28.49236",
    "lng": "-17.84529"
  },
  {
    "country": "ES",
    "name": "Fuencaliente",
    "lat": "39.18624",
    "lng": "-4.02576"
  },
  {
    "country": "ES",
    "name": "Fuencaliente",
    "lat": "38.40602",
    "lng": "-4.30492"
  },
  {
    "country": "ES",
    "name": "Frontera",
    "lat": "27.75404",
    "lng": "-18.00367"
  },
  {
    "country": "ES",
    "name": "Frigiliana",
    "lat": "36.78747",
    "lng": "-3.89441"
  },
  {
    "country": "ES",
    "name": "Fresnedoso de Ibor",
    "lat": "39.68418",
    "lng": "-5.50899"
  },
  {
    "country": "ES",
    "name": "Fresneda de Altarejos",
    "lat": "39.92577",
    "lng": "-2.31498"
  },
  {
    "country": "ES",
    "name": "Freila",
    "lat": "37.5299",
    "lng": "-2.90828"
  },
  {
    "country": "ES",
    "name": "Fregenal de la Sierra",
    "lat": "38.16922",
    "lng": "-6.6537"
  },
  {
    "country": "ES",
    "name": "Frailes",
    "lat": "37.48617",
    "lng": "-3.83743"
  },
  {
    "country": "ES",
    "name": "Foios",
    "lat": "39.53333",
    "lng": "-0.35"
  },
  {
    "country": "ES",
    "name": "Fortuna",
    "lat": "38.1814",
    "lng": "-1.1259"
  },
  {
    "country": "ES",
    "name": "Fortaleny",
    "lat": "39.18333",
    "lng": "-0.3"
  },
  {
    "country": "ES",
    "name": "Fornalutx",
    "lat": "39.78232",
    "lng": "2.74107"
  },
  {
    "country": "ES",
    "name": "Formentera de Segura",
    "lat": "38.08509",
    "lng": "-0.74604"
  },
  {
    "country": "ES",
    "name": "Fontanars dels Alforins",
    "lat": "38.78423",
    "lng": "-0.78667"
  },
  {
    "country": "ES",
    "name": "Fontanarejo",
    "lat": "39.22014",
    "lng": "-4.51753"
  },
  {
    "country": "ES",
    "name": "Fonelas",
    "lat": "37.41042",
    "lng": "-3.17158"
  },
  {
    "country": "ES",
    "name": "Fondón",
    "lat": "36.9802",
    "lng": "-2.85957"
  },
  {
    "country": "ES",
    "name": "Firgas",
    "lat": "28.10711",
    "lng": "-15.56299"
  },
  {
    "country": "ES",
    "name": "Finestrat",
    "lat": "38.56737",
    "lng": "-0.21235"
  },
  {
    "country": "ES",
    "name": "Fines",
    "lat": "37.36074",
    "lng": "-2.2581"
  },
  {
    "country": "ES",
    "name": "Fiñana",
    "lat": "37.1715",
    "lng": "-2.84011"
  },
  {
    "country": "ES",
    "name": "Ferreries",
    "lat": "39.98324",
    "lng": "4.01181"
  },
  {
    "country": "ES",
    "name": "Ferreira",
    "lat": "37.17247",
    "lng": "-3.03539"
  },
  {
    "country": "ES",
    "name": "Fernán-Núñez",
    "lat": "37.67044",
    "lng": "-4.7264"
  },
  {
    "country": "ES",
    "name": "Feria",
    "lat": "38.51151",
    "lng": "-6.56416"
  },
  {
    "country": "ES",
    "name": "Férez",
    "lat": "38.35",
    "lng": "-2"
  },
  {
    "country": "ES",
    "name": "Felanitx",
    "lat": "39.4696",
    "lng": "3.14831"
  },
  {
    "country": "ES",
    "name": "Favara",
    "lat": "39.11667",
    "lng": "-0.28333"
  },
  {
    "country": "ES",
    "name": "Faura",
    "lat": "39.71667",
    "lng": "-0.25"
  },
  {
    "country": "ES",
    "name": "Fasnia",
    "lat": "28.23638",
    "lng": "-16.43886"
  },
  {
    "country": "ES",
    "name": "Faraján",
    "lat": "36.61695",
    "lng": "-5.18839"
  },
  {
    "country": "ES",
    "name": "Famorca",
    "lat": "38.73101",
    "lng": "-0.24726"
  },
  {
    "country": "ES",
    "name": "Facheca",
    "lat": "38.73501",
    "lng": "-0.26766"
  },
  {
    "country": "ES",
    "name": "Estubeny",
    "lat": "39.01792",
    "lng": "-0.62379"
  },
  {
    "country": "ES",
    "name": "Estivella",
    "lat": "39.71667",
    "lng": "-0.35"
  },
  {
    "country": "ES",
    "name": "Estepona",
    "lat": "36.42764",
    "lng": "-5.14589"
  },
  {
    "country": "ES",
    "name": "Estepa",
    "lat": "37.29263",
    "lng": "-4.87896"
  },
  {
    "country": "ES",
    "name": "Estellencs",
    "lat": "39.65338",
    "lng": "2.4813"
  },
  {
    "country": "ES",
    "name": "Esporles",
    "lat": "39.66794",
    "lng": "2.57867"
  },
  {
    "country": "ES",
    "name": "Espinoso del Rey",
    "lat": "39.65333",
    "lng": "-4.78371"
  },
  {
    "country": "ES",
    "name": "Espiel",
    "lat": "38.2",
    "lng": "-5.01667"
  },
  {
    "country": "ES",
    "name": "Espera",
    "lat": "36.87446",
    "lng": "-5.806"
  },
  {
    "country": "ES",
    "name": "Espelúy",
    "lat": "38.0318",
    "lng": "-3.86309"
  },
  {
    "country": "ES",
    "name": "Espejo",
    "lat": "37.6798",
    "lng": "-4.55355"
  },
  {
    "country": "ES",
    "name": "Espartinas",
    "lat": "37.38154",
    "lng": "-6.12578"
  },
  {
    "country": "ES",
    "name": "Esparragosa de la Serena",
    "lat": "38.651",
    "lng": "-5.60657"
  },
  {
    "country": "ES",
    "name": "Esparragosa de Lares",
    "lat": "38.97517",
    "lng": "-5.26968"
  },
  {
    "country": "ES",
    "name": "Esparragalejo",
    "lat": "38.9433",
    "lng": "-6.43549"
  },
  {
    "country": "ES",
    "name": "Eslida",
    "lat": "39.88333",
    "lng": "-0.3"
  },
  {
    "country": "ES",
    "name": "Escúzar",
    "lat": "37.06219",
    "lng": "-3.76126"
  },
  {
    "country": "ES",
    "name": "Escurial",
    "lat": "39.16857",
    "lng": "-5.88465"
  },
  {
    "country": "ES",
    "name": "Escorca",
    "lat": "39.82138",
    "lng": "2.86941"
  },
  {
    "country": "ES",
    "name": "Escañuela",
    "lat": "37.87885",
    "lng": "-4.03376"
  },
  {
    "country": "ES",
    "name": "Escalonilla",
    "lat": "39.9257",
    "lng": "-4.35095"
  },
  {
    "country": "ES",
    "name": "Escacena del Campo",
    "lat": "37.40837",
    "lng": "-6.3887"
  },
  {
    "country": "ES",
    "name": "Erustes",
    "lat": "39.95667",
    "lng": "-4.49656"
  },
  {
    "country": "ES",
    "name": "Entrín Bajo",
    "lat": "38.71855",
    "lng": "-6.71349"
  },
  {
    "country": "ES",
    "name": "Enix",
    "lat": "36.87732",
    "lng": "-2.6018"
  },
  {
    "country": "ES",
    "name": "Enguídanos",
    "lat": "39.66667",
    "lng": "-1.6"
  },
  {
    "country": "ES",
    "name": "Enguera",
    "lat": "38.97974",
    "lng": "-0.68683"
  },
  {
    "country": "ES",
    "name": "Encinas Reales",
    "lat": "37.27419",
    "lng": "-4.48828"
  },
  {
    "country": "ES",
    "name": "Encinasola",
    "lat": "38.13413",
    "lng": "-6.86675"
  },
  {
    "country": "ES",
    "name": "Emperador",
    "lat": "39.55",
    "lng": "-0.33333"
  },
  {
    "country": "ES",
    "name": "El Viso del Alcor",
    "lat": "37.39106",
    "lng": "-5.71993"
  },
  {
    "country": "ES",
    "name": "El Viso",
    "lat": "38.48333",
    "lng": "-4.95"
  },
  {
    "country": "ES",
    "name": "El Varadero",
    "lat": "36.72521",
    "lng": "-3.52183"
  },
  {
    "country": "ES",
    "name": "El Toboso",
    "lat": "39.51333",
    "lng": "-2.99726"
  },
  {
    "country": "ES",
    "name": "El Saucejo",
    "lat": "37.07237",
    "lng": "-5.09818"
  },
  {
    "country": "ES",
    "name": "El Rubio",
    "lat": "37.35617",
    "lng": "-4.98896"
  },
  {
    "country": "ES",
    "name": "El Ronquillo",
    "lat": "37.72628",
    "lng": "-6.1762"
  },
  {
    "country": "ES",
    "name": "El Rompido",
    "lat": "37.21773",
    "lng": "-7.12206"
  },
  {
    "country": "ES",
    "name": "El Robledo",
    "lat": "39.21898",
    "lng": "-4.28099"
  },
  {
    "country": "ES",
    "name": "El Puerto de Santa María",
    "lat": "36.59389",
    "lng": "-6.23298"
  },
  {
    "country": "ES",
    "name": "El Puente del Arzobispo",
    "lat": "39.80174",
    "lng": "-5.17178"
  },
  {
    "country": "ES",
    "name": "El Provencio",
    "lat": "39.3774",
    "lng": "-2.57448"
  },
  {
    "country": "ES",
    "name": "Port de Sóller",
    "lat": "39.79759",
    "lng": "2.69637"
  },
  {
    "country": "ES",
    "name": "El Pedernoso",
    "lat": "39.4858",
    "lng": "-2.74642"
  },
  {
    "country": "ES",
    "name": "El Paso",
    "lat": "28.65007",
    "lng": "-17.88274"
  },
  {
    "country": "ES",
    "name": "El Grao",
    "lat": "39.97358",
    "lng": "0.01284"
  },
  {
    "country": "ES",
    "name": "El Gastor",
    "lat": "36.85478",
    "lng": "-5.32334"
  },
  {
    "country": "ES",
    "name": "El Ejido",
    "lat": "36.77629",
    "lng": "-2.81456"
  },
  {
    "country": "ES",
    "name": "Elda",
    "lat": "38.47783",
    "lng": "-0.79157"
  },
  {
    "country": "ES",
    "name": "El Coronil",
    "lat": "37.07955",
    "lng": "-5.6341"
  },
  {
    "country": "ES",
    "name": "Elche de la Sierra",
    "lat": "38.45123",
    "lng": "-2.0476"
  },
  {
    "country": "ES",
    "name": "Elche",
    "lat": "38.26218",
    "lng": "-0.70107"
  },
  {
    "country": "ES",
    "name": "El Cerro de Andévalo",
    "lat": "37.73537",
    "lng": "-6.93692"
  },
  {
    "country": "ES",
    "name": "El Castillo de las Guardas",
    "lat": "37.69314",
    "lng": "-6.31503"
  },
  {
    "country": "ES",
    "name": "El Casar",
    "lat": "38.53089",
    "lng": "-5.92513"
  },
  {
    "country": "ES",
    "name": "El Carpio de Tajo",
    "lat": "39.88796",
    "lng": "-4.45388"
  },
  {
    "country": "ES",
    "name": "El Carpio",
    "lat": "37.94085",
    "lng": "-4.49696"
  },
  {
    "country": "ES",
    "name": "El Bosque",
    "lat": "36.75828",
    "lng": "-5.50535"
  },
  {
    "country": "ES",
    "name": "El Bonillo",
    "lat": "38.95048",
    "lng": "-2.54048"
  },
  {
    "country": "ES",
    "name": "s'Arenal",
    "lat": "39.5",
    "lng": "2.75"
  },
  {
    "country": "ES",
    "name": "El Arahal",
    "lat": "37.26273",
    "lng": "-5.5453"
  },
  {
    "country": "ES",
    "name": "Écija",
    "lat": "37.5422",
    "lng": "-5.0826"
  },
  {
    "country": "ES",
    "name": "Dúrcal",
    "lat": "36.98788",
    "lng": "-3.56601"
  },
  {
    "country": "ES",
    "name": "Dúdar",
    "lat": "37.18579",
    "lng": "-3.48347"
  },
  {
    "country": "ES",
    "name": "Dos Torres",
    "lat": "38.45",
    "lng": "-4.9"
  },
  {
    "country": "ES",
    "name": "Dos Hermanas",
    "lat": "37.28287",
    "lng": "-5.92088"
  },
  {
    "country": "ES",
    "name": "Dosbarrios",
    "lat": "39.88199",
    "lng": "-3.48419"
  },
  {
    "country": "ES",
    "name": "Dos Aguas",
    "lat": "39.28333",
    "lng": "-0.8"
  },
  {
    "country": "ES",
    "name": "Don Benito",
    "lat": "38.95627",
    "lng": "-5.86162"
  },
  {
    "country": "ES",
    "name": "Doña Mencía",
    "lat": "37.55346",
    "lng": "-4.35602"
  },
  {
    "country": "ES",
    "name": "Don Álvaro",
    "lat": "38.84837",
    "lng": "-6.27475"
  },
  {
    "country": "ES",
    "name": "Domingo Pérez",
    "lat": "39.97661",
    "lng": "-4.50554"
  },
  {
    "country": "ES",
    "name": "Domingo Pérez",
    "lat": "37.49591",
    "lng": "-3.50929"
  },
  {
    "country": "ES",
    "name": "Domeño",
    "lat": "39.66115",
    "lng": "-0.67077"
  },
  {
    "country": "ES",
    "name": "Dolores",
    "lat": "38.14002",
    "lng": "-0.77088"
  },
  {
    "country": "ES",
    "name": "Dílar",
    "lat": "37.07282",
    "lng": "-3.60134"
  },
  {
    "country": "ES",
    "name": "Diezma",
    "lat": "37.31982",
    "lng": "-3.33256"
  },
  {
    "country": "ES",
    "name": "Deià",
    "lat": "39.74806",
    "lng": "2.64823"
  },
  {
    "country": "ES",
    "name": "Denia",
    "lat": "38.84078",
    "lng": "0.10574"
  },
  {
    "country": "ES",
    "name": "Deleitosa",
    "lat": "39.64359",
    "lng": "-5.64576"
  },
  {
    "country": "ES",
    "name": "Deifontes",
    "lat": "37.3262",
    "lng": "-3.59568"
  },
  {
    "country": "ES",
    "name": "Dehesas Viejas",
    "lat": "37.47414",
    "lng": "-3.55225"
  },
  {
    "country": "ES",
    "name": "Dehesas de Guadix",
    "lat": "37.58876",
    "lng": "-3.10317"
  },
  {
    "country": "ES",
    "name": "Daya Vieja",
    "lat": "38.1048",
    "lng": "-0.73804"
  },
  {
    "country": "ES",
    "name": "Daya Nueva",
    "lat": "38.11313",
    "lng": "-0.76028"
  },
  {
    "country": "ES",
    "name": "Darro",
    "lat": "37.34987",
    "lng": "-3.29465"
  },
  {
    "country": "ES",
    "name": "Dalías",
    "lat": "36.82179",
    "lng": "-2.87138"
  },
  {
    "country": "ES",
    "name": "Daimús",
    "lat": "38.96667",
    "lng": "-0.15"
  },
  {
    "country": "ES",
    "name": "Daimiel",
    "lat": "39.07004",
    "lng": "-3.61498"
  },
  {
    "country": "ES",
    "name": "Cútar",
    "lat": "36.83134",
    "lng": "-4.22739"
  },
  {
    "country": "ES",
    "name": "Cumbres Mayores",
    "lat": "38.06194",
    "lng": "-6.64565"
  },
  {
    "country": "ES",
    "name": "Cullera",
    "lat": "39.16667",
    "lng": "-0.25"
  },
  {
    "country": "ES",
    "name": "Cúllar-Vega",
    "lat": "37.15361",
    "lng": "-3.67072"
  },
  {
    "country": "ES",
    "name": "Cuevas de San Marcos",
    "lat": "37.26666",
    "lng": "-4.41432"
  },
  {
    "country": "ES",
    "name": "Cuevas del Campo",
    "lat": "37.60755",
    "lng": "-2.92938"
  },
  {
    "country": "ES",
    "name": "Cuevas del Becerro",
    "lat": "36.87537",
    "lng": "-5.04488"
  },
  {
    "country": "ES",
    "name": "Cuevas del Almanzora",
    "lat": "37.29678",
    "lng": "-1.88218"
  },
  {
    "country": "ES",
    "name": "Cuevas Bajas",
    "lat": "37.23526",
    "lng": "-4.48714"
  },
  {
    "country": "ES",
    "name": "Cuerva",
    "lat": "39.66374",
    "lng": "-4.21085"
  },
  {
    "country": "ES",
    "name": "Quatretonda",
    "lat": "38.95",
    "lng": "-0.4"
  },
  {
    "country": "ES",
    "name": "Quartell",
    "lat": "39.73333",
    "lng": "-0.26667"
  },
  {
    "country": "ES",
    "name": "Quart de Poblet",
    "lat": "39.48139",
    "lng": "-0.43937"
  },
  {
    "country": "ES",
    "name": "Quart de les Valls",
    "lat": "39.73333",
    "lng": "-0.26667"
  },
  {
    "country": "ES",
    "name": "Cristina",
    "lat": "38.83745",
    "lng": "-6.09867"
  },
  {
    "country": "ES",
    "name": "Crevillente",
    "lat": "38.24994",
    "lng": "-0.80975"
  },
  {
    "country": "ES",
    "name": "Cózar",
    "lat": "38.66219",
    "lng": "-3.07205"
  },
  {
    "country": "ES",
    "name": "Cox",
    "lat": "38.14164",
    "lng": "-0.88736"
  },
  {
    "country": "ES",
    "name": "Cotillas",
    "lat": "38.43115",
    "lng": "-2.5055"
  },
  {
    "country": "ES",
    "name": "Cotes",
    "lat": "39.0701",
    "lng": "-0.57449"
  },
  {
    "country": "ES",
    "name": "Costitx",
    "lat": "39.65675",
    "lng": "2.94953"
  },
  {
    "country": "ES",
    "name": "Cortes de Pallás",
    "lat": "39.25",
    "lng": "-0.93333"
  },
  {
    "country": "ES",
    "name": "Cortes de la Frontera",
    "lat": "36.6171",
    "lng": "-5.34266"
  },
  {
    "country": "ES",
    "name": "Cortes de Baza",
    "lat": "37.65514",
    "lng": "-2.77167"
  },
  {
    "country": "ES",
    "name": "Cortelazor",
    "lat": "37.93639",
    "lng": "-6.62462"
  },
  {
    "country": "ES",
    "name": "Cortegana",
    "lat": "37.91116",
    "lng": "-6.82045"
  },
  {
    "country": "ES",
    "name": "Corte de Peleas",
    "lat": "38.72631",
    "lng": "-6.67035"
  },
  {
    "country": "ES",
    "name": "Corteconcepción",
    "lat": "37.9",
    "lng": "-6.5"
  },
  {
    "country": "ES",
    "name": "Corral-Rubio",
    "lat": "38.83462",
    "lng": "-1.46034"
  },
  {
    "country": "ES",
    "name": "Corralejo",
    "lat": "28.73079",
    "lng": "-13.86749"
  },
  {
    "country": "ES",
    "name": "Corral de Calatrava",
    "lat": "38.85793",
    "lng": "-4.0814"
  },
  {
    "country": "ES",
    "name": "Corral de Almaguer",
    "lat": "39.75987",
    "lng": "-3.16452"
  },
  {
    "country": "ES",
    "name": "Coripe",
    "lat": "36.97335",
    "lng": "-5.44022"
  },
  {
    "country": "ES",
    "name": "Coria del Río",
    "lat": "37.28766",
    "lng": "-6.0541"
  },
  {
    "country": "ES",
    "name": "Coria",
    "lat": "39.98406",
    "lng": "-6.53603"
  },
  {
    "country": "ES",
    "name": "Cordobilla de Lácara",
    "lat": "39.14763",
    "lng": "-6.43619"
  },
  {
    "country": "ES",
    "name": "Córdoba",
    "lat": "37.89155",
    "lng": "-4.77275"
  },
  {
    "country": "ES",
    "name": "Corbera",
    "lat": "39.15",
    "lng": "-0.35"
  },
  {
    "country": "ES",
    "name": "Consuegra",
    "lat": "39.46246",
    "lng": "-3.608"
  },
  {
    "country": "ES",
    "name": "Constantina",
    "lat": "37.86667",
    "lng": "-5.61667"
  },
  {
    "country": "ES",
    "name": "Consell",
    "lat": "39.66861",
    "lng": "2.81267"
  },
  {
    "country": "ES",
    "name": "Conquista de la Sierra",
    "lat": "39.3507",
    "lng": "-5.73464"
  },
  {
    "country": "ES",
    "name": "Conquista",
    "lat": "38.4",
    "lng": "-4.5"
  },
  {
    "country": "ES",
    "name": "Conil de la Frontera",
    "lat": "36.27719",
    "lng": "-6.0885"
  },
  {
    "country": "ES",
    "name": "Confrides",
    "lat": "38.68451",
    "lng": "-0.2689"
  },
  {
    "country": "ES",
    "name": "Cómpeta",
    "lat": "36.83352",
    "lng": "-3.9743"
  },
  {
    "country": "ES",
    "name": "Comares",
    "lat": "36.84929",
    "lng": "-4.24664"
  },
  {
    "country": "ES",
    "name": "Colònia de Sant Jordi",
    "lat": "39.3181",
    "lng": "2.99197"
  },
  {
    "country": "ES",
    "name": "Colomera",
    "lat": "37.37156",
    "lng": "-3.71393"
  },
  {
    "country": "ES",
    "name": "Colmenar",
    "lat": "36.90519",
    "lng": "-4.33557"
  },
  {
    "country": "ES",
    "name": "Coll d'en Rabassa",
    "lat": "39.55083",
    "lng": "2.69468"
  },
  {
    "country": "ES",
    "name": "Coín",
    "lat": "36.65947",
    "lng": "-4.75639"
  },
  {
    "country": "ES",
    "name": "Cogollos de Guadix",
    "lat": "37.22521",
    "lng": "-3.16094"
  },
  {
    "country": "ES",
    "name": "Cofrentes",
    "lat": "39.22926",
    "lng": "-1.06061"
  },
  {
    "country": "ES",
    "name": "Cocentaina",
    "lat": "38.73975",
    "lng": "-0.43976"
  },
  {
    "country": "ES",
    "name": "Cobisa",
    "lat": "39.80425",
    "lng": "-4.02528"
  },
  {
    "country": "ES",
    "name": "Cóbdar",
    "lat": "37.26166",
    "lng": "-2.21098"
  },
  {
    "country": "ES",
    "name": "Ciudad Real",
    "lat": "38.98626",
    "lng": "-3.92907"
  },
  {
    "country": "ES",
    "name": "Ciruelos",
    "lat": "39.93881",
    "lng": "-3.61383"
  },
  {
    "country": "ES",
    "name": "Cijuela",
    "lat": "37.198",
    "lng": "-3.81174"
  },
  {
    "country": "ES",
    "name": "Cieza",
    "lat": "38.23998",
    "lng": "-1.41987"
  },
  {
    "country": "ES",
    "name": "Churriana de la Vega",
    "lat": "37.14499",
    "lng": "-3.64617"
  },
  {
    "country": "ES",
    "name": "Chumillas",
    "lat": "39.76667",
    "lng": "-2.03333"
  },
  {
    "country": "ES",
    "name": "Chulilla",
    "lat": "39.65",
    "lng": "-0.88333"
  },
  {
    "country": "ES",
    "name": "Chueca",
    "lat": "39.73191",
    "lng": "-3.94365"
  },
  {
    "country": "ES",
    "name": "Chucena",
    "lat": "37.36305",
    "lng": "-6.39304"
  },
  {
    "country": "ES",
    "name": "Chóvar",
    "lat": "39.85",
    "lng": "-0.31667"
  },
  {
    "country": "ES",
    "name": "Chiva",
    "lat": "39.46667",
    "lng": "-0.71667"
  },
  {
    "country": "ES",
    "name": "Xirivella",
    "lat": "39.46588",
    "lng": "-0.42589"
  },
  {
    "country": "ES",
    "name": "Chirivel",
    "lat": "37.59527",
    "lng": "-2.26844"
  },
  {
    "country": "ES",
    "name": "Chipiona",
    "lat": "36.73663",
    "lng": "-6.43703"
  },
  {
    "country": "ES",
    "name": "Chinchilla de Monte Aragón",
    "lat": "38.92088",
    "lng": "-1.72018"
  },
  {
    "country": "ES",
    "name": "Chimeneas",
    "lat": "37.13125",
    "lng": "-3.8213"
  },
  {
    "country": "ES",
    "name": "Chilluévar",
    "lat": "38.00088",
    "lng": "-3.0324"
  },
  {
    "country": "ES",
    "name": "Chillón",
    "lat": "38.79595",
    "lng": "-4.86628"
  },
  {
    "country": "ES",
    "name": "Chilches",
    "lat": "39.78238",
    "lng": "-0.18742"
  },
  {
    "country": "ES",
    "name": "Chiclana de Segura",
    "lat": "38.31187",
    "lng": "-3.04219"
  },
  {
    "country": "ES",
    "name": "Chiclana de la Frontera",
    "lat": "36.41976",
    "lng": "-6.14367"
  },
  {
    "country": "ES",
    "name": "Cheste",
    "lat": "39.48333",
    "lng": "-0.68333"
  },
  {
    "country": "ES",
    "name": "Chercos",
    "lat": "37.2545",
    "lng": "-2.26657"
  },
  {
    "country": "ES",
    "name": "Chera",
    "lat": "39.6",
    "lng": "-0.96667"
  },
  {
    "country": "ES",
    "name": "Chelva",
    "lat": "39.7493",
    "lng": "-0.99684"
  },
  {
    "country": "ES",
    "name": "Chella",
    "lat": "39.04203",
    "lng": "-0.65916"
  },
  {
    "country": "ES",
    "name": "Cheles",
    "lat": "38.51225",
    "lng": "-7.28177"
  },
  {
    "country": "ES",
    "name": "Chauchina",
    "lat": "37.19977",
    "lng": "-3.77157"
  },
  {
    "country": "ES",
    "name": "Ceuti",
    "lat": "38.07859",
    "lng": "-1.27467"
  },
  {
    "country": "ES",
    "name": "Cervera del Llano",
    "lat": "39.78312",
    "lng": "-2.42019"
  },
  {
    "country": "ES",
    "name": "Cerdà",
    "lat": "38.98333",
    "lng": "-0.56667"
  },
  {
    "country": "ES",
    "name": "Cenizate",
    "lat": "39.3",
    "lng": "-1.65"
  },
  {
    "country": "ES",
    "name": "Cenes de la Vega",
    "lat": "37.16006",
    "lng": "-3.53548"
  },
  {
    "country": "ES",
    "name": "Cehegín",
    "lat": "38.09242",
    "lng": "-1.7985"
  },
  {
    "country": "ES",
    "name": "Cedillo",
    "lat": "39.65099",
    "lng": "-7.49817"
  },
  {
    "country": "ES",
    "name": "Ceclavín",
    "lat": "39.82231",
    "lng": "-6.77329"
  },
  {
    "country": "ES",
    "name": "Cebolla",
    "lat": "39.94897",
    "lng": "-4.57175"
  },
  {
    "country": "ES",
    "name": "Cazorla",
    "lat": "37.91495",
    "lng": "-3.00342"
  },
  {
    "country": "ES",
    "name": "Cazalla de la Sierra",
    "lat": "37.93333",
    "lng": "-5.75"
  },
  {
    "country": "ES",
    "name": "Cazalilla",
    "lat": "37.98389",
    "lng": "-3.88295"
  },
  {
    "country": "ES",
    "name": "Caudete de las Fuentes",
    "lat": "39.55965",
    "lng": "-1.27853"
  },
  {
    "country": "ES",
    "name": "Caudete",
    "lat": "38.70679",
    "lng": "-0.98723"
  },
  {
    "country": "ES",
    "name": "Catral",
    "lat": "38.16061",
    "lng": "-0.80209"
  },
  {
    "country": "ES",
    "name": "Catarroja",
    "lat": "39.4",
    "lng": "-0.4"
  },
  {
    "country": "ES",
    "name": "Catadau",
    "lat": "39.26667",
    "lng": "-0.56667"
  },
  {
    "country": "ES",
    "name": "Castuera",
    "lat": "38.73204",
    "lng": "-5.5439"
  },
  {
    "country": "ES",
    "name": "Castro del Río",
    "lat": "37.69125",
    "lng": "-4.48058"
  },
  {
    "country": "ES",
    "name": "Castro de Filabres",
    "lat": "37.18484",
    "lng": "-2.44024"
  },
  {
    "country": "ES",
    "name": "Castril",
    "lat": "37.79581",
    "lng": "-2.78002"
  },
  {
    "country": "ES",
    "name": "Castillo de Locubín",
    "lat": "37.52858",
    "lng": "-3.9422"
  },
  {
    "country": "ES",
    "name": "Castillo de Garcimuñoz",
    "lat": "39.65928",
    "lng": "-2.3803"
  },
  {
    "country": "ES",
    "name": "Castillejo de Iniesta",
    "lat": "39.53333",
    "lng": "-1.76667"
  },
  {
    "country": "ES",
    "name": "Castilléjar",
    "lat": "37.71697",
    "lng": "-2.6406"
  },
  {
    "country": "ES",
    "name": "Castilleja del Campo",
    "lat": "37.38627",
    "lng": "-6.33443"
  },
  {
    "country": "ES",
    "name": "Castilleja de la Cuesta",
    "lat": "37.38594",
    "lng": "-6.05258"
  },
  {
    "country": "ES",
    "name": "Castilleja de Guzmán",
    "lat": "37.40955",
    "lng": "-6.05515"
  },
  {
    "country": "ES",
    "name": "Castilblanco de los Arroyos",
    "lat": "37.67576",
    "lng": "-5.98886"
  },
  {
    "country": "ES",
    "name": "Castilblanco",
    "lat": "39.28487",
    "lng": "-5.09098"
  },
  {
    "country": "ES",
    "name": "Castellonet de la Conquesta",
    "lat": "38.91667",
    "lng": "-0.26667"
  },
  {
    "country": "ES",
    "name": "Castelló de Rugat",
    "lat": "38.88333",
    "lng": "-0.36667"
  },
  {
    "country": "ES",
    "name": "Castelló de la Plana",
    "lat": "39.98567",
    "lng": "-0.04935"
  },
  {
    "country": "ES",
    "name": "Castellnovo",
    "lat": "39.86667",
    "lng": "-0.45"
  },
  {
    "country": "ES",
    "name": "Castell de Ferro",
    "lat": "36.72569",
    "lng": "-3.355"
  },
  {
    "country": "ES",
    "name": "Castell de Castells",
    "lat": "38.72555",
    "lng": "-0.19242"
  },
  {
    "country": "ES",
    "name": "Castellar de Santiago",
    "lat": "38.53928",
    "lng": "-3.27573"
  },
  {
    "country": "ES",
    "name": "Castellar de la Frontera",
    "lat": "36.31736",
    "lng": "-5.45407"
  },
  {
    "country": "ES",
    "name": "Cástaras",
    "lat": "36.93164",
    "lng": "-3.25406"
  },
  {
    "country": "ES",
    "name": "Castañar de Ibor",
    "lat": "39.62843",
    "lng": "-5.41709"
  },
  {
    "country": "ES",
    "name": "Castalla",
    "lat": "38.59694",
    "lng": "-0.67207"
  },
  {
    "country": "ES",
    "name": "Casinos",
    "lat": "39.7",
    "lng": "-0.7"
  },
  {
    "country": "ES",
    "name": "Casillas de Coria",
    "lat": "39.96543",
    "lng": "-6.63711"
  },
  {
    "country": "ES",
    "name": "Casatejada",
    "lat": "39.88642",
    "lng": "-5.68193"
  },
  {
    "country": "ES",
    "name": "Casasimarro",
    "lat": "39.36667",
    "lng": "-2.03333"
  },
  {
    "country": "ES",
    "name": "Casas Ibáñez",
    "lat": "39.28333",
    "lng": "-1.46667"
  },
  {
    "country": "ES",
    "name": "Casas de Ves",
    "lat": "39.25",
    "lng": "-1.33333"
  },
  {
    "country": "ES",
    "name": "Casas de Reina",
    "lat": "38.2",
    "lng": "-5.96667"
  },
  {
    "country": "ES",
    "name": "Casas de Miravete",
    "lat": "39.72687",
    "lng": "-5.74363"
  },
  {
    "country": "ES",
    "name": "Casas de Millán",
    "lat": "39.81757",
    "lng": "-6.32966"
  },
  {
    "country": "ES",
    "name": "Casas de los Pinos",
    "lat": "39.33375",
    "lng": "-2.36984"
  },
  {
    "country": "ES",
    "name": "Casas de Lázaro",
    "lat": "38.77056",
    "lng": "-2.24044"
  },
  {
    "country": "ES",
    "name": "Casas de Juan Núñez",
    "lat": "39.1019",
    "lng": "-1.55821"
  },
  {
    "country": "ES",
    "name": "Casas de Haro",
    "lat": "39.33355",
    "lng": "-2.27273"
  },
  {
    "country": "ES",
    "name": "Casas de Guijarro",
    "lat": "39.35",
    "lng": "-2.16667"
  },
  {
    "country": "ES",
    "name": "Casas de Garcimolina",
    "lat": "40",
    "lng": "-1.41667"
  },
  {
    "country": "ES",
    "name": "Casas de Fernando Alonso",
    "lat": "39.35065",
    "lng": "-2.32402"
  },
  {
    "country": "ES",
    "name": "Casas de Don Pedro",
    "lat": "39.10822",
    "lng": "-5.33077"
  },
  {
    "country": "ES",
    "name": "Casas de Don Antonio",
    "lat": "39.23578",
    "lng": "-6.29143"
  },
  {
    "country": "ES",
    "name": "Casas de Benítez",
    "lat": "39.36667",
    "lng": "-2.13333"
  },
  {
    "country": "ES",
    "name": "Casasbuenas",
    "lat": "39.76117",
    "lng": "-4.12558"
  },
  {
    "country": "ES",
    "name": "Casariche",
    "lat": "37.29389",
    "lng": "-4.75972"
  },
  {
    "country": "ES",
    "name": "Casares",
    "lat": "36.44689",
    "lng": "-5.2858"
  },
  {
    "country": "ES",
    "name": "Casar de Cáceres",
    "lat": "39.56106",
    "lng": "-6.41944"
  },
  {
    "country": "ES",
    "name": "Casarabonela",
    "lat": "36.78616",
    "lng": "-4.84276"
  },
  {
    "country": "ES",
    "name": "Casabermeja",
    "lat": "36.8926",
    "lng": "-4.42938"
  },
  {
    "country": "ES",
    "name": "Cartaya",
    "lat": "37.28114",
    "lng": "-7.15071"
  },
  {
    "country": "ES",
    "name": "Estación de Cártama",
    "lat": "36.73333",
    "lng": "-4.61667"
  },
  {
    "country": "ES",
    "name": "Cártama",
    "lat": "36.71068",
    "lng": "-4.63297"
  },
  {
    "country": "ES",
    "name": "Cartajima",
    "lat": "36.64548",
    "lng": "-5.1541"
  },
  {
    "country": "ES",
    "name": "Cartagena",
    "lat": "37.60512",
    "lng": "-0.98623"
  },
  {
    "country": "ES",
    "name": "Carrizosa",
    "lat": "38.84204",
    "lng": "-2.9925"
  },
  {
    "country": "ES",
    "name": "Carrizal",
    "lat": "27.91161",
    "lng": "-15.40558"
  },
  {
    "country": "ES",
    "name": "Carrión de los Céspedes",
    "lat": "37.37007",
    "lng": "-6.32923"
  },
  {
    "country": "ES",
    "name": "Carrión de Calatrava",
    "lat": "39.01897",
    "lng": "-3.81683"
  },
  {
    "country": "ES",
    "name": "Carrícola",
    "lat": "38.84133",
    "lng": "-0.4726"
  },
  {
    "country": "ES",
    "name": "Carriches",
    "lat": "39.96417",
    "lng": "-4.45864"
  },
  {
    "country": "ES",
    "name": "Carratraca",
    "lat": "36.8529",
    "lng": "-4.81998"
  },
  {
    "country": "ES",
    "name": "Carrascosa de Haro",
    "lat": "39.59757",
    "lng": "-2.54182"
  },
  {
    "country": "ES",
    "name": "Carrascalejo",
    "lat": "39.63333",
    "lng": "-5.21667"
  },
  {
    "country": "ES",
    "name": "Carmonita",
    "lat": "39.15455",
    "lng": "-6.33864"
  },
  {
    "country": "ES",
    "name": "Carmona",
    "lat": "37.47125",
    "lng": "-5.64608"
  },
  {
    "country": "ES",
    "name": "Carmena",
    "lat": "39.95562",
    "lng": "-4.40149"
  },
  {
    "country": "ES",
    "name": "Carlet",
    "lat": "39.2266",
    "lng": "-0.52142"
  },
  {
    "country": "ES",
    "name": "Cardenete",
    "lat": "39.76667",
    "lng": "-1.68333"
  },
  {
    "country": "ES",
    "name": "Cardeña",
    "lat": "38.27023",
    "lng": "-4.32358"
  },
  {
    "country": "ES",
    "name": "Càrcer",
    "lat": "39.06667",
    "lng": "-0.56667"
  },
  {
    "country": "ES",
    "name": "Carcelén",
    "lat": "39.10202",
    "lng": "-1.30879"
  },
  {
    "country": "ES",
    "name": "Carcaixent",
    "lat": "39.1218",
    "lng": "-0.44812"
  },
  {
    "country": "ES",
    "name": "Carcabuey",
    "lat": "37.4442",
    "lng": "-4.27471"
  },
  {
    "country": "ES",
    "name": "Carboneros",
    "lat": "38.22958",
    "lng": "-3.63139"
  },
  {
    "country": "ES",
    "name": "Carboneras de Guadazaón",
    "lat": "39.88333",
    "lng": "-1.8"
  },
  {
    "country": "ES",
    "name": "Carboneras",
    "lat": "36.99666",
    "lng": "-1.89651"
  },
  {
    "country": "ES",
    "name": "Carbajo",
    "lat": "39.60333",
    "lng": "-7.19565"
  },
  {
    "country": "ES",
    "name": "Caravaca",
    "lat": "38.10558",
    "lng": "-1.86343"
  },
  {
    "country": "ES",
    "name": "Carataunas",
    "lat": "36.92204",
    "lng": "-3.40834"
  },
  {
    "country": "ES",
    "name": "Capilla",
    "lat": "38.82037",
    "lng": "-5.08417"
  },
  {
    "country": "ES",
    "name": "Capileira",
    "lat": "36.96148",
    "lng": "-3.35864"
  },
  {
    "country": "ES",
    "name": "Capdepera",
    "lat": "39.70237",
    "lng": "3.43532"
  },
  {
    "country": "ES",
    "name": "Cantoria",
    "lat": "37.35146",
    "lng": "-2.19209"
  },
  {
    "country": "ES",
    "name": "Cantillana",
    "lat": "37.61032",
    "lng": "-5.82472"
  },
  {
    "country": "ES",
    "name": "Can Picafort",
    "lat": "39.76567",
    "lng": "3.15488"
  },
  {
    "country": "ES",
    "name": "Canjáyar",
    "lat": "37.00959",
    "lng": "-2.73943"
  },
  {
    "country": "ES",
    "name": "Canillas de Albaida",
    "lat": "36.84665",
    "lng": "-3.98678"
  },
  {
    "country": "ES",
    "name": "Canillas de Aceituno",
    "lat": "36.87303",
    "lng": "-4.08254"
  },
  {
    "country": "ES",
    "name": "Caniles",
    "lat": "37.43671",
    "lng": "-2.72482"
  },
  {
    "country": "ES",
    "name": "Cañete la Real",
    "lat": "36.95154",
    "lng": "-5.0244"
  },
  {
    "country": "ES",
    "name": "Cañete de las Torres",
    "lat": "37.86717",
    "lng": "-4.31835"
  },
  {
    "country": "ES",
    "name": "Canet d'En Berenguer",
    "lat": "39.68333",
    "lng": "-0.21667"
  },
  {
    "country": "ES",
    "name": "Canena",
    "lat": "38.0493",
    "lng": "-3.4831"
  },
  {
    "country": "ES",
    "name": "Candelaria",
    "lat": "28.3548",
    "lng": "-16.37268"
  },
  {
    "country": "ES",
    "name": "Cañaveral de León",
    "lat": "38.01667",
    "lng": "-6.51667"
  },
  {
    "country": "ES",
    "name": "Cañaveral",
    "lat": "39.79198",
    "lng": "-6.3913"
  },
  {
    "country": "ES",
    "name": "Cáñar",
    "lat": "36.92684",
    "lng": "-3.42808"
  },
  {
    "country": "ES",
    "name": "Cañamero",
    "lat": "39.37995",
    "lng": "-5.38857"
  },
  {
    "country": "ES",
    "name": "Canals",
    "lat": "38.96251",
    "lng": "-0.58443"
  },
  {
    "country": "ES",
    "name": "Cañada Rosal",
    "lat": "37.59924",
    "lng": "-5.21016"
  },
  {
    "country": "ES",
    "name": "Cañada del Hoyo",
    "lat": "39.96667",
    "lng": "-1.9"
  },
  {
    "country": "ES",
    "name": "Cañada de Calatrava",
    "lat": "38.85429",
    "lng": "-4.02103"
  },
  {
    "country": "ES",
    "name": "Cañada",
    "lat": "38.6739",
    "lng": "-0.8133"
  },
  {
    "country": "ES",
    "name": "Camuñas",
    "lat": "39.42704",
    "lng": "-3.45503"
  },
  {
    "country": "ES",
    "name": "Campotéjar",
    "lat": "37.48235",
    "lng": "-3.61771"
  },
  {
    "country": "ES",
    "name": "Campos del Río",
    "lat": "38.03966",
    "lng": "-1.35306"
  },
  {
    "country": "ES",
    "name": "Campos",
    "lat": "39.43099",
    "lng": "3.01935"
  },
  {
    "country": "ES",
    "name": "Camporrobles",
    "lat": "39.65",
    "lng": "-1.4"
  },
  {
    "country": "ES",
    "name": "Campofrío",
    "lat": "37.76652",
    "lng": "-6.57363"
  },
  {
    "country": "ES",
    "name": "Campo de Criptana",
    "lat": "39.40463",
    "lng": "-3.12492"
  },
  {
    "country": "ES",
    "name": "Campiña",
    "lat": "38.21896",
    "lng": "-2.98069"
  },
  {
    "country": "ES",
    "name": "Campillos-Paravientos",
    "lat": "39.98333",
    "lng": "-1.55"
  },
  {
    "country": "ES",
    "name": "Campillos",
    "lat": "37.04826",
    "lng": "-4.86308"
  },
  {
    "country": "ES",
    "name": "Campillo de Llerena",
    "lat": "38.50196",
    "lng": "-5.83139"
  },
  {
    "country": "ES",
    "name": "Campillo de Deleitosa",
    "lat": "39.70297",
    "lng": "-5.57436"
  },
  {
    "country": "ES",
    "name": "Campillo de Arenas",
    "lat": "37.55535",
    "lng": "-3.63552"
  },
  {
    "country": "ES",
    "name": "Campillo de Altobuey",
    "lat": "39.6",
    "lng": "-1.8"
  },
  {
    "country": "ES",
    "name": "El Campello",
    "lat": "38.42885",
    "lng": "-0.39774"
  },
  {
    "country": "ES",
    "name": "Campanet",
    "lat": "39.7747",
    "lng": "2.96506"
  },
  {
    "country": "ES",
    "name": "Campanario",
    "lat": "38.8644",
    "lng": "-5.61744"
  },
  {
    "country": "ES",
    "name": "Cambil",
    "lat": "37.67934",
    "lng": "-3.56537"
  },
  {
    "country": "ES",
    "name": "Camas",
    "lat": "37.40202",
    "lng": "-6.03314"
  },
  {
    "country": "ES",
    "name": "Calvià",
    "lat": "39.5657",
    "lng": "2.50621"
  },
  {
    "country": "ES",
    "name": "Calp",
    "lat": "38.6447",
    "lng": "0.0445"
  },
  {
    "country": "ES",
    "name": "Calonge",
    "lat": "39.40039",
    "lng": "3.20335"
  },
  {
    "country": "ES",
    "name": "Callosa de Segura",
    "lat": "38.12497",
    "lng": "-0.87822"
  },
  {
    "country": "ES",
    "name": "Callosa d'En Sarrià",
    "lat": "38.65",
    "lng": "-0.11667"
  },
  {
    "country": "ES",
    "name": "Calles",
    "lat": "39.72118",
    "lng": "-0.97057"
  },
  {
    "country": "ES",
    "name": "Calicasas",
    "lat": "37.2713",
    "lng": "-3.61345"
  },
  {
    "country": "ES",
    "name": "Caleruela",
    "lat": "39.87483",
    "lng": "-5.25693"
  },
  {
    "country": "ES",
    "name": "Calera y Chozas",
    "lat": "39.88278",
    "lng": "-4.98213"
  },
  {
    "country": "ES",
    "name": "Calera de León",
    "lat": "38.1",
    "lng": "-6.33333"
  },
  {
    "country": "ES",
    "name": "Calasparra",
    "lat": "38.22997",
    "lng": "-1.69986"
  },
  {
    "country": "ES",
    "name": "Cala Rajada",
    "lat": "39.71174",
    "lng": "3.4631"
  },
  {
    "country": "ES",
    "name": "Calañas",
    "lat": "37.65568",
    "lng": "-6.8805"
  },
  {
    "country": "ES",
    "name": "Calamonte",
    "lat": "38.88861",
    "lng": "-6.38791"
  },
  {
    "country": "ES",
    "name": "Cala",
    "lat": "37.96667",
    "lng": "-6.31667"
  },
  {
    "country": "ES",
    "name": "Cájar",
    "lat": "37.13381",
    "lng": "-3.57274"
  },
  {
    "country": "ES",
    "name": "Cadiz",
    "lat": "36.52672",
    "lng": "-6.2891"
  },
  {
    "country": "ES",
    "name": "Cádiar",
    "lat": "36.94591",
    "lng": "-3.1802"
  },
  {
    "country": "ES",
    "name": "Cachorrilla",
    "lat": "39.91557",
    "lng": "-6.66909"
  },
  {
    "country": "ES",
    "name": "Cáceres",
    "lat": "39.47649",
    "lng": "-6.37224"
  },
  {
    "country": "ES",
    "name": "Cabra del Santo Cristo",
    "lat": "37.70379",
    "lng": "-3.28765"
  },
  {
    "country": "ES",
    "name": "Cabra",
    "lat": "37.47249",
    "lng": "-4.44206"
  },
  {
    "country": "ES",
    "name": "Cabezas Rubias",
    "lat": "37.7266",
    "lng": "-7.08738"
  },
  {
    "country": "ES",
    "name": "Cabezarados",
    "lat": "38.84469",
    "lng": "-4.2983"
  },
  {
    "country": "ES",
    "name": "Cabezamesada",
    "lat": "39.8163",
    "lng": "-3.10236"
  },
  {
    "country": "ES",
    "name": "Cabeza la Vaca",
    "lat": "38.08333",
    "lng": "-6.41667"
  },
  {
    "country": "ES",
    "name": "Cabeza del Buey",
    "lat": "38.72227",
    "lng": "-5.21946"
  },
  {
    "country": "ES",
    "name": "Cabañas de Yepes",
    "lat": "39.89051",
    "lng": "-3.53502"
  },
  {
    "country": "ES",
    "name": "Cabañas del Castillo",
    "lat": "39.54804",
    "lng": "-5.51203"
  },
  {
    "country": "ES",
    "name": "Busquístar",
    "lat": "36.93796",
    "lng": "-3.29444"
  },
  {
    "country": "ES",
    "name": "Busot",
    "lat": "38.48206",
    "lng": "-0.41918"
  },
  {
    "country": "ES",
    "name": "Burujón",
    "lat": "39.90113",
    "lng": "-4.2973"
  },
  {
    "country": "ES",
    "name": "Burriana",
    "lat": "39.88901",
    "lng": "-0.08499"
  },
  {
    "country": "ES",
    "name": "Burjassot",
    "lat": "39.50984",
    "lng": "-0.41327"
  },
  {
    "country": "ES",
    "name": "Burguillos de Toledo",
    "lat": "39.79635",
    "lng": "-3.99254"
  },
  {
    "country": "ES",
    "name": "Burguillos del Cerro",
    "lat": "38.38008",
    "lng": "-6.59037"
  },
  {
    "country": "ES",
    "name": "Burguillos",
    "lat": "37.5844",
    "lng": "-5.96654"
  },
  {
    "country": "ES",
    "name": "Bunyola",
    "lat": "39.69634",
    "lng": "2.69955"
  },
  {
    "country": "ES",
    "name": "Buñol",
    "lat": "39.41667",
    "lng": "-0.78333"
  },
  {
    "country": "ES",
    "name": "Bullas",
    "lat": "38.04667",
    "lng": "-1.67227"
  },
  {
    "country": "ES",
    "name": "Bujalance",
    "lat": "37.89556",
    "lng": "-4.38074"
  },
  {
    "country": "ES",
    "name": "Búger",
    "lat": "39.75809",
    "lng": "2.98349"
  },
  {
    "country": "ES",
    "name": "Bugarra",
    "lat": "39.61667",
    "lng": "-0.76667"
  },
  {
    "country": "ES",
    "name": "Bufali",
    "lat": "38.86775",
    "lng": "-0.51617"
  },
  {
    "country": "ES",
    "name": "Buenavista del Norte",
    "lat": "28.37458",
    "lng": "-16.86098"
  },
  {
    "country": "ES",
    "name": "Buenache de Alarcón",
    "lat": "39.65",
    "lng": "-2.16667"
  },
  {
    "country": "ES",
    "name": "Bubión",
    "lat": "36.949",
    "lng": "-3.35615"
  },
  {
    "country": "ES",
    "name": "Brozas",
    "lat": "39.61278",
    "lng": "-6.7777"
  },
  {
    "country": "ES",
    "name": "Brenes",
    "lat": "37.54944",
    "lng": "-5.87139"
  },
  {
    "country": "ES",
    "name": "Breña Baja",
    "lat": "28.63011",
    "lng": "-17.78953"
  },
  {
    "country": "ES",
    "name": "Breña Alta",
    "lat": "28.65",
    "lng": "-17.78333"
  },
  {
    "country": "ES",
    "name": "Brazatortas",
    "lat": "38.65869",
    "lng": "-4.29368"
  },
  {
    "country": "ES",
    "name": "Botija",
    "lat": "39.34498",
    "lng": "-6.07318"
  },
  {
    "country": "ES",
    "name": "Bornos",
    "lat": "36.81677",
    "lng": "-5.74448"
  },
  {
    "country": "ES",
    "name": "Bormujos",
    "lat": "37.37358",
    "lng": "-6.07233"
  },
  {
    "country": "ES",
    "name": "Bonrepòs i Mirambell",
    "lat": "39.51667",
    "lng": "-0.36667"
  },
  {
    "country": "ES",
    "name": "Boniches",
    "lat": "39.98333",
    "lng": "-1.61667"
  },
  {
    "country": "ES",
    "name": "Bonete",
    "lat": "38.87136",
    "lng": "-1.34851"
  },
  {
    "country": "ES",
    "name": "Bonares",
    "lat": "37.32423",
    "lng": "-6.68073"
  },
  {
    "country": "ES",
    "name": "Bolulla",
    "lat": "38.67529",
    "lng": "-0.11184"
  },
  {
    "country": "ES",
    "name": "Bollullos par del Condado",
    "lat": "37.34127",
    "lng": "-6.5397"
  },
  {
    "country": "ES",
    "name": "Bollullos de la Mitación",
    "lat": "37.34014",
    "lng": "-6.13719"
  },
  {
    "country": "ES",
    "name": "Bolbaite",
    "lat": "39.06041",
    "lng": "-0.67466"
  },
  {
    "country": "ES",
    "name": "Bolaños de Calatrava",
    "lat": "38.9069",
    "lng": "-3.66345"
  },
  {
    "country": "ES",
    "name": "Bohonal de Ibor",
    "lat": "39.78457",
    "lng": "-5.485"
  },
  {
    "country": "ES",
    "name": "Bogarra",
    "lat": "38.58139",
    "lng": "-2.2129"
  },
  {
    "country": "ES",
    "name": "Bodonal de la Sierra",
    "lat": "38.14751",
    "lng": "-6.5595"
  },
  {
    "country": "ES",
    "name": "Bocairent",
    "lat": "38.76667",
    "lng": "-0.61667"
  },
  {
    "country": "ES",
    "name": "Blanca",
    "lat": "38.1791",
    "lng": "-1.37473"
  },
  {
    "country": "ES",
    "name": "Binissalem",
    "lat": "39.68744",
    "lng": "2.84396"
  },
  {
    "country": "ES",
    "name": "Bigastro",
    "lat": "38.06237",
    "lng": "-0.89841"
  },
  {
    "country": "ES",
    "name": "Bienvenida",
    "lat": "38.3",
    "lng": "-6.2"
  },
  {
    "country": "ES",
    "name": "Bienservida",
    "lat": "38.51716",
    "lng": "-2.61087"
  },
  {
    "country": "ES",
    "name": "Bicorp",
    "lat": "39.13215",
    "lng": "-0.7872"
  },
  {
    "country": "ES",
    "name": "Biar",
    "lat": "38.63117",
    "lng": "-0.76458"
  },
  {
    "country": "ES",
    "name": "Bétera",
    "lat": "39.59111",
    "lng": "-0.46151"
  },
  {
    "country": "ES",
    "name": "Berrocalejo",
    "lat": "39.81948",
    "lng": "-5.34951"
  },
  {
    "country": "ES",
    "name": "Berrocal",
    "lat": "37.60863",
    "lng": "-6.54147"
  },
  {
    "country": "ES",
    "name": "Berlanga",
    "lat": "38.28333",
    "lng": "-5.81667"
  },
  {
    "country": "ES",
    "name": "Berja",
    "lat": "36.84693",
    "lng": "-2.94966"
  },
  {
    "country": "ES",
    "name": "Bérchules",
    "lat": "36.97678",
    "lng": "-3.19067"
  },
  {
    "country": "ES",
    "name": "Benzú",
    "lat": "35.91653",
    "lng": "-5.37293"
  },
  {
    "country": "ES",
    "name": "Bentarique",
    "lat": "36.98823",
    "lng": "-2.61991"
  },
  {
    "country": "ES",
    "name": "Benquerencia",
    "lat": "39.30994",
    "lng": "-6.08465"
  },
  {
    "country": "ES",
    "name": "Benizalón",
    "lat": "37.21213",
    "lng": "-2.2418"
  },
  {
    "country": "ES",
    "name": "Benitagla",
    "lat": "37.23138",
    "lng": "-2.23935"
  },
  {
    "country": "ES",
    "name": "Benitachell",
    "lat": "38.73273",
    "lng": "0.14354"
  },
  {
    "country": "ES",
    "name": "Benisuera",
    "lat": "38.9132",
    "lng": "-0.47784"
  },
  {
    "country": "ES",
    "name": "Benissoda",
    "lat": "38.83333",
    "lng": "-0.51667"
  },
  {
    "country": "ES",
    "name": "Benisanó",
    "lat": "39.61667",
    "lng": "-0.56667"
  },
  {
    "country": "ES",
    "name": "Benissa",
    "lat": "38.71492",
    "lng": "0.04849"
  },
  {
    "country": "ES",
    "name": "Benirredrà",
    "lat": "38.96667",
    "lng": "-0.18333"
  },
  {
    "country": "ES",
    "name": "Beniparrell",
    "lat": "39.38333",
    "lng": "-0.41667"
  },
  {
    "country": "ES",
    "name": "Benimuslem",
    "lat": "39.13162",
    "lng": "-0.49288"
  },
  {
    "country": "ES",
    "name": "Benimodo",
    "lat": "39.21403",
    "lng": "-0.52679"
  },
  {
    "country": "ES",
    "name": "Benimeli",
    "lat": "38.82362",
    "lng": "-0.04221"
  },
  {
    "country": "ES",
    "name": "Benimassot",
    "lat": "38.75",
    "lng": "-0.28333"
  },
  {
    "country": "ES",
    "name": "Benimarfull",
    "lat": "38.7759",
    "lng": "-0.39079"
  },
  {
    "country": "ES",
    "name": "Benimantell",
    "lat": "38.67709",
    "lng": "-0.21057"
  },
  {
    "country": "ES",
    "name": "Benillup",
    "lat": "38.75397",
    "lng": "-0.37991"
  },
  {
    "country": "ES",
    "name": "Benilloba",
    "lat": "38.70012",
    "lng": "-0.38998"
  },
  {
    "country": "ES",
    "name": "Benijofar",
    "lat": "38.07785",
    "lng": "-0.7368"
  },
  {
    "country": "ES",
    "name": "Benigànim",
    "lat": "38.95",
    "lng": "-0.43333"
  },
  {
    "country": "ES",
    "name": "Beniflá",
    "lat": "38.92813",
    "lng": "-0.17816"
  },
  {
    "country": "ES",
    "name": "Benifaió",
    "lat": "39.28439",
    "lng": "-0.42598"
  },
  {
    "country": "ES",
    "name": "Benifallim",
    "lat": "38.66259",
    "lng": "-0.39994"
  },
  {
    "country": "ES",
    "name": "Benifairó de les Valls",
    "lat": "39.73333",
    "lng": "-0.26667"
  },
  {
    "country": "ES",
    "name": "Beniel",
    "lat": "38.04636",
    "lng": "-1.00233"
  },
  {
    "country": "ES",
    "name": "Benidorm",
    "lat": "38.53816",
    "lng": "-0.13098"
  },
  {
    "country": "ES",
    "name": "Benidoleig",
    "lat": "38.79278",
    "lng": "-0.02992"
  },
  {
    "country": "ES",
    "name": "Benicolet",
    "lat": "38.91987",
    "lng": "-0.34694"
  },
  {
    "country": "ES",
    "name": "Beniatjar",
    "lat": "38.84754",
    "lng": "-0.41736"
  },
  {
    "country": "ES",
    "name": "Beniarrés",
    "lat": "38.82019",
    "lng": "-0.37741"
  },
  {
    "country": "ES",
    "name": "Beniarjó",
    "lat": "38.93249",
    "lng": "-0.18634"
  },
  {
    "country": "ES",
    "name": "Beniardá",
    "lat": "38.68433",
    "lng": "-0.21629"
  },
  {
    "country": "ES",
    "name": "Beniarbeig",
    "lat": "38.82232",
    "lng": "-0.0021"
  },
  {
    "country": "ES",
    "name": "Benferri",
    "lat": "38.14129",
    "lng": "-0.96212"
  },
  {
    "country": "ES",
    "name": "Benetússer",
    "lat": "39.42265",
    "lng": "-0.39686"
  },
  {
    "country": "ES",
    "name": "Benejúzar",
    "lat": "38.07728",
    "lng": "-0.83942"
  },
  {
    "country": "ES",
    "name": "Beneixama",
    "lat": "38.7",
    "lng": "-0.76667"
  },
  {
    "country": "ES",
    "name": "Beneixida",
    "lat": "39.06667",
    "lng": "-0.55"
  },
  {
    "country": "ES",
    "name": "Benavites",
    "lat": "39.73333",
    "lng": "-0.25"
  },
  {
    "country": "ES",
    "name": "Benatae",
    "lat": "38.35323",
    "lng": "-2.65121"
  },
  {
    "country": "ES",
    "name": "Benasau",
    "lat": "38.69047",
    "lng": "-0.34278"
  },
  {
    "country": "ES",
    "name": "Benarrabá",
    "lat": "36.5512",
    "lng": "-5.27608"
  },
  {
    "country": "ES",
    "name": "Benaoján",
    "lat": "36.71929",
    "lng": "-5.2522"
  },
  {
    "country": "ES",
    "name": "Benaocaz",
    "lat": "36.70069",
    "lng": "-5.42222"
  },
  {
    "country": "ES",
    "name": "Benamocarra",
    "lat": "36.79075",
    "lng": "-4.16146"
  },
  {
    "country": "ES",
    "name": "Benamejí",
    "lat": "37.26833",
    "lng": "-4.54123"
  },
  {
    "country": "ES",
    "name": "Benamaurel",
    "lat": "37.60826",
    "lng": "-2.7025"
  },
  {
    "country": "ES",
    "name": "Benamargosa",
    "lat": "36.83499",
    "lng": "-4.19362"
  },
  {
    "country": "ES",
    "name": "Benalúa de las Villas",
    "lat": "37.42742",
    "lng": "-3.68346"
  },
  {
    "country": "ES",
    "name": "Benalúa de Guadix",
    "lat": "37.35191",
    "lng": "-3.16404"
  },
  {
    "country": "ES",
    "name": "Benalmádena",
    "lat": "36.5961",
    "lng": "-4.57267"
  },
  {
    "country": "ES",
    "name": "Benalauría",
    "lat": "36.59445",
    "lng": "-5.26099"
  },
  {
    "country": "ES",
    "name": "Benahavís",
    "lat": "36.52361",
    "lng": "-5.04631"
  },
  {
    "country": "ES",
    "name": "Benahadux",
    "lat": "36.92493",
    "lng": "-2.45941"
  },
  {
    "country": "ES",
    "name": "Benaguasil",
    "lat": "39.6",
    "lng": "-0.58333"
  },
  {
    "country": "ES",
    "name": "Benagéber",
    "lat": "39.71667",
    "lng": "-1.1"
  },
  {
    "country": "ES",
    "name": "Benacazón",
    "lat": "37.35289",
    "lng": "-6.19663"
  },
  {
    "country": "ES",
    "name": "Belvis de la Jara",
    "lat": "39.75768",
    "lng": "-4.94932"
  },
  {
    "country": "ES",
    "name": "Belmontejo",
    "lat": "39.82212",
    "lng": "-2.34467"
  },
  {
    "country": "ES",
    "name": "Belmonte",
    "lat": "39.55746",
    "lng": "-2.70461"
  },
  {
    "country": "ES",
    "name": "Bélmez de la Moraleda",
    "lat": "37.72382",
    "lng": "-3.38207"
  },
  {
    "country": "ES",
    "name": "Bélmez",
    "lat": "38.26667",
    "lng": "-5.2"
  },
  {
    "country": "ES",
    "name": "Bellús",
    "lat": "38.9458",
    "lng": "-0.48697"
  },
  {
    "country": "ES",
    "name": "Bellreguard",
    "lat": "38.95",
    "lng": "-0.16667"
  },
  {
    "country": "ES",
    "name": "Bèlgida",
    "lat": "38.85",
    "lng": "-0.46667"
  },
  {
    "country": "ES",
    "name": "Belalcázar",
    "lat": "38.57566",
    "lng": "-5.16653"
  },
  {
    "country": "ES",
    "name": "Beires",
    "lat": "37.01237",
    "lng": "-2.79134"
  },
  {
    "country": "ES",
    "name": "Begíjar",
    "lat": "37.98492",
    "lng": "-3.53094"
  },
  {
    "country": "ES",
    "name": "Bédar",
    "lat": "37.19389",
    "lng": "-1.98166"
  },
  {
    "country": "ES",
    "name": "Betxí",
    "lat": "39.93333",
    "lng": "-0.2"
  },
  {
    "country": "ES",
    "name": "Beas de Segura",
    "lat": "38.2524",
    "lng": "-2.88875"
  },
  {
    "country": "ES",
    "name": "Beas de Guadix",
    "lat": "37.27861",
    "lng": "-3.20579"
  },
  {
    "country": "ES",
    "name": "Beas de Granada",
    "lat": "37.21803",
    "lng": "-3.48095"
  },
  {
    "country": "ES",
    "name": "Beas",
    "lat": "37.4257",
    "lng": "-6.79318"
  },
  {
    "country": "ES",
    "name": "Baza",
    "lat": "37.49073",
    "lng": "-2.77259"
  },
  {
    "country": "ES",
    "name": "Bayarque",
    "lat": "37.33062",
    "lng": "-2.4361"
  },
  {
    "country": "ES",
    "name": "Bayárcal",
    "lat": "37.03073",
    "lng": "-2.99606"
  },
  {
    "country": "ES",
    "name": "Baterno",
    "lat": "38.95578",
    "lng": "-4.91039"
  },
  {
    "country": "ES",
    "name": "Barrax",
    "lat": "39.04607",
    "lng": "-2.20152"
  },
  {
    "country": "ES",
    "name": "Barlovento",
    "lat": "28.82708",
    "lng": "-17.80377"
  },
  {
    "country": "ES",
    "name": "Barx",
    "lat": "39.01667",
    "lng": "-0.3"
  },
  {
    "country": "ES",
    "name": "Bargas",
    "lat": "39.94113",
    "lng": "-4.01979"
  },
  {
    "country": "ES",
    "name": "Barcience",
    "lat": "39.98367",
    "lng": "-4.23437"
  },
  {
    "country": "ES",
    "name": "Barchín del Hoyo",
    "lat": "39.66667",
    "lng": "-2.06667"
  },
  {
    "country": "ES",
    "name": "Barxeta",
    "lat": "39.01667",
    "lng": "-0.41667"
  },
  {
    "country": "ES",
    "name": "Barcarrota",
    "lat": "38.51473",
    "lng": "-6.84923"
  },
  {
    "country": "ES",
    "name": "Barbate",
    "lat": "36.19237",
    "lng": "-5.92186"
  },
  {
    "country": "ES",
    "name": "Baños de la Encina",
    "lat": "38.17379",
    "lng": "-3.77477"
  },
  {
    "country": "ES",
    "name": "Banyalbufar",
    "lat": "39.68734",
    "lng": "2.51409"
  },
  {
    "country": "ES",
    "name": "Balsa de Ves",
    "lat": "39.26667",
    "lng": "-1.2"
  },
  {
    "country": "ES",
    "name": "Balones",
    "lat": "38.73726",
    "lng": "-0.34324"
  },
  {
    "country": "ES",
    "name": "Balazote",
    "lat": "38.88444",
    "lng": "-2.1518"
  },
  {
    "country": "ES",
    "name": "Bailén",
    "lat": "38.09639",
    "lng": "-3.77786"
  },
  {
    "country": "ES",
    "name": "Baeza",
    "lat": "37.99384",
    "lng": "-3.47103"
  },
  {
    "country": "ES",
    "name": "Baena",
    "lat": "37.6167",
    "lng": "-4.32245"
  },
  {
    "country": "ES",
    "name": "Badolatosa",
    "lat": "37.30785",
    "lng": "-4.67296"
  },
  {
    "country": "ES",
    "name": "Badajoz",
    "lat": "38.87789",
    "lng": "-6.97061"
  },
  {
    "country": "ES",
    "name": "Azután",
    "lat": "39.78564",
    "lng": "-5.1273"
  },
  {
    "country": "ES",
    "name": "Azuébar",
    "lat": "39.83333",
    "lng": "-0.36667"
  },
  {
    "country": "ES",
    "name": "Azuaga",
    "lat": "38.26667",
    "lng": "-5.68333"
  },
  {
    "country": "ES",
    "name": "Aznalcóllar",
    "lat": "37.51914",
    "lng": "-6.26988"
  },
  {
    "country": "ES",
    "name": "Aznalcázar",
    "lat": "37.30422",
    "lng": "-6.24963"
  },
  {
    "country": "ES",
    "name": "Ayora",
    "lat": "39.05852",
    "lng": "-1.05635"
  },
  {
    "country": "ES",
    "name": "Ayódar",
    "lat": "40",
    "lng": "-0.36667"
  },
  {
    "country": "ES",
    "name": "Ayna",
    "lat": "38.55",
    "lng": "-2.08333"
  },
  {
    "country": "ES",
    "name": "Aielo de Malferit",
    "lat": "38.88333",
    "lng": "-0.58333"
  },
  {
    "country": "ES",
    "name": "Ayamonte",
    "lat": "37.21329",
    "lng": "-7.40807"
  },
  {
    "country": "ES",
    "name": "Atarfe",
    "lat": "37.22479",
    "lng": "-3.68686"
  },
  {
    "country": "ES",
    "name": "Atamaría",
    "lat": "37.59989",
    "lng": "-0.80682"
  },
  {
    "country": "ES",
    "name": "Atalaya del Cañavate",
    "lat": "39.51864",
    "lng": "-2.25175"
  },
  {
    "country": "ES",
    "name": "Atalaya",
    "lat": "38.33333",
    "lng": "-6.46667"
  },
  {
    "country": "ES",
    "name": "Atajate",
    "lat": "36.64017",
    "lng": "-5.24606"
  },
  {
    "country": "ES",
    "name": "Aspe",
    "lat": "38.34511",
    "lng": "-0.76721"
  },
  {
    "country": "ES",
    "name": "Arucas",
    "lat": "28.11983",
    "lng": "-15.52325"
  },
  {
    "country": "ES",
    "name": "Artenara",
    "lat": "28.02055",
    "lng": "-15.64693"
  },
  {
    "country": "ES",
    "name": "Artana",
    "lat": "39.89104",
    "lng": "-0.25758"
  },
  {
    "country": "ES",
    "name": "Artà",
    "lat": "39.69315",
    "lng": "3.34979"
  },
  {
    "country": "ES",
    "name": "Arroyomolinos de León",
    "lat": "38.01667",
    "lng": "-6.41667"
  },
  {
    "country": "ES",
    "name": "Arroyo de San Serván",
    "lat": "38.85443",
    "lng": "-6.45402"
  },
  {
    "country": "ES",
    "name": "Arroyo del Ojanco",
    "lat": "38.32065",
    "lng": "-2.89486"
  },
  {
    "country": "ES",
    "name": "Arroyo de la Luz",
    "lat": "39.48511",
    "lng": "-6.58401"
  },
  {
    "country": "ES",
    "name": "Arriate",
    "lat": "36.80005",
    "lng": "-5.1408"
  },
  {
    "country": "ES",
    "name": "Arrecife",
    "lat": "28.96302",
    "lng": "-13.54769"
  },
  {
    "country": "ES",
    "name": "Arquillos",
    "lat": "38.18148",
    "lng": "-3.42827"
  },
  {
    "country": "ES",
    "name": "Arona",
    "lat": "28.09962",
    "lng": "-16.68102"
  },
  {
    "country": "ES",
    "name": "Aroche",
    "lat": "37.94213",
    "lng": "-6.9576"
  },
  {
    "country": "ES",
    "name": "Armuña de Almanzora",
    "lat": "37.3503",
    "lng": "-2.4115"
  },
  {
    "country": "ES",
    "name": "Armilla",
    "lat": "37.14386",
    "lng": "-3.62534"
  },
  {
    "country": "ES",
    "name": "Arjonilla",
    "lat": "37.97422",
    "lng": "-4.10677"
  },
  {
    "country": "ES",
    "name": "Arjona",
    "lat": "37.93493",
    "lng": "-4.05478"
  },
  {
    "country": "ES",
    "name": "Cruce de Arinaga",
    "lat": "27.87656",
    "lng": "-15.42798"
  },
  {
    "country": "ES",
    "name": "Ariany",
    "lat": "39.65048",
    "lng": "3.11055"
  },
  {
    "country": "ES",
    "name": "Arguisuelas",
    "lat": "39.83333",
    "lng": "-1.81667"
  },
  {
    "country": "ES",
    "name": "Argamasilla de Calatrava",
    "lat": "38.72985",
    "lng": "-4.07627"
  },
  {
    "country": "ES",
    "name": "Argamasilla de Alba",
    "lat": "39.12917",
    "lng": "-3.09247"
  },
  {
    "country": "ES",
    "name": "Arenas de San Juan",
    "lat": "39.21861",
    "lng": "-3.50211"
  },
  {
    "country": "ES",
    "name": "Arenas del Rey",
    "lat": "36.95799",
    "lng": "-3.89362"
  },
  {
    "country": "ES",
    "name": "Arenas",
    "lat": "36.81625",
    "lng": "-4.04411"
  },
  {
    "country": "ES",
    "name": "Ardales",
    "lat": "36.87804",
    "lng": "-4.84694"
  },
  {
    "country": "ES",
    "name": "Arcos de las Salinas",
    "lat": "39.98333",
    "lng": "-1.03333"
  },
  {
    "country": "ES",
    "name": "Arcos de la Frontera",
    "lat": "36.75075",
    "lng": "-5.81056"
  },
  {
    "country": "ES",
    "name": "Archidona",
    "lat": "37.09654",
    "lng": "-4.38869"
  },
  {
    "country": "ES",
    "name": "Árchez",
    "lat": "36.83992",
    "lng": "-3.99208"
  },
  {
    "country": "ES",
    "name": "Archena",
    "lat": "38.11631",
    "lng": "-1.30043"
  },
  {
    "country": "ES",
    "name": "Arboleas",
    "lat": "37.35024",
    "lng": "-2.07384"
  },
  {
    "country": "ES",
    "name": "Arafo",
    "lat": "28.33971",
    "lng": "-16.42244"
  },
  {
    "country": "ES",
    "name": "Aracena",
    "lat": "37.89396",
    "lng": "-6.56116"
  },
  {
    "country": "ES",
    "name": "Antigua",
    "lat": "28.42307",
    "lng": "-14.01379"
  },
  {
    "country": "ES",
    "name": "Antequera",
    "lat": "37.01938",
    "lng": "-4.56123"
  },
  {
    "country": "ES",
    "name": "Antella",
    "lat": "39.07977",
    "lng": "-0.59195"
  },
  {
    "country": "ES",
    "name": "Antas",
    "lat": "37.24536",
    "lng": "-1.9176"
  },
  {
    "country": "ES",
    "name": "Añover de Tajo",
    "lat": "39.98873",
    "lng": "-3.76579"
  },
  {
    "country": "ES",
    "name": "Añora",
    "lat": "38.41667",
    "lng": "-4.9"
  },
  {
    "country": "ES",
    "name": "Anna",
    "lat": "39.02029",
    "lng": "-0.64621"
  },
  {
    "country": "ES",
    "name": "Andújar",
    "lat": "38.03922",
    "lng": "-4.05077"
  },
  {
    "country": "ES",
    "name": "Andratx",
    "lat": "39.57553",
    "lng": "2.42017"
  },
  {
    "country": "ES",
    "name": "Andilla",
    "lat": "39.83333",
    "lng": "-0.8"
  },
  {
    "country": "ES",
    "name": "Anchuras",
    "lat": "39.48059",
    "lng": "-4.83381"
  },
  {
    "country": "ES",
    "name": "Altura",
    "lat": "39.85",
    "lng": "-0.51667"
  },
  {
    "country": "ES",
    "name": "Altea",
    "lat": "38.59885",
    "lng": "-0.05139"
  },
  {
    "country": "ES",
    "name": "Altarejos",
    "lat": "39.91258",
    "lng": "-2.35692"
  },
  {
    "country": "ES",
    "name": "Alsodux",
    "lat": "37.00247",
    "lng": "-2.59476"
  },
  {
    "country": "ES",
    "name": "Alquife",
    "lat": "37.18024",
    "lng": "-3.11553"
  },
  {
    "country": "ES",
    "name": "L'Alqueria de la Comtessa",
    "lat": "38.93333",
    "lng": "-0.15"
  },
  {
    "country": "ES",
    "name": "Alpuente",
    "lat": "39.86667",
    "lng": "-1.01667"
  },
  {
    "country": "ES",
    "name": "Alpera",
    "lat": "38.96667",
    "lng": "-1.21667"
  },
  {
    "country": "ES",
    "name": "Alpandeire",
    "lat": "36.63402",
    "lng": "-5.20216"
  },
  {
    "country": "ES",
    "name": "Alozaina",
    "lat": "36.72736",
    "lng": "-4.85761"
  },
  {
    "country": "ES",
    "name": "Alosno",
    "lat": "37.54861",
    "lng": "-7.1147"
  },
  {
    "country": "ES",
    "name": "Alora",
    "lat": "36.82358",
    "lng": "-4.70575"
  },
  {
    "country": "ES",
    "name": "Almussafes",
    "lat": "39.28333",
    "lng": "-0.41667"
  },
  {
    "country": "ES",
    "name": "Almuñécar",
    "lat": "36.73393",
    "lng": "-3.69072"
  },
  {
    "country": "ES",
    "name": "Almudaina",
    "lat": "38.75999",
    "lng": "-0.35149"
  },
  {
    "country": "ES",
    "name": "Almoradí",
    "lat": "38.10879",
    "lng": "-0.79197"
  },
  {
    "country": "ES",
    "name": "Almonte",
    "lat": "37.2647",
    "lng": "-6.51667"
  },
  {
    "country": "ES",
    "name": "Almonacid del Marquesado",
    "lat": "39.82344",
    "lng": "-2.7677"
  },
  {
    "country": "ES",
    "name": "Almoines",
    "lat": "38.94325",
    "lng": "-0.18155"
  },
  {
    "country": "ES",
    "name": "Almoharín",
    "lat": "39.17685",
    "lng": "-6.04283"
  },
  {
    "country": "ES",
    "name": "Almogía",
    "lat": "36.8255",
    "lng": "-4.5407"
  },
  {
    "country": "ES",
    "name": "Almodóvar del Río",
    "lat": "37.8107",
    "lng": "-5.02037"
  },
  {
    "country": "ES",
    "name": "Almodóvar del Pinar",
    "lat": "39.71667",
    "lng": "-1.88333"
  },
  {
    "country": "ES",
    "name": "Almodóvar del Campo",
    "lat": "38.70936",
    "lng": "-4.17908"
  },
  {
    "country": "ES",
    "name": "Almócita",
    "lat": "37.00262",
    "lng": "-2.79051"
  },
  {
    "country": "ES",
    "name": "Almiserà",
    "lat": "38.91667",
    "lng": "-0.28333"
  },
  {
    "country": "ES",
    "name": "Almería",
    "lat": "36.83814",
    "lng": "-2.45974"
  },
  {
    "country": "ES",
    "name": "Almensilla",
    "lat": "37.31099",
    "lng": "-6.10998"
  },
  {
    "country": "ES",
    "name": "Almendralejo",
    "lat": "38.68316",
    "lng": "-6.40747"
  },
  {
    "country": "ES",
    "name": "Almendral",
    "lat": "38.61418",
    "lng": "-6.82097"
  },
  {
    "country": "ES",
    "name": "Almenara",
    "lat": "39.75",
    "lng": "-0.21667"
  },
  {
    "country": "ES",
    "name": "Almegíjar",
    "lat": "36.90258",
    "lng": "-3.30122"
  },
  {
    "country": "ES",
    "name": "Almedinilla",
    "lat": "37.43902",
    "lng": "-4.09052"
  },
  {
    "country": "ES",
    "name": "Almedina",
    "lat": "38.62453",
    "lng": "-2.95382"
  },
  {
    "country": "ES",
    "name": "Almedíjar",
    "lat": "39.86667",
    "lng": "-0.4"
  },
  {
    "country": "ES",
    "name": "Almassora",
    "lat": "39.94729",
    "lng": "-0.06313"
  },
  {
    "country": "ES",
    "name": "Almargen",
    "lat": "37.0021",
    "lng": "-5.02178"
  },
  {
    "country": "ES",
    "name": "Almaraz",
    "lat": "39.81416",
    "lng": "-5.67698"
  },
  {
    "country": "ES",
    "name": "Almansa",
    "lat": "38.86917",
    "lng": "-1.09713"
  },
  {
    "country": "ES",
    "name": "Almagro",
    "lat": "38.88941",
    "lng": "-3.71131"
  },
  {
    "country": "ES",
    "name": "Almadén de la Plata",
    "lat": "37.87221",
    "lng": "-6.08085"
  },
  {
    "country": "ES",
    "name": "Almadén",
    "lat": "38.77541",
    "lng": "-4.83156"
  },
  {
    "country": "ES",
    "name": "Almáchar",
    "lat": "36.80892",
    "lng": "-4.21614"
  },
  {
    "country": "ES",
    "name": "Aljucén",
    "lat": "39.04425",
    "lng": "-6.33109"
  },
  {
    "country": "ES",
    "name": "Aljaraque",
    "lat": "37.26989",
    "lng": "-7.02313"
  },
  {
    "country": "ES",
    "name": "Aliseda",
    "lat": "39.42329",
    "lng": "-6.69228"
  },
  {
    "country": "ES",
    "name": "Alicún de Ortega",
    "lat": "37.60898",
    "lng": "-3.13648"
  },
  {
    "country": "ES",
    "name": "Alicún",
    "lat": "36.9658",
    "lng": "-2.60212"
  },
  {
    "country": "ES",
    "name": "Alicante",
    "lat": "38.34517",
    "lng": "-0.48149"
  },
  {
    "country": "ES",
    "name": "Aliaguilla",
    "lat": "39.73333",
    "lng": "-1.31667"
  },
  {
    "country": "ES",
    "name": "Alía",
    "lat": "39.44803",
    "lng": "-5.21754"
  },
  {
    "country": "ES",
    "name": "Alhendín",
    "lat": "37.10879",
    "lng": "-3.64557"
  },
  {
    "country": "ES",
    "name": "Alhaurín el Grande",
    "lat": "36.643",
    "lng": "-4.68728"
  },
  {
    "country": "ES",
    "name": "Alhaurín de la Torre",
    "lat": "36.66401",
    "lng": "-4.56139"
  },
  {
    "country": "ES",
    "name": "Alhambra",
    "lat": "38.89925",
    "lng": "-3.05333"
  },
  {
    "country": "ES",
    "name": "Alhama de Murcia",
    "lat": "37.85103",
    "lng": "-1.42507"
  },
  {
    "country": "ES",
    "name": "Alhama de Granada",
    "lat": "37.00689",
    "lng": "-3.98963"
  },
  {
    "country": "ES",
    "name": "Alhama de Almería",
    "lat": "36.95692",
    "lng": "-2.56861"
  },
  {
    "country": "ES",
    "name": "Alhabia",
    "lat": "36.99003",
    "lng": "-2.58655"
  },
  {
    "country": "ES",
    "name": "Algueña",
    "lat": "38.33905",
    "lng": "-1.00433"
  },
  {
    "country": "ES",
    "name": "Alguazas",
    "lat": "38.05356",
    "lng": "-1.25051"
  },
  {
    "country": "ES",
    "name": "Algorfa",
    "lat": "38.08636",
    "lng": "-0.79646"
  },
  {
    "country": "ES",
    "name": "Algodonales",
    "lat": "36.88044",
    "lng": "-5.40536"
  },
  {
    "country": "ES",
    "name": "Alginet",
    "lat": "39.26667",
    "lng": "-0.46667"
  },
  {
    "country": "ES",
    "name": "Algimia de Almonacid",
    "lat": "39.91667",
    "lng": "-0.43333"
  },
  {
    "country": "ES",
    "name": "Algimia de Alfara",
    "lat": "39.75",
    "lng": "-0.36667"
  },
  {
    "country": "ES",
    "name": "Algemesí",
    "lat": "39.19042",
    "lng": "-0.43572"
  },
  {
    "country": "ES",
    "name": "Algeciras",
    "lat": "36.13326",
    "lng": "-5.45051"
  },
  {
    "country": "ES",
    "name": "Algatocín",
    "lat": "36.57356",
    "lng": "-5.27554"
  },
  {
    "country": "ES",
    "name": "Algarrobo",
    "lat": "36.77388",
    "lng": "-4.03952"
  },
  {
    "country": "ES",
    "name": "Algarra",
    "lat": "40",
    "lng": "-1.43333"
  },
  {
    "country": "ES",
    "name": "Algarinejo",
    "lat": "37.32526",
    "lng": "-4.1585"
  },
  {
    "country": "ES",
    "name": "Algar",
    "lat": "36.65748",
    "lng": "-5.65558"
  },
  {
    "country": "ES",
    "name": "Algámitas",
    "lat": "37.01516",
    "lng": "-5.14949"
  },
  {
    "country": "ES",
    "name": "Algaida",
    "lat": "39.55899",
    "lng": "2.89541"
  },
  {
    "country": "ES",
    "name": "Alfondeguilla",
    "lat": "39.83333",
    "lng": "-0.26667"
  },
  {
    "country": "ES",
    "name": "Alfarrasí",
    "lat": "38.9",
    "lng": "-0.5"
  },
  {
    "country": "ES",
    "name": "Alfarp",
    "lat": "39.28333",
    "lng": "-0.55"
  },
  {
    "country": "ES",
    "name": "Alfarnatejo",
    "lat": "36.9957",
    "lng": "-4.26064"
  },
  {
    "country": "ES",
    "name": "Alfarnate",
    "lat": "36.99426",
    "lng": "-4.25929"
  },
  {
    "country": "ES",
    "name": "Alfara del Patriarca",
    "lat": "39.55",
    "lng": "-0.38333"
  },
  {
    "country": "ES",
    "name": "Alfara de Algimia",
    "lat": "39.76667",
    "lng": "-0.35"
  },
  {
    "country": "ES",
    "name": "Alfauir",
    "lat": "38.93333",
    "lng": "-0.25"
  },
  {
    "country": "ES",
    "name": "Alfafara",
    "lat": "38.77339",
    "lng": "-0.55551"
  },
  {
    "country": "ES",
    "name": "Alfafar",
    "lat": "39.41667",
    "lng": "-0.38333"
  },
  {
    "country": "ES",
    "name": "Alfacar",
    "lat": "37.23744",
    "lng": "-3.56807"
  },
  {
    "country": "ES",
    "name": "Aledo",
    "lat": "37.79341",
    "lng": "-1.57356"
  },
  {
    "country": "ES",
    "name": "Aldeire",
    "lat": "37.16012",
    "lng": "-3.07204"
  },
  {
    "country": "ES",
    "name": "Aldeaquemada",
    "lat": "38.41215",
    "lng": "-3.37137"
  },
  {
    "country": "ES",
    "name": "Aldeanueva de San Bartolomé",
    "lat": "39.63608",
    "lng": "-5.11307"
  },
  {
    "country": "ES",
    "name": "Aldeanueva de Barbarroya",
    "lat": "39.75934",
    "lng": "-5.02287"
  },
  {
    "country": "ES",
    "name": "Aldea del Rey",
    "lat": "38.7383",
    "lng": "-3.84017"
  },
  {
    "country": "ES",
    "name": "Aldea del Cano",
    "lat": "39.28874",
    "lng": "-6.31806"
  },
  {
    "country": "ES",
    "name": "Aldeacentenera",
    "lat": "39.52725",
    "lng": "-5.62936"
  },
  {
    "country": "ES",
    "name": "Aldaia",
    "lat": "39.46569",
    "lng": "-0.46005"
  },
  {
    "country": "ES",
    "name": "Alcuéscar",
    "lat": "39.18091",
    "lng": "-6.22917"
  },
  {
    "country": "ES",
    "name": "Alcudia de Veo",
    "lat": "39.91667",
    "lng": "-0.35"
  },
  {
    "country": "ES",
    "name": "Alcudia de Monteagud",
    "lat": "37.23529",
    "lng": "-2.2665"
  },
  {
    "country": "ES",
    "name": "L'Alcúdia de Crespìns",
    "lat": "38.96667",
    "lng": "-0.58333"
  },
  {
    "country": "ES",
    "name": "L'Alcúdia",
    "lat": "39.19717",
    "lng": "-0.50537"
  },
  {
    "country": "ES",
    "name": "Alcúdia",
    "lat": "39.85316",
    "lng": "3.12138"
  },
  {
    "country": "ES",
    "name": "Alcublas",
    "lat": "39.8",
    "lng": "-0.7"
  },
  {
    "country": "ES",
    "name": "Alcubillas",
    "lat": "38.75312",
    "lng": "-3.13407"
  },
  {
    "country": "ES",
    "name": "Alcoy",
    "lat": "38.70545",
    "lng": "-0.47432"
  },
  {
    "country": "ES",
    "name": "Alcóntar",
    "lat": "37.33647",
    "lng": "-2.59725"
  },
  {
    "country": "ES",
    "name": "Alconera",
    "lat": "38.4",
    "lng": "-6.46667"
  },
  {
    "country": "ES",
    "name": "Alconchel de la Estrella",
    "lat": "39.71963",
    "lng": "-2.57366"
  },
  {
    "country": "ES",
    "name": "Alconchel",
    "lat": "38.51648",
    "lng": "-7.07161"
  },
  {
    "country": "ES",
    "name": "Alcollarín",
    "lat": "39.2447",
    "lng": "-5.73924"
  },
  {
    "country": "ES",
    "name": "Alcolea de Tajo",
    "lat": "39.80966",
    "lng": "-5.14738"
  },
  {
    "country": "ES",
    "name": "Alcolea del Río",
    "lat": "37.61506",
    "lng": "-5.66694"
  },
  {
    "country": "ES",
    "name": "Alcolea de Calatrava",
    "lat": "38.9868",
    "lng": "-4.11597"
  },
  {
    "country": "ES",
    "name": "Alcolea",
    "lat": "36.97458",
    "lng": "-2.9615"
  },
  {
    "country": "ES",
    "name": "Alcocer de Planes",
    "lat": "38.79501",
    "lng": "-0.40244"
  },
  {
    "country": "ES",
    "name": "Alcoba",
    "lat": "39.25988",
    "lng": "-4.47715"
  },
  {
    "country": "ES",
    "name": "Alzira",
    "lat": "39.15",
    "lng": "-0.43333"
  },
  {
    "country": "ES",
    "name": "Alcázar de San Juan",
    "lat": "39.39011",
    "lng": "-3.20827"
  },
  {
    "country": "ES",
    "name": "Alcaudete",
    "lat": "37.59091",
    "lng": "-4.08237"
  },
  {
    "country": "ES",
    "name": "Alcaucín",
    "lat": "36.90301",
    "lng": "-4.11406"
  },
  {
    "country": "ES",
    "name": "Alcaraz",
    "lat": "38.6668",
    "lng": "-2.49105"
  },
  {
    "country": "ES",
    "name": "Alcaracejos",
    "lat": "38.38333",
    "lng": "-4.96667"
  },
  {
    "country": "ES",
    "name": "Alcantarilla",
    "lat": "37.96939",
    "lng": "-1.21714"
  },
  {
    "country": "ES",
    "name": "Alcàntera de Xúquer",
    "lat": "39.06667",
    "lng": "-0.55"
  },
  {
    "country": "ES",
    "name": "Alcántara",
    "lat": "39.71895",
    "lng": "-6.88375"
  },
  {
    "country": "ES",
    "name": "Alcañizo",
    "lat": "39.90315",
    "lng": "-5.10588"
  },
  {
    "country": "ES",
    "name": "Alcalalí",
    "lat": "38.75038",
    "lng": "-0.04013"
  },
  {
    "country": "ES",
    "name": "Alcalá la Real",
    "lat": "37.4614",
    "lng": "-3.92301"
  },
  {
    "country": "ES",
    "name": "Alcalá del Valle",
    "lat": "36.90448",
    "lng": "-5.1724"
  },
  {
    "country": "ES",
    "name": "Alcalá de los Gazules",
    "lat": "36.46212",
    "lng": "-5.72382"
  },
  {
    "country": "ES",
    "name": "Alcalá del Júcar",
    "lat": "39.19313",
    "lng": "-1.43017"
  },
  {
    "country": "ES",
    "name": "Alcalá de Guadaira",
    "lat": "37.33791",
    "lng": "-5.83951"
  },
  {
    "country": "ES",
    "name": "Alcadozo",
    "lat": "38.64916",
    "lng": "-1.97998"
  },
  {
    "country": "ES",
    "name": "Alcàsser",
    "lat": "39.36791",
    "lng": "-0.44447"
  },
  {
    "country": "ES",
    "name": "Alcabón",
    "lat": "40.00224",
    "lng": "-4.36852"
  },
  {
    "country": "ES",
    "name": "Alburquerque",
    "lat": "39.22076",
    "lng": "-7.00234"
  },
  {
    "country": "ES",
    "name": "Albuñuelas",
    "lat": "36.92828",
    "lng": "-3.63184"
  },
  {
    "country": "ES",
    "name": "Albuñol",
    "lat": "36.79203",
    "lng": "-3.205"
  },
  {
    "country": "ES",
    "name": "Albuñán",
    "lat": "37.22708",
    "lng": "-3.13321"
  },
  {
    "country": "ES",
    "name": "Albuixech",
    "lat": "39.55",
    "lng": "-0.31667"
  },
  {
    "country": "ES",
    "name": "Albudeite",
    "lat": "38.02895",
    "lng": "-1.38664"
  },
  {
    "country": "ES",
    "name": "Albox",
    "lat": "37.38856",
    "lng": "-2.14949"
  },
  {
    "country": "ES",
    "name": "Alborea",
    "lat": "39.28333",
    "lng": "-1.38333"
  },
  {
    "country": "ES",
    "name": "Alboraya",
    "lat": "39.5",
    "lng": "-0.35"
  },
  {
    "country": "ES",
    "name": "Alborache",
    "lat": "39.38333",
    "lng": "-0.76667"
  },
  {
    "country": "ES",
    "name": "Albondón",
    "lat": "36.8277",
    "lng": "-3.21144"
  },
  {
    "country": "ES",
    "name": "Albolote",
    "lat": "37.23088",
    "lng": "-3.6551"
  },
  {
    "country": "ES",
    "name": "Alberic",
    "lat": "39.11667",
    "lng": "-0.51667"
  },
  {
    "country": "ES",
    "name": "Albatera",
    "lat": "38.17902",
    "lng": "-0.87059"
  },
  {
    "country": "ES",
    "name": "Albatana",
    "lat": "38.57057",
    "lng": "-1.5221"
  },
  {
    "country": "ES",
    "name": "Albarreal de Tajo",
    "lat": "39.89698",
    "lng": "-4.22895"
  },
  {
    "country": "ES",
    "name": "Albánchez",
    "lat": "37.28361",
    "lng": "-2.18229"
  },
  {
    "country": "ES",
    "name": "Albalat dels Tarongers",
    "lat": "39.7",
    "lng": "-0.33333"
  },
  {
    "country": "ES",
    "name": "Albalat dels Sorells",
    "lat": "39.53333",
    "lng": "-0.35"
  },
  {
    "country": "ES",
    "name": "Albalat de la Ribera",
    "lat": "39.2",
    "lng": "-0.38333"
  },
  {
    "country": "ES",
    "name": "Albaladejo del Cuende",
    "lat": "39.80684",
    "lng": "-2.22903"
  },
  {
    "country": "ES",
    "name": "Albaladejo",
    "lat": "38.61887",
    "lng": "-2.80784"
  },
  {
    "country": "ES",
    "name": "Albalá",
    "lat": "39.25592",
    "lng": "-6.18528"
  },
  {
    "country": "ES",
    "name": "Albal",
    "lat": "39.4",
    "lng": "-0.41667"
  },
  {
    "country": "ES",
    "name": "Albaida del Aljarafe",
    "lat": "37.42354",
    "lng": "-6.16675"
  },
  {
    "country": "ES",
    "name": "Albaida",
    "lat": "38.83798",
    "lng": "-0.51721"
  },
  {
    "country": "ES",
    "name": "Albacete",
    "lat": "38.99424",
    "lng": "-1.85643"
  },
  {
    "country": "ES",
    "name": "Alaior",
    "lat": "39.93034",
    "lng": "4.14039"
  },
  {
    "country": "ES",
    "name": "Alatoz",
    "lat": "39.09495",
    "lng": "-1.36098"
  },
  {
    "country": "ES",
    "name": "Alaró",
    "lat": "39.70441",
    "lng": "2.79181"
  },
  {
    "country": "ES",
    "name": "Alarcón",
    "lat": "39.55",
    "lng": "-2.08333"
  },
  {
    "country": "ES",
    "name": "Alanís",
    "lat": "38.03333",
    "lng": "-5.71667"
  },
  {
    "country": "ES",
    "name": "Alange",
    "lat": "38.78495",
    "lng": "-6.24574"
  },
  {
    "country": "ES",
    "name": "Alamillo",
    "lat": "38.67842",
    "lng": "-4.79008"
  },
  {
    "country": "ES",
    "name": "Alamedilla",
    "lat": "37.58232",
    "lng": "-3.24241"
  },
  {
    "country": "ES",
    "name": "Alameda",
    "lat": "37.2087",
    "lng": "-4.6586"
  },
  {
    "country": "ES",
    "name": "Alajeró",
    "lat": "28.06205",
    "lng": "-17.24073"
  },
  {
    "country": "ES",
    "name": "Alájar",
    "lat": "37.87408",
    "lng": "-6.66536"
  },
  {
    "country": "ES",
    "name": "Alaquàs",
    "lat": "39.45568",
    "lng": "-0.461"
  },
  {
    "country": "ES",
    "name": "Ajofrín",
    "lat": "39.71088",
    "lng": "-3.9822"
  },
  {
    "country": "ES",
    "name": "Ahillones",
    "lat": "38.26667",
    "lng": "-5.85"
  },
  {
    "country": "ES",
    "name": "Agulo",
    "lat": "28.18778",
    "lng": "-17.19678"
  },
  {
    "country": "ES",
    "name": "Agullent",
    "lat": "38.82273",
    "lng": "-0.54833"
  },
  {
    "country": "ES",
    "name": "Agüimes",
    "lat": "27.90539",
    "lng": "-15.44609"
  },
  {
    "country": "ES",
    "name": "Águilas",
    "lat": "37.4063",
    "lng": "-1.58289"
  },
  {
    "country": "ES",
    "name": "Aguilar",
    "lat": "37.51476",
    "lng": "-4.65717"
  },
  {
    "country": "ES",
    "name": "Agudo",
    "lat": "38.98183",
    "lng": "-4.87133"
  },
  {
    "country": "ES",
    "name": "Aigües",
    "lat": "38.5",
    "lng": "-0.35"
  },
  {
    "country": "ES",
    "name": "Aguadulce",
    "lat": "37.25273",
    "lng": "-4.99269"
  },
  {
    "country": "ES",
    "name": "Aguadulce",
    "lat": "36.81409",
    "lng": "-2.57235"
  },
  {
    "country": "ES",
    "name": "Agrón",
    "lat": "37.03023",
    "lng": "-3.8287"
  },
  {
    "country": "ES",
    "name": "Agres",
    "lat": "38.78333",
    "lng": "-0.51667"
  },
  {
    "country": "ES",
    "name": "Agost",
    "lat": "38.44003",
    "lng": "-0.63836"
  },
  {
    "country": "ES",
    "name": "Agaete",
    "lat": "28.10023",
    "lng": "-15.69998"
  },
  {
    "country": "ES",
    "name": "Atzeneta d'Albaida",
    "lat": "38.83333",
    "lng": "-0.5"
  },
  {
    "country": "ES",
    "name": "Adsubia",
    "lat": "38.84819",
    "lng": "-0.15324"
  },
  {
    "country": "ES",
    "name": "Adra",
    "lat": "36.74961",
    "lng": "-3.02055"
  },
  {
    "country": "ES",
    "name": "Ador",
    "lat": "38.91823",
    "lng": "-0.22247"
  },
  {
    "country": "ES",
    "name": "Adeje",
    "lat": "28.12271",
    "lng": "-16.726"
  },
  {
    "country": "ES",
    "name": "Adamuz",
    "lat": "38.02674",
    "lng": "-4.52231"
  },
  {
    "country": "ES",
    "name": "Aceuchal",
    "lat": "38.64627",
    "lng": "-6.48636"
  },
  {
    "country": "ES",
    "name": "Acedera",
    "lat": "39.07678",
    "lng": "-5.57384"
  },
  {
    "country": "ES",
    "name": "Alcalá del Río",
    "lat": "37.5178",
    "lng": "-5.98185"
  },
  {
    "country": "ES",
    "name": "Abrucena",
    "lat": "37.13226",
    "lng": "-2.79711"
  },
  {
    "country": "ES",
    "name": "Abla",
    "lat": "37.14245",
    "lng": "-2.77808"
  },
  {
    "country": "ES",
    "name": "Abertura",
    "lat": "39.24352",
    "lng": "-5.81394"
  },
  {
    "country": "ES",
    "name": "Abenójar",
    "lat": "38.88032",
    "lng": "-4.35702"
  },
  {
    "country": "ES",
    "name": "Abengibre",
    "lat": "39.21667",
    "lng": "-1.53333"
  },
  {
    "country": "ES",
    "name": "Abarán",
    "lat": "38.20551",
    "lng": "-1.39907"
  },
  {
    "country": "ES",
    "name": "Abanilla",
    "lat": "38.20537",
    "lng": "-1.04153"
  },
  {
    "country": "ES",
    "name": "Punta Umbría",
    "lat": "37.18213",
    "lng": "-6.96605"
  },
  {
    "country": "ES",
    "name": "Grao de Murviedro",
    "lat": "39.64167",
    "lng": "-0.23889"
  },
  {
    "country": "ES",
    "name": "Zúñiga",
    "lat": "42.69247",
    "lng": "-2.29982"
  },
  {
    "country": "ES",
    "name": "Zuñeda",
    "lat": "42.60501",
    "lng": "-3.22632"
  },
  {
    "country": "ES",
    "name": "Zumaia",
    "lat": "43.29469",
    "lng": "-2.25341"
  },
  {
    "country": "ES",
    "name": "Zumarraga",
    "lat": "43.08858",
    "lng": "-2.31408"
  },
  {
    "country": "ES",
    "name": "Zugarramurdi",
    "lat": "43.26964",
    "lng": "-1.54113"
  },
  {
    "country": "ES",
    "name": "Zuera",
    "lat": "41.86775",
    "lng": "-0.78984"
  },
  {
    "country": "ES",
    "name": "Zucaina",
    "lat": "40.11667",
    "lng": "-0.41667"
  },
  {
    "country": "ES",
    "name": "Zubieta",
    "lat": "43.12473",
    "lng": "-1.74219"
  },
  {
    "country": "ES",
    "name": "Zotes del Páramo",
    "lat": "42.27268",
    "lng": "-5.73617"
  },
  {
    "country": "ES",
    "name": "Zorraquín",
    "lat": "42.32565",
    "lng": "-3.03925"
  },
  {
    "country": "ES",
    "name": "Zorita de los Canes",
    "lat": "40.33052",
    "lng": "-2.88764"
  },
  {
    "country": "ES",
    "name": "Zorita del Maestrazgo",
    "lat": "40.72817",
    "lng": "-0.16667"
  },
  {
    "country": "ES",
    "name": "Zorita de la Frontera",
    "lat": "41.01453",
    "lng": "-5.19659"
  },
  {
    "country": "ES",
    "name": "Zazuar",
    "lat": "41.69528",
    "lng": "-3.55451"
  },
  {
    "country": "ES",
    "name": "Zas",
    "lat": "43.09885",
    "lng": "-8.91558"
  },
  {
    "country": "ES",
    "name": "Zarzuela del Pinar",
    "lat": "41.26018",
    "lng": "-4.18457"
  },
  {
    "country": "ES",
    "name": "Zarzuela del Monte",
    "lat": "40.80888",
    "lng": "-4.33613"
  },
  {
    "country": "ES",
    "name": "Zarzuela de Jadraque",
    "lat": "41.06838",
    "lng": "-3.04436"
  },
  {
    "country": "ES",
    "name": "Zarzuela",
    "lat": "40.25902",
    "lng": "-2.11034"
  },
  {
    "country": "ES",
    "name": "Zarzosa",
    "lat": "42.18294",
    "lng": "-2.34297"
  },
  {
    "country": "ES",
    "name": "Zarzalejo",
    "lat": "40.54811",
    "lng": "-4.18176"
  },
  {
    "country": "ES",
    "name": "Zarza de Tajo",
    "lat": "40.01591",
    "lng": "-3.12877"
  },
  {
    "country": "ES",
    "name": "Zarza de Granadilla",
    "lat": "40.23723",
    "lng": "-6.0485"
  },
  {
    "country": "ES",
    "name": "Zarratón",
    "lat": "42.51649",
    "lng": "-2.88094"
  },
  {
    "country": "ES",
    "name": "Zarautz",
    "lat": "43.28444",
    "lng": "-2.16992"
  },
  {
    "country": "ES",
    "name": "Zaratán",
    "lat": "41.65971",
    "lng": "-4.78417"
  },
  {
    "country": "ES",
    "name": "Zaratamo",
    "lat": "43.21667",
    "lng": "-2.86667"
  },
  {
    "country": "ES",
    "name": "Zarapicos",
    "lat": "41.0383",
    "lng": "-5.84526"
  },
  {
    "country": "ES",
    "name": "Zaragoza",
    "lat": "41.65606",
    "lng": "-0.87734"
  },
  {
    "country": "ES",
    "name": "Zapardiel de la Ribera",
    "lat": "40.35554",
    "lng": "-5.32826"
  },
  {
    "country": "ES",
    "name": "Zapardiel de la Cañada",
    "lat": "40.60648",
    "lng": "-5.33791"
  },
  {
    "country": "ES",
    "name": "Zaorejas",
    "lat": "40.76209",
    "lng": "-2.2012"
  },
  {
    "country": "ES",
    "name": "Zamudio",
    "lat": "43.286",
    "lng": "-2.87"
  },
  {
    "country": "ES",
    "name": "Zamora",
    "lat": "41.50633",
    "lng": "-5.74456"
  },
  {
    "country": "ES",
    "name": "Zambrana",
    "lat": "42.66102",
    "lng": "-2.87909"
  },
  {
    "country": "ES",
    "name": "Zamayón",
    "lat": "41.14861",
    "lng": "-5.83054"
  },
  {
    "country": "ES",
    "name": "Zamarra",
    "lat": "40.51893",
    "lng": "-6.45248"
  },
  {
    "country": "ES",
    "name": "Zaldibia",
    "lat": "43.0372",
    "lng": "-2.1506"
  },
  {
    "country": "ES",
    "name": "Zaldibar",
    "lat": "43.16667",
    "lng": "-2.53333"
  },
  {
    "country": "ES",
    "name": "Zaidín",
    "lat": "41.60402",
    "lng": "0.26429"
  },
  {
    "country": "ES",
    "name": "Zafrilla",
    "lat": "40.2",
    "lng": "-1.61667"
  },
  {
    "country": "ES",
    "name": "Zael",
    "lat": "42.10587",
    "lng": "-3.82623"
  },
  {
    "country": "ES",
    "name": "Iurreta",
    "lat": "43.18333",
    "lng": "-2.63333"
  },
  {
    "country": "ES",
    "name": "Yunquera de Henares",
    "lat": "40.75139",
    "lng": "-3.1626"
  },
  {
    "country": "ES",
    "name": "Yuncos",
    "lat": "40.0859",
    "lng": "-3.87106"
  },
  {
    "country": "ES",
    "name": "Yuncler",
    "lat": "40.04079",
    "lng": "-3.89979"
  },
  {
    "country": "ES",
    "name": "Yésero",
    "lat": "42.61911",
    "lng": "-0.2502"
  },
  {
    "country": "ES",
    "name": "Yesa",
    "lat": "42.62025",
    "lng": "-1.2036"
  },
  {
    "country": "ES",
    "name": "Yelo",
    "lat": "41.21667",
    "lng": "-2.51667"
  },
  {
    "country": "ES",
    "name": "Yeles",
    "lat": "40.12035",
    "lng": "-3.80487"
  },
  {
    "country": "ES",
    "name": "Yélamos de Arriba",
    "lat": "40.64008",
    "lng": "-2.8434"
  },
  {
    "country": "ES",
    "name": "Yélamos de Abajo",
    "lat": "40.63092",
    "lng": "-2.85803"
  },
  {
    "country": "ES",
    "name": "Yecla de Yeltes",
    "lat": "40.95917",
    "lng": "-6.48904"
  },
  {
    "country": "ES",
    "name": "Yebra de Basa",
    "lat": "42.48647",
    "lng": "-0.28178"
  },
  {
    "country": "ES",
    "name": "Yebra",
    "lat": "40.35702",
    "lng": "-2.9663"
  },
  {
    "country": "ES",
    "name": "Yebes",
    "lat": "40.53162",
    "lng": "-3.10782"
  },
  {
    "country": "ES",
    "name": "Yanguas de Eresma",
    "lat": "41.07201",
    "lng": "-4.23905"
  },
  {
    "country": "ES",
    "name": "Yanguas",
    "lat": "42.10171",
    "lng": "-2.33986"
  },
  {
    "country": "ES",
    "name": "Igantzi",
    "lat": "43.22526",
    "lng": "-1.70048"
  },
  {
    "country": "ES",
    "name": "Wamba",
    "lat": "41.67525",
    "lng": "-4.91748"
  },
  {
    "country": "ES",
    "name": "Vozmediano",
    "lat": "41.83752",
    "lng": "-1.8558"
  },
  {
    "country": "ES",
    "name": "Vizmanos",
    "lat": "42.02342",
    "lng": "-2.40869"
  },
  {
    "country": "ES",
    "name": "Vizcaínos",
    "lat": "42.10359",
    "lng": "-3.26698"
  },
  {
    "country": "ES",
    "name": "Viveiro",
    "lat": "43.66228",
    "lng": "-7.59344"
  },
  {
    "country": "ES",
    "name": "Vivel del Río Martín",
    "lat": "40.87091",
    "lng": "-0.93889"
  },
  {
    "country": "ES",
    "name": "Biure",
    "lat": "42.33734",
    "lng": "2.89513"
  },
  {
    "country": "ES",
    "name": "Gasteiz / Vitoria",
    "lat": "42.84998",
    "lng": "-2.67268"
  },
  {
    "country": "ES",
    "name": "Vitigudino",
    "lat": "41.00912",
    "lng": "-6.43404"
  },
  {
    "country": "ES",
    "name": "Vita",
    "lat": "40.81178",
    "lng": "-5.00583"
  },
  {
    "country": "ES",
    "name": "Vistabella del Maestrazgo",
    "lat": "40.29617",
    "lng": "-0.29435"
  },
  {
    "country": "ES",
    "name": "Vistabella",
    "lat": "41.2185",
    "lng": "-1.15358"
  },
  {
    "country": "ES",
    "name": "Visiedo",
    "lat": "40.68558",
    "lng": "-1.09709"
  },
  {
    "country": "ES",
    "name": "Vinuesa",
    "lat": "41.91032",
    "lng": "-2.76483"
  },
  {
    "country": "ES",
    "name": "Viñuelas",
    "lat": "40.79229",
    "lng": "-3.34036"
  },
  {
    "country": "ES",
    "name": "Viniegra de Arriba",
    "lat": "42.09513",
    "lng": "-2.83304"
  },
  {
    "country": "ES",
    "name": "Viniegra de Abajo",
    "lat": "42.15055",
    "lng": "-2.8893"
  },
  {
    "country": "ES",
    "name": "Viñegra de Moraña",
    "lat": "40.85074",
    "lng": "-4.92115"
  },
  {
    "country": "ES",
    "name": "Vinebre",
    "lat": "41.18464",
    "lng": "0.58945"
  },
  {
    "country": "ES",
    "name": "Vindel",
    "lat": "40.58743",
    "lng": "-2.3806"
  },
  {
    "country": "ES",
    "name": "Viñas",
    "lat": "41.7733",
    "lng": "-6.47117"
  },
  {
    "country": "ES",
    "name": "Vinaròs",
    "lat": "40.47033",
    "lng": "0.47559"
  },
  {
    "country": "ES",
    "name": "Vinaixa",
    "lat": "41.43333",
    "lng": "0.98333"
  },
  {
    "country": "ES",
    "name": "Vimianzo",
    "lat": "43.10988",
    "lng": "-9.03351"
  },
  {
    "country": "ES",
    "name": "Vimbodí",
    "lat": "41.40069",
    "lng": "1.05056"
  },
  {
    "country": "ES",
    "name": "Vilviestre del Pinar",
    "lat": "41.95033",
    "lng": "-3.07803"
  },
  {
    "country": "ES",
    "name": "Vilvestre",
    "lat": "41.10636",
    "lng": "-6.72725"
  },
  {
    "country": "ES",
    "name": "Vilobí d'Onyar",
    "lat": "41.88333",
    "lng": "2.75"
  },
  {
    "country": "ES",
    "name": "Vilobí del Penedès",
    "lat": "41.38333",
    "lng": "1.65"
  },
  {
    "country": "ES",
    "name": "Viloria de Rioja",
    "lat": "42.42608",
    "lng": "-3.10056"
  },
  {
    "country": "ES",
    "name": "Viloria",
    "lat": "41.44604",
    "lng": "-4.38356"
  },
  {
    "country": "ES",
    "name": "Vilopriu",
    "lat": "42.1",
    "lng": "3"
  },
  {
    "country": "ES",
    "name": "Villovieco",
    "lat": "42.29478",
    "lng": "-4.48122"
  },
  {
    "country": "ES",
    "name": "Villota del Páramo",
    "lat": "42.55234",
    "lng": "-4.84893"
  },
  {
    "country": "ES",
    "name": "Villoslada de Cameros",
    "lat": "42.11383",
    "lng": "-2.67413"
  },
  {
    "country": "ES",
    "name": "Villoruela",
    "lat": "41.0086",
    "lng": "-5.39381"
  },
  {
    "country": "ES",
    "name": "Villoruebo",
    "lat": "42.16874",
    "lng": "-3.44159"
  },
  {
    "country": "ES",
    "name": "Villoría",
    "lat": "40.99435",
    "lng": "-5.37363"
  },
  {
    "country": "ES",
    "name": "Villores",
    "lat": "40.67478",
    "lng": "-0.20023"
  },
  {
    "country": "ES",
    "name": "Villoldo",
    "lat": "42.28333",
    "lng": "-4.6"
  },
  {
    "country": "ES",
    "name": "Villodrigo",
    "lat": "42.14436",
    "lng": "-4.09527"
  },
  {
    "country": "ES",
    "name": "Villodre",
    "lat": "42.21161",
    "lng": "-4.24484"
  },
  {
    "country": "ES",
    "name": "Villel de Mesa",
    "lat": "41.12616",
    "lng": "-1.99072"
  },
  {
    "country": "ES",
    "name": "Villel",
    "lat": "40.23463",
    "lng": "-1.18611"
  },
  {
    "country": "ES",
    "name": "Villeguillo",
    "lat": "41.2529",
    "lng": "-4.57951"
  },
  {
    "country": "ES",
    "name": "Villegas",
    "lat": "42.46866",
    "lng": "-4.01759"
  },
  {
    "country": "ES",
    "name": "Villazopeque",
    "lat": "42.19845",
    "lng": "-4.01688"
  },
  {
    "country": "ES",
    "name": "Villazanzo de Valderaduey",
    "lat": "42.53592",
    "lng": "-4.96462"
  },
  {
    "country": "ES",
    "name": "Villazala",
    "lat": "42.36146",
    "lng": "-5.856"
  },
  {
    "country": "ES",
    "name": "Vilaión",
    "lat": "43.44859",
    "lng": "-6.70534"
  },
  {
    "country": "ES",
    "name": "Villaviudas",
    "lat": "41.96227",
    "lng": "-4.342"
  },
  {
    "country": "ES",
    "name": "Villavieja de Yeltes",
    "lat": "40.87573",
    "lng": "-6.46792"
  },
  {
    "country": "ES",
    "name": "Villavieja del Lozoya",
    "lat": "41.00396",
    "lng": "-3.6687"
  },
  {
    "country": "ES",
    "name": "Villaviciosa de Odón",
    "lat": "40.35692",
    "lng": "-3.90011"
  },
  {
    "country": "ES",
    "name": "Villaviciosa",
    "lat": "43.48126",
    "lng": "-5.43574"
  },
  {
    "country": "ES",
    "name": "Villavicencio de los Caballeros",
    "lat": "42.05893",
    "lng": "-5.23566"
  },
  {
    "country": "ES",
    "name": "Villaveza de Valverde",
    "lat": "41.94516",
    "lng": "-5.84849"
  },
  {
    "country": "ES",
    "name": "Villaveza del Agua",
    "lat": "41.91922",
    "lng": "-5.67871"
  },
  {
    "country": "ES",
    "name": "Villaverde-Mogina",
    "lat": "42.16041",
    "lng": "-4.05024"
  },
  {
    "country": "ES",
    "name": "Villaverde de Rioja",
    "lat": "42.32051",
    "lng": "-2.8137"
  },
  {
    "country": "ES",
    "name": "Villaverde de Montejo",
    "lat": "41.52225",
    "lng": "-3.65452"
  },
  {
    "country": "ES",
    "name": "Villaverde de Medina",
    "lat": "41.30687",
    "lng": "-5.02625"
  },
  {
    "country": "ES",
    "name": "Villaverde del Monte",
    "lat": "42.16075",
    "lng": "-3.81421"
  },
  {
    "country": "ES",
    "name": "Villaverde de Guareña",
    "lat": "41.06406",
    "lng": "-5.52492"
  },
  {
    "country": "ES",
    "name": "Villaverde",
    "lat": "40.35",
    "lng": "-3.7"
  },
  {
    "country": "ES",
    "name": "Villavendimio",
    "lat": "41.57812",
    "lng": "-5.34287"
  },
  {
    "country": "ES",
    "name": "Villavellid",
    "lat": "41.69218",
    "lng": "-5.2763"
  },
  {
    "country": "ES",
    "name": "Villavelayo",
    "lat": "42.13084",
    "lng": "-2.98565"
  },
  {
    "country": "ES",
    "name": "Villavaquerín",
    "lat": "41.66357",
    "lng": "-4.46287"
  },
  {
    "country": "ES",
    "name": "Villaumbrales",
    "lat": "42.08873",
    "lng": "-4.61384"
  },
  {
    "country": "ES",
    "name": "Villaturiel",
    "lat": "42.51819",
    "lng": "-5.48615"
  },
  {
    "country": "ES",
    "name": "Villaturde",
    "lat": "42.37769",
    "lng": "-4.67085"
  },
  {
    "country": "ES",
    "name": "Villatuerta",
    "lat": "42.66022",
    "lng": "-1.99247"
  },
  {
    "country": "ES",
    "name": "Villatuelda",
    "lat": "41.81499",
    "lng": "-3.88054"
  },
  {
    "country": "ES",
    "name": "Villatoro",
    "lat": "40.55609",
    "lng": "-5.11262"
  },
  {
    "country": "ES",
    "name": "Villastar",
    "lat": "40.28102",
    "lng": "-1.15139"
  },
  {
    "country": "ES",
    "name": "Villasrubias",
    "lat": "40.33822",
    "lng": "-6.6392"
  },
  {
    "country": "ES",
    "name": "Villasila de Valdavia",
    "lat": "42.53192",
    "lng": "-4.55884"
  },
  {
    "country": "ES",
    "name": "Villasexmir",
    "lat": "41.63943",
    "lng": "-5.0647"
  },
  {
    "country": "ES",
    "name": "Villaselán",
    "lat": "42.56105",
    "lng": "-5.0482"
  },
  {
    "country": "ES",
    "name": "Villaseco de los Reyes",
    "lat": "41.16262",
    "lng": "-6.18426"
  },
  {
    "country": "ES",
    "name": "Villaseco de los Gamitos",
    "lat": "41.03621",
    "lng": "-6.11323"
  },
  {
    "country": "ES",
    "name": "Villaseca de Uceda",
    "lat": "40.81827",
    "lng": "-3.34904"
  },
  {
    "country": "ES",
    "name": "Villaseca de Henares",
    "lat": "40.9606",
    "lng": "-2.79775"
  },
  {
    "country": "ES",
    "name": "Villaseca de Arciel",
    "lat": "41.6243",
    "lng": "-2.16176"
  },
  {
    "country": "ES",
    "name": "Villasdardo",
    "lat": "41.00449",
    "lng": "-6.16303"
  },
  {
    "country": "ES",
    "name": "Villasbuenas de Gata",
    "lat": "40.17879",
    "lng": "-6.62641"
  },
  {
    "country": "ES",
    "name": "Villasbuenas",
    "lat": "41.06263",
    "lng": "-6.59662"
  },
  {
    "country": "ES",
    "name": "Villasayas",
    "lat": "41.35291",
    "lng": "-2.61011"
  },
  {
    "country": "ES",
    "name": "Villasarracino",
    "lat": "42.41207",
    "lng": "-4.49633"
  },
  {
    "country": "ES",
    "name": "Villasandino",
    "lat": "42.37072",
    "lng": "-4.10975"
  },
  {
    "country": "ES",
    "name": "Villasana de Mena",
    "lat": "43.10017",
    "lng": "-3.28253"
  },
  {
    "country": "ES",
    "name": "Villasabariego",
    "lat": "42.53288",
    "lng": "-5.41322"
  },
  {
    "country": "ES",
    "name": "Villarta-Quintana",
    "lat": "42.42998",
    "lng": "-3.0484"
  },
  {
    "country": "ES",
    "name": "Villarroya de los Pinares",
    "lat": "40.52917",
    "lng": "-0.669"
  },
  {
    "country": "ES",
    "name": "Villarroya del Campo",
    "lat": "41.14309",
    "lng": "-1.32416"
  },
  {
    "country": "ES",
    "name": "Villarroya de la Sierra",
    "lat": "41.46346",
    "lng": "-1.7835"
  },
  {
    "country": "ES",
    "name": "Villarroya",
    "lat": "42.13053",
    "lng": "-2.06896"
  },
  {
    "country": "ES",
    "name": "Villarrín de Campos",
    "lat": "41.79522",
    "lng": "-5.63898"
  },
  {
    "country": "ES",
    "name": "Urretxu",
    "lat": "43.091",
    "lng": "-2.31701"
  },
  {
    "country": "ES",
    "name": "Villarreal de Huerva",
    "lat": "41.19034",
    "lng": "-1.28983"
  },
  {
    "country": "ES",
    "name": "Villarramiel",
    "lat": "42.04301",
    "lng": "-4.91215"
  },
  {
    "country": "ES",
    "name": "Villarrabé",
    "lat": "42.4209",
    "lng": "-4.78445"
  },
  {
    "country": "ES",
    "name": "Villarquemado",
    "lat": "40.5175",
    "lng": "-1.265"
  },
  {
    "country": "ES",
    "name": "Areatza",
    "lat": "43.11667",
    "lng": "-2.76667"
  },
  {
    "country": "ES",
    "name": "Villarmuerto",
    "lat": "41.0562",
    "lng": "-6.36294"
  },
  {
    "country": "ES",
    "name": "Villarmentero de Esgueva",
    "lat": "41.68515",
    "lng": "-4.54636"
  },
  {
    "country": "ES",
    "name": "Villarmentero de Campos",
    "lat": "42.29777",
    "lng": "-4.49992"
  },
  {
    "country": "ES",
    "name": "Villarmayor",
    "lat": "41.01514",
    "lng": "-5.97151"
  },
  {
    "country": "ES",
    "name": "Villarluengo",
    "lat": "40.64842",
    "lng": "-0.53066"
  },
  {
    "country": "ES",
    "name": "Villarino de los Aires",
    "lat": "41.27102",
    "lng": "-6.46847"
  },
  {
    "country": "ES",
    "name": "Vilariño de Conso",
    "lat": "42.16667",
    "lng": "-7.18333"
  },
  {
    "country": "ES",
    "name": "Villariezo",
    "lat": "42.26965",
    "lng": "-3.73272"
  },
  {
    "country": "ES",
    "name": "Villares de Yeltes",
    "lat": "40.86594",
    "lng": "-6.413"
  },
  {
    "country": "ES",
    "name": "Villares de Órbigo",
    "lat": "42.46955",
    "lng": "-5.91002"
  },
  {
    "country": "ES",
    "name": "Villares de la Reina",
    "lat": "41.00832",
    "lng": "-5.64881"
  },
  {
    "country": "ES",
    "name": "Villares de Jadraque",
    "lat": "41.10169",
    "lng": "-3.02558"
  },
  {
    "country": "ES",
    "name": "Villarejo de Salvanés",
    "lat": "40.16663",
    "lng": "-3.27277"
  },
  {
    "country": "ES",
    "name": "Villarejo de Órbigo",
    "lat": "42.44559",
    "lng": "-5.90462"
  },
  {
    "country": "ES",
    "name": "Villarejo del Valle",
    "lat": "40.28638",
    "lng": "-4.99674"
  },
  {
    "country": "ES",
    "name": "Villarejo de la Peñuela",
    "lat": "40.08745",
    "lng": "-2.40996"
  },
  {
    "country": "ES",
    "name": "Villarejo",
    "lat": "42.37417",
    "lng": "-2.88712"
  },
  {
    "country": "ES",
    "name": "Villardondiego",
    "lat": "41.58483",
    "lng": "-5.37707"
  },
  {
    "country": "ES",
    "name": "Villárdiga",
    "lat": "41.8195",
    "lng": "-5.46439"
  },
  {
    "country": "ES",
    "name": "Villardiegua de la Ribera",
    "lat": "41.53543",
    "lng": "-6.18327"
  },
  {
    "country": "ES",
    "name": "Villar de Torre",
    "lat": "42.37133",
    "lng": "-2.86411"
  },
  {
    "country": "ES",
    "name": "Villar de Samaniego",
    "lat": "41.11667",
    "lng": "-6.43333"
  },
  {
    "country": "ES",
    "name": "Villar de Plasencia",
    "lat": "40.13773",
    "lng": "-6.0279"
  },
  {
    "country": "ES",
    "name": "Villar de Peralonso",
    "lat": "41.03223",
    "lng": "-6.22284"
  },
  {
    "country": "ES",
    "name": "Villar de Olalla",
    "lat": "40.01496",
    "lng": "-2.19561"
  },
  {
    "country": "ES",
    "name": "Villar del Salz",
    "lat": "40.682",
    "lng": "-1.49967"
  },
  {
    "country": "ES",
    "name": "Villar del Río",
    "lat": "42.07574",
    "lng": "-2.35082"
  },
  {
    "country": "ES",
    "name": "Villar de los Navarros",
    "lat": "41.15949",
    "lng": "-1.04199"
  },
  {
    "country": "ES",
    "name": "Villar del Olmo",
    "lat": "40.33468",
    "lng": "-3.23399"
  },
  {
    "country": "ES",
    "name": "Villar del Infantado",
    "lat": "40.45514",
    "lng": "-2.47905"
  },
  {
    "country": "ES",
    "name": "Villar del Cobo",
    "lat": "40.39475",
    "lng": "-1.67332"
  },
  {
    "country": "ES",
    "name": "Villar del Campo",
    "lat": "41.78881",
    "lng": "-2.14955"
  },
  {
    "country": "ES",
    "name": "Villar del Buey",
    "lat": "41.33024",
    "lng": "-6.18935"
  },
  {
    "country": "ES",
    "name": "Villar de la Yegua",
    "lat": "40.72554",
    "lng": "-6.70364"
  },
  {
    "country": "ES",
    "name": "Villar del Ala",
    "lat": "41.91638",
    "lng": "-2.56651"
  },
  {
    "country": "ES",
    "name": "Villar de Gallimazo",
    "lat": "40.95367",
    "lng": "-5.28819"
  },
  {
    "country": "ES",
    "name": "Villardefrades",
    "lat": "41.72358",
    "lng": "-5.25513"
  },
  {
    "country": "ES",
    "name": "Villar de Fallaves",
    "lat": "41.92503",
    "lng": "-5.34039"
  },
  {
    "country": "ES",
    "name": "Villar de Domingo García",
    "lat": "40.23732",
    "lng": "-2.29136"
  },
  {
    "country": "ES",
    "name": "Villar de Corneja",
    "lat": "40.47462",
    "lng": "-5.43307"
  },
  {
    "country": "ES",
    "name": "Villardeciervos",
    "lat": "41.94206",
    "lng": "-6.28647"
  },
  {
    "country": "ES",
    "name": "Villar de Ciervo",
    "lat": "40.73772",
    "lng": "-6.7385"
  },
  {
    "country": "ES",
    "name": "Villaralbo",
    "lat": "41.49224",
    "lng": "-5.68359"
  },
  {
    "country": "ES",
    "name": "Villaquirán de los Infantes",
    "lat": "42.22744",
    "lng": "-4.00864"
  },
  {
    "country": "ES",
    "name": "Villaquirán de la Puebla",
    "lat": "42.28287",
    "lng": "-4.10037"
  },
  {
    "country": "ES",
    "name": "Villaquilambre",
    "lat": "42.64685",
    "lng": "-5.55835"
  },
  {
    "country": "ES",
    "name": "Villaquejida",
    "lat": "42.145",
    "lng": "-5.59699"
  },
  {
    "country": "ES",
    "name": "Villaprovedo",
    "lat": "42.51674",
    "lng": "-4.39645"
  },
  {
    "country": "ES",
    "name": "Villaobispo de Otero",
    "lat": "42.50065",
    "lng": "-6.05809"
  },
  {
    "country": "ES",
    "name": "Villanuño de Valdavia",
    "lat": "42.50775",
    "lng": "-4.51887"
  },
  {
    "country": "ES",
    "name": "Vilanova i la Geltrú",
    "lat": "41.22392",
    "lng": "1.72511"
  },
  {
    "country": "ES",
    "name": "Villanueva de Viver",
    "lat": "40.05",
    "lng": "-0.65"
  },
  {
    "country": "ES",
    "name": "Villanueva de Valdegovía",
    "lat": "42.84777",
    "lng": "-3.09883"
  },
  {
    "country": "ES",
    "name": "Villanueva de Teba",
    "lat": "42.6489",
    "lng": "-3.16313"
  },
  {
    "country": "ES",
    "name": "Villanueva de Sigena",
    "lat": "41.71576",
    "lng": "-0.00897"
  },
  {
    "country": "ES",
    "name": "Villanueva de San Mancio",
    "lat": "41.92842",
    "lng": "-5.012"
  },
  {
    "country": "ES",
    "name": "Villanueva de Perales",
    "lat": "40.34541",
    "lng": "-4.09891"
  },
  {
    "country": "ES",
    "name": "Villanueva de Oscos",
    "lat": "43.31144",
    "lng": "-6.98645"
  },
  {
    "country": "ES",
    "name": "Villanueva del Rebollar de la Sierra",
    "lat": "40.89108",
    "lng": "-1.00837"
  },
  {
    "country": "ES",
    "name": "Villanueva del Rebollar",
    "lat": "42.24114",
    "lng": "-4.74288"
  },
  {
    "country": "ES",
    "name": "Villanueva del Pardillo",
    "lat": "40.49014",
    "lng": "-3.96383"
  },
  {
    "country": "ES",
    "name": "Villanueva de los Caballeros",
    "lat": "41.75916",
    "lng": "-5.24786"
  },
  {
    "country": "ES",
    "name": "Villanueva del Conde",
    "lat": "40.51039",
    "lng": "-6.0121"
  },
  {
    "country": "ES",
    "name": "Villanueva del Campo",
    "lat": "41.98492",
    "lng": "-5.4066"
  },
  {
    "country": "ES",
    "name": "Villanueva del Campillo",
    "lat": "40.57646",
    "lng": "-5.18002"
  },
  {
    "country": "ES",
    "name": "Villanueva de la Vera",
    "lat": "40.12998",
    "lng": "-5.4625"
  },
  {
    "country": "ES",
    "name": "Villanueva de la Torre",
    "lat": "40.58216",
    "lng": "-3.29764"
  },
  {
    "country": "ES",
    "name": "Villanueva de las Peras",
    "lat": "41.93478",
    "lng": "-5.97942"
  },
  {
    "country": "ES",
    "name": "Villanueva de las Manzanas",
    "lat": "42.47264",
    "lng": "-5.48043"
  },
  {
    "country": "ES",
    "name": "Villanueva de la Sierra",
    "lat": "40.20163",
    "lng": "-6.40611"
  },
  {
    "country": "ES",
    "name": "Villanueva de la Condesa",
    "lat": "42.14914",
    "lng": "-5.0955"
  },
  {
    "country": "ES",
    "name": "Villanueva del Aceral",
    "lat": "41.04095",
    "lng": "-4.85419"
  },
  {
    "country": "ES",
    "name": "Villanueva de la Cañada",
    "lat": "40.44689",
    "lng": "-4.00428"
  },
  {
    "country": "ES",
    "name": "Villanueva de Jiloca",
    "lat": "41.07625",
    "lng": "-1.3896"
  },
  {
    "country": "ES",
    "name": "Villanueva de Gumiel",
    "lat": "41.73778",
    "lng": "-3.62658"
  },
  {
    "country": "ES",
    "name": "Villanueva de Gormaz",
    "lat": "41.4674",
    "lng": "-3.06223"
  },
  {
    "country": "ES",
    "name": "Villanueva de Gómez",
    "lat": "40.88269",
    "lng": "-4.7165"
  },
  {
    "country": "ES",
    "name": "Villanueva de Gállego",
    "lat": "41.76917",
    "lng": "-0.8235"
  },
  {
    "country": "ES",
    "name": "Villanueva de Duero",
    "lat": "41.51946",
    "lng": "-4.86671"
  },
  {
    "country": "ES",
    "name": "Villanueva de Carazo",
    "lat": "41.98275",
    "lng": "-3.32428"
  },
  {
    "country": "ES",
    "name": "Villanueva de Campeán",
    "lat": "41.35447",
    "lng": "-5.7702"
  },
  {
    "country": "ES",
    "name": "Villanueva de Cameros",
    "lat": "42.16719",
    "lng": "-2.6504"
  },
  {
    "country": "ES",
    "name": "Villanueva de Azoague",
    "lat": "41.97607",
    "lng": "-5.664"
  },
  {
    "country": "ES",
    "name": "Vilanova de Arousa",
    "lat": "42.56667",
    "lng": "-8.83333"
  },
  {
    "country": "ES",
    "name": "Villanueva de Argecilla",
    "lat": "40.90257",
    "lng": "-2.91431"
  },
  {
    "country": "ES",
    "name": "Villanueva de Argaño",
    "lat": "42.38045",
    "lng": "-3.93353"
  },
  {
    "country": "ES",
    "name": "Villanueva de Alcorón",
    "lat": "40.67956",
    "lng": "-2.25145"
  },
  {
    "country": "ES",
    "name": "Villanubla",
    "lat": "41.69877",
    "lng": "-4.84173"
  },
  {
    "country": "ES",
    "name": "Villanúa",
    "lat": "42.6797",
    "lng": "-0.53769"
  },
  {
    "country": "ES",
    "name": "Villangómez",
    "lat": "42.17961",
    "lng": "-3.77419"
  },
  {
    "country": "ES",
    "name": "Villán de Tordesillas",
    "lat": "41.59311",
    "lng": "-4.92214"
  },
  {
    "country": "ES",
    "name": "Villanázar",
    "lat": "41.97398",
    "lng": "-5.78043"
  },
  {
    "country": "ES",
    "name": "Villamuriel de Cerrato",
    "lat": "41.94935",
    "lng": "-4.51584"
  },
  {
    "country": "ES",
    "name": "Villamuriel de Campos",
    "lat": "41.9469",
    "lng": "-5.20717"
  },
  {
    "country": "ES",
    "name": "Villamuera de la Cueza",
    "lat": "42.25843",
    "lng": "-4.6886"
  },
  {
    "country": "ES",
    "name": "Villamoronta",
    "lat": "42.40337",
    "lng": "-4.69899"
  },
  {
    "country": "ES",
    "name": "Villamor de los Escuderos",
    "lat": "41.25244",
    "lng": "-5.57485"
  },
  {
    "country": "ES",
    "name": "Villamoratiel de las Matas",
    "lat": "42.39755",
    "lng": "-5.30064"
  },
  {
    "country": "ES",
    "name": "Villamontán de la Valduerna",
    "lat": "42.30962",
    "lng": "-5.99656"
  },
  {
    "country": "ES",
    "name": "Villamol",
    "lat": "42.42766",
    "lng": "-5.04832"
  },
  {
    "country": "ES",
    "name": "Villamiel de la Sierra",
    "lat": "42.19124",
    "lng": "-3.41771"
  },
  {
    "country": "ES",
    "name": "Villamiel",
    "lat": "40.18635",
    "lng": "-6.78425"
  },
  {
    "country": "ES",
    "name": "Villameriel",
    "lat": "42.52822",
    "lng": "-4.47572"
  },
  {
    "country": "ES",
    "name": "Villamejil",
    "lat": "42.56205",
    "lng": "-6.02514"
  },
  {
    "country": "ES",
    "name": "Villamedianilla",
    "lat": "42.1607",
    "lng": "-4.14592"
  },
  {
    "country": "ES",
    "name": "Villamediana de Iregua",
    "lat": "42.42658",
    "lng": "-2.41943"
  },
  {
    "country": "ES",
    "name": "Villamediana",
    "lat": "42.05024",
    "lng": "-4.36115"
  },
  {
    "country": "ES",
    "name": "Villamayor de Treviño",
    "lat": "42.46048",
    "lng": "-4.11923"
  },
  {
    "country": "ES",
    "name": "Villamayor de Monjardín",
    "lat": "42.62937",
    "lng": "-2.10503"
  },
  {
    "country": "ES",
    "name": "Villamayor de los Montes",
    "lat": "42.10565",
    "lng": "-3.76542"
  },
  {
    "country": "ES",
    "name": "Villamayor de Campos",
    "lat": "41.8987",
    "lng": "-5.35963"
  },
  {
    "country": "ES",
    "name": "Villamayor",
    "lat": "40.99939",
    "lng": "-5.69579"
  },
  {
    "country": "ES",
    "name": "Villamartín de Don Sancho",
    "lat": "42.56943",
    "lng": "-5.06056"
  },
  {
    "country": "ES",
    "name": "Villamartín de Campos",
    "lat": "42.01598",
    "lng": "-4.66414"
  },
  {
    "country": "ES",
    "name": "Vilamarín",
    "lat": "42.46488",
    "lng": "-7.89119"
  },
  {
    "country": "ES",
    "name": "Villamantilla",
    "lat": "40.33846",
    "lng": "-4.12986"
  },
  {
    "country": "ES",
    "name": "Villamanta",
    "lat": "40.29858",
    "lng": "-4.1088"
  },
  {
    "country": "ES",
    "name": "Villamanrique de Tajo",
    "lat": "40.06617",
    "lng": "-3.23668"
  },
  {
    "country": "ES",
    "name": "Villamanín",
    "lat": "42.93864",
    "lng": "-5.65669"
  },
  {
    "country": "ES",
    "name": "Villamandos",
    "lat": "42.18058",
    "lng": "-5.59397"
  },
  {
    "country": "ES",
    "name": "Villamañán",
    "lat": "42.32198",
    "lng": "-5.58195"
  },
  {
    "country": "ES",
    "name": "Villaluenga de la Vega",
    "lat": "42.52386",
    "lng": "-4.76489"
  },
  {
    "country": "ES",
    "name": "Villalube",
    "lat": "41.61005",
    "lng": "-5.54545"
  },
  {
    "country": "ES",
    "name": "Villalpando",
    "lat": "41.86517",
    "lng": "-5.41231"
  },
  {
    "country": "ES",
    "name": "Villalonso",
    "lat": "41.59767",
    "lng": "-5.29769"
  },
  {
    "country": "ES",
    "name": "Villalón de Campos",
    "lat": "42.09994",
    "lng": "-5.0344"
  },
  {
    "country": "ES",
    "name": "Villalobos",
    "lat": "41.94567",
    "lng": "-5.47517"
  },
  {
    "country": "ES",
    "name": "Villalobón",
    "lat": "42.03037",
    "lng": "-4.5034"
  },
  {
    "country": "ES",
    "name": "Villalobar de Rioja",
    "lat": "42.49123",
    "lng": "-2.96404"
  },
  {
    "country": "ES",
    "name": "Villalmanzo",
    "lat": "42.0484",
    "lng": "-3.74195"
  },
  {
    "country": "ES",
    "name": "Villalengua",
    "lat": "41.43548",
    "lng": "-1.84125"
  },
  {
    "country": "ES",
    "name": "Villaldemiro",
    "lat": "42.24719",
    "lng": "-3.98534"
  },
  {
    "country": "ES",
    "name": "Villalcón",
    "lat": "42.29287",
    "lng": "-4.85527"
  },
  {
    "country": "ES",
    "name": "Villalcázar de Sirga",
    "lat": "42.31662",
    "lng": "-4.54278"
  },
  {
    "country": "ES",
    "name": "Villalcampo",
    "lat": "41.52229",
    "lng": "-6.04801"
  },
  {
    "country": "ES",
    "name": "Villalbilla de Gumiel",
    "lat": "41.80621",
    "lng": "-3.62584"
  },
  {
    "country": "ES",
    "name": "Villalbilla de Burgos",
    "lat": "42.34757",
    "lng": "-3.78101"
  },
  {
    "country": "ES",
    "name": "Villalbilla",
    "lat": "40.43044",
    "lng": "-3.29904"
  },
  {
    "country": "ES",
    "name": "Villalbarba",
    "lat": "41.60389",
    "lng": "-5.21281"
  },
  {
    "country": "ES",
    "name": "Villalba de Rioja",
    "lat": "42.60967",
    "lng": "-2.88687"
  },
  {
    "country": "ES",
    "name": "Villalba de Perejil",
    "lat": "41.32742",
    "lng": "-1.54833"
  },
  {
    "country": "ES",
    "name": "Villalba del Rey",
    "lat": "40.34653",
    "lng": "-2.63902"
  },
  {
    "country": "ES",
    "name": "Villalba de los Llanos",
    "lat": "40.8002",
    "lng": "-5.9758"
  },
  {
    "country": "ES",
    "name": "Vilalba dels Arcs",
    "lat": "41.11667",
    "lng": "0.41667"
  },
  {
    "country": "ES",
    "name": "Villalba de los Alcores",
    "lat": "41.86361",
    "lng": "-4.86063"
  },
  {
    "country": "ES",
    "name": "Villalba de la Sierra",
    "lat": "40.23437",
    "lng": "-2.08929"
  },
  {
    "country": "ES",
    "name": "Villalba de la Loma",
    "lat": "42.17472",
    "lng": "-5.19023"
  },
  {
    "country": "ES",
    "name": "Villalba de la Lampreana",
    "lat": "41.74327",
    "lng": "-5.64094"
  },
  {
    "country": "ES",
    "name": "Villalba de Guardo",
    "lat": "42.72229",
    "lng": "-4.82328"
  },
  {
    "country": "ES",
    "name": "Villalba de Duero",
    "lat": "41.68243",
    "lng": "-3.74443"
  },
  {
    "country": "ES",
    "name": "Vilalba",
    "lat": "43.29806",
    "lng": "-7.6813"
  },
  {
    "country": "ES",
    "name": "Villalazán",
    "lat": "41.49414",
    "lng": "-5.5891"
  },
  {
    "country": "ES",
    "name": "Villalar de los Comuneros",
    "lat": "41.54966",
    "lng": "-5.1381"
  },
  {
    "country": "ES",
    "name": "Villalán de Campos",
    "lat": "42.01484",
    "lng": "-5.23642"
  },
  {
    "country": "ES",
    "name": "Villalaco",
    "lat": "42.15569",
    "lng": "-4.2594"
  },
  {
    "country": "ES",
    "name": "Villahoz",
    "lat": "42.07587",
    "lng": "-3.9129"
  },
  {
    "country": "ES",
    "name": "Villaherreros",
    "lat": "42.38964",
    "lng": "-4.46254"
  },
  {
    "country": "ES",
    "name": "Villahermosa del Río",
    "lat": "40.20268",
    "lng": "-0.4199"
  },
  {
    "country": "ES",
    "name": "Villahermosa del Campo",
    "lat": "41.10942",
    "lng": "-1.24692"
  },
  {
    "country": "ES",
    "name": "Villahán",
    "lat": "42.05031",
    "lng": "-4.13104"
  },
  {
    "country": "ES",
    "name": "Villagonzalo-Pedernales",
    "lat": "42.30145",
    "lng": "-3.73539"
  },
  {
    "country": "ES",
    "name": "Villagonzalo de Tormes",
    "lat": "40.89221",
    "lng": "-5.49664"
  },
  {
    "country": "ES",
    "name": "Villagómez la Nueva",
    "lat": "42.15592",
    "lng": "-5.14208"
  },
  {
    "country": "ES",
    "name": "Villageriz",
    "lat": "42.11884",
    "lng": "-5.95554"
  },
  {
    "country": "ES",
    "name": "Villagatón",
    "lat": "42.63413",
    "lng": "-6.16184"
  },
  {
    "country": "ES",
    "name": "Villagarcía de Campos",
    "lat": "41.78032",
    "lng": "-5.19242"
  },
  {
    "country": "ES",
    "name": "Vilagarcía de Arousa",
    "lat": "42.59631",
    "lng": "-8.76426"
  },
  {
    "country": "ES",
    "name": "Villagalijo",
    "lat": "42.34872",
    "lng": "-3.19203"
  },
  {
    "country": "ES",
    "name": "Villafufre",
    "lat": "43.26557",
    "lng": "-3.8937"
  },
  {
    "country": "ES",
    "name": "Villafuerte",
    "lat": "41.73431",
    "lng": "-4.32365"
  },
  {
    "country": "ES",
    "name": "Villafruela",
    "lat": "41.91647",
    "lng": "-3.91371"
  },
  {
    "country": "ES",
    "name": "Villafrechós",
    "lat": "41.8929",
    "lng": "-5.21859"
  },
  {
    "country": "ES",
    "name": "Ordizia",
    "lat": "43.0541",
    "lng": "-2.17632"
  },
  {
    "country": "ES",
    "name": "Vilafranca del Penedès",
    "lat": "41.34618",
    "lng": "1.69713"
  },
  {
    "country": "ES",
    "name": "Villafranca del Cid",
    "lat": "40.42885",
    "lng": "-0.25775"
  },
  {
    "country": "ES",
    "name": "Villafranca del Campo",
    "lat": "40.69545",
    "lng": "-1.34722"
  },
  {
    "country": "ES",
    "name": "Villafranca del Bierzo",
    "lat": "42.60601",
    "lng": "-6.81069"
  },
  {
    "country": "ES",
    "name": "Villafranca de la Sierra",
    "lat": "40.49806",
    "lng": "-5.23005"
  },
  {
    "country": "ES",
    "name": "Villafranca de Ebro",
    "lat": "41.57473",
    "lng": "-0.65039"
  },
  {
    "country": "ES",
    "name": "Villafranca de Duero",
    "lat": "41.4331",
    "lng": "-5.30192"
  },
  {
    "country": "ES",
    "name": "Villafranca",
    "lat": "42.27933",
    "lng": "-1.74628"
  },
  {
    "country": "ES",
    "name": "Villafrades de Campos",
    "lat": "42.07853",
    "lng": "-4.97125"
  },
  {
    "country": "ES",
    "name": "Villaflores",
    "lat": "41.08397",
    "lng": "-5.23436"
  },
  {
    "country": "ES",
    "name": "Villaflor",
    "lat": "40.75865",
    "lng": "-4.87379"
  },
  {
    "country": "ES",
    "name": "Villaferrueña",
    "lat": "42.0983",
    "lng": "-5.85802"
  },
  {
    "country": "ES",
    "name": "Villafeliche",
    "lat": "41.19509",
    "lng": "-1.50983"
  },
  {
    "country": "ES",
    "name": "Villafamés",
    "lat": "40.11667",
    "lng": "-0.05"
  },
  {
    "country": "ES",
    "name": "Villafáfila",
    "lat": "41.84692",
    "lng": "-5.61527"
  },
  {
    "country": "ES",
    "name": "Villaespasa",
    "lat": "42.09991",
    "lng": "-3.40436"
  },
  {
    "country": "ES",
    "name": "Villaescusa la Sombría",
    "lat": "42.41518",
    "lng": "-3.4184"
  },
  {
    "country": "ES",
    "name": "Villaescusa de Roa",
    "lat": "41.72727",
    "lng": "-4.0172"
  },
  {
    "country": "ES",
    "name": "Villaescusa",
    "lat": "42.96262",
    "lng": "-4.16706"
  },
  {
    "country": "ES",
    "name": "Villaescusa",
    "lat": "41.20617",
    "lng": "-5.46406"
  },
  {
    "country": "ES",
    "name": "Villaeles de Valdavia",
    "lat": "42.56556",
    "lng": "-4.58318"
  },
  {
    "country": "ES",
    "name": "Villadoz",
    "lat": "41.16234",
    "lng": "-1.288"
  },
  {
    "country": "ES",
    "name": "Villadiego",
    "lat": "42.51589",
    "lng": "-4.00958"
  },
  {
    "country": "ES",
    "name": "Villadepera",
    "lat": "41.547",
    "lng": "-6.13305"
  },
  {
    "country": "ES",
    "name": "Villademor de la Vega",
    "lat": "42.26964",
    "lng": "-5.56808"
  },
  {
    "country": "ES",
    "name": "Villa del Prado",
    "lat": "40.27852",
    "lng": "-4.30534"
  },
  {
    "country": "ES",
    "name": "Villa del Campo",
    "lat": "40.14223",
    "lng": "-6.42679"
  },
  {
    "country": "ES",
    "name": "Villadecanes",
    "lat": "42.57973",
    "lng": "-6.75971"
  },
  {
    "country": "ES",
    "name": "Villadangos del Páramo",
    "lat": "42.51672",
    "lng": "-5.76737"
  },
  {
    "country": "ES",
    "name": "Villada",
    "lat": "42.25111",
    "lng": "-4.96708"
  },
  {
    "country": "ES",
    "name": "Villaconejos de Trabaque",
    "lat": "40.40064",
    "lng": "-2.31956"
  },
  {
    "country": "ES",
    "name": "Villaconejos",
    "lat": "40.10139",
    "lng": "-3.48258"
  },
  {
    "country": "ES",
    "name": "Villaconancio",
    "lat": "41.87174",
    "lng": "-4.22379"
  },
  {
    "country": "ES",
    "name": "Villaco",
    "lat": "41.74022",
    "lng": "-4.26817"
  },
  {
    "country": "ES",
    "name": "Villaciervos",
    "lat": "41.76227",
    "lng": "-2.62678"
  },
  {
    "country": "ES",
    "name": "Villacid de Campos",
    "lat": "42.0825",
    "lng": "-5.12498"
  },
  {
    "country": "ES",
    "name": "Villacidaler",
    "lat": "42.22168",
    "lng": "-4.97668"
  },
  {
    "country": "ES",
    "name": "Villacastín",
    "lat": "40.7796",
    "lng": "-4.41357"
  },
  {
    "country": "ES",
    "name": "Villacarriedo",
    "lat": "43.22851",
    "lng": "-3.81057"
  },
  {
    "country": "ES",
    "name": "Villacarralón",
    "lat": "42.18999",
    "lng": "-5.04324"
  },
  {
    "country": "ES",
    "name": "Villabuena del Puente",
    "lat": "41.38074",
    "lng": "-5.40787"
  },
  {
    "country": "ES",
    "name": "Eskuernaga / Villabuena de Álava",
    "lat": "42.54787",
    "lng": "-2.66552"
  },
  {
    "country": "ES",
    "name": "Villabrázaro",
    "lat": "42.05394",
    "lng": "-5.72748"
  },
  {
    "country": "ES",
    "name": "Villabraz",
    "lat": "42.24658",
    "lng": "-5.44593"
  },
  {
    "country": "ES",
    "name": "Villabrágima",
    "lat": "41.82178",
    "lng": "-5.11546"
  },
  {
    "country": "ES",
    "name": "Villabona",
    "lat": "43.1854",
    "lng": "-2.05304"
  },
  {
    "country": "ES",
    "name": "Villablino",
    "lat": "42.93932",
    "lng": "-6.31943"
  },
  {
    "country": "ES",
    "name": "Villabaruz de Campos",
    "lat": "42.01099",
    "lng": "-4.99624"
  },
  {
    "country": "ES",
    "name": "Villabáñez",
    "lat": "41.63097",
    "lng": "-4.52192"
  },
  {
    "country": "ES",
    "name": "Atarrabia",
    "lat": "42.8323",
    "lng": "-1.60735"
  },
  {
    "country": "ES",
    "name": "Vileña",
    "lat": "42.62227",
    "lng": "-3.32293"
  },
  {
    "country": "ES",
    "name": "Vila-seca",
    "lat": "41.11118",
    "lng": "1.14764"
  },
  {
    "country": "ES",
    "name": "Vilaseca",
    "lat": "42.06174",
    "lng": "2.25528"
  },
  {
    "country": "ES",
    "name": "Vilasantar",
    "lat": "43.07106",
    "lng": "-8.12163"
  },
  {
    "country": "ES",
    "name": "Vila-sacra",
    "lat": "42.26578",
    "lng": "3.01839"
  },
  {
    "country": "ES",
    "name": "Vilaplana",
    "lat": "41.228",
    "lng": "1.03325"
  },
  {
    "country": "ES",
    "name": "Vilanova de Sau",
    "lat": "41.947",
    "lng": "2.3844"
  },
  {
    "country": "ES",
    "name": "Vilanova de Prades",
    "lat": "41.3485",
    "lng": "0.95667"
  },
  {
    "country": "ES",
    "name": "Vilanova del Camí",
    "lat": "41.57165",
    "lng": "1.63751"
  },
  {
    "country": "ES",
    "name": "Vilanova d'Escornalbou",
    "lat": "41.11667",
    "lng": "0.93333"
  },
  {
    "country": "ES",
    "name": "Vilanova de Bellpuig",
    "lat": "41.61379",
    "lng": "0.96432"
  },
  {
    "country": "ES",
    "name": "Vilanant",
    "lat": "42.25471",
    "lng": "2.88923"
  },
  {
    "country": "ES",
    "name": "Vilamaniscle",
    "lat": "42.37522",
    "lng": "3.06755"
  },
  {
    "country": "ES",
    "name": "Vilamalla",
    "lat": "42.2172",
    "lng": "2.97009"
  },
  {
    "country": "ES",
    "name": "Vilamacolum",
    "lat": "42.19618",
    "lng": "3.05662"
  },
  {
    "country": "ES",
    "name": "Vilajuïga",
    "lat": "42.32533",
    "lng": "3.09302"
  },
  {
    "country": "ES",
    "name": "Vilafant",
    "lat": "42.24668",
    "lng": "2.9382"
  },
  {
    "country": "ES",
    "name": "Viladrau",
    "lat": "41.84746",
    "lng": "2.39019"
  },
  {
    "country": "ES",
    "name": "Viladasens",
    "lat": "42.08333",
    "lng": "2.93333"
  },
  {
    "country": "ES",
    "name": "Vilademuls",
    "lat": "42.1389",
    "lng": "2.88819"
  },
  {
    "country": "ES",
    "name": "Viladecans",
    "lat": "41.31405",
    "lng": "2.01427"
  },
  {
    "country": "ES",
    "name": "Viladecavalls",
    "lat": "41.55",
    "lng": "1.95"
  },
  {
    "country": "ES",
    "name": "Vilada",
    "lat": "42.13695",
    "lng": "1.93162"
  },
  {
    "country": "ES",
    "name": "Vilablareix",
    "lat": "41.95746",
    "lng": "2.77377"
  },
  {
    "country": "ES",
    "name": "Vilabertran",
    "lat": "42.28255",
    "lng": "2.98144"
  },
  {
    "country": "ES",
    "name": "Vilabella",
    "lat": "41.24779",
    "lng": "1.33019"
  },
  {
    "country": "ES",
    "name": "Viguera",
    "lat": "42.30934",
    "lng": "-2.53334"
  },
  {
    "country": "ES",
    "name": "Vigo",
    "lat": "42.23282",
    "lng": "-8.72264"
  },
  {
    "country": "ES",
    "name": "Vierlas",
    "lat": "41.92708",
    "lng": "-1.68123"
  },
  {
    "country": "ES",
    "name": "Vielha",
    "lat": "42.70196",
    "lng": "0.79556"
  },
  {
    "country": "ES",
    "name": "Vidreres",
    "lat": "41.78333",
    "lng": "2.78333"
  },
  {
    "country": "ES",
    "name": "Vidrà",
    "lat": "42.12285",
    "lng": "2.30977"
  },
  {
    "country": "ES",
    "name": "Videmala",
    "lat": "41.61299",
    "lng": "-6.04056"
  },
  {
    "country": "ES",
    "name": "Vidayanes",
    "lat": "41.91011",
    "lng": "-5.57424"
  },
  {
    "country": "ES",
    "name": "Vic",
    "lat": "41.93012",
    "lng": "2.25486"
  },
  {
    "country": "ES",
    "name": "Vicálvaro",
    "lat": "40.4",
    "lng": "-3.6"
  },
  {
    "country": "ES",
    "name": "Viandar de la Vera",
    "lat": "40.12191",
    "lng": "-5.53593"
  },
  {
    "country": "ES",
    "name": "Viana de Jadraque",
    "lat": "41.02577",
    "lng": "-2.76966"
  },
  {
    "country": "ES",
    "name": "Viana de Duero",
    "lat": "41.53406",
    "lng": "-2.46099"
  },
  {
    "country": "ES",
    "name": "Viana de Cega",
    "lat": "41.52927",
    "lng": "-4.75245"
  },
  {
    "country": "ES",
    "name": "Viana",
    "lat": "42.51552",
    "lng": "-2.37123"
  },
  {
    "country": "ES",
    "name": "Vezdemarbán",
    "lat": "41.6548",
    "lng": "-5.36609"
  },
  {
    "country": "ES",
    "name": "Vertavillo",
    "lat": "41.83281",
    "lng": "-4.32707"
  },
  {
    "country": "ES",
    "name": "Verín",
    "lat": "41.94149",
    "lng": "-7.43809"
  },
  {
    "country": "ES",
    "name": "Verges",
    "lat": "42.06283",
    "lng": "3.04579"
  },
  {
    "country": "ES",
    "name": "Bergara",
    "lat": "43.1151",
    "lng": "-2.4175"
  },
  {
    "country": "ES",
    "name": "Verea",
    "lat": "42.10653",
    "lng": "-8.00092"
  },
  {
    "country": "ES",
    "name": "Verdú",
    "lat": "41.61057",
    "lng": "1.14284"
  },
  {
    "country": "ES",
    "name": "Vera de Moncayo",
    "lat": "41.824",
    "lng": "-1.68799"
  },
  {
    "country": "ES",
    "name": "Bera",
    "lat": "43.28177",
    "lng": "-1.68632"
  },
  {
    "country": "ES",
    "name": "Venturada",
    "lat": "40.79717",
    "lng": "-3.61974"
  },
  {
    "country": "ES",
    "name": "Ventrosa",
    "lat": "42.15705",
    "lng": "-2.85044"
  },
  {
    "country": "ES",
    "name": "Ventosa del Río Almar",
    "lat": "40.92728",
    "lng": "-5.34838"
  },
  {
    "country": "ES",
    "name": "Ventosa de la Cuesta",
    "lat": "41.4111",
    "lng": "-4.82932"
  },
  {
    "country": "ES",
    "name": "Ventosa",
    "lat": "42.40495",
    "lng": "-2.62651"
  },
  {
    "country": "ES",
    "name": "Ventalló",
    "lat": "42.14921",
    "lng": "3.02635"
  },
  {
    "country": "ES",
    "name": "Venta de Baños",
    "lat": "41.9211",
    "lng": "-4.49089"
  },
  {
    "country": "ES",
    "name": "Venialbo",
    "lat": "41.38957",
    "lng": "-5.53596"
  },
  {
    "country": "ES",
    "name": "El Vendrell",
    "lat": "41.21667",
    "lng": "1.53333"
  },
  {
    "country": "ES",
    "name": "Velliza",
    "lat": "41.57918",
    "lng": "-4.94655"
  },
  {
    "country": "ES",
    "name": "Vellisca",
    "lat": "40.12965",
    "lng": "-2.81444"
  },
  {
    "country": "ES",
    "name": "Velilla de San Antonio",
    "lat": "40.36516",
    "lng": "-3.48484"
  },
  {
    "country": "ES",
    "name": "Velilla del Río Carrión",
    "lat": "42.82611",
    "lng": "-4.84626"
  },
  {
    "country": "ES",
    "name": "Velilla de los Ajos",
    "lat": "41.49058",
    "lng": "-2.25579"
  },
  {
    "country": "ES",
    "name": "Velilla de Jiloca",
    "lat": "41.27509",
    "lng": "-1.60396"
  },
  {
    "country": "ES",
    "name": "Velilla de Ebro",
    "lat": "41.37416",
    "lng": "-0.43483"
  },
  {
    "country": "ES",
    "name": "Velilla",
    "lat": "41.5592",
    "lng": "-5.00454"
  },
  {
    "country": "ES",
    "name": "Velayos",
    "lat": "40.84157",
    "lng": "-4.62324"
  },
  {
    "country": "ES",
    "name": "Velascálvaro",
    "lat": "41.23028",
    "lng": "-4.97242"
  },
  {
    "country": "ES",
    "name": "Velamazán",
    "lat": "41.44895",
    "lng": "-2.69935"
  },
  {
    "country": "ES",
    "name": "Veguillas de la Sierra",
    "lat": "40.15",
    "lng": "-1.4"
  },
  {
    "country": "ES",
    "name": "Vegas de Matute",
    "lat": "40.79476",
    "lng": "-4.27762"
  },
  {
    "country": "ES",
    "name": "Vegaquemada",
    "lat": "42.8187",
    "lng": "-5.33242"
  },
  {
    "country": "ES",
    "name": "Veganzones",
    "lat": "41.19308",
    "lng": "-3.99329"
  },
  {
    "country": "ES",
    "name": "Vegalatrave",
    "lat": "41.70026",
    "lng": "-6.10675"
  },
  {
    "country": "ES",
    "name": "Vega de Villalobos",
    "lat": "41.97057",
    "lng": "-5.46324"
  },
  {
    "country": "ES",
    "name": "Vega de Valdetronco",
    "lat": "41.59364",
    "lng": "-5.11319"
  },
  {
    "country": "ES",
    "name": "Vega de Valcarce",
    "lat": "42.66068",
    "lng": "-6.93785"
  },
  {
    "country": "ES",
    "name": "Vega de Tirados",
    "lat": "41.02543",
    "lng": "-5.88667"
  },
  {
    "country": "ES",
    "name": "Vega de Tera",
    "lat": "41.99759",
    "lng": "-6.125"
  },
  {
    "country": "ES",
    "name": "Vega de Santa María",
    "lat": "40.83618",
    "lng": "-4.64287"
  },
  {
    "country": "ES",
    "name": "Vega de Ruiponce",
    "lat": "42.18808",
    "lng": "-5.11477"
  },
  {
    "country": "ES",
    "name": "Vega de Pas",
    "lat": "43.15692",
    "lng": "-3.78316"
  },
  {
    "country": "ES",
    "name": "Vegadeo",
    "lat": "43.46834",
    "lng": "-7.0539"
  },
  {
    "country": "ES",
    "name": "Vega de Infanzones",
    "lat": "42.48116",
    "lng": "-5.53295"
  },
  {
    "country": "ES",
    "name": "Vega de Espinareda",
    "lat": "42.72537",
    "lng": "-6.65439"
  },
  {
    "country": "ES",
    "name": "Vegacervera",
    "lat": "42.88808",
    "lng": "-5.53549"
  },
  {
    "country": "ES",
    "name": "Vedra",
    "lat": "42.77817",
    "lng": "-8.47636"
  },
  {
    "country": "ES",
    "name": "Vecinos",
    "lat": "40.77875",
    "lng": "-5.87815"
  },
  {
    "country": "ES",
    "name": "Valverdón",
    "lat": "41.04691",
    "lng": "-5.76955"
  },
  {
    "country": "ES",
    "name": "Valverde-Enrique",
    "lat": "42.30459",
    "lng": "-5.2999"
  },
  {
    "country": "ES",
    "name": "Valverde de Valdelacasa",
    "lat": "40.48155",
    "lng": "-5.78145"
  },
  {
    "country": "ES",
    "name": "Valverde de los Arroyos",
    "lat": "41.1293",
    "lng": "-3.23333"
  },
  {
    "country": "ES",
    "name": "Valverde del Majano",
    "lat": "40.95689",
    "lng": "-4.23468"
  },
  {
    "country": "ES",
    "name": "Valverde del Fresno",
    "lat": "40.2221",
    "lng": "-6.87848"
  },
  {
    "country": "ES",
    "name": "Valverde de la Virgen",
    "lat": "42.56823",
    "lng": "-5.68461"
  },
  {
    "country": "ES",
    "name": "Valverde de la Vera",
    "lat": "40.12268",
    "lng": "-5.49541"
  },
  {
    "country": "ES",
    "name": "Valverde de Campos",
    "lat": "41.8351",
    "lng": "-5.03674"
  },
  {
    "country": "ES",
    "name": "Valverde de Alcalá",
    "lat": "40.41667",
    "lng": "-3.29631"
  },
  {
    "country": "ES",
    "name": "Valtorres",
    "lat": "41.29855",
    "lng": "-1.7408"
  },
  {
    "country": "ES",
    "name": "Valtierra",
    "lat": "42.19653",
    "lng": "-1.63459"
  },
  {
    "country": "ES",
    "name": "Valtiendas",
    "lat": "41.47851",
    "lng": "-3.91766"
  },
  {
    "country": "ES",
    "name": "Valtajeros",
    "lat": "41.93808",
    "lng": "-2.22289"
  },
  {
    "country": "ES",
    "name": "Valtablado del Río",
    "lat": "40.7142",
    "lng": "-2.40225"
  },
  {
    "country": "ES",
    "name": "Valseca",
    "lat": "40.99933",
    "lng": "-4.17514"
  },
  {
    "country": "ES",
    "name": "Valsalobre",
    "lat": "40.61742",
    "lng": "-2.09297"
  },
  {
    "country": "ES",
    "name": "Valsalabroso",
    "lat": "41.10962",
    "lng": "-6.50269"
  },
  {
    "country": "ES",
    "name": "Valpalmas",
    "lat": "42.15821",
    "lng": "-0.85481"
  },
  {
    "country": "ES",
    "name": "Valoria la Buena",
    "lat": "41.79966",
    "lng": "-4.53055"
  },
  {
    "country": "ES",
    "name": "Valmojado",
    "lat": "40.20444",
    "lng": "-4.09146"
  },
  {
    "country": "ES",
    "name": "Balmaseda",
    "lat": "43.2",
    "lng": "-3.2"
  },
  {
    "country": "ES",
    "name": "Valmala",
    "lat": "42.3059",
    "lng": "-3.25456"
  },
  {
    "country": "ES",
    "name": "Valmadrid",
    "lat": "41.44351",
    "lng": "-0.88482"
  },
  {
    "country": "ES",
    "name": "Valluércanes",
    "lat": "42.5722",
    "lng": "-3.12113"
  },
  {
    "country": "ES",
    "name": "Valls",
    "lat": "41.28612",
    "lng": "1.24993"
  },
  {
    "country": "ES",
    "name": "Vallromanes",
    "lat": "41.53333",
    "lng": "2.3"
  },
  {
    "country": "ES",
    "name": "Vallmoll",
    "lat": "41.24311",
    "lng": "1.249"
  },
  {
    "country": "ES",
    "name": "Vallirana",
    "lat": "41.38676",
    "lng": "1.93205"
  },
  {
    "country": "ES",
    "name": "Vallibona",
    "lat": "40.603",
    "lng": "0.04642"
  },
  {
    "country": "ES",
    "name": "Vallgorguina",
    "lat": "41.64822",
    "lng": "2.50996"
  },
  {
    "country": "ES",
    "name": "Vallfogona de Riucorb",
    "lat": "41.5628",
    "lng": "1.23691"
  },
  {
    "country": "ES",
    "name": "Vallfogona de Balaguer",
    "lat": "41.75211",
    "lng": "0.81385"
  },
  {
    "country": "ES",
    "name": "Valles de Palenzuela",
    "lat": "42.12019",
    "lng": "-4.0775"
  },
  {
    "country": "ES",
    "name": "Vallesa de la Guareña",
    "lat": "41.13532",
    "lng": "-5.32611"
  },
  {
    "country": "ES",
    "name": "Valleruela de Sepúlveda",
    "lat": "41.18794",
    "lng": "-3.77277"
  },
  {
    "country": "ES",
    "name": "Valleruela de Pedraza",
    "lat": "41.17937",
    "lng": "-3.80717"
  },
  {
    "country": "ES",
    "name": "Vallelado",
    "lat": "41.40436",
    "lng": "-4.42662"
  },
  {
    "country": "ES",
    "name": "Vallejera de Riofrío",
    "lat": "40.4091",
    "lng": "-5.71943"
  },
  {
    "country": "ES",
    "name": "Valle de Tabladillo",
    "lat": "41.36304",
    "lng": "-3.83966"
  },
  {
    "country": "ES",
    "name": "Valle de Cerrato",
    "lat": "41.88045",
    "lng": "-4.36243"
  },
  {
    "country": "ES",
    "name": "Vallecillo",
    "lat": "42.35604",
    "lng": "-5.21088"
  },
  {
    "country": "ES",
    "name": "Vallclara",
    "lat": "41.37958",
    "lng": "0.98342"
  },
  {
    "country": "ES",
    "name": "Vallcebre",
    "lat": "42.20347",
    "lng": "1.81815"
  },
  {
    "country": "ES",
    "name": "Vallbona de les Monges",
    "lat": "41.52631",
    "lng": "1.08872"
  },
  {
    "country": "ES",
    "name": "Vallarta de Bureba",
    "lat": "42.58864",
    "lng": "-3.20457"
  },
  {
    "country": "ES",
    "name": "Vallanca",
    "lat": "40.06667",
    "lng": "-1.33333"
  },
  {
    "country": "ES",
    "name": "Valladolid",
    "lat": "41.65518",
    "lng": "-4.72372"
  },
  {
    "country": "ES",
    "name": "Valjunquera",
    "lat": "40.9525",
    "lng": "0.02575"
  },
  {
    "country": "ES",
    "name": "Valhermoso",
    "lat": "40.7859",
    "lng": "-1.96121"
  },
  {
    "country": "ES",
    "name": "Valgañón",
    "lat": "42.31782",
    "lng": "-3.06725"
  },
  {
    "country": "ES",
    "name": "Valga",
    "lat": "42.69792",
    "lng": "-8.63959"
  },
  {
    "country": "ES",
    "name": "Valfermoso de Tajuña",
    "lat": "40.61902",
    "lng": "-2.95407"
  },
  {
    "country": "ES",
    "name": "Valfarta",
    "lat": "41.55726",
    "lng": "-0.13304"
  },
  {
    "country": "ES",
    "name": "Valero",
    "lat": "40.53533",
    "lng": "-5.94307"
  },
  {
    "country": "ES",
    "name": "Valencia de Don Juan",
    "lat": "42.29374",
    "lng": "-5.5172"
  },
  {
    "country": "ES",
    "name": "Valdunquillo",
    "lat": "42.04232",
    "lng": "-5.31339"
  },
  {
    "country": "ES",
    "name": "Valdunciel",
    "lat": "41.08544",
    "lng": "-5.67217"
  },
  {
    "country": "ES",
    "name": "Valdoviño",
    "lat": "43.6",
    "lng": "-8.13333"
  },
  {
    "country": "ES",
    "name": "Valdorros",
    "lat": "42.17232",
    "lng": "-3.70938"
  },
  {
    "country": "ES",
    "name": "Valdilecha",
    "lat": "40.2953",
    "lng": "-3.30233"
  },
  {
    "country": "ES",
    "name": "Valdezate",
    "lat": "41.60231",
    "lng": "-3.93045"
  },
  {
    "country": "ES",
    "name": "Valdevimbre",
    "lat": "42.41959",
    "lng": "-5.61975"
  },
  {
    "country": "ES",
    "name": "Valdevacas de Montejo",
    "lat": "41.52068",
    "lng": "-3.63571"
  },
  {
    "country": "ES",
    "name": "Valdetorres de Jarama",
    "lat": "40.69366",
    "lng": "-3.51156"
  },
  {
    "country": "ES",
    "name": "Valdestillas",
    "lat": "41.47697",
    "lng": "-4.77116"
  },
  {
    "country": "ES",
    "name": "Valdesotos",
    "lat": "40.95546",
    "lng": "-3.32542"
  },
  {
    "country": "ES",
    "name": "Valdescorriel",
    "lat": "42.02233",
    "lng": "-5.50998"
  },
  {
    "country": "ES",
    "name": "Val de San Martín",
    "lat": "41.05787",
    "lng": "-1.44934"
  },
  {
    "country": "ES",
    "name": "Val de San Lorenzo",
    "lat": "42.41819",
    "lng": "-6.12391"
  },
  {
    "country": "ES",
    "name": "Valdesamario",
    "lat": "42.72094",
    "lng": "-5.95104"
  },
  {
    "country": "ES",
    "name": "Valderrueda",
    "lat": "42.81558",
    "lng": "-4.94731"
  },
  {
    "country": "ES",
    "name": "Valderrodrigo",
    "lat": "41.06524",
    "lng": "-6.50878"
  },
  {
    "country": "ES",
    "name": "Valderrodilla",
    "lat": "41.56346",
    "lng": "-2.80777"
  },
  {
    "country": "ES",
    "name": "Valderrobres",
    "lat": "40.87209",
    "lng": "0.15431"
  },
  {
    "country": "ES",
    "name": "Valderrey",
    "lat": "42.39408",
    "lng": "-6.02151"
  },
  {
    "country": "ES",
    "name": "Valderrebollo",
    "lat": "40.81035",
    "lng": "-2.72887"
  },
  {
    "country": "ES",
    "name": "Valderrábano",
    "lat": "42.60674",
    "lng": "-4.65584"
  },
  {
    "country": "ES",
    "name": "Valderas",
    "lat": "42.0783",
    "lng": "-5.44355"
  },
  {
    "country": "ES",
    "name": "Valdeprados",
    "lat": "40.81766",
    "lng": "-4.25734"
  },
  {
    "country": "ES",
    "name": "Valdeprado",
    "lat": "41.93768",
    "lng": "-2.10915"
  },
  {
    "country": "ES",
    "name": "Valdepolo",
    "lat": "42.57686",
    "lng": "-5.22513"
  },
  {
    "country": "ES",
    "name": "Valdepiélagos",
    "lat": "40.75842",
    "lng": "-3.46163"
  },
  {
    "country": "ES",
    "name": "Valdepiélago",
    "lat": "42.86895",
    "lng": "-5.39763"
  },
  {
    "country": "ES",
    "name": "Valdepeñas de la Sierra",
    "lat": "40.90562",
    "lng": "-3.38414"
  },
  {
    "country": "ES",
    "name": "Valdeolmos",
    "lat": "40.63708",
    "lng": "-3.45064"
  },
  {
    "country": "ES",
    "name": "Valdeolmillos",
    "lat": "42.04123",
    "lng": "-4.40015"
  },
  {
    "country": "ES",
    "name": "Valdeolivas",
    "lat": "40.506",
    "lng": "-2.44532"
  },
  {
    "country": "ES",
    "name": "Valdeobispo",
    "lat": "40.08297",
    "lng": "-6.24757"
  },
  {
    "country": "ES",
    "name": "Valdenebro de los Valles",
    "lat": "41.8569",
    "lng": "-4.97005"
  },
  {
    "country": "ES",
    "name": "Valdenebro",
    "lat": "41.57167",
    "lng": "-2.96424"
  },
  {
    "country": "ES",
    "name": "Valdemoro-Sierra",
    "lat": "40.1",
    "lng": "-1.76667"
  },
  {
    "country": "ES",
    "name": "Valdemoro",
    "lat": "40.19081",
    "lng": "-3.67887"
  },
  {
    "country": "ES",
    "name": "Valdemorillo de la Sierra",
    "lat": "40.03333",
    "lng": "-1.78333"
  },
  {
    "country": "ES",
    "name": "Valdemorillo",
    "lat": "40.50064",
    "lng": "-4.0671"
  },
  {
    "country": "ES",
    "name": "Valdemora",
    "lat": "42.19541",
    "lng": "-5.42747"
  },
  {
    "country": "ES",
    "name": "Valdemierque",
    "lat": "40.82176",
    "lng": "-5.58225"
  },
  {
    "country": "ES",
    "name": "Valdemeca",
    "lat": "40.22367",
    "lng": "-1.74358"
  },
  {
    "country": "ES",
    "name": "Valdemaqueda",
    "lat": "40.51201",
    "lng": "-4.29722"
  },
  {
    "country": "ES",
    "name": "Valdemanco",
    "lat": "40.87039",
    "lng": "-3.65873"
  },
  {
    "country": "ES",
    "name": "Valdemaluque",
    "lat": "41.67377",
    "lng": "-3.04643"
  },
  {
    "country": "ES",
    "name": "Valdemadera",
    "lat": "41.98408",
    "lng": "-2.07403"
  },
  {
    "country": "ES",
    "name": "Valdeltormo",
    "lat": "40.98716",
    "lng": "0.08342"
  },
  {
    "country": "ES",
    "name": "Valdelosa",
    "lat": "41.17157",
    "lng": "-5.7839"
  },
  {
    "country": "ES",
    "name": "Valdelinares",
    "lat": "40.39114",
    "lng": "-0.60593"
  },
  {
    "country": "ES",
    "name": "Valdelcubo",
    "lat": "41.22637",
    "lng": "-2.67588"
  },
  {
    "country": "ES",
    "name": "Valdelagua del Cerro",
    "lat": "41.88825",
    "lng": "-2.11538"
  },
  {
    "country": "ES",
    "name": "Valdelageve",
    "lat": "40.36949",
    "lng": "-5.99078"
  },
  {
    "country": "ES",
    "name": "Valdelacasa",
    "lat": "40.50631",
    "lng": "-5.76354"
  },
  {
    "country": "ES",
    "name": "Valdehorna",
    "lat": "41.07275",
    "lng": "-1.42376"
  },
  {
    "country": "ES",
    "name": "Valdehijaderos",
    "lat": "40.41916",
    "lng": "-5.84792"
  },
  {
    "country": "ES",
    "name": "Valdegrudas",
    "lat": "40.71125",
    "lng": "-3.01209"
  },
  {
    "country": "ES",
    "name": "Valdefuentes de Sangusín",
    "lat": "40.46578",
    "lng": "-5.83286"
  },
  {
    "country": "ES",
    "name": "Valdefuentes del Páramo",
    "lat": "42.3237",
    "lng": "-5.83097"
  },
  {
    "country": "ES",
    "name": "Valdefresno",
    "lat": "42.59492",
    "lng": "-5.49355"
  },
  {
    "country": "ES",
    "name": "Valdefinjas",
    "lat": "41.45172",
    "lng": "-5.45232"
  },
  {
    "country": "ES",
    "name": "Valdecuenca",
    "lat": "40.29776",
    "lng": "-1.40829"
  },
  {
    "country": "ES",
    "name": "Valdeconcha",
    "lat": "40.45643",
    "lng": "-2.87663"
  },
  {
    "country": "ES",
    "name": "Valdecasa",
    "lat": "40.65931",
    "lng": "-5.01183"
  },
  {
    "country": "ES",
    "name": "Valdecarros",
    "lat": "40.77007",
    "lng": "-5.42219"
  },
  {
    "country": "ES",
    "name": "Valdeaveruelo",
    "lat": "40.63473",
    "lng": "-3.31367"
  },
  {
    "country": "ES",
    "name": "Valdeavero",
    "lat": "40.6298",
    "lng": "-3.33001"
  },
  {
    "country": "ES",
    "name": "Valdeavellano de Tera",
    "lat": "41.94229",
    "lng": "-2.57634"
  },
  {
    "country": "ES",
    "name": "Valdeavellano",
    "lat": "40.6656",
    "lng": "-2.96977"
  },
  {
    "country": "ES",
    "name": "Valdearenas",
    "lat": "40.80939",
    "lng": "-2.99218"
  },
  {
    "country": "ES",
    "name": "Valdearcos de la Vega",
    "lat": "41.6426",
    "lng": "-4.04845"
  },
  {
    "country": "ES",
    "name": "Valdeande",
    "lat": "41.83302",
    "lng": "-3.52792"
  },
  {
    "country": "ES",
    "name": "Valdealgorfa",
    "lat": "40.99066",
    "lng": "-0.03433"
  },
  {
    "country": "ES",
    "name": "Valdastillas",
    "lat": "40.13293",
    "lng": "-5.87932"
  },
  {
    "country": "ES",
    "name": "Valdarachas",
    "lat": "40.5171",
    "lng": "-3.12652"
  },
  {
    "country": "ES",
    "name": "Valdaracete",
    "lat": "40.2077",
    "lng": "-3.19101"
  },
  {
    "country": "ES",
    "name": "Valcabado",
    "lat": "41.54863",
    "lng": "-5.74916"
  },
  {
    "country": "ES",
    "name": "Valbuena de Pisuerga",
    "lat": "42.14584",
    "lng": "-4.2401"
  },
  {
    "country": "ES",
    "name": "Valbuena de Duero",
    "lat": "41.64323",
    "lng": "-4.29271"
  },
  {
    "country": "ES",
    "name": "Valbona",
    "lat": "40.22877",
    "lng": "-0.81079"
  },
  {
    "country": "ES",
    "name": "Valacloche",
    "lat": "40.19092",
    "lng": "-1.09134"
  },
  {
    "country": "ES",
    "name": "Vadocondes",
    "lat": "41.63925",
    "lng": "-3.57378"
  },
  {
    "country": "ES",
    "name": "Vadillo de la Sierra",
    "lat": "40.60634",
    "lng": "-5.12506"
  },
  {
    "country": "ES",
    "name": "Vadillo de la Guareña",
    "lat": "41.28242",
    "lng": "-5.353"
  },
  {
    "country": "ES",
    "name": "Vadillo",
    "lat": "41.79111",
    "lng": "-3.00845"
  },
  {
    "country": "ES",
    "name": "Rivas-Vaciamadrid",
    "lat": "40.32605",
    "lng": "-3.51089"
  },
  {
    "country": "ES",
    "name": "Utrillas",
    "lat": "40.81267",
    "lng": "-0.84545"
  },
  {
    "country": "ES",
    "name": "Uterga",
    "lat": "42.70981",
    "lng": "-1.76004"
  },
  {
    "country": "ES",
    "name": "Utebo",
    "lat": "41.70826",
    "lng": "-0.99916"
  },
  {
    "country": "ES",
    "name": "Utande",
    "lat": "40.84832",
    "lng": "-2.9277"
  },
  {
    "country": "ES",
    "name": "Usurbil",
    "lat": "43.27164",
    "lng": "-2.04912"
  },
  {
    "country": "ES",
    "name": "Used",
    "lat": "41.05554",
    "lng": "-1.55954"
  },
  {
    "country": "ES",
    "name": "Urzainqui",
    "lat": "42.83029",
    "lng": "-0.94617"
  },
  {
    "country": "ES",
    "name": "Uruñuela",
    "lat": "42.4431",
    "lng": "-2.70749"
  },
  {
    "country": "ES",
    "name": "Urueñas",
    "lat": "41.35589",
    "lng": "-3.77391"
  },
  {
    "country": "ES",
    "name": "Urueña",
    "lat": "41.72738",
    "lng": "-5.20304"
  },
  {
    "country": "ES",
    "name": "Urriés",
    "lat": "42.51943",
    "lng": "-1.13022"
  },
  {
    "country": "ES",
    "name": "Urrea de Jalón",
    "lat": "41.66715",
    "lng": "-1.2342"
  },
  {
    "country": "ES",
    "name": "Urones de Castroponce",
    "lat": "42.09911",
    "lng": "-5.28222"
  },
  {
    "country": "ES",
    "name": "Urnieta",
    "lat": "43.24727",
    "lng": "-1.99084"
  },
  {
    "country": "ES",
    "name": "Urdiales del Páramo",
    "lat": "42.37034",
    "lng": "-5.77297"
  },
  {
    "country": "ES",
    "name": "Unzué",
    "lat": "42.65252",
    "lng": "-1.62598"
  },
  {
    "country": "ES",
    "name": "Undués de Lerda",
    "lat": "42.56572",
    "lng": "-1.16944"
  },
  {
    "country": "ES",
    "name": "Uncastillo",
    "lat": "42.35963",
    "lng": "-1.12842"
  },
  {
    "country": "ES",
    "name": "Uña de Quintana",
    "lat": "42.08662",
    "lng": "-6.14475"
  },
  {
    "country": "ES",
    "name": "Uña",
    "lat": "40.2241",
    "lng": "-1.97788"
  },
  {
    "country": "ES",
    "name": "Umbrías",
    "lat": "40.3153",
    "lng": "-5.58037"
  },
  {
    "country": "ES",
    "name": "Ultramort",
    "lat": "42.0364",
    "lng": "3.03455"
  },
  {
    "country": "ES",
    "name": "Ullastret",
    "lat": "42",
    "lng": "3.06667"
  },
  {
    "country": "ES",
    "name": "Ulldemolins",
    "lat": "41.32216",
    "lng": "0.8765"
  },
  {
    "country": "ES",
    "name": "Ulldecona",
    "lat": "40.59734",
    "lng": "0.44718"
  },
  {
    "country": "ES",
    "name": "Ullastrell",
    "lat": "41.52643",
    "lng": "1.95537"
  },
  {
    "country": "ES",
    "name": "Ullà",
    "lat": "42.04964",
    "lng": "3.10754"
  },
  {
    "country": "ES",
    "name": "Ujué",
    "lat": "42.5",
    "lng": "-1.5"
  },
  {
    "country": "ES",
    "name": "Ujados",
    "lat": "41.23526",
    "lng": "-3.00482"
  },
  {
    "country": "ES",
    "name": "Ugena",
    "lat": "40.15572",
    "lng": "-3.87603"
  },
  {
    "country": "ES",
    "name": "Ucero",
    "lat": "41.71685",
    "lng": "-3.05154"
  },
  {
    "country": "ES",
    "name": "Uceda",
    "lat": "40.83944",
    "lng": "-3.4604"
  },
  {
    "country": "ES",
    "name": "Tui",
    "lat": "42.04713",
    "lng": "-8.64435"
  },
  {
    "country": "ES",
    "name": "Turégano",
    "lat": "41.1561",
    "lng": "-4.00696"
  },
  {
    "country": "ES",
    "name": "Turcia",
    "lat": "42.53431",
    "lng": "-5.87844"
  },
  {
    "country": "ES",
    "name": "Tulebras",
    "lat": "41.97695",
    "lng": "-1.67618"
  },
  {
    "country": "ES",
    "name": "Tudelilla",
    "lat": "42.30023",
    "lng": "-2.11749"
  },
  {
    "country": "ES",
    "name": "Tudela de Duero",
    "lat": "41.5845",
    "lng": "-4.58093"
  },
  {
    "country": "ES",
    "name": "Tudela",
    "lat": "42.06166",
    "lng": "-1.60452"
  },
  {
    "country": "ES",
    "name": "Tubilla del Lago",
    "lat": "41.80154",
    "lng": "-3.58625"
  },
  {
    "country": "ES",
    "name": "Tubilla del Agua",
    "lat": "42.70932",
    "lng": "-3.80116"
  },
  {
    "country": "ES",
    "name": "Truchas",
    "lat": "42.26093",
    "lng": "-6.43605"
  },
  {
    "country": "ES",
    "name": "Tronchón",
    "lat": "40.62091",
    "lng": "-0.39833"
  },
  {
    "country": "ES",
    "name": "Triollo",
    "lat": "42.92456",
    "lng": "-4.6813"
  },
  {
    "country": "ES",
    "name": "Trillo",
    "lat": "40.70086",
    "lng": "-2.59265"
  },
  {
    "country": "ES",
    "name": "Trijueque",
    "lat": "40.77426",
    "lng": "-2.99253"
  },
  {
    "country": "ES",
    "name": "Trigueros del Valle",
    "lat": "41.83049",
    "lng": "-4.65179"
  },
  {
    "country": "ES",
    "name": "Tricio",
    "lat": "42.40223",
    "lng": "-2.71912"
  },
  {
    "country": "ES",
    "name": "Treviana",
    "lat": "42.55901",
    "lng": "-3.05032"
  },
  {
    "country": "ES",
    "name": "Tresviso",
    "lat": "43.25753",
    "lng": "-4.66768"
  },
  {
    "country": "ES",
    "name": "Trespaderne",
    "lat": "42.80221",
    "lng": "-3.38989"
  },
  {
    "country": "ES",
    "name": "Trescasas",
    "lat": "40.96442",
    "lng": "-4.0359"
  },
  {
    "country": "ES",
    "name": "Tremp",
    "lat": "42.16703",
    "lng": "0.89487"
  },
  {
    "country": "ES",
    "name": "Tremedal de Tormes",
    "lat": "41.07423",
    "lng": "-6.18164"
  },
  {
    "country": "ES",
    "name": "Trefacio",
    "lat": "42.12165",
    "lng": "-6.65407"
  },
  {
    "country": "ES",
    "name": "Trazo",
    "lat": "43.01667",
    "lng": "-8.53333"
  },
  {
    "country": "ES",
    "name": "Traspinedo",
    "lat": "41.57509",
    "lng": "-4.47569"
  },
  {
    "country": "ES",
    "name": "Trasobares",
    "lat": "41.64308",
    "lng": "-1.64192"
  },
  {
    "country": "ES",
    "name": "Trasmoz",
    "lat": "41.82599",
    "lng": "-1.72279"
  },
  {
    "country": "ES",
    "name": "Trasmiras",
    "lat": "42.0254",
    "lng": "-7.61735"
  },
  {
    "country": "ES",
    "name": "Tramaced",
    "lat": "41.97318",
    "lng": "-0.29752"
  },
  {
    "country": "ES",
    "name": "Tramacastilla",
    "lat": "40.43059",
    "lng": "-1.57466"
  },
  {
    "country": "ES",
    "name": "Tramacastiel",
    "lat": "40.18842",
    "lng": "-1.24081"
  },
  {
    "country": "ES",
    "name": "Traiguera",
    "lat": "40.52511",
    "lng": "0.29023"
  },
  {
    "country": "ES",
    "name": "Trabazos",
    "lat": "41.74793",
    "lng": "-6.49094"
  },
  {
    "country": "ES",
    "name": "Trabanca",
    "lat": "41.23278",
    "lng": "-6.38484"
  },
  {
    "country": "ES",
    "name": "Trabadelo",
    "lat": "42.64874",
    "lng": "-6.88"
  },
  {
    "country": "ES",
    "name": "Trabada",
    "lat": "43.44475",
    "lng": "-7.19527"
  },
  {
    "country": "ES",
    "name": "Touro",
    "lat": "42.86812",
    "lng": "-8.30764"
  },
  {
    "country": "ES",
    "name": "Tossa de Mar",
    "lat": "41.71667",
    "lng": "2.93333"
  },
  {
    "country": "ES",
    "name": "Tosos",
    "lat": "41.31542",
    "lng": "-1.07292"
  },
  {
    "country": "ES",
    "name": "Toses",
    "lat": "42.32162",
    "lng": "2.01582"
  },
  {
    "country": "ES",
    "name": "Tosantos",
    "lat": "42.41368",
    "lng": "-3.24286"
  },
  {
    "country": "ES",
    "name": "Tortuero",
    "lat": "40.93414",
    "lng": "-3.35024"
  },
  {
    "country": "ES",
    "name": "Tortuera",
    "lat": "40.97181",
    "lng": "-1.79764"
  },
  {
    "country": "ES",
    "name": "Tortosa",
    "lat": "40.81249",
    "lng": "0.5216"
  },
  {
    "country": "ES",
    "name": "Tórtoles",
    "lat": "40.5612",
    "lng": "-5.2612"
  },
  {
    "country": "ES",
    "name": "Tórtola de Henares",
    "lat": "40.70425",
    "lng": "-3.12316"
  },
  {
    "country": "ES",
    "name": "Torrubia de Soria",
    "lat": "41.63045",
    "lng": "-2.09151"
  },
  {
    "country": "ES",
    "name": "Torrubia",
    "lat": "40.96581",
    "lng": "-1.90064"
  },
  {
    "country": "ES",
    "name": "Torroella de Montgrí",
    "lat": "42.04254",
    "lng": "3.12703"
  },
  {
    "country": "ES",
    "name": "Torroella de Fluvià",
    "lat": "42.17522",
    "lng": "3.04025"
  },
  {
    "country": "ES",
    "name": "Torrijo del Campo",
    "lat": "40.82575",
    "lng": "-1.33766"
  },
  {
    "country": "ES",
    "name": "Torrijo de la Cañada",
    "lat": "41.47304",
    "lng": "-1.87441"
  },
  {
    "country": "ES",
    "name": "Torrijas",
    "lat": "40.01667",
    "lng": "-0.95"
  },
  {
    "country": "ES",
    "name": "Torrevelilla",
    "lat": "40.902",
    "lng": "-0.10977"
  },
  {
    "country": "ES",
    "name": "Torre Val de San Pedro",
    "lat": "41.07534",
    "lng": "-3.87116"
  },
  {
    "country": "ES",
    "name": "Torresmenudas",
    "lat": "41.10249",
    "lng": "-5.78475"
  },
  {
    "country": "ES",
    "name": "Torres de Segre",
    "lat": "41.53399",
    "lng": "0.5142"
  },
  {
    "country": "ES",
    "name": "Torres del Río",
    "lat": "42.55162",
    "lng": "-2.27285"
  },
  {
    "country": "ES",
    "name": "Torres del Carrizal",
    "lat": "41.61701",
    "lng": "-5.67173"
  },
  {
    "country": "ES",
    "name": "Torres de la Alameda",
    "lat": "40.40264",
    "lng": "-3.35767"
  },
  {
    "country": "ES",
    "name": "Torres de Berrellén",
    "lat": "41.75797",
    "lng": "-1.0655"
  },
  {
    "country": "ES",
    "name": "Torres de Barbués",
    "lat": "41.9605",
    "lng": "-0.4335"
  },
  {
    "country": "ES",
    "name": "Torres de Alcanadre",
    "lat": "41.96727",
    "lng": "-0.11096"
  },
  {
    "country": "ES",
    "name": "Torres de Albarracín",
    "lat": "40.42709",
    "lng": "-1.53242"
  },
  {
    "country": "ES",
    "name": "Torrescárcela",
    "lat": "41.48455",
    "lng": "-4.3192"
  },
  {
    "country": "ES",
    "name": "Torresandino",
    "lat": "41.8292",
    "lng": "-3.90981"
  },
  {
    "country": "ES",
    "name": "Torrent",
    "lat": "41.95243",
    "lng": "3.12684"
  },
  {
    "country": "ES",
    "name": "Torremormojón",
    "lat": "41.96018",
    "lng": "-4.77765"
  },
  {
    "country": "ES",
    "name": "Torremontalbo",
    "lat": "42.5",
    "lng": "-2.68333"
  },
  {
    "country": "ES",
    "name": "Torremochuela",
    "lat": "40.76528",
    "lng": "-1.8419"
  },
  {
    "country": "ES",
    "name": "Torremocha del Pinar",
    "lat": "40.88954",
    "lng": "-2.04497"
  },
  {
    "country": "ES",
    "name": "Torremocha del Campo",
    "lat": "40.97819",
    "lng": "-2.61881"
  },
  {
    "country": "ES",
    "name": "Torremocha de Jarama",
    "lat": "40.84148",
    "lng": "-3.49666"
  },
  {
    "country": "ES",
    "name": "Torremocha de Jadraque",
    "lat": "41.01881",
    "lng": "-2.89918"
  },
  {
    "country": "ES",
    "name": "Torremenga",
    "lat": "40.04658",
    "lng": "-5.77471"
  },
  {
    "country": "ES",
    "name": "Torre los Negros",
    "lat": "40.85308",
    "lng": "-1.09782"
  },
  {
    "country": "ES",
    "name": "Torrelodones",
    "lat": "40.57654",
    "lng": "-3.92658"
  },
  {
    "country": "ES",
    "name": "Torrelobatón",
    "lat": "41.64942",
    "lng": "-5.02526"
  },
  {
    "country": "ES",
    "name": "Torrelles de Llobregat",
    "lat": "41.35",
    "lng": "1.98333"
  },
  {
    "country": "ES",
    "name": "Torrellas",
    "lat": "41.89444",
    "lng": "-1.77139"
  },
  {
    "country": "ES",
    "name": "Torrelavega",
    "lat": "43.34943",
    "lng": "-4.04785"
  },
  {
    "country": "ES",
    "name": "Torrelara",
    "lat": "42.16673",
    "lng": "-3.51689"
  },
  {
    "country": "ES",
    "name": "Torrelapaja",
    "lat": "41.58133",
    "lng": "-1.95181"
  },
  {
    "country": "ES",
    "name": "Torrelaguna",
    "lat": "40.82764",
    "lng": "-3.53683"
  },
  {
    "country": "ES",
    "name": "Torrejón de Velasco",
    "lat": "40.18746",
    "lng": "-3.77681"
  },
  {
    "country": "ES",
    "name": "Torrejón del Rey",
    "lat": "40.64325",
    "lng": "-3.33376"
  },
  {
    "country": "ES",
    "name": "Torrejón de la Calzada",
    "lat": "40.19886",
    "lng": "-3.797"
  },
  {
    "country": "ES",
    "name": "Torrejón de Ardoz",
    "lat": "40.45535",
    "lng": "-3.46973"
  },
  {
    "country": "ES",
    "name": "Torreiglesias",
    "lat": "41.10236",
    "lng": "-4.0328"
  },
  {
    "country": "ES",
    "name": "Torrehermosa",
    "lat": "41.23767",
    "lng": "-2.128"
  },
  {
    "country": "ES",
    "name": "Torregamones",
    "lat": "41.487",
    "lng": "-6.18335"
  },
  {
    "country": "ES",
    "name": "Torregalindo",
    "lat": "41.58299",
    "lng": "-3.75222"
  },
  {
    "country": "ES",
    "name": "Torrefarrera",
    "lat": "41.67318",
    "lng": "0.60671"
  },
  {
    "country": "ES",
    "name": "Torre en Cameros",
    "lat": "42.24133",
    "lng": "-2.51805"
  },
  {
    "country": "ES",
    "name": "Torre de Peñafiel",
    "lat": "41.53646",
    "lng": "-4.08833"
  },
  {
    "country": "ES",
    "name": "Torredembarra",
    "lat": "41.14505",
    "lng": "1.39861"
  },
  {
    "country": "ES",
    "name": "Torre del Compte",
    "lat": "40.93625",
    "lng": "0.10934"
  },
  {
    "country": "ES",
    "name": "Torre del Burgo",
    "lat": "40.79176",
    "lng": "-3.07723"
  },
  {
    "country": "ES",
    "name": "Torre del Bierzo",
    "lat": "42.60769",
    "lng": "-6.36675"
  },
  {
    "country": "ES",
    "name": "Torre de las Arcas",
    "lat": "40.84166",
    "lng": "-0.71783"
  },
  {
    "country": "ES",
    "name": "Torre de Esgueva",
    "lat": "41.76821",
    "lng": "-4.20003"
  },
  {
    "country": "ES",
    "name": "Torre de Don Miguel",
    "lat": "40.22333",
    "lng": "-6.57686"
  },
  {
    "country": "ES",
    "name": "Torre de Arcas",
    "lat": "40.75137",
    "lng": "-0.06892"
  },
  {
    "country": "ES",
    "name": "Torrecuadradilla",
    "lat": "40.85364",
    "lng": "-2.53215"
  },
  {
    "country": "ES",
    "name": "Torrecuadrada de Molina",
    "lat": "40.74947",
    "lng": "-1.80707"
  },
  {
    "country": "ES",
    "name": "Torrecilla sobre Alesanco",
    "lat": "42.40825",
    "lng": "-2.83379"
  },
  {
    "country": "ES",
    "name": "Torrecilla en Cameros",
    "lat": "42.25532",
    "lng": "-2.63109"
  },
  {
    "country": "ES",
    "name": "Torrecilla del Rebollar",
    "lat": "40.90978",
    "lng": "-1.07244"
  },
  {
    "country": "ES",
    "name": "Torrecilla del Pinar",
    "lat": "41.3736",
    "lng": "-4.03838"
  },
  {
    "country": "ES",
    "name": "Torrecilla de los Ángeles",
    "lat": "40.24788",
    "lng": "-6.41606"
  },
  {
    "country": "ES",
    "name": "Torrecilla del Monte",
    "lat": "42.0949",
    "lng": "-3.69356"
  },
  {
    "country": "ES",
    "name": "Torrecilla de la Torre",
    "lat": "41.66716",
    "lng": "-5.04982"
  },
  {
    "country": "ES",
    "name": "Torrecilla de la Orden",
    "lat": "41.21885",
    "lng": "-5.22384"
  },
  {
    "country": "ES",
    "name": "Torrecilla de la Abadesa",
    "lat": "41.48498",
    "lng": "-5.08762"
  },
  {
    "country": "ES",
    "name": "Torrecilla de Alcañiz",
    "lat": "40.96056",
    "lng": "-0.09077"
  },
  {
    "country": "ES",
    "name": "Torrechiva",
    "lat": "40.05",
    "lng": "-0.4"
  },
  {
    "country": "ES",
    "name": "Torrecaballeros",
    "lat": "40.99211",
    "lng": "-4.0247"
  },
  {
    "country": "ES",
    "name": "Torreblanca",
    "lat": "40.22033",
    "lng": "0.1965"
  },
  {
    "country": "ES",
    "name": "Torreblacos",
    "lat": "41.66927",
    "lng": "-2.87881"
  },
  {
    "country": "ES",
    "name": "Torrebesses",
    "lat": "41.43333",
    "lng": "0.6"
  },
  {
    "country": "ES",
    "name": "Torreadrada",
    "lat": "41.44474",
    "lng": "-3.84"
  },
  {
    "country": "ES",
    "name": "Torralbilla",
    "lat": "41.21009",
    "lng": "-1.338"
  },
  {
    "country": "ES",
    "name": "Torralba de Ribota",
    "lat": "41.41803",
    "lng": "-1.68429"
  },
  {
    "country": "ES",
    "name": "Torralba de los Sisones",
    "lat": "40.89084",
    "lng": "-1.45866"
  },
  {
    "country": "ES",
    "name": "Torralba de los Frailes",
    "lat": "41.03622",
    "lng": "-1.66046"
  },
  {
    "country": "ES",
    "name": "Torralba de Aragón",
    "lat": "41.93487",
    "lng": "-0.51053"
  },
  {
    "country": "ES",
    "name": "Torralba",
    "lat": "40.30253",
    "lng": "-2.28546"
  },
  {
    "country": "ES",
    "name": "Torquemada",
    "lat": "42.0349",
    "lng": "-4.31841"
  },
  {
    "country": "ES",
    "name": "Toro",
    "lat": "41.52417",
    "lng": "-5.39534"
  },
  {
    "country": "ES",
    "name": "Tornos",
    "lat": "40.96188",
    "lng": "-1.43389"
  },
  {
    "country": "ES",
    "name": "Tornavacas",
    "lat": "40.25498",
    "lng": "-5.68876"
  },
  {
    "country": "ES",
    "name": "Tornadizos de Ávila",
    "lat": "40.62757",
    "lng": "-4.61426"
  },
  {
    "country": "ES",
    "name": "Tornabous",
    "lat": "41.70117",
    "lng": "1.05384"
  },
  {
    "country": "ES",
    "name": "Tormón",
    "lat": "40.20266",
    "lng": "-1.35406"
  },
  {
    "country": "ES",
    "name": "Tormellas",
    "lat": "40.30404",
    "lng": "-5.51185"
  },
  {
    "country": "ES",
    "name": "Tormantos",
    "lat": "42.49431",
    "lng": "-3.07446"
  },
  {
    "country": "ES",
    "name": "Torlengua",
    "lat": "41.45483",
    "lng": "-2.16183"
  },
  {
    "country": "ES",
    "name": "Torija",
    "lat": "40.74251",
    "lng": "-3.0283"
  },
  {
    "country": "ES",
    "name": "Toreno",
    "lat": "42.69955",
    "lng": "-6.51236"
  },
  {
    "country": "ES",
    "name": "Torelló",
    "lat": "42.04627",
    "lng": "2.26679"
  },
  {
    "country": "ES",
    "name": "Tordómar",
    "lat": "42.0463",
    "lng": "-3.86514"
  },
  {
    "country": "ES",
    "name": "Tordillos",
    "lat": "40.85266",
    "lng": "-5.35278"
  },
  {
    "country": "ES",
    "name": "Tordesilos",
    "lat": "40.67074",
    "lng": "-1.59372"
  },
  {
    "country": "ES",
    "name": "Tordesillas",
    "lat": "41.50202",
    "lng": "-5.00146"
  },
  {
    "country": "ES",
    "name": "Tordera",
    "lat": "41.69914",
    "lng": "2.71888"
  },
  {
    "country": "ES",
    "name": "Tordelrábano",
    "lat": "41.21827",
    "lng": "-2.75792"
  },
  {
    "country": "ES",
    "name": "Tordellego",
    "lat": "40.72165",
    "lng": "-1.67036"
  },
  {
    "country": "ES",
    "name": "Tordehumos",
    "lat": "41.81531",
    "lng": "-5.15811"
  },
  {
    "country": "ES",
    "name": "Toral de los Guzmanes",
    "lat": "42.24274",
    "lng": "-5.56771"
  },
  {
    "country": "ES",
    "name": "Torà de Riubregós",
    "lat": "41.81667",
    "lng": "1.4"
  },
  {
    "country": "ES",
    "name": "Topas",
    "lat": "41.15759",
    "lng": "-5.63402"
  },
  {
    "country": "ES",
    "name": "Tona",
    "lat": "41.84789",
    "lng": "2.22808"
  },
  {
    "country": "ES",
    "name": "Tomiño",
    "lat": "41.98772",
    "lng": "-8.75502"
  },
  {
    "country": "ES",
    "name": "Tolosa",
    "lat": "43.13484",
    "lng": "-2.07801"
  },
  {
    "country": "ES",
    "name": "Toloriu",
    "lat": "42.3621",
    "lng": "1.62761"
  },
  {
    "country": "ES",
    "name": "Tolocirio",
    "lat": "41.13425",
    "lng": "-4.65121"
  },
  {
    "country": "ES",
    "name": "Tolbaños",
    "lat": "40.75168",
    "lng": "-4.58191"
  },
  {
    "country": "ES",
    "name": "Toga",
    "lat": "40.05",
    "lng": "-0.36667"
  },
  {
    "country": "ES",
    "name": "Toén",
    "lat": "42.31765",
    "lng": "-7.95435"
  },
  {
    "country": "ES",
    "name": "Todolella",
    "lat": "40.64675",
    "lng": "-0.24675"
  },
  {
    "country": "ES",
    "name": "Tobía",
    "lat": "42.29846",
    "lng": "-2.81399"
  },
  {
    "country": "ES",
    "name": "Tobed",
    "lat": "41.33866",
    "lng": "-1.39975"
  },
  {
    "country": "ES",
    "name": "Tobar",
    "lat": "42.48384",
    "lng": "-3.93984"
  },
  {
    "country": "ES",
    "name": "Tivissa",
    "lat": "41.03333",
    "lng": "0.73333"
  },
  {
    "country": "ES",
    "name": "Tivenys",
    "lat": "40.90787",
    "lng": "0.51236"
  },
  {
    "country": "ES",
    "name": "Tiurana",
    "lat": "41.97527",
    "lng": "1.25608"
  },
  {
    "country": "ES",
    "name": "Titulcia",
    "lat": "40.13537",
    "lng": "-3.56763"
  },
  {
    "country": "ES",
    "name": "Tirgo",
    "lat": "42.54587",
    "lng": "-2.9494"
  },
  {
    "country": "ES",
    "name": "Tirapu",
    "lat": "42.6574",
    "lng": "-1.70263"
  },
  {
    "country": "ES",
    "name": "Tiñosillos",
    "lat": "40.934",
    "lng": "-4.72767"
  },
  {
    "country": "ES",
    "name": "Tineo",
    "lat": "43.33765",
    "lng": "-6.41452"
  },
  {
    "country": "ES",
    "name": "Tinajas",
    "lat": "40.32547",
    "lng": "-2.58228"
  },
  {
    "country": "ES",
    "name": "Tierzo",
    "lat": "40.74925",
    "lng": "-1.93069"
  },
  {
    "country": "ES",
    "name": "Tierz",
    "lat": "42.13356",
    "lng": "-0.35489"
  },
  {
    "country": "ES",
    "name": "Tielmes",
    "lat": "40.24652",
    "lng": "-3.31461"
  },
  {
    "country": "ES",
    "name": "Tiedra",
    "lat": "41.65239",
    "lng": "-5.26688"
  },
  {
    "country": "ES",
    "name": "Tiana",
    "lat": "41.48201",
    "lng": "2.26702"
  },
  {
    "country": "ES",
    "name": "Teià",
    "lat": "41.49804",
    "lng": "2.32206"
  },
  {
    "country": "ES",
    "name": "Tetuán de las Victorias",
    "lat": "40.45975",
    "lng": "-3.6975"
  },
  {
    "country": "ES",
    "name": "Terzaga",
    "lat": "40.69508",
    "lng": "-1.90386"
  },
  {
    "country": "ES",
    "name": "Teruel",
    "lat": "40.3456",
    "lng": "-1.10646"
  },
  {
    "country": "ES",
    "name": "Terroba",
    "lat": "42.25809",
    "lng": "-2.44375"
  },
  {
    "country": "ES",
    "name": "Terriente",
    "lat": "40.29741",
    "lng": "-1.50399"
  },
  {
    "country": "ES",
    "name": "Terrer",
    "lat": "41.32811",
    "lng": "-1.71329"
  },
  {
    "country": "ES",
    "name": "Terradillos de Esgueva",
    "lat": "41.81885",
    "lng": "-3.84318"
  },
  {
    "country": "ES",
    "name": "Terradillos",
    "lat": "40.83836",
    "lng": "-5.5416"
  },
  {
    "country": "ES",
    "name": "Terrades",
    "lat": "42.31032",
    "lng": "2.83855"
  },
  {
    "country": "ES",
    "name": "Térmens",
    "lat": "41.71667",
    "lng": "0.76667"
  },
  {
    "country": "ES",
    "name": "Teo",
    "lat": "42.75",
    "lng": "-8.5"
  },
  {
    "country": "ES",
    "name": "Tenebrón",
    "lat": "40.62449",
    "lng": "-6.3545"
  },
  {
    "country": "ES",
    "name": "Tendilla",
    "lat": "40.54379",
    "lng": "-2.95782"
  },
  {
    "country": "ES",
    "name": "Tejeda y Segoyuela",
    "lat": "40.63155",
    "lng": "-6.02311"
  },
  {
    "country": "ES",
    "name": "Tejeda de Tiétar",
    "lat": "40.0179",
    "lng": "-5.86953"
  },
  {
    "country": "ES",
    "name": "Tejado",
    "lat": "41.58887",
    "lng": "-2.26721"
  },
  {
    "country": "ES",
    "name": "Tejadillos",
    "lat": "40.13333",
    "lng": "-1.63333"
  },
  {
    "country": "ES",
    "name": "Tejada",
    "lat": "41.95249",
    "lng": "-3.53514"
  },
  {
    "country": "ES",
    "name": "Tavertet",
    "lat": "41.99572",
    "lng": "2.41859"
  },
  {
    "country": "ES",
    "name": "Tauste",
    "lat": "41.91804",
    "lng": "-1.25343"
  },
  {
    "country": "ES",
    "name": "Tartanedo",
    "lat": "40.99347",
    "lng": "-1.92459"
  },
  {
    "country": "ES",
    "name": "Tàrrega",
    "lat": "41.64704",
    "lng": "1.13957"
  },
  {
    "country": "ES",
    "name": "Terrassa",
    "lat": "41.56667",
    "lng": "2.01667"
  },
  {
    "country": "ES",
    "name": "Tarragona",
    "lat": "41.11667",
    "lng": "1.25"
  },
  {
    "country": "ES",
    "name": "Taroda",
    "lat": "41.34798",
    "lng": "-2.43318"
  },
  {
    "country": "ES",
    "name": "Tardienta",
    "lat": "41.97781",
    "lng": "-0.53731"
  },
  {
    "country": "ES",
    "name": "Tardelcuende",
    "lat": "41.59402",
    "lng": "-2.64439"
  },
  {
    "country": "ES",
    "name": "Tardajos",
    "lat": "42.34909",
    "lng": "-3.817"
  },
  {
    "country": "ES",
    "name": "Tardáguila",
    "lat": "41.11493",
    "lng": "-5.57423"
  },
  {
    "country": "ES",
    "name": "Tarazona de Guareña",
    "lat": "41.17206",
    "lng": "-5.25005"
  },
  {
    "country": "ES",
    "name": "Tarazona",
    "lat": "41.90475",
    "lng": "-1.72678"
  },
  {
    "country": "ES",
    "name": "Taravilla",
    "lat": "40.69743",
    "lng": "-1.96817"
  },
  {
    "country": "ES",
    "name": "Tarancón",
    "lat": "40.00851",
    "lng": "-3.00731"
  },
  {
    "country": "ES",
    "name": "Taramundi",
    "lat": "43.3602",
    "lng": "-7.10828"
  },
  {
    "country": "ES",
    "name": "Taragudo",
    "lat": "40.82106",
    "lng": "-3.0768"
  },
  {
    "country": "ES",
    "name": "Taradell",
    "lat": "41.87495",
    "lng": "2.28662"
  },
  {
    "country": "ES",
    "name": "Tapioles",
    "lat": "41.85741",
    "lng": "-5.49623"
  },
  {
    "country": "ES",
    "name": "Tapia de Casariego",
    "lat": "43.57019",
    "lng": "-6.94383"
  },
  {
    "country": "ES",
    "name": "Tamarón",
    "lat": "42.27386",
    "lng": "-3.99154"
  },
  {
    "country": "ES",
    "name": "Tamariz de Campos",
    "lat": "41.97706",
    "lng": "-5.02335"
  },
  {
    "country": "ES",
    "name": "Tamarit de Llitera / Tamarite de Litera",
    "lat": "41.8691",
    "lng": "0.42214"
  },
  {
    "country": "ES",
    "name": "Tamames",
    "lat": "40.65725",
    "lng": "-6.10536"
  },
  {
    "country": "ES",
    "name": "Tamajón",
    "lat": "40.99914",
    "lng": "-3.24743"
  },
  {
    "country": "ES",
    "name": "Talamantes",
    "lat": "41.73051",
    "lng": "-1.67857"
  },
  {
    "country": "ES",
    "name": "Talamanca de Jarama",
    "lat": "40.74325",
    "lng": "-3.50889"
  },
  {
    "country": "ES",
    "name": "Talamanca",
    "lat": "41.7374",
    "lng": "1.97791"
  },
  {
    "country": "ES",
    "name": "Tajueco",
    "lat": "41.53641",
    "lng": "-2.84845"
  },
  {
    "country": "ES",
    "name": "Tajahuerce",
    "lat": "41.73991",
    "lng": "-2.15069"
  },
  {
    "country": "ES",
    "name": "Tagamanent",
    "lat": "41.73747",
    "lng": "2.2672"
  },
  {
    "country": "ES",
    "name": "Tafalla",
    "lat": "42.52687",
    "lng": "-1.67446"
  },
  {
    "country": "ES",
    "name": "Tabuenca",
    "lat": "41.695",
    "lng": "-1.54335"
  },
  {
    "country": "ES",
    "name": "Taboadela",
    "lat": "42.24234",
    "lng": "-7.82719"
  },
  {
    "country": "ES",
    "name": "Taboada",
    "lat": "42.699",
    "lng": "-7.82298"
  },
  {
    "country": "ES",
    "name": "Tabera de Abajo",
    "lat": "40.91021",
    "lng": "-6.00227"
  },
  {
    "country": "ES",
    "name": "Tábara",
    "lat": "41.82458",
    "lng": "-5.9642"
  },
  {
    "country": "ES",
    "name": "Tabanera la Luenga",
    "lat": "41.09647",
    "lng": "-4.23937"
  },
  {
    "country": "ES",
    "name": "Tabanera de Valdavia",
    "lat": "42.64728",
    "lng": "-4.69414"
  },
  {
    "country": "ES",
    "name": "Tabanera de Cerrato",
    "lat": "42.02469",
    "lng": "-4.12361"
  },
  {
    "country": "ES",
    "name": "Susqueda",
    "lat": "41.97776",
    "lng": "2.51652"
  },
  {
    "country": "ES",
    "name": "Susinos del Páramo",
    "lat": "42.47108",
    "lng": "-3.92555"
  },
  {
    "country": "ES",
    "name": "Súria",
    "lat": "41.83333",
    "lng": "1.75"
  },
  {
    "country": "ES",
    "name": "Sunyer",
    "lat": "41.51667",
    "lng": "0.6"
  },
  {
    "country": "ES",
    "name": "Sunbilla",
    "lat": "43.16667",
    "lng": "-1.66667"
  },
  {
    "country": "ES",
    "name": "Suellacabras",
    "lat": "41.85298",
    "lng": "-2.22398"
  },
  {
    "country": "ES",
    "name": "Subirats",
    "lat": "41.4",
    "lng": "1.83333"
  },
  {
    "country": "ES",
    "name": "Suances",
    "lat": "43.43341",
    "lng": "-4.04338"
  },
  {
    "country": "ES",
    "name": "Sotresgudo",
    "lat": "42.57935",
    "lng": "-4.17725"
  },
  {
    "country": "ES",
    "name": "Sotragero",
    "lat": "42.40996",
    "lng": "-3.71312"
  },
  {
    "country": "ES",
    "name": "Soto y Amío",
    "lat": "42.77477",
    "lng": "-5.88693"
  },
  {
    "country": "ES",
    "name": "Sotoserrano",
    "lat": "40.43499",
    "lng": "-6.03261"
  },
  {
    "country": "ES",
    "name": "Sotosalbos",
    "lat": "41.03537",
    "lng": "-3.94115"
  },
  {
    "country": "ES",
    "name": "Soto en Cameros",
    "lat": "42.28591",
    "lng": "-2.42597"
  },
  {
    "country": "ES",
    "name": "Sotodosos",
    "lat": "40.92149",
    "lng": "-2.39211"
  },
  {
    "country": "ES",
    "name": "Soto del Barco",
    "lat": "43.53288",
    "lng": "-6.06984"
  },
  {
    "country": "ES",
    "name": "Soto de la Vega",
    "lat": "42.33227",
    "lng": "-5.88225"
  },
  {
    "country": "ES",
    "name": "Soto de Cerrato",
    "lat": "41.95312",
    "lng": "-4.42998"
  },
  {
    "country": "ES",
    "name": "Sotobañado y Priorato",
    "lat": "42.58987",
    "lng": "-4.44185"
  },
  {
    "country": "ES",
    "name": "Sotillo del Rincón",
    "lat": "41.9322",
    "lng": "-2.60297"
  },
  {
    "country": "ES",
    "name": "Sotillo de las Palomas",
    "lat": "40.10359",
    "lng": "-4.82736"
  },
  {
    "country": "ES",
    "name": "Sotillo de la Ribera",
    "lat": "41.77717",
    "lng": "-3.82525"
  },
  {
    "country": "ES",
    "name": "Sotillo de la Adrada",
    "lat": "40.2912",
    "lng": "-4.58385"
  },
  {
    "country": "ES",
    "name": "Sotillo",
    "lat": "41.25846",
    "lng": "-3.63729"
  },
  {
    "country": "ES",
    "name": "Sotalbo",
    "lat": "40.5417",
    "lng": "-4.84548"
  },
  {
    "country": "ES",
    "name": "Soses",
    "lat": "41.53333",
    "lng": "0.48333"
  },
  {
    "country": "ES",
    "name": "Sos del Rey Católico",
    "lat": "42.49686",
    "lng": "-1.21514"
  },
  {
    "country": "ES",
    "name": "Sorzano",
    "lat": "42.34307",
    "lng": "-2.52872"
  },
  {
    "country": "ES",
    "name": "Sort",
    "lat": "42.41319",
    "lng": "1.13045"
  },
  {
    "country": "ES",
    "name": "Sorlada",
    "lat": "42.61507",
    "lng": "-2.21525"
  },
  {
    "country": "ES",
    "name": "Sorihuela",
    "lat": "40.44378",
    "lng": "-5.67818"
  },
  {
    "country": "ES",
    "name": "Soria",
    "lat": "41.76401",
    "lng": "-2.46883"
  },
  {
    "country": "ES",
    "name": "Sordillos",
    "lat": "42.46197",
    "lng": "-4.10726"
  },
  {
    "country": "ES",
    "name": "Sora",
    "lat": "42.11236",
    "lng": "2.16083"
  },
  {
    "country": "ES",
    "name": "Sopela",
    "lat": "43.37891",
    "lng": "-2.98313"
  },
  {
    "country": "ES",
    "name": "Porto do Son",
    "lat": "42.72482",
    "lng": "-9.00527"
  },
  {
    "country": "ES",
    "name": "Somozas",
    "lat": "43.53333",
    "lng": "-7.93333"
  },
  {
    "country": "ES",
    "name": "Somosierra",
    "lat": "41.13269",
    "lng": "-3.58237"
  },
  {
    "country": "ES",
    "name": "Somolinos",
    "lat": "41.24606",
    "lng": "-3.06004"
  },
  {
    "country": "ES",
    "name": "Solsona",
    "lat": "41.99395",
    "lng": "1.51706"
  },
  {
    "country": "ES",
    "name": "Solosancho",
    "lat": "40.55294",
    "lng": "-4.90479"
  },
  {
    "country": "ES",
    "name": "Solórzano",
    "lat": "43.38233",
    "lng": "-3.58785"
  },
  {
    "country": "ES",
    "name": "Soliedra",
    "lat": "41.46932",
    "lng": "-2.38164"
  },
  {
    "country": "ES",
    "name": "Solarana",
    "lat": "41.97168",
    "lng": "-3.65876"
  },
  {
    "country": "ES",
    "name": "Solanillos del Extremo",
    "lat": "40.75088",
    "lng": "-2.69799"
  },
  {
    "country": "ES",
    "name": "Sojuela",
    "lat": "42.36988",
    "lng": "-2.54525"
  },
  {
    "country": "ES",
    "name": "Sobrado",
    "lat": "43.03882",
    "lng": "-8.02784"
  },
  {
    "country": "ES",
    "name": "Sobrado",
    "lat": "42.51667",
    "lng": "-6.85"
  },
  {
    "country": "ES",
    "name": "Sobradillo",
    "lat": "40.91754",
    "lng": "-6.79729"
  },
  {
    "country": "ES",
    "name": "Sobradiel",
    "lat": "41.73875",
    "lng": "-1.03765"
  },
  {
    "country": "ES",
    "name": "Sober",
    "lat": "42.46127",
    "lng": "-7.5864"
  },
  {
    "country": "ES",
    "name": "Sitges",
    "lat": "41.23506",
    "lng": "1.81193"
  },
  {
    "country": "ES",
    "name": "Sisamón",
    "lat": "41.17124",
    "lng": "-2.00386"
  },
  {
    "country": "ES",
    "name": "Sinlabajos",
    "lat": "41.0765",
    "lng": "-4.83242"
  },
  {
    "country": "ES",
    "name": "Singra",
    "lat": "40.65508",
    "lng": "-1.31158"
  },
  {
    "country": "ES",
    "name": "Simancas",
    "lat": "41.59072",
    "lng": "-4.82796"
  },
  {
    "country": "ES",
    "name": "Sils",
    "lat": "41.80842",
    "lng": "2.74507"
  },
  {
    "country": "ES",
    "name": "Silleda",
    "lat": "42.69605",
    "lng": "-8.24653"
  },
  {
    "country": "ES",
    "name": "Sigüés",
    "lat": "42.6303",
    "lng": "-1.01212"
  },
  {
    "country": "ES",
    "name": "Sigüenza",
    "lat": "41.06892",
    "lng": "-2.64308"
  },
  {
    "country": "ES",
    "name": "Sigeres",
    "lat": "40.79939",
    "lng": "-4.93361"
  },
  {
    "country": "ES",
    "name": "Siete Iglesias de Trabancos",
    "lat": "41.35223",
    "lng": "-5.18488"
  },
  {
    "country": "ES",
    "name": "Siétamo",
    "lat": "42.12392",
    "lng": "-0.28066"
  },
  {
    "country": "ES",
    "name": "Sierra-Engarcerán",
    "lat": "40.26929",
    "lng": "-0.01892"
  },
  {
    "country": "ES",
    "name": "Sierra de Luna",
    "lat": "42.04818",
    "lng": "-0.91025"
  },
  {
    "country": "ES",
    "name": "Sienes",
    "lat": "41.20096",
    "lng": "-2.65332"
  },
  {
    "country": "ES",
    "name": "Sidamon",
    "lat": "41.63333",
    "lng": "0.83333"
  },
  {
    "country": "ES",
    "name": "Sevilla La Nueva",
    "lat": "40.34775",
    "lng": "-4.02727"
  },
  {
    "country": "ES",
    "name": "Seva",
    "lat": "41.83831",
    "lng": "2.28007"
  },
  {
    "country": "ES",
    "name": "Setiles",
    "lat": "40.73419",
    "lng": "-1.6172"
  },
  {
    "country": "ES",
    "name": "Sesué",
    "lat": "42.55131",
    "lng": "0.47212"
  },
  {
    "country": "ES",
    "name": "Sestrica",
    "lat": "41.48595",
    "lng": "-1.59501"
  },
  {
    "country": "ES",
    "name": "Sestao",
    "lat": "43.30975",
    "lng": "-3.00716"
  },
  {
    "country": "ES",
    "name": "Sesma",
    "lat": "42.47748",
    "lng": "-2.08353"
  },
  {
    "country": "ES",
    "name": "Seseña",
    "lat": "40.10473",
    "lng": "-3.69793"
  },
  {
    "country": "ES",
    "name": "Sesa",
    "lat": "41.99484",
    "lng": "-0.24511"
  },
  {
    "country": "ES",
    "name": "Serranillos del Valle",
    "lat": "40.20211",
    "lng": "-3.88187"
  },
  {
    "country": "ES",
    "name": "Serranillos",
    "lat": "40.33625",
    "lng": "-4.91165"
  },
  {
    "country": "ES",
    "name": "Serradilla del Llano",
    "lat": "40.49996",
    "lng": "-6.35701"
  },
  {
    "country": "ES",
    "name": "Serradilla del Arroyo",
    "lat": "40.52133",
    "lng": "-6.36008"
  },
  {
    "country": "ES",
    "name": "Serra de Daró",
    "lat": "42.02877",
    "lng": "3.07222"
  },
  {
    "country": "ES",
    "name": "Serrada",
    "lat": "41.45722",
    "lng": "-4.86279"
  },
  {
    "country": "ES",
    "name": "Seròs",
    "lat": "41.46667",
    "lng": "0.41667"
  },
  {
    "country": "ES",
    "name": "Sequeros",
    "lat": "40.51295",
    "lng": "-6.02495"
  },
  {
    "country": "ES",
    "name": "Sequera de Fresno",
    "lat": "41.3664",
    "lng": "-3.54612"
  },
  {
    "country": "ES",
    "name": "Sepúlveda",
    "lat": "41.29695",
    "lng": "-3.74221"
  },
  {
    "country": "ES",
    "name": "la Seu d'Urgell",
    "lat": "42.35877",
    "lng": "1.46144"
  },
  {
    "country": "ES",
    "name": "Seno",
    "lat": "40.81225",
    "lng": "-0.33816"
  },
  {
    "country": "ES",
    "name": "Sentmenat",
    "lat": "41.60862",
    "lng": "2.13532"
  },
  {
    "country": "ES",
    "name": "Senés de Alcubierre",
    "lat": "41.90731",
    "lng": "-0.48906"
  },
  {
    "country": "ES",
    "name": "Senan",
    "lat": "41.46994",
    "lng": "1.08541"
  },
  {
    "country": "ES",
    "name": "Sena de Luna",
    "lat": "42.92906",
    "lng": "-5.95267"
  },
  {
    "country": "ES",
    "name": "Semillas",
    "lat": "41.05857",
    "lng": "-3.11945"
  },
  {
    "country": "ES",
    "name": "Selaya",
    "lat": "43.21376",
    "lng": "-3.80563"
  },
  {
    "country": "ES",
    "name": "Selas",
    "lat": "40.9515",
    "lng": "-2.10203"
  },
  {
    "country": "ES",
    "name": "Seira",
    "lat": "42.47696",
    "lng": "0.43127"
  },
  {
    "country": "ES",
    "name": "Segurilla",
    "lat": "40.02386",
    "lng": "-4.86418"
  },
  {
    "country": "ES",
    "name": "Segura de Toro",
    "lat": "40.22427",
    "lng": "-5.94836"
  },
  {
    "country": "ES",
    "name": "Segura de los Baños",
    "lat": "40.94088",
    "lng": "-0.95111"
  },
  {
    "country": "ES",
    "name": "Segura",
    "lat": "43.00753",
    "lng": "-2.254"
  },
  {
    "country": "ES",
    "name": "Segovia",
    "lat": "40.94808",
    "lng": "-4.11839"
  },
  {
    "country": "ES",
    "name": "Sediles",
    "lat": "41.34613",
    "lng": "-1.53177"
  },
  {
    "country": "ES",
    "name": "Secastilla",
    "lat": "42.18112",
    "lng": "0.26736"
  },
  {
    "country": "ES",
    "name": "Sebúlcor",
    "lat": "41.27091",
    "lng": "-3.88398"
  },
  {
    "country": "ES",
    "name": "Sayatón",
    "lat": "40.37635",
    "lng": "-2.85253"
  },
  {
    "country": "ES",
    "name": "Sauquillo de Cabezas",
    "lat": "41.19422",
    "lng": "-4.06884"
  },
  {
    "country": "ES",
    "name": "Saucelle",
    "lat": "41.04769",
    "lng": "-6.75328"
  },
  {
    "country": "ES",
    "name": "Saúca",
    "lat": "41.03098",
    "lng": "-2.52905"
  },
  {
    "country": "ES",
    "name": "Sástago",
    "lat": "41.32166",
    "lng": "-0.35075"
  },
  {
    "country": "ES",
    "name": "Sasamón",
    "lat": "42.41687",
    "lng": "-4.04288"
  },
  {
    "country": "ES",
    "name": "Sartajada",
    "lat": "40.2132",
    "lng": "-4.79427"
  },
  {
    "country": "ES",
    "name": "Sartaguda",
    "lat": "42.38333",
    "lng": "-2.05709"
  },
  {
    "country": "ES",
    "name": "Sarrión",
    "lat": "40.14175",
    "lng": "-0.81533"
  },
  {
    "country": "ES",
    "name": "Sarrià de Ter",
    "lat": "42.01667",
    "lng": "2.83333"
  },
  {
    "country": "ES",
    "name": "Sarria",
    "lat": "42.78148",
    "lng": "-7.41431"
  },
  {
    "country": "ES",
    "name": "Sarreaus",
    "lat": "42.08784",
    "lng": "-7.60348"
  },
  {
    "country": "ES",
    "name": "Sarratella",
    "lat": "40.31284",
    "lng": "0.0315"
  },
  {
    "country": "ES",
    "name": "Sarracín",
    "lat": "42.25813",
    "lng": "-3.68608"
  },
  {
    "country": "ES",
    "name": "Saro",
    "lat": "43.25961",
    "lng": "-3.84283"
  },
  {
    "country": "ES",
    "name": "Sariñena",
    "lat": "41.79128",
    "lng": "-0.15804"
  },
  {
    "country": "ES",
    "name": "Sariegos",
    "lat": "42.65",
    "lng": "-5.63333"
  },
  {
    "country": "ES",
    "name": "Sariego",
    "lat": "43.4",
    "lng": "-5.53333"
  },
  {
    "country": "ES",
    "name": "Sargentes de la Lora",
    "lat": "42.76917",
    "lng": "-3.87278"
  },
  {
    "country": "ES",
    "name": "Sardón de los Frailes",
    "lat": "41.21373",
    "lng": "-6.27101"
  },
  {
    "country": "ES",
    "name": "Sardón de Duero",
    "lat": "41.60847",
    "lng": "-4.43397"
  },
  {
    "country": "ES",
    "name": "Cerdanyola del Vallès",
    "lat": "41.49109",
    "lng": "2.14079"
  },
  {
    "country": "ES",
    "name": "Sanzoles",
    "lat": "41.43235",
    "lng": "-5.5671"
  },
  {
    "country": "ES",
    "name": "San Vitero",
    "lat": "41.7774",
    "lng": "-6.34877"
  },
  {
    "country": "ES",
    "name": "Sant Vicenç de Montalt",
    "lat": "41.57853",
    "lng": "2.50879"
  },
  {
    "country": "ES",
    "name": "San Vicente del Valle",
    "lat": "42.33756",
    "lng": "-3.1621"
  },
  {
    "country": "ES",
    "name": "Sant Vicenç dels Horts",
    "lat": "41.39317",
    "lng": "2.00689"
  },
  {
    "country": "ES",
    "name": "San Vicente del Palacio",
    "lat": "41.21901",
    "lng": "-4.85158"
  },
  {
    "country": "ES",
    "name": "San Vicente de la Sonsierra",
    "lat": "42.56321",
    "lng": "-2.76071"
  },
  {
    "country": "ES",
    "name": "San Vicente de la Cabeza",
    "lat": "41.80696",
    "lng": "-6.24993"
  },
  {
    "country": "ES",
    "name": "San Vicente de la Barquera",
    "lat": "43.38509",
    "lng": "-4.39934"
  },
  {
    "country": "ES",
    "name": "Sant Vicenç de Castellet",
    "lat": "41.66667",
    "lng": "1.86667"
  },
  {
    "country": "ES",
    "name": "Barakaldo",
    "lat": "43.29639",
    "lng": "-2.98813"
  },
  {
    "country": "ES",
    "name": "San Vicente de Arévalo",
    "lat": "40.96773",
    "lng": "-4.80194"
  },
  {
    "country": "ES",
    "name": "Santurdejo",
    "lat": "42.37696",
    "lng": "-2.95437"
  },
  {
    "country": "ES",
    "name": "Santurtzi",
    "lat": "43.32842",
    "lng": "-3.03248"
  },
  {
    "country": "ES",
    "name": "Sants",
    "lat": "41.37426",
    "lng": "2.13826"
  },
  {
    "country": "ES",
    "name": "Santoyo",
    "lat": "42.21473",
    "lng": "-4.34296"
  },
  {
    "country": "ES",
    "name": "Santovenia de Pisuerga",
    "lat": "41.69457",
    "lng": "-4.69029"
  },
  {
    "country": "ES",
    "name": "Santovenia",
    "lat": "41.87857",
    "lng": "-5.71003"
  },
  {
    "country": "ES",
    "name": "Santo Tomé de Zabarcos",
    "lat": "40.78726",
    "lng": "-4.91048"
  },
  {
    "country": "ES",
    "name": "San Torcuato",
    "lat": "42.48219",
    "lng": "-2.88923"
  },
  {
    "country": "ES",
    "name": "Santorcaz",
    "lat": "40.47176",
    "lng": "-3.23462"
  },
  {
    "country": "ES",
    "name": "Santoña",
    "lat": "43.44386",
    "lng": "-3.45757"
  },
  {
    "country": "ES",
    "name": "Santo Domingo de Silos",
    "lat": "41.964",
    "lng": "-3.4174"
  },
  {
    "country": "ES",
    "name": "Santo Domingo de Pirón",
    "lat": "41.04104",
    "lng": "-3.98933"
  },
  {
    "country": "ES",
    "name": "Santo Domingo de las Posadas",
    "lat": "40.812",
    "lng": "-4.63383"
  },
  {
    "country": "ES",
    "name": "Santo Domingo de la Calzada",
    "lat": "42.44015",
    "lng": "-2.95365"
  },
  {
    "country": "ES",
    "name": "Sant Just Desvern",
    "lat": "41.38389",
    "lng": "2.06758"
  },
  {
    "country": "ES",
    "name": "Sant Julià de Vilatorta",
    "lat": "41.92189",
    "lng": "2.32447"
  },
  {
    "country": "ES",
    "name": "Sant Joan les Fonts",
    "lat": "42.21186",
    "lng": "2.51291"
  },
  {
    "country": "ES",
    "name": "Sant Joan de Vilatorrada",
    "lat": "41.74549",
    "lng": "1.80476"
  },
  {
    "country": "ES",
    "name": "Santiz",
    "lat": "41.20579",
    "lng": "-5.89654"
  },
  {
    "country": "ES",
    "name": "Santiuste de San Juan Bautista",
    "lat": "41.15593",
    "lng": "-4.57202"
  },
  {
    "country": "ES",
    "name": "Santiuste",
    "lat": "41.08462",
    "lng": "-2.80953"
  },
  {
    "country": "ES",
    "name": "Santiurde de Toranzo",
    "lat": "43.23819",
    "lng": "-3.93947"
  },
  {
    "country": "ES",
    "name": "Santiurde de Reinosa",
    "lat": "43.06144",
    "lng": "-4.08351"
  },
  {
    "country": "ES",
    "name": "Santiso",
    "lat": "42.87388",
    "lng": "-8.05497"
  },
  {
    "country": "ES",
    "name": "Santillana",
    "lat": "43.38903",
    "lng": "-4.10844"
  },
  {
    "country": "ES",
    "name": "Santibáñez el Bajo",
    "lat": "40.17637",
    "lng": "-6.22441"
  },
  {
    "country": "ES",
    "name": "Santibáñez el Alto",
    "lat": "40.18525",
    "lng": "-6.54782"
  },
  {
    "country": "ES",
    "name": "Santibáñez de Vidriales",
    "lat": "42.07362",
    "lng": "-6.01549"
  },
  {
    "country": "ES",
    "name": "Santibáñez de Valcorba",
    "lat": "41.56983",
    "lng": "-4.44938"
  },
  {
    "country": "ES",
    "name": "Santibáñez de Tera",
    "lat": "41.98563",
    "lng": "-5.92257"
  },
  {
    "country": "ES",
    "name": "Santibáñez del Val",
    "lat": "41.97354",
    "lng": "-3.48142"
  },
  {
    "country": "ES",
    "name": "Santibáñez de la Sierra",
    "lat": "40.49464",
    "lng": "-5.91576"
  },
  {
    "country": "ES",
    "name": "Santibáñez de la Peña",
    "lat": "42.80929",
    "lng": "-4.73026"
  },
  {
    "country": "ES",
    "name": "Santibáñez de Ecla",
    "lat": "42.70784",
    "lng": "-4.37263"
  },
  {
    "country": "ES",
    "name": "Santibáñez de Béjar",
    "lat": "40.48785",
    "lng": "-5.6111"
  },
  {
    "country": "ES",
    "name": "Santiago Millas",
    "lat": "42.38379",
    "lng": "-6.10538"
  },
  {
    "country": "ES",
    "name": "Santiago del Collado",
    "lat": "40.43326",
    "lng": "-5.35631"
  },
  {
    "country": "ES",
    "name": "Santiago de la Puebla",
    "lat": "40.80132",
    "lng": "-5.28073"
  },
  {
    "country": "ES",
    "name": "Santiago de Compostela",
    "lat": "42.88052",
    "lng": "-8.54569"
  },
  {
    "country": "ES",
    "name": "Doneztebe",
    "lat": "43.13333",
    "lng": "-1.66667"
  },
  {
    "country": "ES",
    "name": "Santervás de la Vega",
    "lat": "42.50677",
    "lng": "-4.80002"
  },
  {
    "country": "ES",
    "name": "Santervás de Campos",
    "lat": "42.2182",
    "lng": "-5.10027"
  },
  {
    "country": "ES",
    "name": "Santed",
    "lat": "41.03172",
    "lng": "-1.51028"
  },
  {
    "country": "ES",
    "name": "Santa Susanna",
    "lat": "41.63333",
    "lng": "2.71667"
  },
  {
    "country": "ES",
    "name": "Santas Martas",
    "lat": "42.4322",
    "lng": "-5.37066"
  },
  {
    "country": "ES",
    "name": "Santa Perpètua de Mogoda",
    "lat": "41.53333",
    "lng": "2.18333"
  },
  {
    "country": "ES",
    "name": "Santa Pau",
    "lat": "42.1443",
    "lng": "2.57123"
  },
  {
    "country": "ES",
    "name": "Santa Oliva",
    "lat": "41.25357",
    "lng": "1.55086"
  },
  {
    "country": "ES",
    "name": "Santa Olalla de Bureba",
    "lat": "42.47721",
    "lng": "-3.44109"
  },
  {
    "country": "ES",
    "name": "Santa Olalla",
    "lat": "40.02348",
    "lng": "-4.43025"
  },
  {
    "country": "ES",
    "name": "Sant Aniol de Finestres",
    "lat": "42.09023",
    "lng": "2.58688"
  },
  {
    "country": "ES",
    "name": "Santander",
    "lat": "43.46472",
    "lng": "-3.80444"
  },
  {
    "country": "ES",
    "name": "Santa Marta de Tormes",
    "lat": "40.95065",
    "lng": "-5.62723"
  },
  {
    "country": "ES",
    "name": "Santa Marta de Ortigueira",
    "lat": "43.68333",
    "lng": "-7.85"
  },
  {
    "country": "ES",
    "name": "Santa Marta del Cerro",
    "lat": "41.21843",
    "lng": "-3.68582"
  },
  {
    "country": "ES",
    "name": "Santa Marina del Rey",
    "lat": "42.51334",
    "lng": "-5.86065"
  },
  {
    "country": "ES",
    "name": "Santa María la Real de Nieva",
    "lat": "41.06998",
    "lng": "-4.40709"
  },
  {
    "country": "ES",
    "name": "Santa María de Valverde",
    "lat": "41.93479",
    "lng": "-5.9356"
  },
  {
    "country": "ES",
    "name": "Santa María de Sando",
    "lat": "40.97909",
    "lng": "-6.12904"
  },
  {
    "country": "ES",
    "name": "Santa Maria de Palautordera",
    "lat": "41.7",
    "lng": "2.45"
  },
  {
    "country": "ES",
    "name": "Santa María de Ordás",
    "lat": "42.72653",
    "lng": "-5.82301"
  },
  {
    "country": "ES",
    "name": "Santa Maria d'Oló",
    "lat": "41.86667",
    "lng": "2.03333"
  },
  {
    "country": "ES",
    "name": "Santa María del Val",
    "lat": "40.50439",
    "lng": "-2.04115"
  },
  {
    "country": "ES",
    "name": "Santa María del Páramo",
    "lat": "42.35512",
    "lng": "-5.75151"
  },
  {
    "country": "ES",
    "name": "Santa María de los Caballeros",
    "lat": "40.38925",
    "lng": "-5.45112"
  },
  {
    "country": "ES",
    "name": "Santa María del Monte de Cea",
    "lat": "42.49137",
    "lng": "-5.11689"
  },
  {
    "country": "ES",
    "name": "Santa María del Invierno",
    "lat": "42.44288",
    "lng": "-3.43782"
  },
  {
    "country": "ES",
    "name": "Santa María del Campo",
    "lat": "42.13304",
    "lng": "-3.97283"
  },
  {
    "country": "ES",
    "name": "Santa María del Berrocal",
    "lat": "40.50845",
    "lng": "-5.40483"
  },
  {
    "country": "ES",
    "name": "Santa María de la Vega",
    "lat": "42.08497",
    "lng": "-5.80851"
  },
  {
    "country": "ES",
    "name": "Santa María de las Hoyas",
    "lat": "41.77145",
    "lng": "-3.14172"
  },
  {
    "country": "ES",
    "name": "Santa María de la Isla",
    "lat": "42.35533",
    "lng": "-5.9287"
  },
  {
    "country": "ES",
    "name": "Santa María de la Alameda",
    "lat": "40.59492",
    "lng": "-4.25772"
  },
  {
    "country": "ES",
    "name": "Santa María de Huerta",
    "lat": "41.26667",
    "lng": "-2.16667"
  },
  {
    "country": "ES",
    "name": "Santa Maria de Corcó",
    "lat": "42.03333",
    "lng": "2.36667"
  },
  {
    "country": "ES",
    "name": "Santa María de Cayón",
    "lat": "43.30849",
    "lng": "-3.8368"
  },
  {
    "country": "ES",
    "name": "Barberà del Vallès",
    "lat": "41.5159",
    "lng": "2.12457"
  },
  {
    "country": "ES",
    "name": "Santa Magdalena de Pulpis",
    "lat": "40.35625",
    "lng": "0.30258"
  },
  {
    "country": "ES",
    "name": "Santa Inés",
    "lat": "42.04013",
    "lng": "-3.70322"
  },
  {
    "country": "ES",
    "name": "Santa Gadea del Cid",
    "lat": "42.71531",
    "lng": "-3.05885"
  },
  {
    "country": "ES",
    "name": "Santa Eulàlia de Ronçana",
    "lat": "41.65",
    "lng": "2.23333"
  },
  {
    "country": "ES",
    "name": "Santa Eulalia de Oscos",
    "lat": "43.2595",
    "lng": "-7.01895"
  },
  {
    "country": "ES",
    "name": "Santa Eulalia de Gállego",
    "lat": "42.287",
    "lng": "-0.76065"
  },
  {
    "country": "ES",
    "name": "Santa Eulalia Bajera",
    "lat": "42.2096",
    "lng": "-2.19174"
  },
  {
    "country": "ES",
    "name": "Santa Eulalia",
    "lat": "43.41621",
    "lng": "-5.41128"
  },
  {
    "country": "ES",
    "name": "Santa Eulalia",
    "lat": "40.56742",
    "lng": "-1.31354"
  },
  {
    "country": "ES",
    "name": "Santa Eugènia de Berga",
    "lat": "41.9",
    "lng": "2.28333"
  },
  {
    "country": "ES",
    "name": "Santa Eufemia del Barco",
    "lat": "41.67808",
    "lng": "-5.89831"
  },
  {
    "country": "ES",
    "name": "Santa Eufemia del Arroyo",
    "lat": "41.89505",
    "lng": "-5.26575"
  },
  {
    "country": "ES",
    "name": "Santa Elena de Jamuz",
    "lat": "42.26064",
    "lng": "-5.88762"
  },
  {
    "country": "ES",
    "name": "Santa Cruz de Yanguas",
    "lat": "42.0625",
    "lng": "-2.44894"
  },
  {
    "country": "ES",
    "name": "Santa Cruz de Pinares",
    "lat": "40.54265",
    "lng": "-4.58036"
  },
  {
    "country": "ES",
    "name": "Santa Cruz de Paniagua",
    "lat": "40.19167",
    "lng": "-6.34003"
  },
  {
    "country": "ES",
    "name": "Santa Cruz de Nogueras",
    "lat": "41.11475",
    "lng": "-1.08933"
  },
  {
    "country": "ES",
    "name": "Santa Cruz de Moncayo",
    "lat": "41.8824",
    "lng": "-1.75637"
  },
  {
    "country": "ES",
    "name": "Santa Cruz del Valle Urbión",
    "lat": "42.30558",
    "lng": "-3.2214"
  },
  {
    "country": "ES",
    "name": "Santa Cruz del Valle",
    "lat": "40.2516",
    "lng": "-5.00133"
  },
  {
    "country": "ES",
    "name": "Santa Cruz del Retamar",
    "lat": "40.11917",
    "lng": "-4.24158"
  },
  {
    "country": "ES",
    "name": "Santa Cruz de la Serós",
    "lat": "42.52271",
    "lng": "-0.67515"
  },
  {
    "country": "ES",
    "name": "Santa Cruz de la Salceda",
    "lat": "41.59591",
    "lng": "-3.59317"
  },
  {
    "country": "ES",
    "name": "Santa Cruz de Grío",
    "lat": "41.3705",
    "lng": "-1.43009"
  },
  {
    "country": "ES",
    "name": "Santa Cruz de Boedo",
    "lat": "42.52531",
    "lng": "-4.37398"
  },
  {
    "country": "ES",
    "name": "Santa Cruz de Bezana",
    "lat": "43.4437",
    "lng": "-3.90324"
  },
  {
    "country": "ES",
    "name": "Santa Croya de Tera",
    "lat": "41.98334",
    "lng": "-5.97725"
  },
  {
    "country": "ES",
    "name": "Santa Cristina de Valmadrigal",
    "lat": "42.35446",
    "lng": "-5.30929"
  },
  {
    "country": "ES",
    "name": "Santa Cristina de la Polvorosa",
    "lat": "41.99985",
    "lng": "-5.71355"
  },
  {
    "country": "ES",
    "name": "Santa Cristina d'Aro",
    "lat": "41.81667",
    "lng": "3"
  },
  {
    "country": "ES",
    "name": "Santa Comba",
    "lat": "43.03306",
    "lng": "-8.80925"
  },
  {
    "country": "ES",
    "name": "Santa Colomba de Somoza",
    "lat": "42.44466",
    "lng": "-6.24483"
  },
  {
    "country": "ES",
    "name": "Santa Colomba de las Monjas",
    "lat": "41.95833",
    "lng": "-5.68389"
  },
  {
    "country": "ES",
    "name": "Santa Colomba de Curueño",
    "lat": "42.75058",
    "lng": "-5.41201"
  },
  {
    "country": "ES",
    "name": "Santa Coloma de Queralt",
    "lat": "41.53333",
    "lng": "1.38333"
  },
  {
    "country": "ES",
    "name": "Santa Coloma de Gramenet",
    "lat": "41.45152",
    "lng": "2.2081"
  },
  {
    "country": "ES",
    "name": "Santa Coloma de Farners",
    "lat": "41.86667",
    "lng": "2.66667"
  },
  {
    "country": "ES",
    "name": "Santa Coloma de Cervelló",
    "lat": "41.36736",
    "lng": "2.01426"
  },
  {
    "country": "ES",
    "name": "Santa Coloma",
    "lat": "42.36717",
    "lng": "-2.65598"
  },
  {
    "country": "ES",
    "name": "Santa Clara de Avedillo",
    "lat": "41.33877",
    "lng": "-5.67692"
  },
  {
    "country": "ES",
    "name": "Santa Cecília de Voltregà",
    "lat": "42",
    "lng": "2.23333"
  },
  {
    "country": "ES",
    "name": "Santa Cecilia del Alcor",
    "lat": "41.93227",
    "lng": "-4.65546"
  },
  {
    "country": "ES",
    "name": "Santa Cecilia",
    "lat": "42.05225",
    "lng": "-3.80345"
  },
  {
    "country": "ES",
    "name": "Santacara",
    "lat": "42.36667",
    "lng": "-1.63333"
  },
  {
    "country": "ES",
    "name": "Santa Bárbara",
    "lat": "40.71542",
    "lng": "0.49292"
  },
  {
    "country": "ES",
    "name": "Sansol",
    "lat": "42.55362",
    "lng": "-2.26676"
  },
  {
    "country": "ES",
    "name": "San Sebastián de los Reyes",
    "lat": "40.55555",
    "lng": "-3.62733"
  },
  {
    "country": "ES",
    "name": "Donostia / San Sebastián",
    "lat": "43.31283",
    "lng": "-1.97499"
  },
  {
    "country": "ES",
    "name": "San Sadurniño",
    "lat": "43.53333",
    "lng": "-8.06667"
  },
  {
    "country": "ES",
    "name": "San Salvador",
    "lat": "41.6206",
    "lng": "-5.08713"
  },
  {
    "country": "ES",
    "name": "Sant Sadurní d'Anoia",
    "lat": "41.42555",
    "lng": "1.78519"
  },
  {
    "country": "ES",
    "name": "San Román de la Cuba",
    "lat": "42.26257",
    "lng": "-4.85724"
  },
  {
    "country": "ES",
    "name": "San Román de Hornija",
    "lat": "41.48131",
    "lng": "-5.28454"
  },
  {
    "country": "ES",
    "name": "San Román de Cameros",
    "lat": "42.23255",
    "lng": "-2.47436"
  },
  {
    "country": "ES",
    "name": "San Román",
    "lat": "42.86932",
    "lng": "-7.06261"
  },
  {
    "country": "ES",
    "name": "Sant Quirze Safaja",
    "lat": "41.73333",
    "lng": "2.15"
  },
  {
    "country": "ES",
    "name": "Sant Quirze del Vallès",
    "lat": "41.53333",
    "lng": "2.08333"
  },
  {
    "country": "ES",
    "name": "Sant Pol de Mar",
    "lat": "41.60177",
    "lng": "2.61741"
  },
  {
    "country": "ES",
    "name": "San Pelayo de Guareña",
    "lat": "41.11579",
    "lng": "-5.85702"
  },
  {
    "country": "ES",
    "name": "San Pelayo",
    "lat": "41.68033",
    "lng": "-5.03403"
  },
  {
    "country": "ES",
    "name": "Sant Pere Pescador",
    "lat": "42.18812",
    "lng": "3.08212"
  },
  {
    "country": "ES",
    "name": "San Pedro Palmiches",
    "lat": "40.42956",
    "lng": "-2.40602"
  },
  {
    "country": "ES",
    "name": "San Pedro Manrique",
    "lat": "42.0286",
    "lng": "-2.23104"
  },
  {
    "country": "ES",
    "name": "Sant Pere de Vilamajor",
    "lat": "41.68333",
    "lng": "2.38333"
  },
  {
    "country": "ES",
    "name": "San Pedro de Rozados",
    "lat": "40.79008",
    "lng": "-5.73716"
  },
  {
    "country": "ES",
    "name": "Sant Pere de Riudebitlles",
    "lat": "41.45",
    "lng": "1.7"
  },
  {
    "country": "ES",
    "name": "Sant Pere de Ribes",
    "lat": "41.26045",
    "lng": "1.77391"
  },
  {
    "country": "ES",
    "name": "San Pedro del Valle",
    "lat": "41.03332",
    "lng": "-5.86025"
  },
  {
    "country": "ES",
    "name": "San Pedro del Romeral",
    "lat": "43.11514",
    "lng": "-3.8186"
  },
  {
    "country": "ES",
    "name": "San Pedro de Latarce",
    "lat": "41.73556",
    "lng": "-5.32592"
  },
  {
    "country": "ES",
    "name": "San Pedro del Arroyo",
    "lat": "40.80213",
    "lng": "-4.87075"
  },
  {
    "country": "ES",
    "name": "San Pedro de Gaíllos",
    "lat": "41.22662",
    "lng": "-3.80921"
  },
  {
    "country": "ES",
    "name": "San Pedro de Ceque",
    "lat": "42.04334",
    "lng": "-6.07242"
  },
  {
    "country": "ES",
    "name": "San Pedro Bercianos",
    "lat": "42.39145",
    "lng": "-5.71341"
  },
  {
    "country": "ES",
    "name": "San Pascual",
    "lat": "40.88141",
    "lng": "-4.75612"
  },
  {
    "country": "ES",
    "name": "San Pablo de la Moraleja",
    "lat": "41.161",
    "lng": "-4.77761"
  },
  {
    "country": "ES",
    "name": "San Muñoz",
    "lat": "40.78334",
    "lng": "-6.12758"
  },
  {
    "country": "ES",
    "name": "Sant Mori",
    "lat": "42.1559",
    "lng": "2.98946"
  },
  {
    "country": "ES",
    "name": "San Morales",
    "lat": "40.99358",
    "lng": "-5.50234"
  },
  {
    "country": "ES",
    "name": "San Millán de Yécora",
    "lat": "42.54705",
    "lng": "-3.09681"
  },
  {
    "country": "ES",
    "name": "San Millán de los Caballeros",
    "lat": "42.2852",
    "lng": "-5.56107"
  },
  {
    "country": "ES",
    "name": "San Millán de Lara",
    "lat": "42.13621",
    "lng": "-3.34515"
  },
  {
    "country": "ES",
    "name": "San Millán de la Cogolla",
    "lat": "42.32974",
    "lng": "-2.86185"
  },
  {
    "country": "ES",
    "name": "San Miguel de Valero",
    "lat": "40.54361",
    "lng": "-5.9228"
  },
  {
    "country": "ES",
    "name": "San Miguel de Serrezuela",
    "lat": "40.67064",
    "lng": "-5.28857"
  },
  {
    "country": "ES",
    "name": "San Miguel de Meruelo",
    "lat": "43.46211",
    "lng": "-3.58877"
  },
  {
    "country": "ES",
    "name": "San Miguel del Pino",
    "lat": "41.50941",
    "lng": "-4.91149"
  },
  {
    "country": "ES",
    "name": "San Miguel del Arroyo",
    "lat": "41.44328",
    "lng": "-4.4599"
  },
  {
    "country": "ES",
    "name": "San Miguel de la Ribera",
    "lat": "41.33301",
    "lng": "-5.57689"
  },
  {
    "country": "ES",
    "name": "Sant Miquel de Fluvià",
    "lat": "42.172",
    "lng": "2.99259"
  },
  {
    "country": "ES",
    "name": "San Miguel de Corneja",
    "lat": "40.48722",
    "lng": "-5.28654"
  },
  {
    "country": "ES",
    "name": "Sant Miquel de Campmajor",
    "lat": "42.13333",
    "lng": "2.68333"
  },
  {
    "country": "ES",
    "name": "San Miguel de Aguayo",
    "lat": "43.05383",
    "lng": "-4.0255"
  },
  {
    "country": "ES",
    "name": "San Mateo de Gállego",
    "lat": "41.83043",
    "lng": "-0.76578"
  },
  {
    "country": "ES",
    "name": "Sant Martí Vell",
    "lat": "42.01667",
    "lng": "2.93333"
  },
  {
    "country": "ES",
    "name": "Sant Martí Sarroca",
    "lat": "41.38576",
    "lng": "1.61121"
  },
  {
    "country": "ES",
    "name": "San Martín de Valvení",
    "lat": "41.75336",
    "lng": "-4.56724"
  },
  {
    "country": "ES",
    "name": "San Martín de Valderaduey",
    "lat": "41.81414",
    "lng": "-5.47249"
  },
  {
    "country": "ES",
    "name": "San Martín de Valdeiglesias",
    "lat": "40.36185",
    "lng": "-4.39831"
  },
  {
    "country": "ES",
    "name": "San Martín de Unx",
    "lat": "42.52473",
    "lng": "-1.56091"
  },
  {
    "country": "ES",
    "name": "San Martín de Trevejo",
    "lat": "40.21241",
    "lng": "-6.79535"
  },
  {
    "country": "ES",
    "name": "Sant Martí de Tous",
    "lat": "41.55",
    "lng": "1.51667"
  },
  {
    "country": "ES",
    "name": "San Martín de Rubiales",
    "lat": "41.64191",
    "lng": "-3.99134"
  },
  {
    "country": "ES",
    "name": "San Martín de Oscos",
    "lat": "43.26587",
    "lng": "-6.96241"
  },
  {
    "country": "ES",
    "name": "San Martín del Río",
    "lat": "41.06633",
    "lng": "-1.38733"
  },
  {
    "country": "ES",
    "name": "San Martín del Pimpollar",
    "lat": "40.3683",
    "lng": "-5.05443"
  },
  {
    "country": "ES",
    "name": "San Martín del Castañar",
    "lat": "40.52264",
    "lng": "-6.06387"
  },
  {
    "country": "ES",
    "name": "San Martín de la Vega del Alberche",
    "lat": "40.43053",
    "lng": "-5.155"
  },
  {
    "country": "ES",
    "name": "San Martín de la Vega",
    "lat": "40.20735",
    "lng": "-3.57063"
  },
  {
    "country": "ES",
    "name": "San Martín de Elines",
    "lat": "42.82864",
    "lng": "-3.86865"
  },
  {
    "country": "ES",
    "name": "Sant Martí de Centelles",
    "lat": "41.76617",
    "lng": "2.20566"
  },
  {
    "country": "ES",
    "name": "San Mamés de Campos",
    "lat": "42.35512",
    "lng": "-4.56565"
  },
  {
    "country": "ES",
    "name": "San Mamés de Burgos",
    "lat": "42.33685",
    "lng": "-3.79397"
  },
  {
    "country": "ES",
    "name": "San Lorenzo de Tormes",
    "lat": "40.36984",
    "lng": "-5.48848"
  },
  {
    "country": "ES",
    "name": "Sant Llorenç de la Muga",
    "lat": "42.31976",
    "lng": "2.78888"
  },
  {
    "country": "ES",
    "name": "Sant Llorenç d'Hortons",
    "lat": "41.46667",
    "lng": "1.83333"
  },
  {
    "country": "ES",
    "name": "San Lorenzo de El Escorial",
    "lat": "40.59144",
    "lng": "-4.14738"
  },
  {
    "country": "ES",
    "name": "San Llorente",
    "lat": "41.68631",
    "lng": "-4.066"
  },
  {
    "country": "ES",
    "name": "San Leonardo de Yagüe",
    "lat": "41.83034",
    "lng": "-3.0688"
  },
  {
    "country": "ES",
    "name": "San Justo de la Vega",
    "lat": "42.45696",
    "lng": "-6.01825"
  },
  {
    "country": "ES",
    "name": "San Justo",
    "lat": "42.13321",
    "lng": "-6.62388"
  },
  {
    "country": "ES",
    "name": "San Julián de Muskiz",
    "lat": "43.33333",
    "lng": "-3.1"
  },
  {
    "country": "ES",
    "name": "Sant Julià de Cerdanyola",
    "lat": "42.2235",
    "lng": "1.89308"
  },
  {
    "country": "ES",
    "name": "Vilassar de Mar",
    "lat": "41.50507",
    "lng": "2.39227"
  },
  {
    "country": "ES",
    "name": "Sant Joan Despí",
    "lat": "41.36718",
    "lng": "2.0574"
  },
  {
    "country": "ES",
    "name": "San Juan de Moró",
    "lat": "40.0599",
    "lng": "-0.13691"
  },
  {
    "country": "ES",
    "name": "Sant Joan de Mollet",
    "lat": "42.05",
    "lng": "2.95"
  },
  {
    "country": "ES",
    "name": "San Juan del Monte",
    "lat": "41.68313",
    "lng": "-3.52337"
  },
  {
    "country": "ES",
    "name": "San Juan del Molinillo",
    "lat": "40.45909",
    "lng": "-4.81711"
  },
  {
    "country": "ES",
    "name": "Sant Joan de les Abadesses",
    "lat": "42.23332",
    "lng": "2.28524"
  },
  {
    "country": "ES",
    "name": "San Juan de la Nava",
    "lat": "40.4788",
    "lng": "-4.68238"
  },
  {
    "country": "ES",
    "name": "San Juan de la Encinilla",
    "lat": "40.8302",
    "lng": "-4.83957"
  },
  {
    "country": "ES",
    "name": "Sant Jordi",
    "lat": "40.50982",
    "lng": "0.33208"
  },
  {
    "country": "ES",
    "name": "Sant Jordi Desvalls",
    "lat": "42.06667",
    "lng": "2.95"
  },
  {
    "country": "ES",
    "name": "Sant Jaume dels Domenys",
    "lat": "41.3",
    "lng": "1.56667"
  },
  {
    "country": "ES",
    "name": "San Ildefonso",
    "lat": "40.90182",
    "lng": "-4.00685"
  },
  {
    "country": "ES",
    "name": "Sant Hilari Sacalm",
    "lat": "41.88333",
    "lng": "2.51667"
  },
  {
    "country": "ES",
    "name": "Sangüesa/Zangoza",
    "lat": "42.57483",
    "lng": "-1.28283"
  },
  {
    "country": "ES",
    "name": "Sant Gregori",
    "lat": "41.98333",
    "lng": "2.73333"
  },
  {
    "country": "ES",
    "name": "Sanxenxo",
    "lat": "42.39996",
    "lng": "-8.80698"
  },
  {
    "country": "ES",
    "name": "Sangarrén",
    "lat": "42.01921",
    "lng": "-0.43323"
  },
  {
    "country": "ES",
    "name": "San García de Ingelmos",
    "lat": "40.76912",
    "lng": "-5.11523"
  },
  {
    "country": "ES",
    "name": "Sangarcía",
    "lat": "40.95023",
    "lng": "-4.41085"
  },
  {
    "country": "ES",
    "name": "Sant Fruitós de Bages",
    "lat": "41.75",
    "lng": "1.86667"
  },
  {
    "country": "ES",
    "name": "Sant Ferriol",
    "lat": "42.2",
    "lng": "2.66667"
  },
  {
    "country": "ES",
    "name": "San Fernando de Henares",
    "lat": "40.42386",
    "lng": "-3.53261"
  },
  {
    "country": "ES",
    "name": "Sant Feliu Sasserra",
    "lat": "41.95",
    "lng": "2.03333"
  },
  {
    "country": "ES",
    "name": "Sant Feliu de Pallerols",
    "lat": "42.07708",
    "lng": "2.50935"
  },
  {
    "country": "ES",
    "name": "Sant Feliu de Llobregat",
    "lat": "41.38333",
    "lng": "2.05"
  },
  {
    "country": "ES",
    "name": "Sant Feliu de Guíxols",
    "lat": "41.78333",
    "lng": "3.03333"
  },
  {
    "country": "ES",
    "name": "Sant Feliu de Codines",
    "lat": "41.7",
    "lng": "2.16667"
  },
  {
    "country": "ES",
    "name": "San Felices de los Gallegos",
    "lat": "40.84954",
    "lng": "-6.70804"
  },
  {
    "country": "ES",
    "name": "San Felices",
    "lat": "41.93708",
    "lng": "-2.02638"
  },
  {
    "country": "ES",
    "name": "San Esteban de Nogales",
    "lat": "42.15995",
    "lng": "-5.93065"
  },
  {
    "country": "ES",
    "name": "San Esteban del Valle",
    "lat": "40.2751",
    "lng": "-4.98215"
  },
  {
    "country": "ES",
    "name": "San Esteban de los Patos",
    "lat": "40.74705",
    "lng": "-4.62413"
  },
  {
    "country": "ES",
    "name": "San Esteban del Molar",
    "lat": "41.93717",
    "lng": "-5.55158"
  },
  {
    "country": "ES",
    "name": "San Esteban de la Sierra",
    "lat": "40.5068",
    "lng": "-5.90619"
  },
  {
    "country": "ES",
    "name": "San Esteban de Gormaz",
    "lat": "41.57436",
    "lng": "-3.20418"
  },
  {
    "country": "ES",
    "name": "San Emiliano",
    "lat": "42.97164",
    "lng": "-6.00075"
  },
  {
    "country": "ES",
    "name": "Sando",
    "lat": "40.96773",
    "lng": "-6.11136"
  },
  {
    "country": "ES",
    "name": "Sant Cugat del Vallès",
    "lat": "41.47063",
    "lng": "2.08611"
  },
  {
    "country": "ES",
    "name": "San Cristóbal de Segovia",
    "lat": "40.95225",
    "lng": "-4.07652"
  },
  {
    "country": "ES",
    "name": "San Cristóbal de la Vega",
    "lat": "41.11214",
    "lng": "-4.64448"
  },
  {
    "country": "ES",
    "name": "San Cristóbal de la Polantera",
    "lat": "42.39041",
    "lng": "-5.90732"
  },
  {
    "country": "ES",
    "name": "San Cristóbal de la Cuesta",
    "lat": "41.02919",
    "lng": "-5.61771"
  },
  {
    "country": "ES",
    "name": "San Cristóbal de Entreviñas",
    "lat": "42.04575",
    "lng": "-5.63468"
  },
  {
    "country": "ES",
    "name": "San Cristóbal de Cuéllar",
    "lat": "41.40591",
    "lng": "-4.40445"
  },
  {
    "country": "ES",
    "name": "San Cristóbal de Boedo",
    "lat": "42.54194",
    "lng": "-4.35325"
  },
  {
    "country": "ES",
    "name": "Sanchotello",
    "lat": "40.43812",
    "lng": "-5.75394"
  },
  {
    "country": "ES",
    "name": "Sanchorreja",
    "lat": "40.66475",
    "lng": "-4.91494"
  },
  {
    "country": "ES",
    "name": "Sanchonuño",
    "lat": "41.32325",
    "lng": "-4.30531"
  },
  {
    "country": "ES",
    "name": "Sanchón de la Sagrada",
    "lat": "40.74287",
    "lng": "-6.02502"
  },
  {
    "country": "ES",
    "name": "Sanchón de la Ribera",
    "lat": "41.08844",
    "lng": "-6.41314"
  },
  {
    "country": "ES",
    "name": "Sanchidrián",
    "lat": "40.89347",
    "lng": "-4.58132"
  },
  {
    "country": "ES",
    "name": "Sant Celoni",
    "lat": "41.68921",
    "lng": "2.48965"
  },
  {
    "country": "ES",
    "name": "Sancedo",
    "lat": "42.66666",
    "lng": "-6.63456"
  },
  {
    "country": "ES",
    "name": "San Cebrián de Mudá",
    "lat": "42.89261",
    "lng": "-4.38719"
  },
  {
    "country": "ES",
    "name": "San Cebrián de Mazote",
    "lat": "41.68022",
    "lng": "-5.14847"
  },
  {
    "country": "ES",
    "name": "San Cebrián de Castro",
    "lat": "41.70632",
    "lng": "-5.75605"
  },
  {
    "country": "ES",
    "name": "San Cebrián de Campos",
    "lat": "42.20063",
    "lng": "-4.53127"
  },
  {
    "country": "ES",
    "name": "Sant Carles de la Ràpita",
    "lat": "40.61667",
    "lng": "0.6"
  },
  {
    "country": "ES",
    "name": "Sant Boi de Lluçanès",
    "lat": "42.05",
    "lng": "2.15"
  },
  {
    "country": "ES",
    "name": "Sant Boi de Llobregat",
    "lat": "41.34357",
    "lng": "2.03659"
  },
  {
    "country": "ES",
    "name": "San Bartolomé de Corneja",
    "lat": "40.49257",
    "lng": "-5.38519"
  },
  {
    "country": "ES",
    "name": "San Bartolomé de Béjar",
    "lat": "40.40783",
    "lng": "-5.66261"
  },
  {
    "country": "ES",
    "name": "San Asensio",
    "lat": "42.49677",
    "lng": "-2.75057"
  },
  {
    "country": "ES",
    "name": "San Antolín",
    "lat": "43.03849",
    "lng": "-6.87376"
  },
  {
    "country": "ES",
    "name": "Sant Andreu Salou",
    "lat": "41.86667",
    "lng": "2.83333"
  },
  {
    "country": "ES",
    "name": "Sant Andreu",
    "lat": "41.43541",
    "lng": "2.18982"
  },
  {
    "country": "ES",
    "name": "San Andrés del Rey",
    "lat": "40.63837",
    "lng": "-2.8202"
  },
  {
    "country": "ES",
    "name": "San Andrés del Rabanedo",
    "lat": "42.61174",
    "lng": "-5.61671"
  },
  {
    "country": "ES",
    "name": "Sant Andreu de Llavaneres",
    "lat": "41.56667",
    "lng": "2.48333"
  },
  {
    "country": "ES",
    "name": "San Andrés del Congosto",
    "lat": "40.99775",
    "lng": "-3.02423"
  },
  {
    "country": "ES",
    "name": "Sant Andreu de la Barca",
    "lat": "41.44659",
    "lng": "1.97187"
  },
  {
    "country": "ES",
    "name": "San Amaro",
    "lat": "42.37385",
    "lng": "-8.07347"
  },
  {
    "country": "ES",
    "name": "San Agustín del Pozo",
    "lat": "41.88613",
    "lng": "-5.59351"
  },
  {
    "country": "ES",
    "name": "San Agustín del Guadalix",
    "lat": "40.67882",
    "lng": "-3.61639"
  },
  {
    "country": "ES",
    "name": "San Agustín",
    "lat": "40.05",
    "lng": "-0.68333"
  },
  {
    "country": "ES",
    "name": "San Adrián del Valle",
    "lat": "42.13033",
    "lng": "-5.72905"
  },
  {
    "country": "ES",
    "name": "San Adrián de Juarros",
    "lat": "42.27427",
    "lng": "-3.47551"
  },
  {
    "country": "ES",
    "name": "Sant Adrià de Besòs",
    "lat": "41.43073",
    "lng": "2.21855"
  },
  {
    "country": "ES",
    "name": "San Adrián",
    "lat": "42.33433",
    "lng": "-1.93509"
  },
  {
    "country": "ES",
    "name": "Sant Iscle de Vallalta",
    "lat": "41.61667",
    "lng": "2.56667"
  },
  {
    "country": "ES",
    "name": "Samper del Salz",
    "lat": "41.23458",
    "lng": "-0.8251"
  },
  {
    "country": "ES",
    "name": "Samper de Calanda",
    "lat": "41.18933",
    "lng": "-0.38883"
  },
  {
    "country": "ES",
    "name": "Santpedor",
    "lat": "41.78309",
    "lng": "1.84673"
  },
  {
    "country": "ES",
    "name": "Samos",
    "lat": "42.731",
    "lng": "-7.32582"
  },
  {
    "country": "ES",
    "name": "Samir de los Caños",
    "lat": "41.6728",
    "lng": "-6.16415"
  },
  {
    "country": "ES",
    "name": "Samboal",
    "lat": "41.25758",
    "lng": "-4.41727"
  },
  {
    "country": "ES",
    "name": "Samaniego",
    "lat": "42.56854",
    "lng": "-2.67974"
  },
  {
    "country": "ES",
    "name": "Sama",
    "lat": "43.29568",
    "lng": "-5.68416"
  },
  {
    "country": "ES",
    "name": "Salvatierra de Tormes",
    "lat": "40.59007",
    "lng": "-5.59763"
  },
  {
    "country": "ES",
    "name": "Salvatierra de Miño",
    "lat": "42.08333",
    "lng": "-8.5"
  },
  {
    "country": "ES",
    "name": "Salvatierra de Esca",
    "lat": "42.67002",
    "lng": "-1.00475"
  },
  {
    "country": "ES",
    "name": "Agurain / Salvatierra",
    "lat": "42.85162",
    "lng": "-2.39123"
  },
  {
    "country": "ES",
    "name": "Salvador de Zapardiel",
    "lat": "41.11696",
    "lng": "-4.87486"
  },
  {
    "country": "ES",
    "name": "Salvadiós",
    "lat": "40.87836",
    "lng": "-5.09629"
  },
  {
    "country": "ES",
    "name": "Salvacañete",
    "lat": "40.1",
    "lng": "-1.5"
  },
  {
    "country": "ES",
    "name": "Salt",
    "lat": "41.97489",
    "lng": "2.79281"
  },
  {
    "country": "ES",
    "name": "Salou",
    "lat": "41.07663",
    "lng": "1.14163"
  },
  {
    "country": "ES",
    "name": "Salomó",
    "lat": "41.22955",
    "lng": "1.37445"
  },
  {
    "country": "ES",
    "name": "Salobral",
    "lat": "40.61179",
    "lng": "-4.81013"
  },
  {
    "country": "ES",
    "name": "Salmoral",
    "lat": "40.80137",
    "lng": "-5.2191"
  },
  {
    "country": "ES",
    "name": "Salmerón",
    "lat": "40.54529",
    "lng": "-2.49315"
  },
  {
    "country": "ES",
    "name": "Sallent de Gállego",
    "lat": "42.77127",
    "lng": "-0.33448"
  },
  {
    "country": "ES",
    "name": "Sallent",
    "lat": "41.82602",
    "lng": "1.8955"
  },
  {
    "country": "ES",
    "name": "Salinillas de Bureba",
    "lat": "42.55243",
    "lng": "-3.38753"
  },
  {
    "country": "ES",
    "name": "Salinas de Pisuerga",
    "lat": "42.85046",
    "lng": "-4.37783"
  },
  {
    "country": "ES",
    "name": "Salinas de Oro",
    "lat": "42.77487",
    "lng": "-1.88999"
  },
  {
    "country": "ES",
    "name": "Salinas del Manzano",
    "lat": "40.08333",
    "lng": "-1.55"
  },
  {
    "country": "ES",
    "name": "Leintz-Gatzaga",
    "lat": "42.98684",
    "lng": "-2.56851"
  },
  {
    "country": "ES",
    "name": "Salillas de Jalón",
    "lat": "41.56789",
    "lng": "-1.32344"
  },
  {
    "country": "ES",
    "name": "Salillas",
    "lat": "41.99498",
    "lng": "-0.22278"
  },
  {
    "country": "ES",
    "name": "Salduero",
    "lat": "41.88946",
    "lng": "-2.7967"
  },
  {
    "country": "ES",
    "name": "Saldón",
    "lat": "40.32513",
    "lng": "-1.42782"
  },
  {
    "country": "ES",
    "name": "Saldías",
    "lat": "43.08858",
    "lng": "-1.77946"
  },
  {
    "country": "ES",
    "name": "Saldes",
    "lat": "42.23333",
    "lng": "1.73333"
  },
  {
    "country": "ES",
    "name": "Saldeana",
    "lat": "41.02068",
    "lng": "-6.64015"
  },
  {
    "country": "ES",
    "name": "Saldaña de Burgos",
    "lat": "42.25838",
    "lng": "-3.69707"
  },
  {
    "country": "ES",
    "name": "Saldaña",
    "lat": "42.52146",
    "lng": "-4.73605"
  },
  {
    "country": "ES",
    "name": "Salcedillo",
    "lat": "40.962",
    "lng": "-1.00433"
  },
  {
    "country": "ES",
    "name": "Salce",
    "lat": "41.26996",
    "lng": "-6.21875"
  },
  {
    "country": "ES",
    "name": "Salas de los Infantes",
    "lat": "42.02242",
    "lng": "-3.28631"
  },
  {
    "country": "ES",
    "name": "Sales de Llierca",
    "lat": "42.23333",
    "lng": "2.65"
  },
  {
    "country": "ES",
    "name": "Salas de Bureba",
    "lat": "42.6919",
    "lng": "-3.47359"
  },
  {
    "country": "ES",
    "name": "Salas Bajas",
    "lat": "42.10046",
    "lng": "0.08349"
  },
  {
    "country": "ES",
    "name": "Salas Altas",
    "lat": "42.11407",
    "lng": "0.06821"
  },
  {
    "country": "ES",
    "name": "Salas",
    "lat": "43.4118",
    "lng": "-6.26023"
  },
  {
    "country": "ES",
    "name": "Salamanca",
    "lat": "40.96882",
    "lng": "-5.66388"
  },
  {
    "country": "ES",
    "name": "Sajazarra",
    "lat": "42.58884",
    "lng": "-2.96124"
  },
  {
    "country": "ES",
    "name": "Sahagún",
    "lat": "42.37085",
    "lng": "-5.02942"
  },
  {
    "country": "ES",
    "name": "Sagàs",
    "lat": "42.05",
    "lng": "1.96667"
  },
  {
    "country": "ES",
    "name": "Saelices el Chico",
    "lat": "40.66998",
    "lng": "-6.63271"
  },
  {
    "country": "ES",
    "name": "Saelices de Mayorga",
    "lat": "42.21206",
    "lng": "-5.20534"
  },
  {
    "country": "ES",
    "name": "Saelices de la Sal",
    "lat": "40.90723",
    "lng": "-2.32325"
  },
  {
    "country": "ES",
    "name": "Sádaba",
    "lat": "42.2818",
    "lng": "-1.26951"
  },
  {
    "country": "ES",
    "name": "Sada",
    "lat": "43.35619",
    "lng": "-8.25796"
  },
  {
    "country": "ES",
    "name": "Sacramenia",
    "lat": "41.49419",
    "lng": "-3.9621"
  },
  {
    "country": "ES",
    "name": "Sacedón",
    "lat": "40.48076",
    "lng": "-2.73337"
  },
  {
    "country": "ES",
    "name": "Saceda-Trasierra",
    "lat": "40.15525",
    "lng": "-2.85369"
  },
  {
    "country": "ES",
    "name": "Sacecorbo",
    "lat": "40.8328",
    "lng": "-2.41838"
  },
  {
    "country": "ES",
    "name": "Sabiñánigo",
    "lat": "42.51924",
    "lng": "-0.36607"
  },
  {
    "country": "ES",
    "name": "Sabero",
    "lat": "42.83593",
    "lng": "-5.14875"
  },
  {
    "country": "ES",
    "name": "Sabadell",
    "lat": "41.54329",
    "lng": "2.10942"
  },
  {
    "country": "ES",
    "name": "Rupià",
    "lat": "42.01667",
    "lng": "3.01667"
  },
  {
    "country": "ES",
    "name": "Ruesga",
    "lat": "42.86413",
    "lng": "-4.52942"
  },
  {
    "country": "ES",
    "name": "Ruesca",
    "lat": "41.2835",
    "lng": "-1.48142"
  },
  {
    "country": "ES",
    "name": "Ruente",
    "lat": "43.25826",
    "lng": "-4.26791"
  },
  {
    "country": "ES",
    "name": "Rueda de la Sierra",
    "lat": "40.91795",
    "lng": "-1.85439"
  },
  {
    "country": "ES",
    "name": "Rueda",
    "lat": "41.41231",
    "lng": "-4.95885"
  },
  {
    "country": "ES",
    "name": "Rucandio",
    "lat": "42.75111",
    "lng": "-3.54166"
  },
  {
    "country": "ES",
    "name": "Rublacedo de Abajo",
    "lat": "42.55332",
    "lng": "-3.50236"
  },
  {
    "country": "ES",
    "name": "Rubielos de Mora",
    "lat": "40.18894",
    "lng": "-0.65307"
  },
  {
    "country": "ES",
    "name": "Rubielos de la Cérida",
    "lat": "40.77058",
    "lng": "-1.21291"
  },
  {
    "country": "ES",
    "name": "Rubí de Bracamonte",
    "lat": "41.21421",
    "lng": "-4.92491"
  },
  {
    "country": "ES",
    "name": "Rubiales",
    "lat": "40.27623",
    "lng": "-1.27167"
  },
  {
    "country": "ES",
    "name": "Rubí",
    "lat": "41.49226",
    "lng": "2.03305"
  },
  {
    "country": "ES",
    "name": "Rubena",
    "lat": "42.38746",
    "lng": "-3.57485"
  },
  {
    "country": "ES",
    "name": "Rozas de Puerto Real",
    "lat": "40.31667",
    "lng": "-4.48333"
  },
  {
    "country": "ES",
    "name": "Royuela de Río Franco",
    "lat": "42.00217",
    "lng": "-3.95547"
  },
  {
    "country": "ES",
    "name": "Royuela",
    "lat": "40.37846",
    "lng": "-1.51337"
  },
  {
    "country": "ES",
    "name": "Roturas",
    "lat": "41.66791",
    "lng": "-4.11901"
  },
  {
    "country": "ES",
    "name": "Rosell",
    "lat": "40.61792",
    "lng": "0.22133"
  },
  {
    "country": "ES",
    "name": "Roses",
    "lat": "42.26199",
    "lng": "3.17689"
  },
  {
    "country": "ES",
    "name": "O Rosal",
    "lat": "41.93536",
    "lng": "-8.83677"
  },
  {
    "country": "ES",
    "name": "Roperuelos del Páramo",
    "lat": "42.2378",
    "lng": "-5.78235"
  },
  {
    "country": "ES",
    "name": "Romanos",
    "lat": "41.12636",
    "lng": "-1.27502"
  },
  {
    "country": "ES",
    "name": "Romanones",
    "lat": "40.57149",
    "lng": "-2.99072"
  },
  {
    "country": "ES",
    "name": "Romanillos de Atienza",
    "lat": "41.26667",
    "lng": "-2.9"
  },
  {
    "country": "ES",
    "name": "Rollán",
    "lat": "40.9623",
    "lng": "-5.91753"
  },
  {
    "country": "ES",
    "name": "Rollamienta",
    "lat": "41.92592",
    "lng": "-2.53125"
  },
  {
    "country": "ES",
    "name": "Rojas",
    "lat": "42.57781",
    "lng": "-3.44195"
  },
  {
    "country": "ES",
    "name": "Rois",
    "lat": "42.76295",
    "lng": "-8.70528"
  },
  {
    "country": "ES",
    "name": "Rodezno",
    "lat": "42.52576",
    "lng": "-2.84597"
  },
  {
    "country": "ES",
    "name": "Ródenas",
    "lat": "40.64076",
    "lng": "-1.51617"
  },
  {
    "country": "ES",
    "name": "Rodeiro",
    "lat": "42.65193",
    "lng": "-7.95519"
  },
  {
    "country": "ES",
    "name": "Roda de Eresma",
    "lat": "41.02852",
    "lng": "-4.1813"
  },
  {
    "country": "ES",
    "name": "Roda de Barà",
    "lat": "41.18645",
    "lng": "1.45893"
  },
  {
    "country": "ES",
    "name": "Robres del Castillo",
    "lat": "42.27593",
    "lng": "-2.29245"
  },
  {
    "country": "ES",
    "name": "Robres",
    "lat": "41.86746",
    "lng": "-0.46094"
  },
  {
    "country": "ES",
    "name": "Robregordo",
    "lat": "41.10657",
    "lng": "-3.59369"
  },
  {
    "country": "ES",
    "name": "Robliza de Cojos",
    "lat": "40.86766",
    "lng": "-5.97786"
  },
  {
    "country": "ES",
    "name": "Robledo de Corpes",
    "lat": "41.11838",
    "lng": "-2.95"
  },
  {
    "country": "ES",
    "name": "Robledo de Chavela",
    "lat": "40.50062",
    "lng": "-4.23635"
  },
  {
    "country": "ES",
    "name": "Robledillo de Mohernando",
    "lat": "40.85118",
    "lng": "-3.23162"
  },
  {
    "country": "ES",
    "name": "Robledillo de la Vera",
    "lat": "40.10093",
    "lng": "-5.58896"
  },
  {
    "country": "ES",
    "name": "Robledillo de la Jara",
    "lat": "40.95054",
    "lng": "-3.52181"
  },
  {
    "country": "ES",
    "name": "Robledillo de Gata",
    "lat": "40.32234",
    "lng": "-6.47129"
  },
  {
    "country": "ES",
    "name": "Robleda-Cervantes",
    "lat": "42.08246",
    "lng": "-6.59414"
  },
  {
    "country": "ES",
    "name": "Robleda",
    "lat": "40.38469",
    "lng": "-6.60726"
  },
  {
    "country": "ES",
    "name": "Robladillo",
    "lat": "41.60838",
    "lng": "-4.90992"
  },
  {
    "country": "ES",
    "name": "Roales",
    "lat": "41.5517",
    "lng": "-5.77211"
  },
  {
    "country": "ES",
    "name": "Roa",
    "lat": "41.69699",
    "lng": "-3.92782"
  },
  {
    "country": "ES",
    "name": "Rivilla de Barajas",
    "lat": "40.9021",
    "lng": "-4.98836"
  },
  {
    "country": "ES",
    "name": "Riumors",
    "lat": "42.22726",
    "lng": "3.0419"
  },
  {
    "country": "ES",
    "name": "Riudoms",
    "lat": "41.13333",
    "lng": "1.05"
  },
  {
    "country": "ES",
    "name": "Riudellots de la Selva",
    "lat": "41.89327",
    "lng": "2.80452"
  },
  {
    "country": "ES",
    "name": "Riudecols",
    "lat": "41.169",
    "lng": "0.97625"
  },
  {
    "country": "ES",
    "name": "Riudecanyes",
    "lat": "41.13333",
    "lng": "0.96667"
  },
  {
    "country": "ES",
    "name": "Riudarenes",
    "lat": "41.81667",
    "lng": "2.71667"
  },
  {
    "country": "ES",
    "name": "Ripollet",
    "lat": "41.49686",
    "lng": "2.15739"
  },
  {
    "country": "ES",
    "name": "Ripoll",
    "lat": "42.20064",
    "lng": "2.19033"
  },
  {
    "country": "ES",
    "name": "Ríotorto",
    "lat": "43.35",
    "lng": "-7.23333"
  },
  {
    "country": "ES",
    "name": "Riós",
    "lat": "41.97457",
    "lng": "-7.28234"
  },
  {
    "country": "ES",
    "name": "Ríofrío de Aliste",
    "lat": "41.81724",
    "lng": "-6.17741"
  },
  {
    "country": "ES",
    "name": "Riodeva",
    "lat": "40.11667",
    "lng": "-1.15"
  },
  {
    "country": "ES",
    "name": "Riocavado de la Sierra",
    "lat": "42.15209",
    "lng": "-3.19759"
  },
  {
    "country": "ES",
    "name": "Ruayer",
    "lat": "43.05372",
    "lng": "-5.55019"
  },
  {
    "country": "ES",
    "name": "Rincón de Soto",
    "lat": "42.23475",
    "lng": "-1.85214"
  },
  {
    "country": "ES",
    "name": "Rillo de Gallo",
    "lat": "40.86635",
    "lng": "-1.9374"
  },
  {
    "country": "ES",
    "name": "Rillo",
    "lat": "40.72233",
    "lng": "-0.99623"
  },
  {
    "country": "ES",
    "name": "Errigoiti",
    "lat": "43.31667",
    "lng": "-2.71667"
  },
  {
    "country": "ES",
    "name": "Riells i Viabrea",
    "lat": "41.78333",
    "lng": "2.51667"
  },
  {
    "country": "ES",
    "name": "Riego de la Vega",
    "lat": "42.39138",
    "lng": "-5.98102"
  },
  {
    "country": "ES",
    "name": "Ricla",
    "lat": "41.5058",
    "lng": "-1.40468"
  },
  {
    "country": "ES",
    "name": "Ribota",
    "lat": "41.36477",
    "lng": "-3.42964"
  },
  {
    "country": "ES",
    "name": "Ribesalbes",
    "lat": "40.01667",
    "lng": "-0.26667"
  },
  {
    "country": "ES",
    "name": "Riberos de la Cueza",
    "lat": "42.27881",
    "lng": "-4.72503"
  },
  {
    "country": "ES",
    "name": "Ribeira",
    "lat": "42.74611",
    "lng": "-8.44392"
  },
  {
    "country": "ES",
    "name": "Ribatejada",
    "lat": "40.6642",
    "lng": "-3.38976"
  },
  {
    "country": "ES",
    "name": "Luintra",
    "lat": "42.40964",
    "lng": "-7.72682"
  },
  {
    "country": "ES",
    "name": "Ribes de Freser",
    "lat": "42.30417",
    "lng": "2.16757"
  },
  {
    "country": "ES",
    "name": "Ribas de Campos",
    "lat": "42.15249",
    "lng": "-4.51649"
  },
  {
    "country": "ES",
    "name": "Ribaforada",
    "lat": "41.99814",
    "lng": "-1.51272"
  },
  {
    "country": "ES",
    "name": "Ribadumia",
    "lat": "42.51667",
    "lng": "-8.75"
  },
  {
    "country": "ES",
    "name": "Ribadesella",
    "lat": "43.46145",
    "lng": "-5.05955"
  },
  {
    "country": "ES",
    "name": "Riba de Saelices",
    "lat": "40.91145",
    "lng": "-2.29715"
  },
  {
    "country": "ES",
    "name": "Ribadeo",
    "lat": "43.53704",
    "lng": "-7.04095"
  },
  {
    "country": "ES",
    "name": "Ribadavia",
    "lat": "42.28804",
    "lng": "-8.14362"
  },
  {
    "country": "ES",
    "name": "Riaza",
    "lat": "41.27826",
    "lng": "-3.47787"
  },
  {
    "country": "ES",
    "name": "Riaño",
    "lat": "42.97705",
    "lng": "-5.00352"
  },
  {
    "country": "ES",
    "name": "Rianxo",
    "lat": "42.64977",
    "lng": "-8.81763"
  },
  {
    "country": "ES",
    "name": "Riaguas de San Bartolomé",
    "lat": "41.4264",
    "lng": "-3.48893"
  },
  {
    "country": "ES",
    "name": "Reznos",
    "lat": "41.5909",
    "lng": "-2.02779"
  },
  {
    "country": "ES",
    "name": "Rezmondo",
    "lat": "42.51565",
    "lng": "-4.23877"
  },
  {
    "country": "ES",
    "name": "Reyero",
    "lat": "42.94882",
    "lng": "-5.19892"
  },
  {
    "country": "ES",
    "name": "Revillarruz",
    "lat": "42.23006",
    "lng": "-3.65246"
  },
  {
    "country": "ES",
    "name": "Revilla del Campo",
    "lat": "42.21081",
    "lng": "-3.54289"
  },
  {
    "country": "ES",
    "name": "Revilla de Collazos",
    "lat": "42.6296",
    "lng": "-4.50343"
  },
  {
    "country": "ES",
    "name": "Revenga de Campos",
    "lat": "42.28401",
    "lng": "-4.48218"
  },
  {
    "country": "ES",
    "name": "Revellinos",
    "lat": "41.88982",
    "lng": "-5.56871"
  },
  {
    "country": "ES",
    "name": "Reus",
    "lat": "41.15612",
    "lng": "1.10687"
  },
  {
    "country": "ES",
    "name": "Retuerta",
    "lat": "42.02945",
    "lng": "-3.50679"
  },
  {
    "country": "ES",
    "name": "Retortillo de Soria",
    "lat": "41.31092",
    "lng": "-2.98228"
  },
  {
    "country": "ES",
    "name": "Retortillo",
    "lat": "40.80132",
    "lng": "-6.35951"
  },
  {
    "country": "ES",
    "name": "Retiendas",
    "lat": "40.96835",
    "lng": "-3.27229"
  },
  {
    "country": "ES",
    "name": "Retascón",
    "lat": "41.1435",
    "lng": "-1.38376"
  },
  {
    "country": "ES",
    "name": "Respenda de la Peña",
    "lat": "42.76512",
    "lng": "-4.6854"
  },
  {
    "country": "ES",
    "name": "Requena de Campos",
    "lat": "42.30796",
    "lng": "-4.34304"
  },
  {
    "country": "ES",
    "name": "Requejo",
    "lat": "42.03044",
    "lng": "-6.74227"
  },
  {
    "country": "ES",
    "name": "Reocín",
    "lat": "43.33915",
    "lng": "-4.09403"
  },
  {
    "country": "ES",
    "name": "Errenteria",
    "lat": "43.31195",
    "lng": "-1.90234"
  },
  {
    "country": "ES",
    "name": "Renieblas",
    "lat": "41.82009",
    "lng": "-2.37236"
  },
  {
    "country": "ES",
    "name": "Renera",
    "lat": "40.48976",
    "lng": "-3.01367"
  },
  {
    "country": "ES",
    "name": "Renedo de la Vega",
    "lat": "42.45348",
    "lng": "-4.70298"
  },
  {
    "country": "ES",
    "name": "Renau",
    "lat": "41.22448",
    "lng": "1.31083"
  },
  {
    "country": "ES",
    "name": "Remondo",
    "lat": "41.341",
    "lng": "-4.4839"
  },
  {
    "country": "ES",
    "name": "Remolinos",
    "lat": "41.83946",
    "lng": "-1.17768"
  },
  {
    "country": "ES",
    "name": "Rello",
    "lat": "41.33297",
    "lng": "-2.74925"
  },
  {
    "country": "ES",
    "name": "Reinoso de Cerrato",
    "lat": "41.97624",
    "lng": "-4.38337"
  },
  {
    "country": "ES",
    "name": "Reinoso",
    "lat": "42.50915",
    "lng": "-3.38466"
  },
  {
    "country": "ES",
    "name": "Reinosa",
    "lat": "42.99959",
    "lng": "-4.13801"
  },
  {
    "country": "ES",
    "name": "Regumiel de la Sierra",
    "lat": "41.95623",
    "lng": "-2.98843"
  },
  {
    "country": "ES",
    "name": "Regueras de Arriba",
    "lat": "42.29414",
    "lng": "-5.85958"
  },
  {
    "country": "ES",
    "name": "Errezil",
    "lat": "43.16505",
    "lng": "-2.17395"
  },
  {
    "country": "ES",
    "name": "Regencós",
    "lat": "41.95271",
    "lng": "3.17006"
  },
  {
    "country": "ES",
    "name": "Redueña",
    "lat": "40.81685",
    "lng": "-3.59837"
  },
  {
    "country": "ES",
    "name": "Redondela",
    "lat": "42.28337",
    "lng": "-8.6096"
  },
  {
    "country": "ES",
    "name": "Redecilla del Campo",
    "lat": "42.46675",
    "lng": "-3.11531"
  },
  {
    "country": "ES",
    "name": "Redecilla del Camino",
    "lat": "42.43804",
    "lng": "-3.06547"
  },
  {
    "country": "ES",
    "name": "Recuerda",
    "lat": "41.47408",
    "lng": "-2.9946"
  },
  {
    "country": "ES",
    "name": "Recas",
    "lat": "40.05286",
    "lng": "-3.9909"
  },
  {
    "country": "ES",
    "name": "Rebollosa de Jadraque",
    "lat": "41.0904",
    "lng": "-2.84201"
  },
  {
    "country": "ES",
    "name": "Rebollo",
    "lat": "41.19318",
    "lng": "-3.85771"
  },
  {
    "country": "ES",
    "name": "Rebolledo de la Torre",
    "lat": "42.68931",
    "lng": "-4.22693"
  },
  {
    "country": "ES",
    "name": "Rasueros",
    "lat": "41.02344",
    "lng": "-5.07377"
  },
  {
    "country": "ES",
    "name": "Rasquera",
    "lat": "41.00267",
    "lng": "0.59967"
  },
  {
    "country": "ES",
    "name": "Rasines",
    "lat": "43.30505",
    "lng": "-3.42919"
  },
  {
    "country": "ES",
    "name": "Rascafría",
    "lat": "40.90407",
    "lng": "-3.87898"
  },
  {
    "country": "ES",
    "name": "Rapariegos",
    "lat": "41.09498",
    "lng": "-4.65271"
  },
  {
    "country": "ES",
    "name": "Ramiro",
    "lat": "41.22845",
    "lng": "-4.78608"
  },
  {
    "country": "ES",
    "name": "Ramales de la Victoria",
    "lat": "43.2572",
    "lng": "-3.46516"
  },
  {
    "country": "ES",
    "name": "Rajadell",
    "lat": "41.72802",
    "lng": "1.70621"
  },
  {
    "country": "ES",
    "name": "Rairiz de Veiga",
    "lat": "42.08364",
    "lng": "-7.83503"
  },
  {
    "country": "ES",
    "name": "Rágama",
    "lat": "40.99768",
    "lng": "-5.12724"
  },
  {
    "country": "ES",
    "name": "Ráfales",
    "lat": "40.8377",
    "lng": "0.01923"
  },
  {
    "country": "ES",
    "name": "Rabós",
    "lat": "42.3789",
    "lng": "3.02828"
  },
  {
    "country": "ES",
    "name": "Rabé de las Calzadas",
    "lat": "42.34065",
    "lng": "-3.83414"
  },
  {
    "country": "ES",
    "name": "Rábanos",
    "lat": "42.31971",
    "lng": "-3.27029"
  },
  {
    "country": "ES",
    "name": "Rábano de Aliste",
    "lat": "41.7443",
    "lng": "-6.43302"
  },
  {
    "country": "ES",
    "name": "Rábano",
    "lat": "41.53314",
    "lng": "-4.06214"
  },
  {
    "country": "ES",
    "name": "Rabanera del Pinar",
    "lat": "41.89375",
    "lng": "-3.19665"
  },
  {
    "country": "ES",
    "name": "Rabanera",
    "lat": "42.18955",
    "lng": "-2.48654"
  },
  {
    "country": "ES",
    "name": "Rabanales",
    "lat": "41.74287",
    "lng": "-6.27674"
  },
  {
    "country": "ES",
    "name": "Rábade",
    "lat": "43.117",
    "lng": "-7.61714"
  },
  {
    "country": "ES",
    "name": "Quismondo",
    "lat": "40.10533",
    "lng": "-4.32394"
  },
  {
    "country": "ES",
    "name": "Quiruelas de Vidriales",
    "lat": "42.01762",
    "lng": "-5.82947"
  },
  {
    "country": "ES",
    "name": "Quiroga",
    "lat": "42.47678",
    "lng": "-7.27463"
  },
  {
    "country": "ES",
    "name": "Quinto",
    "lat": "41.42378",
    "lng": "-0.49592"
  },
  {
    "country": "ES",
    "name": "Quintela de Leirado",
    "lat": "42.13967",
    "lng": "-8.10126"
  },
  {
    "country": "ES",
    "name": "Quintanilla de Urz",
    "lat": "42.0329",
    "lng": "-5.84866"
  },
  {
    "country": "ES",
    "name": "Quintanilla de Trigueros",
    "lat": "41.85449",
    "lng": "-4.65931"
  },
  {
    "country": "ES",
    "name": "Quintanilla de Onsoña",
    "lat": "42.46937",
    "lng": "-4.66385"
  },
  {
    "country": "ES",
    "name": "Quintanilla de Onésimo",
    "lat": "41.6249",
    "lng": "-4.36291"
  },
  {
    "country": "ES",
    "name": "Quintanilla del Olmo",
    "lat": "41.90561",
    "lng": "-5.40726"
  },
  {
    "country": "ES",
    "name": "Quintanilla del Monte",
    "lat": "41.86812",
    "lng": "-5.34928"
  },
  {
    "country": "ES",
    "name": "Quintanilla del Molar",
    "lat": "41.98935",
    "lng": "-5.44928"
  },
  {
    "country": "ES",
    "name": "Quintanilla del Coco",
    "lat": "41.98333",
    "lng": "-3.51667"
  },
  {
    "country": "ES",
    "name": "Quintanilla de la Mata",
    "lat": "41.98855",
    "lng": "-3.76756"
  },
  {
    "country": "ES",
    "name": "Quintanilla de Arriba",
    "lat": "41.61974",
    "lng": "-4.21774"
  },
  {
    "country": "ES",
    "name": "Quintana y Congosto",
    "lat": "42.25585",
    "lng": "-6.03636"
  },
  {
    "country": "ES",
    "name": "Quintanavides",
    "lat": "42.48084",
    "lng": "-3.42449"
  },
  {
    "country": "ES",
    "name": "Quintanas de Gormaz",
    "lat": "41.50926",
    "lng": "-2.97631"
  },
  {
    "country": "ES",
    "name": "Quintana Redonda",
    "lat": "41.63905",
    "lng": "-2.61449"
  },
  {
    "country": "ES",
    "name": "Quintanar de la Sierra",
    "lat": "41.98288",
    "lng": "-3.03765"
  },
  {
    "country": "ES",
    "name": "Quintanapalla",
    "lat": "42.40914",
    "lng": "-3.53296"
  },
  {
    "country": "ES",
    "name": "Quintanaortuño",
    "lat": "42.45",
    "lng": "-3.68333"
  },
  {
    "country": "ES",
    "name": "Quintanaélez",
    "lat": "42.66921",
    "lng": "-3.29877"
  },
  {
    "country": "ES",
    "name": "Quintana del Puente",
    "lat": "42.08471",
    "lng": "-4.20649"
  },
  {
    "country": "ES",
    "name": "Quintana del Pidio",
    "lat": "41.75886",
    "lng": "-3.75121"
  },
  {
    "country": "ES",
    "name": "Quintana del Marco",
    "lat": "42.2067",
    "lng": "-5.8503"
  },
  {
    "country": "ES",
    "name": "Quintana del Castillo",
    "lat": "42.65987",
    "lng": "-6.04978"
  },
  {
    "country": "ES",
    "name": "Quintanabureba",
    "lat": "42.58665",
    "lng": "-3.36685"
  },
  {
    "country": "ES",
    "name": "Quijorna",
    "lat": "40.42763",
    "lng": "-4.05683"
  },
  {
    "country": "ES",
    "name": "Quicena",
    "lat": "42.14797",
    "lng": "-0.36049"
  },
  {
    "country": "ES",
    "name": "Querol",
    "lat": "41.42293",
    "lng": "1.39684"
  },
  {
    "country": "ES",
    "name": "Quer",
    "lat": "40.60532",
    "lng": "-3.2753"
  },
  {
    "country": "ES",
    "name": "Quemada",
    "lat": "41.70073",
    "lng": "-3.57476"
  },
  {
    "country": "ES",
    "name": "Quel",
    "lat": "42.22979",
    "lng": "-2.05196"
  },
  {
    "country": "ES",
    "name": "Quart d’Onyar",
    "lat": "41.94047",
    "lng": "2.84079"
  },
  {
    "country": "ES",
    "name": "Purujosa",
    "lat": "41.68259",
    "lng": "-1.76519"
  },
  {
    "country": "ES",
    "name": "Puras",
    "lat": "41.18333",
    "lng": "-4.65"
  },
  {
    "country": "ES",
    "name": "Punxín",
    "lat": "42.37072",
    "lng": "-8.01058"
  },
  {
    "country": "ES",
    "name": "Pujalt",
    "lat": "41.7171",
    "lng": "1.42088"
  },
  {
    "country": "ES",
    "name": "Puig-reig",
    "lat": "41.96667",
    "lng": "1.88333"
  },
  {
    "country": "ES",
    "name": "Puigpelat",
    "lat": "41.27899",
    "lng": "1.29713"
  },
  {
    "country": "ES",
    "name": "Puigcerdà",
    "lat": "42.4316",
    "lng": "1.92819"
  },
  {
    "country": "ES",
    "name": "Pueyo de Santa Cruz",
    "lat": "41.85799",
    "lng": "0.1566"
  },
  {
    "country": "ES",
    "name": "Pueyo",
    "lat": "42.56506",
    "lng": "-1.64826"
  },
  {
    "country": "ES",
    "name": "Puerto Seguro",
    "lat": "40.82718",
    "lng": "-6.76109"
  },
  {
    "country": "ES",
    "name": "Puertomingalvo",
    "lat": "40.2643",
    "lng": "-0.45756"
  },
  {
    "country": "ES",
    "name": "Portomarín",
    "lat": "42.8062",
    "lng": "-7.61644"
  },
  {
    "country": "ES",
    "name": "Puértolas",
    "lat": "42.54748",
    "lng": "0.13214"
  },
  {
    "country": "ES",
    "name": "Puerto de Béjar",
    "lat": "40.35052",
    "lng": "-5.83756"
  },
  {
    "country": "ES",
    "name": "Puerto Castilla",
    "lat": "40.288",
    "lng": "-5.62366"
  },
  {
    "country": "ES",
    "name": "Puertas",
    "lat": "41.09681",
    "lng": "-6.28752"
  },
  {
    "country": "ES",
    "name": "Puente Viesgo",
    "lat": "43.29815",
    "lng": "-3.96817"
  },
  {
    "country": "ES",
    "name": "As Pontes de García Rodríguez",
    "lat": "43.45266",
    "lng": "-7.85178"
  },
  {
    "country": "ES",
    "name": "Puente la Reina",
    "lat": "42.67291",
    "lng": "-1.81412"
  },
  {
    "country": "ES",
    "name": "Puentedura",
    "lat": "42.04134",
    "lng": "-3.58227"
  },
  {
    "country": "ES",
    "name": "Puente de Vallecas",
    "lat": "40.39354",
    "lng": "-3.662"
  },
  {
    "country": "ES",
    "name": "Puente del Congosto",
    "lat": "40.49041",
    "lng": "-5.52628"
  },
  {
    "country": "ES",
    "name": "Puente de Domingo Flórez",
    "lat": "42.41166",
    "lng": "-6.82077"
  },
  {
    "country": "ES",
    "name": "Ponte Caldelas",
    "lat": "42.38911",
    "lng": "-8.50235"
  },
  {
    "country": "ES",
    "name": "Ponteareas",
    "lat": "42.17476",
    "lng": "-8.50398"
  },
  {
    "country": "ES",
    "name": "Pueblica de Valverde",
    "lat": "41.91843",
    "lng": "-5.89975"
  },
  {
    "country": "ES",
    "name": "Puebla de Yeltes",
    "lat": "40.62528",
    "lng": "-6.1815"
  },
  {
    "country": "ES",
    "name": "Puebla de San Miguel",
    "lat": "40.05",
    "lng": "-1.13333"
  },
  {
    "country": "ES",
    "name": "Puebla de San Medel",
    "lat": "40.51073",
    "lng": "-5.73673"
  },
  {
    "country": "ES",
    "name": "Puebla de Sanabria",
    "lat": "42.05401",
    "lng": "-6.6335"
  },
  {
    "country": "ES",
    "name": "Puebla de Pedraza",
    "lat": "41.20557",
    "lng": "-3.91378"
  },
  {
    "country": "ES",
    "name": "Puebla de Lillo",
    "lat": "43.00691",
    "lng": "-5.27387"
  },
  {
    "country": "ES",
    "name": "A Pobra do Brollon",
    "lat": "42.55612",
    "lng": "-7.3914"
  },
  {
    "country": "ES",
    "name": "Puebla de Beleña",
    "lat": "40.88794",
    "lng": "-3.21624"
  },
  {
    "country": "ES",
    "name": "Puebla de Azaba",
    "lat": "40.44732",
    "lng": "-6.74616"
  },
  {
    "country": "ES",
    "name": "Puebla de Arenoso",
    "lat": "40.1",
    "lng": "-0.58333"
  },
  {
    "country": "ES",
    "name": "Puebla de Alfindén",
    "lat": "41.63188",
    "lng": "-0.75154"
  },
  {
    "country": "ES",
    "name": "Puebla de Albortón",
    "lat": "41.38517",
    "lng": "-0.85558"
  },
  {
    "country": "ES",
    "name": "Proaza",
    "lat": "43.25178",
    "lng": "-6.01633"
  },
  {
    "country": "ES",
    "name": "Prioro",
    "lat": "42.89481",
    "lng": "-4.96349"
  },
  {
    "country": "ES",
    "name": "Priego",
    "lat": "40.44936",
    "lng": "-2.31435"
  },
  {
    "country": "ES",
    "name": "Priaranza del Bierzo",
    "lat": "42.50978",
    "lng": "-6.67017"
  },
  {
    "country": "ES",
    "name": "Presencio",
    "lat": "42.18656",
    "lng": "-3.90135"
  },
  {
    "country": "ES",
    "name": "Premià de Mar",
    "lat": "41.49206",
    "lng": "2.36524"
  },
  {
    "country": "ES",
    "name": "Préjano",
    "lat": "42.18648",
    "lng": "-2.17998"
  },
  {
    "country": "ES",
    "name": "Pravia",
    "lat": "43.48861",
    "lng": "-6.1117"
  },
  {
    "country": "ES",
    "name": "Prats de Lluçanès",
    "lat": "42.01667",
    "lng": "2.03333"
  },
  {
    "country": "ES",
    "name": "Prados Redondos",
    "lat": "40.78505",
    "lng": "-1.79329"
  },
  {
    "country": "ES",
    "name": "Pradosegar",
    "lat": "40.5502",
    "lng": "-5.07015"
  },
  {
    "country": "ES",
    "name": "Pradoluengo",
    "lat": "42.32484",
    "lng": "-3.20284"
  },
  {
    "country": "ES",
    "name": "Prado de la Guzpeña",
    "lat": "42.78309",
    "lng": "-5.02554"
  },
  {
    "country": "ES",
    "name": "Prado",
    "lat": "41.92077",
    "lng": "-5.42027"
  },
  {
    "country": "ES",
    "name": "Pradillo",
    "lat": "42.1766",
    "lng": "-2.64185"
  },
  {
    "country": "ES",
    "name": "Pradilla de Ebro",
    "lat": "41.86111",
    "lng": "-1.26325"
  },
  {
    "country": "ES",
    "name": "Prades",
    "lat": "41.30983",
    "lng": "0.98866"
  },
  {
    "country": "ES",
    "name": "Prádena del Rincón",
    "lat": "41.04414",
    "lng": "-3.54075"
  },
  {
    "country": "ES",
    "name": "Prádena de Atienza",
    "lat": "41.17245",
    "lng": "-3.00728"
  },
  {
    "country": "ES",
    "name": "Prádena",
    "lat": "41.13911",
    "lng": "-3.68823"
  },
  {
    "country": "ES",
    "name": "Pradejón",
    "lat": "42.33446",
    "lng": "-2.06851"
  },
  {
    "country": "ES",
    "name": "Prádanos de Ojeda",
    "lat": "42.68156",
    "lng": "-4.34659"
  },
  {
    "country": "ES",
    "name": "Prádanos de Bureba",
    "lat": "42.50264",
    "lng": "-3.34752"
  },
  {
    "country": "ES",
    "name": "Pradales",
    "lat": "41.45555",
    "lng": "-3.70753"
  },
  {
    "country": "ES",
    "name": "Pozuelo de Zarzón",
    "lat": "40.14805",
    "lng": "-6.41458"
  },
  {
    "country": "ES",
    "name": "Pozuelo de Tábara",
    "lat": "41.78502",
    "lng": "-5.89455"
  },
  {
    "country": "ES",
    "name": "Pozuelo del Rey",
    "lat": "40.36463",
    "lng": "-3.31699"
  },
  {
    "country": "ES",
    "name": "Pozuelo del Páramo",
    "lat": "42.17101",
    "lng": "-5.76813"
  },
  {
    "country": "ES",
    "name": "Pozuelo de la Orden",
    "lat": "41.82138",
    "lng": "-5.25891"
  },
  {
    "country": "ES",
    "name": "Pozuelo de Aragón",
    "lat": "41.7643",
    "lng": "-1.42305"
  },
  {
    "country": "ES",
    "name": "Pozuelo de Alarcón",
    "lat": "40.43293",
    "lng": "-3.81338"
  },
  {
    "country": "ES",
    "name": "Pozuel del Campo",
    "lat": "40.77125",
    "lng": "-1.50575"
  },
  {
    "country": "ES",
    "name": "Pozuel de Ariza",
    "lat": "41.35",
    "lng": "-2.15"
  },
  {
    "country": "ES",
    "name": "Pozos de Hinojo",
    "lat": "40.91303",
    "lng": "-6.41144"
  },
  {
    "country": "ES",
    "name": "Pozondón",
    "lat": "40.56112",
    "lng": "-1.47033"
  },
  {
    "country": "ES",
    "name": "Pozo de Urama",
    "lat": "42.25438",
    "lng": "-4.89389"
  },
  {
    "country": "ES",
    "name": "Pozo de Guadalajara",
    "lat": "40.49533",
    "lng": "-3.1814"
  },
  {
    "country": "ES",
    "name": "Pozo de Almoguera",
    "lat": "40.3403",
    "lng": "-3.02638"
  },
  {
    "country": "ES",
    "name": "Pozoantiguo",
    "lat": "41.5973",
    "lng": "-5.4366"
  },
  {
    "country": "ES",
    "name": "Pozán de Vero",
    "lat": "42.08219",
    "lng": "0.03066"
  },
  {
    "country": "ES",
    "name": "Pozanco",
    "lat": "40.80095",
    "lng": "-4.66772"
  },
  {
    "country": "ES",
    "name": "Pozalmuro",
    "lat": "41.77449",
    "lng": "-2.10215"
  },
  {
    "country": "ES",
    "name": "Pozal de Gallinas",
    "lat": "41.31831",
    "lng": "-4.83936"
  },
  {
    "country": "ES",
    "name": "Poza de la Vega",
    "lat": "42.57823",
    "lng": "-4.79845"
  },
  {
    "country": "ES",
    "name": "Poza de la Sal",
    "lat": "42.66542",
    "lng": "-3.5014"
  },
  {
    "country": "ES",
    "name": "Poio",
    "lat": "42.44775",
    "lng": "-8.68594"
  },
  {
    "country": "ES",
    "name": "Poio",
    "lat": "42.42929",
    "lng": "-8.66075"
  },
  {
    "country": "ES",
    "name": "Poyales del Hoyo",
    "lat": "40.17254",
    "lng": "-5.16597"
  },
  {
    "country": "ES",
    "name": "Poveda de la Sierra",
    "lat": "40.64329",
    "lng": "-2.02905"
  },
  {
    "country": "ES",
    "name": "Poveda de las Cintas",
    "lat": "41.04596",
    "lng": "-5.26019"
  },
  {
    "country": "ES",
    "name": "Poveda",
    "lat": "40.56799",
    "lng": "-5.07909"
  },
  {
    "country": "ES",
    "name": "Potes",
    "lat": "43.15457",
    "lng": "-4.62055"
  },
  {
    "country": "ES",
    "name": "Posada de Valdeón",
    "lat": "43.15154",
    "lng": "-4.92102"
  },
  {
    "country": "ES",
    "name": "Portugalete",
    "lat": "43.32099",
    "lng": "-3.02064"
  },
  {
    "country": "ES",
    "name": "Porto",
    "lat": "42.16737",
    "lng": "-6.89934"
  },
  {
    "country": "ES",
    "name": "Portillo de Toledo",
    "lat": "40.06415",
    "lng": "-4.22793"
  },
  {
    "country": "ES",
    "name": "Portillo de Soria",
    "lat": "41.63504",
    "lng": "-2.12142"
  },
  {
    "country": "ES",
    "name": "Portillo",
    "lat": "41.47867",
    "lng": "-4.58967"
  },
  {
    "country": "ES",
    "name": "Portilla",
    "lat": "40.28957",
    "lng": "-2.08178"
  },
  {
    "country": "ES",
    "name": "Portell de Morella",
    "lat": "40.53267",
    "lng": "-0.26249"
  },
  {
    "country": "ES",
    "name": "Portbou",
    "lat": "42.4265",
    "lng": "3.15805"
  },
  {
    "country": "ES",
    "name": "Portas",
    "lat": "42.58531",
    "lng": "-8.65573"
  },
  {
    "country": "ES",
    "name": "Porriño",
    "lat": "42.16156",
    "lng": "-8.6198"
  },
  {
    "country": "ES",
    "name": "Porqueres",
    "lat": "42.11682",
    "lng": "2.74143"
  },
  {
    "country": "ES",
    "name": "Porqueira",
    "lat": "42.01667",
    "lng": "-7.85"
  },
  {
    "country": "ES",
    "name": "Pontós",
    "lat": "42.18665",
    "lng": "2.91706"
  },
  {
    "country": "ES",
    "name": "Pontils",
    "lat": "41.47734",
    "lng": "1.38772"
  },
  {
    "country": "ES",
    "name": "Pontevedra",
    "lat": "42.431",
    "lng": "-8.64435"
  },
  {
    "country": "ES",
    "name": "Pont de Molins",
    "lat": "42.3144",
    "lng": "2.92996"
  },
  {
    "country": "ES",
    "name": "Ponts",
    "lat": "41.91607",
    "lng": "1.18515"
  },
  {
    "country": "ES",
    "name": "Ponferrada",
    "lat": "42.54664",
    "lng": "-6.59619"
  },
  {
    "country": "ES",
    "name": "Pomer",
    "lat": "41.63765",
    "lng": "-1.84104"
  },
  {
    "country": "ES",
    "name": "Pomar de Valdivia",
    "lat": "42.77437",
    "lng": "-4.16756"
  },
  {
    "country": "ES",
    "name": "Pollos",
    "lat": "41.44406",
    "lng": "-5.12491"
  },
  {
    "country": "ES",
    "name": "Polinyà",
    "lat": "41.55",
    "lng": "2.15"
  },
  {
    "country": "ES",
    "name": "Polentinos",
    "lat": "42.93932",
    "lng": "-4.52887"
  },
  {
    "country": "ES",
    "name": "Poleñino",
    "lat": "41.86972",
    "lng": "-0.31009"
  },
  {
    "country": "ES",
    "name": "Pola de Somiedo",
    "lat": "43.0929",
    "lng": "-6.25629"
  },
  {
    "country": "ES",
    "name": "Pola de Siero",
    "lat": "43.39228",
    "lng": "-5.66335"
  },
  {
    "country": "ES",
    "name": "Pola de Lena",
    "lat": "43.16089",
    "lng": "-5.82878"
  },
  {
    "country": "ES",
    "name": "Pola de Laviana",
    "lat": "43.24538",
    "lng": "-5.5629"
  },
  {
    "country": "ES",
    "name": "Pola de Allande",
    "lat": "43.27307",
    "lng": "-6.62152"
  },
  {
    "country": "ES",
    "name": "Pol",
    "lat": "43.14892",
    "lng": "-7.33022"
  },
  {
    "country": "ES",
    "name": "Pobladura de Valderaduey",
    "lat": "41.70009",
    "lng": "-5.54189"
  },
  {
    "country": "ES",
    "name": "Pobladura de Pelayo García",
    "lat": "42.30602",
    "lng": "-5.6856"
  },
  {
    "country": "ES",
    "name": "Pobladura del Valle",
    "lat": "42.10257",
    "lng": "-5.73333"
  },
  {
    "country": "ES",
    "name": "la Pobla de Massaluca",
    "lat": "41.18333",
    "lng": "0.35"
  },
  {
    "country": "ES",
    "name": "Población de Cerrato",
    "lat": "41.79298",
    "lng": "-4.42874"
  },
  {
    "country": "ES",
    "name": "Población de Campos",
    "lat": "42.26994",
    "lng": "-4.44744"
  },
  {
    "country": "ES",
    "name": "Población de Arroyo",
    "lat": "42.33675",
    "lng": "-4.87398"
  },
  {
    "country": "ES",
    "name": "el Poal",
    "lat": "41.68333",
    "lng": "0.86667"
  },
  {
    "country": "ES",
    "name": "Plou",
    "lat": "40.99274",
    "lng": "-0.85441"
  },
  {
    "country": "ES",
    "name": "Plentzia",
    "lat": "43.4053",
    "lng": "-2.94794"
  },
  {
    "country": "ES",
    "name": "Plenas",
    "lat": "41.11209",
    "lng": "-0.96442"
  },
  {
    "country": "ES",
    "name": "Pleitas",
    "lat": "41.71135",
    "lng": "-1.20251"
  },
  {
    "country": "ES",
    "name": "Plasencia de Jalón",
    "lat": "41.68154",
    "lng": "-1.22996"
  },
  {
    "country": "ES",
    "name": "Plasencia",
    "lat": "40.03116",
    "lng": "-6.08845"
  },
  {
    "country": "ES",
    "name": "Planoles",
    "lat": "42.31667",
    "lng": "2.1"
  },
  {
    "country": "ES",
    "name": "Plan",
    "lat": "42.58126",
    "lng": "0.33742"
  },
  {
    "country": "ES",
    "name": "el Pla del Penedès",
    "lat": "41.41667",
    "lng": "1.71667"
  },
  {
    "country": "ES",
    "name": "El Pla de Santa Maria",
    "lat": "41.36336",
    "lng": "1.29152"
  },
  {
    "country": "ES",
    "name": "Pizarral",
    "lat": "40.6145",
    "lng": "-5.65238"
  },
  {
    "country": "ES",
    "name": "Pitillas",
    "lat": "42.42172",
    "lng": "-1.62017"
  },
  {
    "country": "ES",
    "name": "Pitiegua",
    "lat": "41.0621",
    "lng": "-5.46647"
  },
  {
    "country": "ES",
    "name": "Pitarque",
    "lat": "40.6485",
    "lng": "-0.59324"
  },
  {
    "country": "ES",
    "name": "Piracés",
    "lat": "42.00448",
    "lng": "-0.31769"
  },
  {
    "country": "ES",
    "name": "Piqueras",
    "lat": "40.66367",
    "lng": "-1.72202"
  },
  {
    "country": "ES",
    "name": "Pioz",
    "lat": "40.46153",
    "lng": "-3.17234"
  },
  {
    "country": "ES",
    "name": "Piornal",
    "lat": "40.11731",
    "lng": "-5.84787"
  },
  {
    "country": "ES",
    "name": "Pinto",
    "lat": "40.24147",
    "lng": "-3.69999"
  },
  {
    "country": "ES",
    "name": "Pinseque",
    "lat": "41.73657",
    "lng": "-1.10041"
  },
  {
    "country": "ES",
    "name": "Piñor",
    "lat": "42.5012",
    "lng": "-8.00151"
  },
  {
    "country": "ES",
    "name": "Pinofranqueado",
    "lat": "40.30351",
    "lng": "-6.33181"
  },
  {
    "country": "ES",
    "name": "Pino del Río",
    "lat": "42.64504",
    "lng": "-4.80795"
  },
  {
    "country": "ES",
    "name": "Pinillos",
    "lat": "42.19951",
    "lng": "-2.59709"
  },
  {
    "country": "ES",
    "name": "Pinilla de Toro",
    "lat": "41.62783",
    "lng": "-5.36414"
  },
  {
    "country": "ES",
    "name": "Pinilla de Molina",
    "lat": "40.67969",
    "lng": "-1.88034"
  },
  {
    "country": "ES",
    "name": "Pinilla del Valle",
    "lat": "40.92448",
    "lng": "-3.81688"
  },
  {
    "country": "ES",
    "name": "Pinilla de los Moros",
    "lat": "42.06815",
    "lng": "-3.32706"
  },
  {
    "country": "ES",
    "name": "Pinilla de los Barruecos",
    "lat": "41.91791",
    "lng": "-3.30371"
  },
  {
    "country": "ES",
    "name": "Pinilla del Campo",
    "lat": "41.71691",
    "lng": "-2.0835"
  },
  {
    "country": "ES",
    "name": "Pinilla de Jadraque",
    "lat": "41.01988",
    "lng": "-2.94254"
  },
  {
    "country": "ES",
    "name": "Piñel de Arriba",
    "lat": "41.69923",
    "lng": "-4.12808"
  },
  {
    "country": "ES",
    "name": "Piñel de Abajo",
    "lat": "41.67459",
    "lng": "-4.14655"
  },
  {
    "country": "ES",
    "name": "Pinedas",
    "lat": "40.44493",
    "lng": "-5.96025"
  },
  {
    "country": "ES",
    "name": "Pineda de la Sierra",
    "lat": "42.2156",
    "lng": "-3.2969"
  },
  {
    "country": "ES",
    "name": "Pineda de Gigüela",
    "lat": "40.08546",
    "lng": "-2.54368"
  },
  {
    "country": "ES",
    "name": "Pineda de Mar",
    "lat": "41.62763",
    "lng": "2.6889"
  },
  {
    "country": "ES",
    "name": "Pinarnegrillo",
    "lat": "41.19098",
    "lng": "-4.20967"
  },
  {
    "country": "ES",
    "name": "Pinarejos",
    "lat": "41.2595",
    "lng": "-4.29364"
  },
  {
    "country": "ES",
    "name": "Pina de Montalgrao",
    "lat": "40.01667",
    "lng": "-0.65"
  },
  {
    "country": "ES",
    "name": "Piña de Esgueva",
    "lat": "41.72843",
    "lng": "-4.42823"
  },
  {
    "country": "ES",
    "name": "Pina de Ebro",
    "lat": "41.48846",
    "lng": "-0.5312"
  },
  {
    "country": "ES",
    "name": "Piña de Campos",
    "lat": "42.21326",
    "lng": "-4.43657"
  },
  {
    "country": "ES",
    "name": "Piloña",
    "lat": "43.35",
    "lng": "-5.36667"
  },
  {
    "country": "ES",
    "name": "Piérnigas",
    "lat": "42.5903",
    "lng": "-3.41337"
  },
  {
    "country": "ES",
    "name": "Piera",
    "lat": "41.52232",
    "lng": "1.75076"
  },
  {
    "country": "ES",
    "name": "Piedratajada",
    "lat": "42.12124",
    "lng": "-0.80373"
  },
  {
    "country": "ES",
    "name": "Piedramillera",
    "lat": "42.632",
    "lng": "-2.20416"
  },
  {
    "country": "ES",
    "name": "Piedralaves",
    "lat": "40.31721",
    "lng": "-4.70025"
  },
  {
    "country": "ES",
    "name": "Piedrahita de Castro",
    "lat": "41.68089",
    "lng": "-5.72886"
  },
  {
    "country": "ES",
    "name": "Pías",
    "lat": "42.08333",
    "lng": "-7"
  },
  {
    "country": "ES",
    "name": "Pezuela de las Torres",
    "lat": "40.41613",
    "lng": "-3.17363"
  },
  {
    "country": "ES",
    "name": "Petín",
    "lat": "42.38191",
    "lng": "-7.12899"
  },
  {
    "country": "ES",
    "name": "Petilla de Aragón",
    "lat": "42.45",
    "lng": "-1.11667"
  },
  {
    "country": "ES",
    "name": "Pesquera",
    "lat": "43.08223",
    "lng": "-4.07932"
  },
  {
    "country": "ES",
    "name": "Pesoz",
    "lat": "43.25",
    "lng": "-6.86667"
  },
  {
    "country": "ES",
    "name": "Pertusa",
    "lat": "42.00214",
    "lng": "-0.12732"
  },
  {
    "country": "ES",
    "name": "Perosillo",
    "lat": "41.39294",
    "lng": "-4.14115"
  },
  {
    "country": "ES",
    "name": "Peromingo",
    "lat": "40.46386",
    "lng": "-5.77238"
  },
  {
    "country": "ES",
    "name": "Perilla de Castro",
    "lat": "41.7254",
    "lng": "-5.87636"
  },
  {
    "country": "ES",
    "name": "Pereruela",
    "lat": "41.4165",
    "lng": "-5.87812"
  },
  {
    "country": "ES",
    "name": "El Perelló",
    "lat": "40.87431",
    "lng": "0.71125"
  },
  {
    "country": "ES",
    "name": "Peralada",
    "lat": "42.30823",
    "lng": "3.0091"
  },
  {
    "country": "ES",
    "name": "Pereiro de Aguiar",
    "lat": "42.34524",
    "lng": "-7.80008"
  },
  {
    "country": "ES",
    "name": "Perdiguera",
    "lat": "41.75458",
    "lng": "-0.63148"
  },
  {
    "country": "ES",
    "name": "Peranzanes",
    "lat": "42.87725",
    "lng": "-6.63383"
  },
  {
    "country": "ES",
    "name": "Peralveche",
    "lat": "40.61078",
    "lng": "-2.44957"
  },
  {
    "country": "ES",
    "name": "Peraltilla",
    "lat": "42.05407",
    "lng": "-0.0184"
  },
  {
    "country": "ES",
    "name": "Peralta",
    "lat": "42.33834",
    "lng": "-1.80035"
  },
  {
    "country": "ES",
    "name": "Perales de Tajuña",
    "lat": "40.2313",
    "lng": "-3.35021"
  },
  {
    "country": "ES",
    "name": "Perales del Puerto",
    "lat": "40.15596",
    "lng": "-6.68192"
  },
  {
    "country": "ES",
    "name": "Perales del Alfambra",
    "lat": "40.63383",
    "lng": "-1.00181"
  },
  {
    "country": "ES",
    "name": "Perales",
    "lat": "42.19398",
    "lng": "-4.58105"
  },
  {
    "country": "ES",
    "name": "Peralejos de las Truchas",
    "lat": "40.59336",
    "lng": "-1.90953"
  },
  {
    "country": "ES",
    "name": "Peralejos de Arriba",
    "lat": "41.0041",
    "lng": "-6.33362"
  },
  {
    "country": "ES",
    "name": "Peralejos de Abajo",
    "lat": "41.00469",
    "lng": "-6.36238"
  },
  {
    "country": "ES",
    "name": "Peralejos",
    "lat": "40.48433",
    "lng": "-1.03408"
  },
  {
    "country": "ES",
    "name": "Peral de Arlanza",
    "lat": "42.07612",
    "lng": "-4.07733"
  },
  {
    "country": "ES",
    "name": "Peracense",
    "lat": "40.64099",
    "lng": "-1.47075"
  },
  {
    "country": "ES",
    "name": "Peque",
    "lat": "42.07297",
    "lng": "-6.27489"
  },
  {
    "country": "ES",
    "name": "Peníscola",
    "lat": "40.3574",
    "lng": "0.40692"
  },
  {
    "country": "ES",
    "name": "Penelles",
    "lat": "41.75",
    "lng": "0.96667"
  },
  {
    "country": "ES",
    "name": "Peñausende",
    "lat": "41.28662",
    "lng": "-5.86755"
  },
  {
    "country": "ES",
    "name": "Peñarandilla",
    "lat": "40.88348",
    "lng": "-5.3936"
  },
  {
    "country": "ES",
    "name": "Peñaranda de Duero",
    "lat": "41.68849",
    "lng": "-3.47863"
  },
  {
    "country": "ES",
    "name": "Peñaranda de Bracamonte",
    "lat": "40.90108",
    "lng": "-5.20026"
  },
  {
    "country": "ES",
    "name": "Peñaparda",
    "lat": "40.32093",
    "lng": "-6.66948"
  },
  {
    "country": "ES",
    "name": "Peñalver",
    "lat": "40.5814",
    "lng": "-2.8889"
  },
  {
    "country": "ES",
    "name": "Peñalén",
    "lat": "40.6656",
    "lng": "-2.06999"
  },
  {
    "country": "ES",
    "name": "Peñalba de Ávila",
    "lat": "40.77266",
    "lng": "-4.74595"
  },
  {
    "country": "ES",
    "name": "Peñalba",
    "lat": "41.50087",
    "lng": "-0.03798"
  },
  {
    "country": "ES",
    "name": "Penagos",
    "lat": "43.35216",
    "lng": "-3.81382"
  },
  {
    "country": "ES",
    "name": "Peñaflor de Hornija",
    "lat": "41.71159",
    "lng": "-4.98333"
  },
  {
    "country": "ES",
    "name": "Peñafiel",
    "lat": "41.60165",
    "lng": "-4.11418"
  },
  {
    "country": "ES",
    "name": "Peñacaballera",
    "lat": "40.34353",
    "lng": "-5.86121"
  },
  {
    "country": "ES",
    "name": "Peleas de Abajo",
    "lat": "41.3926",
    "lng": "-5.68966"
  },
  {
    "country": "ES",
    "name": "Peleagonzalo",
    "lat": "41.48175",
    "lng": "-5.48304"
  },
  {
    "country": "ES",
    "name": "Pelayos del Arroyo",
    "lat": "41.05086",
    "lng": "-3.94104"
  },
  {
    "country": "ES",
    "name": "Pelayos de la Presa",
    "lat": "40.36051",
    "lng": "-4.33462"
  },
  {
    "country": "ES",
    "name": "Pelayos",
    "lat": "40.64985",
    "lng": "-5.5758"
  },
  {
    "country": "ES",
    "name": "Pelarrodríguez",
    "lat": "40.88723",
    "lng": "-6.21271"
  },
  {
    "country": "ES",
    "name": "Pelahustán",
    "lat": "40.17599",
    "lng": "-4.59842"
  },
  {
    "country": "ES",
    "name": "Pelabravo",
    "lat": "40.93658",
    "lng": "-5.57916"
  },
  {
    "country": "ES",
    "name": "Peguerinos",
    "lat": "40.6262",
    "lng": "-4.23154"
  },
  {
    "country": "ES",
    "name": "Pedroso",
    "lat": "42.29959",
    "lng": "-2.71889"
  },
  {
    "country": "ES",
    "name": "Pedrosillo el Ralo",
    "lat": "41.06305",
    "lng": "-5.54794"
  },
  {
    "country": "ES",
    "name": "Pedrosillo de los Aires",
    "lat": "40.71524",
    "lng": "-5.70511"
  },
  {
    "country": "ES",
    "name": "Pedrosillo de Alba",
    "lat": "40.82277",
    "lng": "-5.39506"
  },
  {
    "country": "ES",
    "name": "Pedrosa del Rey",
    "lat": "41.55617",
    "lng": "-5.20466"
  },
  {
    "country": "ES",
    "name": "Pedrosa del Príncipe",
    "lat": "42.24918",
    "lng": "-4.19849"
  },
  {
    "country": "ES",
    "name": "Pedrosa del Páramo",
    "lat": "42.44208",
    "lng": "-3.9719"
  },
  {
    "country": "ES",
    "name": "Pedrosa de la Vega",
    "lat": "42.48159",
    "lng": "-4.74678"
  },
  {
    "country": "ES",
    "name": "Pedrosa de Duero",
    "lat": "41.71289",
    "lng": "-3.98804"
  },
  {
    "country": "ES",
    "name": "Pedrola",
    "lat": "41.79102",
    "lng": "-1.21357"
  },
  {
    "country": "ES",
    "name": "Pedro Bernardo",
    "lat": "40.24214",
    "lng": "-4.90963"
  },
  {
    "country": "ES",
    "name": "Pedrezuela",
    "lat": "40.74277",
    "lng": "-3.5998"
  },
  {
    "country": "ES",
    "name": "Pedraza de Campos",
    "lat": "41.98419",
    "lng": "-4.73524"
  },
  {
    "country": "ES",
    "name": "Pedraza de Alba",
    "lat": "40.75502",
    "lng": "-5.37524"
  },
  {
    "country": "ES",
    "name": "Pedraza",
    "lat": "41.13092",
    "lng": "-3.81116"
  },
  {
    "country": "ES",
    "name": "Pedrajas de San Esteban",
    "lat": "41.34145",
    "lng": "-4.58225"
  },
  {
    "country": "ES",
    "name": "Pazuengos",
    "lat": "42.31776",
    "lng": "-2.92539"
  },
  {
    "country": "ES",
    "name": "Payo de Ojeda",
    "lat": "42.71859",
    "lng": "-4.47752"
  },
  {
    "country": "ES",
    "name": "Pau",
    "lat": "42.31607",
    "lng": "3.11621"
  },
  {
    "country": "ES",
    "name": "Patones",
    "lat": "40.85563",
    "lng": "-3.4849"
  },
  {
    "country": "ES",
    "name": "Pastrana",
    "lat": "40.41902",
    "lng": "-2.92256"
  },
  {
    "country": "ES",
    "name": "Pastores",
    "lat": "40.51508",
    "lng": "-6.51018"
  },
  {
    "country": "ES",
    "name": "Pascualcobo",
    "lat": "40.65637",
    "lng": "-5.27733"
  },
  {
    "country": "ES",
    "name": "Parrillas",
    "lat": "40.06225",
    "lng": "-5.0639"
  },
  {
    "country": "ES",
    "name": "Parres",
    "lat": "43.35",
    "lng": "-5.15"
  },
  {
    "country": "ES",
    "name": "Parlavà",
    "lat": "42.02163",
    "lng": "3.03197"
  },
  {
    "country": "ES",
    "name": "Parla",
    "lat": "40.23604",
    "lng": "-3.76752"
  },
  {
    "country": "ES",
    "name": "Parets del Vallès",
    "lat": "41.57481",
    "lng": "2.23306"
  },
  {
    "country": "ES",
    "name": "Pareja",
    "lat": "40.55578",
    "lng": "-2.64882"
  },
  {
    "country": "ES",
    "name": "Paredes de Sigüenza",
    "lat": "41.24283",
    "lng": "-2.73376"
  },
  {
    "country": "ES",
    "name": "Paredes de Nava",
    "lat": "42.15367",
    "lng": "-4.69193"
  },
  {
    "country": "ES",
    "name": "Paredes de Escalona",
    "lat": "40.20472",
    "lng": "-4.4305"
  },
  {
    "country": "ES",
    "name": "Paredes",
    "lat": "40.06578",
    "lng": "-2.854"
  },
  {
    "country": "ES",
    "name": "Pardos",
    "lat": "40.94818",
    "lng": "-1.92555"
  },
  {
    "country": "ES",
    "name": "Pardilla",
    "lat": "41.55183",
    "lng": "-3.71089"
  },
  {
    "country": "ES",
    "name": "Páramo del Sil",
    "lat": "42.82056",
    "lng": "-6.48747"
  },
  {
    "country": "ES",
    "name": "Páramo de Boedo",
    "lat": "42.57842",
    "lng": "-4.40042"
  },
  {
    "country": "ES",
    "name": "O Páramo",
    "lat": "42.95",
    "lng": "-7.3"
  },
  {
    "country": "ES",
    "name": "Paradinas de San Juan",
    "lat": "40.98325",
    "lng": "-5.15418"
  },
  {
    "country": "ES",
    "name": "Paradela",
    "lat": "42.76667",
    "lng": "-7.56667"
  },
  {
    "country": "ES",
    "name": "Parada de Rubiales",
    "lat": "41.14818",
    "lng": "-5.43638"
  },
  {
    "country": "ES",
    "name": "Parada de Arriba",
    "lat": "40.98655",
    "lng": "-5.79332"
  },
  {
    "country": "ES",
    "name": "Paracuellos de la Ribera",
    "lat": "41.42273",
    "lng": "-1.56245"
  },
  {
    "country": "ES",
    "name": "Paracuellos de Jiloca",
    "lat": "41.31378",
    "lng": "-1.64029"
  },
  {
    "country": "ES",
    "name": "Paracuellos de Jarama",
    "lat": "40.50353",
    "lng": "-3.52775"
  },
  {
    "country": "ES",
    "name": "Papatrigo",
    "lat": "40.8679",
    "lng": "-4.83399"
  },
  {
    "country": "ES",
    "name": "Pantón",
    "lat": "42.51667",
    "lng": "-7.6"
  },
  {
    "country": "ES",
    "name": "Pantoja",
    "lat": "40.04336",
    "lng": "-3.8328"
  },
  {
    "country": "ES",
    "name": "Paniza",
    "lat": "41.284",
    "lng": "-1.21224"
  },
  {
    "country": "ES",
    "name": "Pancrudo",
    "lat": "40.76223",
    "lng": "-1.02967"
  },
  {
    "country": "ES",
    "name": "Pancorbo",
    "lat": "42.63418",
    "lng": "-3.1118"
  },
  {
    "country": "ES",
    "name": "Pamplona",
    "lat": "42.81687",
    "lng": "-1.64323"
  },
  {
    "country": "ES",
    "name": "Pampliega",
    "lat": "42.20582",
    "lng": "-3.98666"
  },
  {
    "country": "ES",
    "name": "Pals",
    "lat": "41.97102",
    "lng": "3.14814"
  },
  {
    "country": "ES",
    "name": "Palomero",
    "lat": "40.24688",
    "lng": "-6.27706"
  },
  {
    "country": "ES",
    "name": "Palomeque",
    "lat": "40.11966",
    "lng": "-3.96403"
  },
  {
    "country": "ES",
    "name": "Palomar de Arroyos",
    "lat": "40.77911",
    "lng": "-0.75055"
  },
  {
    "country": "ES",
    "name": "Palol de Revardit",
    "lat": "42.06667",
    "lng": "2.8"
  },
  {
    "country": "ES",
    "name": "Palo",
    "lat": "42.3227",
    "lng": "0.24376"
  },
  {
    "country": "ES",
    "name": "Pálmaces de Jadraque",
    "lat": "41.0561",
    "lng": "-2.9106"
  },
  {
    "country": "ES",
    "name": "Pallejà",
    "lat": "41.42394",
    "lng": "1.99505"
  },
  {
    "country": "ES",
    "name": "els Pallaresos",
    "lat": "41.17491",
    "lng": "1.2709"
  },
  {
    "country": "ES",
    "name": "Palenzuela",
    "lat": "42.09518",
    "lng": "-4.13039"
  },
  {
    "country": "ES",
    "name": "Palencia de Negrilla",
    "lat": "41.09439",
    "lng": "-5.60168"
  },
  {
    "country": "ES",
    "name": "Palencia",
    "lat": "42.00955",
    "lng": "-4.52406"
  },
  {
    "country": "ES",
    "name": "Palazuelos de Muñó",
    "lat": "42.19692",
    "lng": "-3.98984"
  },
  {
    "country": "ES",
    "name": "Palazuelos de la Sierra",
    "lat": "42.21162",
    "lng": "-3.46014"
  },
  {
    "country": "ES",
    "name": "Palazuelos de Eresma",
    "lat": "40.93055",
    "lng": "-4.06071"
  },
  {
    "country": "ES",
    "name": "Palazuelo de Vedija",
    "lat": "41.92966",
    "lng": "-5.14534"
  },
  {
    "country": "ES",
    "name": "Palau-sator",
    "lat": "41.98897",
    "lng": "3.11016"
  },
  {
    "country": "ES",
    "name": "Palanques",
    "lat": "40.718",
    "lng": "-0.17941"
  },
  {
    "country": "ES",
    "name": "Palamós",
    "lat": "41.84843",
    "lng": "3.12912"
  },
  {
    "country": "ES",
    "name": "Palafrugell",
    "lat": "41.91738",
    "lng": "3.1631"
  },
  {
    "country": "ES",
    "name": "Palafolls",
    "lat": "41.66667",
    "lng": "2.75"
  },
  {
    "country": "ES",
    "name": "Palaciosrubios",
    "lat": "41.05238",
    "lng": "-5.19507"
  },
  {
    "country": "ES",
    "name": "Palacios de Sanabria",
    "lat": "42.05901",
    "lng": "-6.52362"
  },
  {
    "country": "ES",
    "name": "Palacios del Sil",
    "lat": "42.87601",
    "lng": "-6.4315"
  },
  {
    "country": "ES",
    "name": "Palacios del Pan",
    "lat": "41.60242",
    "lng": "-5.87773"
  },
  {
    "country": "ES",
    "name": "Palacios de la Valduerna",
    "lat": "42.32773",
    "lng": "-5.9383"
  },
  {
    "country": "ES",
    "name": "Palacios de la Sierra",
    "lat": "41.96392",
    "lng": "-3.12788"
  },
  {
    "country": "ES",
    "name": "Palacios del Arzobispo",
    "lat": "41.16655",
    "lng": "-5.88933"
  },
  {
    "country": "ES",
    "name": "Palacios de Goda",
    "lat": "41.11798",
    "lng": "-4.78496"
  },
  {
    "country": "ES",
    "name": "Pajares de los Oteros",
    "lat": "42.3301",
    "lng": "-5.47313"
  },
  {
    "country": "ES",
    "name": "Pajares de la Lampreana",
    "lat": "41.71551",
    "lng": "-5.69351"
  },
  {
    "country": "ES",
    "name": "Pajares de la Laguna",
    "lat": "41.08754",
    "lng": "-5.50888"
  },
  {
    "country": "ES",
    "name": "Pajares de Adaja",
    "lat": "40.92398",
    "lng": "-4.64048"
  },
  {
    "country": "ES",
    "name": "Pajarejos",
    "lat": "41.38994",
    "lng": "-3.58997"
  },
  {
    "country": "ES",
    "name": "Padrones de Bureba",
    "lat": "42.70582",
    "lng": "-3.53296"
  },
  {
    "country": "ES",
    "name": "Padrón",
    "lat": "42.73875",
    "lng": "-8.66057"
  },
  {
    "country": "ES",
    "name": "Padrenda",
    "lat": "42.13333",
    "lng": "-8.15"
  },
  {
    "country": "ES",
    "name": "Padilla de Arriba",
    "lat": "42.43803",
    "lng": "-4.19094"
  },
  {
    "country": "ES",
    "name": "Padilla de Abajo",
    "lat": "42.40774",
    "lng": "-4.17652"
  },
  {
    "country": "ES",
    "name": "Padiernos",
    "lat": "40.62168",
    "lng": "-4.84523"
  },
  {
    "country": "ES",
    "name": "Paderne",
    "lat": "43.28567",
    "lng": "-8.17415"
  },
  {
    "country": "ES",
    "name": "Oion / Oyón",
    "lat": "42.50571",
    "lng": "-2.43638"
  },
  {
    "country": "ES",
    "name": "Oia",
    "lat": "42",
    "lng": "-8.86667"
  },
  {
    "country": "ES",
    "name": "Oviedo",
    "lat": "43.36029",
    "lng": "-5.84476"
  },
  {
    "country": "ES",
    "name": "Outes",
    "lat": "42.86189",
    "lng": "-8.90181"
  },
  {
    "country": "ES",
    "name": "Outeiro",
    "lat": "43.14458",
    "lng": "-7.29212"
  },
  {
    "country": "ES",
    "name": "Ourol",
    "lat": "42.87013",
    "lng": "-7.61447"
  },
  {
    "country": "ES",
    "name": "Outeiro de Rei",
    "lat": "43.10198",
    "lng": "-7.61497"
  },
  {
    "country": "ES",
    "name": "Otero de Herreros",
    "lat": "40.82016",
    "lng": "-4.2099"
  },
  {
    "country": "ES",
    "name": "Otero de Bodas",
    "lat": "41.93868",
    "lng": "-6.15024"
  },
  {
    "country": "ES",
    "name": "Oteiza",
    "lat": "42.61905",
    "lng": "-1.95385"
  },
  {
    "country": "ES",
    "name": "Ossó de Sió",
    "lat": "41.75485",
    "lng": "1.159"
  },
  {
    "country": "ES",
    "name": "Osornillo",
    "lat": "42.37047",
    "lng": "-4.29153"
  },
  {
    "country": "ES",
    "name": "Oseja de Sajambre",
    "lat": "43.13671",
    "lng": "-5.03786"
  },
  {
    "country": "ES",
    "name": "Oseja",
    "lat": "41.59564",
    "lng": "-1.70026"
  },
  {
    "country": "ES",
    "name": "Os de Balaguer",
    "lat": "41.87314",
    "lng": "0.72017"
  },
  {
    "country": "ES",
    "name": "Ortuella",
    "lat": "43.31113",
    "lng": "-3.05617"
  },
  {
    "country": "ES",
    "name": "Ortigosa de Pestaño",
    "lat": "41.08741",
    "lng": "-4.39516"
  },
  {
    "country": "ES",
    "name": "Ortigosa del Monte",
    "lat": "40.84182",
    "lng": "-4.17724"
  },
  {
    "country": "ES",
    "name": "Ortigosa",
    "lat": "42.17568",
    "lng": "-2.70513"
  },
  {
    "country": "ES",
    "name": "Òrrius",
    "lat": "41.55",
    "lng": "2.35"
  },
  {
    "country": "ES",
    "name": "Orrios",
    "lat": "40.58945",
    "lng": "-0.98614"
  },
  {
    "country": "ES",
    "name": "Orpí",
    "lat": "41.5187",
    "lng": "1.57536"
  },
  {
    "country": "ES",
    "name": "Oroso",
    "lat": "42.98333",
    "lng": "-8.43333"
  },
  {
    "country": "ES",
    "name": "Oropesa del Mar",
    "lat": "40.09134",
    "lng": "0.14115"
  },
  {
    "country": "ES",
    "name": "Oronz",
    "lat": "42.86873",
    "lng": "-1.09683"
  },
  {
    "country": "ES",
    "name": "Ormaiztegi",
    "lat": "43.04339",
    "lng": "-2.25673"
  },
  {
    "country": "ES",
    "name": "Oristà",
    "lat": "41.93333",
    "lng": "2.06667"
  },
  {
    "country": "ES",
    "name": "Orísoain",
    "lat": "42.60122",
    "lng": "-1.60403"
  },
  {
    "country": "ES",
    "name": "Orís",
    "lat": "42.05967",
    "lng": "2.22066"
  },
  {
    "country": "ES",
    "name": "Orio",
    "lat": "43.2787",
    "lng": "-2.12537"
  },
  {
    "country": "ES",
    "name": "Orihuela del Tremedal",
    "lat": "40.55",
    "lng": "-1.65"
  },
  {
    "country": "ES",
    "name": "Oria",
    "lat": "43.25541",
    "lng": "-2.01873"
  },
  {
    "country": "ES",
    "name": "Orés",
    "lat": "42.27765",
    "lng": "-1.0015"
  },
  {
    "country": "ES",
    "name": "Orera",
    "lat": "41.29842",
    "lng": "-1.47849"
  },
  {
    "country": "ES",
    "name": "Ourense",
    "lat": "42.33669",
    "lng": "-7.86407"
  },
  {
    "country": "ES",
    "name": "Orendain",
    "lat": "43.07896",
    "lng": "-2.11201"
  },
  {
    "country": "ES",
    "name": "Orexa",
    "lat": "43.09382",
    "lng": "-2.01119"
  },
  {
    "country": "ES",
    "name": "Orea",
    "lat": "40.55725",
    "lng": "-1.72738"
  },
  {
    "country": "ES",
    "name": "Urduña / Orduña",
    "lat": "42.99435",
    "lng": "-3.00974"
  },
  {
    "country": "ES",
    "name": "Ordis",
    "lat": "42.2183",
    "lng": "2.90705"
  },
  {
    "country": "ES",
    "name": "Ordes",
    "lat": "43.07654",
    "lng": "-8.409"
  },
  {
    "country": "ES",
    "name": "Orkoien",
    "lat": "42.8238",
    "lng": "-1.70485"
  },
  {
    "country": "ES",
    "name": "Orcajo",
    "lat": "41.10975",
    "lng": "-1.48933"
  },
  {
    "country": "ES",
    "name": "Orbita",
    "lat": "40.99846",
    "lng": "-4.64833"
  },
  {
    "country": "ES",
    "name": "Orbara",
    "lat": "42.96728",
    "lng": "-1.24213"
  },
  {
    "country": "ES",
    "name": "Oquillas",
    "lat": "41.83085",
    "lng": "-3.70564"
  },
  {
    "country": "ES",
    "name": "Onzonilla",
    "lat": "42.52435",
    "lng": "-5.5816"
  },
  {
    "country": "ES",
    "name": "Ontiñena",
    "lat": "41.67663",
    "lng": "0.08858"
  },
  {
    "country": "ES",
    "name": "Ondarroa",
    "lat": "43.31667",
    "lng": "-2.41667"
  },
  {
    "country": "ES",
    "name": "Oncala",
    "lat": "41.97021",
    "lng": "-2.31493"
  },
  {
    "country": "ES",
    "name": "Oñati",
    "lat": "43.03262",
    "lng": "-2.40997"
  },
  {
    "country": "ES",
    "name": "Oña",
    "lat": "42.734",
    "lng": "-3.41459"
  },
  {
    "country": "ES",
    "name": "Oltza",
    "lat": "42.85",
    "lng": "-1.76667"
  },
  {
    "country": "ES",
    "name": "Olvés",
    "lat": "41.23965",
    "lng": "-1.64647"
  },
  {
    "country": "ES",
    "name": "Olvega",
    "lat": "41.77901",
    "lng": "-1.98391"
  },
  {
    "country": "ES",
    "name": "Olot",
    "lat": "42.18096",
    "lng": "2.49012"
  },
  {
    "country": "ES",
    "name": "Olost",
    "lat": "41.9854",
    "lng": "2.09457"
  },
  {
    "country": "ES",
    "name": "Olóriz",
    "lat": "42.63522",
    "lng": "-1.61276"
  },
  {
    "country": "ES",
    "name": "Olombrada",
    "lat": "41.41492",
    "lng": "-4.16071"
  },
  {
    "country": "ES",
    "name": "Olocau del Rey",
    "lat": "40.63775",
    "lng": "-0.34041"
  },
  {
    "country": "ES",
    "name": "Olmos de Peñafiel",
    "lat": "41.57142",
    "lng": "-4.04316"
  },
  {
    "country": "ES",
    "name": "Olmos de Ojeda",
    "lat": "42.72274",
    "lng": "-4.42446"
  },
  {
    "country": "ES",
    "name": "Olmos de Esgueva",
    "lat": "41.68815",
    "lng": "-4.52255"
  },
  {
    "country": "ES",
    "name": "Olmillos de Muñó",
    "lat": "42.20322",
    "lng": "-3.93911"
  },
  {
    "country": "ES",
    "name": "Olmillos de Castro",
    "lat": "41.73179",
    "lng": "-5.96791"
  },
  {
    "country": "ES",
    "name": "Olmedo de Camaces",
    "lat": "40.87967",
    "lng": "-6.6236"
  },
  {
    "country": "ES",
    "name": "Olmedo",
    "lat": "41.28706",
    "lng": "-4.68878"
  },
  {
    "country": "ES",
    "name": "Olmedillo de Roa",
    "lat": "41.78362",
    "lng": "-3.93419"
  },
  {
    "country": "ES",
    "name": "Olmedilla de Eliz",
    "lat": "40.30232",
    "lng": "-2.41952"
  },
  {
    "country": "ES",
    "name": "Olmeda de la Cuesta",
    "lat": "40.31088",
    "lng": "-2.47592"
  },
  {
    "country": "ES",
    "name": "Olmeda de Cobeta",
    "lat": "40.85971",
    "lng": "-2.1828"
  },
  {
    "country": "ES",
    "name": "Ollauri",
    "lat": "42.54256",
    "lng": "-2.83448"
  },
  {
    "country": "ES",
    "name": "Olivella",
    "lat": "41.31667",
    "lng": "1.81667"
  },
  {
    "country": "ES",
    "name": "Olivares de Duero",
    "lat": "41.63755",
    "lng": "-4.36547"
  },
  {
    "country": "ES",
    "name": "Oliva de Plasencia",
    "lat": "40.11227",
    "lng": "-6.08648"
  },
  {
    "country": "ES",
    "name": "Olius",
    "lat": "42.01035",
    "lng": "1.5646"
  },
  {
    "country": "ES",
    "name": "Olite",
    "lat": "42.47971",
    "lng": "-1.65196"
  },
  {
    "country": "ES",
    "name": "Oliete",
    "lat": "40.99791",
    "lng": "-0.67429"
  },
  {
    "country": "ES",
    "name": "Oliana",
    "lat": "42.06895",
    "lng": "1.31353"
  },
  {
    "country": "ES",
    "name": "Olesa de Montserrat",
    "lat": "41.54372",
    "lng": "1.89407"
  },
  {
    "country": "ES",
    "name": "Olesa de Bonesvalls",
    "lat": "41.35435",
    "lng": "1.84907"
  },
  {
    "country": "ES",
    "name": "Olejua",
    "lat": "42.62329",
    "lng": "-2.14202"
  },
  {
    "country": "ES",
    "name": "Oleiros",
    "lat": "43.33333",
    "lng": "-8.31667"
  },
  {
    "country": "ES",
    "name": "Olea de Boedo",
    "lat": "42.6099",
    "lng": "-4.4504"
  },
  {
    "country": "ES",
    "name": "Olvan",
    "lat": "42.06667",
    "lng": "1.9"
  },
  {
    "country": "ES",
    "name": "Olba",
    "lat": "40.13333",
    "lng": "-0.61667"
  },
  {
    "country": "ES",
    "name": "Olazagutía",
    "lat": "42.87584",
    "lng": "-2.19538"
  },
  {
    "country": "ES",
    "name": "Olaberria",
    "lat": "43.02726",
    "lng": "-2.20349"
  },
  {
    "country": "ES",
    "name": "Ojos Negros",
    "lat": "40.7375",
    "lng": "-1.49875"
  },
  {
    "country": "ES",
    "name": "Ojos-Albos",
    "lat": "40.70596",
    "lng": "-4.51633"
  },
  {
    "country": "ES",
    "name": "Ojacastro",
    "lat": "42.3472",
    "lng": "-3.0049"
  },
  {
    "country": "ES",
    "name": "Oitz",
    "lat": "43.11667",
    "lng": "-1.68333"
  },
  {
    "country": "ES",
    "name": "Oimbra",
    "lat": "41.88554",
    "lng": "-7.47216"
  },
  {
    "country": "ES",
    "name": "Oencia",
    "lat": "42.54758",
    "lng": "-6.96859"
  },
  {
    "country": "ES",
    "name": "Odón",
    "lat": "40.88417",
    "lng": "-1.56792"
  },
  {
    "country": "ES",
    "name": "Òdena",
    "lat": "41.6",
    "lng": "1.65"
  },
  {
    "country": "ES",
    "name": "Ocón",
    "lat": "42.29898",
    "lng": "-2.24019"
  },
  {
    "country": "ES",
    "name": "Oco",
    "lat": "42.63828",
    "lng": "-2.16476"
  },
  {
    "country": "ES",
    "name": "Ochánduri",
    "lat": "42.52525",
    "lng": "-3.00415"
  },
  {
    "country": "ES",
    "name": "Otxandio",
    "lat": "43.03333",
    "lng": "-2.65"
  },
  {
    "country": "ES",
    "name": "Ocentejo",
    "lat": "40.77234",
    "lng": "-2.39764"
  },
  {
    "country": "ES",
    "name": "Obón",
    "lat": "40.9045",
    "lng": "-0.723"
  },
  {
    "country": "ES",
    "name": "Obanos",
    "lat": "42.68071",
    "lng": "-1.78493"
  },
  {
    "country": "ES",
    "name": "Nuñomoral",
    "lat": "40.40692",
    "lng": "-6.24636"
  },
  {
    "country": "ES",
    "name": "Nuño Gómez",
    "lat": "40.11383",
    "lng": "-4.61978"
  },
  {
    "country": "ES",
    "name": "Numancia de la Sagra",
    "lat": "40.07395",
    "lng": "-3.85118"
  },
  {
    "country": "ES",
    "name": "Nuez de Ebro",
    "lat": "41.58957",
    "lng": "-0.66774"
  },
  {
    "country": "ES",
    "name": "Nuevo Baztán",
    "lat": "40.36731",
    "lng": "-3.24125"
  },
  {
    "country": "ES",
    "name": "Nueva Villa de las Torres",
    "lat": "41.26762",
    "lng": "-5.05685"
  },
  {
    "country": "ES",
    "name": "Nuévalos",
    "lat": "41.21185",
    "lng": "-1.78954"
  },
  {
    "country": "ES",
    "name": "Nueno",
    "lat": "42.26697",
    "lng": "-0.43906"
  },
  {
    "country": "ES",
    "name": "Noia",
    "lat": "42.78583",
    "lng": "-8.88734"
  },
  {
    "country": "ES",
    "name": "Novillas",
    "lat": "41.93334",
    "lng": "-1.39412"
  },
  {
    "country": "ES",
    "name": "Noviercas",
    "lat": "41.71194",
    "lng": "-2.03433"
  },
  {
    "country": "ES",
    "name": "Novallas",
    "lat": "41.95",
    "lng": "-1.7"
  },
  {
    "country": "ES",
    "name": "Novales",
    "lat": "42.03201",
    "lng": "-0.287"
  },
  {
    "country": "ES",
    "name": "Noreña",
    "lat": "43.39364",
    "lng": "-5.70662"
  },
  {
    "country": "ES",
    "name": "Nonaspe",
    "lat": "41.20881",
    "lng": "0.24775"
  },
  {
    "country": "ES",
    "name": "Nombrevilla",
    "lat": "41.1073",
    "lng": "-1.35904"
  },
  {
    "country": "ES",
    "name": "Nombela",
    "lat": "40.1553",
    "lng": "-4.50223"
  },
  {
    "country": "ES",
    "name": "Nolay",
    "lat": "41.52721",
    "lng": "-2.35061"
  },
  {
    "country": "ES",
    "name": "Noja",
    "lat": "43.48917",
    "lng": "-3.52306"
  },
  {
    "country": "ES",
    "name": "Nogueruelas",
    "lat": "40.23622",
    "lng": "-0.63606"
  },
  {
    "country": "ES",
    "name": "Nogueras",
    "lat": "41.13475",
    "lng": "-1.06708"
  },
  {
    "country": "ES",
    "name": "Nogueira de Ramuín",
    "lat": "42.41712",
    "lng": "-7.74982"
  },
  {
    "country": "ES",
    "name": "Nogal de las Huertas",
    "lat": "42.39255",
    "lng": "-4.64156"
  },
  {
    "country": "ES",
    "name": "Niharra",
    "lat": "40.58945",
    "lng": "-4.83895"
  },
  {
    "country": "ES",
    "name": "Nigüella",
    "lat": "41.53621",
    "lng": "-1.5245"
  },
  {
    "country": "ES",
    "name": "Nigrán",
    "lat": "42.14153",
    "lng": "-8.80656"
  },
  {
    "country": "ES",
    "name": "Nieva de Cameros",
    "lat": "42.21835",
    "lng": "-2.667"
  },
  {
    "country": "ES",
    "name": "Nieva",
    "lat": "41.08191",
    "lng": "-4.42501"
  },
  {
    "country": "ES",
    "name": "Nestares",
    "lat": "42.27014",
    "lng": "-2.61993"
  },
  {
    "country": "ES",
    "name": "Nepas",
    "lat": "41.52639",
    "lng": "-2.39866"
  },
  {
    "country": "ES",
    "name": "Neila de San Miguel",
    "lat": "40.42372",
    "lng": "-5.6509"
  },
  {
    "country": "ES",
    "name": "Neila",
    "lat": "42.06016",
    "lng": "-2.99691"
  },
  {
    "country": "ES",
    "name": "Negrilla de Palencia",
    "lat": "41.09185",
    "lng": "-5.59165"
  },
  {
    "country": "ES",
    "name": "Negreira",
    "lat": "42.90402",
    "lng": "-8.74273"
  },
  {
    "country": "ES",
    "name": "Negredo",
    "lat": "41.02737",
    "lng": "-2.85878"
  },
  {
    "country": "ES",
    "name": "Nebreda",
    "lat": "41.96881",
    "lng": "-3.6343"
  },
  {
    "country": "ES",
    "name": "Nazar",
    "lat": "42.63686",
    "lng": "-2.27966"
  },
  {
    "country": "ES",
    "name": "Navianos de Valverde",
    "lat": "41.95319",
    "lng": "-5.81781"
  },
  {
    "country": "ES",
    "name": "Navia de Suarna",
    "lat": "42.96667",
    "lng": "-7"
  },
  {
    "country": "ES",
    "name": "Navia",
    "lat": "43.53544",
    "lng": "-6.71935"
  },
  {
    "country": "ES",
    "name": "Navatejares",
    "lat": "40.33602",
    "lng": "-5.5322"
  },
  {
    "country": "ES",
    "name": "Navatalgordo",
    "lat": "40.4152",
    "lng": "-4.87155"
  },
  {
    "country": "ES",
    "name": "Navata",
    "lat": "42.22353",
    "lng": "2.8611"
  },
  {
    "country": "ES",
    "name": "Navasfrías",
    "lat": "40.29679",
    "lng": "-6.81975"
  },
  {
    "country": "ES",
    "name": "Navas de Oro",
    "lat": "41.19627",
    "lng": "-4.43754"
  },
  {
    "country": "ES",
    "name": "Navas del Rey",
    "lat": "40.3861",
    "lng": "-4.25117"
  },
  {
    "country": "ES",
    "name": "Navas de Bureba",
    "lat": "42.6809",
    "lng": "-3.32698"
  },
  {
    "country": "ES",
    "name": "Navascués",
    "lat": "42.71758",
    "lng": "-1.11744"
  },
  {
    "country": "ES",
    "name": "Navàs",
    "lat": "41.89998",
    "lng": "1.87763"
  },
  {
    "country": "ES",
    "name": "Navarrevisca",
    "lat": "40.36417",
    "lng": "-4.89352"
  },
  {
    "country": "ES",
    "name": "Navarrete",
    "lat": "42.43068",
    "lng": "-2.56466"
  },
  {
    "country": "ES",
    "name": "Navarredondilla",
    "lat": "40.45416",
    "lng": "-4.82199"
  },
  {
    "country": "ES",
    "name": "Navarredonda de la Rinconada",
    "lat": "40.60657",
    "lng": "-6.01169"
  },
  {
    "country": "ES",
    "name": "Navaridas",
    "lat": "42.54566",
    "lng": "-2.6265"
  },
  {
    "country": "ES",
    "name": "Navares de las Cuevas",
    "lat": "41.41431",
    "lng": "-3.75076"
  },
  {
    "country": "ES",
    "name": "Navares de Enmedio",
    "lat": "41.38096",
    "lng": "-3.72283"
  },
  {
    "country": "ES",
    "name": "Navares de Ayuso",
    "lat": "41.37447",
    "lng": "-3.70745"
  },
  {
    "country": "ES",
    "name": "Navardún",
    "lat": "42.51255",
    "lng": "-1.14822"
  },
  {
    "country": "ES",
    "name": "Navarcles",
    "lat": "41.75171",
    "lng": "1.90357"
  },
  {
    "country": "ES",
    "name": "Navaquesera",
    "lat": "40.42558",
    "lng": "-4.91108"
  },
  {
    "country": "ES",
    "name": "Navamorcuende",
    "lat": "40.15659",
    "lng": "-4.78625"
  },
  {
    "country": "ES",
    "name": "Navamorales",
    "lat": "40.47618",
    "lng": "-5.47893"
  },
  {
    "country": "ES",
    "name": "Navaluenga",
    "lat": "40.41123",
    "lng": "-4.70897"
  },
  {
    "country": "ES",
    "name": "Navalquejigo",
    "lat": "40.60705",
    "lng": "-4.04966"
  },
  {
    "country": "ES",
    "name": "Navalperal de Tormes",
    "lat": "40.3528",
    "lng": "-5.30084"
  },
  {
    "country": "ES",
    "name": "Navalperal de Pinares",
    "lat": "40.59398",
    "lng": "-4.41149"
  },
  {
    "country": "ES",
    "name": "Navalosa",
    "lat": "40.40212",
    "lng": "-4.92999"
  },
  {
    "country": "ES",
    "name": "Navalmoral de Béjar",
    "lat": "40.42264",
    "lng": "-5.7831"
  },
  {
    "country": "ES",
    "name": "Navalmoral",
    "lat": "40.46028",
    "lng": "-4.76859"
  },
  {
    "country": "ES",
    "name": "Navalmanzano",
    "lat": "41.21594",
    "lng": "-4.25631"
  },
  {
    "country": "ES",
    "name": "Navalilla",
    "lat": "41.34146",
    "lng": "-3.93211"
  },
  {
    "country": "ES",
    "name": "Navales",
    "lat": "40.78857",
    "lng": "-5.47863"
  },
  {
    "country": "ES",
    "name": "Navaleno",
    "lat": "41.8383",
    "lng": "-3.00418"
  },
  {
    "country": "ES",
    "name": "Navalcarnero",
    "lat": "40.28908",
    "lng": "-4.01197"
  },
  {
    "country": "ES",
    "name": "Navalcán",
    "lat": "40.06667",
    "lng": "-5.08333"
  },
  {
    "country": "ES",
    "name": "Navalagamella",
    "lat": "40.46894",
    "lng": "-4.12334"
  },
  {
    "country": "ES",
    "name": "Navalafuente",
    "lat": "40.82063",
    "lng": "-3.67266"
  },
  {
    "country": "ES",
    "name": "Navalacruz",
    "lat": "40.43993",
    "lng": "-4.93122"
  },
  {
    "country": "ES",
    "name": "Naval",
    "lat": "42.19503",
    "lng": "0.15183"
  },
  {
    "country": "ES",
    "name": "Navajún",
    "lat": "41.96667",
    "lng": "-2.1"
  },
  {
    "country": "ES",
    "name": "Navahondilla",
    "lat": "40.3251",
    "lng": "-4.49661"
  },
  {
    "country": "ES",
    "name": "Navafría",
    "lat": "41.05514",
    "lng": "-3.82478"
  },
  {
    "country": "ES",
    "name": "Navaescurial",
    "lat": "40.47163",
    "lng": "-5.27756"
  },
  {
    "country": "ES",
    "name": "Navadijos",
    "lat": "40.42524",
    "lng": "-5.08285"
  },
  {
    "country": "ES",
    "name": "Nava de Sotrobal",
    "lat": "40.89039",
    "lng": "-5.28562"
  },
  {
    "country": "ES",
    "name": "Nava de Roa",
    "lat": "41.61326",
    "lng": "-3.96442"
  },
  {
    "country": "ES",
    "name": "Nava del Rey",
    "lat": "41.33036",
    "lng": "-5.08095"
  },
  {
    "country": "ES",
    "name": "Nava del Barco",
    "lat": "40.29321",
    "lng": "-5.54022"
  },
  {
    "country": "ES",
    "name": "Nava de la Asunción",
    "lat": "41.15586",
    "lng": "-4.48751"
  },
  {
    "country": "ES",
    "name": "Nava de Francia",
    "lat": "40.53572",
    "lng": "-6.11628"
  },
  {
    "country": "ES",
    "name": "Nava de Béjar",
    "lat": "40.47518",
    "lng": "-5.67856"
  },
  {
    "country": "ES",
    "name": "Nava de Arévalo",
    "lat": "40.97803",
    "lng": "-4.77573"
  },
  {
    "country": "ES",
    "name": "Navaconcejo",
    "lat": "40.17712",
    "lng": "-5.83108"
  },
  {
    "country": "ES",
    "name": "Navacerrada",
    "lat": "40.72905",
    "lng": "-4.01696"
  },
  {
    "country": "ES",
    "name": "Navacepedilla de Corneja",
    "lat": "40.48602",
    "lng": "-5.1838"
  },
  {
    "country": "ES",
    "name": "Navacarros",
    "lat": "40.39776",
    "lng": "-5.71425"
  },
  {
    "country": "ES",
    "name": "Nava",
    "lat": "43.3581",
    "lng": "-5.51064"
  },
  {
    "country": "ES",
    "name": "Narros de Saldueña",
    "lat": "40.87268",
    "lng": "-4.86909"
  },
  {
    "country": "ES",
    "name": "Narros de Matalayegua",
    "lat": "40.6988",
    "lng": "-5.92658"
  },
  {
    "country": "ES",
    "name": "Narros del Puerto",
    "lat": "40.54131",
    "lng": "-4.99291"
  },
  {
    "country": "ES",
    "name": "Narros del Castillo",
    "lat": "40.85869",
    "lng": "-5.0601"
  },
  {
    "country": "ES",
    "name": "Narros",
    "lat": "41.84923",
    "lng": "-2.29474"
  },
  {
    "country": "ES",
    "name": "Narrillos del Rebollar",
    "lat": "40.66488",
    "lng": "-4.96577"
  },
  {
    "country": "ES",
    "name": "Narrillos del Álamo",
    "lat": "40.56673",
    "lng": "-5.46584"
  },
  {
    "country": "ES",
    "name": "Narón",
    "lat": "43.50175",
    "lng": "-8.19082"
  },
  {
    "country": "ES",
    "name": "Nalec",
    "lat": "41.55",
    "lng": "1.11667"
  },
  {
    "country": "ES",
    "name": "Nalda",
    "lat": "42.33467",
    "lng": "-2.4871"
  },
  {
    "country": "ES",
    "name": "Nájera",
    "lat": "42.41822",
    "lng": "-2.72865"
  },
  {
    "country": "ES",
    "name": "Nafría de Ucero",
    "lat": "41.72273",
    "lng": "-3.09499"
  },
  {
    "country": "ES",
    "name": "Mutiloa",
    "lat": "43.02288",
    "lng": "-2.27257"
  },
  {
    "country": "ES",
    "name": "Muruzábal",
    "lat": "42.69051",
    "lng": "-1.76931"
  },
  {
    "country": "ES",
    "name": "Muros de Nalón",
    "lat": "43.54277",
    "lng": "-6.10348"
  },
  {
    "country": "ES",
    "name": "Muros",
    "lat": "42.77617",
    "lng": "-9.06032"
  },
  {
    "country": "ES",
    "name": "Muro en Cameros",
    "lat": "42.22509",
    "lng": "-2.53038"
  },
  {
    "country": "ES",
    "name": "Muro de Aguas",
    "lat": "42.13364",
    "lng": "-2.11175"
  },
  {
    "country": "ES",
    "name": "Murillo el Fruto",
    "lat": "42.39272",
    "lng": "-1.46034"
  },
  {
    "country": "ES",
    "name": "Murillo de Río Leza",
    "lat": "42.40099",
    "lng": "-2.32464"
  },
  {
    "country": "ES",
    "name": "Murieta",
    "lat": "42.65618",
    "lng": "-2.15452"
  },
  {
    "country": "ES",
    "name": "Muriel Viejo",
    "lat": "41.78261",
    "lng": "-2.91522"
  },
  {
    "country": "ES",
    "name": "Muriel de la Fuente",
    "lat": "41.7232",
    "lng": "-2.86"
  },
  {
    "country": "ES",
    "name": "Murias de Paredes",
    "lat": "42.85027",
    "lng": "-6.19164"
  },
  {
    "country": "ES",
    "name": "Murgia",
    "lat": "42.95686",
    "lng": "-2.81945"
  },
  {
    "country": "ES",
    "name": "Murero",
    "lat": "41.15967",
    "lng": "-1.48275"
  },
  {
    "country": "ES",
    "name": "Murchante",
    "lat": "42.03185",
    "lng": "-1.65582"
  },
  {
    "country": "ES",
    "name": "Muras",
    "lat": "43.46685",
    "lng": "-7.72383"
  },
  {
    "country": "ES",
    "name": "Mura",
    "lat": "41.69943",
    "lng": "1.97612"
  },
  {
    "country": "ES",
    "name": "Muñoveros",
    "lat": "41.17234",
    "lng": "-3.95161"
  },
  {
    "country": "ES",
    "name": "Muñotello",
    "lat": "40.54236",
    "lng": "-5.04187"
  },
  {
    "country": "ES",
    "name": "Muñosancho",
    "lat": "40.92097",
    "lng": "-5.03559"
  },
  {
    "country": "ES",
    "name": "Muñopepe",
    "lat": "40.63408",
    "lng": "-4.81876"
  },
  {
    "country": "ES",
    "name": "Muñopedro",
    "lat": "40.88804",
    "lng": "-4.47213"
  },
  {
    "country": "ES",
    "name": "Muñomer del Peco",
    "lat": "40.85878",
    "lng": "-4.87992"
  },
  {
    "country": "ES",
    "name": "Muñogrande",
    "lat": "40.82181",
    "lng": "-4.92223"
  },
  {
    "country": "ES",
    "name": "Muñogalindo",
    "lat": "40.60324",
    "lng": "-4.89895"
  },
  {
    "country": "ES",
    "name": "Munilla",
    "lat": "42.189",
    "lng": "-2.29506"
  },
  {
    "country": "ES",
    "name": "Muniesa",
    "lat": "41.03308",
    "lng": "-0.81141"
  },
  {
    "country": "ES",
    "name": "Muñico",
    "lat": "40.70678",
    "lng": "-5.02717"
  },
  {
    "country": "ES",
    "name": "Mungia",
    "lat": "43.35461",
    "lng": "-2.84524"
  },
  {
    "country": "ES",
    "name": "Munébrega",
    "lat": "41.25203",
    "lng": "-1.70557"
  },
  {
    "country": "ES",
    "name": "Mundaka",
    "lat": "43.40804",
    "lng": "-2.69852"
  },
  {
    "country": "ES",
    "name": "Muñana",
    "lat": "40.59042",
    "lng": "-5.01447"
  },
  {
    "country": "ES",
    "name": "Muiños",
    "lat": "41.95609",
    "lng": "-7.97396"
  },
  {
    "country": "ES",
    "name": "Mugia",
    "lat": "43.10414",
    "lng": "-9.21791"
  },
  {
    "country": "ES",
    "name": "Mugardos",
    "lat": "43.4604",
    "lng": "-8.25507"
  },
  {
    "country": "ES",
    "name": "Muga de Sayago",
    "lat": "41.38779",
    "lng": "-6.19777"
  },
  {
    "country": "ES",
    "name": "Muelas de los Caballeros",
    "lat": "42.12843",
    "lng": "-6.33719"
  },
  {
    "country": "ES",
    "name": "Muel",
    "lat": "41.46633",
    "lng": "-1.08503"
  },
  {
    "country": "ES",
    "name": "Muduex",
    "lat": "40.8293",
    "lng": "-2.95899"
  },
  {
    "country": "ES",
    "name": "Mudá",
    "lat": "42.8753",
    "lng": "-4.39426"
  },
  {
    "country": "ES",
    "name": "Mucientes",
    "lat": "41.74278",
    "lng": "-4.76191"
  },
  {
    "country": "ES",
    "name": "Mozota",
    "lat": "41.4841",
    "lng": "-1.06807"
  },
  {
    "country": "ES",
    "name": "Mozoncillo",
    "lat": "41.14539",
    "lng": "-4.18753"
  },
  {
    "country": "ES",
    "name": "Mozárbez",
    "lat": "40.85652",
    "lng": "-5.65144"
  },
  {
    "country": "ES",
    "name": "Moyuela",
    "lat": "41.12792",
    "lng": "-0.92225"
  },
  {
    "country": "ES",
    "name": "Moià",
    "lat": "41.81112",
    "lng": "2.09839"
  },
  {
    "country": "ES",
    "name": "Mutriku",
    "lat": "43.30643",
    "lng": "-2.38517"
  },
  {
    "country": "ES",
    "name": "Mota del Marqués",
    "lat": "41.63247",
    "lng": "-5.17681"
  },
  {
    "country": "ES",
    "name": "Móstoles",
    "lat": "40.32234",
    "lng": "-3.86496"
  },
  {
    "country": "ES",
    "name": "Mosqueruela",
    "lat": "40.36133",
    "lng": "-0.4489"
  },
  {
    "country": "ES",
    "name": "Moscardón",
    "lat": "40.33295",
    "lng": "-1.53683"
  },
  {
    "country": "ES",
    "name": "Mos",
    "lat": "43.15667",
    "lng": "-7.55047"
  },
  {
    "country": "ES",
    "name": "Moros",
    "lat": "41.39775",
    "lng": "-1.82839"
  },
  {
    "country": "ES",
    "name": "Moronta",
    "lat": "40.97688",
    "lng": "-6.43103"
  },
  {
    "country": "ES",
    "name": "Morón de Almazán",
    "lat": "41.41361",
    "lng": "-2.41317"
  },
  {
    "country": "ES",
    "name": "Moriscos",
    "lat": "41.00818",
    "lng": "-5.58184"
  },
  {
    "country": "ES",
    "name": "Morille",
    "lat": "40.80693",
    "lng": "-5.69833"
  },
  {
    "country": "ES",
    "name": "Morés",
    "lat": "41.47326",
    "lng": "-1.56491"
  },
  {
    "country": "ES",
    "name": "Moreruela de Tábara",
    "lat": "41.79588",
    "lng": "-5.86849"
  },
  {
    "country": "ES",
    "name": "Moreruela de los Infanzones",
    "lat": "41.63118",
    "lng": "-5.70614"
  },
  {
    "country": "ES",
    "name": "Morentin",
    "lat": "42.61286",
    "lng": "-2.01393"
  },
  {
    "country": "ES",
    "name": "Morenilla",
    "lat": "40.78687",
    "lng": "-1.70717"
  },
  {
    "country": "ES",
    "name": "Morella",
    "lat": "40.61966",
    "lng": "-0.09892"
  },
  {
    "country": "ES",
    "name": "Moreda Araba / Moreda de Álava",
    "lat": "42.52571",
    "lng": "-2.40828"
  },
  {
    "country": "ES",
    "name": "Morcillo",
    "lat": "40.01884",
    "lng": "-6.39746"
  },
  {
    "country": "ES",
    "name": "Moratinos",
    "lat": "42.36191",
    "lng": "-4.92831"
  },
  {
    "country": "ES",
    "name": "Moratilla de los Meleros",
    "lat": "40.50182",
    "lng": "-2.94276"
  },
  {
    "country": "ES",
    "name": "Moratalaz",
    "lat": "40.40742",
    "lng": "-3.64935"
  },
  {
    "country": "ES",
    "name": "Morata de Tajuña",
    "lat": "40.2268",
    "lng": "-3.43269"
  },
  {
    "country": "ES",
    "name": "Morata de Jiloca",
    "lat": "41.24797",
    "lng": "-1.58665"
  },
  {
    "country": "ES",
    "name": "Morata de Jalón",
    "lat": "41.47348",
    "lng": "-1.47628"
  },
  {
    "country": "ES",
    "name": "Morasverdes",
    "lat": "40.60019",
    "lng": "-6.27503"
  },
  {
    "country": "ES",
    "name": "Moraña",
    "lat": "42.55",
    "lng": "-8.58333"
  },
  {
    "country": "ES",
    "name": "Moralzarzal",
    "lat": "40.67816",
    "lng": "-3.9707"
  },
  {
    "country": "ES",
    "name": "Moralina",
    "lat": "41.49001",
    "lng": "-6.1367"
  },
  {
    "country": "ES",
    "name": "Morales de Valverde",
    "lat": "41.93643",
    "lng": "-5.89255"
  },
  {
    "country": "ES",
    "name": "Morales de Toro",
    "lat": "41.53737",
    "lng": "-5.30642"
  },
  {
    "country": "ES",
    "name": "Morales del Vino",
    "lat": "41.44736",
    "lng": "-5.7307"
  },
  {
    "country": "ES",
    "name": "Morales de Campos",
    "lat": "41.86068",
    "lng": "-5.17252"
  },
  {
    "country": "ES",
    "name": "Moraleja de Sayago",
    "lat": "41.16916",
    "lng": "-6.00369"
  },
  {
    "country": "ES",
    "name": "Moraleja de Matacabras",
    "lat": "41.10732",
    "lng": "-4.95717"
  },
  {
    "country": "ES",
    "name": "Moraleja del Vino",
    "lat": "41.46385",
    "lng": "-5.65631"
  },
  {
    "country": "ES",
    "name": "Moraleja de las Panaderas",
    "lat": "41.27636",
    "lng": "-4.82521"
  },
  {
    "country": "ES",
    "name": "Moraleja de Enmedio",
    "lat": "40.26125",
    "lng": "-3.85963"
  },
  {
    "country": "ES",
    "name": "Moraleja",
    "lat": "40.06682",
    "lng": "-6.65983"
  },
  {
    "country": "ES",
    "name": "Moral de Sayago",
    "lat": "41.47019",
    "lng": "-6.1006"
  },
  {
    "country": "ES",
    "name": "Moral de la Reina",
    "lat": "41.98611",
    "lng": "-5.07208"
  },
  {
    "country": "ES",
    "name": "Moradillo de Roa",
    "lat": "41.55164",
    "lng": "-3.79118"
  },
  {
    "country": "ES",
    "name": "Mora de Rubielos",
    "lat": "40.2502",
    "lng": "-0.75249"
  },
  {
    "country": "ES",
    "name": "Monzón de Campos",
    "lat": "42.11604",
    "lng": "-4.49283"
  },
  {
    "country": "ES",
    "name": "Monzón",
    "lat": "41.91084",
    "lng": "0.19406"
  },
  {
    "country": "ES",
    "name": "Mont-roig del Camp",
    "lat": "41.08675",
    "lng": "0.95925"
  },
  {
    "country": "ES",
    "name": "Mont-ral",
    "lat": "41.28333",
    "lng": "1.1"
  },
  {
    "country": "ES",
    "name": "Montornès del Vallès",
    "lat": "41.54206",
    "lng": "2.26748"
  },
  {
    "country": "ES",
    "name": "Montorio",
    "lat": "42.58469",
    "lng": "-3.77724"
  },
  {
    "country": "ES",
    "name": "Montón",
    "lat": "41.20667",
    "lng": "-1.5155"
  },
  {
    "country": "ES",
    "name": "Montmeló",
    "lat": "41.55002",
    "lng": "2.2419"
  },
  {
    "country": "ES",
    "name": "Montferri",
    "lat": "41.26545",
    "lng": "1.36517"
  },
  {
    "country": "ES",
    "name": "Montesquiu",
    "lat": "42.11667",
    "lng": "2.21667"
  },
  {
    "country": "ES",
    "name": "Montesclaros",
    "lat": "40.10646",
    "lng": "-4.93849"
  },
  {
    "country": "ES",
    "name": "Monterrubio de la Sierra",
    "lat": "40.75592",
    "lng": "-5.69329"
  },
  {
    "country": "ES",
    "name": "Monterrubio de Armuña",
    "lat": "41.02651",
    "lng": "-5.64389"
  },
  {
    "country": "ES",
    "name": "Monterrubio",
    "lat": "40.84914",
    "lng": "-4.35001"
  },
  {
    "country": "ES",
    "name": "Monterroso",
    "lat": "42.7925",
    "lng": "-7.83425"
  },
  {
    "country": "ES",
    "name": "Monterde de Albarracín",
    "lat": "40.49708",
    "lng": "-1.49216"
  },
  {
    "country": "ES",
    "name": "Monterde",
    "lat": "41.17434",
    "lng": "-1.73505"
  },
  {
    "country": "ES",
    "name": "Montenegro de Cameros",
    "lat": "42.08924",
    "lng": "-2.75406"
  },
  {
    "country": "ES",
    "name": "Montemayor de Pililla",
    "lat": "41.50874",
    "lng": "-4.45745"
  },
  {
    "country": "ES",
    "name": "Montemayor del Río",
    "lat": "40.34836",
    "lng": "-5.89427"
  },
  {
    "country": "ES",
    "name": "Montejo de Tiermes",
    "lat": "41.36838",
    "lng": "-3.20016"
  },
  {
    "country": "ES",
    "name": "Montejo de la Vega de la Serrezuela",
    "lat": "41.55032",
    "lng": "-3.65406"
  },
  {
    "country": "ES",
    "name": "Montejo de la Sierra",
    "lat": "41.05955",
    "lng": "-3.52993"
  },
  {
    "country": "ES",
    "name": "Montejo de Arévalo",
    "lat": "41.14027",
    "lng": "-4.66414"
  },
  {
    "country": "ES",
    "name": "Montejo",
    "lat": "40.63246",
    "lng": "-5.62287"
  },
  {
    "country": "ES",
    "name": "Montehermoso",
    "lat": "40.08796",
    "lng": "-6.34984"
  },
  {
    "country": "ES",
    "name": "Montederramo",
    "lat": "42.27554",
    "lng": "-7.50138"
  },
  {
    "country": "ES",
    "name": "Monteagudo del Castillo",
    "lat": "40.45656",
    "lng": "-0.81781"
  },
  {
    "country": "ES",
    "name": "Monteagudo de las Vicarías",
    "lat": "41.36485",
    "lng": "-2.1696"
  },
  {
    "country": "ES",
    "name": "Monteagudo",
    "lat": "41.96667",
    "lng": "-1.68333"
  },
  {
    "country": "ES",
    "name": "Montblanc",
    "lat": "41.37636",
    "lng": "1.16163"
  },
  {
    "country": "ES",
    "name": "Montarrón",
    "lat": "40.90675",
    "lng": "-3.11495"
  },
  {
    "country": "ES",
    "name": "Muntanyola",
    "lat": "41.88333",
    "lng": "2.18333"
  },
  {
    "country": "ES",
    "name": "Montanejos",
    "lat": "40.06667",
    "lng": "-0.51667"
  },
  {
    "country": "ES",
    "name": "Montán",
    "lat": "40.03333",
    "lng": "-0.55"
  },
  {
    "country": "ES",
    "name": "Montamarta",
    "lat": "41.64724",
    "lng": "-5.80402"
  },
  {
    "country": "ES",
    "name": "Montalbán",
    "lat": "40.83278",
    "lng": "-0.80178"
  },
  {
    "country": "ES",
    "name": "Monsalupe",
    "lat": "40.76953",
    "lng": "-4.78131"
  },
  {
    "country": "ES",
    "name": "Monsagro",
    "lat": "40.50343",
    "lng": "-6.2711"
  },
  {
    "country": "ES",
    "name": "Monroyo",
    "lat": "40.78775",
    "lng": "-0.0355"
  },
  {
    "country": "ES",
    "name": "Monreal del Campo",
    "lat": "40.788",
    "lng": "-1.35541"
  },
  {
    "country": "ES",
    "name": "Monreal de Ariza",
    "lat": "41.29165",
    "lng": "-2.10493"
  },
  {
    "country": "ES",
    "name": "Monreal",
    "lat": "42.70421",
    "lng": "-1.50785"
  },
  {
    "country": "ES",
    "name": "Monleras",
    "lat": "41.18704",
    "lng": "-6.22622"
  },
  {
    "country": "ES",
    "name": "Monleón",
    "lat": "40.58192",
    "lng": "-5.84312"
  },
  {
    "country": "ES",
    "name": "Monistrol de Montserrat",
    "lat": "41.61667",
    "lng": "1.85"
  },
  {
    "country": "ES",
    "name": "Montgat",
    "lat": "41.46859",
    "lng": "2.28001"
  },
  {
    "country": "ES",
    "name": "Monforte de Moyuela",
    "lat": "41.05512",
    "lng": "-1.01411"
  },
  {
    "country": "ES",
    "name": "Monforte de Lemos",
    "lat": "42.52165",
    "lng": "-7.51422"
  },
  {
    "country": "ES",
    "name": "Monforte de la Sierra",
    "lat": "40.48264",
    "lng": "-6.05671"
  },
  {
    "country": "ES",
    "name": "Monfero",
    "lat": "43.33333",
    "lng": "-8.01667"
  },
  {
    "country": "ES",
    "name": "Monfarracinos",
    "lat": "41.55468",
    "lng": "-5.70795"
  },
  {
    "country": "ES",
    "name": "Moneva",
    "lat": "41.12817",
    "lng": "-0.83591"
  },
  {
    "country": "ES",
    "name": "Monegrillo",
    "lat": "41.63856",
    "lng": "-0.4157"
  },
  {
    "country": "ES",
    "name": "Arrasate / Mondragón",
    "lat": "43.06441",
    "lng": "-2.48977"
  },
  {
    "country": "ES",
    "name": "Mondoñedo",
    "lat": "43.4",
    "lng": "-7.4"
  },
  {
    "country": "ES",
    "name": "Mondéjar",
    "lat": "40.32095",
    "lng": "-3.10686"
  },
  {
    "country": "ES",
    "name": "Mondariz-Balneario",
    "lat": "42.22686",
    "lng": "-8.46728"
  },
  {
    "country": "ES",
    "name": "Mondariz",
    "lat": "42.2311",
    "lng": "-8.45839"
  },
  {
    "country": "ES",
    "name": "Moncalvillo",
    "lat": "41.95413",
    "lng": "-3.19886"
  },
  {
    "country": "ES",
    "name": "Montcada i Reixac",
    "lat": "41.48333",
    "lng": "2.18333"
  },
  {
    "country": "ES",
    "name": "Monasterio de Vega",
    "lat": "42.23015",
    "lng": "-5.18095"
  },
  {
    "country": "ES",
    "name": "Monasterio de Rodilla",
    "lat": "42.45775",
    "lng": "-3.46965"
  },
  {
    "country": "ES",
    "name": "Monasterio de la Sierra",
    "lat": "42.0518",
    "lng": "-3.19314"
  },
  {
    "country": "ES",
    "name": "Monasterio",
    "lat": "40.98547",
    "lng": "-3.09711"
  },
  {
    "country": "ES",
    "name": "Mombuey",
    "lat": "42.02283",
    "lng": "-6.33027"
  },
  {
    "country": "ES",
    "name": "Momblona",
    "lat": "41.4442",
    "lng": "-2.3466"
  },
  {
    "country": "ES",
    "name": "Mombeltrán",
    "lat": "40.25987",
    "lng": "-5.01749"
  },
  {
    "country": "ES",
    "name": "Mollet de Peralada",
    "lat": "42.35959",
    "lng": "3.00034"
  },
  {
    "country": "ES",
    "name": "Mollet del Vallès",
    "lat": "41.54026",
    "lng": "2.21306"
  },
  {
    "country": "ES",
    "name": "Mollerussa",
    "lat": "41.63333",
    "lng": "0.9"
  },
  {
    "country": "ES",
    "name": "Molledo",
    "lat": "43.14974",
    "lng": "-4.04239"
  },
  {
    "country": "ES",
    "name": "Molins de Rei",
    "lat": "41.41667",
    "lng": "2.01667"
  },
  {
    "country": "ES",
    "name": "Molinos de Duero",
    "lat": "41.88603",
    "lng": "-2.78682"
  },
  {
    "country": "ES",
    "name": "Molinos",
    "lat": "40.821",
    "lng": "-0.45017"
  },
  {
    "country": "ES",
    "name": "Molinillo",
    "lat": "40.46898",
    "lng": "-5.94493"
  },
  {
    "country": "ES",
    "name": "Molinaseca",
    "lat": "42.53829",
    "lng": "-6.51997"
  },
  {
    "country": "ES",
    "name": "Molina de Aragón",
    "lat": "40.84358",
    "lng": "-1.88762"
  },
  {
    "country": "ES",
    "name": "Molezuelas de la Carballeda",
    "lat": "42.08166",
    "lng": "-6.18723"
  },
  {
    "country": "ES",
    "name": "Molacillos",
    "lat": "41.58269",
    "lng": "-5.66046"
  },
  {
    "country": "ES",
    "name": "Mojados",
    "lat": "41.43237",
    "lng": "-4.6649"
  },
  {
    "country": "ES",
    "name": "Mohernando",
    "lat": "40.80129",
    "lng": "-3.17234"
  },
  {
    "country": "ES",
    "name": "Mogarraz",
    "lat": "40.49264",
    "lng": "-6.05327"
  },
  {
    "country": "ES",
    "name": "Moeche",
    "lat": "43.55",
    "lng": "-8.01667"
  },
  {
    "country": "ES",
    "name": "Modúbar de la Emparedada",
    "lat": "42.26118",
    "lng": "-3.65965"
  },
  {
    "country": "ES",
    "name": "Mochales",
    "lat": "41.09647",
    "lng": "-2.0156"
  },
  {
    "country": "ES",
    "name": "Moaña",
    "lat": "42.28333",
    "lng": "-8.75"
  },
  {
    "country": "ES",
    "name": "Mironcillo",
    "lat": "40.55435",
    "lng": "-4.82449"
  },
  {
    "country": "ES",
    "name": "Miravet",
    "lat": "41.0393",
    "lng": "0.59665"
  },
  {
    "country": "ES",
    "name": "Miraveche",
    "lat": "42.67396",
    "lng": "-3.19947"
  },
  {
    "country": "ES",
    "name": "Miranda del Castañar",
    "lat": "40.48448",
    "lng": "-5.99581"
  },
  {
    "country": "ES",
    "name": "Miranda de Ebro",
    "lat": "42.6865",
    "lng": "-2.94695"
  },
  {
    "country": "ES",
    "name": "Miranda de Azán",
    "lat": "40.88752",
    "lng": "-5.68182"
  },
  {
    "country": "ES",
    "name": "Miranda de Arga",
    "lat": "42.48337",
    "lng": "-1.82759"
  },
  {
    "country": "ES",
    "name": "Mirambel",
    "lat": "40.58733",
    "lng": "-0.34266"
  },
  {
    "country": "ES",
    "name": "Miralrío",
    "lat": "40.88901",
    "lng": "-2.9434"
  },
  {
    "country": "ES",
    "name": "Miralcamp",
    "lat": "41.60516",
    "lng": "0.87987"
  },
  {
    "country": "ES",
    "name": "Mirafuentes",
    "lat": "42.62297",
    "lng": "-2.27966"
  },
  {
    "country": "ES",
    "name": "Miraflores de la Sierra",
    "lat": "40.8155",
    "lng": "-3.76213"
  },
  {
    "country": "ES",
    "name": "Mirabueno",
    "lat": "40.94479",
    "lng": "-2.72438"
  },
  {
    "country": "ES",
    "name": "Miño de San Esteban",
    "lat": "41.53584",
    "lng": "-3.34579"
  },
  {
    "country": "ES",
    "name": "Miño",
    "lat": "43.35",
    "lng": "-8.2"
  },
  {
    "country": "ES",
    "name": "Mingorría",
    "lat": "40.75192",
    "lng": "-4.66583"
  },
  {
    "country": "ES",
    "name": "Milmarcos",
    "lat": "41.08622",
    "lng": "-1.87652"
  },
  {
    "country": "ES",
    "name": "Milles de la Polvorosa",
    "lat": "41.92339",
    "lng": "-5.73309"
  },
  {
    "country": "ES",
    "name": "Millana",
    "lat": "40.50717",
    "lng": "-2.57116"
  },
  {
    "country": "ES",
    "name": "Milagros",
    "lat": "41.575",
    "lng": "-3.69907"
  },
  {
    "country": "ES",
    "name": "Milagro",
    "lat": "42.2416",
    "lng": "-1.76588"
  },
  {
    "country": "ES",
    "name": "Mijares",
    "lat": "40.29655",
    "lng": "-4.83651"
  },
  {
    "country": "ES",
    "name": "Migueláñez",
    "lat": "41.12155",
    "lng": "-4.3641"
  },
  {
    "country": "ES",
    "name": "Mieza",
    "lat": "41.16424",
    "lng": "-6.69137"
  },
  {
    "country": "ES",
    "name": "Mieres",
    "lat": "43.25",
    "lng": "-5.76667"
  },
  {
    "country": "ES",
    "name": "Mieres",
    "lat": "42.12247",
    "lng": "2.6385"
  },
  {
    "country": "ES",
    "name": "Miengo",
    "lat": "43.42861",
    "lng": "-3.99866"
  },
  {
    "country": "ES",
    "name": "Miedes de Atienza",
    "lat": "41.26672",
    "lng": "-2.96375"
  },
  {
    "country": "ES",
    "name": "Micieces de Ojeda",
    "lat": "42.69078",
    "lng": "-4.46166"
  },
  {
    "country": "ES",
    "name": "Micereces de Tera",
    "lat": "41.98886",
    "lng": "-5.87133"
  },
  {
    "country": "ES",
    "name": "Mianos",
    "lat": "42.58544",
    "lng": "-0.95478"
  },
  {
    "country": "ES",
    "name": "Mezquita de Jarque",
    "lat": "40.721",
    "lng": "-0.867"
  },
  {
    "country": "ES",
    "name": "Mezalocha",
    "lat": "41.42581",
    "lng": "-1.08276"
  },
  {
    "country": "ES",
    "name": "Metauten",
    "lat": "42.67714",
    "lng": "-2.13015"
  },
  {
    "country": "ES",
    "name": "Mesones de Isuela",
    "lat": "41.55119",
    "lng": "-1.53858"
  },
  {
    "country": "ES",
    "name": "Mesia",
    "lat": "43.1",
    "lng": "-8.26667"
  },
  {
    "country": "ES",
    "name": "Mesegar de Corneja",
    "lat": "40.50209",
    "lng": "-5.30131"
  },
  {
    "country": "ES",
    "name": "Mequinensa / Mequinenza",
    "lat": "41.37211",
    "lng": "0.30169"
  },
  {
    "country": "ES",
    "name": "Méntrida",
    "lat": "40.23899",
    "lng": "-4.19337"
  },
  {
    "country": "ES",
    "name": "Mengamuñoz",
    "lat": "40.50006",
    "lng": "-4.99983"
  },
  {
    "country": "ES",
    "name": "Meneses de Campos",
    "lat": "41.94142",
    "lng": "-4.91927"
  },
  {
    "country": "ES",
    "name": "Mendigorría",
    "lat": "42.62822",
    "lng": "-1.8345"
  },
  {
    "country": "ES",
    "name": "Mendavia",
    "lat": "42.44335",
    "lng": "-2.20087"
  },
  {
    "country": "ES",
    "name": "Mendaro",
    "lat": "43.25326",
    "lng": "-2.38568"
  },
  {
    "country": "ES",
    "name": "Membrillera",
    "lat": "40.94807",
    "lng": "-2.97969"
  },
  {
    "country": "ES",
    "name": "Membribe de la Sierra",
    "lat": "40.69123",
    "lng": "-5.80568"
  },
  {
    "country": "ES",
    "name": "Membibre de la Hoz",
    "lat": "41.44958",
    "lng": "-4.09571"
  },
  {
    "country": "ES",
    "name": "Melque de Cercos",
    "lat": "41.05166",
    "lng": "-4.46944"
  },
  {
    "country": "ES",
    "name": "Melón",
    "lat": "42.26016",
    "lng": "-8.214"
  },
  {
    "country": "ES",
    "name": "Melide",
    "lat": "42.91382",
    "lng": "-8.01496"
  },
  {
    "country": "ES",
    "name": "Mélida",
    "lat": "42.35869",
    "lng": "-1.54888"
  },
  {
    "country": "ES",
    "name": "Melgar de Yuso",
    "lat": "42.25381",
    "lng": "-4.25394"
  },
  {
    "country": "ES",
    "name": "Melgar de Tera",
    "lat": "41.96618",
    "lng": "-6.0139"
  },
  {
    "country": "ES",
    "name": "Melgar de Fernamental",
    "lat": "42.40445",
    "lng": "-4.24484"
  },
  {
    "country": "ES",
    "name": "Melgar de Arriba",
    "lat": "42.26806",
    "lng": "-5.09712"
  },
  {
    "country": "ES",
    "name": "Melgar de Abajo",
    "lat": "42.24344",
    "lng": "-5.14216"
  },
  {
    "country": "ES",
    "name": "Mejorada del Campo",
    "lat": "40.39283",
    "lng": "-3.48194"
  },
  {
    "country": "ES",
    "name": "Mejorada",
    "lat": "40.00991",
    "lng": "-4.88506"
  },
  {
    "country": "ES",
    "name": "Meis",
    "lat": "42.5",
    "lng": "-8.75"
  },
  {
    "country": "ES",
    "name": "Meira",
    "lat": "43.21337",
    "lng": "-7.29372"
  },
  {
    "country": "ES",
    "name": "Megina",
    "lat": "40.63911",
    "lng": "-1.87041"
  },
  {
    "country": "ES",
    "name": "Megeces",
    "lat": "41.40828",
    "lng": "-4.56166"
  },
  {
    "country": "ES",
    "name": "Medrano",
    "lat": "42.38361",
    "lng": "-2.55394"
  },
  {
    "country": "ES",
    "name": "Medranda",
    "lat": "40.98333",
    "lng": "-2.93719"
  },
  {
    "country": "ES",
    "name": "Mediona",
    "lat": "41.47798",
    "lng": "1.61222"
  },
  {
    "country": "ES",
    "name": "Medinilla",
    "lat": "40.43967",
    "lng": "-5.61772"
  },
  {
    "country": "ES",
    "name": "Medina de Ríoseco",
    "lat": "41.88327",
    "lng": "-5.04405"
  },
  {
    "country": "ES",
    "name": "Medina de Pomar",
    "lat": "42.92938",
    "lng": "-3.48804"
  },
  {
    "country": "ES",
    "name": "Medina del Campo",
    "lat": "41.31239",
    "lng": "-4.91413"
  },
  {
    "country": "ES",
    "name": "Medinaceli",
    "lat": "41.17224",
    "lng": "-2.43476"
  },
  {
    "country": "ES",
    "name": "Mediana de Voltoya",
    "lat": "40.70104",
    "lng": "-4.56341"
  },
  {
    "country": "ES",
    "name": "Meco",
    "lat": "40.55274",
    "lng": "-3.32894"
  },
  {
    "country": "ES",
    "name": "Mecerreyes",
    "lat": "42.09536",
    "lng": "-3.57393"
  },
  {
    "country": "ES",
    "name": "Meaño",
    "lat": "42.44661",
    "lng": "-8.78122"
  },
  {
    "country": "ES",
    "name": "Mazuela",
    "lat": "42.20767",
    "lng": "-3.9192"
  },
  {
    "country": "ES",
    "name": "Mazuecos de Valdeginate",
    "lat": "42.16814",
    "lng": "-4.84059"
  },
  {
    "country": "ES",
    "name": "Mazuecos",
    "lat": "40.2602",
    "lng": "-3.00755"
  },
  {
    "country": "ES",
    "name": "Mazariegos",
    "lat": "42.02691",
    "lng": "-4.71542"
  },
  {
    "country": "ES",
    "name": "Mazaricos",
    "lat": "42.94033",
    "lng": "-8.97187"
  },
  {
    "country": "ES",
    "name": "Mazarete",
    "lat": "41.00086",
    "lng": "-2.15921"
  },
  {
    "country": "ES",
    "name": "Mazaleón",
    "lat": "41.05056",
    "lng": "0.1029"
  },
  {
    "country": "ES",
    "name": "Mayorga",
    "lat": "42.16687",
    "lng": "-5.26304"
  },
  {
    "country": "ES",
    "name": "Maials",
    "lat": "41.36667",
    "lng": "0.5"
  },
  {
    "country": "ES",
    "name": "Mayalde",
    "lat": "41.2508",
    "lng": "-5.79767"
  },
  {
    "country": "ES",
    "name": "Matute",
    "lat": "42.29888",
    "lng": "-2.79564"
  },
  {
    "country": "ES",
    "name": "Matillas",
    "lat": "40.94415",
    "lng": "-2.8359"
  },
  {
    "country": "ES",
    "name": "Matilla la Seca",
    "lat": "41.57935",
    "lng": "-5.5003"
  },
  {
    "country": "ES",
    "name": "Matilla de los Caños del Río",
    "lat": "40.82539",
    "lng": "-5.94276"
  },
  {
    "country": "ES",
    "name": "Matilla de los Caños",
    "lat": "41.54818",
    "lng": "-4.96761"
  },
  {
    "country": "ES",
    "name": "Matilla de Arzón",
    "lat": "42.10499",
    "lng": "-5.64156"
  },
  {
    "country": "ES",
    "name": "Matarrubia",
    "lat": "40.86463",
    "lng": "-3.28944"
  },
  {
    "country": "ES",
    "name": "Mataró",
    "lat": "41.54211",
    "lng": "2.4445"
  },
  {
    "country": "ES",
    "name": "Matapozuelos",
    "lat": "41.41423",
    "lng": "-4.79122"
  },
  {
    "country": "ES",
    "name": "Mataporquera",
    "lat": "42.87486",
    "lng": "-4.16276"
  },
  {
    "country": "ES",
    "name": "Matamala de Almazán",
    "lat": "41.50563",
    "lng": "-2.64122"
  },
  {
    "country": "ES",
    "name": "Matallana de Torío",
    "lat": "42.8656",
    "lng": "-5.52034"
  },
  {
    "country": "ES",
    "name": "Matalebreras",
    "lat": "41.84116",
    "lng": "-2.04644"
  },
  {
    "country": "ES",
    "name": "Matadepera",
    "lat": "41.59886",
    "lng": "2.02648"
  },
  {
    "country": "ES",
    "name": "Matadeón de los Oteros",
    "lat": "42.33776",
    "lng": "-5.36887"
  },
  {
    "country": "ES",
    "name": "Mata de Cuéllar",
    "lat": "41.39655",
    "lng": "-4.47167"
  },
  {
    "country": "ES",
    "name": "Matabuena",
    "lat": "41.0959",
    "lng": "-3.75827"
  },
  {
    "country": "ES",
    "name": "Masueco",
    "lat": "41.20352",
    "lng": "-6.58938"
  },
  {
    "country": "ES",
    "name": "Maçanet de la Selva",
    "lat": "41.78333",
    "lng": "2.73333"
  },
  {
    "country": "ES",
    "name": "Maçanet de Cabrenys",
    "lat": "42.38597",
    "lng": "2.74806"
  },
  {
    "country": "ES",
    "name": "Massanes",
    "lat": "41.76536",
    "lng": "2.65324"
  },
  {
    "country": "ES",
    "name": "el Masroig",
    "lat": "41.13333",
    "lng": "0.73333"
  },
  {
    "country": "ES",
    "name": "Masquefa",
    "lat": "41.50353",
    "lng": "1.81136"
  },
  {
    "country": "ES",
    "name": "El Masnou",
    "lat": "41.47978",
    "lng": "2.3188"
  },
  {
    "country": "ES",
    "name": "Maside",
    "lat": "42.41031",
    "lng": "-8.02582"
  },
  {
    "country": "ES",
    "name": "Masegoso de Tajuña",
    "lat": "40.82552",
    "lng": "-2.69532"
  },
  {
    "country": "ES",
    "name": "Masegosa",
    "lat": "40.54689",
    "lng": "-2.02588"
  },
  {
    "country": "ES",
    "name": "Masdenverge",
    "lat": "40.716",
    "lng": "0.53009"
  },
  {
    "country": "ES",
    "name": "Mas de las Matas",
    "lat": "40.83408",
    "lng": "-0.24292"
  },
  {
    "country": "ES",
    "name": "Mas de Barberans",
    "lat": "40.73333",
    "lng": "0.36667"
  },
  {
    "country": "ES",
    "name": "Masarac",
    "lat": "42.3509",
    "lng": "2.97296"
  },
  {
    "country": "ES",
    "name": "Marzales",
    "lat": "41.58644",
    "lng": "-5.13455"
  },
  {
    "country": "ES",
    "name": "Marugán",
    "lat": "40.89943",
    "lng": "-4.38383"
  },
  {
    "country": "ES",
    "name": "Martorell",
    "lat": "41.47402",
    "lng": "1.93062"
  },
  {
    "country": "ES",
    "name": "Martín Muñoz de las Posadas",
    "lat": "40.99546",
    "lng": "-4.59672"
  },
  {
    "country": "ES",
    "name": "Martín Muñoz de la Dehesa",
    "lat": "41.06652",
    "lng": "-4.68676"
  },
  {
    "country": "ES",
    "name": "Martín Miguel",
    "lat": "40.9522",
    "lng": "-4.27166"
  },
  {
    "country": "ES",
    "name": "Martínez",
    "lat": "40.63046",
    "lng": "-5.34801"
  },
  {
    "country": "ES",
    "name": "Martín de Yeltes",
    "lat": "40.77594",
    "lng": "-6.29162"
  },
  {
    "country": "ES",
    "name": "Martín del Río",
    "lat": "40.84459",
    "lng": "-0.89549"
  },
  {
    "country": "ES",
    "name": "Martinamor",
    "lat": "40.80676",
    "lng": "-5.59913"
  },
  {
    "country": "ES",
    "name": "Martiherrero",
    "lat": "40.67392",
    "lng": "-4.78156"
  },
  {
    "country": "ES",
    "name": "Martiago",
    "lat": "40.4542",
    "lng": "-6.4901"
  },
  {
    "country": "ES",
    "name": "Marracos",
    "lat": "42.08826",
    "lng": "-0.77587"
  },
  {
    "country": "ES",
    "name": "Markina-Xemein",
    "lat": "43.26667",
    "lng": "-2.5"
  },
  {
    "country": "ES",
    "name": "Marín",
    "lat": "42.38333",
    "lng": "-8.7"
  },
  {
    "country": "ES",
    "name": "Mariana",
    "lat": "40.16717",
    "lng": "-2.14601"
  },
  {
    "country": "ES",
    "name": "María de Huerva",
    "lat": "41.5388",
    "lng": "-0.99615"
  },
  {
    "country": "ES",
    "name": "Margalef",
    "lat": "41.28496",
    "lng": "0.75331"
  },
  {
    "country": "ES",
    "name": "Marcilla de Campos",
    "lat": "42.3177",
    "lng": "-4.3967"
  },
  {
    "country": "ES",
    "name": "Marcilla",
    "lat": "42.32794",
    "lng": "-1.73714"
  },
  {
    "country": "ES",
    "name": "Marchamalo",
    "lat": "40.66677",
    "lng": "-3.19914"
  },
  {
    "country": "ES",
    "name": "Marchagaz",
    "lat": "40.26769",
    "lng": "-6.27485"
  },
  {
    "country": "ES",
    "name": "Marazuela",
    "lat": "40.97912",
    "lng": "-4.36506"
  },
  {
    "country": "ES",
    "name": "Marazoleja",
    "lat": "40.96086",
    "lng": "-4.33882"
  },
  {
    "country": "ES",
    "name": "Marañón",
    "lat": "42.62941",
    "lng": "-2.43931"
  },
  {
    "country": "ES",
    "name": "Meranges",
    "lat": "42.44518",
    "lng": "1.78777"
  },
  {
    "country": "ES",
    "name": "Maranchón",
    "lat": "41.04754",
    "lng": "-2.20482"
  },
  {
    "country": "ES",
    "name": "Maraña",
    "lat": "43.04991",
    "lng": "-5.17726"
  },
  {
    "country": "ES",
    "name": "Mara",
    "lat": "41.2895",
    "lng": "-1.51842"
  },
  {
    "country": "ES",
    "name": "Maqueda",
    "lat": "40.06614",
    "lng": "-4.37066"
  },
  {
    "country": "ES",
    "name": "Manzanillo",
    "lat": "41.58617",
    "lng": "-4.18826"
  },
  {
    "country": "ES",
    "name": "Manzanera",
    "lat": "40.05",
    "lng": "-0.83333"
  },
  {
    "country": "ES",
    "name": "Manzaneda",
    "lat": "42.30962",
    "lng": "-7.23209"
  },
  {
    "country": "ES",
    "name": "Manzanares el Real",
    "lat": "40.72627",
    "lng": "-3.86265"
  },
  {
    "country": "ES",
    "name": "Manzanares de Rioja",
    "lat": "42.3961",
    "lng": "-2.8959"
  },
  {
    "country": "ES",
    "name": "Manzanal de los Infantes",
    "lat": "42.05428",
    "lng": "-6.38288"
  },
  {
    "country": "ES",
    "name": "Manzanal del Barco",
    "lat": "41.63501",
    "lng": "-5.94671"
  },
  {
    "country": "ES",
    "name": "Manzanal de Arriba",
    "lat": "41.99217",
    "lng": "-6.44012"
  },
  {
    "country": "ES",
    "name": "Mantinos",
    "lat": "42.75259",
    "lng": "-4.84213"
  },
  {
    "country": "ES",
    "name": "Mantiel",
    "lat": "40.61892",
    "lng": "-2.66324"
  },
  {
    "country": "ES",
    "name": "Mansilla Mayor",
    "lat": "42.50943",
    "lng": "-5.44271"
  },
  {
    "country": "ES",
    "name": "Mansilla de las Mulas",
    "lat": "42.49886",
    "lng": "-5.41738"
  },
  {
    "country": "ES",
    "name": "Manresa",
    "lat": "41.72815",
    "lng": "1.82399"
  },
  {
    "country": "ES",
    "name": "Manquillos",
    "lat": "42.20518",
    "lng": "-4.56841"
  },
  {
    "country": "ES",
    "name": "Mañón",
    "lat": "43.65",
    "lng": "-7.73333"
  },
  {
    "country": "ES",
    "name": "Manlleu",
    "lat": "42.00228",
    "lng": "2.28476"
  },
  {
    "country": "ES",
    "name": "Manjarrés",
    "lat": "42.39152",
    "lng": "-2.67512"
  },
  {
    "country": "ES",
    "name": "Manjabálago",
    "lat": "40.66441",
    "lng": "-5.07719"
  },
  {
    "country": "ES",
    "name": "Manganeses de la Polvorosa",
    "lat": "42.03563",
    "lng": "-5.74694"
  },
  {
    "country": "ES",
    "name": "Manganeses de la Lampreana",
    "lat": "41.75085",
    "lng": "-5.71048"
  },
  {
    "country": "ES",
    "name": "Mañeru",
    "lat": "42.67001",
    "lng": "-1.86297"
  },
  {
    "country": "ES",
    "name": "Mandayona",
    "lat": "40.9561",
    "lng": "-2.75021"
  },
  {
    "country": "ES",
    "name": "Manciles",
    "lat": "42.45728",
    "lng": "-3.94461"
  },
  {
    "country": "ES",
    "name": "Manchones",
    "lat": "41.15",
    "lng": "-1.46667"
  },
  {
    "country": "ES",
    "name": "Mancera de Arriba",
    "lat": "40.79139",
    "lng": "-5.14772"
  },
  {
    "country": "ES",
    "name": "Mancera de Abajo",
    "lat": "40.83974",
    "lng": "-5.19933"
  },
  {
    "country": "ES",
    "name": "Mañaria",
    "lat": "43.13819",
    "lng": "-2.66104"
  },
  {
    "country": "ES",
    "name": "Mamolar",
    "lat": "41.92762",
    "lng": "-3.36228"
  },
  {
    "country": "ES",
    "name": "Mambrillas de Lara",
    "lat": "42.09446",
    "lng": "-3.46195"
  },
  {
    "country": "ES",
    "name": "Mambrilla de Castrejón",
    "lat": "41.66634",
    "lng": "-3.98448"
  },
  {
    "country": "ES",
    "name": "Mamblas",
    "lat": "41.01925",
    "lng": "-5.00873"
  },
  {
    "country": "ES",
    "name": "Malva",
    "lat": "41.65467",
    "lng": "-5.48657"
  },
  {
    "country": "ES",
    "name": "Maluenda",
    "lat": "41.28772",
    "lng": "-1.61603"
  },
  {
    "country": "ES",
    "name": "Malpica",
    "lat": "43.3228",
    "lng": "-8.81052"
  },
  {
    "country": "ES",
    "name": "Malpartida de Corneja",
    "lat": "40.52208",
    "lng": "-5.35026"
  },
  {
    "country": "ES",
    "name": "Malpartida",
    "lat": "40.76269",
    "lng": "-5.23149"
  },
  {
    "country": "ES",
    "name": "Malón",
    "lat": "41.95235",
    "lng": "-1.67199"
  },
  {
    "country": "ES",
    "name": "Mallén",
    "lat": "41.90064",
    "lng": "-1.41994"
  },
  {
    "country": "ES",
    "name": "Malgrat de Mar",
    "lat": "41.64662",
    "lng": "2.74135"
  },
  {
    "country": "ES",
    "name": "Maleján",
    "lat": "41.82762",
    "lng": "-1.54906"
  },
  {
    "country": "ES",
    "name": "Malanquilla",
    "lat": "41.56856",
    "lng": "-1.87481"
  },
  {
    "country": "ES",
    "name": "Malaguilla",
    "lat": "40.81956",
    "lng": "-3.2545"
  },
  {
    "country": "ES",
    "name": "Málaga del Fresno",
    "lat": "40.7874",
    "lng": "-3.24465"
  },
  {
    "country": "ES",
    "name": "Maján",
    "lat": "41.46888",
    "lng": "-2.30268"
  },
  {
    "country": "ES",
    "name": "Majaelrayo",
    "lat": "41.1126",
    "lng": "-3.30257"
  },
  {
    "country": "ES",
    "name": "Majadahonda",
    "lat": "40.47353",
    "lng": "-3.87182"
  },
  {
    "country": "ES",
    "name": "Maire de Castroponce",
    "lat": "42.11283",
    "lng": "-5.78475"
  },
  {
    "country": "ES",
    "name": "Mainar",
    "lat": "41.19275",
    "lng": "-1.30292"
  },
  {
    "country": "ES",
    "name": "Maicas",
    "lat": "40.96708",
    "lng": "-0.89041"
  },
  {
    "country": "ES",
    "name": "Mahide",
    "lat": "41.86917",
    "lng": "-6.37784"
  },
  {
    "country": "ES",
    "name": "Mahamud",
    "lat": "42.11981",
    "lng": "-3.9406"
  },
  {
    "country": "ES",
    "name": "Magaz de Cepeda",
    "lat": "42.53967",
    "lng": "-6.0717"
  },
  {
    "country": "ES",
    "name": "Magaña",
    "lat": "41.90089",
    "lng": "-2.16269"
  },
  {
    "country": "ES",
    "name": "Magallón",
    "lat": "41.83248",
    "lng": "-1.45979"
  },
  {
    "country": "ES",
    "name": "Maello",
    "lat": "40.80929",
    "lng": "-4.51186"
  },
  {
    "country": "ES",
    "name": "Maella",
    "lat": "41.12251",
    "lng": "0.13926"
  },
  {
    "country": "ES",
    "name": "Madroñal",
    "lat": "40.46407",
    "lng": "-6.06271"
  },
  {
    "country": "ES",
    "name": "Madrigalejo del Monte",
    "lat": "42.12442",
    "lng": "-3.72509"
  },
  {
    "country": "ES",
    "name": "Madrigal del Monte",
    "lat": "42.14464",
    "lng": "-3.67571"
  },
  {
    "country": "ES",
    "name": "Madrigal de la Vera",
    "lat": "40.1476",
    "lng": "-5.36818"
  },
  {
    "country": "ES",
    "name": "Madrigal de las Altas Torres",
    "lat": "41.08968",
    "lng": "-4.99863"
  },
  {
    "country": "ES",
    "name": "Madridanos",
    "lat": "41.47967",
    "lng": "-5.60459"
  },
  {
    "country": "ES",
    "name": "Madrid",
    "lat": "40.4165",
    "lng": "-3.70256"
  },
  {
    "country": "ES",
    "name": "Madremanya",
    "lat": "41.98333",
    "lng": "2.96667"
  },
  {
    "country": "ES",
    "name": "Maderuelo",
    "lat": "41.48644",
    "lng": "-3.52218"
  },
  {
    "country": "ES",
    "name": "Macotera",
    "lat": "40.83105",
    "lng": "-5.28526"
  },
  {
    "country": "ES",
    "name": "Machacón",
    "lat": "40.92623",
    "lng": "-5.5243"
  },
  {
    "country": "ES",
    "name": "Maceda",
    "lat": "42.26972",
    "lng": "-7.65052"
  },
  {
    "country": "ES",
    "name": "Luzón",
    "lat": "41.02691",
    "lng": "-2.27691"
  },
  {
    "country": "ES",
    "name": "Luzmela",
    "lat": "43.29685",
    "lng": "-4.20884"
  },
  {
    "country": "ES",
    "name": "Luzaga",
    "lat": "40.97337",
    "lng": "-2.44497"
  },
  {
    "country": "ES",
    "name": "Luyego",
    "lat": "42.36667",
    "lng": "-6.23333"
  },
  {
    "country": "ES",
    "name": "Lupiana",
    "lat": "40.60846",
    "lng": "-3.05118"
  },
  {
    "country": "ES",
    "name": "Luna",
    "lat": "42.1676",
    "lng": "-0.93292"
  },
  {
    "country": "ES",
    "name": "Lumpiaque",
    "lat": "41.62953",
    "lng": "-1.30156"
  },
  {
    "country": "ES",
    "name": "Lumbreras",
    "lat": "42.10477",
    "lng": "-2.62189"
  },
  {
    "country": "ES",
    "name": "Lumbrales",
    "lat": "40.93501",
    "lng": "-6.71948"
  },
  {
    "country": "ES",
    "name": "Lumbier",
    "lat": "42.65303",
    "lng": "-1.30669"
  },
  {
    "country": "ES",
    "name": "Lugones",
    "lat": "43.40272",
    "lng": "-5.81215"
  },
  {
    "country": "ES",
    "name": "Lugo",
    "lat": "43.00992",
    "lng": "-7.55602"
  },
  {
    "country": "ES",
    "name": "Luesma",
    "lat": "41.16583",
    "lng": "-1.14575"
  },
  {
    "country": "ES",
    "name": "Luesia",
    "lat": "42.36974",
    "lng": "-1.02421"
  },
  {
    "country": "ES",
    "name": "Luelmo",
    "lat": "41.4403",
    "lng": "-6.13338"
  },
  {
    "country": "ES",
    "name": "Ludiente",
    "lat": "40.08333",
    "lng": "-0.36667"
  },
  {
    "country": "ES",
    "name": "Luceni",
    "lat": "41.82857",
    "lng": "-1.23889"
  },
  {
    "country": "ES",
    "name": "Lucena del Cid",
    "lat": "40.13333",
    "lng": "-0.28333"
  },
  {
    "country": "ES",
    "name": "Lucena de Jalón",
    "lat": "41.55301",
    "lng": "-1.31305"
  },
  {
    "country": "ES",
    "name": "Lubián",
    "lat": "42.03569",
    "lng": "-6.90541"
  },
  {
    "country": "ES",
    "name": "Luanco",
    "lat": "43.61517",
    "lng": "-5.79344"
  },
  {
    "country": "ES",
    "name": "Lozoya",
    "lat": "40.94949",
    "lng": "-3.79086"
  },
  {
    "country": "ES",
    "name": "Lobios",
    "lat": "41.87493",
    "lng": "-8.08783"
  },
  {
    "country": "ES",
    "name": "Lousame",
    "lat": "42.77299",
    "lng": "-8.8444"
  },
  {
    "country": "ES",
    "name": "Los Santos de la Humosa",
    "lat": "40.49968",
    "lng": "-3.25332"
  },
  {
    "country": "ES",
    "name": "Los Molinos",
    "lat": "40.71578",
    "lng": "-4.07402"
  },
  {
    "country": "ES",
    "name": "Loscos",
    "lat": "41.08108",
    "lng": "-1.04433"
  },
  {
    "country": "ES",
    "name": "Los Corrales de Buelna",
    "lat": "43.26358",
    "lng": "-4.07262"
  },
  {
    "country": "ES",
    "name": "Loscorrales",
    "lat": "42.25451",
    "lng": "-0.64296"
  },
  {
    "country": "ES",
    "name": "Losar de la Vera",
    "lat": "40.12158",
    "lng": "-5.60454"
  },
  {
    "country": "ES",
    "name": "Los Arcos",
    "lat": "42.57076",
    "lng": "-2.19275"
  },
  {
    "country": "ES",
    "name": "Losacio",
    "lat": "41.71092",
    "lng": "-6.04059"
  },
  {
    "country": "ES",
    "name": "Losacino",
    "lat": "41.68084",
    "lng": "-6.07986"
  },
  {
    "country": "ES",
    "name": "Loranca de Tajuña",
    "lat": "40.44368",
    "lng": "-3.11082"
  },
  {
    "country": "ES",
    "name": "Loporzano",
    "lat": "42.16137",
    "lng": "-0.32337"
  },
  {
    "country": "ES",
    "name": "Longás",
    "lat": "42.48092",
    "lng": "-0.9342"
  },
  {
    "country": "ES",
    "name": "Longares",
    "lat": "41.40308",
    "lng": "-1.16876"
  },
  {
    "country": "ES",
    "name": "Lominchar",
    "lat": "40.09061",
    "lng": "-3.96713"
  },
  {
    "country": "ES",
    "name": "Lomas",
    "lat": "42.27362",
    "lng": "-4.55095"
  },
  {
    "country": "ES",
    "name": "Logroño",
    "lat": "42.46667",
    "lng": "-2.45"
  },
  {
    "country": "ES",
    "name": "Loeches",
    "lat": "40.38343",
    "lng": "-3.4146"
  },
  {
    "country": "ES",
    "name": "Lodosa",
    "lat": "42.42269",
    "lng": "-2.07741"
  },
  {
    "country": "ES",
    "name": "Lobios",
    "lat": "42.40746",
    "lng": "-7.53164"
  },
  {
    "country": "ES",
    "name": "Lobera de Onsella",
    "lat": "42.47848",
    "lng": "-1.02208"
  },
  {
    "country": "ES",
    "name": "Loarre",
    "lat": "42.31432",
    "lng": "-0.62588"
  },
  {
    "country": "ES",
    "name": "Lloret de Mar",
    "lat": "41.69993",
    "lng": "2.84565"
  },
  {
    "country": "ES",
    "name": "Laudio / Llodio",
    "lat": "43.14322",
    "lng": "-2.96204"
  },
  {
    "country": "ES",
    "name": "Llívia",
    "lat": "42.46462",
    "lng": "1.9807"
  },
  {
    "country": "ES",
    "name": "Lliçà de Vall",
    "lat": "41.59054",
    "lng": "2.24121"
  },
  {
    "country": "ES",
    "name": "Lliçà d'Amunt",
    "lat": "41.61667",
    "lng": "2.23333"
  },
  {
    "country": "ES",
    "name": "Llinars del Vallès",
    "lat": "41.63333",
    "lng": "2.4"
  },
  {
    "country": "ES",
    "name": "Llimiana",
    "lat": "42.07476",
    "lng": "0.91621"
  },
  {
    "country": "ES",
    "name": "Lles de Cerdanya",
    "lat": "42.39025",
    "lng": "1.68692"
  },
  {
    "country": "ES",
    "name": "Llers",
    "lat": "42.29571",
    "lng": "2.91183"
  },
  {
    "country": "ES",
    "name": "Lledó",
    "lat": "40.95498",
    "lng": "0.27749"
  },
  {
    "country": "ES",
    "name": "Llançà",
    "lat": "42.36241",
    "lng": "3.15213"
  },
  {
    "country": "ES",
    "name": "Llano de Olmedo",
    "lat": "41.26727",
    "lng": "-4.61386"
  },
  {
    "country": "ES",
    "name": "Llano de Bureba",
    "lat": "42.62435",
    "lng": "-3.4589"
  },
  {
    "country": "ES",
    "name": "Llanes",
    "lat": "43.41982",
    "lng": "-4.75485"
  },
  {
    "country": "ES",
    "name": "Llanera",
    "lat": "43.46189",
    "lng": "-5.9311"
  },
  {
    "country": "ES",
    "name": "Llanera",
    "lat": "43.43333",
    "lng": "-5.88333"
  },
  {
    "country": "ES",
    "name": "Llambilles",
    "lat": "41.92106",
    "lng": "2.85078"
  },
  {
    "country": "ES",
    "name": "Llamas de la Ribera",
    "lat": "42.63504",
    "lng": "-5.82524"
  },
  {
    "country": "ES",
    "name": "Llagostera",
    "lat": "41.82688",
    "lng": "2.89365"
  },
  {
    "country": "ES",
    "name": "Lladó",
    "lat": "42.24769",
    "lng": "2.81373"
  },
  {
    "country": "ES",
    "name": "Lizoáin",
    "lat": "42.79868",
    "lng": "-1.46753"
  },
  {
    "country": "ES",
    "name": "Lizartza",
    "lat": "43.10236",
    "lng": "-2.03489"
  },
  {
    "country": "ES",
    "name": "Lituénigo",
    "lat": "41.83533",
    "lng": "-1.76196"
  },
  {
    "country": "ES",
    "name": "Litago",
    "lat": "41.81407",
    "lng": "-1.75276"
  },
  {
    "country": "ES",
    "name": "Linyola",
    "lat": "41.7",
    "lng": "0.91667"
  },
  {
    "country": "ES",
    "name": "Linares de Riofrío",
    "lat": "40.58338",
    "lng": "-5.92091"
  },
  {
    "country": "ES",
    "name": "Linares de Mora",
    "lat": "40.32159",
    "lng": "-0.57468"
  },
  {
    "country": "ES",
    "name": "Limpias",
    "lat": "43.36402",
    "lng": "-3.41778"
  },
  {
    "country": "ES",
    "name": "Liédena",
    "lat": "42.61943",
    "lng": "-1.27579"
  },
  {
    "country": "ES",
    "name": "Lidón",
    "lat": "40.71725",
    "lng": "-1.1125"
  },
  {
    "country": "ES",
    "name": "Liceras",
    "lat": "41.37939",
    "lng": "-3.24371"
  },
  {
    "country": "ES",
    "name": "Libros",
    "lat": "40.16311",
    "lng": "-1.23361"
  },
  {
    "country": "ES",
    "name": "Lezo",
    "lat": "43.32142",
    "lng": "-1.89739"
  },
  {
    "country": "ES",
    "name": "Lezáun",
    "lat": "42.77739",
    "lng": "-1.99385"
  },
  {
    "country": "ES",
    "name": "Lezama",
    "lat": "43.02799",
    "lng": "-2.97257"
  },
  {
    "country": "ES",
    "name": "Leza de Río Leza",
    "lat": "42.32952",
    "lng": "-2.40606"
  },
  {
    "country": "ES",
    "name": "Leza",
    "lat": "42.56552",
    "lng": "-2.63324"
  },
  {
    "country": "ES",
    "name": "Letux",
    "lat": "41.25512",
    "lng": "-0.80269"
  },
  {
    "country": "ES",
    "name": "Lesaka",
    "lat": "43.25",
    "lng": "-1.7"
  },
  {
    "country": "ES",
    "name": "Les",
    "lat": "42.81076",
    "lng": "0.7105"
  },
  {
    "country": "ES",
    "name": "Lerma",
    "lat": "42.02609",
    "lng": "-3.75978"
  },
  {
    "country": "ES",
    "name": "Lerín",
    "lat": "42.48318",
    "lng": "-1.97184"
  },
  {
    "country": "ES",
    "name": "Lleida",
    "lat": "41.61674",
    "lng": "0.62218"
  },
  {
    "country": "ES",
    "name": "Lerga",
    "lat": "42.56781",
    "lng": "-1.5011"
  },
  {
    "country": "ES",
    "name": "Lekeitio",
    "lat": "43.36417",
    "lng": "-2.50492"
  },
  {
    "country": "ES",
    "name": "León",
    "lat": "42.60003",
    "lng": "-5.57032"
  },
  {
    "country": "ES",
    "name": "Leioa",
    "lat": "43.32686",
    "lng": "-2.98884"
  },
  {
    "country": "ES",
    "name": "Leitza",
    "lat": "43.08333",
    "lng": "-1.91667"
  },
  {
    "country": "ES",
    "name": "Leiva",
    "lat": "42.50281",
    "lng": "-3.04701"
  },
  {
    "country": "ES",
    "name": "Legorreta",
    "lat": "43.08464",
    "lng": "-2.15017"
  },
  {
    "country": "ES",
    "name": "Legazpi",
    "lat": "43.05319",
    "lng": "-2.33689"
  },
  {
    "country": "ES",
    "name": "Legaria",
    "lat": "42.64924",
    "lng": "-2.17392"
  },
  {
    "country": "ES",
    "name": "Legarda",
    "lat": "42.71183",
    "lng": "-1.76846"
  },
  {
    "country": "ES",
    "name": "Leganiel",
    "lat": "40.16568",
    "lng": "-2.94966"
  },
  {
    "country": "ES",
    "name": "Leganés",
    "lat": "40.32718",
    "lng": "-3.7635"
  },
  {
    "country": "ES",
    "name": "Ledrada",
    "lat": "40.46878",
    "lng": "-5.72038"
  },
  {
    "country": "ES",
    "name": "Ledigos",
    "lat": "42.3548",
    "lng": "-4.8648"
  },
  {
    "country": "ES",
    "name": "Ledesma de la Cogolla",
    "lat": "42.32032",
    "lng": "-2.719"
  },
  {
    "country": "ES",
    "name": "Ledesma",
    "lat": "41.08829",
    "lng": "-6.00178"
  },
  {
    "country": "ES",
    "name": "Ledanca",
    "lat": "40.86881",
    "lng": "-2.8434"
  },
  {
    "country": "ES",
    "name": "Lekunberri",
    "lat": "43.0005",
    "lng": "-1.89257"
  },
  {
    "country": "ES",
    "name": "Leciñena",
    "lat": "41.79868",
    "lng": "-0.61174"
  },
  {
    "country": "ES",
    "name": "Lechón",
    "lat": "41.08633",
    "lng": "-1.28483"
  },
  {
    "country": "ES",
    "name": "Lécera",
    "lat": "41.20491",
    "lng": "-0.71133"
  },
  {
    "country": "ES",
    "name": "Leache",
    "lat": "42.60718",
    "lng": "-1.40728"
  },
  {
    "country": "ES",
    "name": "Leaburu",
    "lat": "43.12188",
    "lng": "-2.0543"
  },
  {
    "country": "ES",
    "name": "Lazkao",
    "lat": "43.03239",
    "lng": "-2.18616"
  },
  {
    "country": "ES",
    "name": "Lazagurría",
    "lat": "42.49286",
    "lng": "-2.24018"
  },
  {
    "country": "ES",
    "name": "Laza",
    "lat": "42.06136",
    "lng": "-7.462"
  },
  {
    "country": "ES",
    "name": "Layana",
    "lat": "42.29546",
    "lng": "-1.24483"
  },
  {
    "country": "ES",
    "name": "La Torre de Esteban Hambrán",
    "lat": "40.16935",
    "lng": "-4.21549"
  },
  {
    "country": "ES",
    "name": "la Tallada d'Empordà",
    "lat": "42.0802",
    "lng": "3.05583"
  },
  {
    "country": "ES",
    "name": "Las Ventas de Retamosa",
    "lat": "40.15526",
    "lng": "-4.11455"
  },
  {
    "country": "ES",
    "name": "Lastras del Pozo",
    "lat": "40.8792",
    "lng": "-4.34658"
  },
  {
    "country": "ES",
    "name": "Lastras de Cuéllar",
    "lat": "41.29762",
    "lng": "-4.1067"
  },
  {
    "country": "ES",
    "name": "Las Rozas de Madrid",
    "lat": "40.49292",
    "lng": "-3.87371"
  },
  {
    "country": "ES",
    "name": "Laspuña",
    "lat": "42.50374",
    "lng": "0.15441"
  },
  {
    "country": "ES",
    "name": "les Planes d'Hostoles",
    "lat": "42.05669",
    "lng": "2.54093"
  },
  {
    "country": "ES",
    "name": "Laspaúles",
    "lat": "42.47136",
    "lng": "0.59698"
  },
  {
    "country": "ES",
    "name": "Las Navas del Marqués",
    "lat": "40.60244",
    "lng": "-4.33449"
  },
  {
    "country": "ES",
    "name": "Las Matas",
    "lat": "40.55779",
    "lng": "-3.89173"
  },
  {
    "country": "ES",
    "name": "les Llosses",
    "lat": "42.15",
    "lng": "2.11667"
  },
  {
    "country": "ES",
    "name": "La Selva del Camp",
    "lat": "41.21484",
    "lng": "1.13883"
  },
  {
    "country": "ES",
    "name": "la Cellera de Ter",
    "lat": "41.96919",
    "lng": "2.62402"
  },
  {
    "country": "ES",
    "name": "La Secuita",
    "lat": "41.2046",
    "lng": "1.27996"
  },
  {
    "country": "ES",
    "name": "La Seca",
    "lat": "41.41364",
    "lng": "-4.90552"
  },
  {
    "country": "ES",
    "name": "Lascuarre",
    "lat": "42.19611",
    "lng": "0.5201"
  },
  {
    "country": "ES",
    "name": "Les Cases d'Alcanar",
    "lat": "40.55359",
    "lng": "0.53022"
  },
  {
    "country": "ES",
    "name": "Lasarte",
    "lat": "43.26774",
    "lng": "-2.02169"
  },
  {
    "country": "ES",
    "name": "La Sagrera",
    "lat": "41.42271",
    "lng": "2.18589"
  },
  {
    "country": "ES",
    "name": "A Rúa",
    "lat": "42.40048",
    "lng": "-7.10268"
  },
  {
    "country": "ES",
    "name": "Larrodrigo",
    "lat": "40.73722",
    "lng": "-5.44895"
  },
  {
    "country": "ES",
    "name": "Larraul",
    "lat": "43.18773",
    "lng": "-2.10202"
  },
  {
    "country": "ES",
    "name": "Larraona",
    "lat": "42.7797",
    "lng": "-2.25682"
  },
  {
    "country": "ES",
    "name": "Larraga",
    "lat": "42.55841",
    "lng": "-1.84954"
  },
  {
    "country": "ES",
    "name": "La Roca del Vallès",
    "lat": "41.58333",
    "lng": "2.33333"
  },
  {
    "country": "ES",
    "name": "La Robla",
    "lat": "42.80302",
    "lng": "-5.62904"
  },
  {
    "country": "ES",
    "name": "Sant Pere, Santa Caterina i La Ribera",
    "lat": "41.3845",
    "lng": "2.18152"
  },
  {
    "country": "ES",
    "name": "Laredo",
    "lat": "43.4098",
    "lng": "-3.41613"
  },
  {
    "country": "ES",
    "name": "Lardero",
    "lat": "42.42686",
    "lng": "-2.46153"
  },
  {
    "country": "ES",
    "name": "Laracha",
    "lat": "43.25375",
    "lng": "-8.58535"
  },
  {
    "country": "ES",
    "name": "Lapuebla de Labarca",
    "lat": "42.49455",
    "lng": "-2.57341"
  },
  {
    "country": "ES",
    "name": "La Pola de Gordón",
    "lat": "42.85658",
    "lng": "-5.66768"
  },
  {
    "country": "ES",
    "name": "la Pobla de Mafumet",
    "lat": "41.18333",
    "lng": "1.21667"
  },
  {
    "country": "ES",
    "name": "La Pobla de Claramunt",
    "lat": "41.55423",
    "lng": "1.67712"
  },
  {
    "country": "ES",
    "name": "Lapoblación",
    "lat": "42.60478",
    "lng": "-2.46008"
  },
  {
    "country": "ES",
    "name": "La Plaza",
    "lat": "43.16397",
    "lng": "-6.09943"
  },
  {
    "country": "ES",
    "name": "La Pineda",
    "lat": "41.07625",
    "lng": "1.18515"
  },
  {
    "country": "ES",
    "name": "La Pesga",
    "lat": "40.3263",
    "lng": "-6.17603"
  },
  {
    "country": "ES",
    "name": "Laperdiguera",
    "lat": "41.99053",
    "lng": "-0.04657"
  },
  {
    "country": "ES",
    "name": "La Pedraja de Portillo",
    "lat": "41.47124",
    "lng": "-4.64639"
  },
  {
    "country": "ES",
    "name": "Lanzuela",
    "lat": "41.0985",
    "lng": "-1.20616"
  },
  {
    "country": "ES",
    "name": "Lantz",
    "lat": "43",
    "lng": "-1.61667"
  },
  {
    "country": "ES",
    "name": "Lantadilla",
    "lat": "42.34078",
    "lng": "-4.27866"
  },
  {
    "country": "ES",
    "name": "Languilla",
    "lat": "41.44926",
    "lng": "-3.42438"
  },
  {
    "country": "ES",
    "name": "Langayo",
    "lat": "41.56986",
    "lng": "-4.19866"
  },
  {
    "country": "ES",
    "name": "Langa del Castillo",
    "lat": "41.212",
    "lng": "-1.3985"
  },
  {
    "country": "ES",
    "name": "Langa de Duero",
    "lat": "41.60985",
    "lng": "-3.40061"
  },
  {
    "country": "ES",
    "name": "Langa",
    "lat": "41.0055",
    "lng": "-4.85946"
  },
  {
    "country": "ES",
    "name": "Lanestosa",
    "lat": "43.21986",
    "lng": "-3.4392"
  },
  {
    "country": "ES",
    "name": "Láncara",
    "lat": "42.86425",
    "lng": "-7.33667"
  },
  {
    "country": "ES",
    "name": "Lanaja",
    "lat": "41.77063",
    "lng": "-0.33095"
  },
  {
    "country": "ES",
    "name": "la Morera de Montsant",
    "lat": "41.26529",
    "lng": "0.84157"
  },
  {
    "country": "ES",
    "name": "Lama",
    "lat": "42.4",
    "lng": "-8.43333"
  },
  {
    "country": "ES",
    "name": "Lalueza",
    "lat": "41.83967",
    "lng": "-0.25493"
  },
  {
    "country": "ES",
    "name": "Laluenga",
    "lat": "42.00703",
    "lng": "-0.04715"
  },
  {
    "country": "ES",
    "name": "La Llagosta",
    "lat": "41.51435",
    "lng": "2.19297"
  },
  {
    "country": "ES",
    "name": "Lalín",
    "lat": "42.66085",
    "lng": "-8.11285"
  },
  {
    "country": "ES",
    "name": "La Lastrilla",
    "lat": "40.96817",
    "lng": "-4.10468"
  },
  {
    "country": "ES",
    "name": "la Jonquera",
    "lat": "42.41728",
    "lng": "2.87363"
  },
  {
    "country": "ES",
    "name": "La Iglesuela del Cid",
    "lat": "40.48312",
    "lng": "-0.31938"
  },
  {
    "country": "ES",
    "name": "Polanco",
    "lat": "43.38524",
    "lng": "-4.01642"
  },
  {
    "country": "ES",
    "name": "Lagunilla del Jubera",
    "lat": "42.33414",
    "lng": "-2.32117"
  },
  {
    "country": "ES",
    "name": "Lagunilla",
    "lat": "40.32491",
    "lng": "-5.97132"
  },
  {
    "country": "ES",
    "name": "Lagunaseca",
    "lat": "40.531",
    "lng": "-2.01956"
  },
  {
    "country": "ES",
    "name": "Laguna de Negrillos",
    "lat": "42.23889",
    "lng": "-5.66066"
  },
  {
    "country": "ES",
    "name": "Laguna del Marquesado",
    "lat": "40.17749",
    "lng": "-1.67167"
  },
  {
    "country": "ES",
    "name": "Laguna de Duero",
    "lat": "41.58151",
    "lng": "-4.72332"
  },
  {
    "country": "ES",
    "name": "Laguna de Contreras",
    "lat": "41.49513",
    "lng": "-4.02874"
  },
  {
    "country": "ES",
    "name": "Laguna de Cameros",
    "lat": "42.17455",
    "lng": "-2.54282"
  },
  {
    "country": "ES",
    "name": "Laguna Dalga",
    "lat": "42.33192",
    "lng": "-5.7522"
  },
  {
    "country": "ES",
    "name": "Lagueruela",
    "lat": "41.0425",
    "lng": "-1.19283"
  },
  {
    "country": "ES",
    "name": "Laguardia",
    "lat": "42.55461",
    "lng": "-2.58528"
  },
  {
    "country": "ES",
    "name": "A Guarda",
    "lat": "41.90131",
    "lng": "-8.87423"
  },
  {
    "country": "ES",
    "name": "La Granada",
    "lat": "41.37816",
    "lng": "1.71902"
  },
  {
    "country": "ES",
    "name": "Lagrán",
    "lat": "42.62625",
    "lng": "-2.58385"
  },
  {
    "country": "ES",
    "name": "La Ginebrosa",
    "lat": "40.86991",
    "lng": "-0.13525"
  },
  {
    "country": "ES",
    "name": "Laxe",
    "lat": "43.22019",
    "lng": "-9.0063"
  },
  {
    "country": "ES",
    "name": "Lagata",
    "lat": "41.2397",
    "lng": "-0.80487"
  },
  {
    "country": "ES",
    "name": "Lagartos",
    "lat": "42.40578",
    "lng": "-4.90454"
  },
  {
    "country": "ES",
    "name": "la Garriga",
    "lat": "41.68333",
    "lng": "2.28333"
  },
  {
    "country": "ES",
    "name": "La Fuliola",
    "lat": "41.71358",
    "lng": "1.01746"
  },
  {
    "country": "ES",
    "name": "La Fuente de San Esteban",
    "lat": "40.80161",
    "lng": "-6.25852"
  },
  {
    "country": "ES",
    "name": "La Frontera",
    "lat": "40.40161",
    "lng": "-2.21699"
  },
  {
    "country": "ES",
    "name": "A Estrada",
    "lat": "42.68911",
    "lng": "-8.48842"
  },
  {
    "country": "ES",
    "name": "l'Escala",
    "lat": "42.12562",
    "lng": "3.13261"
  },
  {
    "country": "ES",
    "name": "Ladrillar",
    "lat": "40.46576",
    "lng": "-6.22427"
  },
  {
    "country": "ES",
    "name": "Lakuntza",
    "lat": "42.92249",
    "lng": "-2.02337"
  },
  {
    "country": "ES",
    "name": "La Cuesta",
    "lat": "41.0828",
    "lng": "-3.96017"
  },
  {
    "country": "ES",
    "name": "A Coruña",
    "lat": "43.37135",
    "lng": "-8.396"
  },
  {
    "country": "ES",
    "name": "La Carrera",
    "lat": "40.34777",
    "lng": "-5.55474"
  },
  {
    "country": "ES",
    "name": "La Canonja",
    "lat": "41.1211",
    "lng": "1.18065"
  },
  {
    "country": "ES",
    "name": "La Cabrera",
    "lat": "40.86386",
    "lng": "-3.61265"
  },
  {
    "country": "ES",
    "name": "Labuerda",
    "lat": "42.45234",
    "lng": "0.13561"
  },
  {
    "country": "ES",
    "name": "La Bouza",
    "lat": "40.83626",
    "lng": "-6.79551"
  },
  {
    "country": "ES",
    "name": "la Bisbal d'Empordà",
    "lat": "41.95",
    "lng": "3.05"
  },
  {
    "country": "ES",
    "name": "Bastida / Labastida",
    "lat": "42.58974",
    "lng": "-2.79568"
  },
  {
    "country": "ES",
    "name": "La Bañeza",
    "lat": "42.30026",
    "lng": "-5.89772"
  },
  {
    "country": "ES",
    "name": "Labajos",
    "lat": "40.84335",
    "lng": "-4.52005"
  },
  {
    "country": "ES",
    "name": "L'Ampolla",
    "lat": "40.81235",
    "lng": "0.71008"
  },
  {
    "country": "ES",
    "name": "l'Ametlla de Mar",
    "lat": "40.9",
    "lng": "0.8"
  },
  {
    "country": "ES",
    "name": "L'Ametlla del Vallès",
    "lat": "41.66667",
    "lng": "2.26667"
  },
  {
    "country": "ES",
    "name": "La Almunia de Doña Godina",
    "lat": "41.4767",
    "lng": "-1.37451"
  },
  {
    "country": "ES",
    "name": "La Alberca",
    "lat": "40.48908",
    "lng": "-6.11107"
  },
  {
    "country": "ES",
    "name": "La Alameda de la Sagra",
    "lat": "40.01199",
    "lng": "-3.79255"
  },
  {
    "country": "ES",
    "name": "La Adrada",
    "lat": "40.29953",
    "lng": "-4.63589"
  },
  {
    "country": "ES",
    "name": "Juzbado",
    "lat": "41.07791",
    "lng": "-5.8614"
  },
  {
    "country": "ES",
    "name": "Juià",
    "lat": "42.01667",
    "lng": "2.91667"
  },
  {
    "country": "ES",
    "name": "Justel",
    "lat": "42.14861",
    "lng": "-6.29594"
  },
  {
    "country": "ES",
    "name": "Juneda",
    "lat": "41.54847",
    "lng": "0.82451"
  },
  {
    "country": "ES",
    "name": "Juncosa",
    "lat": "41.37033",
    "lng": "0.7765"
  },
  {
    "country": "ES",
    "name": "Junciana",
    "lat": "40.41076",
    "lng": "-5.55698"
  },
  {
    "country": "ES",
    "name": "Juarros de Voltoya",
    "lat": "41.03097",
    "lng": "-4.51922"
  },
  {
    "country": "ES",
    "name": "Xove",
    "lat": "43.68656",
    "lng": "-7.5113"
  },
  {
    "country": "ES",
    "name": "Josa",
    "lat": "40.9555",
    "lng": "-0.76683"
  },
  {
    "country": "ES",
    "name": "Jorcas",
    "lat": "40.54275",
    "lng": "-0.75308"
  },
  {
    "country": "ES",
    "name": "Jorba",
    "lat": "41.60193",
    "lng": "1.5475"
  },
  {
    "country": "ES",
    "name": "Joarilla de las Matas",
    "lat": "42.28755",
    "lng": "-5.17855"
  },
  {
    "country": "ES",
    "name": "Jirueque",
    "lat": "40.96431",
    "lng": "-2.90289"
  },
  {
    "country": "ES",
    "name": "Jerte",
    "lat": "40.22271",
    "lng": "-5.75011"
  },
  {
    "country": "ES",
    "name": "Javier",
    "lat": "42.59119",
    "lng": "-1.20884"
  },
  {
    "country": "ES",
    "name": "Jaulín",
    "lat": "41.45198",
    "lng": "-0.99256"
  },
  {
    "country": "ES",
    "name": "Jatiel",
    "lat": "41.22008",
    "lng": "-0.38183"
  },
  {
    "country": "ES",
    "name": "Jasa",
    "lat": "42.6948",
    "lng": "-0.66605"
  },
  {
    "country": "ES",
    "name": "Jarque de la Val",
    "lat": "40.70283",
    "lng": "-0.80083"
  },
  {
    "country": "ES",
    "name": "Jarque",
    "lat": "41.55613",
    "lng": "-1.67563"
  },
  {
    "country": "ES",
    "name": "Jarilla",
    "lat": "40.17156",
    "lng": "-6.00281"
  },
  {
    "country": "ES",
    "name": "Jarandilla de la Vera",
    "lat": "40.12915",
    "lng": "-5.66079"
  },
  {
    "country": "ES",
    "name": "Jaramillo Quemado",
    "lat": "42.08568",
    "lng": "-3.35868"
  },
  {
    "country": "ES",
    "name": "Jaramillo de la Fuente",
    "lat": "42.11472",
    "lng": "-3.31239"
  },
  {
    "country": "ES",
    "name": "Jaraíz de la Vera",
    "lat": "40.06005",
    "lng": "-5.75426"
  },
  {
    "country": "ES",
    "name": "Jaraba",
    "lat": "41.19083",
    "lng": "-1.8844"
  },
  {
    "country": "ES",
    "name": "Jambrina",
    "lat": "41.39196",
    "lng": "-5.66411"
  },
  {
    "country": "ES",
    "name": "Jalón de Cameros",
    "lat": "42.21804",
    "lng": "-2.49004"
  },
  {
    "country": "ES",
    "name": "Jafre",
    "lat": "42.07254",
    "lng": "3.01062"
  },
  {
    "country": "ES",
    "name": "Jadraque",
    "lat": "40.92454",
    "lng": "-2.92468"
  },
  {
    "country": "ES",
    "name": "Jaca",
    "lat": "42.56898",
    "lng": "-0.54987"
  },
  {
    "country": "ES",
    "name": "Jabaloyas",
    "lat": "40.2401",
    "lng": "-1.40886"
  },
  {
    "country": "ES",
    "name": "Izurtza",
    "lat": "43.15",
    "lng": "-2.63333"
  },
  {
    "country": "ES",
    "name": "Izagre",
    "lat": "42.2241",
    "lng": "-5.25727"
  },
  {
    "country": "ES",
    "name": "Iturmendi",
    "lat": "42.88993",
    "lng": "-2.11916"
  },
  {
    "country": "ES",
    "name": "Ituren",
    "lat": "43.13238",
    "lng": "-1.72063"
  },
  {
    "country": "ES",
    "name": "Ituero y Lama",
    "lat": "40.80066",
    "lng": "-4.37917"
  },
  {
    "country": "ES",
    "name": "Ituero de Azaba",
    "lat": "40.48487",
    "lng": "-6.69272"
  },
  {
    "country": "ES",
    "name": "Itero del Castillo",
    "lat": "42.28988",
    "lng": "-4.24441"
  },
  {
    "country": "ES",
    "name": "Itero de la Vega",
    "lat": "42.28804",
    "lng": "-4.25677"
  },
  {
    "country": "ES",
    "name": "Isuerre",
    "lat": "42.48729",
    "lng": "-1.054"
  },
  {
    "country": "ES",
    "name": "Isòvol",
    "lat": "42.37763",
    "lng": "1.81807"
  },
  {
    "country": "ES",
    "name": "Iscar",
    "lat": "41.36117",
    "lng": "-4.53348"
  },
  {
    "country": "ES",
    "name": "Itsasondo",
    "lat": "43.06909",
    "lng": "-2.16464"
  },
  {
    "country": "ES",
    "name": "Isar",
    "lat": "42.3614",
    "lng": "-3.9304"
  },
  {
    "country": "ES",
    "name": "Irurtzun",
    "lat": "42.91667",
    "lng": "-1.83333"
  },
  {
    "country": "ES",
    "name": "Irura",
    "lat": "43.16651",
    "lng": "-2.06746"
  },
  {
    "country": "ES",
    "name": "Irun",
    "lat": "43.33904",
    "lng": "-1.78938"
  },
  {
    "country": "ES",
    "name": "Irueste",
    "lat": "40.61206",
    "lng": "-2.89072"
  },
  {
    "country": "ES",
    "name": "Iruelos",
    "lat": "41.14135",
    "lng": "-6.32808"
  },
  {
    "country": "ES",
    "name": "Irixoa",
    "lat": "43.2847",
    "lng": "-8.05916"
  },
  {
    "country": "ES",
    "name": "Irañeta",
    "lat": "42.92287",
    "lng": "-1.94595"
  },
  {
    "country": "ES",
    "name": "Iniéstola",
    "lat": "40.994",
    "lng": "-2.37063"
  },
  {
    "country": "ES",
    "name": "Incio",
    "lat": "42.63333",
    "lng": "-7.35"
  },
  {
    "country": "ES",
    "name": "Illueca",
    "lat": "41.53818",
    "lng": "-1.62747"
  },
  {
    "country": "ES",
    "name": "Illescas",
    "lat": "40.12213",
    "lng": "-3.84704"
  },
  {
    "country": "ES",
    "name": "Illas",
    "lat": "43.49716",
    "lng": "-5.97499"
  },
  {
    "country": "ES",
    "name": "Illano",
    "lat": "43.33385",
    "lng": "-6.8656"
  },
  {
    "country": "ES",
    "name": "Illana",
    "lat": "40.18442",
    "lng": "-2.90889"
  },
  {
    "country": "ES",
    "name": "Ilche",
    "lat": "41.95702",
    "lng": "0.05728"
  },
  {
    "country": "ES",
    "name": "Igúzquiza",
    "lat": "42.64545",
    "lng": "-2.08551"
  },
  {
    "country": "ES",
    "name": "Igüeña",
    "lat": "42.72853",
    "lng": "-6.27738"
  },
  {
    "country": "ES",
    "name": "Igualada",
    "lat": "41.58098",
    "lng": "1.6172"
  },
  {
    "country": "ES",
    "name": "Igriés",
    "lat": "42.21443",
    "lng": "-0.43201"
  },
  {
    "country": "ES",
    "name": "Iglesias",
    "lat": "42.29807",
    "lng": "-3.98932"
  },
  {
    "country": "ES",
    "name": "Iglesiarrubia",
    "lat": "41.97383",
    "lng": "-3.84701"
  },
  {
    "country": "ES",
    "name": "Igea",
    "lat": "42.06777",
    "lng": "-2.01094"
  },
  {
    "country": "ES",
    "name": "Idiazabal",
    "lat": "43.01189",
    "lng": "-2.23356"
  },
  {
    "country": "ES",
    "name": "Ikaztegieta",
    "lat": "43.09444",
    "lng": "-2.12373"
  },
  {
    "country": "ES",
    "name": "Ibrillos",
    "lat": "42.45431",
    "lng": "-3.08238"
  },
  {
    "country": "ES",
    "name": "Ivorra",
    "lat": "41.76667",
    "lng": "1.4"
  },
  {
    "country": "ES",
    "name": "Ibieca",
    "lat": "42.16079",
    "lng": "-0.20855"
  },
  {
    "country": "ES",
    "name": "Ibeas de Juarros",
    "lat": "42.33088",
    "lng": "-3.53519"
  },
  {
    "country": "ES",
    "name": "Ibdes",
    "lat": "41.21667",
    "lng": "-1.83333"
  },
  {
    "country": "ES",
    "name": "Ivars d'Urgell",
    "lat": "41.68019",
    "lng": "0.98696"
  },
  {
    "country": "ES",
    "name": "Ibarrangelu",
    "lat": "43.39027",
    "lng": "-2.63423"
  },
  {
    "country": "ES",
    "name": "Ibarra",
    "lat": "43.13127",
    "lng": "-2.06487"
  },
  {
    "country": "ES",
    "name": "Husillos",
    "lat": "42.09054",
    "lng": "-4.52709"
  },
  {
    "country": "ES",
    "name": "Hurtumpascual",
    "lat": "40.692",
    "lng": "-5.11379"
  },
  {
    "country": "ES",
    "name": "Hurones",
    "lat": "42.40571",
    "lng": "-3.61588"
  },
  {
    "country": "ES",
    "name": "Humanes de Madrid",
    "lat": "40.25038",
    "lng": "-3.83062"
  },
  {
    "country": "ES",
    "name": "Humanes",
    "lat": "40.82598",
    "lng": "-3.15257"
  },
  {
    "country": "ES",
    "name": "Humada",
    "lat": "42.66667",
    "lng": "-4.08333"
  },
  {
    "country": "ES",
    "name": "Hueva",
    "lat": "40.46221",
    "lng": "-2.96039"
  },
  {
    "country": "ES",
    "name": "Huete",
    "lat": "40.14526",
    "lng": "-2.69026"
  },
  {
    "country": "ES",
    "name": "Huesca",
    "lat": "42.13615",
    "lng": "-0.4087"
  },
  {
    "country": "ES",
    "name": "Huesa del Común",
    "lat": "41.01053",
    "lng": "-0.91882"
  },
  {
    "country": "ES",
    "name": "Huerto",
    "lat": "41.93128",
    "lng": "-0.16684"
  },
  {
    "country": "ES",
    "name": "Huertahernando",
    "lat": "40.82348",
    "lng": "-2.28697"
  },
  {
    "country": "ES",
    "name": "Huerta del Rey",
    "lat": "41.8391",
    "lng": "-3.34755"
  },
  {
    "country": "ES",
    "name": "Huerta del Marquesado",
    "lat": "40.15",
    "lng": "-1.68333"
  },
  {
    "country": "ES",
    "name": "Huerta de Arriba",
    "lat": "42.11672",
    "lng": "-3.08211"
  },
  {
    "country": "ES",
    "name": "Huerta",
    "lat": "40.96843",
    "lng": "-5.46769"
  },
  {
    "country": "ES",
    "name": "Huérmeces del Cerro",
    "lat": "41.05332",
    "lng": "-2.79711"
  },
  {
    "country": "ES",
    "name": "Huérmeces",
    "lat": "42.5225",
    "lng": "-3.77072"
  },
  {
    "country": "ES",
    "name": "Huérguina",
    "lat": "40.03333",
    "lng": "-1.6"
  },
  {
    "country": "ES",
    "name": "Huércanos",
    "lat": "42.428",
    "lng": "-2.69589"
  },
  {
    "country": "ES",
    "name": "Huelves",
    "lat": "40.04282",
    "lng": "-2.88444"
  },
  {
    "country": "ES",
    "name": "Huélamo",
    "lat": "40.27658",
    "lng": "-1.80957"
  },
  {
    "country": "ES",
    "name": "Huélaga",
    "lat": "40.05582",
    "lng": "-6.61568"
  },
  {
    "country": "ES",
    "name": "Huecas",
    "lat": "40.0123",
    "lng": "-4.19541"
  },
  {
    "country": "ES",
    "name": "Huarte-Uharte",
    "lat": "42.83035",
    "lng": "-1.59087"
  },
  {
    "country": "ES",
    "name": "Hoz de Jaca",
    "lat": "42.69045",
    "lng": "-0.3065"
  },
  {
    "country": "ES",
    "name": "Hoyos de Miguel Muñoz",
    "lat": "40.39237",
    "lng": "-5.06713"
  },
  {
    "country": "ES",
    "name": "Hoyos del Espino",
    "lat": "40.35623",
    "lng": "-5.17505"
  },
  {
    "country": "ES",
    "name": "Hoyos del Collado",
    "lat": "40.35945",
    "lng": "-5.20027"
  },
  {
    "country": "ES",
    "name": "Hoyos",
    "lat": "40.17154",
    "lng": "-6.72092"
  },
  {
    "country": "ES",
    "name": "Hoyorredondo",
    "lat": "40.4627",
    "lng": "-5.41097"
  },
  {
    "country": "ES",
    "name": "Hoyo de Manzanares",
    "lat": "40.62265",
    "lng": "-3.90733"
  },
  {
    "country": "ES",
    "name": "Hoyocasero",
    "lat": "40.3989",
    "lng": "-4.97455"
  },
  {
    "country": "ES",
    "name": "Hoyales de Roa",
    "lat": "41.65893",
    "lng": "-3.86202"
  },
  {
    "country": "ES",
    "name": "Hostalric",
    "lat": "41.75",
    "lng": "2.63333"
  },
  {
    "country": "ES",
    "name": "L'Hospitalet de Llobregat",
    "lat": "41.35967",
    "lng": "2.10028"
  },
  {
    "country": "ES",
    "name": "Hospital de Órbigo",
    "lat": "42.46354",
    "lng": "-5.88636"
  },
  {
    "country": "ES",
    "name": "Hortigüela",
    "lat": "42.06842",
    "lng": "-3.42578"
  },
  {
    "country": "ES",
    "name": "Hortaleza",
    "lat": "40.47444",
    "lng": "-3.6411"
  },
  {
    "country": "ES",
    "name": "Horta de Sant Joan",
    "lat": "40.95",
    "lng": "0.31667"
  },
  {
    "country": "ES",
    "name": "Horta",
    "lat": "41.43628",
    "lng": "2.15725"
  },
  {
    "country": "ES",
    "name": "Hornos de Moncalvillo",
    "lat": "42.39198",
    "lng": "-2.5855"
  },
  {
    "country": "ES",
    "name": "Hornillos del Camino",
    "lat": "42.33863",
    "lng": "-3.9256"
  },
  {
    "country": "ES",
    "name": "Hornillos de Cerrato",
    "lat": "41.98772",
    "lng": "-4.27207"
  },
  {
    "country": "ES",
    "name": "Hornillos de Cameros",
    "lat": "42.21001",
    "lng": "-2.4196"
  },
  {
    "country": "ES",
    "name": "Hormilleja",
    "lat": "42.45628",
    "lng": "-2.73155"
  },
  {
    "country": "ES",
    "name": "Hormilla",
    "lat": "42.43828",
    "lng": "-2.77447"
  },
  {
    "country": "ES",
    "name": "Hormigos",
    "lat": "40.09778",
    "lng": "-4.44473"
  },
  {
    "country": "ES",
    "name": "Horche",
    "lat": "40.56399",
    "lng": "-3.0611"
  },
  {
    "country": "ES",
    "name": "Horcajuelo de la Sierra",
    "lat": "41.06019",
    "lng": "-3.5464"
  },
  {
    "country": "ES",
    "name": "Horcajo de Montemayor",
    "lat": "40.42265",
    "lng": "-5.89427"
  },
  {
    "country": "ES",
    "name": "Horcajo de las Torres",
    "lat": "41.06497",
    "lng": "-5.09092"
  },
  {
    "country": "ES",
    "name": "Horcajo de la Sierra",
    "lat": "41.06723",
    "lng": "-3.58534"
  },
  {
    "country": "ES",
    "name": "Hontoria de Valdearados",
    "lat": "41.74488",
    "lng": "-3.51983"
  },
  {
    "country": "ES",
    "name": "Hontoria del Pinar",
    "lat": "41.84838",
    "lng": "-3.16245"
  },
  {
    "country": "ES",
    "name": "Hontoria de la Cantera",
    "lat": "42.18879",
    "lng": "-3.64251"
  },
  {
    "country": "ES",
    "name": "Hontoria de Cerrato",
    "lat": "41.91061",
    "lng": "-4.44209"
  },
  {
    "country": "ES",
    "name": "Hontoba",
    "lat": "40.45385",
    "lng": "-3.03858"
  },
  {
    "country": "ES",
    "name": "Hontangas",
    "lat": "41.58216",
    "lng": "-3.7955"
  },
  {
    "country": "ES",
    "name": "Hontanas",
    "lat": "42.31312",
    "lng": "-4.04529"
  },
  {
    "country": "ES",
    "name": "Hontanares de Eresma",
    "lat": "40.98273",
    "lng": "-4.20439"
  },
  {
    "country": "ES",
    "name": "Hontalbilla",
    "lat": "41.34551",
    "lng": "-4.12149"
  },
  {
    "country": "ES",
    "name": "Honrubia de la Cuesta",
    "lat": "41.50998",
    "lng": "-3.70453"
  },
  {
    "country": "ES",
    "name": "Hombrados",
    "lat": "40.80118",
    "lng": "-1.68558"
  },
  {
    "country": "ES",
    "name": "Hita",
    "lat": "40.82149",
    "lng": "-3.0454"
  },
  {
    "country": "ES",
    "name": "Hinojosa de San Vicente",
    "lat": "40.10463",
    "lng": "-4.72269"
  },
  {
    "country": "ES",
    "name": "Hinojosa del Campo",
    "lat": "41.73844",
    "lng": "-2.09946"
  },
  {
    "country": "ES",
    "name": "Hinojosa de Jarque",
    "lat": "40.69049",
    "lng": "-0.78541"
  },
  {
    "country": "ES",
    "name": "Hinojosa de Duero",
    "lat": "40.98674",
    "lng": "-6.79529"
  },
  {
    "country": "ES",
    "name": "Hijes",
    "lat": "41.25139",
    "lng": "-2.99989"
  },
  {
    "country": "ES",
    "name": "Híjar",
    "lat": "41.17429",
    "lng": "-0.45112"
  },
  {
    "country": "ES",
    "name": "Higuera de las Dueñas",
    "lat": "40.23903",
    "lng": "-4.60361"
  },
  {
    "country": "ES",
    "name": "Hiendelaencina",
    "lat": "41.08373",
    "lng": "-3.00337"
  },
  {
    "country": "ES",
    "name": "Hervías",
    "lat": "42.44781",
    "lng": "-2.88714"
  },
  {
    "country": "ES",
    "name": "Hervás",
    "lat": "40.27081",
    "lng": "-5.86721"
  },
  {
    "country": "ES",
    "name": "Herrín de Campos",
    "lat": "42.12476",
    "lng": "-4.95239"
  },
  {
    "country": "ES",
    "name": "Herreros de Suso",
    "lat": "40.80361",
    "lng": "-5.03892"
  },
  {
    "country": "ES",
    "name": "Herrería",
    "lat": "40.88815",
    "lng": "-1.96014"
  },
  {
    "country": "ES",
    "name": "Herrera de Valdecañas",
    "lat": "42.04828",
    "lng": "-4.20004"
  },
  {
    "country": "ES",
    "name": "Herrera de Soria",
    "lat": "41.76269",
    "lng": "-3.01243"
  },
  {
    "country": "ES",
    "name": "Herrera de Pisuerga",
    "lat": "42.59492",
    "lng": "-4.33034"
  },
  {
    "country": "ES",
    "name": "Herrera de los Navarros",
    "lat": "41.21024",
    "lng": "-1.08271"
  },
  {
    "country": "ES",
    "name": "Herramélluri",
    "lat": "42.50295",
    "lng": "-3.01954"
  },
  {
    "country": "ES",
    "name": "Hernialde",
    "lat": "43.15446",
    "lng": "-2.08521"
  },
  {
    "country": "ES",
    "name": "Hernansancho",
    "lat": "40.85753",
    "lng": "-4.73045"
  },
  {
    "country": "ES",
    "name": "Hernán-Pérez",
    "lat": "40.21246",
    "lng": "-6.46479"
  },
  {
    "country": "ES",
    "name": "Hernani",
    "lat": "43.26615",
    "lng": "-1.97615"
  },
  {
    "country": "ES",
    "name": "Hermisende",
    "lat": "41.96898",
    "lng": "-6.89616"
  },
  {
    "country": "ES",
    "name": "Hérmedes de Cerrato",
    "lat": "41.81972",
    "lng": "-4.17361"
  },
  {
    "country": "ES",
    "name": "Herguijuela del Campo",
    "lat": "40.63102",
    "lng": "-5.86398"
  },
  {
    "country": "ES",
    "name": "Herguijuela de la Sierra",
    "lat": "40.44535",
    "lng": "-6.07445"
  },
  {
    "country": "ES",
    "name": "Herguijuela de Ciudad Rodrigo",
    "lat": "40.4586",
    "lng": "-6.52075"
  },
  {
    "country": "ES",
    "name": "Herce",
    "lat": "42.21423",
    "lng": "-2.16488"
  },
  {
    "country": "ES",
    "name": "Herbés",
    "lat": "40.721",
    "lng": "-0.00441"
  },
  {
    "country": "ES",
    "name": "Henche",
    "lat": "40.71474",
    "lng": "-2.70746"
  },
  {
    "country": "ES",
    "name": "Echo",
    "lat": "42.73844",
    "lng": "-0.75016"
  },
  {
    "country": "ES",
    "name": "Hazas de Cesto",
    "lat": "43.39653",
    "lng": "-3.58916"
  },
  {
    "country": "ES",
    "name": "Haza",
    "lat": "41.61667",
    "lng": "-3.81667"
  },
  {
    "country": "ES",
    "name": "Haro",
    "lat": "42.57634",
    "lng": "-2.8476"
  },
  {
    "country": "ES",
    "name": "Hacinas",
    "lat": "41.98514",
    "lng": "-3.28709"
  },
  {
    "country": "ES",
    "name": "Gutierre-Muñoz",
    "lat": "40.98295",
    "lng": "-4.63839"
  },
  {
    "country": "ES",
    "name": "Gusendos de los Oteros",
    "lat": "42.37818",
    "lng": "-5.43088"
  },
  {
    "country": "ES",
    "name": "Gurrea de Gállego",
    "lat": "42.01541",
    "lng": "-0.7615"
  },
  {
    "country": "ES",
    "name": "Guntín",
    "lat": "42.88702",
    "lng": "-7.69259"
  },
  {
    "country": "ES",
    "name": "Guitiriz",
    "lat": "43.18169",
    "lng": "-7.89656"
  },
  {
    "country": "ES",
    "name": "Guisando",
    "lat": "40.22225",
    "lng": "-5.1395"
  },
  {
    "country": "ES",
    "name": "Guirguillano",
    "lat": "42.71725",
    "lng": "-1.87798"
  },
  {
    "country": "ES",
    "name": "Guimerà",
    "lat": "41.5645",
    "lng": "1.18528"
  },
  {
    "country": "ES",
    "name": "Guils de Cerdanya",
    "lat": "42.4474",
    "lng": "1.88012"
  },
  {
    "country": "ES",
    "name": "Guijuelo",
    "lat": "40.55757",
    "lng": "-5.67067"
  },
  {
    "country": "ES",
    "name": "Guijo de Santa Bárbara",
    "lat": "40.1541",
    "lng": "-5.65414"
  },
  {
    "country": "ES",
    "name": "Guijo de Granadilla",
    "lat": "40.19351",
    "lng": "-6.16339"
  },
  {
    "country": "ES",
    "name": "Guijo de Galisteo",
    "lat": "40.09383",
    "lng": "-6.41007"
  },
  {
    "country": "ES",
    "name": "Guijo de Coria",
    "lat": "40.10098",
    "lng": "-6.46383"
  },
  {
    "country": "ES",
    "name": "Guijo de Ávila",
    "lat": "40.53078",
    "lng": "-5.6397"
  },
  {
    "country": "ES",
    "name": "Getaria",
    "lat": "43.30326",
    "lng": "-2.20444"
  },
  {
    "country": "ES",
    "name": "Gernika-Lumo",
    "lat": "43.31667",
    "lng": "-2.68333"
  },
  {
    "country": "ES",
    "name": "Güeñes",
    "lat": "43.21252",
    "lng": "-3.09497"
  },
  {
    "country": "ES",
    "name": "Getxo",
    "lat": "43.35689",
    "lng": "-3.01146"
  },
  {
    "country": "ES",
    "name": "Gúdar",
    "lat": "40.44107",
    "lng": "-0.72048"
  },
  {
    "country": "ES",
    "name": "Guaza de Campos",
    "lat": "42.13365",
    "lng": "-4.90949"
  },
  {
    "country": "ES",
    "name": "Guardo",
    "lat": "42.78966",
    "lng": "-4.84823"
  },
  {
    "country": "ES",
    "name": "Guardiola de Berguedà",
    "lat": "42.2349",
    "lng": "1.87716"
  },
  {
    "country": "ES",
    "name": "Sant Salvador de Guardiola",
    "lat": "41.68333",
    "lng": "1.76667"
  },
  {
    "country": "ES",
    "name": "Gualta",
    "lat": "42.02953",
    "lng": "3.10312"
  },
  {
    "country": "ES",
    "name": "Guadramiro",
    "lat": "41.01703",
    "lng": "-6.49369"
  },
  {
    "country": "ES",
    "name": "Guadarrama",
    "lat": "40.6727",
    "lng": "-4.08949"
  },
  {
    "country": "ES",
    "name": "Guadalix de la Sierra",
    "lat": "40.78496",
    "lng": "-3.69347"
  },
  {
    "country": "ES",
    "name": "Guadalaviar",
    "lat": "40.38824",
    "lng": "-1.71803"
  },
  {
    "country": "ES",
    "name": "Guadalajara",
    "lat": "40.62862",
    "lng": "-3.16185"
  },
  {
    "country": "ES",
    "name": "O Grove",
    "lat": "42.49444",
    "lng": "-8.86502"
  },
  {
    "country": "ES",
    "name": "Grisén",
    "lat": "41.74524",
    "lng": "-1.1626"
  },
  {
    "country": "ES",
    "name": "Grisel",
    "lat": "41.87109",
    "lng": "-1.72794"
  },
  {
    "country": "ES",
    "name": "Grisaleña",
    "lat": "42.59122",
    "lng": "-3.26416"
  },
  {
    "country": "ES",
    "name": "Griñón",
    "lat": "40.21249",
    "lng": "-3.85482"
  },
  {
    "country": "ES",
    "name": "Grijota",
    "lat": "42.05289",
    "lng": "-4.58309"
  },
  {
    "country": "ES",
    "name": "Grijalba",
    "lat": "42.43002",
    "lng": "-4.11896"
  },
  {
    "country": "ES",
    "name": "Griegos",
    "lat": "40.42722",
    "lng": "-1.71201"
  },
  {
    "country": "ES",
    "name": "Grávalos",
    "lat": "42.10836",
    "lng": "-1.99874"
  },
  {
    "country": "ES",
    "name": "Graus",
    "lat": "42.18885",
    "lng": "0.33749"
  },
  {
    "country": "ES",
    "name": "Granucillo",
    "lat": "42.05209",
    "lng": "-5.92777"
  },
  {
    "country": "ES",
    "name": "Grañón",
    "lat": "42.44992",
    "lng": "-3.02767"
  },
  {
    "country": "ES",
    "name": "Granollers",
    "lat": "41.60797",
    "lng": "2.28773"
  },
  {
    "country": "ES",
    "name": "Granja de Moreruela",
    "lat": "41.81026",
    "lng": "-5.73893"
  },
  {
    "country": "ES",
    "name": "la Granja d'Escarp",
    "lat": "41.41667",
    "lng": "0.36667"
  },
  {
    "country": "ES",
    "name": "Granera",
    "lat": "41.72741",
    "lng": "2.05924"
  },
  {
    "country": "ES",
    "name": "Grañén",
    "lat": "41.94104",
    "lng": "-0.36941"
  },
  {
    "country": "ES",
    "name": "Grandas de Salime",
    "lat": "43.21554",
    "lng": "-6.8757"
  },
  {
    "country": "ES",
    "name": "la Granadella",
    "lat": "41.35",
    "lng": "0.66667"
  },
  {
    "country": "ES",
    "name": "Grajera",
    "lat": "41.37319",
    "lng": "-3.61304"
  },
  {
    "country": "ES",
    "name": "Grajal de Campos",
    "lat": "42.32073",
    "lng": "-5.01938"
  },
  {
    "country": "ES",
    "name": "Grado",
    "lat": "43.38801",
    "lng": "-6.07433"
  },
  {
    "country": "ES",
    "name": "Gradefes",
    "lat": "42.62396",
    "lng": "-5.22691"
  },
  {
    "country": "ES",
    "name": "Gràcia",
    "lat": "41.40237",
    "lng": "2.15641"
  },
  {
    "country": "ES",
    "name": "Gotor",
    "lat": "41.54583",
    "lng": "-1.64915"
  },
  {
    "country": "ES",
    "name": "Gotarrendura",
    "lat": "40.82652",
    "lng": "-4.7409"
  },
  {
    "country": "ES",
    "name": "Gósol",
    "lat": "42.23697",
    "lng": "1.6601"
  },
  {
    "country": "ES",
    "name": "Gormaz",
    "lat": "41.49232",
    "lng": "-3.005"
  },
  {
    "country": "ES",
    "name": "Elexalde",
    "lat": "43.4149",
    "lng": "-2.93678"
  },
  {
    "country": "ES",
    "name": "Gordoncillo",
    "lat": "42.13557",
    "lng": "-5.40181"
  },
  {
    "country": "ES",
    "name": "Gordaliza del Pino",
    "lat": "42.34357",
    "lng": "-5.15731"
  },
  {
    "country": "ES",
    "name": "Goñi",
    "lat": "42.85167",
    "lng": "-1.90358"
  },
  {
    "country": "ES",
    "name": "Gondomar",
    "lat": "42.11155",
    "lng": "-8.74971"
  },
  {
    "country": "ES",
    "name": "Gomecello",
    "lat": "41.0428",
    "lng": "-5.53585"
  },
  {
    "country": "ES",
    "name": "Gómara",
    "lat": "41.62347",
    "lng": "-2.22493"
  },
  {
    "country": "ES",
    "name": "Golpejas",
    "lat": "40.99981",
    "lng": "-5.90687"
  },
  {
    "country": "ES",
    "name": "Golmés",
    "lat": "41.63354",
    "lng": "0.93125"
  },
  {
    "country": "ES",
    "name": "Golmayo",
    "lat": "41.7662",
    "lng": "-2.52267"
  },
  {
    "country": "ES",
    "name": "Goizueta",
    "lat": "43.17187",
    "lng": "-1.86411"
  },
  {
    "country": "ES",
    "name": "Godojos",
    "lat": "41.26838",
    "lng": "-1.8641"
  },
  {
    "country": "ES",
    "name": "Gistaín",
    "lat": "42.5911",
    "lng": "0.33478"
  },
  {
    "country": "ES",
    "name": "Gironella",
    "lat": "42.03433",
    "lng": "1.88019"
  },
  {
    "country": "ES",
    "name": "Xinzo de Limia",
    "lat": "42.0635",
    "lng": "-7.72459"
  },
  {
    "country": "ES",
    "name": "Ginestar",
    "lat": "41.04184",
    "lng": "0.6329"
  },
  {
    "country": "ES",
    "name": "Gimileo",
    "lat": "42.54992",
    "lng": "-2.82237"
  },
  {
    "country": "ES",
    "name": "Gimialcón",
    "lat": "40.87705",
    "lng": "-5.12308"
  },
  {
    "country": "ES",
    "name": "Gijón",
    "lat": "43.53573",
    "lng": "-5.66152"
  },
  {
    "country": "ES",
    "name": "Getafe",
    "lat": "40.30571",
    "lng": "-3.73295"
  },
  {
    "country": "ES",
    "name": "Girona",
    "lat": "41.98311",
    "lng": "2.82493"
  },
  {
    "country": "ES",
    "name": "Geria",
    "lat": "41.57868",
    "lng": "-4.87663"
  },
  {
    "country": "ES",
    "name": "Ger",
    "lat": "42.41059",
    "lng": "1.84536"
  },
  {
    "country": "ES",
    "name": "Genevilla",
    "lat": "42.6452",
    "lng": "-2.39021"
  },
  {
    "country": "ES",
    "name": "Gemuño",
    "lat": "40.59159",
    "lng": "-4.78178"
  },
  {
    "country": "ES",
    "name": "Gema",
    "lat": "41.41855",
    "lng": "-5.64906"
  },
  {
    "country": "ES",
    "name": "Gelsa",
    "lat": "41.40766",
    "lng": "-0.46158"
  },
  {
    "country": "ES",
    "name": "Gelida",
    "lat": "41.43333",
    "lng": "1.86667"
  },
  {
    "country": "ES",
    "name": "Gejuelo del Barro",
    "lat": "41.07633",
    "lng": "-6.12332"
  },
  {
    "country": "ES",
    "name": "Gea de Albarracín",
    "lat": "40.41114",
    "lng": "-1.34823"
  },
  {
    "country": "ES",
    "name": "Gaztelu",
    "lat": "43.11622",
    "lng": "-2.02439"
  },
  {
    "country": "ES",
    "name": "Gabiria",
    "lat": "43.04934",
    "lng": "-2.27962"
  },
  {
    "country": "ES",
    "name": "Gavilanes",
    "lat": "40.27791",
    "lng": "-4.85321"
  },
  {
    "country": "ES",
    "name": "Gavà",
    "lat": "41.30605",
    "lng": "2.00123"
  },
  {
    "country": "ES",
    "name": "Gatón de Campos",
    "lat": "42.04984",
    "lng": "-4.98078"
  },
  {
    "country": "ES",
    "name": "Gatika",
    "lat": "43.36313",
    "lng": "-2.87294"
  },
  {
    "country": "ES",
    "name": "Gata",
    "lat": "40.23758",
    "lng": "-6.59684"
  },
  {
    "country": "ES",
    "name": "Gascueña de Bornova",
    "lat": "41.14243",
    "lng": "-3.01924"
  },
  {
    "country": "ES",
    "name": "Gascueña",
    "lat": "40.29937",
    "lng": "-2.51856"
  },
  {
    "country": "ES",
    "name": "Gascones",
    "lat": "41.01843",
    "lng": "-3.64217"
  },
  {
    "country": "ES",
    "name": "Garriguella",
    "lat": "42.34392",
    "lng": "3.06506"
  },
  {
    "country": "ES",
    "name": "Garrigoles",
    "lat": "42.1",
    "lng": "3.03333"
  },
  {
    "country": "ES",
    "name": "Garrigàs",
    "lat": "42.19343",
    "lng": "2.95438"
  },
  {
    "country": "ES",
    "name": "Garray",
    "lat": "41.81617",
    "lng": "-2.44592"
  },
  {
    "country": "ES",
    "name": "Garralda",
    "lat": "42.94818",
    "lng": "-1.28624"
  },
  {
    "country": "ES",
    "name": "Garrafe de Torío",
    "lat": "42.73285",
    "lng": "-5.5236"
  },
  {
    "country": "ES",
    "name": "Garínoain",
    "lat": "42.60036",
    "lng": "-1.64434"
  },
  {
    "country": "ES",
    "name": "Gargüera",
    "lat": "40.0613",
    "lng": "-5.92781"
  },
  {
    "country": "ES",
    "name": "Gargantilla",
    "lat": "40.24835",
    "lng": "-5.92068"
  },
  {
    "country": "ES",
    "name": "Garganta la Olla",
    "lat": "40.11049",
    "lng": "-5.77665"
  },
  {
    "country": "ES",
    "name": "Garganta del Villar",
    "lat": "40.44965",
    "lng": "-5.1042"
  },
  {
    "country": "ES",
    "name": "Garganta de los Montes",
    "lat": "40.91992",
    "lng": "-3.68375"
  },
  {
    "country": "ES",
    "name": "Gargallo",
    "lat": "40.83583",
    "lng": "-0.58442"
  },
  {
    "country": "ES",
    "name": "Garde",
    "lat": "42.78937",
    "lng": "-0.92589"
  },
  {
    "country": "ES",
    "name": "Garcirrey",
    "lat": "40.90049",
    "lng": "-6.1312"
  },
  {
    "country": "ES",
    "name": "Garcillán",
    "lat": "40.97771",
    "lng": "-4.26577"
  },
  {
    "country": "ES",
    "name": "Garcihernández",
    "lat": "40.86096",
    "lng": "-5.43567"
  },
  {
    "country": "ES",
    "name": "Garcibuey",
    "lat": "40.51552",
    "lng": "-5.99439"
  },
  {
    "country": "ES",
    "name": "Garcia",
    "lat": "41.13333",
    "lng": "0.65"
  },
  {
    "country": "ES",
    "name": "Garaioa",
    "lat": "42.93333",
    "lng": "-1.23333"
  },
  {
    "country": "ES",
    "name": "Gandesa",
    "lat": "41.05375",
    "lng": "0.4385"
  },
  {
    "country": "ES",
    "name": "Gamones",
    "lat": "41.4669",
    "lng": "-6.17621"
  },
  {
    "country": "ES",
    "name": "Galve de Sorbe",
    "lat": "41.21667",
    "lng": "-3.18333"
  },
  {
    "country": "ES",
    "name": "Galve",
    "lat": "40.65591",
    "lng": "-0.88217"
  },
  {
    "country": "ES",
    "name": "Gallur",
    "lat": "41.8683",
    "lng": "-1.31577"
  },
  {
    "country": "ES",
    "name": "Gallocanta",
    "lat": "40.99624",
    "lng": "-1.50774"
  },
  {
    "country": "ES",
    "name": "Gallipienzo",
    "lat": "42.5245",
    "lng": "-1.41115"
  },
  {
    "country": "ES",
    "name": "Gallinero de Cameros",
    "lat": "42.17229",
    "lng": "-2.61793"
  },
  {
    "country": "ES",
    "name": "Gallifa",
    "lat": "41.69243",
    "lng": "2.11346"
  },
  {
    "country": "ES",
    "name": "Gallegos de Sobrinos",
    "lat": "40.71693",
    "lng": "-5.11224"
  },
  {
    "country": "ES",
    "name": "Gallegos del Río",
    "lat": "41.73497",
    "lng": "-6.17435"
  },
  {
    "country": "ES",
    "name": "Gallegos del Pan",
    "lat": "41.59985",
    "lng": "-5.58117"
  },
  {
    "country": "ES",
    "name": "Gallegos de Hornija",
    "lat": "41.6098",
    "lng": "-5.09768"
  },
  {
    "country": "ES",
    "name": "Gallegos de Argañán",
    "lat": "40.63146",
    "lng": "-6.70246"
  },
  {
    "country": "ES",
    "name": "Gallegos",
    "lat": "41.07508",
    "lng": "-3.78591"
  },
  {
    "country": "ES",
    "name": "Galisancho",
    "lat": "40.74418",
    "lng": "-5.55471"
  },
  {
    "country": "ES",
    "name": "Galinduste",
    "lat": "40.66266",
    "lng": "-5.54003"
  },
  {
    "country": "ES",
    "name": "Galindo y Perahuy",
    "lat": "40.94397",
    "lng": "-5.8741"
  },
  {
    "country": "ES",
    "name": "Galilea",
    "lat": "42.34703",
    "lng": "-2.23605"
  },
  {
    "country": "ES",
    "name": "Galende",
    "lat": "42.1044",
    "lng": "-6.66252"
  },
  {
    "country": "ES",
    "name": "Galdakao",
    "lat": "43.23333",
    "lng": "-2.83333"
  },
  {
    "country": "ES",
    "name": "Galbárruli",
    "lat": "42.62181",
    "lng": "-2.96087"
  },
  {
    "country": "ES",
    "name": "Galbarros",
    "lat": "42.52729",
    "lng": "-3.43827"
  },
  {
    "country": "ES",
    "name": "Galar",
    "lat": "42.76147",
    "lng": "-1.69881"
  },
  {
    "country": "ES",
    "name": "Galápagos",
    "lat": "40.69347",
    "lng": "-3.33537"
  },
  {
    "country": "ES",
    "name": "Galapagar",
    "lat": "40.5783",
    "lng": "-4.00426"
  },
  {
    "country": "ES",
    "name": "Gajates",
    "lat": "40.78254",
    "lng": "-5.36506"
  },
  {
    "country": "ES",
    "name": "Gajanejos",
    "lat": "40.84147",
    "lng": "-2.89229"
  },
  {
    "country": "ES",
    "name": "Gaintza",
    "lat": "43.05271",
    "lng": "-2.1329"
  },
  {
    "country": "ES",
    "name": "Fustiñana",
    "lat": "42.02087",
    "lng": "-1.48526"
  },
  {
    "country": "ES",
    "name": "Funes",
    "lat": "42.31562",
    "lng": "-1.80017"
  },
  {
    "country": "ES",
    "name": "Fulleda",
    "lat": "41.46334",
    "lng": "1.02395"
  },
  {
    "country": "ES",
    "name": "Fuertescusa",
    "lat": "40.47552",
    "lng": "-2.1762"
  },
  {
    "country": "ES",
    "name": "Fuentidueña de Tajo",
    "lat": "40.11574",
    "lng": "-3.15718"
  },
  {
    "country": "ES",
    "name": "Fuentidueña",
    "lat": "41.44226",
    "lng": "-3.97899"
  },
  {
    "country": "ES",
    "name": "Fuentestrún",
    "lat": "41.87466",
    "lng": "-2.08283"
  },
  {
    "country": "ES",
    "name": "Fuentespreadas",
    "lat": "41.32627",
    "lng": "-5.62798"
  },
  {
    "country": "ES",
    "name": "Fuentespina",
    "lat": "41.63079",
    "lng": "-3.68475"
  },
  {
    "country": "ES",
    "name": "Fuentespalda",
    "lat": "40.80666",
    "lng": "0.06517"
  },
  {
    "country": "ES",
    "name": "Fuentesoto",
    "lat": "41.45664",
    "lng": "-3.91835"
  },
  {
    "country": "ES",
    "name": "Fuentesecas",
    "lat": "41.63077",
    "lng": "-5.47252"
  },
  {
    "country": "ES",
    "name": "Fuentes de Valdepero",
    "lat": "42.07532",
    "lng": "-4.5005"
  },
  {
    "country": "ES",
    "name": "Fuentes de Rubielos",
    "lat": "40.16667",
    "lng": "-0.61667"
  },
  {
    "country": "ES",
    "name": "Fuentes de Ropel",
    "lat": "42.00377",
    "lng": "-5.54532"
  },
  {
    "country": "ES",
    "name": "Fuentes de Oñoro",
    "lat": "40.59102",
    "lng": "-6.81144"
  },
  {
    "country": "ES",
    "name": "Fuentes de Nava",
    "lat": "42.08333",
    "lng": "-4.78333"
  },
  {
    "country": "ES",
    "name": "Fuentes de Magaña",
    "lat": "41.93521",
    "lng": "-2.1795"
  },
  {
    "country": "ES",
    "name": "Fuentes de Jiloca",
    "lat": "41.22859",
    "lng": "-1.53616"
  },
  {
    "country": "ES",
    "name": "Fuentes de Ebro",
    "lat": "41.5125",
    "lng": "-0.63159"
  },
  {
    "country": "ES",
    "name": "Fuentes de Carbajal",
    "lat": "42.17776",
    "lng": "-5.44606"
  },
  {
    "country": "ES",
    "name": "Fuentes de Béjar",
    "lat": "40.50815",
    "lng": "-5.6927"
  },
  {
    "country": "ES",
    "name": "Fuentes de Ayódar",
    "lat": "40.03333",
    "lng": "-0.41667"
  },
  {
    "country": "ES",
    "name": "Fuentes de Año",
    "lat": "41.01769",
    "lng": "-4.89907"
  },
  {
    "country": "ES",
    "name": "Fuentes Claras",
    "lat": "40.86375",
    "lng": "-1.32266"
  },
  {
    "country": "ES",
    "name": "Fuentes Calientes",
    "lat": "40.7",
    "lng": "-0.96667"
  },
  {
    "country": "ES",
    "name": "Fuentesaúco de Fuentidueña",
    "lat": "41.42445",
    "lng": "-4.06215"
  },
  {
    "country": "ES",
    "name": "Fuentesaúco",
    "lat": "41.23043",
    "lng": "-5.49722"
  },
  {
    "country": "ES",
    "name": "Fuenterroble de Salvatierra",
    "lat": "40.56466",
    "lng": "-5.73379"
  },
  {
    "country": "ES",
    "name": "Hondarribia",
    "lat": "43.36859",
    "lng": "-1.79622"
  },
  {
    "country": "ES",
    "name": "Fuentepinilla",
    "lat": "41.56683",
    "lng": "-2.76288"
  },
  {
    "country": "ES",
    "name": "Fuentepiñel",
    "lat": "41.39892",
    "lng": "-4.04295"
  },
  {
    "country": "ES",
    "name": "Fuentepelayo",
    "lat": "41.22249",
    "lng": "-4.1757"
  },
  {
    "country": "ES",
    "name": "Fuentenovilla",
    "lat": "40.36248",
    "lng": "-3.09102"
  },
  {
    "country": "ES",
    "name": "Fuentenebro",
    "lat": "41.52873",
    "lng": "-3.75449"
  },
  {
    "country": "ES",
    "name": "Fuentemolinos",
    "lat": "41.60477",
    "lng": "-3.85005"
  },
  {
    "country": "ES",
    "name": "Fuentelviejo",
    "lat": "40.52637",
    "lng": "-2.9843"
  },
  {
    "country": "ES",
    "name": "Fuentelsaz de Soria",
    "lat": "41.86586",
    "lng": "-2.41525"
  },
  {
    "country": "ES",
    "name": "Fuentelsaz",
    "lat": "41.07359",
    "lng": "-1.83108"
  },
  {
    "country": "ES",
    "name": "Fuentelisendo",
    "lat": "41.62274",
    "lng": "-3.90129"
  },
  {
    "country": "ES",
    "name": "Fuentelencina",
    "lat": "40.51781",
    "lng": "-2.88226"
  },
  {
    "country": "ES",
    "name": "Fuentelcésped",
    "lat": "41.59162",
    "lng": "-3.64064"
  },
  {
    "country": "ES",
    "name": "Fuente la Reina",
    "lat": "40.06667",
    "lng": "-0.6"
  },
  {
    "country": "ES",
    "name": "Fuentelapeña",
    "lat": "41.25144",
    "lng": "-5.38325"
  },
  {
    "country": "ES",
    "name": "Fuentelahiguera de Albatages",
    "lat": "40.78312",
    "lng": "-3.30492"
  },
  {
    "country": "ES",
    "name": "Fuenteguinaldo",
    "lat": "40.42876",
    "lng": "-6.67528"
  },
  {
    "country": "ES",
    "name": "Fuente Encalada",
    "lat": "42.11011",
    "lng": "-5.99622"
  },
  {
    "country": "ES",
    "name": "Fuente el Sol",
    "lat": "41.17603",
    "lng": "-4.9343"
  },
  {
    "country": "ES",
    "name": "Fuente el Saz",
    "lat": "40.63215",
    "lng": "-3.51146"
  },
  {
    "country": "ES",
    "name": "Fuente el Olmo de Fuentidueña",
    "lat": "41.37929",
    "lng": "-4.00086"
  },
  {
    "country": "ES",
    "name": "Fuente de Santa Cruz",
    "lat": "41.20972",
    "lng": "-4.6353"
  },
  {
    "country": "ES",
    "name": "Fuentecén",
    "lat": "41.62852",
    "lng": "-3.86867"
  },
  {
    "country": "ES",
    "name": "Fuentecantos",
    "lat": "41.84929",
    "lng": "-2.42846"
  },
  {
    "country": "ES",
    "name": "Fuentecambrón",
    "lat": "41.50579",
    "lng": "-3.32872"
  },
  {
    "country": "ES",
    "name": "Fuentebureba",
    "lat": "42.634",
    "lng": "-3.2351"
  },
  {
    "country": "ES",
    "name": "Fuentearmegil",
    "lat": "41.71496",
    "lng": "-3.18362"
  },
  {
    "country": "ES",
    "name": "Fuensalida",
    "lat": "40.05288",
    "lng": "-4.20718"
  },
  {
    "country": "ES",
    "name": "Fuensaldaña",
    "lat": "41.70617",
    "lng": "-4.76547"
  },
  {
    "country": "ES",
    "name": "Fuenmayor",
    "lat": "42.46729",
    "lng": "-2.56153"
  },
  {
    "country": "ES",
    "name": "Fuenlabrada",
    "lat": "40.28419",
    "lng": "-3.79415"
  },
  {
    "country": "ES",
    "name": "Fuenferrada",
    "lat": "40.86923",
    "lng": "-1.01179"
  },
  {
    "country": "ES",
    "name": "Fuendetodos",
    "lat": "41.34245",
    "lng": "-0.95988"
  },
  {
    "country": "ES",
    "name": "Fuendejalón",
    "lat": "41.7605",
    "lng": "-1.47213"
  },
  {
    "country": "ES",
    "name": "Fuencemillán",
    "lat": "40.92063",
    "lng": "-3.09818"
  },
  {
    "country": "ES",
    "name": "Fuembellida",
    "lat": "40.75589",
    "lng": "-1.99861"
  },
  {
    "country": "ES",
    "name": "Frumales",
    "lat": "41.38333",
    "lng": "-4.18631"
  },
  {
    "country": "ES",
    "name": "Frómista",
    "lat": "42.26667",
    "lng": "-4.40546"
  },
  {
    "country": "ES",
    "name": "Friol",
    "lat": "43.03213",
    "lng": "-7.79514"
  },
  {
    "country": "ES",
    "name": "Friera de Valverde",
    "lat": "41.91214",
    "lng": "-5.84153"
  },
  {
    "country": "ES",
    "name": "Frías de Albarracín",
    "lat": "40.33754",
    "lng": "-1.6147"
  },
  {
    "country": "ES",
    "name": "Frías",
    "lat": "42.76225",
    "lng": "-3.29394"
  },
  {
    "country": "ES",
    "name": "Fresno El Viejo",
    "lat": "41.19752",
    "lng": "-5.14413"
  },
  {
    "country": "ES",
    "name": "Fresno de Torote",
    "lat": "40.5904",
    "lng": "-3.41003"
  },
  {
    "country": "ES",
    "name": "Fresno de Sayago",
    "lat": "41.31848",
    "lng": "-5.97129"
  },
  {
    "country": "ES",
    "name": "Fresno de Rodilla",
    "lat": "42.42054",
    "lng": "-3.48507"
  },
  {
    "country": "ES",
    "name": "Fresno del Río",
    "lat": "42.68176",
    "lng": "-4.81734"
  },
  {
    "country": "ES",
    "name": "Fresno de la Vega",
    "lat": "42.34545",
    "lng": "-5.53587"
  },
  {
    "country": "ES",
    "name": "Fresno de la Ribera",
    "lat": "41.52926",
    "lng": "-5.56658"
  },
  {
    "country": "ES",
    "name": "Fresno de la Polvorosa",
    "lat": "42.0831",
    "lng": "-5.76969"
  },
  {
    "country": "ES",
    "name": "Fresno de la Fuente",
    "lat": "41.39243",
    "lng": "-3.64491"
  },
  {
    "country": "ES",
    "name": "Fresno de Caracena",
    "lat": "41.45247",
    "lng": "-3.09123"
  },
  {
    "country": "ES",
    "name": "Fresno de Cantespino",
    "lat": "41.3682",
    "lng": "-3.4995"
  },
  {
    "country": "ES",
    "name": "Fresnillo de las Dueñas",
    "lat": "41.647",
    "lng": "-3.64558"
  },
  {
    "country": "ES",
    "name": "Fresneña",
    "lat": "42.41366",
    "lng": "-3.13453"
  },
  {
    "country": "ES",
    "name": "Fresnedoso",
    "lat": "40.43619",
    "lng": "-5.70969"
  },
  {
    "country": "ES",
    "name": "Fresnedillas",
    "lat": "40.48704",
    "lng": "-4.17146"
  },
  {
    "country": "ES",
    "name": "Fresnedilla",
    "lat": "40.23233",
    "lng": "-4.62201"
  },
  {
    "country": "ES",
    "name": "Fresneda de la Sierra Tirón",
    "lat": "42.31535",
    "lng": "-3.13596"
  },
  {
    "country": "ES",
    "name": "Fresneda de la Sierra",
    "lat": "40.39101",
    "lng": "-2.14233"
  },
  {
    "country": "ES",
    "name": "Fresneda de Cuéllar",
    "lat": "41.31905",
    "lng": "-4.44938"
  },
  {
    "country": "ES",
    "name": "Fréscano",
    "lat": "41.88333",
    "lng": "-1.45"
  },
  {
    "country": "ES",
    "name": "Frechilla de Almazán",
    "lat": "41.42656",
    "lng": "-2.51444"
  },
  {
    "country": "ES",
    "name": "Frechilla",
    "lat": "42.13768",
    "lng": "-4.84112"
  },
  {
    "country": "ES",
    "name": "Frandovínez",
    "lat": "42.31032",
    "lng": "-3.83783"
  },
  {
    "country": "ES",
    "name": "Fraga",
    "lat": "41.52294",
    "lng": "0.34894"
  },
  {
    "country": "ES",
    "name": "Frades de la Sierra",
    "lat": "40.65687",
    "lng": "-5.78223"
  },
  {
    "country": "ES",
    "name": "Frades",
    "lat": "43.05011",
    "lng": "-8.29391"
  },
  {
    "country": "ES",
    "name": "Foz-Calanda",
    "lat": "40.92208",
    "lng": "-0.26483"
  },
  {
    "country": "ES",
    "name": "Foz",
    "lat": "43.5692",
    "lng": "-7.25441"
  },
  {
    "country": "ES",
    "name": "Forua",
    "lat": "43.33343",
    "lng": "-2.67504"
  },
  {
    "country": "ES",
    "name": "Fortià",
    "lat": "42.2432",
    "lng": "3.03881"
  },
  {
    "country": "ES",
    "name": "Fortanete",
    "lat": "40.50533",
    "lng": "-0.52283"
  },
  {
    "country": "ES",
    "name": "Fórnoles",
    "lat": "40.89359",
    "lng": "-0.00383"
  },
  {
    "country": "ES",
    "name": "Fornelos de Montes",
    "lat": "42.34126",
    "lng": "-8.45291"
  },
  {
    "country": "ES",
    "name": "Fornells de la Selva",
    "lat": "41.93159",
    "lng": "2.80907"
  },
  {
    "country": "ES",
    "name": "Formiche Alto",
    "lat": "40.32367",
    "lng": "-0.89241"
  },
  {
    "country": "ES",
    "name": "Forfoleda",
    "lat": "41.09779",
    "lng": "-5.74979"
  },
  {
    "country": "ES",
    "name": "Forès",
    "lat": "41.48333",
    "lng": "1.23333"
  },
  {
    "country": "ES",
    "name": "Forcall",
    "lat": "40.64542",
    "lng": "-0.19992"
  },
  {
    "country": "ES",
    "name": "Fonzaleche",
    "lat": "42.58114",
    "lng": "-3.01218"
  },
  {
    "country": "ES",
    "name": "Fonz",
    "lat": "42.01015",
    "lng": "0.25878"
  },
  {
    "country": "ES",
    "name": "Fontiveros",
    "lat": "40.92997",
    "lng": "-4.96445"
  },
  {
    "country": "ES",
    "name": "Fontioso",
    "lat": "41.94273",
    "lng": "-3.73872"
  },
  {
    "country": "ES",
    "name": "Fontihoyuelo",
    "lat": "42.16192",
    "lng": "-5.05791"
  },
  {
    "country": "ES",
    "name": "Fontellas",
    "lat": "42.02694",
    "lng": "-1.57648"
  },
  {
    "country": "ES",
    "name": "Fontcoberta",
    "lat": "42.13333",
    "lng": "2.8"
  },
  {
    "country": "ES",
    "name": "Fontanilles",
    "lat": "42.01117",
    "lng": "3.10776"
  },
  {
    "country": "ES",
    "name": "Fontanar",
    "lat": "40.72466",
    "lng": "-3.17309"
  },
  {
    "country": "ES",
    "name": "Fonsagrada",
    "lat": "43.12398",
    "lng": "-7.0679"
  },
  {
    "country": "ES",
    "name": "Fonollosa",
    "lat": "41.76303",
    "lng": "1.66867"
  },
  {
    "country": "ES",
    "name": "Fonfría",
    "lat": "41.63493",
    "lng": "-6.14081"
  },
  {
    "country": "ES",
    "name": "Fonfría",
    "lat": "40.99566",
    "lng": "-1.08475"
  },
  {
    "country": "ES",
    "name": "Foncea",
    "lat": "42.61529",
    "lng": "-3.03897"
  },
  {
    "country": "ES",
    "name": "Fompedraza",
    "lat": "41.53541",
    "lng": "-4.14483"
  },
  {
    "country": "ES",
    "name": "Fombuena",
    "lat": "41.14442",
    "lng": "-1.19266"
  },
  {
    "country": "ES",
    "name": "Fombellida",
    "lat": "41.76693",
    "lng": "-4.18409"
  },
  {
    "country": "ES",
    "name": "Folgoso de la Ribera",
    "lat": "42.64693",
    "lng": "-6.32035"
  },
  {
    "country": "ES",
    "name": "Foixà",
    "lat": "42.03626",
    "lng": "3.00021"
  },
  {
    "country": "ES",
    "name": "Fogars de Montclús",
    "lat": "41.73333",
    "lng": "2.45"
  },
  {
    "country": "ES",
    "name": "Florida de Liébana",
    "lat": "41.02361",
    "lng": "-5.76252"
  },
  {
    "country": "ES",
    "name": "Flores de Ávila",
    "lat": "40.93358",
    "lng": "-5.07914"
  },
  {
    "country": "ES",
    "name": "Flix",
    "lat": "41.23074",
    "lng": "0.55008"
  },
  {
    "country": "ES",
    "name": "Flaçà",
    "lat": "42.06667",
    "lng": "2.96667"
  },
  {
    "country": "ES",
    "name": "Fitero",
    "lat": "42.0577",
    "lng": "-1.85756"
  },
  {
    "country": "ES",
    "name": "Fiscal",
    "lat": "42.49561",
    "lng": "-0.12094"
  },
  {
    "country": "ES",
    "name": "Fisterra",
    "lat": "42.90492",
    "lng": "-9.26289"
  },
  {
    "country": "ES",
    "name": "Figueruelas",
    "lat": "41.76651",
    "lng": "-1.17473"
  },
  {
    "country": "ES",
    "name": "Figueruela de Arriba",
    "lat": "41.86867",
    "lng": "-6.44454"
  },
  {
    "country": "ES",
    "name": "Figueroles",
    "lat": "40.11667",
    "lng": "-0.23333"
  },
  {
    "country": "ES",
    "name": "Figueras",
    "lat": "43.53943",
    "lng": "-7.02559"
  },
  {
    "country": "ES",
    "name": "Figueres",
    "lat": "42.26645",
    "lng": "2.96163"
  },
  {
    "country": "ES",
    "name": "Ferreruela de Huerva",
    "lat": "41.06325",
    "lng": "-1.2335"
  },
  {
    "country": "ES",
    "name": "Ferreruela",
    "lat": "41.76673",
    "lng": "-6.07215"
  },
  {
    "country": "ES",
    "name": "Ferreras de Arriba",
    "lat": "41.89878",
    "lng": "-6.19461"
  },
  {
    "country": "ES",
    "name": "Ferreras de Abajo",
    "lat": "41.89651",
    "lng": "-6.07904"
  },
  {
    "country": "ES",
    "name": "Fermoselle",
    "lat": "41.31738",
    "lng": "-6.39584"
  },
  {
    "country": "ES",
    "name": "Fene",
    "lat": "43.45",
    "lng": "-8.15"
  },
  {
    "country": "ES",
    "name": "Fayón",
    "lat": "41.23851",
    "lng": "0.33302"
  },
  {
    "country": "ES",
    "name": "la Fatarella",
    "lat": "41.16667",
    "lng": "0.48333"
  },
  {
    "country": "ES",
    "name": "Farrera",
    "lat": "42.49654",
    "lng": "1.27216"
  },
  {
    "country": "ES",
    "name": "Farlete",
    "lat": "41.68122",
    "lng": "-0.50678"
  },
  {
    "country": "ES",
    "name": "Fariza",
    "lat": "41.41667",
    "lng": "-6.26667"
  },
  {
    "country": "ES",
    "name": "Faramontanos de Tábara",
    "lat": "41.83469",
    "lng": "-5.88883"
  },
  {
    "country": "ES",
    "name": "Fanzara",
    "lat": "40.01667",
    "lng": "-0.31667"
  },
  {
    "country": "ES",
    "name": "Falset",
    "lat": "41.14576",
    "lng": "0.81979"
  },
  {
    "country": "ES",
    "name": "Falces",
    "lat": "42.38966",
    "lng": "-1.79321"
  },
  {
    "country": "ES",
    "name": "Fago",
    "lat": "42.7344",
    "lng": "-0.88131"
  },
  {
    "country": "ES",
    "name": "Fabero",
    "lat": "42.76803",
    "lng": "-6.62651"
  },
  {
    "country": "ES",
    "name": "Fabara",
    "lat": "41.1775",
    "lng": "0.16908"
  },
  {
    "country": "ES",
    "name": "Ezkurra",
    "lat": "43.08333",
    "lng": "-1.81667"
  },
  {
    "country": "ES",
    "name": "Ezcaray",
    "lat": "42.32536",
    "lng": "-3.01309"
  },
  {
    "country": "ES",
    "name": "Eulate",
    "lat": "42.77641",
    "lng": "-2.20638"
  },
  {
    "country": "ES",
    "name": "Etayo",
    "lat": "42.61695",
    "lng": "-2.15447"
  },
  {
    "country": "ES",
    "name": "Estriégana",
    "lat": "41.05821",
    "lng": "-2.52363"
  },
  {
    "country": "ES",
    "name": "Estremera",
    "lat": "40.18333",
    "lng": "-3.1"
  },
  {
    "country": "ES",
    "name": "Estollo",
    "lat": "42.32953",
    "lng": "-2.85092"
  },
  {
    "country": "ES",
    "name": "Estercuel",
    "lat": "40.855",
    "lng": "-0.63208"
  },
  {
    "country": "ES",
    "name": "Estépar",
    "lat": "42.27731",
    "lng": "-3.89946"
  },
  {
    "country": "ES",
    "name": "Estepa de San Juan",
    "lat": "41.92661",
    "lng": "-2.33322"
  },
  {
    "country": "ES",
    "name": "Estella-Lizarra",
    "lat": "42.67182",
    "lng": "-2.03226"
  },
  {
    "country": "ES",
    "name": "l'Estartit",
    "lat": "42.0534",
    "lng": "3.19767"
  },
  {
    "country": "ES",
    "name": "Estadilla",
    "lat": "42.05657",
    "lng": "0.24343"
  },
  {
    "country": "ES",
    "name": "Estada",
    "lat": "42.07201",
    "lng": "0.23219"
  },
  {
    "country": "ES",
    "name": "Establés",
    "lat": "41.00767",
    "lng": "-2.02438"
  },
  {
    "country": "ES",
    "name": "Esquivias",
    "lat": "40.1044",
    "lng": "-3.76677"
  },
  {
    "country": "ES",
    "name": "Espronceda",
    "lat": "42.59707",
    "lng": "-2.30524"
  },
  {
    "country": "ES",
    "name": "Espot",
    "lat": "42.57838",
    "lng": "1.08666"
  },
  {
    "country": "ES",
    "name": "Esponellà",
    "lat": "42.16667",
    "lng": "2.8"
  },
  {
    "country": "ES",
    "name": "Espolla",
    "lat": "42.3912",
    "lng": "3.00064"
  },
  {
    "country": "ES",
    "name": "Esplús",
    "lat": "41.7987",
    "lng": "0.27586"
  },
  {
    "country": "ES",
    "name": "Esplugues de Llobregat",
    "lat": "41.37732",
    "lng": "2.08809"
  },
  {
    "country": "ES",
    "name": "Esplegares",
    "lat": "40.8565",
    "lng": "-2.37084"
  },
  {
    "country": "ES",
    "name": "Espirdo",
    "lat": "40.99764",
    "lng": "-4.07331"
  },
  {
    "country": "ES",
    "name": "Espinosa de Villagonzalo",
    "lat": "42.47949",
    "lng": "-4.37218"
  },
  {
    "country": "ES",
    "name": "Espinosa de los Monteros",
    "lat": "43.07754",
    "lng": "-3.55365"
  },
  {
    "country": "ES",
    "name": "Espinosa del Camino",
    "lat": "42.4059",
    "lng": "-3.28019"
  },
  {
    "country": "ES",
    "name": "Espinosa de Henares",
    "lat": "40.90053",
    "lng": "-3.06956"
  },
  {
    "country": "ES",
    "name": "Espinosa de Cervera",
    "lat": "41.89683",
    "lng": "-3.46858"
  },
  {
    "country": "ES",
    "name": "Espinosa de Cerrato",
    "lat": "41.96679",
    "lng": "-3.95346"
  },
  {
    "country": "ES",
    "name": "Espino de la Orbada",
    "lat": "41.10693",
    "lng": "-5.42515"
  },
  {
    "country": "ES",
    "name": "Espejón",
    "lat": "41.83023",
    "lng": "-3.25936"
  },
  {
    "country": "ES",
    "name": "Espeja de San Marcelino",
    "lat": "41.80227",
    "lng": "-3.2223"
  },
  {
    "country": "ES",
    "name": "Espeja",
    "lat": "40.56565",
    "lng": "-6.71582"
  },
  {
    "country": "ES",
    "name": "Esparreguera",
    "lat": "41.53809",
    "lng": "1.87025"
  },
  {
    "country": "ES",
    "name": "Espadilla",
    "lat": "40.03333",
    "lng": "-0.35"
  },
  {
    "country": "ES",
    "name": "Espadañedo",
    "lat": "42.11618",
    "lng": "-6.39419"
  },
  {
    "country": "ES",
    "name": "Espadaña",
    "lat": "41.06085",
    "lng": "-6.28457"
  },
  {
    "country": "ES",
    "name": "Eslava",
    "lat": "42.56459",
    "lng": "-1.45947"
  },
  {
    "country": "ES",
    "name": "Esguevillas de Esgueva",
    "lat": "41.75018",
    "lng": "-4.38062"
  },
  {
    "country": "ES",
    "name": "Esgos",
    "lat": "42.32549",
    "lng": "-7.69691"
  },
  {
    "country": "ES",
    "name": "Escurial de la Sierra",
    "lat": "40.61731",
    "lng": "-5.9552"
  },
  {
    "country": "ES",
    "name": "Escucha",
    "lat": "40.79467",
    "lng": "-0.81012"
  },
  {
    "country": "ES",
    "name": "Escorihuela",
    "lat": "40.544",
    "lng": "-0.97078"
  },
  {
    "country": "ES",
    "name": "Eskoriatza",
    "lat": "43.01829",
    "lng": "-2.52598"
  },
  {
    "country": "ES",
    "name": "Escopete",
    "lat": "40.41324",
    "lng": "-3.0046"
  },
  {
    "country": "ES",
    "name": "Escobosa de Almazán",
    "lat": "41.48626",
    "lng": "-2.3714"
  },
  {
    "country": "ES",
    "name": "Escobar de Polendos",
    "lat": "41.09079",
    "lng": "-4.13117"
  },
  {
    "country": "ES",
    "name": "Escobar de Campos",
    "lat": "42.31337",
    "lng": "-4.96573"
  },
  {
    "country": "ES",
    "name": "Escatrón",
    "lat": "41.29149",
    "lng": "-0.32308"
  },
  {
    "country": "ES",
    "name": "Escariche",
    "lat": "40.40553",
    "lng": "-3.0531"
  },
  {
    "country": "ES",
    "name": "Escarabajosa de Cabezas",
    "lat": "41.1047",
    "lng": "-4.19411"
  },
  {
    "country": "ES",
    "name": "Escamilla",
    "lat": "40.54979",
    "lng": "-2.56292"
  },
  {
    "country": "ES",
    "name": "Escalona del Prado",
    "lat": "41.16682",
    "lng": "-4.12272"
  },
  {
    "country": "ES",
    "name": "Escalona",
    "lat": "40.1669",
    "lng": "-4.40484"
  },
  {
    "country": "ES",
    "name": "Escalante",
    "lat": "43.43678",
    "lng": "-3.51347"
  },
  {
    "country": "ES",
    "name": "Ermua",
    "lat": "43.18725",
    "lng": "-2.50261"
  },
  {
    "country": "ES",
    "name": "Erla",
    "lat": "42.11732",
    "lng": "-0.95019"
  },
  {
    "country": "ES",
    "name": "Eratsun",
    "lat": "43.08333",
    "lng": "-1.8"
  },
  {
    "country": "ES",
    "name": "Erandio",
    "lat": "43.30438",
    "lng": "-2.97352"
  },
  {
    "country": "ES",
    "name": "Épila",
    "lat": "41.60045",
    "lng": "-1.28007"
  },
  {
    "country": "ES",
    "name": "Entrimo",
    "lat": "41.93297",
    "lng": "-8.11725"
  },
  {
    "country": "ES",
    "name": "Entrena",
    "lat": "42.38782",
    "lng": "-2.53066"
  },
  {
    "country": "ES",
    "name": "Entrambasaguas",
    "lat": "43.37846",
    "lng": "-3.68072"
  },
  {
    "country": "ES",
    "name": "Entrala",
    "lat": "41.43006",
    "lng": "-5.75556"
  },
  {
    "country": "ES",
    "name": "Enériz",
    "lat": "42.67095",
    "lng": "-1.72794"
  },
  {
    "country": "ES",
    "name": "Endrinal",
    "lat": "40.59109",
    "lng": "-5.80411"
  },
  {
    "country": "ES",
    "name": "Enciso",
    "lat": "42.14946",
    "lng": "-2.26953"
  },
  {
    "country": "ES",
    "name": "Encío",
    "lat": "42.67115",
    "lng": "-3.0868"
  },
  {
    "country": "ES",
    "name": "Encinillas",
    "lat": "41.01809",
    "lng": "-4.15784"
  },
  {
    "country": "ES",
    "name": "Encinedo",
    "lat": "42.27049",
    "lng": "-6.59368"
  },
  {
    "country": "ES",
    "name": "Encinasola de los Comendadores",
    "lat": "41.03089",
    "lng": "-6.53261"
  },
  {
    "country": "ES",
    "name": "Encinas de Esgueva",
    "lat": "41.75653",
    "lng": "-4.10357"
  },
  {
    "country": "ES",
    "name": "Encinas de Arriba",
    "lat": "40.7712",
    "lng": "-5.55661"
  },
  {
    "country": "ES",
    "name": "Encinas de Abajo",
    "lat": "40.93493",
    "lng": "-5.47037"
  },
  {
    "country": "ES",
    "name": "Encinas",
    "lat": "41.37511",
    "lng": "-3.66762"
  },
  {
    "country": "ES",
    "name": "Encina de San Silvestre",
    "lat": "41.01442",
    "lng": "-6.09268"
  },
  {
    "country": "ES",
    "name": "Encinacorba",
    "lat": "41.28516",
    "lng": "-1.27516"
  },
  {
    "country": "ES",
    "name": "Embid de Ariza",
    "lat": "41.3783",
    "lng": "-1.97373"
  },
  {
    "country": "ES",
    "name": "Embid",
    "lat": "40.97256",
    "lng": "-1.71206"
  },
  {
    "country": "ES",
    "name": "El Viso de San Juan",
    "lat": "40.14154",
    "lng": "-3.91817"
  },
  {
    "country": "ES",
    "name": "El Vellón",
    "lat": "40.76495",
    "lng": "-3.57969"
  },
  {
    "country": "ES",
    "name": "El Tiemblo",
    "lat": "40.41533",
    "lng": "-4.50156"
  },
  {
    "country": "ES",
    "name": "El Real de San Vicente",
    "lat": "40.13561",
    "lng": "-4.69095"
  },
  {
    "country": "ES",
    "name": "El Prat de Llobregat",
    "lat": "41.32784",
    "lng": "2.09472"
  },
  {
    "country": "ES",
    "name": "El Pardo",
    "lat": "40.51454",
    "lng": "-3.77253"
  },
  {
    "country": "ES",
    "name": "Elorz",
    "lat": "42.73258",
    "lng": "-1.56152"
  },
  {
    "country": "ES",
    "name": "Elorrio",
    "lat": "43.12924",
    "lng": "-2.54056"
  },
  {
    "country": "ES",
    "name": "El Molar",
    "lat": "40.73215",
    "lng": "-3.57969"
  },
  {
    "country": "ES",
    "name": "Éller",
    "lat": "42.41636",
    "lng": "1.79223"
  },
  {
    "country": "ES",
    "name": "Eljas",
    "lat": "40.21648",
    "lng": "-6.84616"
  },
  {
    "country": "ES",
    "name": "El Hoyo de Pinares",
    "lat": "40.50084",
    "lng": "-4.42357"
  },
  {
    "country": "ES",
    "name": "Gurb",
    "lat": "41.95419",
    "lng": "2.23537"
  },
  {
    "country": "ES",
    "name": "Elgeta",
    "lat": "43.13703",
    "lng": "-2.48862"
  },
  {
    "country": "ES",
    "name": "Empuriabrava",
    "lat": "42.24691",
    "lng": "3.12059"
  },
  {
    "country": "ES",
    "name": "Elgorriaga",
    "lat": "43.13858",
    "lng": "-1.68657"
  },
  {
    "country": "ES",
    "name": "Elgoibar",
    "lat": "43.21601",
    "lng": "-2.41334"
  },
  {
    "country": "ES",
    "name": "El Franco",
    "lat": "43.55522",
    "lng": "-6.8662"
  },
  {
    "country": "ES",
    "name": "Figaró",
    "lat": "41.72122",
    "lng": "2.27297"
  },
  {
    "country": "ES",
    "name": "Ferrol",
    "lat": "43.48961",
    "lng": "-8.2194"
  },
  {
    "country": "ES",
    "name": "El Escorial",
    "lat": "40.58254",
    "lng": "-4.12846"
  },
  {
    "country": "ES",
    "name": "Elduain",
    "lat": "43.14017",
    "lng": "-2.00102"
  },
  {
    "country": "ES",
    "name": "Zalla",
    "lat": "43.23333",
    "lng": "-3.13333"
  },
  {
    "country": "ES",
    "name": "Elciego",
    "lat": "42.51569",
    "lng": "-2.61897"
  },
  {
    "country": "ES",
    "name": "El Castellar",
    "lat": "40.36531",
    "lng": "-0.81734"
  },
  {
    "country": "ES",
    "name": "El Casar de Escalona",
    "lat": "40.0464",
    "lng": "-4.52507"
  },
  {
    "country": "ES",
    "name": "El Burgo de Osma",
    "lat": "41.58619",
    "lng": "-3.06522"
  },
  {
    "country": "ES",
    "name": "El Burgo de Ebro",
    "lat": "41.57157",
    "lng": "-0.74128"
  },
  {
    "country": "ES",
    "name": "O Barco de Valdeorras",
    "lat": "42.41642",
    "lng": "-6.99005"
  },
  {
    "country": "ES",
    "name": "El Barco de Ávila",
    "lat": "40.3571",
    "lng": "-5.52365"
  },
  {
    "country": "ES",
    "name": "El Astillero",
    "lat": "43.40094",
    "lng": "-3.82051"
  },
  {
    "country": "ES",
    "name": "el Raval",
    "lat": "41.38042",
    "lng": "2.1686"
  },
  {
    "country": "ES",
    "name": "Elantxobe",
    "lat": "43.40243",
    "lng": "-2.63912"
  },
  {
    "country": "ES",
    "name": "El Álamo",
    "lat": "40.23066",
    "lng": "-3.99447"
  },
  {
    "country": "ES",
    "name": "Ejulve",
    "lat": "40.77633",
    "lng": "-0.55344"
  },
  {
    "country": "ES",
    "name": "Ejeme",
    "lat": "40.76685",
    "lng": "-5.53828"
  },
  {
    "country": "ES",
    "name": "Ejea de los Caballeros",
    "lat": "42.12632",
    "lng": "-1.13716"
  },
  {
    "country": "ES",
    "name": "Eibar",
    "lat": "43.18493",
    "lng": "-2.47158"
  },
  {
    "country": "ES",
    "name": "Echarri-Aranaz",
    "lat": "42.90791",
    "lng": "-2.06474"
  },
  {
    "country": "ES",
    "name": "Echarri",
    "lat": "42.78017",
    "lng": "-1.82525"
  },
  {
    "country": "ES",
    "name": "Etxalar",
    "lat": "43.23376",
    "lng": "-1.63671"
  },
  {
    "country": "ES",
    "name": "Ea",
    "lat": "43.37985",
    "lng": "-2.58556"
  },
  {
    "country": "ES",
    "name": "Duruelo de la Sierra",
    "lat": "41.95448",
    "lng": "-2.93086"
  },
  {
    "country": "ES",
    "name": "Duruelo",
    "lat": "41.23622",
    "lng": "-3.64914"
  },
  {
    "country": "ES",
    "name": "Durón",
    "lat": "40.6253",
    "lng": "-2.72662"
  },
  {
    "country": "ES",
    "name": "Durango",
    "lat": "43.17124",
    "lng": "-2.6338"
  },
  {
    "country": "ES",
    "name": "Dumbría",
    "lat": "43.00836",
    "lng": "-9.11328"
  },
  {
    "country": "ES",
    "name": "Dueñas",
    "lat": "41.87717",
    "lng": "-4.54714"
  },
  {
    "country": "ES",
    "name": "Driebes",
    "lat": "40.24498",
    "lng": "-3.04165"
  },
  {
    "country": "ES",
    "name": "Dozón",
    "lat": "42.58333",
    "lng": "-8.01667"
  },
  {
    "country": "ES",
    "name": "Dosrius",
    "lat": "41.58333",
    "lng": "2.41667"
  },
  {
    "country": "ES",
    "name": "Duesaigües",
    "lat": "41.15",
    "lng": "0.93333"
  },
  {
    "country": "ES",
    "name": "Donvidas",
    "lat": "41.08954",
    "lng": "-4.80634"
  },
  {
    "country": "ES",
    "name": "Donjimeno",
    "lat": "40.95978",
    "lng": "-4.84627"
  },
  {
    "country": "ES",
    "name": "Doñinos de Salamanca",
    "lat": "40.95978",
    "lng": "-5.74349"
  },
  {
    "country": "ES",
    "name": "Doñinos de Ledesma",
    "lat": "41.01251",
    "lng": "-6.03412"
  },
  {
    "country": "ES",
    "name": "Donhierro",
    "lat": "41.11642",
    "lng": "-4.6967"
  },
  {
    "country": "ES",
    "name": "Domingo García",
    "lat": "41.11528",
    "lng": "-4.37927"
  },
  {
    "country": "ES",
    "name": "Dios le Guarde",
    "lat": "40.64283",
    "lng": "-6.31511"
  },
  {
    "country": "ES",
    "name": "Dicastillo",
    "lat": "42.59647",
    "lng": "-2.02666"
  },
  {
    "country": "ES",
    "name": "Deza",
    "lat": "41.46373",
    "lng": "-2.02046"
  },
  {
    "country": "ES",
    "name": "Deba",
    "lat": "43.29571",
    "lng": "-2.35213"
  },
  {
    "country": "ES",
    "name": "Destriana",
    "lat": "42.32729",
    "lng": "-6.09573"
  },
  {
    "country": "ES",
    "name": "Desojo",
    "lat": "42.5879",
    "lng": "-2.27438"
  },
  {
    "country": "ES",
    "name": "Descargamaría",
    "lat": "40.30446",
    "lng": "-6.48666"
  },
  {
    "country": "ES",
    "name": "Derio",
    "lat": "43.30544",
    "lng": "-2.88116"
  },
  {
    "country": "ES",
    "name": "Dehesa de Romanos",
    "lat": "42.63876",
    "lng": "-4.43518"
  },
  {
    "country": "ES",
    "name": "Dehesa de Montejo",
    "lat": "42.81939",
    "lng": "-4.51019"
  },
  {
    "country": "ES",
    "name": "Degaña",
    "lat": "42.93969",
    "lng": "-6.56935"
  },
  {
    "country": "ES",
    "name": "Das",
    "lat": "42.36143",
    "lng": "1.87051"
  },
  {
    "country": "ES",
    "name": "Daroca",
    "lat": "41.11475",
    "lng": "-1.41492"
  },
  {
    "country": "ES",
    "name": "Darnius",
    "lat": "42.36667",
    "lng": "2.83333"
  },
  {
    "country": "ES",
    "name": "Daganzo de Arriba",
    "lat": "40.54293",
    "lng": "-3.45457"
  },
  {
    "country": "ES",
    "name": "Cuzcurrita de Río Tirón",
    "lat": "42.54151",
    "lng": "-2.96421"
  },
  {
    "country": "ES",
    "name": "Curtis",
    "lat": "43.12374",
    "lng": "-8.14818"
  },
  {
    "country": "ES",
    "name": "Curiel de Duero",
    "lat": "41.64327",
    "lng": "-4.1011"
  },
  {
    "country": "ES",
    "name": "Cuntis",
    "lat": "42.63396",
    "lng": "-8.56256"
  },
  {
    "country": "ES",
    "name": "Cunit",
    "lat": "41.19829",
    "lng": "1.63645"
  },
  {
    "country": "ES",
    "name": "Culleredo",
    "lat": "43.28788",
    "lng": "-8.38858"
  },
  {
    "country": "ES",
    "name": "Culla",
    "lat": "40.3365",
    "lng": "-0.16569"
  },
  {
    "country": "ES",
    "name": "Cuevas Labradas",
    "lat": "40.4535",
    "lng": "-1.05008"
  },
  {
    "country": "ES",
    "name": "Cuevas de Vinromá",
    "lat": "40.30976",
    "lng": "0.12084"
  },
  {
    "country": "ES",
    "name": "Cuevas de San Clemente",
    "lat": "42.13009",
    "lng": "-3.5684"
  },
  {
    "country": "ES",
    "name": "Cuevas de Provanco",
    "lat": "41.54209",
    "lng": "-3.96203"
  },
  {
    "country": "ES",
    "name": "Cuevas del Valle",
    "lat": "40.29418",
    "lng": "-5.00938"
  },
  {
    "country": "ES",
    "name": "Cuevas de Almudén",
    "lat": "40.71342",
    "lng": "-0.82958"
  },
  {
    "country": "ES",
    "name": "Cueva del Hierro",
    "lat": "40.58258",
    "lng": "-2.03612"
  },
  {
    "country": "ES",
    "name": "Cueva de Ágreda",
    "lat": "41.7631",
    "lng": "-1.88818"
  },
  {
    "country": "ES",
    "name": "Cuenca de Campos",
    "lat": "42.05927",
    "lng": "-5.05539"
  },
  {
    "country": "ES",
    "name": "Cuenca",
    "lat": "40.06667",
    "lng": "-2.13333"
  },
  {
    "country": "ES",
    "name": "Cuéllar",
    "lat": "41.40155",
    "lng": "-4.31474"
  },
  {
    "country": "ES",
    "name": "Cuelgamures",
    "lat": "41.30738",
    "lng": "-5.65769"
  },
  {
    "country": "ES",
    "name": "Cudillero",
    "lat": "43.56217",
    "lng": "-6.14589"
  },
  {
    "country": "ES",
    "name": "Cucalón",
    "lat": "41.08608",
    "lng": "-1.21475"
  },
  {
    "country": "ES",
    "name": "Cubo de la Solana",
    "lat": "41.60224",
    "lng": "-2.42179"
  },
  {
    "country": "ES",
    "name": "Cubo de Bureba",
    "lat": "42.64011",
    "lng": "-3.20626"
  },
  {
    "country": "ES",
    "name": "Cubo de Benavente",
    "lat": "42.1249",
    "lng": "-6.16342"
  },
  {
    "country": "ES",
    "name": "Cubla",
    "lat": "40.20978",
    "lng": "-1.07917"
  },
  {
    "country": "ES",
    "name": "Cubillos del Sil",
    "lat": "42.62519",
    "lng": "-6.5636"
  },
  {
    "country": "ES",
    "name": "Cubillos",
    "lat": "41.57436",
    "lng": "-5.7392"
  },
  {
    "country": "ES",
    "name": "Cubillo del Campo",
    "lat": "42.16854",
    "lng": "-3.61025"
  },
  {
    "country": "ES",
    "name": "Cubillo",
    "lat": "41.12138",
    "lng": "-3.90878"
  },
  {
    "country": "ES",
    "name": "Cubillas de Santa Marta",
    "lat": "41.83358",
    "lng": "-4.61463"
  },
  {
    "country": "ES",
    "name": "Cubillas de Rueda",
    "lat": "42.65626",
    "lng": "-5.17528"
  },
  {
    "country": "ES",
    "name": "Cubillas de los Oteros",
    "lat": "42.37199",
    "lng": "-5.50877"
  },
  {
    "country": "ES",
    "name": "Cubillas de Cerrato",
    "lat": "41.79844",
    "lng": "-4.4672"
  },
  {
    "country": "ES",
    "name": "Cubilla",
    "lat": "41.74905",
    "lng": "-2.93717"
  },
  {
    "country": "ES",
    "name": "Cubells",
    "lat": "41.85062",
    "lng": "0.959"
  },
  {
    "country": "ES",
    "name": "Cubelles",
    "lat": "41.20772",
    "lng": "1.67267"
  },
  {
    "country": "ES",
    "name": "Cubel",
    "lat": "41.09604",
    "lng": "-1.63729"
  },
  {
    "country": "ES",
    "name": "Cubas",
    "lat": "40.189",
    "lng": "-3.83526"
  },
  {
    "country": "ES",
    "name": "Cuarte de Huerva",
    "lat": "41.59466",
    "lng": "-0.93268"
  },
  {
    "country": "ES",
    "name": "Cualedro",
    "lat": "41.98897",
    "lng": "-7.59464"
  },
  {
    "country": "ES",
    "name": "Cuadros",
    "lat": "42.71163",
    "lng": "-5.63828"
  },
  {
    "country": "ES",
    "name": "Cruïlles",
    "lat": "41.95",
    "lng": "3.01667"
  },
  {
    "country": "ES",
    "name": "Crivillén",
    "lat": "40.88325",
    "lng": "-0.57666"
  },
  {
    "country": "ES",
    "name": "Cristóbal",
    "lat": "40.46923",
    "lng": "-5.88967"
  },
  {
    "country": "ES",
    "name": "Crespos",
    "lat": "40.87128",
    "lng": "-4.97094"
  },
  {
    "country": "ES",
    "name": "Crespià",
    "lat": "42.18333",
    "lng": "2.8"
  },
  {
    "country": "ES",
    "name": "Crémenes",
    "lat": "42.90357",
    "lng": "-5.14374"
  },
  {
    "country": "ES",
    "name": "Creixell",
    "lat": "41.16618",
    "lng": "1.44032"
  },
  {
    "country": "ES",
    "name": "Cozuelos de Fuentidueña",
    "lat": "41.39086",
    "lng": "-4.09564"
  },
  {
    "country": "ES",
    "name": "Covelo",
    "lat": "42.23333",
    "lng": "-8.35"
  },
  {
    "country": "ES",
    "name": "Covarrubias",
    "lat": "42.05927",
    "lng": "-3.51956"
  },
  {
    "country": "ES",
    "name": "Covaleda",
    "lat": "41.93493",
    "lng": "-2.88325"
  },
  {
    "country": "ES",
    "name": "Cosuenda",
    "lat": "41.36559",
    "lng": "-1.29867"
  },
  {
    "country": "ES",
    "name": "Costur",
    "lat": "40.11971",
    "lng": "-0.17385"
  },
  {
    "country": "ES",
    "name": "Coslada",
    "lat": "40.42378",
    "lng": "-3.56129"
  },
  {
    "country": "ES",
    "name": "Coscurita",
    "lat": "41.43483",
    "lng": "-2.47571"
  },
  {
    "country": "ES",
    "name": "Cosa",
    "lat": "40.83392",
    "lng": "-1.1365"
  },
  {
    "country": "ES",
    "name": "Coruña del Conde",
    "lat": "41.76566",
    "lng": "-3.39059"
  },
  {
    "country": "ES",
    "name": "Corullón",
    "lat": "42.57896",
    "lng": "-6.81925"
  },
  {
    "country": "ES",
    "name": "Kortezubi",
    "lat": "43.33333",
    "lng": "-2.65"
  },
  {
    "country": "ES",
    "name": "Cortes de Arenoso",
    "lat": "40.18812",
    "lng": "-0.54195"
  },
  {
    "country": "ES",
    "name": "Cortes de Aragón",
    "lat": "40.97366",
    "lng": "-0.83575"
  },
  {
    "country": "ES",
    "name": "Cortes",
    "lat": "41.92269",
    "lng": "-1.42045"
  },
  {
    "country": "ES",
    "name": "Cortegada",
    "lat": "42.20983",
    "lng": "-8.1682"
  },
  {
    "country": "ES",
    "name": "Corçà",
    "lat": "41.98333",
    "lng": "3.01667"
  },
  {
    "country": "ES",
    "name": "Corrales de Duero",
    "lat": "41.67205",
    "lng": "-4.04817"
  },
  {
    "country": "ES",
    "name": "Corrales",
    "lat": "41.358",
    "lng": "-5.72479"
  },
  {
    "country": "ES",
    "name": "Corral de Ayllón",
    "lat": "41.39081",
    "lng": "-3.45856"
  },
  {
    "country": "ES",
    "name": "Corporales",
    "lat": "42.43208",
    "lng": "-2.99535"
  },
  {
    "country": "ES",
    "name": "Corpa",
    "lat": "40.42327",
    "lng": "-3.26003"
  },
  {
    "country": "ES",
    "name": "Cornellà del Terri",
    "lat": "42.08333",
    "lng": "2.81667"
  },
  {
    "country": "ES",
    "name": "Cornellà de Llobregat",
    "lat": "41.35",
    "lng": "2.08333"
  },
  {
    "country": "ES",
    "name": "Cornago",
    "lat": "42.06444",
    "lng": "-2.09486"
  },
  {
    "country": "ES",
    "name": "Coristanco",
    "lat": "43.2",
    "lng": "-8.75"
  },
  {
    "country": "ES",
    "name": "Corgo",
    "lat": "42.94434",
    "lng": "-7.4314"
  },
  {
    "country": "ES",
    "name": "Coreses",
    "lat": "41.54794",
    "lng": "-5.62252"
  },
  {
    "country": "ES",
    "name": "Corera",
    "lat": "42.34344",
    "lng": "-2.22023"
  },
  {
    "country": "ES",
    "name": "Corella",
    "lat": "42.11507",
    "lng": "-1.78563"
  },
  {
    "country": "ES",
    "name": "Corduente",
    "lat": "40.84304",
    "lng": "-1.97841"
  },
  {
    "country": "ES",
    "name": "Cordovín",
    "lat": "42.38557",
    "lng": "-2.815"
  },
  {
    "country": "ES",
    "name": "Cordovilla la Real",
    "lat": "42.07961",
    "lng": "-4.25988"
  },
  {
    "country": "ES",
    "name": "Cordovilla",
    "lat": "40.95095",
    "lng": "-5.40725"
  },
  {
    "country": "ES",
    "name": "Corcubión",
    "lat": "42.94414",
    "lng": "-9.1926"
  },
  {
    "country": "ES",
    "name": "Corcos",
    "lat": "41.80946",
    "lng": "-4.6927"
  },
  {
    "country": "ES",
    "name": "Corbins",
    "lat": "41.68333",
    "lng": "0.7"
  },
  {
    "country": "ES",
    "name": "Corbillos de los Oteros",
    "lat": "42.40769",
    "lng": "-5.45963"
  },
  {
    "country": "ES",
    "name": "Corbera de Llobregat",
    "lat": "41.41702",
    "lng": "1.9197"
  },
  {
    "country": "ES",
    "name": "Corbalán",
    "lat": "40.40308",
    "lng": "-0.98525"
  },
  {
    "country": "ES",
    "name": "Copernal",
    "lat": "40.86463",
    "lng": "-3.05396"
  },
  {
    "country": "ES",
    "name": "Coomonte",
    "lat": "42.11546",
    "lng": "-5.81316"
  },
  {
    "country": "ES",
    "name": "Contreras",
    "lat": "42.02004",
    "lng": "-3.41084"
  },
  {
    "country": "ES",
    "name": "Contamina",
    "lat": "41.30535",
    "lng": "-1.91731"
  },
  {
    "country": "ES",
    "name": "Constanzana",
    "lat": "40.93821",
    "lng": "-4.87515"
  },
  {
    "country": "ES",
    "name": "Constantí",
    "lat": "41.15392",
    "lng": "1.21262"
  },
  {
    "country": "ES",
    "name": "Congostrina",
    "lat": "41.03719",
    "lng": "-2.98569"
  },
  {
    "country": "ES",
    "name": "Congosto de Valdavia",
    "lat": "42.71584",
    "lng": "-4.63366"
  },
  {
    "country": "ES",
    "name": "Congosto",
    "lat": "42.61755",
    "lng": "-6.52048"
  },
  {
    "country": "ES",
    "name": "Conesa",
    "lat": "41.51667",
    "lng": "1.3"
  },
  {
    "country": "ES",
    "name": "Condemios de Arriba",
    "lat": "41.21644",
    "lng": "-3.12543"
  },
  {
    "country": "ES",
    "name": "Condemios de Abajo",
    "lat": "41.21667",
    "lng": "-3.1"
  },
  {
    "country": "ES",
    "name": "Comillas",
    "lat": "43.38603",
    "lng": "-4.29162"
  },
  {
    "country": "ES",
    "name": "Combarro",
    "lat": "42.43188",
    "lng": "-8.70649"
  },
  {
    "country": "ES",
    "name": "Colungo",
    "lat": "42.17125",
    "lng": "0.06812"
  },
  {
    "country": "ES",
    "name": "Colunga",
    "lat": "43.48531",
    "lng": "-5.27009"
  },
  {
    "country": "ES",
    "name": "Colomers",
    "lat": "42.08333",
    "lng": "2.98333"
  },
  {
    "country": "ES",
    "name": "Colmenar Viejo",
    "lat": "40.65909",
    "lng": "-3.76762"
  },
  {
    "country": "ES",
    "name": "Colmenarejo",
    "lat": "40.56063",
    "lng": "-4.01713"
  },
  {
    "country": "ES",
    "name": "Colmenar de Oreja",
    "lat": "40.10675",
    "lng": "-3.38547"
  },
  {
    "country": "ES",
    "name": "Colmenar de Montemayor",
    "lat": "40.39957",
    "lng": "-5.95618"
  },
  {
    "country": "ES",
    "name": "Colmenar del Arroyo",
    "lat": "40.41897",
    "lng": "-4.19845"
  },
  {
    "country": "ES",
    "name": "Collsuspina",
    "lat": "41.8258",
    "lng": "2.17546"
  },
  {
    "country": "ES",
    "name": "Coll de Nargó",
    "lat": "42.17473",
    "lng": "1.31694"
  },
  {
    "country": "ES",
    "name": "Colldejou",
    "lat": "41.0997",
    "lng": "0.88717"
  },
  {
    "country": "ES",
    "name": "Collbató",
    "lat": "41.57009",
    "lng": "1.82712"
  },
  {
    "country": "ES",
    "name": "Collazos de Boedo",
    "lat": "42.62009",
    "lng": "-4.48294"
  },
  {
    "country": "ES",
    "name": "Collado-Villalba",
    "lat": "40.63506",
    "lng": "-4.00486"
  },
  {
    "country": "ES",
    "name": "Collado Mediano",
    "lat": "40.69326",
    "lng": "-4.0228"
  },
  {
    "country": "ES",
    "name": "Collado Hermoso",
    "lat": "41.03869",
    "lng": "-3.91859"
  },
  {
    "country": "ES",
    "name": "Collado del Mirón",
    "lat": "40.55307",
    "lng": "-5.35398"
  },
  {
    "country": "ES",
    "name": "Collado de Contreras",
    "lat": "40.88743",
    "lng": "-4.9314"
  },
  {
    "country": "ES",
    "name": "Collado",
    "lat": "40.05729",
    "lng": "-5.72052"
  },
  {
    "country": "ES",
    "name": "Colindres",
    "lat": "43.39667",
    "lng": "-3.45361"
  },
  {
    "country": "ES",
    "name": "Coles",
    "lat": "42.4",
    "lng": "-7.83333"
  },
  {
    "country": "ES",
    "name": "Colera",
    "lat": "42.40394",
    "lng": "3.15153"
  },
  {
    "country": "ES",
    "name": "Coirós",
    "lat": "43.25",
    "lng": "-8.16667"
  },
  {
    "country": "ES",
    "name": "el Cogul",
    "lat": "41.46667",
    "lng": "0.68333"
  },
  {
    "country": "ES",
    "name": "Cogolludo",
    "lat": "40.94691",
    "lng": "-3.0893"
  },
  {
    "country": "ES",
    "name": "Cogollos",
    "lat": "42.19982",
    "lng": "-3.70005"
  },
  {
    "country": "ES",
    "name": "Cogollor",
    "lat": "40.84818",
    "lng": "-2.74425"
  },
  {
    "country": "ES",
    "name": "Cogeces del Monte",
    "lat": "41.5103",
    "lng": "-4.31721"
  },
  {
    "country": "ES",
    "name": "Codos",
    "lat": "41.29266",
    "lng": "-1.37425"
  },
  {
    "country": "ES",
    "name": "Codorniz",
    "lat": "41.06745",
    "lng": "-4.60021"
  },
  {
    "country": "ES",
    "name": "Coca de Alba",
    "lat": "40.87833",
    "lng": "-5.36537"
  },
  {
    "country": "ES",
    "name": "Coca",
    "lat": "41.21767",
    "lng": "-4.52145"
  },
  {
    "country": "ES",
    "name": "Cobreros",
    "lat": "42.07323",
    "lng": "-6.70053"
  },
  {
    "country": "ES",
    "name": "Cobos de Fuentidueña",
    "lat": "41.38265",
    "lng": "-3.92723"
  },
  {
    "country": "ES",
    "name": "Cobos de Cerrato",
    "lat": "42.02808",
    "lng": "-4.00251"
  },
  {
    "country": "ES",
    "name": "Cobeta",
    "lat": "40.8656",
    "lng": "-2.14211"
  },
  {
    "country": "ES",
    "name": "Cobeña",
    "lat": "40.56667",
    "lng": "-3.5"
  },
  {
    "country": "ES",
    "name": "Cobeja",
    "lat": "40.02076",
    "lng": "-3.85599"
  },
  {
    "country": "ES",
    "name": "Coaña",
    "lat": "43.51392",
    "lng": "-6.75527"
  },
  {
    "country": "ES",
    "name": "el Clot",
    "lat": "41.40986",
    "lng": "2.19053"
  },
  {
    "country": "ES",
    "name": "Clavijo",
    "lat": "42.34897",
    "lng": "-2.42666"
  },
  {
    "country": "ES",
    "name": "Clarés de Ribota",
    "lat": "41.52957",
    "lng": "-1.83773"
  },
  {
    "country": "ES",
    "name": "Zizurkil",
    "lat": "43.19917",
    "lng": "-2.0742"
  },
  {
    "country": "ES",
    "name": "Cizur Mayor",
    "lat": "42.78795",
    "lng": "-1.69065"
  },
  {
    "country": "ES",
    "name": "Ciutadilla",
    "lat": "41.56113",
    "lng": "1.13935"
  },
  {
    "country": "ES",
    "name": "Siurana",
    "lat": "42.20916",
    "lng": "2.99392"
  },
  {
    "country": "ES",
    "name": "Ciudad Rodrigo",
    "lat": "40.6",
    "lng": "-6.53333"
  },
  {
    "country": "ES",
    "name": "Ciudad Lineal",
    "lat": "40.44505",
    "lng": "-3.65132"
  },
  {
    "country": "ES",
    "name": "Ciutadella",
    "lat": "40.00112",
    "lng": "3.84144"
  },
  {
    "country": "ES",
    "name": "Cistierna",
    "lat": "42.80344",
    "lng": "-5.12664"
  },
  {
    "country": "ES",
    "name": "Cistérniga",
    "lat": "41.61294",
    "lng": "-4.68697"
  },
  {
    "country": "ES",
    "name": "Cistella",
    "lat": "42.2687",
    "lng": "2.8478"
  },
  {
    "country": "ES",
    "name": "Cisneros",
    "lat": "42.22046",
    "lng": "-4.85807"
  },
  {
    "country": "ES",
    "name": "Cisla",
    "lat": "40.96662",
    "lng": "-5.01405"
  },
  {
    "country": "ES",
    "name": "Cirujales del Río",
    "lat": "41.86691",
    "lng": "-2.32549"
  },
  {
    "country": "ES",
    "name": "Cirueña",
    "lat": "42.41214",
    "lng": "-2.89593"
  },
  {
    "country": "ES",
    "name": "Ciruelos de Cervera",
    "lat": "41.90562",
    "lng": "-3.53015"
  },
  {
    "country": "ES",
    "name": "Ciruelas",
    "lat": "40.75021",
    "lng": "-3.0858"
  },
  {
    "country": "ES",
    "name": "Ciriza",
    "lat": "42.79019",
    "lng": "-1.82822"
  },
  {
    "country": "ES",
    "name": "Ciria",
    "lat": "41.61831",
    "lng": "-1.96578"
  },
  {
    "country": "ES",
    "name": "Cirauqui",
    "lat": "42.67596",
    "lng": "-1.89115"
  },
  {
    "country": "ES",
    "name": "Cirat",
    "lat": "40.05",
    "lng": "-0.45"
  },
  {
    "country": "ES",
    "name": "Cipérez",
    "lat": "40.9621",
    "lng": "-6.26552"
  },
  {
    "country": "ES",
    "name": "Ziordia",
    "lat": "42.87068",
    "lng": "-2.22954"
  },
  {
    "country": "ES",
    "name": "Cintruénigo",
    "lat": "42.07937",
    "lng": "-1.80458"
  },
  {
    "country": "ES",
    "name": "Cinctorres",
    "lat": "40.58333",
    "lng": "-0.21667"
  },
  {
    "country": "ES",
    "name": "Cincovillas",
    "lat": "41.20501",
    "lng": "-2.81834"
  },
  {
    "country": "ES",
    "name": "Cinco Olivas",
    "lat": "41.33966",
    "lng": "-0.37116"
  },
  {
    "country": "ES",
    "name": "Cimballa",
    "lat": "41.10118",
    "lng": "-1.77352"
  },
  {
    "country": "ES",
    "name": "Cimanes del Tejar",
    "lat": "42.61789",
    "lng": "-5.80506"
  },
  {
    "country": "ES",
    "name": "Cimanes de la Vega",
    "lat": "42.11646",
    "lng": "-5.59851"
  },
  {
    "country": "ES",
    "name": "Cilleruelo de San Mamés",
    "lat": "41.4322",
    "lng": "-3.56614"
  },
  {
    "country": "ES",
    "name": "Cilleruelo de Arriba",
    "lat": "41.90487",
    "lng": "-3.66102"
  },
  {
    "country": "ES",
    "name": "Cilleruelo de Abajo",
    "lat": "41.88405",
    "lng": "-3.79723"
  },
  {
    "country": "ES",
    "name": "Cilleros de la Bastida",
    "lat": "40.57614",
    "lng": "-6.06094"
  },
  {
    "country": "ES",
    "name": "Cilleros",
    "lat": "40.11486",
    "lng": "-6.79256"
  },
  {
    "country": "ES",
    "name": "Cillán",
    "lat": "40.70675",
    "lng": "-4.98135"
  },
  {
    "country": "ES",
    "name": "Cihuri",
    "lat": "42.56499",
    "lng": "-2.92287"
  },
  {
    "country": "ES",
    "name": "Cihuela",
    "lat": "41.40721",
    "lng": "-1.99989"
  },
  {
    "country": "ES",
    "name": "Ciguñuela",
    "lat": "41.64064",
    "lng": "-4.85688"
  },
  {
    "country": "ES",
    "name": "Cigudosa",
    "lat": "41.93333",
    "lng": "-2.05"
  },
  {
    "country": "ES",
    "name": "Cigales",
    "lat": "41.7578",
    "lng": "-4.69848"
  },
  {
    "country": "ES",
    "name": "Cifuentes",
    "lat": "40.78622",
    "lng": "-2.62245"
  },
  {
    "country": "ES",
    "name": "Zierbena",
    "lat": "43.35",
    "lng": "-3.08333"
  },
  {
    "country": "ES",
    "name": "Ciempozuelos",
    "lat": "40.15913",
    "lng": "-3.62103"
  },
  {
    "country": "ES",
    "name": "Cidones",
    "lat": "41.81444",
    "lng": "-2.63991"
  },
  {
    "country": "ES",
    "name": "Cidamón",
    "lat": "42.49518",
    "lng": "-2.87834"
  },
  {
    "country": "ES",
    "name": "Ciadoncha",
    "lat": "42.15814",
    "lng": "-3.93235"
  },
  {
    "country": "ES",
    "name": "Chozas de Canales",
    "lat": "40.10014",
    "lng": "-4.04333"
  },
  {
    "country": "ES",
    "name": "Chozas de Abajo",
    "lat": "42.50657",
    "lng": "-5.68656"
  },
  {
    "country": "ES",
    "name": "Chodes",
    "lat": "41.48696",
    "lng": "-1.48012"
  },
  {
    "country": "ES",
    "name": "Chiprana",
    "lat": "41.26317",
    "lng": "-0.12741"
  },
  {
    "country": "ES",
    "name": "Chinchón",
    "lat": "40.1402",
    "lng": "-3.42267"
  },
  {
    "country": "ES",
    "name": "Chimillas",
    "lat": "42.17033",
    "lng": "-0.45168"
  },
  {
    "country": "ES",
    "name": "Chiloeches",
    "lat": "40.57038",
    "lng": "-3.16003"
  },
  {
    "country": "ES",
    "name": "Chillarón del Rey",
    "lat": "40.59818",
    "lng": "-2.69126"
  },
  {
    "country": "ES",
    "name": "Chillarón de Cuenca",
    "lat": "40.10539",
    "lng": "-2.22181"
  },
  {
    "country": "ES",
    "name": "Chía",
    "lat": "42.5208",
    "lng": "0.46563"
  },
  {
    "country": "ES",
    "name": "Chert/Xert",
    "lat": "40.51944",
    "lng": "0.15831"
  },
  {
    "country": "ES",
    "name": "Chequilla",
    "lat": "40.606",
    "lng": "-1.82787"
  },
  {
    "country": "ES",
    "name": "Checa",
    "lat": "40.58614",
    "lng": "-1.79056"
  },
  {
    "country": "ES",
    "name": "Chapinería",
    "lat": "40.37891",
    "lng": "-4.21009"
  },
  {
    "country": "ES",
    "name": "Chantada",
    "lat": "42.60876",
    "lng": "-7.77115"
  },
  {
    "country": "ES",
    "name": "Chañe",
    "lat": "41.33834",
    "lng": "-4.42764"
  },
  {
    "country": "ES",
    "name": "Chamartín",
    "lat": "40.46206",
    "lng": "-3.6766"
  },
  {
    "country": "ES",
    "name": "Chamartín",
    "lat": "40.70267",
    "lng": "-4.95769"
  },
  {
    "country": "ES",
    "name": "Chalamera",
    "lat": "41.66567",
    "lng": "0.16299"
  },
  {
    "country": "ES",
    "name": "Cevico Navero",
    "lat": "41.86112",
    "lng": "-4.18498"
  },
  {
    "country": "ES",
    "name": "Cevico de la Torre",
    "lat": "41.85113",
    "lng": "-4.40973"
  },
  {
    "country": "ES",
    "name": "Cetina",
    "lat": "41.29208",
    "lng": "-1.96281"
  },
  {
    "country": "ES",
    "name": "Cesuras",
    "lat": "43.17282",
    "lng": "-8.20061"
  },
  {
    "country": "ES",
    "name": "Zestoa",
    "lat": "43.23973",
    "lng": "-2.2579"
  },
  {
    "country": "ES",
    "name": "Cervo",
    "lat": "43.67019",
    "lng": "-7.41013"
  },
  {
    "country": "ES",
    "name": "Cervillego de la Cruz",
    "lat": "41.18783",
    "lng": "-4.94966"
  },
  {
    "country": "ES",
    "name": "Cervià de Ter",
    "lat": "42.0665",
    "lng": "2.90743"
  },
  {
    "country": "ES",
    "name": "Cerveruela",
    "lat": "41.21567",
    "lng": "-1.21525"
  },
  {
    "country": "ES",
    "name": "Cervera de Pisuerga",
    "lat": "42.86676",
    "lng": "-4.49796"
  },
  {
    "country": "ES",
    "name": "Cervera del Río Alhama",
    "lat": "42.00517",
    "lng": "-1.95531"
  },
  {
    "country": "ES",
    "name": "Cervera de los Montes",
    "lat": "40.05182",
    "lng": "-4.81072"
  },
  {
    "country": "ES",
    "name": "Cervera del Maestre",
    "lat": "40.45366",
    "lng": "0.27659"
  },
  {
    "country": "ES",
    "name": "Cervera de la Cañada",
    "lat": "41.43301",
    "lng": "-1.73568"
  },
  {
    "country": "ES",
    "name": "Cervera de Buitrago",
    "lat": "40.91988",
    "lng": "-3.52702"
  },
  {
    "country": "ES",
    "name": "Cervera",
    "lat": "41.67003",
    "lng": "1.2721"
  },
  {
    "country": "ES",
    "name": "Cervelló",
    "lat": "41.39587",
    "lng": "1.95917"
  },
  {
    "country": "ES",
    "name": "Cervatos de la Cueza",
    "lat": "42.29054",
    "lng": "-4.76947"
  },
  {
    "country": "ES",
    "name": "Cerratón de Juarros",
    "lat": "42.42227",
    "lng": "-3.37347"
  },
  {
    "country": "ES",
    "name": "Cerralbo",
    "lat": "40.97347",
    "lng": "-6.5871"
  },
  {
    "country": "ES",
    "name": "Cernadilla",
    "lat": "42.02083",
    "lng": "-6.41701"
  },
  {
    "country": "ES",
    "name": "Cerezo de Río Tirón",
    "lat": "42.4914",
    "lng": "-3.136"
  },
  {
    "country": "ES",
    "name": "Cerezo de Arriba",
    "lat": "41.2389",
    "lng": "-3.55846"
  },
  {
    "country": "ES",
    "name": "Cerezo de Abajo",
    "lat": "41.21817",
    "lng": "-3.59126"
  },
  {
    "country": "ES",
    "name": "Cerezo",
    "lat": "40.23678",
    "lng": "-6.22764"
  },
  {
    "country": "ES",
    "name": "Cerezal de Peñahorcada",
    "lat": "41.13071",
    "lng": "-6.65357"
  },
  {
    "country": "ES",
    "name": "Cerecinos del Carrizal",
    "lat": "41.68384",
    "lng": "-5.65303"
  },
  {
    "country": "ES",
    "name": "Cerecinos de Campos",
    "lat": "41.90017",
    "lng": "-5.48605"
  },
  {
    "country": "ES",
    "name": "Cereceda de la Sierra",
    "lat": "40.56627",
    "lng": "-6.0914"
  },
  {
    "country": "ES",
    "name": "Cerdido",
    "lat": "43.62063",
    "lng": "-7.99959"
  },
  {
    "country": "ES",
    "name": "Cercedilla",
    "lat": "40.74101",
    "lng": "-4.05644"
  },
  {
    "country": "ES",
    "name": "Cerceda",
    "lat": "43.18333",
    "lng": "-8.48333"
  },
  {
    "country": "ES",
    "name": "Cerbón",
    "lat": "41.92934",
    "lng": "-2.16895"
  },
  {
    "country": "ES",
    "name": "Zerain",
    "lat": "43.01237",
    "lng": "-2.27264"
  },
  {
    "country": "ES",
    "name": "Cepeda la Mora",
    "lat": "40.4578",
    "lng": "-5.04833"
  },
  {
    "country": "ES",
    "name": "Cepeda",
    "lat": "40.466",
    "lng": "-6.041"
  },
  {
    "country": "ES",
    "name": "Centenera de Andaluz",
    "lat": "41.50679",
    "lng": "-2.71813"
  },
  {
    "country": "ES",
    "name": "Centenera",
    "lat": "40.65064",
    "lng": "-3.0512"
  },
  {
    "country": "ES",
    "name": "Centelles",
    "lat": "41.79746",
    "lng": "2.21902"
  },
  {
    "country": "ES",
    "name": "Cenlle",
    "lat": "42.34183",
    "lng": "-8.08982"
  },
  {
    "country": "ES",
    "name": "Cenicientos",
    "lat": "40.26459",
    "lng": "-4.46683"
  },
  {
    "country": "ES",
    "name": "Cenicero",
    "lat": "42.4813",
    "lng": "-2.64412"
  },
  {
    "country": "ES",
    "name": "Cendejas de la Torre",
    "lat": "40.97916",
    "lng": "-2.85053"
  },
  {
    "country": "ES",
    "name": "Celrà",
    "lat": "42.03333",
    "lng": "2.88333"
  },
  {
    "country": "ES",
    "name": "Cellorigo",
    "lat": "42.62703",
    "lng": "-3.00016"
  },
  {
    "country": "ES",
    "name": "Cella",
    "lat": "40.45325",
    "lng": "-1.2875"
  },
  {
    "country": "ES",
    "name": "Celanova",
    "lat": "42.15303",
    "lng": "-7.95513"
  },
  {
    "country": "ES",
    "name": "Celada del Camino",
    "lat": "42.26359",
    "lng": "-3.93362"
  },
  {
    "country": "ES",
    "name": "Ceinos de Campos",
    "lat": "42.03284",
    "lng": "-5.15007"
  },
  {
    "country": "ES",
    "name": "Zegama",
    "lat": "42.97556",
    "lng": "-2.29091"
  },
  {
    "country": "ES",
    "name": "Cee",
    "lat": "42.95466",
    "lng": "-9.188"
  },
  {
    "country": "ES",
    "name": "Cedrillas",
    "lat": "40.43708",
    "lng": "-0.8515"
  },
  {
    "country": "ES",
    "name": "Cedillo del Condado",
    "lat": "40.1126",
    "lng": "-3.92127"
  },
  {
    "country": "ES",
    "name": "Cedillo de la Torre",
    "lat": "41.42482",
    "lng": "-3.60577"
  },
  {
    "country": "ES",
    "name": "Cedeira",
    "lat": "43.66044",
    "lng": "-8.05719"
  },
  {
    "country": "ES",
    "name": "Cebrones del Río",
    "lat": "42.25726",
    "lng": "-5.82622"
  },
  {
    "country": "ES",
    "name": "Cebreros",
    "lat": "40.45835",
    "lng": "-4.46433"
  },
  {
    "country": "ES",
    "name": "Cebrecos",
    "lat": "41.98408",
    "lng": "-3.59661"
  },
  {
    "country": "ES",
    "name": "Cebanico",
    "lat": "42.72526",
    "lng": "-5.02568"
  },
  {
    "country": "ES",
    "name": "Zeanuri",
    "lat": "43.1",
    "lng": "-2.75"
  },
  {
    "country": "ES",
    "name": "Cea",
    "lat": "42.4749",
    "lng": "-7.98739"
  },
  {
    "country": "ES",
    "name": "Cazurra",
    "lat": "41.41583",
    "lng": "-5.70454"
  },
  {
    "country": "ES",
    "name": "Cazalegas",
    "lat": "40.00958",
    "lng": "-4.67606"
  },
  {
    "country": "ES",
    "name": "Cayuela",
    "lat": "42.27223",
    "lng": "-3.81895"
  },
  {
    "country": "ES",
    "name": "Catoira",
    "lat": "42.66748",
    "lng": "-8.72323"
  },
  {
    "country": "ES",
    "name": "el Catllar",
    "lat": "41.16667",
    "lng": "1.31667"
  },
  {
    "country": "ES",
    "name": "Catí",
    "lat": "40.47156",
    "lng": "0.02275"
  },
  {
    "country": "ES",
    "name": "Castroverde de Cerrato",
    "lat": "41.75609",
    "lng": "-4.22151"
  },
  {
    "country": "ES",
    "name": "Castroverde de Campos",
    "lat": "41.97049",
    "lng": "-5.31434"
  },
  {
    "country": "ES",
    "name": "Castroverde",
    "lat": "43.0302",
    "lng": "-7.32428"
  },
  {
    "country": "ES",
    "name": "Castro-Urdiales",
    "lat": "43.38285",
    "lng": "-3.22043"
  },
  {
    "country": "ES",
    "name": "Castroserracín",
    "lat": "41.39329",
    "lng": "-3.80196"
  },
  {
    "country": "ES",
    "name": "Castroserna de Abajo",
    "lat": "41.20835",
    "lng": "-3.73387"
  },
  {
    "country": "ES",
    "name": "Castroponce",
    "lat": "42.12646",
    "lng": "-5.18245"
  },
  {
    "country": "ES",
    "name": "Castropol",
    "lat": "43.52777",
    "lng": "-7.03048"
  },
  {
    "country": "ES",
    "name": "Castropodame",
    "lat": "42.57943",
    "lng": "-6.46837"
  },
  {
    "country": "ES",
    "name": "Castronuño",
    "lat": "41.38918",
    "lng": "-5.26408"
  },
  {
    "country": "ES",
    "name": "Castronuevo de Esgueva",
    "lat": "41.6818",
    "lng": "-4.58866"
  },
  {
    "country": "ES",
    "name": "Castronuevo",
    "lat": "41.72046",
    "lng": "-5.54315"
  },
  {
    "country": "ES",
    "name": "Castromonte",
    "lat": "41.77355",
    "lng": "-5.03909"
  },
  {
    "country": "ES",
    "name": "Castromocho",
    "lat": "42.03104",
    "lng": "-4.82404"
  },
  {
    "country": "ES",
    "name": "Castromembibre",
    "lat": "41.67246",
    "lng": "-5.30473"
  },
  {
    "country": "ES",
    "name": "Castrojimeno",
    "lat": "41.39659",
    "lng": "-3.84726"
  },
  {
    "country": "ES",
    "name": "Castrogonzalo",
    "lat": "41.99099",
    "lng": "-5.60301"
  },
  {
    "country": "ES",
    "name": "Castrodeza",
    "lat": "41.64921",
    "lng": "-4.95888"
  },
  {
    "country": "ES",
    "name": "Castro de Rei",
    "lat": "43.20866",
    "lng": "-7.40026"
  },
  {
    "country": "ES",
    "name": "Castro de Fuentidueña",
    "lat": "41.42044",
    "lng": "-3.85528"
  },
  {
    "country": "ES",
    "name": "Castrocontrigo",
    "lat": "42.18363",
    "lng": "-6.19022"
  },
  {
    "country": "ES",
    "name": "Castro Caldelas",
    "lat": "42.37366",
    "lng": "-7.42578"
  },
  {
    "country": "ES",
    "name": "Castrocalbón",
    "lat": "42.19706",
    "lng": "-5.98226"
  },
  {
    "country": "ES",
    "name": "Castrobol",
    "lat": "42.13717",
    "lng": "-5.31423"
  },
  {
    "country": "ES",
    "name": "Castro",
    "lat": "42.76667",
    "lng": "-7.58333"
  },
  {
    "country": "ES",
    "name": "Castrillo-Tejeriego",
    "lat": "41.7034",
    "lng": "-4.37142"
  },
  {
    "country": "ES",
    "name": "Castrillo de Villavega",
    "lat": "42.45463",
    "lng": "-4.48069"
  },
  {
    "country": "ES",
    "name": "Castrillo de Onielo",
    "lat": "41.8582",
    "lng": "-4.30125"
  },
  {
    "country": "ES",
    "name": "Castrillo del Val",
    "lat": "42.31401",
    "lng": "-3.58501"
  },
  {
    "country": "ES",
    "name": "Castrillo de la Vega",
    "lat": "41.65166",
    "lng": "-3.78089"
  },
  {
    "country": "ES",
    "name": "Castrillo de la Valduerna",
    "lat": "42.32393",
    "lng": "-6.13455"
  },
  {
    "country": "ES",
    "name": "Castrillo de la Reina",
    "lat": "41.98714",
    "lng": "-3.2356"
  },
  {
    "country": "ES",
    "name": "Castrillo de la Guareña",
    "lat": "41.23043",
    "lng": "-5.3255"
  },
  {
    "country": "ES",
    "name": "Castrillo de Duero",
    "lat": "41.57494",
    "lng": "-4.01547"
  },
  {
    "country": "ES",
    "name": "Castrillo de Don Juan",
    "lat": "41.79086",
    "lng": "-4.07031"
  },
  {
    "country": "ES",
    "name": "Castrillo de Cabrera",
    "lat": "42.34036",
    "lng": "-6.54451"
  },
  {
    "country": "ES",
    "name": "Castrelo de Miño",
    "lat": "42.29798",
    "lng": "-8.06697"
  },
  {
    "country": "ES",
    "name": "Castrejón de la Peña",
    "lat": "42.80795",
    "lng": "-4.59901"
  },
  {
    "country": "ES",
    "name": "Castraz",
    "lat": "40.70517",
    "lng": "-6.33383"
  },
  {
    "country": "ES",
    "name": "Castilruiz",
    "lat": "41.87678",
    "lng": "-2.0593"
  },
  {
    "country": "ES",
    "name": "Castilnuevo",
    "lat": "40.81431",
    "lng": "-1.85782"
  },
  {
    "country": "ES",
    "name": "Castillonuevo",
    "lat": "42.6827",
    "lng": "-1.03121"
  },
  {
    "country": "ES",
    "name": "Castillo de Villamalefa",
    "lat": "40.13333",
    "lng": "-0.38333"
  },
  {
    "country": "ES",
    "name": "Castillo de Bayuela",
    "lat": "40.10032",
    "lng": "-4.68562"
  },
  {
    "country": "ES",
    "name": "Castell-Platja d'Aro",
    "lat": "41.81751",
    "lng": "3.06742"
  },
  {
    "country": "ES",
    "name": "Castillo-Albaráñez",
    "lat": "40.29869",
    "lng": "-2.39277"
  },
  {
    "country": "ES",
    "name": "Castillejo-Sierra",
    "lat": "40.37477",
    "lng": "-2.1404"
  },
  {
    "country": "ES",
    "name": "Castillejo de Robledo",
    "lat": "41.55867",
    "lng": "-3.49689"
  },
  {
    "country": "ES",
    "name": "Castillejo de Mesleón",
    "lat": "41.281",
    "lng": "-3.60137"
  },
  {
    "country": "ES",
    "name": "Castillejo de Martín Viejo",
    "lat": "40.69728",
    "lng": "-6.63763"
  },
  {
    "country": "ES",
    "name": "Castillazuelo",
    "lat": "42.06774",
    "lng": "0.06491"
  },
  {
    "country": "ES",
    "name": "Castiliscar",
    "lat": "42.37662",
    "lng": "-1.27326"
  },
  {
    "country": "ES",
    "name": "Castilfrío de la Sierra",
    "lat": "41.91929",
    "lng": "-2.30497"
  },
  {
    "country": "ES",
    "name": "Castilforte",
    "lat": "40.55735",
    "lng": "-2.43226"
  },
  {
    "country": "ES",
    "name": "Castilfalé",
    "lat": "42.21991",
    "lng": "-5.42122"
  },
  {
    "country": "ES",
    "name": "Castil de Vela",
    "lat": "41.98461",
    "lng": "-4.9592"
  },
  {
    "country": "ES",
    "name": "Castil de Peones",
    "lat": "42.48347",
    "lng": "-3.38461"
  },
  {
    "country": "ES",
    "name": "Castildelgado",
    "lat": "42.43756",
    "lng": "-3.08389"
  },
  {
    "country": "ES",
    "name": "Castigaleu",
    "lat": "42.20374",
    "lng": "0.57944"
  },
  {
    "country": "ES",
    "name": "Castiello de Jaca",
    "lat": "42.62964",
    "lng": "-0.5502"
  },
  {
    "country": "ES",
    "name": "Castielfabib",
    "lat": "40.13076",
    "lng": "-1.30396"
  },
  {
    "country": "ES",
    "name": "Castelserás",
    "lat": "40.98133",
    "lng": "-0.14666"
  },
  {
    "country": "ES",
    "name": "Castelnou",
    "lat": "41.22892",
    "lng": "-0.36434"
  },
  {
    "country": "ES",
    "name": "Castellví de Rosanes",
    "lat": "41.45",
    "lng": "1.9"
  },
  {
    "country": "ES",
    "name": "Castellterçol",
    "lat": "41.75",
    "lng": "2.11667"
  },
  {
    "country": "ES",
    "name": "Castellserà",
    "lat": "41.75",
    "lng": "1"
  },
  {
    "country": "ES",
    "name": "Castellote",
    "lat": "40.8",
    "lng": "-0.31975"
  },
  {
    "country": "ES",
    "name": "Castellolí",
    "lat": "41.59829",
    "lng": "1.70057"
  },
  {
    "country": "ES",
    "name": "Castelló de Farfanya",
    "lat": "41.81667",
    "lng": "0.73333"
  },
  {
    "country": "ES",
    "name": "Castelló d'Empúries",
    "lat": "42.25673",
    "lng": "3.07446"
  },
  {
    "country": "ES",
    "name": "Castellnou de Seana",
    "lat": "41.64802",
    "lng": "0.97093"
  },
  {
    "country": "ES",
    "name": "Castellfollit de Riubregós",
    "lat": "41.76667",
    "lng": "1.43333"
  },
  {
    "country": "ES",
    "name": "Castellfollit del Boix",
    "lat": "41.66667",
    "lng": "1.7"
  },
  {
    "country": "ES",
    "name": "Castellfort",
    "lat": "40.50208",
    "lng": "-0.19133"
  },
  {
    "country": "ES",
    "name": "Castellet",
    "lat": "41.26281",
    "lng": "1.63369"
  },
  {
    "country": "ES",
    "name": "Castelldefels",
    "lat": "41.27794",
    "lng": "1.97033"
  },
  {
    "country": "ES",
    "name": "Castell de Cabres",
    "lat": "40.66058",
    "lng": "0.04217"
  },
  {
    "country": "ES",
    "name": "Castellcir",
    "lat": "41.76074",
    "lng": "2.16128"
  },
  {
    "country": "ES",
    "name": "Castellbisbal",
    "lat": "41.47534",
    "lng": "1.98174"
  },
  {
    "country": "ES",
    "name": "Castellar de la Muela",
    "lat": "40.81902",
    "lng": "-1.75932"
  },
  {
    "country": "ES",
    "name": "Castellar del Vallès",
    "lat": "41.61667",
    "lng": "2.08333"
  },
  {
    "country": "ES",
    "name": "Castellanos de Zapardiel",
    "lat": "41.0845",
    "lng": "-4.90984"
  },
  {
    "country": "ES",
    "name": "Castellanos de Villiquera",
    "lat": "41.05139",
    "lng": "-5.69477"
  },
  {
    "country": "ES",
    "name": "Castellanos de Moriscos",
    "lat": "41.01917",
    "lng": "-5.59065"
  },
  {
    "country": "ES",
    "name": "Castellanos de Castro",
    "lat": "42.32806",
    "lng": "-4.03417"
  },
  {
    "country": "ES",
    "name": "Castelflorite",
    "lat": "41.80273",
    "lng": "-0.02169"
  },
  {
    "country": "ES",
    "name": "Castel de Cabra",
    "lat": "40.80255",
    "lng": "-0.696"
  },
  {
    "country": "ES",
    "name": "Castejón de Valdejasa",
    "lat": "41.98204",
    "lng": "-0.99393"
  },
  {
    "country": "ES",
    "name": "Castejón de Tornos",
    "lat": "40.99726",
    "lng": "-1.42805"
  },
  {
    "country": "ES",
    "name": "Castejón de Sos",
    "lat": "42.51235",
    "lng": "0.49241"
  },
  {
    "country": "ES",
    "name": "Castejón de Monegros",
    "lat": "41.61802",
    "lng": "-0.24013"
  },
  {
    "country": "ES",
    "name": "Castejón del Puente",
    "lat": "41.96179",
    "lng": "0.15883"
  },
  {
    "country": "ES",
    "name": "Castejón de las Armas",
    "lat": "41.30976",
    "lng": "-1.81084"
  },
  {
    "country": "ES",
    "name": "Castejón de Henares",
    "lat": "40.93762",
    "lng": "-2.78665"
  },
  {
    "country": "ES",
    "name": "Castejón de Alarba",
    "lat": "41.18365",
    "lng": "-1.63612"
  },
  {
    "country": "ES",
    "name": "Castejón",
    "lat": "42.16912",
    "lng": "-1.68951"
  },
  {
    "country": "ES",
    "name": "Castandiello",
    "lat": "43.27962",
    "lng": "-5.89201"
  },
  {
    "country": "ES",
    "name": "Castañares de Rioja",
    "lat": "42.51248",
    "lng": "-2.93148"
  },
  {
    "country": "ES",
    "name": "Cassà de la Selva",
    "lat": "41.88784",
    "lng": "2.87524"
  },
  {
    "country": "ES",
    "name": "Caspueñas",
    "lat": "40.69497",
    "lng": "-2.97941"
  },
  {
    "country": "ES",
    "name": "Caspe",
    "lat": "41.23402",
    "lng": "-0.03945"
  },
  {
    "country": "ES",
    "name": "Casla",
    "lat": "41.16602",
    "lng": "-3.65643"
  },
  {
    "country": "ES",
    "name": "Casillas de Flores",
    "lat": "40.38108",
    "lng": "-6.75602"
  },
  {
    "country": "ES",
    "name": "Casillas",
    "lat": "40.3261",
    "lng": "-4.57182"
  },
  {
    "country": "ES",
    "name": "Caseres",
    "lat": "41.03333",
    "lng": "0.25"
  },
  {
    "country": "ES",
    "name": "Cáseda",
    "lat": "42.52255",
    "lng": "-1.36636"
  },
  {
    "country": "ES",
    "name": "Cascante del Río",
    "lat": "40.19652",
    "lng": "-1.11414"
  },
  {
    "country": "ES",
    "name": "Cascante",
    "lat": "41.99769",
    "lng": "-1.68098"
  },
  {
    "country": "ES",
    "name": "Cascajares de la Sierra",
    "lat": "42.06177",
    "lng": "-3.39936"
  },
  {
    "country": "ES",
    "name": "Cascajares de Bureba",
    "lat": "42.67884",
    "lng": "-3.23768"
  },
  {
    "country": "ES",
    "name": "Casbas de Huesca",
    "lat": "42.1555",
    "lng": "-0.1399"
  },
  {
    "country": "ES",
    "name": "Casavieja",
    "lat": "40.28325",
    "lng": "-4.7667"
  },
  {
    "country": "ES",
    "name": "Casasola de Arión",
    "lat": "41.57825",
    "lng": "-5.24076"
  },
  {
    "country": "ES",
    "name": "Casaseca de las Chanas",
    "lat": "41.4387",
    "lng": "-5.67547"
  },
  {
    "country": "ES",
    "name": "Casaseca de Campeán",
    "lat": "41.37429",
    "lng": "-5.74648"
  },
  {
    "country": "ES",
    "name": "Casas de San Galindo",
    "lat": "40.87234",
    "lng": "-2.9575"
  },
  {
    "country": "ES",
    "name": "Casas del Monte",
    "lat": "40.2032",
    "lng": "-5.96152"
  },
  {
    "country": "ES",
    "name": "Casas del Castañar",
    "lat": "40.10785",
    "lng": "-5.90509"
  },
  {
    "country": "ES",
    "name": "Casas de Don Gómez",
    "lat": "40.00932",
    "lng": "-6.60073"
  },
  {
    "country": "ES",
    "name": "Casas Bajas",
    "lat": "40.01667",
    "lng": "-1.26667"
  },
  {
    "country": "ES",
    "name": "Casas Altas",
    "lat": "40.03333",
    "lng": "-1.26667"
  },
  {
    "country": "ES",
    "name": "Casarrubuelos",
    "lat": "40.17146",
    "lng": "-3.83105"
  },
  {
    "country": "ES",
    "name": "Casarrubios del Monte",
    "lat": "40.18697",
    "lng": "-4.03644"
  },
  {
    "country": "ES",
    "name": "Casares de las Hurdes",
    "lat": "40.43333",
    "lng": "-6.28333"
  },
  {
    "country": "ES",
    "name": "Casarejos",
    "lat": "41.79651",
    "lng": "-3.03251"
  },
  {
    "country": "ES",
    "name": "Casar de Palomero",
    "lat": "40.29483",
    "lng": "-6.25698"
  },
  {
    "country": "ES",
    "name": "Casalarreina",
    "lat": "42.54911",
    "lng": "-2.90994"
  },
  {
    "country": "ES",
    "name": "Casafranca",
    "lat": "40.59267",
    "lng": "-5.76039"
  },
  {
    "country": "ES",
    "name": "Casa de Uceda",
    "lat": "40.84115",
    "lng": "-3.36849"
  },
  {
    "country": "ES",
    "name": "Carucedo",
    "lat": "42.49029",
    "lng": "-6.76565"
  },
  {
    "country": "ES",
    "name": "Cartes",
    "lat": "43.32596",
    "lng": "-4.06893"
  },
  {
    "country": "ES",
    "name": "Cartelle",
    "lat": "42.25109",
    "lng": "-8.07062"
  },
  {
    "country": "ES",
    "name": "Carrocera",
    "lat": "42.79605",
    "lng": "-5.74374"
  },
  {
    "country": "ES",
    "name": "Carrizo de la Ribera",
    "lat": "42.58395",
    "lng": "-5.82881"
  },
  {
    "country": "ES",
    "name": "Carrión de los Condes",
    "lat": "42.3413",
    "lng": "-4.60071"
  },
  {
    "country": "ES",
    "name": "Carrias",
    "lat": "42.48141",
    "lng": "-3.28319"
  },
  {
    "country": "ES",
    "name": "Carreña",
    "lat": "43.31737",
    "lng": "-4.84609"
  },
  {
    "country": "ES",
    "name": "Carrascosa de la Sierra",
    "lat": "41.89535",
    "lng": "-2.28003"
  },
  {
    "country": "ES",
    "name": "Carrascosa de Abajo",
    "lat": "41.42338",
    "lng": "-3.08955"
  },
  {
    "country": "ES",
    "name": "Carrascosa",
    "lat": "40.59092",
    "lng": "-2.16305"
  },
  {
    "country": "ES",
    "name": "Carrascal del Río",
    "lat": "41.36801",
    "lng": "-3.89819"
  },
  {
    "country": "ES",
    "name": "Carrascal del Obispo",
    "lat": "40.76376",
    "lng": "-5.99913"
  },
  {
    "country": "ES",
    "name": "Carrascal de Barregas",
    "lat": "40.97868",
    "lng": "-5.76227"
  },
  {
    "country": "ES",
    "name": "Carranque",
    "lat": "40.16976",
    "lng": "-3.90092"
  },
  {
    "country": "ES",
    "name": "Carral",
    "lat": "43.2286",
    "lng": "-8.35545"
  },
  {
    "country": "ES",
    "name": "Carracedelo",
    "lat": "42.55602",
    "lng": "-6.73317"
  },
  {
    "country": "ES",
    "name": "Carpio de Azaba",
    "lat": "40.59602",
    "lng": "-6.6468"
  },
  {
    "country": "ES",
    "name": "Carpio",
    "lat": "41.21329",
    "lng": "-5.10907"
  },
  {
    "country": "ES",
    "name": "Carnota",
    "lat": "42.8233",
    "lng": "-9.08913"
  },
  {
    "country": "ES",
    "name": "Cármenes",
    "lat": "42.95863",
    "lng": "-5.57346"
  },
  {
    "country": "ES",
    "name": "Cariño",
    "lat": "43.74134",
    "lng": "-7.86715"
  },
  {
    "country": "ES",
    "name": "Cariñena",
    "lat": "41.33733",
    "lng": "-1.22444"
  },
  {
    "country": "ES",
    "name": "Carenas",
    "lat": "41.27755",
    "lng": "-1.79754"
  },
  {
    "country": "ES",
    "name": "Cardona",
    "lat": "41.91371",
    "lng": "1.67855"
  },
  {
    "country": "ES",
    "name": "Cardiel de los Montes",
    "lat": "40.06348",
    "lng": "-4.65488"
  },
  {
    "country": "ES",
    "name": "Cardeñosa de Volpejera",
    "lat": "42.23214",
    "lng": "-4.70197"
  },
  {
    "country": "ES",
    "name": "Cardeñosa",
    "lat": "40.7424",
    "lng": "-4.74579"
  },
  {
    "country": "ES",
    "name": "Cárdenas",
    "lat": "42.37464",
    "lng": "-2.76726"
  },
  {
    "country": "ES",
    "name": "Cardeñajimeno",
    "lat": "42.33038",
    "lng": "-3.62103"
  },
  {
    "country": "ES",
    "name": "Cardeñadijo",
    "lat": "42.30217",
    "lng": "-3.66779"
  },
  {
    "country": "ES",
    "name": "Cardedeu",
    "lat": "41.63976",
    "lng": "2.35739"
  },
  {
    "country": "ES",
    "name": "Carcedo de Burgos",
    "lat": "42.28696",
    "lng": "-3.62274"
  },
  {
    "country": "ES",
    "name": "Carcedo de Bureba",
    "lat": "42.57818",
    "lng": "-3.49831"
  },
  {
    "country": "ES",
    "name": "Carcastillo",
    "lat": "42.37908",
    "lng": "-1.44376"
  },
  {
    "country": "ES",
    "name": "Cárcar",
    "lat": "42.39314",
    "lng": "-1.97904"
  },
  {
    "country": "ES",
    "name": "Carcaboso",
    "lat": "40.04968",
    "lng": "-6.21375"
  },
  {
    "country": "ES",
    "name": "Carbonero el Mayor",
    "lat": "41.12257",
    "lng": "-4.26478"
  },
  {
    "country": "ES",
    "name": "Carbellino",
    "lat": "41.22975",
    "lng": "-6.14901"
  },
  {
    "country": "ES",
    "name": "Carballo",
    "lat": "43.213",
    "lng": "-8.69104"
  },
  {
    "country": "ES",
    "name": "O Carballiño",
    "lat": "42.43163",
    "lng": "-8.07899"
  },
  {
    "country": "ES",
    "name": "Carballedo",
    "lat": "42.52191",
    "lng": "-7.8284"
  },
  {
    "country": "ES",
    "name": "Carballeda de Avia",
    "lat": "42.3214",
    "lng": "-8.16456"
  },
  {
    "country": "ES",
    "name": "Carbajosa de la Sagrada",
    "lat": "40.93305",
    "lng": "-5.65026"
  },
  {
    "country": "ES",
    "name": "Carbajales de Alba",
    "lat": "41.65347",
    "lng": "-5.99706"
  },
  {
    "country": "ES",
    "name": "Carazo",
    "lat": "41.96832",
    "lng": "-3.3531"
  },
  {
    "country": "ES",
    "name": "Caracena",
    "lat": "41.38321",
    "lng": "-3.09146"
  },
  {
    "country": "ES",
    "name": "Carabantes",
    "lat": "41.55211",
    "lng": "-1.9981"
  },
  {
    "country": "ES",
    "name": "Carabaña",
    "lat": "40.25424",
    "lng": "-3.23572"
  },
  {
    "country": "ES",
    "name": "Capmany",
    "lat": "42.37351",
    "lng": "2.92026"
  },
  {
    "country": "ES",
    "name": "Capillas",
    "lat": "42.01362",
    "lng": "-4.89051"
  },
  {
    "country": "ES",
    "name": "Capellades",
    "lat": "41.53005",
    "lng": "1.68651"
  },
  {
    "country": "ES",
    "name": "Capella",
    "lat": "42.19635",
    "lng": "0.39637"
  },
  {
    "country": "ES",
    "name": "Capdesaso",
    "lat": "41.84287",
    "lng": "-0.18316"
  },
  {
    "country": "ES",
    "name": "Caparroso",
    "lat": "42.34129",
    "lng": "-1.64962"
  },
  {
    "country": "ES",
    "name": "Capafonts",
    "lat": "41.3",
    "lng": "1.03333"
  },
  {
    "country": "ES",
    "name": "Cantiveros",
    "lat": "40.95215",
    "lng": "-4.95455"
  },
  {
    "country": "ES",
    "name": "Cantimpalos",
    "lat": "41.07406",
    "lng": "-4.15988"
  },
  {
    "country": "ES",
    "name": "Cantavieja",
    "lat": "40.52642",
    "lng": "-0.40558"
  },
  {
    "country": "ES",
    "name": "Cantaracillo",
    "lat": "40.90376",
    "lng": "-5.16291"
  },
  {
    "country": "ES",
    "name": "Cantalpino",
    "lat": "41.05341",
    "lng": "-5.33045"
  },
  {
    "country": "ES",
    "name": "Cantalojas",
    "lat": "41.23472",
    "lng": "-3.24629"
  },
  {
    "country": "ES",
    "name": "Cantallops",
    "lat": "42.42216",
    "lng": "2.92524"
  },
  {
    "country": "ES",
    "name": "Cantalejo",
    "lat": "41.2576",
    "lng": "-3.92791"
  },
  {
    "country": "ES",
    "name": "Cantalapiedra",
    "lat": "41.1263",
    "lng": "-5.18351"
  },
  {
    "country": "ES",
    "name": "Cantagallo",
    "lat": "40.37239",
    "lng": "-5.8189"
  },
  {
    "country": "ES",
    "name": "Cantabrana",
    "lat": "42.73422",
    "lng": "-3.46704"
  },
  {
    "country": "ES",
    "name": "Canredondo",
    "lat": "40.81257",
    "lng": "-2.49377"
  },
  {
    "country": "ES",
    "name": "Cànoves i Samalús",
    "lat": "41.68333",
    "lng": "2.35"
  },
  {
    "country": "ES",
    "name": "Canovelles",
    "lat": "41.61667",
    "lng": "2.28333"
  },
  {
    "country": "ES",
    "name": "Cañizo",
    "lat": "41.76955",
    "lng": "-5.50199"
  },
  {
    "country": "ES",
    "name": "Cañizares",
    "lat": "40.5187",
    "lng": "-2.19201"
  },
  {
    "country": "ES",
    "name": "Cañizar del Olivar",
    "lat": "40.81622",
    "lng": "-0.64567"
  },
  {
    "country": "ES",
    "name": "Cañizar",
    "lat": "40.76763",
    "lng": "-3.06399"
  },
  {
    "country": "ES",
    "name": "Cañizal",
    "lat": "41.16654",
    "lng": "-5.36828"
  },
  {
    "country": "ES",
    "name": "Canillas de Río Tuerto",
    "lat": "42.3995",
    "lng": "-2.84091"
  },
  {
    "country": "ES",
    "name": "Canillas de Esgueva",
    "lat": "41.75464",
    "lng": "-4.12502"
  },
  {
    "country": "ES",
    "name": "Canillas de Abajo",
    "lat": "40.92266",
    "lng": "-5.92905"
  },
  {
    "country": "ES",
    "name": "Canicosa de la Sierra",
    "lat": "41.93673",
    "lng": "-3.04089"
  },
  {
    "country": "ES",
    "name": "Cangas de Onís",
    "lat": "43.3514",
    "lng": "-5.12916"
  },
  {
    "country": "ES",
    "name": "Cangas del Narcea",
    "lat": "43.18333",
    "lng": "-6.55"
  },
  {
    "country": "ES",
    "name": "Cangas do Morrazo",
    "lat": "42.26413",
    "lng": "-8.78463"
  },
  {
    "country": "ES",
    "name": "Canfranc",
    "lat": "42.71628",
    "lng": "-0.52563"
  },
  {
    "country": "ES",
    "name": "Canet lo Roig",
    "lat": "40.55142",
    "lng": "0.24308"
  },
  {
    "country": "ES",
    "name": "Cañete",
    "lat": "40.05",
    "lng": "-1.65"
  },
  {
    "country": "ES",
    "name": "Canet de Mar",
    "lat": "41.59054",
    "lng": "2.58116"
  },
  {
    "country": "ES",
    "name": "Canencia",
    "lat": "40.90728",
    "lng": "-3.73523"
  },
  {
    "country": "ES",
    "name": "Candín",
    "lat": "42.81695",
    "lng": "-6.72848"
  },
  {
    "country": "ES",
    "name": "Candilichera",
    "lat": "41.70434",
    "lng": "-2.30123"
  },
  {
    "country": "ES",
    "name": "Candeleda",
    "lat": "40.15521",
    "lng": "-5.24045"
  },
  {
    "country": "ES",
    "name": "Candelario",
    "lat": "40.36806",
    "lng": "-5.74499"
  },
  {
    "country": "ES",
    "name": "Candasnos",
    "lat": "41.50213",
    "lng": "0.06425"
  },
  {
    "country": "ES",
    "name": "Cañaveruelas",
    "lat": "40.40024",
    "lng": "-2.63719"
  },
  {
    "country": "ES",
    "name": "Cañaveras",
    "lat": "40.35994",
    "lng": "-2.39611"
  },
  {
    "country": "ES",
    "name": "Cañas",
    "lat": "42.3924",
    "lng": "-2.84649"
  },
  {
    "country": "ES",
    "name": "Cañamares",
    "lat": "40.45203",
    "lng": "-2.23983"
  },
  {
    "country": "ES",
    "name": "Cañamaque",
    "lat": "41.44453",
    "lng": "-2.23792"
  },
  {
    "country": "ES",
    "name": "Canales de la Sierra",
    "lat": "42.14233",
    "lng": "-3.02458"
  },
  {
    "country": "ES",
    "name": "Canales",
    "lat": "41.00331",
    "lng": "-4.90163"
  },
  {
    "country": "ES",
    "name": "Canalejas de Peñafiel",
    "lat": "41.52513",
    "lng": "-4.11546"
  },
  {
    "country": "ES",
    "name": "Canalejas del Arroyo",
    "lat": "40.3685",
    "lng": "-2.49408"
  },
  {
    "country": "ES",
    "name": "Cañada Vellida",
    "lat": "40.70811",
    "lng": "-0.91489"
  },
  {
    "country": "ES",
    "name": "Cañada de Benatanduz",
    "lat": "40.57934",
    "lng": "-0.53682"
  },
  {
    "country": "ES",
    "name": "Camproviín",
    "lat": "42.35387",
    "lng": "-2.72294"
  },
  {
    "country": "ES",
    "name": "Camprodon",
    "lat": "42.31185",
    "lng": "2.36506"
  },
  {
    "country": "ES",
    "name": "Camporrells",
    "lat": "41.95856",
    "lng": "0.52136"
  },
  {
    "country": "ES",
    "name": "Camporredondo",
    "lat": "41.47333",
    "lng": "-4.50503"
  },
  {
    "country": "ES",
    "name": "Campo Real",
    "lat": "40.33333",
    "lng": "-3.38333"
  },
  {
    "country": "ES",
    "name": "Camponaraya",
    "lat": "42.57799",
    "lng": "-6.66709"
  },
  {
    "country": "ES",
    "name": "Campolara",
    "lat": "42.11953",
    "lng": "-3.4274"
  },
  {
    "country": "ES",
    "name": "Campo de Villavidel",
    "lat": "42.43906",
    "lng": "-5.52808"
  },
  {
    "country": "ES",
    "name": "Campo de San Pedro",
    "lat": "41.42992",
    "lng": "-3.54599"
  },
  {
    "country": "ES",
    "name": "Campo de Caso",
    "lat": "43.1831",
    "lng": "-5.34476"
  },
  {
    "country": "ES",
    "name": "Campo",
    "lat": "42.40956",
    "lng": "0.39615"
  },
  {
    "country": "ES",
    "name": "Campisábalos",
    "lat": "41.26667",
    "lng": "-3.13333"
  },
  {
    "country": "ES",
    "name": "Campins",
    "lat": "41.71667",
    "lng": "2.46667"
  },
  {
    "country": "ES",
    "name": "Campillos-Sierra",
    "lat": "40.1",
    "lng": "-1.7"
  },
  {
    "country": "ES",
    "name": "Campillo de Ranas",
    "lat": "41.08601",
    "lng": "-3.31431"
  },
  {
    "country": "ES",
    "name": "Campillo de Dueñas",
    "lat": "40.88376",
    "lng": "-1.68505"
  },
  {
    "country": "ES",
    "name": "Campillo de Azaba",
    "lat": "40.50951",
    "lng": "-6.68705"
  },
  {
    "country": "ES",
    "name": "Campillo de Aranda",
    "lat": "41.61015",
    "lng": "-3.73017"
  },
  {
    "country": "ES",
    "name": "Campillo de Aragón",
    "lat": "41.12648",
    "lng": "-1.84393"
  },
  {
    "country": "ES",
    "name": "Campdevànol",
    "lat": "42.22445",
    "lng": "2.1686"
  },
  {
    "country": "ES",
    "name": "Campazas",
    "lat": "42.14219",
    "lng": "-5.49349"
  },
  {
    "country": "ES",
    "name": "Campaspero",
    "lat": "41.49208",
    "lng": "-4.19608"
  },
  {
    "country": "ES",
    "name": "Landa",
    "lat": "43.38333",
    "lng": "-2.95"
  },
  {
    "country": "ES",
    "name": "Camós",
    "lat": "42.08776",
    "lng": "2.76288"
  },
  {
    "country": "ES",
    "name": "Caminreal",
    "lat": "40.83883",
    "lng": "-1.32416"
  },
  {
    "country": "ES",
    "name": "Caminomorisco",
    "lat": "40.32719",
    "lng": "-6.28923"
  },
  {
    "country": "ES",
    "name": "Cambrils",
    "lat": "41.06997",
    "lng": "1.05949"
  },
  {
    "country": "ES",
    "name": "Cambre",
    "lat": "43.29438",
    "lng": "-8.34736"
  },
  {
    "country": "ES",
    "name": "Cambados",
    "lat": "42.51222",
    "lng": "-8.8131"
  },
  {
    "country": "ES",
    "name": "Camarzana de Tera",
    "lat": "41.99471",
    "lng": "-6.02657"
  },
  {
    "country": "ES",
    "name": "Camarma de Esteruelas",
    "lat": "40.55032",
    "lng": "-3.37295"
  },
  {
    "country": "ES",
    "name": "Camariñas",
    "lat": "43.13115",
    "lng": "-9.18172"
  },
  {
    "country": "ES",
    "name": "Camarillas",
    "lat": "40.61242",
    "lng": "-0.75416"
  },
  {
    "country": "ES",
    "name": "Camargo",
    "lat": "43.40744",
    "lng": "-3.88498"
  },
  {
    "country": "ES",
    "name": "Camarenilla",
    "lat": "40.01672",
    "lng": "-4.07624"
  },
  {
    "country": "ES",
    "name": "Camarena de la Sierra",
    "lat": "40.15",
    "lng": "-1.03333"
  },
  {
    "country": "ES",
    "name": "Camarena",
    "lat": "40.09311",
    "lng": "-4.11927"
  },
  {
    "country": "ES",
    "name": "Camarasa",
    "lat": "41.87486",
    "lng": "0.87814"
  },
  {
    "country": "ES",
    "name": "Camañas",
    "lat": "40.64308",
    "lng": "-1.13752"
  },
  {
    "country": "ES",
    "name": "Camaleño",
    "lat": "43.15078",
    "lng": "-4.69376"
  },
  {
    "country": "ES",
    "name": "Calzadilla de Tera",
    "lat": "41.97899",
    "lng": "-6.08243"
  },
  {
    "country": "ES",
    "name": "Calzadilla",
    "lat": "40.06014",
    "lng": "-6.53328"
  },
  {
    "country": "ES",
    "name": "Calzada de Valdunciel",
    "lat": "41.08663",
    "lng": "-5.70219"
  },
  {
    "country": "ES",
    "name": "Calzada de los Molinos",
    "lat": "42.32724",
    "lng": "-4.65293"
  },
  {
    "country": "ES",
    "name": "Calzada del Coto",
    "lat": "42.38613",
    "lng": "-5.07809"
  },
  {
    "country": "ES",
    "name": "Calzada de Don Diego",
    "lat": "40.905",
    "lng": "-5.90279"
  },
  {
    "country": "ES",
    "name": "Calvos",
    "lat": "41.9479",
    "lng": "-7.89604"
  },
  {
    "country": "ES",
    "name": "Calvarrasa de Arriba",
    "lat": "40.90672",
    "lng": "-5.59199"
  },
  {
    "country": "ES",
    "name": "Calvarrasa de Abajo",
    "lat": "40.94638",
    "lng": "-5.55258"
  },
  {
    "country": "ES",
    "name": "Caltojar",
    "lat": "41.40226",
    "lng": "-2.76436"
  },
  {
    "country": "ES",
    "name": "Calonge",
    "lat": "41.85869",
    "lng": "3.07926"
  },
  {
    "country": "ES",
    "name": "Calomarde",
    "lat": "40.37264",
    "lng": "-1.57435"
  },
  {
    "country": "ES",
    "name": "Calmarza",
    "lat": "41.1581",
    "lng": "-1.91196"
  },
  {
    "country": "ES",
    "name": "Càlig",
    "lat": "40.46262",
    "lng": "0.35521"
  },
  {
    "country": "ES",
    "name": "Caleruega",
    "lat": "41.82548",
    "lng": "-3.48593"
  },
  {
    "country": "ES",
    "name": "Calella",
    "lat": "41.61381",
    "lng": "2.65423"
  },
  {
    "country": "ES",
    "name": "Caldas de Reis",
    "lat": "42.6",
    "lng": "-8.63333"
  },
  {
    "country": "ES",
    "name": "Caldes de Montbui",
    "lat": "41.63333",
    "lng": "2.16667"
  },
  {
    "country": "ES",
    "name": "Caldes de Malavella",
    "lat": "41.83333",
    "lng": "2.81667"
  },
  {
    "country": "ES",
    "name": "Caldes d'Estrac",
    "lat": "41.56667",
    "lng": "2.53333"
  },
  {
    "country": "ES",
    "name": "Calcena",
    "lat": "41.65515",
    "lng": "-1.71764"
  },
  {
    "country": "ES",
    "name": "Calatorao",
    "lat": "41.52228",
    "lng": "-1.34702"
  },
  {
    "country": "ES",
    "name": "Calatayud",
    "lat": "41.35353",
    "lng": "-1.64318"
  },
  {
    "country": "ES",
    "name": "Calatañazor",
    "lat": "41.69879",
    "lng": "-2.81837"
  },
  {
    "country": "ES",
    "name": "Calanda",
    "lat": "40.94153",
    "lng": "-0.23243"
  },
  {
    "country": "ES",
    "name": "Calamocha",
    "lat": "40.91933",
    "lng": "-1.2975"
  },
  {
    "country": "ES",
    "name": "Calahorra de Boedo",
    "lat": "42.57409",
    "lng": "-4.38485"
  },
  {
    "country": "ES",
    "name": "Calahorra",
    "lat": "42.30506",
    "lng": "-1.96521"
  },
  {
    "country": "ES",
    "name": "Calafell",
    "lat": "41.19997",
    "lng": "1.5683"
  },
  {
    "country": "ES",
    "name": "Calaf",
    "lat": "41.73289",
    "lng": "1.51375"
  },
  {
    "country": "ES",
    "name": "Calaceite",
    "lat": "41.01625",
    "lng": "0.18876"
  },
  {
    "country": "ES",
    "name": "Cadrete",
    "lat": "41.55575",
    "lng": "-0.96013"
  },
  {
    "country": "ES",
    "name": "Cadreita",
    "lat": "42.21667",
    "lng": "-1.68333"
  },
  {
    "country": "ES",
    "name": "Cadaqués",
    "lat": "42.28856",
    "lng": "3.27706"
  },
  {
    "country": "ES",
    "name": "Cadalso de los Vidrios",
    "lat": "40.30067",
    "lng": "-4.43348"
  },
  {
    "country": "ES",
    "name": "Cadalso",
    "lat": "40.23743",
    "lng": "-6.54083"
  },
  {
    "country": "ES",
    "name": "Cacabelos",
    "lat": "42.60021",
    "lng": "-6.72373"
  },
  {
    "country": "ES",
    "name": "Cabrils",
    "lat": "41.5276",
    "lng": "2.36996"
  },
  {
    "country": "ES",
    "name": "Cabrillas",
    "lat": "40.73977",
    "lng": "-6.17873"
  },
  {
    "country": "ES",
    "name": "Cabrillanes",
    "lat": "42.95343",
    "lng": "-6.14849"
  },
  {
    "country": "ES",
    "name": "Cabreros del Río",
    "lat": "42.40205",
    "lng": "-5.54154"
  },
  {
    "country": "ES",
    "name": "Cabreros del Monte",
    "lat": "41.84906",
    "lng": "-5.27016"
  },
  {
    "country": "ES",
    "name": "Cabrero",
    "lat": "40.11324",
    "lng": "-5.89293"
  },
  {
    "country": "ES",
    "name": "Cabrerizos",
    "lat": "40.97808",
    "lng": "-5.60907"
  },
  {
    "country": "ES",
    "name": "Cabrera de Mar",
    "lat": "41.51667",
    "lng": "2.4"
  },
  {
    "country": "ES",
    "name": "Cabrejas del Pinar",
    "lat": "41.79596",
    "lng": "-2.84945"
  },
  {
    "country": "ES",
    "name": "Cabrejas del Campo",
    "lat": "41.68096",
    "lng": "-2.26964"
  },
  {
    "country": "ES",
    "name": "Cabredo",
    "lat": "42.62966",
    "lng": "-2.41133"
  },
  {
    "country": "ES",
    "name": "Cabra de Mora",
    "lat": "40.31696",
    "lng": "-0.80678"
  },
  {
    "country": "ES",
    "name": "Cabra del Camp",
    "lat": "41.4",
    "lng": "1.28333"
  },
  {
    "country": "ES",
    "name": "Cabolafuente",
    "lat": "41.21053",
    "lng": "-2.04133"
  },
  {
    "country": "ES",
    "name": "Cabizuela",
    "lat": "40.9009",
    "lng": "-4.80212"
  },
  {
    "country": "ES",
    "name": "Cabezuela del Valle",
    "lat": "40.19364",
    "lng": "-5.8065"
  },
  {
    "country": "ES",
    "name": "Cabezuela",
    "lat": "41.2359",
    "lng": "-3.93173"
  },
  {
    "country": "ES",
    "name": "Cabezón de Valderaduey",
    "lat": "42.16793",
    "lng": "-5.15892"
  },
  {
    "country": "ES",
    "name": "Cabezón de Liébana",
    "lat": "43.13437",
    "lng": "-4.5763"
  },
  {
    "country": "ES",
    "name": "Cabezón de la Sierra",
    "lat": "41.93434",
    "lng": "-3.24153"
  },
  {
    "country": "ES",
    "name": "Cabezón de la Sal",
    "lat": "43.30824",
    "lng": "-4.23571"
  },
  {
    "country": "ES",
    "name": "Cabezón de Cameros",
    "lat": "42.19716",
    "lng": "-2.51989"
  },
  {
    "country": "ES",
    "name": "Cabezón",
    "lat": "41.73369",
    "lng": "-4.6451"
  },
  {
    "country": "ES",
    "name": "Cabezas del Villar",
    "lat": "40.71557",
    "lng": "-5.20956"
  },
  {
    "country": "ES",
    "name": "Cabezas del Pozo",
    "lat": "41.00139",
    "lng": "-4.95453"
  },
  {
    "country": "ES",
    "name": "Cabezas de Alambre",
    "lat": "40.94218",
    "lng": "-4.84184"
  },
  {
    "country": "ES",
    "name": "Cabeza del Caballo",
    "lat": "41.12982",
    "lng": "-6.55742"
  },
  {
    "country": "ES",
    "name": "Cabezabellosa de la Calzada",
    "lat": "41.04395",
    "lng": "-5.48866"
  },
  {
    "country": "ES",
    "name": "Cabezabellosa",
    "lat": "40.13763",
    "lng": "-6.00086"
  },
  {
    "country": "ES",
    "name": "Cabanillas del Campo",
    "lat": "40.63376",
    "lng": "-3.22937"
  },
  {
    "country": "ES",
    "name": "Cabanillas de la Sierra",
    "lat": "40.82009",
    "lng": "-3.62438"
  },
  {
    "country": "ES",
    "name": "Cabanillas",
    "lat": "42.03249",
    "lng": "-1.52591"
  },
  {
    "country": "ES",
    "name": "Cabañes de Esgueva",
    "lat": "41.83023",
    "lng": "-3.78824"
  },
  {
    "country": "ES",
    "name": "Cabanes",
    "lat": "40.156",
    "lng": "0.04325"
  },
  {
    "country": "ES",
    "name": "Cabanelles",
    "lat": "42.23068",
    "lng": "2.81997"
  },
  {
    "country": "ES",
    "name": "Cabañas de Sayago",
    "lat": "41.33333",
    "lng": "-5.78333"
  },
  {
    "country": "ES",
    "name": "Cabañas de Polendos",
    "lat": "41.06667",
    "lng": "-4.1101"
  },
  {
    "country": "ES",
    "name": "Cabañas de la Sagra",
    "lat": "40.0061",
    "lng": "-3.9456"
  },
  {
    "country": "ES",
    "name": "Cabañas de Ebro",
    "lat": "41.8",
    "lng": "-1.2"
  },
  {
    "country": "ES",
    "name": "Caballar",
    "lat": "41.12159",
    "lng": "-3.9642"
  },
  {
    "country": "ES",
    "name": "Busto de Bureba",
    "lat": "42.6591",
    "lng": "-3.26512"
  },
  {
    "country": "ES",
    "name": "Bustillo del Páramo de Carrión",
    "lat": "42.35509",
    "lng": "-4.7398"
  },
  {
    "country": "ES",
    "name": "Bustillo del Páramo",
    "lat": "42.44126",
    "lng": "-5.7928"
  },
  {
    "country": "ES",
    "name": "Bustillo del Oro",
    "lat": "41.6746",
    "lng": "-5.46158"
  },
  {
    "country": "ES",
    "name": "Bustillo de la Vega",
    "lat": "42.45605",
    "lng": "-4.74115"
  },
  {
    "country": "ES",
    "name": "Bustillo de Chaves",
    "lat": "42.13114",
    "lng": "-5.09169"
  },
  {
    "country": "ES",
    "name": "Bustarviejo",
    "lat": "40.8572",
    "lng": "-3.70766"
  },
  {
    "country": "ES",
    "name": "Bustares",
    "lat": "41.13333",
    "lng": "-3.06667"
  },
  {
    "country": "ES",
    "name": "Burón",
    "lat": "43.02486",
    "lng": "-5.05119"
  },
  {
    "country": "ES",
    "name": "Burlata",
    "lat": "42.82562",
    "lng": "-1.61671"
  },
  {
    "country": "ES",
    "name": "Burgos",
    "lat": "42.34106",
    "lng": "-3.70184"
  },
  {
    "country": "ES",
    "name": "Burgohondo",
    "lat": "40.41416",
    "lng": "-4.78509"
  },
  {
    "country": "ES",
    "name": "Burganes de Valverde",
    "lat": "41.9213",
    "lng": "-5.78244"
  },
  {
    "country": "ES",
    "name": "Bureta",
    "lat": "41.81572",
    "lng": "-1.48819"
  },
  {
    "country": "ES",
    "name": "Burela de Cabo",
    "lat": "43.65",
    "lng": "-7.4"
  },
  {
    "country": "ES",
    "name": "Burbáguena",
    "lat": "41.01783",
    "lng": "-1.33825"
  },
  {
    "country": "ES",
    "name": "Buñuel",
    "lat": "41.98009",
    "lng": "-1.44503"
  },
  {
    "country": "ES",
    "name": "Buniel",
    "lat": "42.31197",
    "lng": "-3.8223"
  },
  {
    "country": "ES",
    "name": "Bulbuente",
    "lat": "41.8197",
    "lng": "-1.60238"
  },
  {
    "country": "ES",
    "name": "Bujaraloz",
    "lat": "41.49806",
    "lng": "-0.1529"
  },
  {
    "country": "ES",
    "name": "Bujalaro",
    "lat": "40.93687",
    "lng": "-2.88333"
  },
  {
    "country": "ES",
    "name": "Buitrago del Lozoya",
    "lat": "40.9909",
    "lng": "-3.63365"
  },
  {
    "country": "ES",
    "name": "Buitrago",
    "lat": "41.84735",
    "lng": "-2.40858"
  },
  {
    "country": "ES",
    "name": "Bugedo",
    "lat": "42.64912",
    "lng": "-3.01786"
  },
  {
    "country": "ES",
    "name": "Bueu",
    "lat": "42.32458",
    "lng": "-8.78497"
  },
  {
    "country": "ES",
    "name": "Buendía",
    "lat": "40.36643",
    "lng": "-2.75645"
  },
  {
    "country": "ES",
    "name": "Buenavista de Valdavia",
    "lat": "42.63788",
    "lng": "-4.61446"
  },
  {
    "country": "ES",
    "name": "Buenavista",
    "lat": "40.76763",
    "lng": "-5.61139"
  },
  {
    "country": "ES",
    "name": "Buenaventura",
    "lat": "40.17705",
    "lng": "-4.85003"
  },
  {
    "country": "ES",
    "name": "Buenamadre",
    "lat": "40.85705",
    "lng": "-6.24987"
  },
  {
    "country": "ES",
    "name": "Bueña",
    "lat": "40.70881",
    "lng": "-1.26742"
  },
  {
    "country": "ES",
    "name": "Budia",
    "lat": "40.62734",
    "lng": "-2.75846"
  },
  {
    "country": "ES",
    "name": "Buciegas",
    "lat": "40.33622",
    "lng": "-2.4625"
  },
  {
    "country": "ES",
    "name": "Bubierca",
    "lat": "41.31482",
    "lng": "-1.85386"
  },
  {
    "country": "ES",
    "name": "Buberos",
    "lat": "41.64692",
    "lng": "-2.19406"
  },
  {
    "country": "ES",
    "name": "Brunyola",
    "lat": "41.9",
    "lng": "2.68333"
  },
  {
    "country": "ES",
    "name": "Brunete",
    "lat": "40.40532",
    "lng": "-3.9985"
  },
  {
    "country": "ES",
    "name": "Broto",
    "lat": "42.60434",
    "lng": "-0.12351"
  },
  {
    "country": "ES",
    "name": "Bronchales",
    "lat": "40.51171",
    "lng": "-1.58821"
  },
  {
    "country": "ES",
    "name": "Briviesca",
    "lat": "42.54993",
    "lng": "-3.32315"
  },
  {
    "country": "ES",
    "name": "Briones",
    "lat": "42.54397",
    "lng": "-2.78572"
  },
  {
    "country": "ES",
    "name": "Brincones",
    "lat": "41.11339",
    "lng": "-6.34865"
  },
  {
    "country": "ES",
    "name": "Briñas",
    "lat": "42.60106",
    "lng": "-2.83192"
  },
  {
    "country": "ES",
    "name": "Brime de Urz",
    "lat": "42.03794",
    "lng": "-5.87326"
  },
  {
    "country": "ES",
    "name": "Brime de Sog",
    "lat": "42.06162",
    "lng": "-6.04791"
  },
  {
    "country": "ES",
    "name": "Brihuega",
    "lat": "40.76049",
    "lng": "-2.86966"
  },
  {
    "country": "ES",
    "name": "Brieva de Cameros",
    "lat": "42.16462",
    "lng": "-2.7945"
  },
  {
    "country": "ES",
    "name": "Brieva",
    "lat": "41.03483",
    "lng": "-4.05364"
  },
  {
    "country": "ES",
    "name": "Bretocino",
    "lat": "41.8843",
    "lng": "-5.75473"
  },
  {
    "country": "ES",
    "name": "Bretó",
    "lat": "41.87917",
    "lng": "-5.73902"
  },
  {
    "country": "ES",
    "name": "Breda",
    "lat": "41.74833",
    "lng": "2.55964"
  },
  {
    "country": "ES",
    "name": "Brea de Tajo",
    "lat": "40.23333",
    "lng": "-3.1"
  },
  {
    "country": "ES",
    "name": "Brea de Aragón",
    "lat": "41.52387",
    "lng": "-1.60261"
  },
  {
    "country": "ES",
    "name": "Brazuelo",
    "lat": "42.49702",
    "lng": "-6.15734"
  },
  {
    "country": "ES",
    "name": "Brazacorta",
    "lat": "41.71737",
    "lng": "-3.36711"
  },
  {
    "country": "ES",
    "name": "Braojos",
    "lat": "41.0404",
    "lng": "-3.64329"
  },
  {
    "country": "ES",
    "name": "Brañosera",
    "lat": "42.9362",
    "lng": "-4.30833"
  },
  {
    "country": "ES",
    "name": "Brabos",
    "lat": "40.77846",
    "lng": "-4.93934"
  },
  {
    "country": "ES",
    "name": "Bóveda del Río Almar",
    "lat": "40.85719",
    "lng": "-5.2103"
  },
  {
    "country": "ES",
    "name": "Bóveda",
    "lat": "42.6246",
    "lng": "-7.4767"
  },
  {
    "country": "ES",
    "name": "Botorrita",
    "lat": "41.50706",
    "lng": "-1.03104"
  },
  {
    "country": "ES",
    "name": "Botarell",
    "lat": "41.13627",
    "lng": "0.98919"
  },
  {
    "country": "ES",
    "name": "Bot",
    "lat": "41.00916",
    "lng": "0.38392"
  },
  {
    "country": "ES",
    "name": "Borriol",
    "lat": "40.04249",
    "lng": "-0.07025"
  },
  {
    "country": "ES",
    "name": "Borrenes",
    "lat": "42.49019",
    "lng": "-6.72338"
  },
  {
    "country": "ES",
    "name": "Borredà",
    "lat": "42.13564",
    "lng": "1.99428"
  },
  {
    "country": "ES",
    "name": "Borrassà",
    "lat": "42.22316",
    "lng": "2.9261"
  },
  {
    "country": "ES",
    "name": "Borox",
    "lat": "40.06795",
    "lng": "-3.73804"
  },
  {
    "country": "ES",
    "name": "Borobia",
    "lat": "41.66481",
    "lng": "-1.89615"
  },
  {
    "country": "ES",
    "name": "les Borges del Camp",
    "lat": "41.16667",
    "lng": "1.01667"
  },
  {
    "country": "ES",
    "name": "Borjabad",
    "lat": "41.55245",
    "lng": "-2.36625"
  },
  {
    "country": "ES",
    "name": "Borja",
    "lat": "41.83412",
    "lng": "-1.53271"
  },
  {
    "country": "ES",
    "name": "Bordón",
    "lat": "40.6865",
    "lng": "-0.32216"
  },
  {
    "country": "ES",
    "name": "Bordils",
    "lat": "42.04336",
    "lng": "2.91088"
  },
  {
    "country": "ES",
    "name": "Bordalba",
    "lat": "41.41667",
    "lng": "-2.06667"
  },
  {
    "country": "ES",
    "name": "Borau",
    "lat": "42.65858",
    "lng": "-0.58846"
  },
  {
    "country": "ES",
    "name": "Boquiñeni",
    "lat": "41.84804",
    "lng": "-1.25246"
  },
  {
    "country": "ES",
    "name": "Bonilla de la Sierra",
    "lat": "40.53063",
    "lng": "-5.26452"
  },
  {
    "country": "ES",
    "name": "Bonastre",
    "lat": "41.22031",
    "lng": "1.43936"
  },
  {
    "country": "ES",
    "name": "Boñar",
    "lat": "42.8668",
    "lng": "-5.32386"
  },
  {
    "country": "ES",
    "name": "Bonansa",
    "lat": "42.42691",
    "lng": "0.66692"
  },
  {
    "country": "ES",
    "name": "Bolvir",
    "lat": "42.41775",
    "lng": "1.87986"
  },
  {
    "country": "ES",
    "name": "Boltaña",
    "lat": "42.4455",
    "lng": "0.06802"
  },
  {
    "country": "ES",
    "name": "Bolaños de Campos",
    "lat": "42.0068",
    "lng": "-5.28428"
  },
  {
    "country": "ES",
    "name": "Boiro",
    "lat": "42.64725",
    "lng": "-8.88459"
  },
  {
    "country": "ES",
    "name": "Boimorto",
    "lat": "43",
    "lng": "-8.13333"
  },
  {
    "country": "ES",
    "name": "Bohoyo",
    "lat": "40.31584",
    "lng": "-5.44294"
  },
  {
    "country": "ES",
    "name": "Bogajo",
    "lat": "40.9071",
    "lng": "-6.53065"
  },
  {
    "country": "ES",
    "name": "Boecillo",
    "lat": "41.5409",
    "lng": "-4.6994"
  },
  {
    "country": "ES",
    "name": "Bocos de Duero",
    "lat": "41.62339",
    "lng": "-4.07048"
  },
  {
    "country": "ES",
    "name": "Bocigas",
    "lat": "41.2307",
    "lng": "-4.68128"
  },
  {
    "country": "ES",
    "name": "Boceguillas",
    "lat": "41.33641",
    "lng": "-3.63828"
  },
  {
    "country": "ES",
    "name": "Boca de Huérgano",
    "lat": "42.97287",
    "lng": "-4.92419"
  },
  {
    "country": "ES",
    "name": "Boborás",
    "lat": "42.43332",
    "lng": "-8.14431"
  },
  {
    "country": "ES",
    "name": "Bovera",
    "lat": "41.31667",
    "lng": "0.65"
  },
  {
    "country": "ES",
    "name": "Bobadilla del Campo",
    "lat": "41.20432",
    "lng": "-5.02294"
  },
  {
    "country": "ES",
    "name": "Bobadilla",
    "lat": "42.31873",
    "lng": "-2.75992"
  },
  {
    "country": "ES",
    "name": "Boalo",
    "lat": "40.71603",
    "lng": "-3.91656"
  },
  {
    "country": "ES",
    "name": "Boal",
    "lat": "43.432",
    "lng": "-6.81513"
  },
  {
    "country": "ES",
    "name": "Boadilla del Monte",
    "lat": "40.405",
    "lng": "-3.87835"
  },
  {
    "country": "ES",
    "name": "Boadilla del Camino",
    "lat": "42.25934",
    "lng": "-4.34525"
  },
  {
    "country": "ES",
    "name": "Boada de Campos",
    "lat": "41.98957",
    "lng": "-4.8773"
  },
  {
    "country": "ES",
    "name": "Boada",
    "lat": "40.81569",
    "lng": "-6.30611"
  },
  {
    "country": "ES",
    "name": "Bliecos",
    "lat": "41.5279",
    "lng": "-2.27135"
  },
  {
    "country": "ES",
    "name": "Blesa",
    "lat": "41.0515",
    "lng": "-0.885"
  },
  {
    "country": "ES",
    "name": "Blascosancho",
    "lat": "40.87744",
    "lng": "-4.63743"
  },
  {
    "country": "ES",
    "name": "Blascomillán",
    "lat": "40.80146",
    "lng": "-5.08703"
  },
  {
    "country": "ES",
    "name": "Blanes",
    "lat": "41.67419",
    "lng": "2.79036"
  },
  {
    "country": "ES",
    "name": "Blancos",
    "lat": "41.99652",
    "lng": "-7.75175"
  },
  {
    "country": "ES",
    "name": "Blancas",
    "lat": "40.81392",
    "lng": "-1.48208"
  },
  {
    "country": "ES",
    "name": "Blacos",
    "lat": "41.6809",
    "lng": "-2.85826"
  },
  {
    "country": "ES",
    "name": "Bisimbre",
    "lat": "41.85607",
    "lng": "-1.44268"
  },
  {
    "country": "ES",
    "name": "Biscarrués",
    "lat": "42.22867",
    "lng": "-0.74967"
  },
  {
    "country": "ES",
    "name": "la Bisbal del Penedès",
    "lat": "41.28333",
    "lng": "1.48333"
  },
  {
    "country": "ES",
    "name": "Bisaurri",
    "lat": "42.49677",
    "lng": "0.50647"
  },
  {
    "country": "ES",
    "name": "Biota",
    "lat": "42.26214",
    "lng": "-1.18735"
  },
  {
    "country": "ES",
    "name": "Binéfar",
    "lat": "41.85141",
    "lng": "0.29433"
  },
  {
    "country": "ES",
    "name": "Binaced",
    "lat": "41.82564",
    "lng": "0.20084"
  },
  {
    "country": "ES",
    "name": "Bimenes",
    "lat": "43.31667",
    "lng": "-5.55"
  },
  {
    "country": "ES",
    "name": "Bilbao",
    "lat": "43.26271",
    "lng": "-2.92528"
  },
  {
    "country": "ES",
    "name": "Bijuesca",
    "lat": "41.54083",
    "lng": "-1.92039"
  },
  {
    "country": "ES",
    "name": "Bigues i Riells",
    "lat": "41.68333",
    "lng": "2.23333"
  },
  {
    "country": "ES",
    "name": "Biescas",
    "lat": "42.62897",
    "lng": "-0.32135"
  },
  {
    "country": "ES",
    "name": "Bierge",
    "lat": "42.16216",
    "lng": "-0.08326"
  },
  {
    "country": "ES",
    "name": "Bielsa",
    "lat": "42.63347",
    "lng": "0.21858"
  },
  {
    "country": "ES",
    "name": "Biel",
    "lat": "42.38763",
    "lng": "-0.94154"
  },
  {
    "country": "ES",
    "name": "Bezas",
    "lat": "40.33076",
    "lng": "-1.32511"
  },
  {
    "country": "ES",
    "name": "Bezares",
    "lat": "42.37036",
    "lng": "-2.67076"
  },
  {
    "country": "ES",
    "name": "Beuda",
    "lat": "42.23722",
    "lng": "2.70942"
  },
  {
    "country": "ES",
    "name": "Beteta",
    "lat": "40.57191",
    "lng": "-2.07588"
  },
  {
    "country": "ES",
    "name": "Betelu",
    "lat": "43.02555",
    "lng": "-1.98029"
  },
  {
    "country": "ES",
    "name": "Betanzos",
    "lat": "43.28042",
    "lng": "-8.21467"
  },
  {
    "country": "ES",
    "name": "Bescanó",
    "lat": "41.96603",
    "lng": "2.73922"
  },
  {
    "country": "ES",
    "name": "Besalú",
    "lat": "42.19893",
    "lng": "2.69953"
  },
  {
    "country": "ES",
    "name": "Berzosilla",
    "lat": "42.78053",
    "lng": "-4.03753"
  },
  {
    "country": "ES",
    "name": "Berzosa del Lozoya",
    "lat": "40.9732",
    "lng": "-3.52009"
  },
  {
    "country": "ES",
    "name": "Berzosa de Bureba",
    "lat": "42.62678",
    "lng": "-3.26652"
  },
  {
    "country": "ES",
    "name": "Berrueces",
    "lat": "41.94606",
    "lng": "-5.09693"
  },
  {
    "country": "ES",
    "name": "Berrocalejo de Aragona",
    "lat": "40.69436",
    "lng": "-4.59474"
  },
  {
    "country": "ES",
    "name": "Berrocal de Salvatierra",
    "lat": "40.63331",
    "lng": "-5.69005"
  },
  {
    "country": "ES",
    "name": "Berrocal de Huebra",
    "lat": "40.71864",
    "lng": "-6.00054"
  },
  {
    "country": "ES",
    "name": "Berrobi",
    "lat": "43.14518",
    "lng": "-2.02623"
  },
  {
    "country": "ES",
    "name": "Berriz",
    "lat": "43.16667",
    "lng": "-2.56667"
  },
  {
    "country": "ES",
    "name": "Berriozar",
    "lat": "42.83067",
    "lng": "-1.66648"
  },
  {
    "country": "ES",
    "name": "Berriobeiti",
    "lat": "42.85",
    "lng": "-1.7"
  },
  {
    "country": "ES",
    "name": "Berriatua",
    "lat": "43.31667",
    "lng": "-2.46667"
  },
  {
    "country": "ES",
    "name": "Berninches",
    "lat": "40.57106",
    "lng": "-2.80121"
  },
  {
    "country": "ES",
    "name": "Bernardos",
    "lat": "41.12787",
    "lng": "-4.35119"
  },
  {
    "country": "ES",
    "name": "Bermillo de Sayago",
    "lat": "41.36648",
    "lng": "-6.11223"
  },
  {
    "country": "ES",
    "name": "Bermeo",
    "lat": "43.42088",
    "lng": "-2.72152"
  },
  {
    "country": "ES",
    "name": "Bermellar",
    "lat": "40.99918",
    "lng": "-6.67014"
  },
  {
    "country": "ES",
    "name": "Berlangas de Roa",
    "lat": "41.68913",
    "lng": "-3.87284"
  },
  {
    "country": "ES",
    "name": "Berlanga del Bierzo",
    "lat": "42.73104",
    "lng": "-6.60565"
  },
  {
    "country": "ES",
    "name": "Berlanga de Duero",
    "lat": "41.4656",
    "lng": "-2.86147"
  },
  {
    "country": "ES",
    "name": "Beriáin",
    "lat": "42.73347",
    "lng": "-1.64448"
  },
  {
    "country": "ES",
    "name": "Bergondo",
    "lat": "43.31667",
    "lng": "-8.23333"
  },
  {
    "country": "ES",
    "name": "Berge",
    "lat": "40.85791",
    "lng": "-0.42709"
  },
  {
    "country": "ES",
    "name": "Bergasillas Bajera",
    "lat": "42.24462",
    "lng": "-2.1583"
  },
  {
    "country": "ES",
    "name": "Bergasa",
    "lat": "42.25285",
    "lng": "-2.13221"
  },
  {
    "country": "ES",
    "name": "Berga",
    "lat": "42.10429",
    "lng": "1.84628"
  },
  {
    "country": "ES",
    "name": "Berdejo",
    "lat": "41.56133",
    "lng": "-1.94431"
  },
  {
    "country": "ES",
    "name": "Bercimuel",
    "lat": "41.39925",
    "lng": "-3.57051"
  },
  {
    "country": "ES",
    "name": "Bercianos del Real Camino",
    "lat": "42.38732",
    "lng": "-5.14462"
  },
  {
    "country": "ES",
    "name": "Bercianos del Páramo",
    "lat": "42.38017",
    "lng": "-5.70834"
  },
  {
    "country": "ES",
    "name": "Bercial de Zapardiel",
    "lat": "41.04675",
    "lng": "-4.9691"
  },
  {
    "country": "ES",
    "name": "Bercial",
    "lat": "40.90711",
    "lng": "-4.43638"
  },
  {
    "country": "ES",
    "name": "Berceruelo",
    "lat": "41.58033",
    "lng": "-5.03267"
  },
  {
    "country": "ES",
    "name": "Bercero",
    "lat": "41.56397",
    "lng": "-5.0558"
  },
  {
    "country": "ES",
    "name": "Berceo",
    "lat": "42.33906",
    "lng": "-2.85239"
  },
  {
    "country": "ES",
    "name": "Berbinzana",
    "lat": "42.52779",
    "lng": "-1.83419"
  },
  {
    "country": "ES",
    "name": "Berberana",
    "lat": "42.91784",
    "lng": "-3.06063"
  },
  {
    "country": "ES",
    "name": "Berbegal",
    "lat": "41.95959",
    "lng": "-0.00326"
  },
  {
    "country": "ES",
    "name": "Beratón",
    "lat": "41.71749",
    "lng": "-1.81092"
  },
  {
    "country": "ES",
    "name": "Berastegi",
    "lat": "43.12423",
    "lng": "-1.98019"
  },
  {
    "country": "ES",
    "name": "Berantevilla",
    "lat": "42.68254",
    "lng": "-2.85832"
  },
  {
    "country": "ES",
    "name": "Berango",
    "lat": "43.365",
    "lng": "-2.99601"
  },
  {
    "country": "ES",
    "name": "Benuza",
    "lat": "42.39941",
    "lng": "-6.70969"
  },
  {
    "country": "ES",
    "name": "Benlloch",
    "lat": "40.21075",
    "lng": "0.02717"
  },
  {
    "country": "ES",
    "name": "Benifallet",
    "lat": "40.97422",
    "lng": "0.51767"
  },
  {
    "country": "ES",
    "name": "Benicàssim",
    "lat": "40.05",
    "lng": "0.06667"
  },
  {
    "country": "ES",
    "name": "Benicarló",
    "lat": "40.4165",
    "lng": "0.42709"
  },
  {
    "country": "ES",
    "name": "Benegiles",
    "lat": "41.627",
    "lng": "-5.63479"
  },
  {
    "country": "ES",
    "name": "Benavides",
    "lat": "42.50442",
    "lng": "-5.89442"
  },
  {
    "country": "ES",
    "name": "Benavente",
    "lat": "42.00249",
    "lng": "-5.67826"
  },
  {
    "country": "ES",
    "name": "Benasque",
    "lat": "42.60528",
    "lng": "0.52305"
  },
  {
    "country": "ES",
    "name": "Benassal",
    "lat": "40.3769",
    "lng": "-0.1397"
  },
  {
    "country": "ES",
    "name": "Benafigos",
    "lat": "40.27641",
    "lng": "-0.20772"
  },
  {
    "country": "ES",
    "name": "Benafarces",
    "lat": "41.62133",
    "lng": "-5.29285"
  },
  {
    "country": "ES",
    "name": "Benavarri / Benabarre",
    "lat": "42.10586",
    "lng": "0.48211"
  },
  {
    "country": "ES",
    "name": "Bembibre",
    "lat": "42.61771",
    "lng": "-6.41545"
  },
  {
    "country": "ES",
    "name": "Belver de los Montes",
    "lat": "41.72284",
    "lng": "-5.45182"
  },
  {
    "country": "ES",
    "name": "Belver",
    "lat": "41.69272",
    "lng": "0.17827"
  },
  {
    "country": "ES",
    "name": "Belorado",
    "lat": "42.42048",
    "lng": "-3.19133"
  },
  {
    "country": "ES",
    "name": "Belmonte de Tajo",
    "lat": "40.13162",
    "lng": "-3.3358"
  },
  {
    "country": "ES",
    "name": "Belmonte de Campos",
    "lat": "41.94255",
    "lng": "-4.98659"
  },
  {
    "country": "ES",
    "name": "Belmonte",
    "lat": "43.28245",
    "lng": "-6.21818"
  },
  {
    "country": "ES",
    "name": "Bellvís",
    "lat": "41.67269",
    "lng": "0.81768"
  },
  {
    "country": "ES",
    "name": "Bellver de Cerdanya",
    "lat": "42.36667",
    "lng": "1.78333"
  },
  {
    "country": "ES",
    "name": "Bellpuig",
    "lat": "41.62595",
    "lng": "1.01144"
  },
  {
    "country": "ES",
    "name": "Bellprat",
    "lat": "41.51695",
    "lng": "1.43333"
  },
  {
    "country": "ES",
    "name": "Bello",
    "lat": "40.92266",
    "lng": "-1.4985"
  },
  {
    "country": "ES",
    "name": "Bellcaire d'Urgell",
    "lat": "41.75",
    "lng": "0.91667"
  },
  {
    "country": "ES",
    "name": "Belinchón",
    "lat": "40.04603",
    "lng": "-3.05517"
  },
  {
    "country": "ES",
    "name": "Beleña",
    "lat": "40.75067",
    "lng": "-5.62713"
  },
  {
    "country": "ES",
    "name": "Belchite",
    "lat": "41.30325",
    "lng": "-0.7505"
  },
  {
    "country": "ES",
    "name": "Belbimbre",
    "lat": "42.16873",
    "lng": "-4.0128"
  },
  {
    "country": "ES",
    "name": "Belauntza",
    "lat": "43.13586",
    "lng": "-2.05156"
  },
  {
    "country": "ES",
    "name": "Belascoáin",
    "lat": "42.75619",
    "lng": "-1.83227"
  },
  {
    "country": "ES",
    "name": "Béjar",
    "lat": "40.38641",
    "lng": "-5.76341"
  },
  {
    "country": "ES",
    "name": "Beizama",
    "lat": "43.13385",
    "lng": "-2.20001"
  },
  {
    "country": "ES",
    "name": "Beire",
    "lat": "42.45415",
    "lng": "-1.62101"
  },
  {
    "country": "ES",
    "name": "Begonte",
    "lat": "43.15121",
    "lng": "-7.68643"
  },
  {
    "country": "ES",
    "name": "Begues",
    "lat": "41.33333",
    "lng": "1.93333"
  },
  {
    "country": "ES",
    "name": "Becilla de Valderaduey",
    "lat": "42.09905",
    "lng": "-5.21805"
  },
  {
    "country": "ES",
    "name": "Becerril de la Sierra",
    "lat": "40.71699",
    "lng": "-3.98858"
  },
  {
    "country": "ES",
    "name": "Becerril de Campos",
    "lat": "42.10841",
    "lng": "-4.64152"
  },
  {
    "country": "ES",
    "name": "Becerreá",
    "lat": "42.8561",
    "lng": "-7.1636"
  },
  {
    "country": "ES",
    "name": "Becedillas",
    "lat": "40.53821",
    "lng": "-5.32561"
  },
  {
    "country": "ES",
    "name": "Becedas",
    "lat": "40.40369",
    "lng": "-5.63577"
  },
  {
    "country": "ES",
    "name": "Beasain",
    "lat": "43.05017",
    "lng": "-2.20087"
  },
  {
    "country": "ES",
    "name": "Beamud",
    "lat": "40.18645",
    "lng": "-1.8288"
  },
  {
    "country": "ES",
    "name": "Beade",
    "lat": "42.33074",
    "lng": "-8.1295"
  },
  {
    "country": "ES",
    "name": "Bea",
    "lat": "41.03633",
    "lng": "-1.14725"
  },
  {
    "country": "ES",
    "name": "Bayubas de Arriba",
    "lat": "41.5575",
    "lng": "-2.88731"
  },
  {
    "country": "ES",
    "name": "Bayubas de Abajo",
    "lat": "41.52747",
    "lng": "-2.89586"
  },
  {
    "country": "ES",
    "name": "Baiona",
    "lat": "42.11667",
    "lng": "-8.85"
  },
  {
    "country": "ES",
    "name": "Batres",
    "lat": "40.20981",
    "lng": "-3.92331"
  },
  {
    "country": "ES",
    "name": "Batea",
    "lat": "41.09434",
    "lng": "0.311"
  },
  {
    "country": "ES",
    "name": "Bascuñana de San Pedro",
    "lat": "40.21322",
    "lng": "-2.22812"
  },
  {
    "country": "ES",
    "name": "Bascuñana",
    "lat": "42.42548",
    "lng": "-3.08231"
  },
  {
    "country": "ES",
    "name": "Báscones de Ojeda",
    "lat": "42.67064",
    "lng": "-4.52693"
  },
  {
    "country": "ES",
    "name": "Basconcillos del Tozo",
    "lat": "42.70236",
    "lng": "-3.98937"
  },
  {
    "country": "ES",
    "name": "Bàscara",
    "lat": "42.15998",
    "lng": "2.91028"
  },
  {
    "country": "ES",
    "name": "Basardilla",
    "lat": "41.02737",
    "lng": "-4.02598"
  },
  {
    "country": "ES",
    "name": "Sant Esteve d'en Bas",
    "lat": "42.11809",
    "lng": "2.45682"
  },
  {
    "country": "ES",
    "name": "Bárzana",
    "lat": "43.15742",
    "lng": "-5.97345"
  },
  {
    "country": "ES",
    "name": "Barruelo de Santullán",
    "lat": "42.90641",
    "lng": "-4.28593"
  },
  {
    "country": "ES",
    "name": "Barruecopardo",
    "lat": "41.07215",
    "lng": "-6.66423"
  },
  {
    "country": "ES",
    "name": "Barromán",
    "lat": "41.06536",
    "lng": "-4.93066"
  },
  {
    "country": "ES",
    "name": "Barro",
    "lat": "42.55534",
    "lng": "-8.62231"
  },
  {
    "country": "ES",
    "name": "Barrios de Colina",
    "lat": "42.39595",
    "lng": "-3.46001"
  },
  {
    "country": "ES",
    "name": "Barriopedro",
    "lat": "40.79026",
    "lng": "-2.75246"
  },
  {
    "country": "ES",
    "name": "Barrio de Muñó",
    "lat": "42.17584",
    "lng": "-4.00715"
  },
  {
    "country": "ES",
    "name": "Barrado",
    "lat": "40.08477",
    "lng": "-5.88068"
  },
  {
    "country": "ES",
    "name": "Barraco",
    "lat": "40.47647",
    "lng": "-4.64346"
  },
  {
    "country": "ES",
    "name": "Barrachina",
    "lat": "40.89688",
    "lng": "-1.13858"
  },
  {
    "country": "ES",
    "name": "Barracas",
    "lat": "40.01667",
    "lng": "-0.68333"
  },
  {
    "country": "ES",
    "name": "Barjas",
    "lat": "42.61182",
    "lng": "-6.97979"
  },
  {
    "country": "ES",
    "name": "Barillas",
    "lat": "41.96667",
    "lng": "-1.63333"
  },
  {
    "country": "ES",
    "name": "Bargota",
    "lat": "42.55982",
    "lng": "-2.31067"
  },
  {
    "country": "ES",
    "name": "Bareyo",
    "lat": "43.46686",
    "lng": "-3.60083"
  },
  {
    "country": "ES",
    "name": "Bardallur",
    "lat": "41.68423",
    "lng": "-1.21183"
  },
  {
    "country": "ES",
    "name": "Barcones",
    "lat": "41.29146",
    "lng": "-2.8163"
  },
  {
    "country": "ES",
    "name": "Barcial del Barco",
    "lat": "41.93353",
    "lng": "-5.66268"
  },
  {
    "country": "ES",
    "name": "Barcial de la Loma",
    "lat": "41.95139",
    "lng": "-5.28353"
  },
  {
    "country": "ES",
    "name": "Barceo",
    "lat": "41.06108",
    "lng": "-6.45175"
  },
  {
    "country": "ES",
    "name": "Bárcena de Pie de Concha",
    "lat": "43.1258",
    "lng": "-4.05662"
  },
  {
    "country": "ES",
    "name": "Bárcena de Cicero",
    "lat": "43.4216",
    "lng": "-3.5103"
  },
  {
    "country": "ES",
    "name": "Bárcena de Campos",
    "lat": "42.48428",
    "lng": "-4.49875"
  },
  {
    "country": "ES",
    "name": "la Barceloneta",
    "lat": "41.3799",
    "lng": "2.18971"
  },
  {
    "country": "ES",
    "name": "Barcelona",
    "lat": "41.38879",
    "lng": "2.15899"
  },
  {
    "country": "ES",
    "name": "Bárcabo",
    "lat": "42.24219",
    "lng": "0.06934"
  },
  {
    "country": "ES",
    "name": "Barca",
    "lat": "41.4549",
    "lng": "-2.62217"
  },
  {
    "country": "ES",
    "name": "Barbuñales",
    "lat": "42.02563",
    "lng": "-0.08659"
  },
  {
    "country": "ES",
    "name": "Barbués",
    "lat": "41.98085",
    "lng": "-0.41949"
  },
  {
    "country": "ES",
    "name": "Barbolla",
    "lat": "41.32567",
    "lng": "-3.67361"
  },
  {
    "country": "ES",
    "name": "Bárboles",
    "lat": "41.70898",
    "lng": "-1.18594"
  },
  {
    "country": "ES",
    "name": "Barbastro",
    "lat": "42.03565",
    "lng": "0.12686"
  },
  {
    "country": "ES",
    "name": "Barbalos",
    "lat": "40.67678",
    "lng": "-5.94258"
  },
  {
    "country": "ES",
    "name": "Barbadillo del Pez",
    "lat": "42.11879",
    "lng": "-3.22803"
  },
  {
    "country": "ES",
    "name": "Barbadillo del Mercado",
    "lat": "42.03858",
    "lng": "-3.35669"
  },
  {
    "country": "ES",
    "name": "Barbadillo de Herreros",
    "lat": "42.14974",
    "lng": "-3.17702"
  },
  {
    "country": "ES",
    "name": "Barásoain",
    "lat": "42.60339",
    "lng": "-1.64658"
  },
  {
    "country": "ES",
    "name": "Barañáin",
    "lat": "42.80567",
    "lng": "-1.67731"
  },
  {
    "country": "ES",
    "name": "Baralla",
    "lat": "42.89207",
    "lng": "-7.25492"
  },
  {
    "country": "ES",
    "name": "Barajas de Melo",
    "lat": "40.1234",
    "lng": "-2.91675"
  },
  {
    "country": "ES",
    "name": "Barajas de Madrid",
    "lat": "40.47366",
    "lng": "-3.57777"
  },
  {
    "country": "ES",
    "name": "Baquerín de Campos",
    "lat": "42.016",
    "lng": "-4.78185"
  },
  {
    "country": "ES",
    "name": "Bañuelos de Bureba",
    "lat": "42.50258",
    "lng": "-3.27957"
  },
  {
    "country": "ES",
    "name": "Bañuelos",
    "lat": "41.28601",
    "lng": "-2.91477"
  },
  {
    "country": "ES",
    "name": "Baños de Valdearados",
    "lat": "41.7701",
    "lng": "-3.55589"
  },
  {
    "country": "ES",
    "name": "Baños de Tajo",
    "lat": "40.71667",
    "lng": "-1.96667"
  },
  {
    "country": "ES",
    "name": "Baños de Río Tobía",
    "lat": "42.33533",
    "lng": "-2.76099"
  },
  {
    "country": "ES",
    "name": "Baños de Rioja",
    "lat": "42.5123",
    "lng": "-2.94635"
  },
  {
    "country": "ES",
    "name": "Baños de Montemayor",
    "lat": "40.31671",
    "lng": "-5.86009"
  },
  {
    "country": "ES",
    "name": "Baños de Molgas",
    "lat": "42.24148",
    "lng": "-7.67223"
  },
  {
    "country": "ES",
    "name": "Bañón",
    "lat": "40.83825",
    "lng": "-1.19091"
  },
  {
    "country": "ES",
    "name": "Banyoles",
    "lat": "42.11667",
    "lng": "2.76667"
  },
  {
    "country": "ES",
    "name": "Bañobárez",
    "lat": "40.84825",
    "lng": "-6.61311"
  },
  {
    "country": "ES",
    "name": "Bande",
    "lat": "42.0312",
    "lng": "-7.97489"
  },
  {
    "country": "ES",
    "name": "Banastás",
    "lat": "42.18089",
    "lng": "-0.45191"
  },
  {
    "country": "ES",
    "name": "Bañares",
    "lat": "42.46838",
    "lng": "-2.9101"
  },
  {
    "country": "ES",
    "name": "Baltar",
    "lat": "41.952",
    "lng": "-7.71581"
  },
  {
    "country": "ES",
    "name": "Baltanás",
    "lat": "41.93775",
    "lng": "-4.24656"
  },
  {
    "country": "ES",
    "name": "Balsareny",
    "lat": "41.86311",
    "lng": "1.87356"
  },
  {
    "country": "ES",
    "name": "Ballobar",
    "lat": "41.62106",
    "lng": "0.192"
  },
  {
    "country": "ES",
    "name": "Baliarrain",
    "lat": "43.06928",
    "lng": "-2.12781"
  },
  {
    "country": "ES",
    "name": "Balconchán",
    "lat": "41.08737",
    "lng": "-1.45998"
  },
  {
    "country": "ES",
    "name": "Balboa",
    "lat": "42.70608",
    "lng": "-6.92222"
  },
  {
    "country": "ES",
    "name": "Balaguer",
    "lat": "41.79117",
    "lng": "0.81094"
  },
  {
    "country": "ES",
    "name": "Bailo",
    "lat": "42.50906",
    "lng": "-0.81136"
  },
  {
    "country": "ES",
    "name": "Baides",
    "lat": "41.00685",
    "lng": "-2.7762"
  },
  {
    "country": "ES",
    "name": "Bahabón de Esgueva",
    "lat": "41.86162",
    "lng": "-3.7298"
  },
  {
    "country": "ES",
    "name": "Bahabón",
    "lat": "41.48141",
    "lng": "-4.27941"
  },
  {
    "country": "ES",
    "name": "Begur",
    "lat": "41.95",
    "lng": "3.21667"
  },
  {
    "country": "ES",
    "name": "Bagüés",
    "lat": "42.54935",
    "lng": "-0.94577"
  },
  {
    "country": "ES",
    "name": "Báguena",
    "lat": "41.04181",
    "lng": "-1.35767"
  },
  {
    "country": "ES",
    "name": "Bagà",
    "lat": "42.25289",
    "lng": "1.86098"
  },
  {
    "country": "ES",
    "name": "Baells",
    "lat": "41.95325",
    "lng": "0.45956"
  },
  {
    "country": "ES",
    "name": "Badules",
    "lat": "41.13901",
    "lng": "-1.25366"
  },
  {
    "country": "ES",
    "name": "Bádenas",
    "lat": "41.09216",
    "lng": "-1.12241"
  },
  {
    "country": "ES",
    "name": "Badarán",
    "lat": "42.36794",
    "lng": "-2.81079"
  },
  {
    "country": "ES",
    "name": "Badalona",
    "lat": "41.45004",
    "lng": "2.24741"
  },
  {
    "country": "ES",
    "name": "Bakaiku",
    "lat": "42.89244",
    "lng": "-2.10251"
  },
  {
    "country": "ES",
    "name": "Babilafuente",
    "lat": "40.97704",
    "lng": "-5.42554"
  },
  {
    "country": "ES",
    "name": "Azuqueca de Henares",
    "lat": "40.56566",
    "lng": "-3.26753"
  },
  {
    "country": "ES",
    "name": "Azuelo",
    "lat": "42.60844",
    "lng": "-2.34987"
  },
  {
    "country": "ES",
    "name": "Azuara",
    "lat": "41.25822",
    "lng": "-0.87078"
  },
  {
    "country": "ES",
    "name": "Azpeitia",
    "lat": "43.18246",
    "lng": "-2.26693"
  },
  {
    "country": "ES",
    "name": "Azofra",
    "lat": "42.424",
    "lng": "-2.80086"
  },
  {
    "country": "ES",
    "name": "Azlor",
    "lat": "42.09427",
    "lng": "-0.04594"
  },
  {
    "country": "ES",
    "name": "Azkoitia",
    "lat": "43.17744",
    "lng": "-2.31129"
  },
  {
    "country": "ES",
    "name": "Azara",
    "lat": "42.07033",
    "lng": "-0.02921"
  },
  {
    "country": "ES",
    "name": "Azagra",
    "lat": "42.3",
    "lng": "-1.9"
  },
  {
    "country": "ES",
    "name": "Ayuela",
    "lat": "42.62618",
    "lng": "-4.65979"
  },
  {
    "country": "ES",
    "name": "Aitona",
    "lat": "41.48333",
    "lng": "0.46667"
  },
  {
    "country": "ES",
    "name": "Ayoó de Vidriales",
    "lat": "42.13042",
    "lng": "-6.0655"
  },
  {
    "country": "ES",
    "name": "Ayllón",
    "lat": "41.41899",
    "lng": "-3.37537"
  },
  {
    "country": "ES",
    "name": "Aiguafreda",
    "lat": "41.76807",
    "lng": "2.25051"
  },
  {
    "country": "ES",
    "name": "Ayerbe",
    "lat": "42.27267",
    "lng": "-0.68844"
  },
  {
    "country": "ES",
    "name": "Ayegui",
    "lat": "42.65656",
    "lng": "-2.03934"
  },
  {
    "country": "ES",
    "name": "Aia",
    "lat": "43.23721",
    "lng": "-2.14833"
  },
  {
    "country": "ES",
    "name": "Axpe-San Bartolome",
    "lat": "43.38333",
    "lng": "-2.7"
  },
  {
    "country": "ES",
    "name": "Avión",
    "lat": "42.38333",
    "lng": "-8.25"
  },
  {
    "country": "ES",
    "name": "Avinyonet del Penedès",
    "lat": "41.35",
    "lng": "1.78333"
  },
  {
    "country": "ES",
    "name": "Avinyó",
    "lat": "41.86367",
    "lng": "1.97095"
  },
  {
    "country": "ES",
    "name": "Avinyonet de Puigventós",
    "lat": "42.24984",
    "lng": "2.91509"
  },
  {
    "country": "ES",
    "name": "Avilés",
    "lat": "43.55473",
    "lng": "-5.92483"
  },
  {
    "country": "ES",
    "name": "Ávila",
    "lat": "40.65724",
    "lng": "-4.69951"
  },
  {
    "country": "ES",
    "name": "Avià",
    "lat": "42.06667",
    "lng": "1.85"
  },
  {
    "country": "ES",
    "name": "Avellanosa de Muñó",
    "lat": "41.98349",
    "lng": "-3.82553"
  },
  {
    "country": "ES",
    "name": "Avellaneda",
    "lat": "43.22942",
    "lng": "-3.16172"
  },
  {
    "country": "ES",
    "name": "Avellaneda",
    "lat": "40.38909",
    "lng": "-5.38811"
  },
  {
    "country": "ES",
    "name": "Aveinte",
    "lat": "40.78227",
    "lng": "-4.83649"
  },
  {
    "country": "ES",
    "name": "Autol",
    "lat": "42.21661",
    "lng": "-2.00525"
  },
  {
    "country": "ES",
    "name": "Autillo de Campos",
    "lat": "42.08725",
    "lng": "-4.83376"
  },
  {
    "country": "ES",
    "name": "Autilla del Pino",
    "lat": "41.99207",
    "lng": "-4.63393"
  },
  {
    "country": "ES",
    "name": "Ausejo de la Sierra",
    "lat": "41.89462",
    "lng": "-2.37394"
  },
  {
    "country": "ES",
    "name": "Ausejo",
    "lat": "42.3421",
    "lng": "-2.1671"
  },
  {
    "country": "ES",
    "name": "Auñón",
    "lat": "40.51752",
    "lng": "-2.7925"
  },
  {
    "country": "ES",
    "name": "Aulesti",
    "lat": "43.3",
    "lng": "-2.56667"
  },
  {
    "country": "ES",
    "name": "Atienza",
    "lat": "41.19722",
    "lng": "-2.87129"
  },
  {
    "country": "ES",
    "name": "Ateca",
    "lat": "41.33092",
    "lng": "-1.79353"
  },
  {
    "country": "ES",
    "name": "Atea",
    "lat": "41.16059",
    "lng": "-1.55533"
  },
  {
    "country": "ES",
    "name": "Ataun",
    "lat": "43.00612",
    "lng": "-2.17663"
  },
  {
    "country": "ES",
    "name": "Ataquines",
    "lat": "41.18247",
    "lng": "-4.80319"
  },
  {
    "country": "ES",
    "name": "Atapuerca",
    "lat": "42.37757",
    "lng": "-3.5079"
  },
  {
    "country": "ES",
    "name": "Asturianos",
    "lat": "42.05201",
    "lng": "-6.4894"
  },
  {
    "country": "ES",
    "name": "Astudillo",
    "lat": "42.1933",
    "lng": "-4.29394"
  },
  {
    "country": "ES",
    "name": "Astorga",
    "lat": "42.45879",
    "lng": "-6.05601"
  },
  {
    "country": "ES",
    "name": "Astigarraga",
    "lat": "43.28174",
    "lng": "-1.94634"
  },
  {
    "country": "ES",
    "name": "Asteasu",
    "lat": "43.19436",
    "lng": "-2.09818"
  },
  {
    "country": "ES",
    "name": "Aspariegos",
    "lat": "41.67458",
    "lng": "-5.59955"
  },
  {
    "country": "ES",
    "name": "Aspa",
    "lat": "41.49472",
    "lng": "0.67277"
  },
  {
    "country": "ES",
    "name": "Ascó",
    "lat": "41.18333",
    "lng": "0.56667"
  },
  {
    "country": "ES",
    "name": "Arzúa",
    "lat": "42.93333",
    "lng": "-8.15"
  },
  {
    "country": "ES",
    "name": "Artieda",
    "lat": "42.58538",
    "lng": "-0.98422"
  },
  {
    "country": "ES",
    "name": "Artesa de Segre",
    "lat": "41.89467",
    "lng": "1.04625"
  },
  {
    "country": "ES",
    "name": "Artés",
    "lat": "41.798",
    "lng": "1.95428"
  },
  {
    "country": "ES",
    "name": "Arteixo",
    "lat": "43.30482",
    "lng": "-8.50749"
  },
  {
    "country": "ES",
    "name": "Artazu",
    "lat": "42.69228",
    "lng": "-1.83954"
  },
  {
    "country": "ES",
    "name": "Artajona",
    "lat": "42.58867",
    "lng": "-1.76504"
  },
  {
    "country": "ES",
    "name": "Arrúbal",
    "lat": "42.43485",
    "lng": "-2.25143"
  },
  {
    "country": "ES",
    "name": "Arruazu",
    "lat": "42.92186",
    "lng": "-2.00157"
  },
  {
    "country": "ES",
    "name": "Arroyomolinos de la Vera",
    "lat": "40.05277",
    "lng": "-5.85111"
  },
  {
    "country": "ES",
    "name": "Arroyomolinos",
    "lat": "40.26951",
    "lng": "-3.91946"
  },
  {
    "country": "ES",
    "name": "Arroyo de las Fraguas",
    "lat": "41.10246",
    "lng": "-3.13005"
  },
  {
    "country": "ES",
    "name": "Arroyo de la Encomienda",
    "lat": "41.60956",
    "lng": "-4.79692"
  },
  {
    "country": "ES",
    "name": "Arróniz",
    "lat": "42.58823",
    "lng": "-2.09237"
  },
  {
    "country": "ES",
    "name": "Arrigorriaga",
    "lat": "43.21006",
    "lng": "-2.88562"
  },
  {
    "country": "ES",
    "name": "Arriba",
    "lat": "43.51615",
    "lng": "-5.53511"
  },
  {
    "country": "ES",
    "name": "Arredondo",
    "lat": "43.27325",
    "lng": "-3.60031"
  },
  {
    "country": "ES",
    "name": "Arraya de Oca",
    "lat": "42.41488",
    "lng": "-3.39781"
  },
  {
    "country": "ES",
    "name": "Arrancacepas",
    "lat": "40.3032",
    "lng": "-2.35899"
  },
  {
    "country": "ES",
    "name": "Arrabalde",
    "lat": "42.1076",
    "lng": "-5.89441"
  },
  {
    "country": "ES",
    "name": "Arquillinos",
    "lat": "41.7099",
    "lng": "-5.65708"
  },
  {
    "country": "ES",
    "name": "Arnuero",
    "lat": "43.47756",
    "lng": "-3.56959"
  },
  {
    "country": "ES",
    "name": "Arnedo",
    "lat": "42.228",
    "lng": "-2.10083"
  },
  {
    "country": "ES",
    "name": "Arnedillo",
    "lat": "42.21221",
    "lng": "-2.23602"
  },
  {
    "country": "ES",
    "name": "Armuña de Tajuña",
    "lat": "40.52884",
    "lng": "-3.02819"
  },
  {
    "country": "ES",
    "name": "Armuña",
    "lat": "41.07715",
    "lng": "-4.31949"
  },
  {
    "country": "ES",
    "name": "Armiñón",
    "lat": "42.72313",
    "lng": "-2.87172"
  },
  {
    "country": "ES",
    "name": "Armenteros",
    "lat": "40.5932",
    "lng": "-5.44806"
  },
  {
    "country": "ES",
    "name": "Armañanzas",
    "lat": "42.55963",
    "lng": "-2.28476"
  },
  {
    "country": "ES",
    "name": "Armallones",
    "lat": "40.7358",
    "lng": "-2.30257"
  },
  {
    "country": "ES",
    "name": "Arlanzón",
    "lat": "42.32267",
    "lng": "-3.45784"
  },
  {
    "country": "ES",
    "name": "Ariza",
    "lat": "41.31442",
    "lng": "-2.05332"
  },
  {
    "country": "ES",
    "name": "Aribe",
    "lat": "42.95",
    "lng": "-1.25"
  },
  {
    "country": "ES",
    "name": "Ariño",
    "lat": "41.03019",
    "lng": "-0.59206"
  },
  {
    "country": "ES",
    "name": "Arija",
    "lat": "42.9935",
    "lng": "-3.94497"
  },
  {
    "country": "ES",
    "name": "Aria",
    "lat": "42.95283",
    "lng": "-1.26584"
  },
  {
    "country": "ES",
    "name": "Argujillo",
    "lat": "41.31156",
    "lng": "-5.58763"
  },
  {
    "country": "ES",
    "name": "Arguis",
    "lat": "42.31476",
    "lng": "-0.43967"
  },
  {
    "country": "ES",
    "name": "Arguedas",
    "lat": "42.17759",
    "lng": "-1.59719"
  },
  {
    "country": "ES",
    "name": "Argoños",
    "lat": "43.4574",
    "lng": "-3.49013"
  },
  {
    "country": "ES",
    "name": "Argentona",
    "lat": "41.55336",
    "lng": "2.40114"
  },
  {
    "country": "ES",
    "name": "Argente",
    "lat": "40.68841",
    "lng": "-1.16217"
  },
  {
    "country": "ES",
    "name": "Argelita",
    "lat": "40.05",
    "lng": "-0.35"
  },
  {
    "country": "ES",
    "name": "Argelaguer",
    "lat": "42.21563",
    "lng": "2.64193"
  },
  {
    "country": "ES",
    "name": "Argecilla",
    "lat": "40.88151",
    "lng": "-2.82181"
  },
  {
    "country": "ES",
    "name": "Argavieso",
    "lat": "42.05275",
    "lng": "-0.27834"
  },
  {
    "country": "ES",
    "name": "Arganza",
    "lat": "42.64077",
    "lng": "-6.68627"
  },
  {
    "country": "ES",
    "name": "Argañín",
    "lat": "41.43948",
    "lng": "-6.20827"
  },
  {
    "country": "ES",
    "name": "Arganda",
    "lat": "40.30076",
    "lng": "-3.43722"
  },
  {
    "country": "ES",
    "name": "Arévalo de la Sierra",
    "lat": "41.94723",
    "lng": "-2.40033"
  },
  {
    "country": "ES",
    "name": "Arévalo",
    "lat": "41.06255",
    "lng": "-4.72042"
  },
  {
    "country": "ES",
    "name": "Arevalillo de Cega",
    "lat": "41.16174",
    "lng": "-3.88911"
  },
  {
    "country": "ES",
    "name": "Areso",
    "lat": "43.08209",
    "lng": "-1.95198"
  },
  {
    "country": "ES",
    "name": "Ares del Maestre",
    "lat": "40.45675",
    "lng": "-0.13267"
  },
  {
    "country": "ES",
    "name": "Ares",
    "lat": "43.42995",
    "lng": "-8.24254"
  },
  {
    "country": "ES",
    "name": "Arenzana de Arriba",
    "lat": "42.38745",
    "lng": "-2.69494"
  },
  {
    "country": "ES",
    "name": "Arenzana de Abajo",
    "lat": "42.38599",
    "lng": "-2.7194"
  },
  {
    "country": "ES",
    "name": "Arenys de Munt",
    "lat": "41.61424",
    "lng": "2.53972"
  },
  {
    "country": "ES",
    "name": "Arenys de Mar",
    "lat": "41.5819",
    "lng": "2.54936"
  },
  {
    "country": "ES",
    "name": "Arenys de Lledó / Arens de Lledó",
    "lat": "40.99244",
    "lng": "0.27092"
  },
  {
    "country": "ES",
    "name": "Arenillas",
    "lat": "41.34706",
    "lng": "-2.84618"
  },
  {
    "country": "ES",
    "name": "Arenas de San Pedro",
    "lat": "40.21041",
    "lng": "-5.08694"
  },
  {
    "country": "ES",
    "name": "Arenas de Iguña",
    "lat": "43.18293",
    "lng": "-4.04729"
  },
  {
    "country": "ES",
    "name": "Arellano",
    "lat": "42.60598",
    "lng": "-2.04653"
  },
  {
    "country": "ES",
    "name": "Aretxabaleta",
    "lat": "43.03414",
    "lng": "-2.50456"
  },
  {
    "country": "ES",
    "name": "Ardón",
    "lat": "42.43629",
    "lng": "-5.56048"
  },
  {
    "country": "ES",
    "name": "Arcos de la Sierra",
    "lat": "40.34664",
    "lng": "-2.1131"
  },
  {
    "country": "ES",
    "name": "Arcos de la Polvorosa",
    "lat": "41.94389",
    "lng": "-5.69731"
  },
  {
    "country": "ES",
    "name": "Arcos de Jalón",
    "lat": "41.21592",
    "lng": "-2.2747"
  },
  {
    "country": "ES",
    "name": "Arcos",
    "lat": "42.26664",
    "lng": "-3.75458"
  },
  {
    "country": "ES",
    "name": "Arcones",
    "lat": "41.11817",
    "lng": "-3.72384"
  },
  {
    "country": "ES",
    "name": "Arconada",
    "lat": "42.32774",
    "lng": "-4.49617"
  },
  {
    "country": "ES",
    "name": "Arcicóllar",
    "lat": "40.05517",
    "lng": "-4.11638"
  },
  {
    "country": "ES",
    "name": "Arcenillas",
    "lat": "41.45641",
    "lng": "-5.68512"
  },
  {
    "country": "ES",
    "name": "Arcediano",
    "lat": "41.09379",
    "lng": "-5.56055"
  },
  {
    "country": "ES",
    "name": "Arbúcies",
    "lat": "41.81667",
    "lng": "2.51667"
  },
  {
    "country": "ES",
    "name": "Arbo",
    "lat": "42.11667",
    "lng": "-8.31667"
  },
  {
    "country": "ES",
    "name": "Arbizu",
    "lat": "42.91545",
    "lng": "-2.03917"
  },
  {
    "country": "ES",
    "name": "Arbeteta",
    "lat": "40.66999",
    "lng": "-2.40236"
  },
  {
    "country": "ES",
    "name": "Arbeca",
    "lat": "41.54153",
    "lng": "0.92457"
  },
  {
    "country": "ES",
    "name": "Arbancón",
    "lat": "40.96434",
    "lng": "-3.11505"
  },
  {
    "country": "ES",
    "name": "Araia",
    "lat": "42.89345",
    "lng": "-2.31314"
  },
  {
    "country": "ES",
    "name": "Arauzo de Torre",
    "lat": "41.79818",
    "lng": "-3.42314"
  },
  {
    "country": "ES",
    "name": "Arauzo de Salce",
    "lat": "41.81919",
    "lng": "-3.41191"
  },
  {
    "country": "ES",
    "name": "Arauzo de Miel",
    "lat": "41.85878",
    "lng": "-3.38773"
  },
  {
    "country": "ES",
    "name": "Aras",
    "lat": "42.56172",
    "lng": "-2.356"
  },
  {
    "country": "ES",
    "name": "Arapiles",
    "lat": "40.89366",
    "lng": "-5.64494"
  },
  {
    "country": "ES",
    "name": "Aranzueque",
    "lat": "40.49094",
    "lng": "-3.07448"
  },
  {
    "country": "ES",
    "name": "Arañuel",
    "lat": "40.06667",
    "lng": "-0.48333"
  },
  {
    "country": "ES",
    "name": "Arano",
    "lat": "43.19956",
    "lng": "-1.89569"
  },
  {
    "country": "ES",
    "name": "Aranjuez",
    "lat": "40.03108",
    "lng": "-3.60246"
  },
  {
    "country": "ES",
    "name": "Aranga",
    "lat": "43.23469",
    "lng": "-8.01705"
  },
  {
    "country": "ES",
    "name": "Arandilla del Arroyo",
    "lat": "40.51056",
    "lng": "-2.38355"
  },
  {
    "country": "ES",
    "name": "Arandilla",
    "lat": "41.73778",
    "lng": "-3.42914"
  },
  {
    "country": "ES",
    "name": "Arándiga",
    "lat": "41.50872",
    "lng": "-1.50074"
  },
  {
    "country": "ES",
    "name": "Aranda de Moncayo",
    "lat": "41.57749",
    "lng": "-1.79171"
  },
  {
    "country": "ES",
    "name": "Aranda de Duero",
    "lat": "41.67041",
    "lng": "-3.6892"
  },
  {
    "country": "ES",
    "name": "Arancón",
    "lat": "41.80017",
    "lng": "-2.28141"
  },
  {
    "country": "ES",
    "name": "Arantza",
    "lat": "43.19623",
    "lng": "-1.72494"
  },
  {
    "country": "ES",
    "name": "Aranarache",
    "lat": "42.77979",
    "lng": "-2.22924"
  },
  {
    "country": "ES",
    "name": "Arama",
    "lat": "43.06335",
    "lng": "-2.1654"
  },
  {
    "country": "ES",
    "name": "Arahuetes",
    "lat": "41.13762",
    "lng": "-3.85664"
  },
  {
    "country": "ES",
    "name": "Aragüés del Puerto",
    "lat": "42.70641",
    "lng": "-0.66999"
  },
  {
    "country": "ES",
    "name": "Elexalde",
    "lat": "43.15",
    "lng": "-2.93333"
  },
  {
    "country": "ES",
    "name": "Aoiz",
    "lat": "42.78633",
    "lng": "-1.37252"
  },
  {
    "country": "ES",
    "name": "Antzuola",
    "lat": "43.09725",
    "lng": "-2.37998"
  },
  {
    "country": "ES",
    "name": "Antillón",
    "lat": "42.03639",
    "lng": "-0.16239"
  },
  {
    "country": "ES",
    "name": "Antigüedad",
    "lat": "41.94681",
    "lng": "-4.12058"
  },
  {
    "country": "ES",
    "name": "Ansó",
    "lat": "42.75785",
    "lng": "-0.82947"
  },
  {
    "country": "ES",
    "name": "Anquela del Pedregal",
    "lat": "40.74336",
    "lng": "-1.73697"
  },
  {
    "country": "ES",
    "name": "Anquela del Ducado",
    "lat": "40.97084",
    "lng": "-2.13066"
  },
  {
    "country": "ES",
    "name": "Añover de Tormes",
    "lat": "41.13658",
    "lng": "-5.91585"
  },
  {
    "country": "ES",
    "name": "Añorbe",
    "lat": "42.65732",
    "lng": "-1.7149"
  },
  {
    "country": "ES",
    "name": "Anoeta",
    "lat": "43.16241",
    "lng": "-2.07107"
  },
  {
    "country": "ES",
    "name": "Anguix",
    "lat": "41.75331",
    "lng": "-3.93125"
  },
  {
    "country": "ES",
    "name": "Anguita",
    "lat": "41.02659",
    "lng": "-2.36849"
  },
  {
    "country": "ES",
    "name": "Anguiano",
    "lat": "42.26381",
    "lng": "-2.76463"
  },
  {
    "country": "ES",
    "name": "Angüés",
    "lat": "42.11109",
    "lng": "-0.15298"
  },
  {
    "country": "ES",
    "name": "Anguciana",
    "lat": "42.57421",
    "lng": "-2.90124"
  },
  {
    "country": "ES",
    "name": "Anglesola",
    "lat": "41.65649",
    "lng": "1.08286"
  },
  {
    "country": "ES",
    "name": "Anglès",
    "lat": "41.95617",
    "lng": "2.63603"
  },
  {
    "country": "ES",
    "name": "Anento",
    "lat": "41.06958",
    "lng": "-1.33375"
  },
  {
    "country": "ES",
    "name": "Añe",
    "lat": "41.03702",
    "lng": "-4.29462"
  },
  {
    "country": "ES",
    "name": "Andosilla",
    "lat": "42.38144",
    "lng": "-1.67305"
  },
  {
    "country": "ES",
    "name": "Andorra",
    "lat": "40.97655",
    "lng": "-0.44721"
  },
  {
    "country": "ES",
    "name": "Andoain",
    "lat": "43.21658",
    "lng": "-2.0253"
  },
  {
    "country": "ES",
    "name": "Ancín",
    "lat": "42.66047",
    "lng": "-2.18885"
  },
  {
    "country": "ES",
    "name": "Anchuelo",
    "lat": "40.46527",
    "lng": "-3.26838"
  },
  {
    "country": "ES",
    "name": "Anaya de Alba",
    "lat": "40.72828",
    "lng": "-5.49266"
  },
  {
    "country": "ES",
    "name": "Anaya",
    "lat": "40.99184",
    "lng": "-4.3095"
  },
  {
    "country": "ES",
    "name": "Anadón",
    "lat": "40.98225",
    "lng": "-0.98367"
  },
  {
    "country": "ES",
    "name": "Amusquillo",
    "lat": "41.74853",
    "lng": "-4.30117"
  },
  {
    "country": "ES",
    "name": "Amusco",
    "lat": "42.17306",
    "lng": "-4.47018"
  },
  {
    "country": "ES",
    "name": "Amurrio",
    "lat": "43.05",
    "lng": "-3"
  },
  {
    "country": "ES",
    "name": "Ampuero",
    "lat": "43.34268",
    "lng": "-3.41667"
  },
  {
    "country": "ES",
    "name": "Ampudia",
    "lat": "41.91608",
    "lng": "-4.78033"
  },
  {
    "country": "ES",
    "name": "Amposta",
    "lat": "40.70995",
    "lng": "0.57856"
  },
  {
    "country": "ES",
    "name": "Amoroto",
    "lat": "43.32634",
    "lng": "-2.51349"
  },
  {
    "country": "ES",
    "name": "Amorebieta",
    "lat": "43.21667",
    "lng": "-2.73333"
  },
  {
    "country": "ES",
    "name": "Amoeiro",
    "lat": "42.41667",
    "lng": "-7.95"
  },
  {
    "country": "ES",
    "name": "Amieva",
    "lat": "43.24403",
    "lng": "-5.0746"
  },
  {
    "country": "ES",
    "name": "Amezketa",
    "lat": "43.04813",
    "lng": "-2.08541"
  },
  {
    "country": "ES",
    "name": "Ameyugo",
    "lat": "42.65617",
    "lng": "-3.0617"
  },
  {
    "country": "ES",
    "name": "Amés",
    "lat": "42.90426",
    "lng": "-8.65551"
  },
  {
    "country": "ES",
    "name": "Ambite",
    "lat": "40.3319",
    "lng": "-3.18034"
  },
  {
    "country": "ES",
    "name": "Ambía",
    "lat": "42.20578",
    "lng": "-7.73707"
  },
  {
    "country": "ES",
    "name": "Ambel",
    "lat": "41.79472",
    "lng": "-1.6152"
  },
  {
    "country": "ES",
    "name": "Amayuelas de Arriba",
    "lat": "42.21108",
    "lng": "-4.4888"
  },
  {
    "country": "ES",
    "name": "Amavida",
    "lat": "40.57371",
    "lng": "-5.06541"
  },
  {
    "country": "ES",
    "name": "Altzaga",
    "lat": "43.06468",
    "lng": "-2.154"
  },
  {
    "country": "ES",
    "name": "Alustante",
    "lat": "40.61442",
    "lng": "-1.6591"
  },
  {
    "country": "ES",
    "name": "Altafulla",
    "lat": "41.14286",
    "lng": "1.37269"
  },
  {
    "country": "ES",
    "name": "Altable",
    "lat": "42.60276",
    "lng": "-3.07719"
  },
  {
    "country": "ES",
    "name": "Altsasu",
    "lat": "42.89999",
    "lng": "-2.16516"
  },
  {
    "country": "ES",
    "name": "Alkiza",
    "lat": "43.17263",
    "lng": "-2.10923"
  },
  {
    "country": "ES",
    "name": "Alquézar",
    "lat": "42.17268",
    "lng": "0.02586"
  },
  {
    "country": "ES",
    "name": "Alpicat",
    "lat": "41.6657",
    "lng": "0.55564"
  },
  {
    "country": "ES",
    "name": "Alpens",
    "lat": "42.1193",
    "lng": "2.10135"
  },
  {
    "country": "ES",
    "name": "Alpeñés",
    "lat": "40.79958",
    "lng": "-1.06625"
  },
  {
    "country": "ES",
    "name": "Alpedrete",
    "lat": "40.65889",
    "lng": "-4.02512"
  },
  {
    "country": "ES",
    "name": "Alpartir",
    "lat": "41.42253",
    "lng": "-1.38061"
  },
  {
    "country": "ES",
    "name": "Alpanseque",
    "lat": "41.26505",
    "lng": "-2.67064"
  },
  {
    "country": "ES",
    "name": "Alp",
    "lat": "42.37256",
    "lng": "1.88699"
  },
  {
    "country": "ES",
    "name": "Alovera",
    "lat": "40.59368",
    "lng": "-3.24529"
  },
  {
    "country": "ES",
    "name": "Alonsotegi",
    "lat": "43.24483",
    "lng": "-2.98759"
  },
  {
    "country": "ES",
    "name": "Alocén",
    "lat": "40.57455",
    "lng": "-2.74993"
  },
  {
    "country": "ES",
    "name": "Alobras",
    "lat": "40.18169",
    "lng": "-1.38731"
  },
  {
    "country": "ES",
    "name": "Almuniente",
    "lat": "41.94949",
    "lng": "-0.41173"
  },
  {
    "country": "ES",
    "name": "Almudébar",
    "lat": "42.04255",
    "lng": "-0.58141"
  },
  {
    "country": "ES",
    "name": "Almoster",
    "lat": "41.19758",
    "lng": "1.11167"
  },
  {
    "country": "ES",
    "name": "Almorox",
    "lat": "40.23423",
    "lng": "-4.39044"
  },
  {
    "country": "ES",
    "name": "Almonacid de Zorita",
    "lat": "40.32932",
    "lng": "-2.8504"
  },
  {
    "country": "ES",
    "name": "Almonacid de la Sierra",
    "lat": "41.39754",
    "lng": "-1.32394"
  },
  {
    "country": "ES",
    "name": "Almonacid de la Cuba",
    "lat": "41.28067",
    "lng": "-0.79266"
  },
  {
    "country": "ES",
    "name": "Almohaja",
    "lat": "40.60489",
    "lng": "-1.438"
  },
  {
    "country": "ES",
    "name": "Almoguera",
    "lat": "40.29713",
    "lng": "-2.9824"
  },
  {
    "country": "ES",
    "name": "Almochuel",
    "lat": "41.27992",
    "lng": "-0.55067"
  },
  {
    "country": "ES",
    "name": "Almendral de la Cañada",
    "lat": "40.18456",
    "lng": "-4.74173"
  },
  {
    "country": "ES",
    "name": "Almendra",
    "lat": "41.22922",
    "lng": "-6.34068"
  },
  {
    "country": "ES",
    "name": "Almenar de Soria",
    "lat": "41.6823",
    "lng": "-2.20082"
  },
  {
    "country": "ES",
    "name": "Almenara de Tormes",
    "lat": "41.0639",
    "lng": "-5.8235"
  },
  {
    "country": "ES",
    "name": "Almenara de Adaja",
    "lat": "41.21406",
    "lng": "-4.67824"
  },
  {
    "country": "ES",
    "name": "Almenar",
    "lat": "41.79604",
    "lng": "0.56834"
  },
  {
    "country": "ES",
    "name": "Almazul",
    "lat": "41.574",
    "lng": "-2.1462"
  },
  {
    "country": "ES",
    "name": "Almazán",
    "lat": "41.48648",
    "lng": "-2.53088"
  },
  {
    "country": "ES",
    "name": "Almarza de Cameros",
    "lat": "42.2165",
    "lng": "-2.59873"
  },
  {
    "country": "ES",
    "name": "Almarza",
    "lat": "41.94678",
    "lng": "-2.469"
  },
  {
    "country": "ES",
    "name": "Almaraz de Duero",
    "lat": "41.47505",
    "lng": "-5.91654"
  },
  {
    "country": "ES",
    "name": "Almanza",
    "lat": "42.65825",
    "lng": "-5.0362"
  },
  {
    "country": "ES",
    "name": "Almaluez",
    "lat": "41.28932",
    "lng": "-2.26871"
  },
  {
    "country": "ES",
    "name": "Almajano",
    "lat": "41.85095",
    "lng": "-2.3383"
  },
  {
    "country": "ES",
    "name": "Almadrones",
    "lat": "40.90096",
    "lng": "-2.77406"
  },
  {
    "country": "ES",
    "name": "Almacelles",
    "lat": "41.73216",
    "lng": "0.43722"
  },
  {
    "country": "ES",
    "name": "Allueva",
    "lat": "40.98533",
    "lng": "-1.04258"
  },
  {
    "country": "ES",
    "name": "Alloza",
    "lat": "40.96942",
    "lng": "-0.52941"
  },
  {
    "country": "ES",
    "name": "Allo",
    "lat": "42.56738",
    "lng": "-2.02052"
  },
  {
    "country": "ES",
    "name": "Allepuz",
    "lat": "40.49295",
    "lng": "-0.72478"
  },
  {
    "country": "ES",
    "name": "Allariz",
    "lat": "42.19044",
    "lng": "-7.80175"
  },
  {
    "country": "ES",
    "name": "Aliud",
    "lat": "41.65412",
    "lng": "-2.25314"
  },
  {
    "country": "ES",
    "name": "Alique",
    "lat": "40.58671",
    "lng": "-2.64441"
  },
  {
    "country": "ES",
    "name": "Alió",
    "lat": "41.29422",
    "lng": "1.30585"
  },
  {
    "country": "ES",
    "name": "Aliaga",
    "lat": "40.67411",
    "lng": "-0.70333"
  },
  {
    "country": "ES",
    "name": "Alhóndiga",
    "lat": "40.52669",
    "lng": "-2.82438"
  },
  {
    "country": "ES",
    "name": "Alhama de Aragón",
    "lat": "41.29657",
    "lng": "-1.89358"
  },
  {
    "country": "ES",
    "name": "Alguaire",
    "lat": "41.73703",
    "lng": "0.5845"
  },
  {
    "country": "ES",
    "name": "Algorta",
    "lat": "43.34927",
    "lng": "-3.0094"
  },
  {
    "country": "ES",
    "name": "Algora",
    "lat": "40.96324",
    "lng": "-2.66688"
  },
  {
    "country": "ES",
    "name": "Algodre",
    "lat": "41.56631",
    "lng": "-5.60406"
  },
  {
    "country": "ES",
    "name": "Algete",
    "lat": "40.59711",
    "lng": "-3.49743"
  },
  {
    "country": "ES",
    "name": "Algerri",
    "lat": "41.81482",
    "lng": "0.63633"
  },
  {
    "country": "ES",
    "name": "Algar de Mesa",
    "lat": "41.13494",
    "lng": "-1.95964"
  },
  {
    "country": "ES",
    "name": "Algadefe",
    "lat": "42.21931",
    "lng": "-5.58419"
  },
  {
    "country": "ES",
    "name": "Alforque",
    "lat": "41.32942",
    "lng": "-0.38525"
  },
  {
    "country": "ES",
    "name": "Alforja",
    "lat": "41.21108",
    "lng": "0.97542"
  },
  {
    "country": "ES",
    "name": "Alfés",
    "lat": "41.52143",
    "lng": "0.6205"
  },
  {
    "country": "ES",
    "name": "Alfarràs",
    "lat": "41.81667",
    "lng": "0.58333"
  },
  {
    "country": "ES",
    "name": "Alfaro",
    "lat": "42.18032",
    "lng": "-1.75016"
  },
  {
    "country": "ES",
    "name": "Alfántega",
    "lat": "41.82832",
    "lng": "0.14823"
  },
  {
    "country": "ES",
    "name": "Alfamén",
    "lat": "41.43919",
    "lng": "-1.24458"
  },
  {
    "country": "ES",
    "name": "Alfambra",
    "lat": "40.54638",
    "lng": "-1.03314"
  },
  {
    "country": "ES",
    "name": "Alfajarín",
    "lat": "41.614",
    "lng": "-0.7037"
  },
  {
    "country": "ES",
    "name": "Alesón",
    "lat": "42.40554",
    "lng": "-2.68938"
  },
  {
    "country": "ES",
    "name": "Alesanco",
    "lat": "42.41409",
    "lng": "-2.81666"
  },
  {
    "country": "ES",
    "name": "Alerre",
    "lat": "42.16468",
    "lng": "-0.46369"
  },
  {
    "country": "ES",
    "name": "Alentisque",
    "lat": "41.42059",
    "lng": "-2.33189"
  },
  {
    "country": "ES",
    "name": "Alella",
    "lat": "41.49379",
    "lng": "2.29451"
  },
  {
    "country": "ES",
    "name": "Alegia",
    "lat": "43.10097",
    "lng": "-2.09637"
  },
  {
    "country": "ES",
    "name": "Aldeonte",
    "lat": "41.35092",
    "lng": "-3.67847"
  },
  {
    "country": "ES",
    "name": "Aldehuela de Yeltes",
    "lat": "40.66254",
    "lng": "-6.24332"
  },
  {
    "country": "ES",
    "name": "Aldehuela de Liestos",
    "lat": "41.0641",
    "lng": "-1.70107"
  },
  {
    "country": "ES",
    "name": "Aldehuela del Codonal",
    "lat": "41.05504",
    "lng": "-4.53863"
  },
  {
    "country": "ES",
    "name": "Aldehuela de la Bóveda",
    "lat": "40.85077",
    "lng": "-6.0526"
  },
  {
    "country": "ES",
    "name": "Aldeavieja de Tormes",
    "lat": "40.58307",
    "lng": "-5.61705"
  },
  {
    "country": "ES",
    "name": "Aldeatejada",
    "lat": "40.92168",
    "lng": "-5.69273"
  },
  {
    "country": "ES",
    "name": "Aldeasoña",
    "lat": "41.47285",
    "lng": "-4.05711"
  },
  {
    "country": "ES",
    "name": "Aldeaseca de la Frontera",
    "lat": "40.94161",
    "lng": "-5.20719"
  },
  {
    "country": "ES",
    "name": "Aldeaseca de Alba",
    "lat": "40.81909",
    "lng": "-5.44699"
  },
  {
    "country": "ES",
    "name": "Aldeaseca",
    "lat": "41.04912",
    "lng": "-4.81707"
  },
  {
    "country": "ES",
    "name": "Aldearrubia",
    "lat": "41.00807",
    "lng": "-5.49829"
  },
  {
    "country": "ES",
    "name": "Aldearrodrigo",
    "lat": "41.10966",
    "lng": "-5.80726"
  },
  {
    "country": "ES",
    "name": "Aldea Real",
    "lat": "41.18553",
    "lng": "-4.16559"
  },
  {
    "country": "ES",
    "name": "Aldeanueva de Santa Cruz",
    "lat": "40.38189",
    "lng": "-5.42142"
  },
  {
    "country": "ES",
    "name": "Aldeanueva del Codonal",
    "lat": "41.08236",
    "lng": "-4.54369"
  },
  {
    "country": "ES",
    "name": "Aldeanueva del Camino",
    "lat": "40.2598",
    "lng": "-5.92886"
  },
  {
    "country": "ES",
    "name": "Aldeanueva de la Vera",
    "lat": "40.1271",
    "lng": "-5.7015"
  },
  {
    "country": "ES",
    "name": "Aldeanueva de la Sierra",
    "lat": "40.6162",
    "lng": "-6.10023"
  },
  {
    "country": "ES",
    "name": "Aldeanueva de Guadalajara",
    "lat": "40.67988",
    "lng": "-3.04438"
  },
  {
    "country": "ES",
    "name": "Aldeanueva de Figueroa",
    "lat": "41.14809",
    "lng": "-5.52404"
  },
  {
    "country": "ES",
    "name": "Aldeanueva de Ebro",
    "lat": "42.22911",
    "lng": "-1.88735"
  },
  {
    "country": "ES",
    "name": "Aldeamayor de San Martín",
    "lat": "41.51256",
    "lng": "-4.63955"
  },
  {
    "country": "ES",
    "name": "Aldealseñor",
    "lat": "41.8789",
    "lng": "-2.31565"
  },
  {
    "country": "ES",
    "name": "Aldealpozo",
    "lat": "41.78258",
    "lng": "-2.20416"
  },
  {
    "country": "ES",
    "name": "Aldealengua de Santa María",
    "lat": "41.46196",
    "lng": "-3.46723"
  },
  {
    "country": "ES",
    "name": "Aldealengua",
    "lat": "40.9809",
    "lng": "-5.54922"
  },
  {
    "country": "ES",
    "name": "Aldealcorvo",
    "lat": "41.24443",
    "lng": "-3.79136"
  },
  {
    "country": "ES",
    "name": "Aldealafuente",
    "lat": "41.67194",
    "lng": "-2.32522"
  },
  {
    "country": "ES",
    "name": "Aldea de San Miguel",
    "lat": "41.46098",
    "lng": "-4.6158"
  },
  {
    "country": "ES",
    "name": "Aldea del Obispo",
    "lat": "40.70677",
    "lng": "-6.79253"
  },
  {
    "country": "ES",
    "name": "Aldea del Fresno",
    "lat": "40.3236",
    "lng": "-4.20319"
  },
  {
    "country": "ES",
    "name": "Aldeadávila de la Ribera",
    "lat": "41.21769",
    "lng": "-6.61786"
  },
  {
    "country": "ES",
    "name": "Aldeacipreste",
    "lat": "40.3809",
    "lng": "-5.89754"
  },
  {
    "country": "ES",
    "name": "Alcubilla de Nogales",
    "lat": "42.12787",
    "lng": "-5.92184"
  },
  {
    "country": "ES",
    "name": "Alcubilla de las Peñas",
    "lat": "41.25129",
    "lng": "-2.52684"
  },
  {
    "country": "ES",
    "name": "Alcubilla de Avellaneda",
    "lat": "41.72593",
    "lng": "-3.30471"
  },
  {
    "country": "ES",
    "name": "Alcubierre",
    "lat": "41.80757",
    "lng": "-0.45291"
  },
  {
    "country": "ES",
    "name": "Alcover",
    "lat": "41.26267",
    "lng": "1.1701"
  },
  {
    "country": "ES",
    "name": "Alcoroches",
    "lat": "40.62669",
    "lng": "-1.74629"
  },
  {
    "country": "ES",
    "name": "Alcorisa",
    "lat": "40.8921",
    "lng": "-0.38143"
  },
  {
    "country": "ES",
    "name": "Alcorcón",
    "lat": "40.34582",
    "lng": "-3.82487"
  },
  {
    "country": "ES",
    "name": "l'Alcora",
    "lat": "40.06667",
    "lng": "-0.2"
  },
  {
    "country": "ES",
    "name": "Alconchel de Ariza",
    "lat": "41.20428",
    "lng": "-2.12191"
  },
  {
    "country": "ES",
    "name": "Alconada de Maderuelo",
    "lat": "41.45015",
    "lng": "-3.48554"
  },
  {
    "country": "ES",
    "name": "Alconada",
    "lat": "40.91092",
    "lng": "-5.36305"
  },
  {
    "country": "ES",
    "name": "Alconaba",
    "lat": "41.7236",
    "lng": "-2.38483"
  },
  {
    "country": "ES",
    "name": "Alcoletge",
    "lat": "41.64762",
    "lng": "0.69383"
  },
  {
    "country": "ES",
    "name": "Alcolea del Pinar",
    "lat": "41.03569",
    "lng": "-2.46645"
  },
  {
    "country": "ES",
    "name": "Alcolea de las Peñas",
    "lat": "41.2096",
    "lng": "-2.78483"
  },
  {
    "country": "ES",
    "name": "Alcolea de Cinca",
    "lat": "41.71944",
    "lng": "0.11716"
  },
  {
    "country": "ES",
    "name": "Alcohujate",
    "lat": "40.41763",
    "lng": "-2.6149"
  },
  {
    "country": "ES",
    "name": "Alcocero de Mola",
    "lat": "42.47222",
    "lng": "-3.3579"
  },
  {
    "country": "ES",
    "name": "Alcocer",
    "lat": "40.46972",
    "lng": "-2.6094"
  },
  {
    "country": "ES",
    "name": "Alcocéber",
    "lat": "40.25142",
    "lng": "0.28433"
  },
  {
    "country": "ES",
    "name": "Alcobendas",
    "lat": "40.54746",
    "lng": "-3.64197"
  },
  {
    "country": "ES",
    "name": "Alcazarén",
    "lat": "41.37061",
    "lng": "-4.67262"
  },
  {
    "country": "ES",
    "name": "Alcázar del Rey",
    "lat": "40.06289",
    "lng": "-2.80782"
  },
  {
    "country": "ES",
    "name": "Alcarràs",
    "lat": "41.56667",
    "lng": "0.51667"
  },
  {
    "country": "ES",
    "name": "Alcantud",
    "lat": "40.54818",
    "lng": "-2.33258"
  },
  {
    "country": "ES",
    "name": "Alcanó",
    "lat": "41.48064",
    "lng": "0.61659"
  },
  {
    "country": "ES",
    "name": "Alcañiz",
    "lat": "41.05",
    "lng": "-0.13333"
  },
  {
    "country": "ES",
    "name": "Alcañices",
    "lat": "41.6994",
    "lng": "-6.34647"
  },
  {
    "country": "ES",
    "name": "Alcanar",
    "lat": "40.54316",
    "lng": "0.48082"
  },
  {
    "country": "ES",
    "name": "Alcanadre",
    "lat": "42.40492",
    "lng": "-2.12073"
  },
  {
    "country": "ES",
    "name": "Alcalá de Moncayo",
    "lat": "41.7861",
    "lng": "-1.69544"
  },
  {
    "country": "ES",
    "name": "Alcalá del Obispo",
    "lat": "42.0773",
    "lng": "-0.2912"
  },
  {
    "country": "ES",
    "name": "Alcalá de la Vega",
    "lat": "40.03333",
    "lng": "-1.51667"
  },
  {
    "country": "ES",
    "name": "Alcalá de la Selva",
    "lat": "40.37183",
    "lng": "-0.72015"
  },
  {
    "country": "ES",
    "name": "Alcalá de Henares",
    "lat": "40.48205",
    "lng": "-3.35996"
  },
  {
    "country": "ES",
    "name": "Alcalá de Gurrea",
    "lat": "42.06653",
    "lng": "-0.68534"
  },
  {
    "country": "ES",
    "name": "Alcalá de Ebro",
    "lat": "41.81495",
    "lng": "-1.19429"
  },
  {
    "country": "ES",
    "name": "Alcalà de Xivert",
    "lat": "40.3",
    "lng": "0.23333"
  },
  {
    "country": "ES",
    "name": "Alcaine",
    "lat": "40.95341",
    "lng": "-0.70583"
  },
  {
    "country": "ES",
    "name": "Albornos",
    "lat": "40.83795",
    "lng": "-4.88129"
  },
  {
    "country": "ES",
    "name": "Alborge",
    "lat": "41.33367",
    "lng": "-0.35675"
  },
  {
    "country": "ES",
    "name": "Albons",
    "lat": "42.10389",
    "lng": "3.08433"
  },
  {
    "country": "ES",
    "name": "Albocàsser",
    "lat": "40.35",
    "lng": "0.03333"
  },
  {
    "country": "ES",
    "name": "Albiztur",
    "lat": "43.12933",
    "lng": "-2.13649"
  },
  {
    "country": "ES",
    "name": "Albinyana",
    "lat": "41.25",
    "lng": "1.48333"
  },
  {
    "country": "ES",
    "name": "Albillos",
    "lat": "42.2768",
    "lng": "-3.78908"
  },
  {
    "country": "ES",
    "name": "Albeta",
    "lat": "41.82636",
    "lng": "-1.49936"
  },
  {
    "country": "ES",
    "name": "Albesa",
    "lat": "41.75282",
    "lng": "0.65936"
  },
  {
    "country": "ES",
    "name": "Alberuela de Tubo",
    "lat": "41.90846",
    "lng": "-0.21418"
  },
  {
    "country": "ES",
    "name": "Albero Bajo",
    "lat": "42.0238",
    "lng": "-0.38018"
  },
  {
    "country": "ES",
    "name": "Albero Alto",
    "lat": "42.05031",
    "lng": "-0.3371"
  },
  {
    "country": "ES",
    "name": "Alberite de San Juan",
    "lat": "41.82009",
    "lng": "-1.47063"
  },
  {
    "country": "ES",
    "name": "Alberite",
    "lat": "42.40704",
    "lng": "-2.43894"
  },
  {
    "country": "ES",
    "name": "Albendiego",
    "lat": "41.22742",
    "lng": "-3.05171"
  },
  {
    "country": "ES",
    "name": "Albendea",
    "lat": "40.48751",
    "lng": "-2.41747"
  },
  {
    "country": "ES",
    "name": "Albelda de Iregua",
    "lat": "42.35837",
    "lng": "-2.47278"
  },
  {
    "country": "ES",
    "name": "Albelda",
    "lat": "41.86542",
    "lng": "0.45999"
  },
  {
    "country": "ES",
    "name": "Albarracín",
    "lat": "40.40818",
    "lng": "-1.44375"
  },
  {
    "country": "ES",
    "name": "Albares",
    "lat": "40.3069",
    "lng": "-3.00897"
  },
  {
    "country": "ES",
    "name": "Albalatillo",
    "lat": "41.73527",
    "lng": "-0.15115"
  },
  {
    "country": "ES",
    "name": "Albalate de Zorita",
    "lat": "40.30812",
    "lng": "-2.84267"
  },
  {
    "country": "ES",
    "name": "Albalate de las Nogueras",
    "lat": "40.36614",
    "lng": "-2.27718"
  },
  {
    "country": "ES",
    "name": "Albalate del Arzobispo",
    "lat": "41.12173",
    "lng": "-0.51142"
  },
  {
    "country": "ES",
    "name": "Albalate de Cinca",
    "lat": "41.72521",
    "lng": "0.15244"
  },
  {
    "country": "ES",
    "name": "Alba de Yeltes",
    "lat": "40.6718",
    "lng": "-6.3166"
  },
  {
    "country": "ES",
    "name": "Alba de Tormes",
    "lat": "40.82664",
    "lng": "-5.51237"
  },
  {
    "country": "ES",
    "name": "Alba de Cerrato",
    "lat": "41.81276",
    "lng": "-4.3647"
  },
  {
    "country": "ES",
    "name": "Alba",
    "lat": "40.61825",
    "lng": "-1.34658"
  },
  {
    "country": "ES",
    "name": "Alàs i Cerc",
    "lat": "42.35",
    "lng": "1.51667"
  },
  {
    "country": "ES",
    "name": "Alarilla",
    "lat": "40.84711",
    "lng": "-3.1031"
  },
  {
    "country": "ES",
    "name": "Alar del Rey",
    "lat": "42.66037",
    "lng": "-4.31271"
  },
  {
    "country": "ES",
    "name": "Alarba",
    "lat": "41.20482",
    "lng": "-1.61335"
  },
  {
    "country": "ES",
    "name": "Alaraz",
    "lat": "40.74886",
    "lng": "-5.28781"
  },
  {
    "country": "ES",
    "name": "Alaminos",
    "lat": "40.86303",
    "lng": "-2.72573"
  },
  {
    "country": "ES",
    "name": "Alameda del Valle",
    "lat": "40.9187",
    "lng": "-3.84243"
  },
  {
    "country": "ES",
    "name": "Alagón",
    "lat": "41.76964",
    "lng": "-1.11906"
  },
  {
    "country": "ES",
    "name": "Alaejos",
    "lat": "41.30732",
    "lng": "-5.21567"
  },
  {
    "country": "ES",
    "name": "Aladrén",
    "lat": "41.24917",
    "lng": "-1.15591"
  },
  {
    "country": "ES",
    "name": "Alacón",
    "lat": "41.02575",
    "lng": "-0.69782"
  },
  {
    "country": "ES",
    "name": "Ajamil",
    "lat": "42.16705",
    "lng": "-2.48752"
  },
  {
    "country": "ES",
    "name": "Ajalvir",
    "lat": "40.53205",
    "lng": "-3.47841"
  },
  {
    "country": "ES",
    "name": "Aizarnazabal",
    "lat": "43.25591",
    "lng": "-2.23607"
  },
  {
    "country": "ES",
    "name": "Ainzón",
    "lat": "41.81644",
    "lng": "-1.51995"
  },
  {
    "country": "ES",
    "name": "Aínsa",
    "lat": "42.41547",
    "lng": "0.14008"
  },
  {
    "country": "ES",
    "name": "Aiguaviva",
    "lat": "41.9384",
    "lng": "2.76217"
  },
  {
    "country": "ES",
    "name": "Ahigal de Villarino",
    "lat": "41.15819",
    "lng": "-6.38037"
  },
  {
    "country": "ES",
    "name": "Ahigal de los Aceiteros",
    "lat": "40.87231",
    "lng": "-6.74702"
  },
  {
    "country": "ES",
    "name": "Ahigal",
    "lat": "40.18954",
    "lng": "-6.18815"
  },
  {
    "country": "ES",
    "name": "Agullana",
    "lat": "42.39408",
    "lng": "2.84666"
  },
  {
    "country": "ES",
    "name": "Aguilón",
    "lat": "41.29467",
    "lng": "-1.04634"
  },
  {
    "country": "ES",
    "name": "Aguilar de Segarra",
    "lat": "41.74822",
    "lng": "1.62919"
  },
  {
    "country": "ES",
    "name": "Aguilar del Río Alhama",
    "lat": "41.96212",
    "lng": "-1.9934"
  },
  {
    "country": "ES",
    "name": "Aguilar del Alfambra",
    "lat": "40.59027",
    "lng": "-0.79589"
  },
  {
    "country": "ES",
    "name": "Aguilar de Codés",
    "lat": "42.61249",
    "lng": "-2.38987"
  },
  {
    "country": "ES",
    "name": "Aguilar de Campos",
    "lat": "41.98375",
    "lng": "-5.18117"
  },
  {
    "country": "ES",
    "name": "Aguilar de Campoo",
    "lat": "42.79452",
    "lng": "-4.25892"
  },
  {
    "country": "ES",
    "name": "Aguilar de Bureba",
    "lat": "42.58974",
    "lng": "-3.32913"
  },
  {
    "country": "ES",
    "name": "Aguilafuente",
    "lat": "41.22667",
    "lng": "-4.11185"
  },
  {
    "country": "ES",
    "name": "Agüero",
    "lat": "42.35505",
    "lng": "-0.79324"
  },
  {
    "country": "ES",
    "name": "Aguaviva",
    "lat": "40.82211",
    "lng": "-0.19532"
  },
  {
    "country": "ES",
    "name": "Aguatón",
    "lat": "40.67158",
    "lng": "-1.23475"
  },
  {
    "country": "ES",
    "name": "Aguasal",
    "lat": "41.27495",
    "lng": "-4.6529"
  },
  {
    "country": "ES",
    "name": "Aguarón",
    "lat": "41.33901",
    "lng": "-1.27055"
  },
  {
    "country": "ES",
    "name": "Ágreda",
    "lat": "41.85588",
    "lng": "-1.92244"
  },
  {
    "country": "ES",
    "name": "Agramunt",
    "lat": "41.78686",
    "lng": "1.09683"
  },
  {
    "country": "ES",
    "name": "Agoncillo",
    "lat": "42.44667",
    "lng": "-2.2898"
  },
  {
    "country": "ES",
    "name": "Agón",
    "lat": "41.85574",
    "lng": "-1.45233"
  },
  {
    "country": "ES",
    "name": "Àger",
    "lat": "42",
    "lng": "0.76667"
  },
  {
    "country": "ES",
    "name": "Agallas",
    "lat": "40.44867",
    "lng": "-6.44176"
  },
  {
    "country": "ES",
    "name": "Adzaneta",
    "lat": "40.21616",
    "lng": "-0.17028"
  },
  {
    "country": "ES",
    "name": "Aduna",
    "lat": "43.20375",
    "lng": "-2.05033"
  },
  {
    "country": "ES",
    "name": "Adrados",
    "lat": "41.36816",
    "lng": "-4.11186"
  },
  {
    "country": "ES",
    "name": "Adradas",
    "lat": "41.35098",
    "lng": "-2.47373"
  },
  {
    "country": "ES",
    "name": "Adrada de Pirón",
    "lat": "41.05257",
    "lng": "-4.05107"
  },
  {
    "country": "ES",
    "name": "Adrada de Haza",
    "lat": "41.59454",
    "lng": "-3.82327"
  },
  {
    "country": "ES",
    "name": "Adobes",
    "lat": "40.67584",
    "lng": "-1.67916"
  },
  {
    "country": "ES",
    "name": "Adiós",
    "lat": "42.68635",
    "lng": "-1.73532"
  },
  {
    "country": "ES",
    "name": "Ademuz",
    "lat": "40.06139",
    "lng": "-1.28677"
  },
  {
    "country": "ES",
    "name": "Adanero",
    "lat": "40.94487",
    "lng": "-4.60561"
  },
  {
    "country": "ES",
    "name": "Adalia",
    "lat": "41.64894",
    "lng": "-5.12107"
  },
  {
    "country": "ES",
    "name": "Adahuesca",
    "lat": "42.1461",
    "lng": "-0.00804"
  },
  {
    "country": "ES",
    "name": "Aceituna",
    "lat": "40.15008",
    "lng": "-6.33292"
  },
  {
    "country": "ES",
    "name": "Acebo",
    "lat": "40.20105",
    "lng": "-6.71689"
  },
  {
    "country": "ES",
    "name": "Acebedo",
    "lat": "43.03969",
    "lng": "-5.116"
  },
  {
    "country": "ES",
    "name": "Abusejo",
    "lat": "40.709",
    "lng": "-6.14074"
  },
  {
    "country": "ES",
    "name": "Abrera",
    "lat": "41.51682",
    "lng": "1.901"
  },
  {
    "country": "ES",
    "name": "Ablitas",
    "lat": "41.9745",
    "lng": "-1.64053"
  },
  {
    "country": "ES",
    "name": "Ablanque",
    "lat": "40.89818",
    "lng": "-2.22523"
  },
  {
    "country": "ES",
    "name": "Abizanda",
    "lat": "42.24236",
    "lng": "0.19717"
  },
  {
    "country": "ES",
    "name": "Abiego",
    "lat": "42.12094",
    "lng": "-0.06873"
  },
  {
    "country": "ES",
    "name": "Abia de las Torres",
    "lat": "42.42016",
    "lng": "-4.42131"
  },
  {
    "country": "ES",
    "name": "Abezames",
    "lat": "41.62642",
    "lng": "-5.42577"
  },
  {
    "country": "ES",
    "name": "Abejar",
    "lat": "41.80755",
    "lng": "-2.78407"
  },
  {
    "country": "ES",
    "name": "Abegondo",
    "lat": "43.21667",
    "lng": "-8.28333"
  },
  {
    "country": "ES",
    "name": "Abanto",
    "lat": "41.13751",
    "lng": "-1.69818"
  },
  {
    "country": "ES",
    "name": "Abánades",
    "lat": "40.89261",
    "lng": "-2.48526"
  },
  {
    "country": "ES",
    "name": "Ábalos",
    "lat": "42.57154",
    "lng": "-2.70956"
  },
  {
    "country": "ES",
    "name": "Abaltzisketa",
    "lat": "43.04744",
    "lng": "-2.10532"
  },
  {
    "country": "ES",
    "name": "Abajas",
    "lat": "42.6231",
    "lng": "-3.58086"
  },
  {
    "country": "ES",
    "name": "Abáigar",
    "lat": "42.64823",
    "lng": "-2.14182"
  },
  {
    "country": "ES",
    "name": "Abadín",
    "lat": "43.36667",
    "lng": "-7.48333"
  },
  {
    "country": "ES",
    "name": "Abadiño",
    "lat": "43.1511",
    "lng": "-2.60942"
  },
  {
    "country": "ES",
    "name": "Abadía",
    "lat": "40.25922",
    "lng": "-5.97828"
  },
  {
    "country": "ES",
    "name": "Abades",
    "lat": "40.91646",
    "lng": "-4.26937"
  },
  {
    "country": "ES",
    "name": "Ababuj",
    "lat": "40.54908",
    "lng": "-0.80758"
  },
  {
    "country": "ES",
    "name": "Nou Barris",
    "lat": "41.44163",
    "lng": "2.17727"
  },
  {
    "country": "ES",
    "name": "Yerri",
    "lat": "42.70161",
    "lng": "-1.93806"
  },
  {
    "country": "ES",
    "name": "Blancafort",
    "lat": "41.4374",
    "lng": "1.15983"
  },
  {
    "country": "ES",
    "name": "Pinar de Chamartín",
    "lat": "40.47903",
    "lng": "-3.66836"
  },
  {
    "country": "ES",
    "name": "Las Tablas",
    "lat": "40.50649",
    "lng": "-3.67235"
  },
  {
    "country": "ES",
    "name": "Santa Ponsa",
    "lat": "39.50868",
    "lng": "2.4766"
  },
  {
    "country": "ES",
    "name": "Valdelacalzada",
    "lat": "38.88943",
    "lng": "-6.70029"
  },
  {
    "country": "ES",
    "name": "Areny de Noguera / Arén",
    "lat": "42.25817",
    "lng": "0.72141"
  },
  {
    "country": "ES",
    "name": "Sopeira",
    "lat": "42.31615",
    "lng": "0.74632"
  },
  {
    "country": "ES",
    "name": "el Torricó / Altorricon",
    "lat": "41.8028",
    "lng": "0.4139"
  },
  {
    "country": "ES",
    "name": "Playa del Ingles",
    "lat": "27.7567",
    "lng": "-15.5787"
  },
  {
    "country": "ES",
    "name": "Puerto Rico",
    "lat": "27.78943",
    "lng": "-15.71045"
  },
  {
    "country": "ES",
    "name": "Cala d'Or",
    "lat": "39.3781",
    "lng": "3.23479"
  },
  {
    "country": "ES",
    "name": "Puerto del Carmen",
    "lat": "28.92313",
    "lng": "-13.66579"
  },
  {
    "country": "ES",
    "name": "Magaluf",
    "lat": "39.5111",
    "lng": "2.5353"
  },
  {
    "country": "ES",
    "name": "Can Pastilla",
    "lat": "39.53615",
    "lng": "2.71766"
  },
  {
    "country": "ES",
    "name": "Peguera",
    "lat": "39.53751",
    "lng": "2.44806"
  },
  {
    "country": "ES",
    "name": "Camp de Mar",
    "lat": "39.53827",
    "lng": "2.42386"
  },
  {
    "country": "ES",
    "name": "La Manga del Mar Menor",
    "lat": "37.64129",
    "lng": "-0.71651"
  },
  {
    "country": "ES",
    "name": "Playa de las Américas",
    "lat": "28.06403",
    "lng": "-16.73012"
  },
  {
    "country": "ES",
    "name": "Las Rosas",
    "lat": "28.01539",
    "lng": "-16.65373"
  },
  {
    "country": "ES",
    "name": "Ceuta",
    "lat": "35.88933",
    "lng": "-5.31979"
  },
  {
    "country": "ES",
    "name": "Sopuerta",
    "lat": "43.26239",
    "lng": "-3.15505"
  },
  {
    "country": "ES",
    "name": "Riu de Cerdanya",
    "lat": "42.34541",
    "lng": "1.82631"
  },
  {
    "country": "ES",
    "name": "Urús",
    "lat": "42.35131",
    "lng": "1.85343"
  },
  {
    "country": "ES",
    "name": "el Pont de Bar",
    "lat": "42.3711",
    "lng": "1.60538"
  },
  {
    "country": "ES",
    "name": "Cabanes",
    "lat": "42.30805",
    "lng": "2.97766"
  },
  {
    "country": "ES",
    "name": "Sant Cristòfol de les Fonts",
    "lat": "42.16964",
    "lng": "2.49943"
  },
  {
    "country": "ES",
    "name": "Alquerías del Niño Perdido",
    "lat": "39.89466",
    "lng": "-0.12943"
  },
  {
    "country": "ES",
    "name": "Port d'Alcúdia",
    "lat": "39.84182",
    "lng": "3.13291"
  },
  {
    "country": "ES",
    "name": "Moncloa-Aravaca",
    "lat": "40.43547",
    "lng": "-3.7317"
  },
  {
    "country": "ES",
    "name": "Eixample",
    "lat": "41.38896",
    "lng": "2.16179"
  },
  {
    "country": "ES",
    "name": "Les Corts",
    "lat": "41.38712",
    "lng": "2.13007"
  },
  {
    "country": "ES",
    "name": "Sarrià-Sant Gervasi",
    "lat": "41.40104",
    "lng": "2.1394"
  },
  {
    "country": "ES",
    "name": "Horta-Guinardó",
    "lat": "41.41849",
    "lng": "2.1677"
  },
  {
    "country": "ES",
    "name": "Sants-Montjuïc",
    "lat": "41.37263",
    "lng": "2.1546"
  },
  {
    "country": "ES",
    "name": "Sant Martí",
    "lat": "41.41814",
    "lng": "2.19933"
  },
  {
    "country": "ES",
    "name": "Ciutat Vella",
    "lat": "41.38022",
    "lng": "2.17319"
  },
  {
    "country": "ES",
    "name": "Retamar",
    "lat": "36.8332",
    "lng": "-2.31597"
  },
  {
    "country": "ES",
    "name": "S'Agaró",
    "lat": "41.79368",
    "lng": "3.05364"
  },
  {
    "country": "ES",
    "name": "Benalup-Casas Viejas",
    "lat": "36.34375",
    "lng": "-5.8128"
  },
  {
    "country": "ES",
    "name": "Vecindario",
    "lat": "27.84636",
    "lng": "-15.44455"
  },
  {
    "country": "ES",
    "name": "Ballesteros de Calatrava",
    "lat": "38.8346",
    "lng": "-3.9447"
  },
  {
    "country": "ES",
    "name": "Arganzuela",
    "lat": "40.40021",
    "lng": "-3.69618"
  },
  {
    "country": "ES",
    "name": "San Blas-Canillejas",
    "lat": "40.43893",
    "lng": "-3.61537"
  },
  {
    "country": "ES",
    "name": "Latina",
    "lat": "40.38897",
    "lng": "-3.74569"
  },
  {
    "country": "ES",
    "name": "Usera",
    "lat": "40.38866",
    "lng": "-3.70035"
  },
  {
    "country": "ES",
    "name": "Salamanca",
    "lat": "40.42972",
    "lng": "-3.67975"
  },
  {
    "country": "ES",
    "name": "Chamberí",
    "lat": "40.43404",
    "lng": "-3.70379"
  },
  {
    "country": "ES",
    "name": "Carabanchel",
    "lat": "40.39094",
    "lng": "-3.7242"
  },
  {
    "country": "ES",
    "name": "City Center",
    "lat": "40.41831",
    "lng": "-3.70275"
  },
  {
    "country": "ES",
    "name": "Retiro",
    "lat": "40.41317",
    "lng": "-3.68307"
  },
  {
    "country": "ES",
    "name": "Barri Gòtic",
    "lat": "41.38364",
    "lng": "2.17628"
  },
  {
    "country": "ES",
    "name": "Forcarei",
    "lat": "42.59233",
    "lng": "-8.3509"
  },
  {
    "country": "ES",
    "name": "Poble Sec",
    "lat": "41.37452",
    "lng": "2.16326"
  },
  {
    "country": "ES",
    "name": "Hostafrancs",
    "lat": "41.37694",
    "lng": "2.14306"
  },
  {
    "country": "ES",
    "name": "La Bordeta",
    "lat": "41.37397",
    "lng": "2.14377"
  },
  {
    "country": "ES",
    "name": "La Bonanova",
    "lat": "41.40585",
    "lng": "2.13243"
  },
  {
    "country": "ES",
    "name": "Las Tres Torres",
    "lat": "41.39989",
    "lng": "2.12931"
  },
  {
    "country": "ES",
    "name": "Pedralbes",
    "lat": "41.39046",
    "lng": "2.11019"
  },
  {
    "country": "ES",
    "name": "el Coll",
    "lat": "41.41721",
    "lng": "2.14723"
  },
  {
    "country": "ES",
    "name": "el Poblenou",
    "lat": "41.40392",
    "lng": "2.20413"
  },
  {
    "country": "ES",
    "name": "El Carmel",
    "lat": "41.41758",
    "lng": "2.15914"
  },
  {
    "country": "ES",
    "name": "Pego",
    "lat": "38.84305",
    "lng": "-0.11707"
  },
  {
    "country": "ES",
    "name": "l'Alfàs del Pi",
    "lat": "38.58055",
    "lng": "-0.10321"
  },
  {
    "country": "ES",
    "name": "Deltebre",
    "lat": "40.71944",
    "lng": "0.70835"
  },
  {
    "country": "ES",
    "name": "Sedella",
    "lat": "36.86232",
    "lng": "-4.03314"
  },
  {
    "country": "ES",
    "name": "Las Gabias",
    "lat": "37.13548",
    "lng": "-3.67029"
  },
  {
    "country": "ES",
    "name": "San José del Valle",
    "lat": "36.60554",
    "lng": "-5.79895"
  },
  {
    "country": "ES",
    "name": "Camarles",
    "lat": "40.78169",
    "lng": "0.65509"
  },
  {
    "country": "ES",
    "name": "Vall de Gallinera",
    "lat": "38.82313",
    "lng": "-0.2417"
  },
  {
    "country": "ES",
    "name": "Delicias",
    "lat": "41.64928",
    "lng": "-0.90757"
  },
  {
    "country": "ES",
    "name": "Almozara",
    "lat": "41.66124",
    "lng": "-0.90169"
  },
  {
    "country": "ES",
    "name": "Montecanal",
    "lat": "41.62965",
    "lng": "-0.93873"
  },
  {
    "country": "ES",
    "name": "Oliver-Valdefierro",
    "lat": "41.64454",
    "lng": "-0.93349"
  },
  {
    "country": "ES",
    "name": "Santutxu",
    "lat": "43.25347",
    "lng": "-2.9161"
  },
  {
    "country": "ES",
    "name": "Fort Pienc",
    "lat": "41.39458",
    "lng": "2.17946"
  },
  {
    "country": "ES",
    "name": "Dreta de l'Eixample",
    "lat": "41.39606",
    "lng": "2.16688"
  },
  {
    "country": "ES",
    "name": "Vallcarca",
    "lat": "41.41209",
    "lng": "2.14394"
  },
  {
    "country": "ES",
    "name": "Sagrada Família",
    "lat": "41.40408",
    "lng": "2.17332"
  },
  {
    "country": "ES",
    "name": "Diagonal Mar",
    "lat": "41.40897",
    "lng": "2.21615"
  },
  {
    "country": "ES",
    "name": "Sant Martí de Provençals",
    "lat": "41.4202",
    "lng": "2.19632"
  },
  {
    "country": "ES",
    "name": "Sondika",
    "lat": "43.3002",
    "lng": "-2.92442"
  },
  {
    "country": "ES",
    "name": "El Cotillo",
    "lat": "28.68264",
    "lng": "-14.00637"
  },
  {
    "country": "ES",
    "name": "Los Gigantes",
    "lat": "28.24361",
    "lng": "-16.84153"
  },
  {
    "country": "ES",
    "name": "Los Realejos",
    "lat": "28.38487",
    "lng": "-16.58275"
  },
  {
    "country": "ES",
    "name": "Sant Guim de Freixenet",
    "lat": "41.65573",
    "lng": "1.42024"
  },
  {
    "country": "ES",
    "name": "Sant Joan de Mediona",
    "lat": "41.47862",
    "lng": "1.61164"
  },
  {
    "country": "ES",
    "name": "Pasaia",
    "lat": "43.3253",
    "lng": "-1.92707"
  },
  {
    "country": "ES",
    "name": "El entrego",
    "lat": "43.28752",
    "lng": "-5.638"
  },
  {
    "country": "ES",
    "name": "El Toro",
    "lat": "39.48477",
    "lng": "2.48222"
  },
  {
    "country": "ES",
    "name": "Navas de San Juan",
    "lat": "38.18382",
    "lng": "-3.31598"
  },
  {
    "country": "ES",
    "name": "Basauri",
    "lat": "43.2397",
    "lng": "-2.8858"
  },
  {
    "country": "ES",
    "name": "Castrillón",
    "lat": "43.54793",
    "lng": "-5.99381"
  },
  {
    "country": "ES",
    "name": "Novés",
    "lat": "40.04746",
    "lng": "-4.27471"
  },
  {
    "country": "ES",
    "name": "Sahún",
    "lat": "42.5759",
    "lng": "0.46546"
  },
  {
    "country": "ES",
    "name": "Taberno",
    "lat": "37.4688",
    "lng": "-2.07736"
  },
  {
    "country": "ES",
    "name": "Llefià",
    "lat": "41.43806",
    "lng": "2.2195"
  },
  {
    "country": "ES",
    "name": "Corvera de Asturias",
    "lat": "43.53554",
    "lng": "-5.88893"
  },
  {
    "country": "ES",
    "name": "San Isidro",
    "lat": "38.17249",
    "lng": "-0.83874"
  },
  {
    "country": "ES",
    "name": "Vega del Codorno",
    "lat": "40.42457",
    "lng": "-1.91312"
  },
  {
    "country": "ES",
    "name": "Barreiros",
    "lat": "43.53321",
    "lng": "-7.23342"
  },
  {
    "country": "ES",
    "name": "els Poblets",
    "lat": "38.85381",
    "lng": "0.02103"
  },
  {
    "country": "ES",
    "name": "Navarredonda de Gredos",
    "lat": "40.36136",
    "lng": "-5.13268"
  },
  {
    "country": "ES",
    "name": "Tres Cantos",
    "lat": "40.60092",
    "lng": "-3.70806"
  },
  {
    "country": "ES",
    "name": "Castellar del Riu",
    "lat": "42.12299",
    "lng": "1.77378"
  },
  {
    "country": "ES",
    "name": "Senterada",
    "lat": "42.32549",
    "lng": "0.93641"
  },
  {
    "country": "ES",
    "name": "Mendexa",
    "lat": "43.3459",
    "lng": "-2.4842"
  },
  {
    "country": "ES",
    "name": "Capolat",
    "lat": "42.0772",
    "lng": "1.75352"
  },
  {
    "country": "ES",
    "name": "Totalán",
    "lat": "36.76526",
    "lng": "-4.29707"
  },
  {
    "country": "ES",
    "name": "Jete",
    "lat": "36.79691",
    "lng": "-3.6672"
  },
  {
    "country": "ES",
    "name": "Atanzón",
    "lat": "40.66697",
    "lng": "-2.99686"
  },
  {
    "country": "ES",
    "name": "Etxebarria",
    "lat": "43.25414",
    "lng": "-2.47776"
  },
  {
    "country": "ES",
    "name": "Bakio",
    "lat": "43.42917",
    "lng": "-2.80881"
  },
  {
    "country": "ES",
    "name": "Iturrama",
    "lat": "42.80847",
    "lng": "-1.65825"
  },
  {
    "country": "ES",
    "name": "Ermitagaña",
    "lat": "42.81084",
    "lng": "-1.66409"
  },
  {
    "country": "ES",
    "name": "Primer Ensanche",
    "lat": "42.81483",
    "lng": "-1.64898"
  },
  {
    "country": "ES",
    "name": "Segundo Ensanche",
    "lat": "42.8139",
    "lng": "-1.64295"
  },
  {
    "country": "ES",
    "name": "Pueblonuevo de Miramontes",
    "lat": "40.0606",
    "lng": "-5.37832"
  },
  {
    "country": "ES",
    "name": "Les Franqueses del Vallès",
    "lat": "41.61929",
    "lng": "2.29829"
  },
  {
    "country": "ES",
    "name": "San Tirso de Abres",
    "lat": "43.40873",
    "lng": "-7.14317"
  },
  {
    "country": "ES",
    "name": "Santiago de Alcántara",
    "lat": "39.60661",
    "lng": "-7.24402"
  },
  {
    "country": "ES",
    "name": "Fuencarral-El Pardo",
    "lat": "40.4984",
    "lng": "-3.7314"
  },
  {
    "country": "ES",
    "name": "Villa de Vallecas",
    "lat": "40.36695",
    "lng": "-3.60146"
  },
  {
    "country": "ES",
    "name": "Moriles",
    "lat": "37.4367",
    "lng": "-4.60761"
  },
  {
    "country": "ES",
    "name": "Natahoyo",
    "lat": "43.54035",
    "lng": "-5.68233"
  },
  {
    "country": "ES",
    "name": "Castroviejo",
    "lat": "42.32938",
    "lng": "-2.66122"
  },
  {
    "country": "ES",
    "name": "Daroca de Rioja",
    "lat": "42.37115",
    "lng": "-2.58187"
  },
  {
    "country": "ES",
    "name": "Son Ferrer",
    "lat": "39.49666",
    "lng": "2.50102"
  },
  {
    "country": "ES",
    "name": "Liendo",
    "lat": "43.4008",
    "lng": "-3.37029"
  },
  {
    "country": "ES",
    "name": "Villanova",
    "lat": "42.54702",
    "lng": "0.46183"
  },
  {
    "country": "ES",
    "name": "Gordexola",
    "lat": "43.1786",
    "lng": "-3.076"
  },
  {
    "country": "ES",
    "name": "Liérganes",
    "lat": "43.34614",
    "lng": "-3.74668"
  },
  {
    "country": "ES",
    "name": "Sant Julià de Ramis",
    "lat": "42.02932",
    "lng": "2.85338"
  },
  {
    "country": "ES",
    "name": "Olivenza",
    "lat": "38.68269",
    "lng": "-7.10046"
  },
  {
    "country": "ES",
    "name": "Andosilla",
    "lat": "42.37729",
    "lng": "-1.94267"
  },
  {
    "country": "ES",
    "name": "Muxika",
    "lat": "43.28905",
    "lng": "-2.68937"
  },
  {
    "country": "ES",
    "name": "Costacabana",
    "lat": "36.83807",
    "lng": "-2.38111"
  },
  {
    "country": "ES",
    "name": "Castellnou de Bages",
    "lat": "41.83444",
    "lng": "1.83721"
  },
  {
    "country": "ES",
    "name": "La Pobla de Farnals",
    "lat": "39.56571",
    "lng": "-0.28425"
  },
  {
    "country": "ES",
    "name": "Callús",
    "lat": "41.78146",
    "lng": "1.78401"
  },
  {
    "country": "ES",
    "name": "Ubide",
    "lat": "43.02396",
    "lng": "-2.68759"
  },
  {
    "country": "ES",
    "name": "Valdezorras",
    "lat": "37.42939",
    "lng": "-5.92629"
  },
  {
    "country": "ES",
    "name": "La Gangosa Vistasol",
    "lat": "36.80581",
    "lng": "-2.62174"
  },
  {
    "country": "ES",
    "name": "Balanegra",
    "lat": "36.74886",
    "lng": "-2.9097"
  },
  {
    "country": "ES",
    "name": "Tiétar",
    "lat": "40.02945",
    "lng": "-5.48192"
  },
  {
    "country": "ES",
    "name": "Montbau",
    "lat": "41.43529",
    "lng": "2.13781"
  },
  {
    "country": "ES",
    "name": "Sant Genís dels Agudells",
    "lat": "41.42541",
    "lng": "2.13019"
  },
  {
    "country": "ES",
    "name": "Vallvidrera, el Tibidabo i les Planes",
    "lat": "41.4197",
    "lng": "2.08911"
  },
  {
    "country": "ES",
    "name": "la Marina del Prat Vermell",
    "lat": "41.33937",
    "lng": "2.14262"
  },
  {
    "country": "ES",
    "name": "Sarrià",
    "lat": "41.40269",
    "lng": "2.1162"
  },
  {
    "country": "ES",
    "name": "l'Antiga Esquerra de l'Eixample",
    "lat": "41.38939",
    "lng": "2.15517"
  },
  {
    "country": "ES",
    "name": "el Baix Guinardó",
    "lat": "41.41175",
    "lng": "2.16784"
  },
  {
    "country": "ES",
    "name": "el Parc i la Llacuna del Poblenou",
    "lat": "41.3986",
    "lng": "2.1903"
  },
  {
    "country": "ES",
    "name": "la Prosperitat",
    "lat": "41.44269",
    "lng": "2.182"
  },
  {
    "country": "ES",
    "name": "el Putxet i el Farró",
    "lat": "41.40693",
    "lng": "2.14392"
  },
  {
    "country": "ES",
    "name": "Provenals del Poblenou",
    "lat": "41.41109",
    "lng": "2.2026"
  },
  {
    "country": "ES",
    "name": "Sant Antoni",
    "lat": "41.37857",
    "lng": "2.15937"
  },
  {
    "country": "ES",
    "name": "Can Baró",
    "lat": "41.41677",
    "lng": "2.16242"
  },
  {
    "country": "ES",
    "name": "Baró de Viver",
    "lat": "41.44584",
    "lng": "2.19902"
  },
  {
    "country": "ES",
    "name": "Vallbona",
    "lat": "41.46341",
    "lng": "2.18417"
  },
  {
    "country": "ES",
    "name": "la Vila de Gràcia",
    "lat": "41.40315",
    "lng": "2.15687"
  },
  {
    "country": "ES",
    "name": "la Nova Esquerra de l'Eixample",
    "lat": "41.38309",
    "lng": "2.149"
  },
  {
    "country": "ES",
    "name": "Porta",
    "lat": "41.4349",
    "lng": "2.17883"
  },
  {
    "country": "ES",
    "name": "la Font de la Guatlla",
    "lat": "41.36978",
    "lng": "2.14486"
  },
  {
    "country": "ES",
    "name": "Sants - Badal",
    "lat": "41.37471",
    "lng": "2.12775"
  },
  {
    "country": "ES",
    "name": "la Maternitat i Sant Ramon",
    "lat": "41.38125",
    "lng": "2.11744"
  },
  {
    "country": "ES",
    "name": "Sant Gervasi - Galvany",
    "lat": "41.3975",
    "lng": "2.14301"
  },
  {
    "country": "ES",
    "name": "Verdun",
    "lat": "41.44273",
    "lng": "2.17564"
  },
  {
    "country": "ES",
    "name": "el Camp d'en Grassot i Gràcia Nova",
    "lat": "41.40634",
    "lng": "2.16503"
  },
  {
    "country": "ES",
    "name": "Can Peguera",
    "lat": "41.43487",
    "lng": "2.16646"
  },
  {
    "country": "ES",
    "name": "la Marina de Port",
    "lat": "41.36",
    "lng": "2.13986"
  },
  {
    "country": "ES",
    "name": "Vilapicina i la Torre Llobeta",
    "lat": "41.42861",
    "lng": "2.1741"
  },
  {
    "country": "ES",
    "name": "el Camp de l'Arpa del Clot",
    "lat": "41.41204",
    "lng": "2.18247"
  },
  {
    "country": "ES",
    "name": "el Bon Pastor",
    "lat": "41.437",
    "lng": "2.20182"
  },
  {
    "country": "ES",
    "name": "Canyelles",
    "lat": "41.44509",
    "lng": "2.16346"
  },
  {
    "country": "ES",
    "name": "la Salut",
    "lat": "41.41243",
    "lng": "2.15437"
  },
  {
    "country": "ES",
    "name": "la Font d'en Fargues",
    "lat": "41.42461",
    "lng": "2.16526"
  },
  {
    "country": "ES",
    "name": "el Congrés i els Indians",
    "lat": "41.4246",
    "lng": "2.18086"
  },
  {
    "country": "ES",
    "name": "la Teixonera",
    "lat": "41.42307",
    "lng": "2.14654"
  },
  {
    "country": "ES",
    "name": "la Vall d'Hebron",
    "lat": "41.43038",
    "lng": "2.1483"
  },
  {
    "country": "ES",
    "name": "la Trinitat Nova",
    "lat": "41.45051",
    "lng": "2.18481"
  },
  {
    "country": "ES",
    "name": "Navas",
    "lat": "41.41803",
    "lng": "2.18596"
  },
  {
    "country": "ES",
    "name": "la Guineueta",
    "lat": "41.43884",
    "lng": "2.16893"
  },
  {
    "country": "ES",
    "name": "les Roquetes",
    "lat": "41.44809",
    "lng": "2.17519"
  },
  {
    "country": "ES",
    "name": "Ciutat Meridiana",
    "lat": "41.46119",
    "lng": "2.17494"
  },
  {
    "country": "ES",
    "name": "la Trinitat Vella",
    "lat": "41.45166",
    "lng": "2.19289"
  },
  {
    "country": "ES",
    "name": "la Vila Olímpica del Poblenou",
    "lat": "41.39074",
    "lng": "2.19679"
  },
  {
    "country": "ES",
    "name": "la Verneda i la Pau",
    "lat": "41.42399",
    "lng": "2.20304"
  },
  {
    "country": "ES",
    "name": "el Turó de la Peira",
    "lat": "41.43232",
    "lng": "2.16895"
  },
  {
    "country": "ES",
    "name": "el Besòs i el Maresme",
    "lat": "41.41309",
    "lng": "2.21736"
  },
  {
    "country": "ES",
    "name": "el Guinardó",
    "lat": "41.41885",
    "lng": "2.17364"
  },
  {
    "country": "ES",
    "name": "Torre Baró",
    "lat": "41.4549",
    "lng": "2.17418"
  },
  {
    "country": "ES",
    "name": "Barri de Sant Andreu",
    "lat": "41.43693",
    "lng": "2.19022"
  },
  {
    "country": "ES",
    "name": "Barri de les Corts",
    "lat": "41.38697",
    "lng": "2.13472"
  },
  {
    "country": "ES",
    "name": "Sarriguren",
    "lat": "42.81292",
    "lng": "-1.59815"
  },
  {
    "country": "ES",
    "name": "Rayaces",
    "lat": "41.92137",
    "lng": "-4.71401"
  },
  {
    "country": "ES",
    "name": "San Enrique de Guadiaro",
    "lat": "36.30475",
    "lng": "-5.29095"
  },
  {
    "country": "ES",
    "name": "Asin",
    "lat": "42.28314",
    "lng": "-1.04657"
  },
  {
    "country": "ES",
    "name": "Puente la Reina de Jaca",
    "lat": "42.55908",
    "lng": "-0.78759"
  },
  {
    "country": "ES",
    "name": "Albentosa",
    "lat": "40.10282",
    "lng": "-0.76764"
  },
  {
    "country": "ES",
    "name": "Vilarnaz",
    "lat": "42.4005",
    "lng": "-7.86306"
  },
  {
    "country": "ES",
    "name": "Beranuy",
    "lat": "42.36652",
    "lng": "0.59418"
  },
  {
    "country": "ET",
    "name": "Ziway",
    "lat": "7.93333",
    "lng": "38.71667"
  },
  {
    "country": "ET",
    "name": "Yirga ‘Alem",
    "lat": "6.75",
    "lng": "38.41667"
  },
  {
    "country": "ET",
    "name": "Yabēlo",
    "lat": "4.88333",
    "lng": "38.08333"
  },
  {
    "country": "ET",
    "name": "Werota",
    "lat": "11.91667",
    "lng": "37.7"
  },
  {
    "country": "ET",
    "name": "Were Īlu",
    "lat": "10.58964",
    "lng": "39.43767"
  },
  {
    "country": "ET",
    "name": "Wenjī",
    "lat": "8.45",
    "lng": "39.28333"
  },
  {
    "country": "ET",
    "name": "Wendo",
    "lat": "6.6",
    "lng": "38.41667"
  },
  {
    "country": "ET",
    "name": "Turmi",
    "lat": "4.96667",
    "lng": "36.48333"
  },
  {
    "country": "ET",
    "name": "Tulu Bolo",
    "lat": "8.66667",
    "lng": "38.21667"
  },
  {
    "country": "ET",
    "name": "Tippi",
    "lat": "7.2",
    "lng": "35.45"
  },
  {
    "country": "ET",
    "name": "Sirre",
    "lat": "8.31667",
    "lng": "39.48333"
  },
  {
    "country": "ET",
    "name": "Shashemenē",
    "lat": "7.2",
    "lng": "38.6"
  },
  {
    "country": "ET",
    "name": "Shambu",
    "lat": "9.56667",
    "lng": "37.1"
  },
  {
    "country": "ET",
    "name": "Shakiso",
    "lat": "5.76494",
    "lng": "38.91006"
  },
  {
    "country": "ET",
    "name": "Sendafa",
    "lat": "9.15203",
    "lng": "39.02335"
  },
  {
    "country": "ET",
    "name": "Sebeta",
    "lat": "8.91667",
    "lng": "38.61667"
  },
  {
    "country": "ET",
    "name": "Robīt",
    "lat": "12.01667",
    "lng": "39.63333"
  },
  {
    "country": "ET",
    "name": "Nejo",
    "lat": "9.5",
    "lng": "35.5"
  },
  {
    "country": "ET",
    "name": "Nazrēt",
    "lat": "8.55",
    "lng": "39.26667"
  },
  {
    "country": "ET",
    "name": "Mojo",
    "lat": "8.58679",
    "lng": "39.12111"
  },
  {
    "country": "ET",
    "name": "Mīzan Teferī",
    "lat": "6.99865",
    "lng": "35.58879"
  },
  {
    "country": "ET",
    "name": "Metu",
    "lat": "8.3",
    "lng": "35.58333"
  },
  {
    "country": "ET",
    "name": "Metahāra",
    "lat": "8.9",
    "lng": "39.91667"
  },
  {
    "country": "ET",
    "name": "Mendī",
    "lat": "9.8",
    "lng": "35.1"
  },
  {
    "country": "ET",
    "name": "Mek'ele",
    "lat": "13.49667",
    "lng": "39.47528"
  },
  {
    "country": "ET",
    "name": "Mēga",
    "lat": "4.05",
    "lng": "38.3"
  },
  {
    "country": "ET",
    "name": "Maych’ew",
    "lat": "12.7875",
    "lng": "39.54222"
  },
  {
    "country": "ET",
    "name": "Lobuni",
    "lat": "4.83333",
    "lng": "36.1"
  },
  {
    "country": "ET",
    "name": "Leku",
    "lat": "6.87309",
    "lng": "38.44425"
  },
  {
    "country": "ET",
    "name": "Lalībela",
    "lat": "12.03219",
    "lng": "39.04756"
  },
  {
    "country": "ET",
    "name": "Korem",
    "lat": "12.50583",
    "lng": "39.52278"
  },
  {
    "country": "ET",
    "name": "Konso",
    "lat": "5.25",
    "lng": "37.48333"
  },
  {
    "country": "ET",
    "name": "K’olīto",
    "lat": "7.31667",
    "lng": "38.08333"
  },
  {
    "country": "ET",
    "name": "Kofelē",
    "lat": "7.06667",
    "lng": "38.78333"
  },
  {
    "country": "ET",
    "name": "Kibre Mengist",
    "lat": "5.88333",
    "lng": "38.98333"
  },
  {
    "country": "ET",
    "name": "Kemisē",
    "lat": "10.71668",
    "lng": "39.86997"
  },
  {
    "country": "ET",
    "name": "Kombolcha",
    "lat": "11.08155",
    "lng": "39.74339"
  },
  {
    "country": "ET",
    "name": "Jinka",
    "lat": "5.65",
    "lng": "36.65"
  },
  {
    "country": "ET",
    "name": "Jimma",
    "lat": "7.67344",
    "lng": "36.83441"
  },
  {
    "country": "ET",
    "name": "Jijiga",
    "lat": "9.35",
    "lng": "42.8"
  },
  {
    "country": "ET",
    "name": "Inda Silasē",
    "lat": "14.10307",
    "lng": "38.28289"
  },
  {
    "country": "ET",
    "name": "Huruta",
    "lat": "8.15",
    "lng": "39.35"
  },
  {
    "country": "ET",
    "name": "Hosa’ina",
    "lat": "7.54978",
    "lng": "37.85374"
  },
  {
    "country": "ET",
    "name": "Hīrna",
    "lat": "9.21667",
    "lng": "41.1"
  },
  {
    "country": "ET",
    "name": "Harar",
    "lat": "9.31387",
    "lng": "42.11815"
  },
  {
    "country": "ET",
    "name": "Hāgere Selam",
    "lat": "6.48333",
    "lng": "38.51667"
  },
  {
    "country": "ET",
    "name": "Hāgere Hiywet",
    "lat": "8.98333",
    "lng": "37.85"
  },
  {
    "country": "ET",
    "name": "Guder",
    "lat": "8.96667",
    "lng": "37.76667"
  },
  {
    "country": "ET",
    "name": "Gorē",
    "lat": "8.15",
    "lng": "35.53333"
  },
  {
    "country": "ET",
    "name": "Gondar",
    "lat": "12.6",
    "lng": "37.46667"
  },
  {
    "country": "ET",
    "name": "Goba",
    "lat": "7.01667",
    "lng": "39.98333"
  },
  {
    "country": "ET",
    "name": "Waliso",
    "lat": "8.53417",
    "lng": "37.96515"
  },
  {
    "country": "ET",
    "name": "Ginir",
    "lat": "7.13952",
    "lng": "40.71083"
  },
  {
    "country": "ET",
    "name": "Gimbi",
    "lat": "9.17031",
    "lng": "35.83491"
  },
  {
    "country": "ET",
    "name": "Gīdolē",
    "lat": "5.65",
    "lng": "37.36667"
  },
  {
    "country": "ET",
    "name": "Gewanē",
    "lat": "10.16658",
    "lng": "40.64689"
  },
  {
    "country": "ET",
    "name": "Genet",
    "lat": "9.06667",
    "lng": "38.5"
  },
  {
    "country": "ET",
    "name": "Gelemso",
    "lat": "8.81667",
    "lng": "40.51667"
  },
  {
    "country": "ET",
    "name": "Gēdo",
    "lat": "9.01667",
    "lng": "37.45"
  },
  {
    "country": "ET",
    "name": "Gebre Guracha",
    "lat": "9.8",
    "lng": "38.4"
  },
  {
    "country": "ET",
    "name": "Gambēla",
    "lat": "8.25",
    "lng": "34.58333"
  },
  {
    "country": "ET",
    "name": "Finote Selam",
    "lat": "10.7",
    "lng": "37.26667"
  },
  {
    "country": "ET",
    "name": "Fichē",
    "lat": "9.8",
    "lng": "38.73333"
  },
  {
    "country": "ET",
    "name": "Felege Neway",
    "lat": "6.3",
    "lng": "36.88333"
  },
  {
    "country": "ET",
    "name": "Dubti",
    "lat": "11.73292",
    "lng": "41.082"
  },
  {
    "country": "ET",
    "name": "Dodola",
    "lat": "6.98333",
    "lng": "39.18333"
  },
  {
    "country": "ET",
    "name": "Dire Dawa",
    "lat": "9.59306",
    "lng": "41.86611"
  },
  {
    "country": "ET",
    "name": "Dīla",
    "lat": "6.41667",
    "lng": "38.31667"
  },
  {
    "country": "ET",
    "name": "Desē",
    "lat": "11.13333",
    "lng": "39.63333"
  },
  {
    "country": "ET",
    "name": "Dembī Dolo",
    "lat": "8.53333",
    "lng": "34.8"
  },
  {
    "country": "ET",
    "name": "Dejen",
    "lat": "10.16667",
    "lng": "38.13333"
  },
  {
    "country": "ET",
    "name": "Deder",
    "lat": "9.31168",
    "lng": "41.44301"
  },
  {
    "country": "ET",
    "name": "Bishoftu",
    "lat": "8.75225",
    "lng": "38.97846"
  },
  {
    "country": "ET",
    "name": "Debre Werk’",
    "lat": "10.66667",
    "lng": "38.16667"
  },
  {
    "country": "ET",
    "name": "Debre Tabor",
    "lat": "11.85",
    "lng": "38.01667"
  },
  {
    "country": "ET",
    "name": "Debre Sīna",
    "lat": "9.84752",
    "lng": "39.76027"
  },
  {
    "country": "ET",
    "name": "Debre Mark’os",
    "lat": "10.35",
    "lng": "37.73333"
  },
  {
    "country": "ET",
    "name": "Debre Birhan",
    "lat": "9.67954",
    "lng": "39.53262"
  },
  {
    "country": "ET",
    "name": "Debark’",
    "lat": "13.15611",
    "lng": "37.89806"
  },
  {
    "country": "ET",
    "name": "Dabat",
    "lat": "12.98417",
    "lng": "37.765"
  },
  {
    "country": "ET",
    "name": "Butajīra",
    "lat": "8.11667",
    "lng": "38.36667"
  },
  {
    "country": "ET",
    "name": "Burē",
    "lat": "10.7",
    "lng": "37.06667"
  },
  {
    "country": "ET",
    "name": "Bonga",
    "lat": "7.28333",
    "lng": "36.23333"
  },
  {
    "country": "ET",
    "name": "Bodītī",
    "lat": "6.96667",
    "lng": "37.86667"
  },
  {
    "country": "ET",
    "name": "Bichena",
    "lat": "10.45",
    "lng": "38.2"
  },
  {
    "country": "ET",
    "name": "Bedēsa",
    "lat": "8.9",
    "lng": "40.78333"
  },
  {
    "country": "ET",
    "name": "Bedelē",
    "lat": "8.456",
    "lng": "36.35302"
  },
  {
    "country": "ET",
    "name": "Batī",
    "lat": "11.19152",
    "lng": "40.01675"
  },
  {
    "country": "ET",
    "name": "Bako",
    "lat": "5.78333",
    "lng": "36.56667"
  },
  {
    "country": "ET",
    "name": "Bahir Dar",
    "lat": "11.59364",
    "lng": "37.39077"
  },
  {
    "country": "ET",
    "name": "Āwash",
    "lat": "8.98333",
    "lng": "40.16667"
  },
  {
    "country": "ET",
    "name": "Hawassa",
    "lat": "7.06205",
    "lng": "38.47635"
  },
  {
    "country": "ET",
    "name": "Āsosa",
    "lat": "10.06667",
    "lng": "34.53333"
  },
  {
    "country": "ET",
    "name": "Āsbe Teferī",
    "lat": "9.08569",
    "lng": "40.86708"
  },
  {
    "country": "ET",
    "name": "Asaita",
    "lat": "11.56838",
    "lng": "41.43869"
  },
  {
    "country": "ET",
    "name": "Āsasa",
    "lat": "7.1",
    "lng": "39.2"
  },
  {
    "country": "ET",
    "name": "Āreka",
    "lat": "7.06667",
    "lng": "37.7"
  },
  {
    "country": "ET",
    "name": "Arba Minch",
    "lat": "6.03333",
    "lng": "37.55"
  },
  {
    "country": "ET",
    "name": "Axum",
    "lat": "14.12109",
    "lng": "38.72337"
  },
  {
    "country": "ET",
    "name": "Hagere Maryam",
    "lat": "5.63418",
    "lng": "38.23603"
  },
  {
    "country": "ET",
    "name": "Āgaro",
    "lat": "7.85",
    "lng": "36.65"
  },
  {
    "country": "ET",
    "name": "Ādīs Zemen",
    "lat": "12.11667",
    "lng": "37.78333"
  },
  {
    "country": "ET",
    "name": "Ādīs ‘Alem",
    "lat": "9.03333",
    "lng": "38.4"
  },
  {
    "country": "ET",
    "name": "Addis Ababa",
    "lat": "9.02497",
    "lng": "38.74689"
  },
  {
    "country": "ET",
    "name": "Ādīgrat",
    "lat": "14.277",
    "lng": "39.462"
  },
  {
    "country": "ET",
    "name": "Addiet Canna",
    "lat": "11.26667",
    "lng": "37.48333"
  },
  {
    "country": "ET",
    "name": "Abomsa",
    "lat": "9.98333",
    "lng": "39.98333"
  },
  {
    "country": "ET",
    "name": "Semera",
    "lat": "11.79342",
    "lng": "41.00578"
  },
  {
    "country": "ET",
    "name": "Sodo",
    "lat": "6.86",
    "lng": "37.76159"
  },
  {
    "country": "FI",
    "name": "Ypäjä",
    "lat": "60.8",
    "lng": "23.28333"
  },
  {
    "country": "FI",
    "name": "Ylöjärvi",
    "lat": "61.55632",
    "lng": "23.59606"
  },
  {
    "country": "FI",
    "name": "Ylivieska",
    "lat": "64.08333",
    "lng": "24.55"
  },
  {
    "country": "FI",
    "name": "Ylitornio",
    "lat": "66.30893",
    "lng": "23.67734"
  },
  {
    "country": "FI",
    "name": "Ylistaro",
    "lat": "62.93958",
    "lng": "22.51306"
  },
  {
    "country": "FI",
    "name": "Ylikiiminki",
    "lat": "65.08333",
    "lng": "26.25"
  },
  {
    "country": "FI",
    "name": "Yli-Ii",
    "lat": "65.37181",
    "lng": "25.8458"
  },
  {
    "country": "FI",
    "name": "Ylihärmä",
    "lat": "63.15",
    "lng": "22.78333"
  },
  {
    "country": "FI",
    "name": "Yläne",
    "lat": "60.88333",
    "lng": "22.41667"
  },
  {
    "country": "FI",
    "name": "Ylämaa",
    "lat": "60.8",
    "lng": "28"
  },
  {
    "country": "FI",
    "name": "Vuosaari",
    "lat": "60.20963",
    "lng": "25.14195"
  },
  {
    "country": "FI",
    "name": "Vuolijoki",
    "lat": "64.18538",
    "lng": "26.99547"
  },
  {
    "country": "FI",
    "name": "Vuokatti",
    "lat": "64.14466",
    "lng": "28.28196"
  },
  {
    "country": "FI",
    "name": "Vörå",
    "lat": "63.13607",
    "lng": "22.25223"
  },
  {
    "country": "FI",
    "name": "Virtasalmi",
    "lat": "62.12695",
    "lng": "27.46276"
  },
  {
    "country": "FI",
    "name": "Virrat",
    "lat": "62.24759",
    "lng": "23.78004"
  },
  {
    "country": "FI",
    "name": "Virolahti",
    "lat": "60.51667",
    "lng": "27.68306"
  },
  {
    "country": "FI",
    "name": "Virojoki",
    "lat": "60.5794",
    "lng": "27.70354"
  },
  {
    "country": "FI",
    "name": "Vinkkilä",
    "lat": "60.68333",
    "lng": "21.71667"
  },
  {
    "country": "FI",
    "name": "Vimpeli",
    "lat": "63.16187",
    "lng": "23.81922"
  },
  {
    "country": "FI",
    "name": "Vilppula",
    "lat": "62.02121",
    "lng": "24.50483"
  },
  {
    "country": "FI",
    "name": "Viljakkala",
    "lat": "61.70601",
    "lng": "23.26688"
  },
  {
    "country": "FI",
    "name": "Viitasaari",
    "lat": "63.06667",
    "lng": "25.86667"
  },
  {
    "country": "FI",
    "name": "Viiala",
    "lat": "61.21023",
    "lng": "23.76738"
  },
  {
    "country": "FI",
    "name": "Vihti",
    "lat": "60.41699",
    "lng": "24.31965"
  },
  {
    "country": "FI",
    "name": "Vihanti",
    "lat": "64.48472",
    "lng": "24.99157"
  },
  {
    "country": "FI",
    "name": "Vieremä",
    "lat": "63.75",
    "lng": "27.01667"
  },
  {
    "country": "FI",
    "name": "Veteli",
    "lat": "63.47839",
    "lng": "23.78285"
  },
  {
    "country": "FI",
    "name": "Vesilahti",
    "lat": "61.31667",
    "lng": "23.61667"
  },
  {
    "country": "FI",
    "name": "Vesanto",
    "lat": "62.93333",
    "lng": "26.41667"
  },
  {
    "country": "FI",
    "name": "Velkua",
    "lat": "60.46667",
    "lng": "21.66667"
  },
  {
    "country": "FI",
    "name": "Vehmersalmi",
    "lat": "62.76101",
    "lng": "28.02853"
  },
  {
    "country": "FI",
    "name": "Vehmaa",
    "lat": "60.68333",
    "lng": "21.66667"
  },
  {
    "country": "FI",
    "name": "Västanfjärd",
    "lat": "60.05",
    "lng": "22.68333"
  },
  {
    "country": "FI",
    "name": "Varpaisjärvi",
    "lat": "63.35932",
    "lng": "27.75506"
  },
  {
    "country": "FI",
    "name": "Varkaus",
    "lat": "62.31533",
    "lng": "27.873"
  },
  {
    "country": "FI",
    "name": "Vantaa",
    "lat": "60.29414",
    "lng": "25.04099"
  },
  {
    "country": "FI",
    "name": "Vampula",
    "lat": "61.01667",
    "lng": "22.7"
  },
  {
    "country": "FI",
    "name": "Vammala",
    "lat": "61.33333",
    "lng": "22.9"
  },
  {
    "country": "FI",
    "name": "Valtimo",
    "lat": "63.66667",
    "lng": "28.8"
  },
  {
    "country": "FI",
    "name": "Valkeakoski",
    "lat": "61.26421",
    "lng": "24.03122"
  },
  {
    "country": "FI",
    "name": "Vahto",
    "lat": "60.6",
    "lng": "22.3"
  },
  {
    "country": "FI",
    "name": "Vähäkyrö",
    "lat": "63.05635",
    "lng": "22.10584"
  },
  {
    "country": "FI",
    "name": "Vaasa",
    "lat": "63.096",
    "lng": "21.61577"
  },
  {
    "country": "FI",
    "name": "Vaala",
    "lat": "64.56667",
    "lng": "26.83333"
  },
  {
    "country": "FI",
    "name": "Uusikaupunki",
    "lat": "60.80043",
    "lng": "21.40841"
  },
  {
    "country": "FI",
    "name": "Uurainen",
    "lat": "62.5",
    "lng": "25.45"
  },
  {
    "country": "FI",
    "name": "Utsjoki",
    "lat": "69.90864",
    "lng": "27.02843"
  },
  {
    "country": "FI",
    "name": "Utajärvi",
    "lat": "64.75",
    "lng": "26.38333"
  },
  {
    "country": "FI",
    "name": "Urjala",
    "lat": "61.08333",
    "lng": "23.53333"
  },
  {
    "country": "FI",
    "name": "Ulvila",
    "lat": "61.42844",
    "lng": "21.87103"
  },
  {
    "country": "FI",
    "name": "Ullava",
    "lat": "63.6",
    "lng": "24.08333"
  },
  {
    "country": "FI",
    "name": "Tyrnävä",
    "lat": "64.76469",
    "lng": "25.6523"
  },
  {
    "country": "FI",
    "name": "Tuusula",
    "lat": "60.40368",
    "lng": "25.02638"
  },
  {
    "country": "FI",
    "name": "Tuusniemi",
    "lat": "62.81667",
    "lng": "28.5"
  },
  {
    "country": "FI",
    "name": "Tuupovaara",
    "lat": "62.48372",
    "lng": "30.62731"
  },
  {
    "country": "FI",
    "name": "Tuulos",
    "lat": "61.15",
    "lng": "24.8"
  },
  {
    "country": "FI",
    "name": "Turku",
    "lat": "60.45148",
    "lng": "22.26869"
  },
  {
    "country": "FI",
    "name": "Turenki",
    "lat": "60.91667",
    "lng": "24.63333"
  },
  {
    "country": "FI",
    "name": "Töysä",
    "lat": "62.62803",
    "lng": "23.81828"
  },
  {
    "country": "FI",
    "name": "Tornio",
    "lat": "65.84811",
    "lng": "24.14662"
  },
  {
    "country": "FI",
    "name": "Toivakka",
    "lat": "62.1",
    "lng": "26.08333"
  },
  {
    "country": "FI",
    "name": "Akaa",
    "lat": "61.16667",
    "lng": "23.86667"
  },
  {
    "country": "FI",
    "name": "Toholampi",
    "lat": "63.76667",
    "lng": "24.25"
  },
  {
    "country": "FI",
    "name": "Tohmajärvi",
    "lat": "62.18333",
    "lng": "30.38333"
  },
  {
    "country": "FI",
    "name": "Teuva",
    "lat": "62.4819",
    "lng": "21.74156"
  },
  {
    "country": "FI",
    "name": "Tervola",
    "lat": "66.08333",
    "lng": "24.8"
  },
  {
    "country": "FI",
    "name": "Tervo",
    "lat": "62.95",
    "lng": "26.75"
  },
  {
    "country": "FI",
    "name": "Tervakoski",
    "lat": "60.81412",
    "lng": "24.62594"
  },
  {
    "country": "FI",
    "name": "Tarvasjoki",
    "lat": "60.58333",
    "lng": "22.73333"
  },
  {
    "country": "FI",
    "name": "Tampere",
    "lat": "61.49911",
    "lng": "23.78712"
  },
  {
    "country": "FI",
    "name": "Tammela",
    "lat": "60.81035",
    "lng": "23.76823"
  },
  {
    "country": "FI",
    "name": "Taivassalo",
    "lat": "60.56085",
    "lng": "21.61639"
  },
  {
    "country": "FI",
    "name": "Taivalkoski",
    "lat": "65.56667",
    "lng": "28.25"
  },
  {
    "country": "FI",
    "name": "Taipalsaari",
    "lat": "61.15",
    "lng": "28.05"
  },
  {
    "country": "FI",
    "name": "Taavetti",
    "lat": "60.91667",
    "lng": "27.56667"
  },
  {
    "country": "FI",
    "name": "Sysmä",
    "lat": "61.5",
    "lng": "25.68333"
  },
  {
    "country": "FI",
    "name": "Suonenjoki",
    "lat": "62.61667",
    "lng": "27.13333"
  },
  {
    "country": "FI",
    "name": "Suomussalmi",
    "lat": "64.88685",
    "lng": "28.90778"
  },
  {
    "country": "FI",
    "name": "Suomusjärvi",
    "lat": "60.35",
    "lng": "23.65"
  },
  {
    "country": "FI",
    "name": "Suolahti",
    "lat": "62.56421",
    "lng": "25.85363"
  },
  {
    "country": "FI",
    "name": "Suodenniemi",
    "lat": "61.5581",
    "lng": "22.78526"
  },
  {
    "country": "FI",
    "name": "Sumiainen",
    "lat": "62.65736",
    "lng": "26.04642"
  },
  {
    "country": "FI",
    "name": "Sulkava",
    "lat": "61.78691",
    "lng": "28.37299"
  },
  {
    "country": "FI",
    "name": "Sotkamo",
    "lat": "64.13333",
    "lng": "28.41667"
  },
  {
    "country": "FI",
    "name": "Sonkajärvi",
    "lat": "63.66667",
    "lng": "27.51667"
  },
  {
    "country": "FI",
    "name": "Somero",
    "lat": "60.61667",
    "lng": "23.53333"
  },
  {
    "country": "FI",
    "name": "Soini",
    "lat": "62.86667",
    "lng": "24.21667"
  },
  {
    "country": "FI",
    "name": "Sodankylä",
    "lat": "67.41667",
    "lng": "26.6"
  },
  {
    "country": "FI",
    "name": "Smedsby",
    "lat": "63.11667",
    "lng": "21.7"
  },
  {
    "country": "FI",
    "name": "Siuntio",
    "lat": "60.13862",
    "lng": "24.22715"
  },
  {
    "country": "FI",
    "name": "Simpele",
    "lat": "61.43333",
    "lng": "29.36667"
  },
  {
    "country": "FI",
    "name": "Simo",
    "lat": "65.66667",
    "lng": "25.05"
  },
  {
    "country": "FI",
    "name": "Broby",
    "lat": "60.5",
    "lng": "26.71667"
  },
  {
    "country": "FI",
    "name": "Siilinjärvi",
    "lat": "63.08333",
    "lng": "27.66667"
  },
  {
    "country": "FI",
    "name": "Siikajoki",
    "lat": "64.81455",
    "lng": "24.75924"
  },
  {
    "country": "FI",
    "name": "Siikainen",
    "lat": "61.87703",
    "lng": "21.81945"
  },
  {
    "country": "FI",
    "name": "Sievi",
    "lat": "63.9",
    "lng": "24.5"
  },
  {
    "country": "FI",
    "name": "Sibbo",
    "lat": "60.37752",
    "lng": "25.26906"
  },
  {
    "country": "FI",
    "name": "Seinäjoki",
    "lat": "62.79446",
    "lng": "22.82822"
  },
  {
    "country": "FI",
    "name": "Säynätsalo",
    "lat": "62.14025",
    "lng": "25.76948"
  },
  {
    "country": "FI",
    "name": "Savukoski",
    "lat": "67.2925",
    "lng": "28.15806"
  },
  {
    "country": "FI",
    "name": "Savonranta",
    "lat": "62.18333",
    "lng": "29.2"
  },
  {
    "country": "FI",
    "name": "Savonlinna",
    "lat": "61.8699",
    "lng": "28.87999"
  },
  {
    "country": "FI",
    "name": "Savitaipale",
    "lat": "61.2",
    "lng": "27.7"
  },
  {
    "country": "FI",
    "name": "Sauvo",
    "lat": "60.34306",
    "lng": "22.69642"
  },
  {
    "country": "FI",
    "name": "Saukkola",
    "lat": "60.38333",
    "lng": "23.98333"
  },
  {
    "country": "FI",
    "name": "Särkisalo",
    "lat": "60.11389",
    "lng": "22.95"
  },
  {
    "country": "FI",
    "name": "Sammatti",
    "lat": "60.31991",
    "lng": "23.82085"
  },
  {
    "country": "FI",
    "name": "Salo",
    "lat": "60.38333",
    "lng": "23.13333"
  },
  {
    "country": "FI",
    "name": "Salla",
    "lat": "66.83333",
    "lng": "28.66667"
  },
  {
    "country": "FI",
    "name": "Säkylä",
    "lat": "61.03333",
    "lng": "22.33333"
  },
  {
    "country": "FI",
    "name": "Sahalahti",
    "lat": "61.4746",
    "lng": "24.32652"
  },
  {
    "country": "FI",
    "name": "Saarijärvi",
    "lat": "62.70486",
    "lng": "25.25396"
  },
  {
    "country": "FI",
    "name": "Saari",
    "lat": "61.65",
    "lng": "29.75"
  },
  {
    "country": "FI",
    "name": "Rymättylä",
    "lat": "60.37658",
    "lng": "21.94184"
  },
  {
    "country": "FI",
    "name": "Ruukki",
    "lat": "64.66667",
    "lng": "25.1"
  },
  {
    "country": "FI",
    "name": "Rusko",
    "lat": "60.53333",
    "lng": "22.21667"
  },
  {
    "country": "FI",
    "name": "Ruovesi",
    "lat": "61.98575",
    "lng": "24.05714"
  },
  {
    "country": "FI",
    "name": "Ruotsinpyhtää",
    "lat": "60.5268",
    "lng": "26.46203"
  },
  {
    "country": "FI",
    "name": "Ruokolahti",
    "lat": "61.28333",
    "lng": "28.83333"
  },
  {
    "country": "FI",
    "name": "Rovaniemi",
    "lat": "66.5",
    "lng": "25.71667"
  },
  {
    "country": "FI",
    "name": "Ristijärvi",
    "lat": "64.5",
    "lng": "28.21667"
  },
  {
    "country": "FI",
    "name": "Ristiina",
    "lat": "61.50579",
    "lng": "27.24643"
  },
  {
    "country": "FI",
    "name": "Riihimäki",
    "lat": "60.73769",
    "lng": "24.77726"
  },
  {
    "country": "FI",
    "name": "Replot",
    "lat": "63.22882",
    "lng": "21.41691"
  },
  {
    "country": "FI",
    "name": "Renko",
    "lat": "60.89563",
    "lng": "24.28785"
  },
  {
    "country": "FI",
    "name": "Reisjärvi",
    "lat": "63.61667",
    "lng": "24.9"
  },
  {
    "country": "FI",
    "name": "Rautjärvi",
    "lat": "61.43333",
    "lng": "29.35"
  },
  {
    "country": "FI",
    "name": "Rautavaara",
    "lat": "63.48333",
    "lng": "28.3"
  },
  {
    "country": "FI",
    "name": "Rautalampi",
    "lat": "62.63333",
    "lng": "26.83333"
  },
  {
    "country": "FI",
    "name": "Rauma",
    "lat": "61.12724",
    "lng": "21.51127"
  },
  {
    "country": "FI",
    "name": "Ranua",
    "lat": "65.91667",
    "lng": "26.53333"
  },
  {
    "country": "FI",
    "name": "Rantsila",
    "lat": "64.50613",
    "lng": "25.66449"
  },
  {
    "country": "FI",
    "name": "Rantasalmi",
    "lat": "62.06667",
    "lng": "28.3"
  },
  {
    "country": "FI",
    "name": "Raisio",
    "lat": "60.48592",
    "lng": "22.16895"
  },
  {
    "country": "FI",
    "name": "Rääkkylä",
    "lat": "62.31667",
    "lng": "29.61667"
  },
  {
    "country": "FI",
    "name": "Raahe",
    "lat": "64.68333",
    "lng": "24.48333"
  },
  {
    "country": "FI",
    "name": "Pylkönmäki",
    "lat": "62.66667",
    "lng": "24.8"
  },
  {
    "country": "FI",
    "name": "Pyhtää",
    "lat": "60.49349",
    "lng": "26.54346"
  },
  {
    "country": "FI",
    "name": "Pyhäselkä",
    "lat": "62.43333",
    "lng": "29.96667"
  },
  {
    "country": "FI",
    "name": "Pyhäsalmi",
    "lat": "63.68333",
    "lng": "25.98333"
  },
  {
    "country": "FI",
    "name": "Pyhäranta",
    "lat": "60.95",
    "lng": "21.45"
  },
  {
    "country": "FI",
    "name": "Pyhäntä",
    "lat": "64.1",
    "lng": "26.31667"
  },
  {
    "country": "FI",
    "name": "Pyhäjoki",
    "lat": "64.46667",
    "lng": "24.23333"
  },
  {
    "country": "FI",
    "name": "Pyhäjärvi",
    "lat": "67.0701",
    "lng": "27.21763"
  },
  {
    "country": "FI",
    "name": "Pyhäjärvi",
    "lat": "63.66667",
    "lng": "25.9"
  },
  {
    "country": "FI",
    "name": "Puumala",
    "lat": "61.52728",
    "lng": "28.17495"
  },
  {
    "country": "FI",
    "name": "Puolanka",
    "lat": "64.86667",
    "lng": "27.66667"
  },
  {
    "country": "FI",
    "name": "Punkalaidun",
    "lat": "61.11667",
    "lng": "23.1"
  },
  {
    "country": "FI",
    "name": "Punkaharju",
    "lat": "61.75883",
    "lng": "29.38843"
  },
  {
    "country": "FI",
    "name": "Pulkkila",
    "lat": "64.26667",
    "lng": "25.86667"
  },
  {
    "country": "FI",
    "name": "Pukkila",
    "lat": "60.65",
    "lng": "25.56667"
  },
  {
    "country": "FI",
    "name": "Pudasjärvi",
    "lat": "65.38333",
    "lng": "26.91667"
  },
  {
    "country": "FI",
    "name": "Pöytyä",
    "lat": "60.76667",
    "lng": "22.66667"
  },
  {
    "country": "FI",
    "name": "Posio",
    "lat": "66.10856",
    "lng": "28.17186"
  },
  {
    "country": "FI",
    "name": "Pornainen",
    "lat": "60.47581",
    "lng": "25.3749"
  },
  {
    "country": "FI",
    "name": "Pori",
    "lat": "61.48333",
    "lng": "21.78333"
  },
  {
    "country": "FI",
    "name": "Pomarkku",
    "lat": "61.69348",
    "lng": "22.00862"
  },
  {
    "country": "FI",
    "name": "Polvijärvi",
    "lat": "62.85",
    "lng": "29.36667"
  },
  {
    "country": "FI",
    "name": "Pohja",
    "lat": "60.09626",
    "lng": "23.52757"
  },
  {
    "country": "FI",
    "name": "Pirkkala",
    "lat": "61.46125",
    "lng": "23.63228"
  },
  {
    "country": "FI",
    "name": "Piippola",
    "lat": "64.16667",
    "lng": "25.96667"
  },
  {
    "country": "FI",
    "name": "Piikkiö",
    "lat": "60.42481",
    "lng": "22.51601"
  },
  {
    "country": "FI",
    "name": "Pihtipudas",
    "lat": "63.38333",
    "lng": "25.56667"
  },
  {
    "country": "FI",
    "name": "Pielavesi",
    "lat": "63.23333",
    "lng": "26.75"
  },
  {
    "country": "FI",
    "name": "Pieksämäki",
    "lat": "62.3",
    "lng": "27.13333"
  },
  {
    "country": "FI",
    "name": "Petäjävesi",
    "lat": "62.25",
    "lng": "25.2"
  },
  {
    "country": "FI",
    "name": "Pertunmaa",
    "lat": "61.5",
    "lng": "26.48333"
  },
  {
    "country": "FI",
    "name": "Pertteli",
    "lat": "60.43333",
    "lng": "23.26667"
  },
  {
    "country": "FI",
    "name": "Perniö",
    "lat": "60.2",
    "lng": "23.13333"
  },
  {
    "country": "FI",
    "name": "Pernå",
    "lat": "60.44869",
    "lng": "26.03187"
  },
  {
    "country": "FI",
    "name": "Perho",
    "lat": "63.21667",
    "lng": "24.41667"
  },
  {
    "country": "FI",
    "name": "Pello",
    "lat": "66.77364",
    "lng": "23.96255"
  },
  {
    "country": "FI",
    "name": "Pelkosenniemi",
    "lat": "67.11083",
    "lng": "27.51056"
  },
  {
    "country": "FI",
    "name": "Pedersöre",
    "lat": "63.65",
    "lng": "22.68333"
  },
  {
    "country": "FI",
    "name": "Parola",
    "lat": "61.04624",
    "lng": "24.35463"
  },
  {
    "country": "FI",
    "name": "Parkano",
    "lat": "62.01667",
    "lng": "23.01667"
  },
  {
    "country": "FI",
    "name": "Parikkala",
    "lat": "61.55",
    "lng": "29.5"
  },
  {
    "country": "FI",
    "name": "Pargas",
    "lat": "60.30672",
    "lng": "22.30097"
  },
  {
    "country": "FI",
    "name": "Paltamo",
    "lat": "64.41667",
    "lng": "27.83333"
  },
  {
    "country": "FI",
    "name": "Pälkäne",
    "lat": "61.33424",
    "lng": "24.27197"
  },
  {
    "country": "FI",
    "name": "Paimio",
    "lat": "60.45671",
    "lng": "22.68694"
  },
  {
    "country": "FI",
    "name": "Padasjoki",
    "lat": "61.35",
    "lng": "25.28333"
  },
  {
    "country": "FI",
    "name": "Outokumpu",
    "lat": "62.72685",
    "lng": "29.01592"
  },
  {
    "country": "FI",
    "name": "Oulunsalo",
    "lat": "64.93456",
    "lng": "25.41121"
  },
  {
    "country": "FI",
    "name": "Oulu",
    "lat": "65.01236",
    "lng": "25.46816"
  },
  {
    "country": "FI",
    "name": "Oulainen",
    "lat": "64.26667",
    "lng": "24.8"
  },
  {
    "country": "FI",
    "name": "Otaniemi",
    "lat": "60.18395",
    "lng": "24.82786"
  },
  {
    "country": "FI",
    "name": "Orivesi",
    "lat": "61.67766",
    "lng": "24.3572"
  },
  {
    "country": "FI",
    "name": "Oripää",
    "lat": "60.85",
    "lng": "22.68333"
  },
  {
    "country": "FI",
    "name": "Orimattila",
    "lat": "60.80487",
    "lng": "25.72964"
  },
  {
    "country": "FI",
    "name": "Oravais",
    "lat": "63.30135",
    "lng": "22.37821"
  },
  {
    "country": "FI",
    "name": "Oitti",
    "lat": "60.78333",
    "lng": "25.03333"
  },
  {
    "country": "FI",
    "name": "Nykarleby",
    "lat": "63.52277",
    "lng": "22.53073"
  },
  {
    "country": "FI",
    "name": "Nurmo",
    "lat": "62.8287",
    "lng": "22.9099"
  },
  {
    "country": "FI",
    "name": "Nurmijärvi",
    "lat": "60.46407",
    "lng": "24.8073"
  },
  {
    "country": "FI",
    "name": "Nurmes",
    "lat": "63.54205",
    "lng": "29.13965"
  },
  {
    "country": "FI",
    "name": "Nuijamaa",
    "lat": "60.96011",
    "lng": "28.55104"
  },
  {
    "country": "FI",
    "name": "Nousiainen",
    "lat": "60.60416",
    "lng": "22.07926"
  },
  {
    "country": "FI",
    "name": "Noormarkku",
    "lat": "61.59274",
    "lng": "21.86846"
  },
  {
    "country": "FI",
    "name": "Nokia",
    "lat": "61.46667",
    "lng": "23.5"
  },
  {
    "country": "FI",
    "name": "Nivala",
    "lat": "63.91667",
    "lng": "24.96667"
  },
  {
    "country": "FI",
    "name": "Nilsiä",
    "lat": "63.20746",
    "lng": "28.08222"
  },
  {
    "country": "FI",
    "name": "Nickby",
    "lat": "60.38333",
    "lng": "25.28333"
  },
  {
    "country": "FI",
    "name": "Nastola",
    "lat": "60.95",
    "lng": "25.93333"
  },
  {
    "country": "FI",
    "name": "Närpes",
    "lat": "62.47283",
    "lng": "21.33707"
  },
  {
    "country": "FI",
    "name": "Nakkila",
    "lat": "61.36667",
    "lng": "22"
  },
  {
    "country": "FI",
    "name": "Nagu",
    "lat": "60.19375",
    "lng": "21.90972"
  },
  {
    "country": "FI",
    "name": "Naantali",
    "lat": "60.46744",
    "lng": "22.02428"
  },
  {
    "country": "FI",
    "name": "Myrskylä",
    "lat": "60.66965",
    "lng": "25.8475"
  },
  {
    "country": "FI",
    "name": "Mynämäki",
    "lat": "60.67915",
    "lng": "21.99274"
  },
  {
    "country": "FI",
    "name": "Muurla",
    "lat": "60.35",
    "lng": "23.28333"
  },
  {
    "country": "FI",
    "name": "Muurame",
    "lat": "62.13333",
    "lng": "25.66667"
  },
  {
    "country": "FI",
    "name": "Muonio",
    "lat": "67.95",
    "lng": "23.7"
  },
  {
    "country": "FI",
    "name": "Munkkiniemi",
    "lat": "60.19861",
    "lng": "24.87772"
  },
  {
    "country": "FI",
    "name": "Multia",
    "lat": "62.41667",
    "lng": "24.78333"
  },
  {
    "country": "FI",
    "name": "Muhos",
    "lat": "64.80798",
    "lng": "25.99314"
  },
  {
    "country": "FI",
    "name": "Muhos",
    "lat": "64.76667",
    "lng": "26.1"
  },
  {
    "country": "FI",
    "name": "Mouhijärvi",
    "lat": "61.5",
    "lng": "23.01667"
  },
  {
    "country": "FI",
    "name": "Mikkeli",
    "lat": "61.68857",
    "lng": "27.27227"
  },
  {
    "country": "FI",
    "name": "Mietoinen",
    "lat": "60.63333",
    "lng": "21.93333"
  },
  {
    "country": "FI",
    "name": "Miehikkälä",
    "lat": "60.66667",
    "lng": "27.7"
  },
  {
    "country": "FI",
    "name": "Merimasku",
    "lat": "60.48333",
    "lng": "21.86667"
  },
  {
    "country": "FI",
    "name": "Merikarvia",
    "lat": "61.85839",
    "lng": "21.50035"
  },
  {
    "country": "FI",
    "name": "Merijärvi",
    "lat": "64.3",
    "lng": "24.45"
  },
  {
    "country": "FI",
    "name": "Mellunkylä",
    "lat": "60.23355",
    "lng": "25.09947"
  },
  {
    "country": "FI",
    "name": "Mellilä",
    "lat": "60.76667",
    "lng": "22.95"
  },
  {
    "country": "FI",
    "name": "Masku",
    "lat": "60.57082",
    "lng": "22.09883"
  },
  {
    "country": "FI",
    "name": "Marttila",
    "lat": "60.58333",
    "lng": "22.9"
  },
  {
    "country": "FI",
    "name": "Mäntyharju",
    "lat": "61.41667",
    "lng": "26.88333"
  },
  {
    "country": "FI",
    "name": "Mänttä",
    "lat": "62.03014",
    "lng": "24.62791"
  },
  {
    "country": "FI",
    "name": "Mäntsälä",
    "lat": "60.63333",
    "lng": "25.31667"
  },
  {
    "country": "FI",
    "name": "Malax",
    "lat": "62.94225",
    "lng": "21.57311"
  },
  {
    "country": "FI",
    "name": "Maaninka",
    "lat": "63.15523",
    "lng": "27.29939"
  },
  {
    "country": "FI",
    "name": "Luvia",
    "lat": "61.36375",
    "lng": "21.62556"
  },
  {
    "country": "FI",
    "name": "Luumäki",
    "lat": "60.92618",
    "lng": "27.58135"
  },
  {
    "country": "FI",
    "name": "Luopioinen",
    "lat": "61.36293",
    "lng": "24.66781"
  },
  {
    "country": "FI",
    "name": "Lumijoki",
    "lat": "64.83744",
    "lng": "25.18607"
  },
  {
    "country": "FI",
    "name": "Luhanka",
    "lat": "61.79682",
    "lng": "25.70457"
  },
  {
    "country": "FI",
    "name": "Lovisa",
    "lat": "60.45659",
    "lng": "26.22505"
  },
  {
    "country": "FI",
    "name": "Loppi",
    "lat": "60.71667",
    "lng": "24.45"
  },
  {
    "country": "FI",
    "name": "Loimaa",
    "lat": "60.84972",
    "lng": "23.0561"
  },
  {
    "country": "FI",
    "name": "Lohtaja",
    "lat": "64.02472",
    "lng": "23.50482"
  },
  {
    "country": "FI",
    "name": "Lohja",
    "lat": "60.24859",
    "lng": "24.06534"
  },
  {
    "country": "FI",
    "name": "Liperi",
    "lat": "62.53333",
    "lng": "29.36667"
  },
  {
    "country": "FI",
    "name": "Liminka",
    "lat": "64.80985",
    "lng": "25.41545"
  },
  {
    "country": "FI",
    "name": "Liljendal",
    "lat": "60.57346",
    "lng": "26.05257"
  },
  {
    "country": "FI",
    "name": "Lieto",
    "lat": "60.51032",
    "lng": "22.46176"
  },
  {
    "country": "FI",
    "name": "Lieksa",
    "lat": "63.31667",
    "lng": "30.01667"
  },
  {
    "country": "FI",
    "name": "Lestijärvi",
    "lat": "63.53333",
    "lng": "24.65"
  },
  {
    "country": "FI",
    "name": "Leppävirta",
    "lat": "62.49009",
    "lng": "27.78262"
  },
  {
    "country": "FI",
    "name": "Lemu",
    "lat": "60.56667",
    "lng": "21.96667"
  },
  {
    "country": "FI",
    "name": "Lempäälä",
    "lat": "61.31667",
    "lng": "23.75"
  },
  {
    "country": "FI",
    "name": "Lemi",
    "lat": "61.06244",
    "lng": "27.80571"
  },
  {
    "country": "FI",
    "name": "Leivonmäki",
    "lat": "61.91198",
    "lng": "26.12796"
  },
  {
    "country": "FI",
    "name": "Lehtimäki",
    "lat": "62.78333",
    "lng": "23.91667"
  },
  {
    "country": "FI",
    "name": "Lavia",
    "lat": "61.6",
    "lng": "22.6"
  },
  {
    "country": "FI",
    "name": "Lauttasaari",
    "lat": "60.15896",
    "lng": "24.86797"
  },
  {
    "country": "FI",
    "name": "Laukaa",
    "lat": "62.41407",
    "lng": "25.95194"
  },
  {
    "country": "FI",
    "name": "Larsmo",
    "lat": "63.75388",
    "lng": "22.74728"
  },
  {
    "country": "FI",
    "name": "Lapua",
    "lat": "62.96927",
    "lng": "23.0088"
  },
  {
    "country": "FI",
    "name": "Lappi",
    "lat": "61.1",
    "lng": "21.83333"
  },
  {
    "country": "FI",
    "name": "Lappeenranta",
    "lat": "61.05871",
    "lng": "28.18871"
  },
  {
    "country": "FI",
    "name": "Lappajärvi",
    "lat": "63.2",
    "lng": "23.63333"
  },
  {
    "country": "FI",
    "name": "Lapinlahti",
    "lat": "63.36667",
    "lng": "27.4"
  },
  {
    "country": "FI",
    "name": "Lapinjärvi",
    "lat": "60.62443",
    "lng": "26.1972"
  },
  {
    "country": "FI",
    "name": "Längelmäki",
    "lat": "61.65",
    "lng": "22.1"
  },
  {
    "country": "FI",
    "name": "Lammi",
    "lat": "61.08333",
    "lng": "25.01667"
  },
  {
    "country": "FI",
    "name": "Laitila",
    "lat": "60.87575",
    "lng": "21.69765"
  },
  {
    "country": "FI",
    "name": "Laihia",
    "lat": "62.97609",
    "lng": "22.01143"
  },
  {
    "country": "FI",
    "name": "Lahti",
    "lat": "60.98267",
    "lng": "25.66151"
  },
  {
    "country": "FI",
    "name": "Kyyjärvi",
    "lat": "63.03333",
    "lng": "24.56667"
  },
  {
    "country": "FI",
    "name": "Kyrö",
    "lat": "60.7",
    "lng": "22.75"
  },
  {
    "country": "FI",
    "name": "Kirkkonummi",
    "lat": "60.12381",
    "lng": "24.43853"
  },
  {
    "country": "FI",
    "name": "Kylmäkoski",
    "lat": "61.154",
    "lng": "23.68858"
  },
  {
    "country": "FI",
    "name": "Kuusjoki",
    "lat": "60.51667",
    "lng": "23.2"
  },
  {
    "country": "FI",
    "name": "Kuusamo",
    "lat": "65.96667",
    "lng": "29.18333"
  },
  {
    "country": "FI",
    "name": "Kustavi",
    "lat": "60.54529",
    "lng": "21.3588"
  },
  {
    "country": "FI",
    "name": "Kuru",
    "lat": "61.87558",
    "lng": "23.71948"
  },
  {
    "country": "FI",
    "name": "Kurikka",
    "lat": "62.61667",
    "lng": "22.41667"
  },
  {
    "country": "FI",
    "name": "Kuortane",
    "lat": "62.8",
    "lng": "23.5"
  },
  {
    "country": "FI",
    "name": "Kuopio",
    "lat": "62.89238",
    "lng": "27.67703"
  },
  {
    "country": "FI",
    "name": "Kullaa",
    "lat": "61.46998",
    "lng": "22.16145"
  },
  {
    "country": "FI",
    "name": "Kuivaniemi",
    "lat": "65.57847",
    "lng": "25.18814"
  },
  {
    "country": "FI",
    "name": "Kuhmoinen",
    "lat": "61.56667",
    "lng": "25.18333"
  },
  {
    "country": "FI",
    "name": "Kuhmo",
    "lat": "64.13333",
    "lng": "29.51667"
  },
  {
    "country": "FI",
    "name": "Kuhmalahti",
    "lat": "61.5",
    "lng": "24.56667"
  },
  {
    "country": "FI",
    "name": "Kronoby",
    "lat": "63.72859",
    "lng": "23.03387"
  },
  {
    "country": "FI",
    "name": "Kristinestad",
    "lat": "62.27429",
    "lng": "21.37596"
  },
  {
    "country": "FI",
    "name": "Köyliö",
    "lat": "61.1191",
    "lng": "22.30976"
  },
  {
    "country": "FI",
    "name": "Kouvola",
    "lat": "60.86667",
    "lng": "26.7"
  },
  {
    "country": "FI",
    "name": "Kotka",
    "lat": "60.4664",
    "lng": "26.94582"
  },
  {
    "country": "FI",
    "name": "Hämeenkoski",
    "lat": "61.02222",
    "lng": "25.15417"
  },
  {
    "country": "FI",
    "name": "Koski Tl",
    "lat": "60.65",
    "lng": "23.15"
  },
  {
    "country": "FI",
    "name": "Kortesjärvi",
    "lat": "63.3",
    "lng": "23.16667"
  },
  {
    "country": "FI",
    "name": "Korsnäs",
    "lat": "62.78333",
    "lng": "21.2"
  },
  {
    "country": "FI",
    "name": "Korsholm",
    "lat": "63.11418",
    "lng": "21.68216"
  },
  {
    "country": "FI",
    "name": "Korpilahti",
    "lat": "62.01667",
    "lng": "25.55"
  },
  {
    "country": "FI",
    "name": "Kontiolahti",
    "lat": "62.76023",
    "lng": "29.84711"
  },
  {
    "country": "FI",
    "name": "Konnevesi",
    "lat": "62.61667",
    "lng": "26.31667"
  },
  {
    "country": "FI",
    "name": "Kolari",
    "lat": "67.33047",
    "lng": "23.77785"
  },
  {
    "country": "FI",
    "name": "Kokkola",
    "lat": "63.83847",
    "lng": "23.13066"
  },
  {
    "country": "FI",
    "name": "Kokemäki",
    "lat": "61.25647",
    "lng": "22.35643"
  },
  {
    "country": "FI",
    "name": "Kivijärvi",
    "lat": "63.11984",
    "lng": "25.07835"
  },
  {
    "country": "FI",
    "name": "Kiuruvesi",
    "lat": "63.65",
    "lng": "26.61667"
  },
  {
    "country": "FI",
    "name": "Kiukainen",
    "lat": "61.21667",
    "lng": "22.08333"
  },
  {
    "country": "FI",
    "name": "Kittilä",
    "lat": "67.66474",
    "lng": "24.89356"
  },
  {
    "country": "FI",
    "name": "Kitee",
    "lat": "62.1",
    "lng": "30.15"
  },
  {
    "country": "FI",
    "name": "Kisko",
    "lat": "60.23333",
    "lng": "23.48333"
  },
  {
    "country": "FI",
    "name": "Kinnula",
    "lat": "63.38333",
    "lng": "24.95"
  },
  {
    "country": "FI",
    "name": "Kinnula",
    "lat": "63.36667",
    "lng": "24.96667"
  },
  {
    "country": "FI",
    "name": "Kimito",
    "lat": "60.16047",
    "lng": "22.729"
  },
  {
    "country": "FI",
    "name": "Kiiminki",
    "lat": "65.13139",
    "lng": "25.79744"
  },
  {
    "country": "FI",
    "name": "Kiikoinen",
    "lat": "61.45385",
    "lng": "22.57699"
  },
  {
    "country": "FI",
    "name": "Kiikala",
    "lat": "60.46667",
    "lng": "23.56667"
  },
  {
    "country": "FI",
    "name": "Kiihtelysvaara",
    "lat": "62.49525",
    "lng": "30.25081"
  },
  {
    "country": "FI",
    "name": "Kihniö",
    "lat": "62.2",
    "lng": "23.18333"
  },
  {
    "country": "FI",
    "name": "Keuruu",
    "lat": "62.26667",
    "lng": "24.7"
  },
  {
    "country": "FI",
    "name": "Kestilä",
    "lat": "64.35002",
    "lng": "26.27921"
  },
  {
    "country": "FI",
    "name": "Kesälahti",
    "lat": "61.89752",
    "lng": "29.83494"
  },
  {
    "country": "FI",
    "name": "Kerimäki",
    "lat": "61.91069",
    "lng": "29.28228"
  },
  {
    "country": "FI",
    "name": "Kerava",
    "lat": "60.40338",
    "lng": "25.105"
  },
  {
    "country": "FI",
    "name": "Kempele",
    "lat": "64.91314",
    "lng": "25.50339"
  },
  {
    "country": "FI",
    "name": "Kemijärvi",
    "lat": "66.71309",
    "lng": "27.43056"
  },
  {
    "country": "FI",
    "name": "Keminmaa",
    "lat": "65.80158",
    "lng": "24.54483"
  },
  {
    "country": "FI",
    "name": "Kemi",
    "lat": "65.73641",
    "lng": "24.56371"
  },
  {
    "country": "FI",
    "name": "Kellokoski",
    "lat": "60.53271",
    "lng": "25.10917"
  },
  {
    "country": "FI",
    "name": "Keitele",
    "lat": "63.18333",
    "lng": "26.36667"
  },
  {
    "country": "FI",
    "name": "Kaustinen",
    "lat": "63.54878",
    "lng": "23.68845"
  },
  {
    "country": "FI",
    "name": "Kauniainen",
    "lat": "60.21209",
    "lng": "24.72756"
  },
  {
    "country": "FI",
    "name": "Kauhava",
    "lat": "63.10299",
    "lng": "23.07129"
  },
  {
    "country": "FI",
    "name": "Kauhajoki",
    "lat": "62.43333",
    "lng": "22.18333"
  },
  {
    "country": "FI",
    "name": "Kaskinen",
    "lat": "62.38444",
    "lng": "21.22331"
  },
  {
    "country": "FI",
    "name": "Karvia",
    "lat": "62.2",
    "lng": "22.65"
  },
  {
    "country": "FI",
    "name": "Karvia",
    "lat": "62.13333",
    "lng": "22.56667"
  },
  {
    "country": "FI",
    "name": "Karttula",
    "lat": "62.8963",
    "lng": "26.97045"
  },
  {
    "country": "FI",
    "name": "Karstula",
    "lat": "62.86667",
    "lng": "24.78333"
  },
  {
    "country": "FI",
    "name": "Kärsämäki",
    "lat": "63.96667",
    "lng": "25.76667"
  },
  {
    "country": "FI",
    "name": "Kärkölä",
    "lat": "60.91667",
    "lng": "25.25"
  },
  {
    "country": "FI",
    "name": "Kärkölä",
    "lat": "60.61292",
    "lng": "23.94196"
  },
  {
    "country": "FI",
    "name": "Karkkila",
    "lat": "60.53418",
    "lng": "24.20977"
  },
  {
    "country": "FI",
    "name": "Karjalohja",
    "lat": "60.24015",
    "lng": "23.71789"
  },
  {
    "country": "FI",
    "name": "Karis",
    "lat": "60.07178",
    "lng": "23.66163"
  },
  {
    "country": "FI",
    "name": "Karinainen",
    "lat": "60.66667",
    "lng": "22.76667"
  },
  {
    "country": "FI",
    "name": "Karijoki",
    "lat": "62.30851",
    "lng": "21.70856"
  },
  {
    "country": "FI",
    "name": "Karhula",
    "lat": "60.52156",
    "lng": "26.93125"
  },
  {
    "country": "FI",
    "name": "Kannus",
    "lat": "63.9",
    "lng": "23.9"
  },
  {
    "country": "FI",
    "name": "Kannonkoski",
    "lat": "62.96667",
    "lng": "25.25"
  },
  {
    "country": "FI",
    "name": "Kankaanpää",
    "lat": "61.8",
    "lng": "22.41667"
  },
  {
    "country": "FI",
    "name": "Kangasniemi",
    "lat": "61.99357",
    "lng": "26.64785"
  },
  {
    "country": "FI",
    "name": "Kangaslampi",
    "lat": "62.29563",
    "lng": "28.25289"
  },
  {
    "country": "FI",
    "name": "Kangasala",
    "lat": "61.46383",
    "lng": "24.07602"
  },
  {
    "country": "FI",
    "name": "Kalvola",
    "lat": "61.10081",
    "lng": "24.12177"
  },
  {
    "country": "FI",
    "name": "Kälviä",
    "lat": "63.86067",
    "lng": "23.45289"
  },
  {
    "country": "FI",
    "name": "Kallio",
    "lat": "60.18427",
    "lng": "24.95034"
  },
  {
    "country": "FI",
    "name": "Kalajoki",
    "lat": "64.25",
    "lng": "23.95"
  },
  {
    "country": "FI",
    "name": "Kajaani",
    "lat": "64.22728",
    "lng": "27.72846"
  },
  {
    "country": "FI",
    "name": "Kaavi",
    "lat": "62.98333",
    "lng": "28.5"
  },
  {
    "country": "FI",
    "name": "Kaarina",
    "lat": "60.40724",
    "lng": "22.36904"
  },
  {
    "country": "FI",
    "name": "Kaarela",
    "lat": "60.25174",
    "lng": "24.88111"
  },
  {
    "country": "FI",
    "name": "Jyväskylä",
    "lat": "62.24147",
    "lng": "25.72088"
  },
  {
    "country": "FI",
    "name": "Juva",
    "lat": "61.9",
    "lng": "27.85"
  },
  {
    "country": "FI",
    "name": "Juupajoki",
    "lat": "61.79901",
    "lng": "24.36939"
  },
  {
    "country": "FI",
    "name": "Juuka",
    "lat": "63.23333",
    "lng": "29.25"
  },
  {
    "country": "FI",
    "name": "Jurva",
    "lat": "62.68333",
    "lng": "21.98333"
  },
  {
    "country": "FI",
    "name": "Juankoski",
    "lat": "63.06667",
    "lng": "28.35"
  },
  {
    "country": "FI",
    "name": "Joutseno",
    "lat": "61.11796",
    "lng": "28.50763"
  },
  {
    "country": "FI",
    "name": "Joutsa",
    "lat": "61.73333",
    "lng": "26.11667"
  },
  {
    "country": "FI",
    "name": "Joroinen",
    "lat": "62.17823",
    "lng": "27.83165"
  },
  {
    "country": "FI",
    "name": "Jokioinen",
    "lat": "60.80162",
    "lng": "23.48004"
  },
  {
    "country": "FI",
    "name": "Joensuu",
    "lat": "62.60118",
    "lng": "29.76316"
  },
  {
    "country": "FI",
    "name": "Järvenpää",
    "lat": "60.47369",
    "lng": "25.08992"
  },
  {
    "country": "FI",
    "name": "Järvelä",
    "lat": "60.86667",
    "lng": "25.28333"
  },
  {
    "country": "FI",
    "name": "Jäppilä",
    "lat": "62.37899",
    "lng": "27.43372"
  },
  {
    "country": "FI",
    "name": "Janakkala",
    "lat": "60.9",
    "lng": "24.6"
  },
  {
    "country": "FI",
    "name": "Jämsänkoski",
    "lat": "61.919",
    "lng": "25.17011"
  },
  {
    "country": "FI",
    "name": "Jämsä",
    "lat": "61.8642",
    "lng": "25.19002"
  },
  {
    "country": "FI",
    "name": "Jämijärvi",
    "lat": "61.81667",
    "lng": "22.7"
  },
  {
    "country": "FI",
    "name": "Jalasjärvi",
    "lat": "62.5",
    "lng": "22.75"
  },
  {
    "country": "FI",
    "name": "Jakobstad",
    "lat": "63.67486",
    "lng": "22.70256"
  },
  {
    "country": "FI",
    "name": "Jaala",
    "lat": "61.05251",
    "lng": "26.48117"
  },
  {
    "country": "FI",
    "name": "Ivalo",
    "lat": "68.65986",
    "lng": "27.53891"
  },
  {
    "country": "FI",
    "name": "Isokyrö",
    "lat": "63.01172",
    "lng": "22.33332"
  },
  {
    "country": "FI",
    "name": "Isojoki",
    "lat": "62.11319",
    "lng": "21.95884"
  },
  {
    "country": "FI",
    "name": "Iniö",
    "lat": "60.4",
    "lng": "21.4"
  },
  {
    "country": "FI",
    "name": "Ingå",
    "lat": "60.04587",
    "lng": "24.00459"
  },
  {
    "country": "FI",
    "name": "Inari",
    "lat": "68.90596",
    "lng": "27.02881"
  },
  {
    "country": "FI",
    "name": "Imatra",
    "lat": "61.17185",
    "lng": "28.75242"
  },
  {
    "country": "FI",
    "name": "Ilomantsi",
    "lat": "62.67162",
    "lng": "30.93276"
  },
  {
    "country": "FI",
    "name": "Ilmajoki",
    "lat": "62.73333",
    "lng": "22.56667"
  },
  {
    "country": "FI",
    "name": "Ikaalinen",
    "lat": "61.76951",
    "lng": "23.0658"
  },
  {
    "country": "FI",
    "name": "Iitti",
    "lat": "60.89488",
    "lng": "26.33869"
  },
  {
    "country": "FI",
    "name": "Iisalmi",
    "lat": "63.55915",
    "lng": "27.19067"
  },
  {
    "country": "FI",
    "name": "Ii",
    "lat": "65.31735",
    "lng": "25.3731"
  },
  {
    "country": "FI",
    "name": "Hyvinge",
    "lat": "60.63333",
    "lng": "24.86667"
  },
  {
    "country": "FI",
    "name": "Hyrynsalmi",
    "lat": "64.66667",
    "lng": "28.53333"
  },
  {
    "country": "FI",
    "name": "Humppila",
    "lat": "60.93333",
    "lng": "23.36667"
  },
  {
    "country": "FI",
    "name": "Huittinen",
    "lat": "61.18333",
    "lng": "22.7"
  },
  {
    "country": "FI",
    "name": "Houtskär",
    "lat": "60.22284",
    "lng": "21.37218"
  },
  {
    "country": "FI",
    "name": "Honkajoki",
    "lat": "61.98333",
    "lng": "22.26667"
  },
  {
    "country": "FI",
    "name": "Hollola",
    "lat": "61.05",
    "lng": "25.43333"
  },
  {
    "country": "FI",
    "name": "Hollola",
    "lat": "61",
    "lng": "25.5"
  },
  {
    "country": "FI",
    "name": "Hirvensalmi",
    "lat": "61.63333",
    "lng": "26.8"
  },
  {
    "country": "FI",
    "name": "Himanka",
    "lat": "64.06218",
    "lng": "23.65447"
  },
  {
    "country": "FI",
    "name": "Helsinki",
    "lat": "60.16952",
    "lng": "24.93545"
  },
  {
    "country": "FI",
    "name": "Heinola",
    "lat": "61.20564",
    "lng": "26.03811"
  },
  {
    "country": "FI",
    "name": "Heinävesi",
    "lat": "62.43333",
    "lng": "28.6"
  },
  {
    "country": "FI",
    "name": "Hausjärvi",
    "lat": "60.78333",
    "lng": "24.93333"
  },
  {
    "country": "FI",
    "name": "Haukivuori",
    "lat": "62.01753",
    "lng": "27.21906"
  },
  {
    "country": "FI",
    "name": "Haukipudas",
    "lat": "65.17654",
    "lng": "25.35233"
  },
  {
    "country": "FI",
    "name": "Hauho",
    "lat": "61.17255",
    "lng": "24.56303"
  },
  {
    "country": "FI",
    "name": "Hartola",
    "lat": "61.58333",
    "lng": "26.01667"
  },
  {
    "country": "FI",
    "name": "Harjavalta",
    "lat": "61.31667",
    "lng": "22.13333"
  },
  {
    "country": "FI",
    "name": "Hankasalmi",
    "lat": "62.38333",
    "lng": "26.43333"
  },
  {
    "country": "FI",
    "name": "Hanko",
    "lat": "59.83333",
    "lng": "22.95"
  },
  {
    "country": "FI",
    "name": "Hamina",
    "lat": "60.56974",
    "lng": "27.19794"
  },
  {
    "country": "FI",
    "name": "Hämeenlinna",
    "lat": "60.99596",
    "lng": "24.46434"
  },
  {
    "country": "FI",
    "name": "Hämeenkyrö",
    "lat": "61.63913",
    "lng": "23.19531"
  },
  {
    "country": "FI",
    "name": "Halsua",
    "lat": "63.46667",
    "lng": "24.16667"
  },
  {
    "country": "FI",
    "name": "Halikko",
    "lat": "60.4",
    "lng": "23.08333"
  },
  {
    "country": "FI",
    "name": "Hailuoto",
    "lat": "65.009",
    "lng": "24.71385"
  },
  {
    "country": "FI",
    "name": "Haapavesi",
    "lat": "64.13333",
    "lng": "25.36667"
  },
  {
    "country": "FI",
    "name": "Haapajärvi",
    "lat": "63.75",
    "lng": "25.33333"
  },
  {
    "country": "FI",
    "name": "Gumböle",
    "lat": "60.21948",
    "lng": "24.61684"
  },
  {
    "country": "FI",
    "name": "Forssa",
    "lat": "60.81462",
    "lng": "23.62146"
  },
  {
    "country": "FI",
    "name": "Evijärvi",
    "lat": "63.36667",
    "lng": "23.48333"
  },
  {
    "country": "FI",
    "name": "Eurajoki",
    "lat": "61.2",
    "lng": "21.73333"
  },
  {
    "country": "FI",
    "name": "Eura",
    "lat": "61.13333",
    "lng": "22.13333"
  },
  {
    "country": "FI",
    "name": "Espoo",
    "lat": "60.2052",
    "lng": "24.6522"
  },
  {
    "country": "FI",
    "name": "Enontekiö",
    "lat": "68.38573",
    "lng": "23.63215"
  },
  {
    "country": "FI",
    "name": "Enonkoski",
    "lat": "62.08333",
    "lng": "28.93333"
  },
  {
    "country": "FI",
    "name": "Eno",
    "lat": "62.80511",
    "lng": "30.15422"
  },
  {
    "country": "FI",
    "name": "Elimäki",
    "lat": "60.71667",
    "lng": "26.46667"
  },
  {
    "country": "FI",
    "name": "Ekenäs",
    "lat": "59.97359",
    "lng": "23.43389"
  },
  {
    "country": "FI",
    "name": "Dragsfjärd",
    "lat": "60.06667",
    "lng": "22.48333"
  },
  {
    "country": "FI",
    "name": "Porvoo",
    "lat": "60.39233",
    "lng": "25.66507"
  },
  {
    "country": "FI",
    "name": "Bennäs",
    "lat": "63.6",
    "lng": "22.8"
  },
  {
    "country": "FI",
    "name": "Auttoinen",
    "lat": "61.29901",
    "lng": "25.08887"
  },
  {
    "country": "FI",
    "name": "Aura",
    "lat": "60.6471",
    "lng": "22.58755"
  },
  {
    "country": "FI",
    "name": "Askola",
    "lat": "60.53333",
    "lng": "25.6"
  },
  {
    "country": "FI",
    "name": "Askainen",
    "lat": "60.56667",
    "lng": "21.86667"
  },
  {
    "country": "FI",
    "name": "Asikkala",
    "lat": "61.21667",
    "lng": "25.5"
  },
  {
    "country": "FI",
    "name": "Artjärvi",
    "lat": "60.74544",
    "lng": "26.07084"
  },
  {
    "country": "FI",
    "name": "Anjala",
    "lat": "60.68333",
    "lng": "26.83333"
  },
  {
    "country": "FI",
    "name": "Alavus",
    "lat": "62.58333",
    "lng": "23.61667"
  },
  {
    "country": "FI",
    "name": "Alavieska",
    "lat": "64.16667",
    "lng": "24.3"
  },
  {
    "country": "FI",
    "name": "Alastaro",
    "lat": "60.95",
    "lng": "22.85"
  },
  {
    "country": "FI",
    "name": "Alajärvi",
    "lat": "63",
    "lng": "23.81667"
  },
  {
    "country": "FI",
    "name": "Alahärmä",
    "lat": "63.23333",
    "lng": "22.85"
  },
  {
    "country": "FI",
    "name": "Ähtäri",
    "lat": "62.55403",
    "lng": "24.06186"
  },
  {
    "country": "FI",
    "name": "Äänekoski",
    "lat": "62.6",
    "lng": "25.73333"
  },
  {
    "country": "FI",
    "name": "Äetsä",
    "lat": "61.28333",
    "lng": "22.68333"
  },
  {
    "country": "FI",
    "name": "Kilo",
    "lat": "60.21746",
    "lng": "24.78151"
  },
  {
    "country": "FI",
    "name": "Koukkuniemi",
    "lat": "60.15261",
    "lng": "24.76467"
  },
  {
    "country": "FI",
    "name": "Ristinummi",
    "lat": "63.09192",
    "lng": "21.72297"
  },
  {
    "country": "FI",
    "name": "Teeriniemi",
    "lat": "63.09705",
    "lng": "21.6959"
  },
  {
    "country": "FI",
    "name": "Toijala",
    "lat": "61.1678",
    "lng": "23.83819"
  },
  {
    "country": "FI",
    "name": "Länsi-Turunmaa",
    "lat": "60.29972",
    "lng": "22.3004"
  },
  {
    "country": "FI",
    "name": "Älajärvi",
    "lat": "63.00027",
    "lng": "23.81586"
  },
  {
    "country": "FJ",
    "name": "Suva",
    "lat": "-18.14161",
    "lng": "178.44149"
  },
  {
    "country": "FJ",
    "name": "Nadi",
    "lat": "-17.80309",
    "lng": "177.41617"
  },
  {
    "country": "FJ",
    "name": "Levuka",
    "lat": "-18.06667",
    "lng": "179.31667"
  },
  {
    "country": "FJ",
    "name": "Lautoka",
    "lat": "-17.61686",
    "lng": "177.45049"
  },
  {
    "country": "FJ",
    "name": "Labasa",
    "lat": "-16.4332",
    "lng": "179.36451"
  },
  {
    "country": "FJ",
    "name": "Ahau",
    "lat": "-12.5",
    "lng": "177.05"
  },
  {
    "country": "FJ",
    "name": "Ba",
    "lat": "-17.5343",
    "lng": "177.67407"
  },
  {
    "country": "FK",
    "name": "Stanley",
    "lat": "-51.69382",
    "lng": "-57.85701"
  },
  {
    "country": "FM",
    "name": "Weno",
    "lat": "7.44648",
    "lng": "151.84135"
  },
  {
    "country": "FM",
    "name": "Tofol",
    "lat": "5.32479",
    "lng": "163.00781"
  },
  {
    "country": "FM",
    "name": "Palikir - National Government Center",
    "lat": "6.92477",
    "lng": "158.16109"
  },
  {
    "country": "FM",
    "name": "Kolonia Town",
    "lat": "6.964",
    "lng": "158.206"
  },
  {
    "country": "FM",
    "name": "Rumung",
    "lat": "9.622",
    "lng": "138.154"
  },
  {
    "country": "FM",
    "name": "Kolonia",
    "lat": "6.964",
    "lng": "158.2062"
  },
  {
    "country": "FM",
    "name": "Kapingamarangi",
    "lat": "1.07861",
    "lng": "154.80752"
  },
  {
    "country": "FM",
    "name": "Nukuoro",
    "lat": "3.83619",
    "lng": "154.97143"
  },
  {
    "country": "FM",
    "name": "Ngatik",
    "lat": "5.7885",
    "lng": "157.15942"
  },
  {
    "country": "FM",
    "name": "Pingelap",
    "lat": "6.20589",
    "lng": "160.70327"
  },
  {
    "country": "FM",
    "name": "Namoluk",
    "lat": "5.915",
    "lng": "153.14"
  },
  {
    "country": "FM",
    "name": "Houk",
    "lat": "6.6894",
    "lng": "149.29908"
  },
  {
    "country": "FM",
    "name": "Polowat",
    "lat": "7.35661",
    "lng": "149.19908"
  },
  {
    "country": "FM",
    "name": "Pulap",
    "lat": "7.6366",
    "lng": "149.42878"
  },
  {
    "country": "FM",
    "name": "Tamatam",
    "lat": "7.53868",
    "lng": "149.41428"
  },
  {
    "country": "FM",
    "name": "Onoun",
    "lat": "8.575",
    "lng": "149.687"
  },
  {
    "country": "FM",
    "name": "Pisaras",
    "lat": "8.569",
    "lng": "150.4195"
  },
  {
    "country": "FM",
    "name": "Onou",
    "lat": "8.799",
    "lng": "150.2915"
  },
  {
    "country": "FM",
    "name": "Unanu",
    "lat": "8.75",
    "lng": "150.341"
  },
  {
    "country": "FM",
    "name": "Makur",
    "lat": "8.985",
    "lng": "150.1275"
  },
  {
    "country": "FM",
    "name": "Mokil",
    "lat": "6.69281",
    "lng": "159.76283"
  },
  {
    "country": "FM",
    "name": "Nomwin",
    "lat": "8.43",
    "lng": "151.748"
  },
  {
    "country": "FM",
    "name": "Fananu",
    "lat": "8.55811",
    "lng": "151.90922"
  },
  {
    "country": "FM",
    "name": "Murilo",
    "lat": "8.692",
    "lng": "152.3435"
  },
  {
    "country": "FM",
    "name": "Ruo",
    "lat": "8.609",
    "lng": "152.2455"
  },
  {
    "country": "FM",
    "name": "Nema",
    "lat": "6.993",
    "lng": "152.575"
  },
  {
    "country": "FM",
    "name": "Losap",
    "lat": "6.894",
    "lng": "152.74"
  },
  {
    "country": "FM",
    "name": "Piis",
    "lat": "6.834",
    "lng": "152.701"
  },
  {
    "country": "FM",
    "name": "Ettal",
    "lat": "5.592",
    "lng": "153.564"
  },
  {
    "country": "FM",
    "name": "Lukunor",
    "lat": "5.507",
    "lng": "153.8205"
  },
  {
    "country": "FM",
    "name": "Oneop",
    "lat": "5.5066",
    "lng": "153.7105"
  },
  {
    "country": "FM",
    "name": "Moch",
    "lat": "5.4918",
    "lng": "153.54"
  },
  {
    "country": "FM",
    "name": "Kuttu",
    "lat": "5.453",
    "lng": "153.4575"
  },
  {
    "country": "FM",
    "name": "Ta",
    "lat": "5.2842",
    "lng": "153.648"
  },
  {
    "country": "FM",
    "name": "Satowan",
    "lat": "5.334",
    "lng": "153.738"
  },
  {
    "country": "FM",
    "name": "Satawal",
    "lat": "7.382",
    "lng": "147.0322"
  },
  {
    "country": "FM",
    "name": "Lamotrek",
    "lat": "7.491",
    "lng": "146.305"
  },
  {
    "country": "FM",
    "name": "Elato",
    "lat": "7.502",
    "lng": "146.166"
  },
  {
    "country": "FM",
    "name": "Faraulep",
    "lat": "8.588",
    "lng": "144.508"
  },
  {
    "country": "FM",
    "name": "Ifalik",
    "lat": "7.25",
    "lng": "144.4445"
  },
  {
    "country": "FM",
    "name": "Eauripik",
    "lat": "6.687",
    "lng": "143.0375"
  },
  {
    "country": "FM",
    "name": "Sorol",
    "lat": "8.1435",
    "lng": "140.394"
  },
  {
    "country": "FM",
    "name": "Fais",
    "lat": "9.766",
    "lng": "140.52"
  },
  {
    "country": "FM",
    "name": "Ngulu",
    "lat": "8.45",
    "lng": "137.484"
  },
  {
    "country": "FM",
    "name": "Colonia",
    "lat": "9.51638",
    "lng": "138.12167"
  },
  {
    "country": "FM",
    "name": "Lelu",
    "lat": "5.33359",
    "lng": "163.02248"
  },
  {
    "country": "FM",
    "name": "Tafunsak",
    "lat": "5.3671",
    "lng": "162.98532"
  },
  {
    "country": "FM",
    "name": "Malem",
    "lat": "5.28599",
    "lng": "163.02609"
  },
  {
    "country": "FM",
    "name": "Utwe",
    "lat": "5.27486",
    "lng": "162.97656"
  },
  {
    "country": "FM",
    "name": "Madolenihm Municipality Government",
    "lat": "6.83493",
    "lng": "158.2987"
  },
  {
    "country": "FM",
    "name": "Tonoas Municipal Building",
    "lat": "7.37597",
    "lng": "151.88433"
  },
  {
    "country": "FM",
    "name": "Weno Municipal Offices",
    "lat": "7.44428",
    "lng": "151.84103"
  },
  {
    "country": "FO",
    "name": "Vestmanna",
    "lat": "62.15354",
    "lng": "-7.17291"
  },
  {
    "country": "FO",
    "name": "Vágur",
    "lat": "61.47324",
    "lng": "-6.81185"
  },
  {
    "country": "FO",
    "name": "Tvøroyri",
    "lat": "61.55557",
    "lng": "-6.81109"
  },
  {
    "country": "FO",
    "name": "Tórshavn",
    "lat": "62.00973",
    "lng": "-6.77164"
  },
  {
    "country": "FO",
    "name": "Sørvágur",
    "lat": "62.07203",
    "lng": "-7.30749"
  },
  {
    "country": "FO",
    "name": "Sandur",
    "lat": "61.8425",
    "lng": "-6.80778"
  },
  {
    "country": "FO",
    "name": "Miðvágur",
    "lat": "62.05111",
    "lng": "-7.19389"
  },
  {
    "country": "FO",
    "name": "Kunoy",
    "lat": "62.30388",
    "lng": "-6.64754"
  },
  {
    "country": "FO",
    "name": "Kollafjørður",
    "lat": "62.11167",
    "lng": "-6.91067"
  },
  {
    "country": "FO",
    "name": "Klaksvík",
    "lat": "62.22655",
    "lng": "-6.58901"
  },
  {
    "country": "FO",
    "name": "Hoyvík",
    "lat": "62.03407",
    "lng": "-6.78127"
  },
  {
    "country": "FO",
    "name": "Fuglafjørður",
    "lat": "62.24398",
    "lng": "-6.81395"
  },
  {
    "country": "FO",
    "name": "Eiði",
    "lat": "62.2993",
    "lng": "-7.09245"
  },
  {
    "country": "FO",
    "name": "Argir",
    "lat": "61.99595",
    "lng": "-6.77154"
  },
  {
    "country": "FO",
    "name": "Eystur",
    "lat": "62.20907",
    "lng": "-6.75247"
  },
  {
    "country": "FR",
    "name": "Peyrat-le-Château",
    "lat": "45.81578",
    "lng": "1.77233"
  },
  {
    "country": "FR",
    "name": "Blaye",
    "lat": "45.13333",
    "lng": "-0.66667"
  },
  {
    "country": "FR",
    "name": "Zuydcoote",
    "lat": "51.06096",
    "lng": "2.49338"
  },
  {
    "country": "FR",
    "name": "Zutkerque",
    "lat": "50.85303",
    "lng": "2.06818"
  },
  {
    "country": "FR",
    "name": "Zonza",
    "lat": "41.74813",
    "lng": "9.17102"
  },
  {
    "country": "FR",
    "name": "Zimmersheim",
    "lat": "47.72021",
    "lng": "7.38819"
  },
  {
    "country": "FR",
    "name": "Zillisheim",
    "lat": "47.69562",
    "lng": "7.29516"
  },
  {
    "country": "FR",
    "name": "Zegerscappel",
    "lat": "50.88333",
    "lng": "2.4"
  },
  {
    "country": "FR",
    "name": "Yzeures-sur-Creuse",
    "lat": "46.78609",
    "lng": "0.87166"
  },
  {
    "country": "FR",
    "name": "Yzeure",
    "lat": "46.56438",
    "lng": "3.35495"
  },
  {
    "country": "FR",
    "name": "Yzernay",
    "lat": "47.02229",
    "lng": "-0.70295"
  },
  {
    "country": "FR",
    "name": "Yvré-le-Pôlin",
    "lat": "47.82235",
    "lng": "0.15581"
  },
  {
    "country": "FR",
    "name": "Yvrac",
    "lat": "44.87786",
    "lng": "-0.4587"
  },
  {
    "country": "FR",
    "name": "Yvignac-la-Tour",
    "lat": "48.35",
    "lng": "-2.18333"
  },
  {
    "country": "FR",
    "name": "Yvetot",
    "lat": "49.61744",
    "lng": "0.75814"
  },
  {
    "country": "FR",
    "name": "Yves",
    "lat": "46.01922",
    "lng": "-1.04833"
  },
  {
    "country": "FR",
    "name": "Ytrac",
    "lat": "44.91343",
    "lng": "2.36295"
  },
  {
    "country": "FR",
    "name": "Yssingeaux",
    "lat": "45.13333",
    "lng": "4.11667"
  },
  {
    "country": "FR",
    "name": "Yport",
    "lat": "49.73716",
    "lng": "0.31537"
  },
  {
    "country": "FR",
    "name": "Youx",
    "lat": "46.14441",
    "lng": "2.80004"
  },
  {
    "country": "FR",
    "name": "Ymare",
    "lat": "49.3506",
    "lng": "1.17938"
  },
  {
    "country": "FR",
    "name": "Ygos-Saint-Saturnin",
    "lat": "43.97651",
    "lng": "-0.7378"
  },
  {
    "country": "FR",
    "name": "Yffiniac",
    "lat": "48.48428",
    "lng": "-2.67647"
  },
  {
    "country": "FR",
    "name": "Yèvres",
    "lat": "48.21078",
    "lng": "1.18717"
  },
  {
    "country": "FR",
    "name": "Yerville",
    "lat": "49.6672",
    "lng": "0.89594"
  },
  {
    "country": "FR",
    "name": "Yerres",
    "lat": "48.71785",
    "lng": "2.49338"
  },
  {
    "country": "FR",
    "name": "Yenne",
    "lat": "45.7042",
    "lng": "5.75795"
  },
  {
    "country": "FR",
    "name": "Yébleron",
    "lat": "49.63333",
    "lng": "0.53746"
  },
  {
    "country": "FR",
    "name": "Ydes",
    "lat": "45.33333",
    "lng": "2.46667"
  },
  {
    "country": "FR",
    "name": "Ychoux",
    "lat": "44.32869",
    "lng": "-0.95179"
  },
  {
    "country": "FR",
    "name": "Yainville",
    "lat": "49.45371",
    "lng": "0.8292"
  },
  {
    "country": "FR",
    "name": "Xonrupt-Longemer",
    "lat": "48.08223",
    "lng": "6.92944"
  },
  {
    "country": "FR",
    "name": "Xertigny",
    "lat": "48.04394",
    "lng": "6.40836"
  },
  {
    "country": "FR",
    "name": "Woustviller",
    "lat": "49.07636",
    "lng": "7.00487"
  },
  {
    "country": "FR",
    "name": "Wormhout",
    "lat": "50.88129",
    "lng": "2.46901"
  },
  {
    "country": "FR",
    "name": "Wolfisheim",
    "lat": "48.58723",
    "lng": "7.66708"
  },
  {
    "country": "FR",
    "name": "Wolfgantzen",
    "lat": "48.02805",
    "lng": "7.5004"
  },
  {
    "country": "FR",
    "name": "Woippy",
    "lat": "49.15111",
    "lng": "6.15132"
  },
  {
    "country": "FR",
    "name": "Woincourt",
    "lat": "50.0663",
    "lng": "1.53676"
  },
  {
    "country": "FR",
    "name": "Woerth",
    "lat": "48.93953",
    "lng": "7.74279"
  },
  {
    "country": "FR",
    "name": "Wizernes",
    "lat": "50.7117",
    "lng": "2.24316"
  },
  {
    "country": "FR",
    "name": "Wittisheim",
    "lat": "48.26451",
    "lng": "7.58683"
  },
  {
    "country": "FR",
    "name": "Wittenheim",
    "lat": "47.8078",
    "lng": "7.33702"
  },
  {
    "country": "FR",
    "name": "Wittelsheim",
    "lat": "47.80947",
    "lng": "7.24154"
  },
  {
    "country": "FR",
    "name": "Witry-lès-Reims",
    "lat": "49.29162",
    "lng": "4.11921"
  },
  {
    "country": "FR",
    "name": "Wissous",
    "lat": "48.73352",
    "lng": "2.32338"
  },
  {
    "country": "FR",
    "name": "Wissembourg",
    "lat": "49.03708",
    "lng": "7.94548"
  },
  {
    "country": "FR",
    "name": "Wissant",
    "lat": "50.8853",
    "lng": "1.66263"
  },
  {
    "country": "FR",
    "name": "Wisches",
    "lat": "48.50881",
    "lng": "7.26814"
  },
  {
    "country": "FR",
    "name": "Wintzenheim",
    "lat": "48.07269",
    "lng": "7.29072"
  },
  {
    "country": "FR",
    "name": "Winnezeele",
    "lat": "50.841",
    "lng": "2.55118"
  },
  {
    "country": "FR",
    "name": "Wingles",
    "lat": "50.49382",
    "lng": "2.855"
  },
  {
    "country": "FR",
    "name": "Wingersheim",
    "lat": "48.72149",
    "lng": "7.63464"
  },
  {
    "country": "FR",
    "name": "Wingen-sur-Moder",
    "lat": "48.919",
    "lng": "7.37955"
  },
  {
    "country": "FR",
    "name": "Wimmenau",
    "lat": "48.91217",
    "lng": "7.42189"
  },
  {
    "country": "FR",
    "name": "Wimille",
    "lat": "50.76418",
    "lng": "1.63137"
  },
  {
    "country": "FR",
    "name": "Wimereux",
    "lat": "50.76963",
    "lng": "1.61139"
  },
  {
    "country": "FR",
    "name": "Willerwald",
    "lat": "49.02481",
    "lng": "7.03726"
  },
  {
    "country": "FR",
    "name": "Willems",
    "lat": "50.63206",
    "lng": "3.2384"
  },
  {
    "country": "FR",
    "name": "Wihr-au-Val",
    "lat": "48.05312",
    "lng": "7.20489"
  },
  {
    "country": "FR",
    "name": "Wignehies",
    "lat": "50.0155",
    "lng": "4.00913"
  },
  {
    "country": "FR",
    "name": "Wiesviller",
    "lat": "49.08095",
    "lng": "7.16415"
  },
  {
    "country": "FR",
    "name": "Widensolen",
    "lat": "48.06289",
    "lng": "7.48057"
  },
  {
    "country": "FR",
    "name": "Weyersheim",
    "lat": "48.71622",
    "lng": "7.80127"
  },
  {
    "country": "FR",
    "name": "Wettolsheim",
    "lat": "48.05755",
    "lng": "7.29844"
  },
  {
    "country": "FR",
    "name": "Westhoffen",
    "lat": "48.60352",
    "lng": "7.44289"
  },
  {
    "country": "FR",
    "name": "Wervicq-Sud",
    "lat": "50.7745",
    "lng": "3.04207"
  },
  {
    "country": "FR",
    "name": "Weitbruch",
    "lat": "48.75455",
    "lng": "7.77935"
  },
  {
    "country": "FR",
    "name": "Waziers",
    "lat": "50.38717",
    "lng": "3.1149"
  },
  {
    "country": "FR",
    "name": "Wavrin",
    "lat": "50.57386",
    "lng": "2.9363"
  },
  {
    "country": "FR",
    "name": "Wavrechain-sous-Denain",
    "lat": "50.33224",
    "lng": "3.41252"
  },
  {
    "country": "FR",
    "name": "Wavignies",
    "lat": "49.54748",
    "lng": "2.36032"
  },
  {
    "country": "FR",
    "name": "Wattwiller",
    "lat": "47.83649",
    "lng": "7.17785"
  },
  {
    "country": "FR",
    "name": "Wattrelos",
    "lat": "50.70118",
    "lng": "3.21812"
  },
  {
    "country": "FR",
    "name": "Wattignies",
    "lat": "50.58639",
    "lng": "3.04394"
  },
  {
    "country": "FR",
    "name": "Watten",
    "lat": "50.83685",
    "lng": "2.21346"
  },
  {
    "country": "FR",
    "name": "Wassy",
    "lat": "48.49811",
    "lng": "4.94775"
  },
  {
    "country": "FR",
    "name": "Wassigny",
    "lat": "50.01334",
    "lng": "3.59988"
  },
  {
    "country": "FR",
    "name": "Wasselonne",
    "lat": "48.63779",
    "lng": "7.44506"
  },
  {
    "country": "FR",
    "name": "Wasquehal",
    "lat": "50.67043",
    "lng": "3.13382"
  },
  {
    "country": "FR",
    "name": "Warmeriville",
    "lat": "49.35227",
    "lng": "4.21882"
  },
  {
    "country": "FR",
    "name": "Warluis",
    "lat": "49.38874",
    "lng": "2.1422"
  },
  {
    "country": "FR",
    "name": "Warhem",
    "lat": "50.97592",
    "lng": "2.49303"
  },
  {
    "country": "FR",
    "name": "Wargnies-le-Grand",
    "lat": "50.30751",
    "lng": "3.66038"
  },
  {
    "country": "FR",
    "name": "Wardrecques",
    "lat": "50.71108",
    "lng": "2.34483"
  },
  {
    "country": "FR",
    "name": "Warcq",
    "lat": "49.77517",
    "lng": "4.68175"
  },
  {
    "country": "FR",
    "name": "Wangenbourg-Engenthal",
    "lat": "48.62805",
    "lng": "7.30471"
  },
  {
    "country": "FR",
    "name": "Wandignies-Hamage",
    "lat": "50.39609",
    "lng": "3.3145"
  },
  {
    "country": "FR",
    "name": "Wambrechies",
    "lat": "50.68276",
    "lng": "3.04784"
  },
  {
    "country": "FR",
    "name": "Walscheid",
    "lat": "48.65308",
    "lng": "7.14998"
  },
  {
    "country": "FR",
    "name": "Wallers",
    "lat": "50.37432",
    "lng": "3.39188"
  },
  {
    "country": "FR",
    "name": "Walincourt-Selvigny",
    "lat": "50.06667",
    "lng": "3.33333"
  },
  {
    "country": "FR",
    "name": "Waldighofen",
    "lat": "47.55126",
    "lng": "7.31743"
  },
  {
    "country": "FR",
    "name": "Walbourg",
    "lat": "48.88628",
    "lng": "7.78828"
  },
  {
    "country": "FR",
    "name": "Wailly",
    "lat": "50.52287",
    "lng": "2.06792"
  },
  {
    "country": "FR",
    "name": "Wahagnies",
    "lat": "50.48665",
    "lng": "3.03448"
  },
  {
    "country": "FR",
    "name": "Vulaines-sur-Seine",
    "lat": "48.43186",
    "lng": "2.76476"
  },
  {
    "country": "FR",
    "name": "Vue",
    "lat": "47.19953",
    "lng": "-1.8775"
  },
  {
    "country": "FR",
    "name": "Vrigne-aux-Bois",
    "lat": "49.73716",
    "lng": "4.85567"
  },
  {
    "country": "FR",
    "name": "Vred",
    "lat": "50.39455",
    "lng": "3.23029"
  },
  {
    "country": "FR",
    "name": "Voves",
    "lat": "48.27138",
    "lng": "1.62583"
  },
  {
    "country": "FR",
    "name": "Vouzon",
    "lat": "47.64515",
    "lng": "2.05609"
  },
  {
    "country": "FR",
    "name": "Vouziers",
    "lat": "49.4",
    "lng": "4.7"
  },
  {
    "country": "FR",
    "name": "Vouvray",
    "lat": "47.41087",
    "lng": "0.79892"
  },
  {
    "country": "FR",
    "name": "Voutezac",
    "lat": "45.29246",
    "lng": "1.43714"
  },
  {
    "country": "FR",
    "name": "Vourles",
    "lat": "45.65674",
    "lng": "4.77157"
  },
  {
    "country": "FR",
    "name": "Vourey",
    "lat": "45.31958",
    "lng": "5.52028"
  },
  {
    "country": "FR",
    "name": "Vouneuil-sur-Vienne",
    "lat": "46.71793",
    "lng": "0.53936"
  },
  {
    "country": "FR",
    "name": "Vouneuil-sous-Biard",
    "lat": "46.57387",
    "lng": "0.26988"
  },
  {
    "country": "FR",
    "name": "Voulx",
    "lat": "48.28204",
    "lng": "2.96747"
  },
  {
    "country": "FR",
    "name": "Voulangis",
    "lat": "48.85252",
    "lng": "2.89558"
  },
  {
    "country": "FR",
    "name": "Voujeaucourt",
    "lat": "47.47513",
    "lng": "6.77431"
  },
  {
    "country": "FR",
    "name": "Vouillé",
    "lat": "46.64011",
    "lng": "0.16778"
  },
  {
    "country": "FR",
    "name": "Vouillé",
    "lat": "46.3155",
    "lng": "-0.36845"
  },
  {
    "country": "FR",
    "name": "Vougy",
    "lat": "46.1018",
    "lng": "4.11973"
  },
  {
    "country": "FR",
    "name": "Vougy",
    "lat": "46.06676",
    "lng": "6.49419"
  },
  {
    "country": "FR",
    "name": "Vorey",
    "lat": "45.18357",
    "lng": "3.90992"
  },
  {
    "country": "FR",
    "name": "Voreppe",
    "lat": "45.29476",
    "lng": "5.63324"
  },
  {
    "country": "FR",
    "name": "Vonnas",
    "lat": "46.21867",
    "lng": "4.99161"
  },
  {
    "country": "FR",
    "name": "Volx",
    "lat": "43.87383",
    "lng": "5.8413"
  },
  {
    "country": "FR",
    "name": "Volvic",
    "lat": "45.87196",
    "lng": "3.03832"
  },
  {
    "country": "FR",
    "name": "Volstroff",
    "lat": "49.31135",
    "lng": "6.25976"
  },
  {
    "country": "FR",
    "name": "Volonne",
    "lat": "44.11039",
    "lng": "6.01424"
  },
  {
    "country": "FR",
    "name": "Volmerange-les-Mines",
    "lat": "49.44326",
    "lng": "6.08062"
  },
  {
    "country": "FR",
    "name": "Voisins-le-Bretonneux",
    "lat": "48.75793",
    "lng": "2.05137"
  },
  {
    "country": "FR",
    "name": "Voisenon",
    "lat": "48.5717",
    "lng": "2.6648"
  },
  {
    "country": "FR",
    "name": "Voiron",
    "lat": "45.36395",
    "lng": "5.59209"
  },
  {
    "country": "FR",
    "name": "Void-Vacon",
    "lat": "48.68333",
    "lng": "5.61667"
  },
  {
    "country": "FR",
    "name": "Voglans",
    "lat": "45.6339",
    "lng": "5.90227"
  },
  {
    "country": "FR",
    "name": "Volgelsheim",
    "lat": "48.01462",
    "lng": "7.55456"
  },
  {
    "country": "FR",
    "name": "Vœuil-et-Giget",
    "lat": "45.58333",
    "lng": "0.15"
  },
  {
    "country": "FR",
    "name": "Vizille",
    "lat": "45.07819",
    "lng": "5.77074"
  },
  {
    "country": "FR",
    "name": "Vix",
    "lat": "46.36456",
    "lng": "-0.86072"
  },
  {
    "country": "FR",
    "name": "Vivy",
    "lat": "47.32648",
    "lng": "-0.05531"
  },
  {
    "country": "FR",
    "name": "Vivonne",
    "lat": "46.42953",
    "lng": "0.26443"
  },
  {
    "country": "FR",
    "name": "Viviez",
    "lat": "44.55678",
    "lng": "2.21649"
  },
  {
    "country": "FR",
    "name": "Viviers-lès-Montagnes",
    "lat": "43.55474",
    "lng": "2.17672"
  },
  {
    "country": "FR",
    "name": "Viviers",
    "lat": "44.48515",
    "lng": "4.68721"
  },
  {
    "country": "FR",
    "name": "Vivier-au-Court",
    "lat": "49.73326",
    "lng": "4.82939"
  },
  {
    "country": "FR",
    "name": "Viuz-la-Chiésaz",
    "lat": "45.81084",
    "lng": "6.06207"
  },
  {
    "country": "FR",
    "name": "Viuz-en-Sallaz",
    "lat": "46.14556",
    "lng": "6.40986"
  },
  {
    "country": "FR",
    "name": "Vittel",
    "lat": "48.20085",
    "lng": "5.94843"
  },
  {
    "country": "FR",
    "name": "Vitteaux",
    "lat": "47.39732",
    "lng": "4.5419"
  },
  {
    "country": "FR",
    "name": "Vitry-sur-Seine",
    "lat": "48.78716",
    "lng": "2.40332"
  },
  {
    "country": "FR",
    "name": "Vitry-sur-Orne",
    "lat": "49.26595",
    "lng": "6.11074"
  },
  {
    "country": "FR",
    "name": "Vitry-le-François",
    "lat": "48.73333",
    "lng": "4.58333"
  },
  {
    "country": "FR",
    "name": "Vitry-en-Artois",
    "lat": "50.3266",
    "lng": "2.97999"
  },
  {
    "country": "FR",
    "name": "Vitry-aux-Loges",
    "lat": "47.93333",
    "lng": "2.26667"
  },
  {
    "country": "FR",
    "name": "Vitrolles",
    "lat": "43.46",
    "lng": "5.24861"
  },
  {
    "country": "FR",
    "name": "Vitré",
    "lat": "48.11776",
    "lng": "-1.20577"
  },
  {
    "country": "FR",
    "name": "Visan",
    "lat": "44.3141",
    "lng": "4.95202"
  },
  {
    "country": "FR",
    "name": "Viry-Noureuil",
    "lat": "49.63214",
    "lng": "3.24322"
  },
  {
    "country": "FR",
    "name": "Viry-Châtillon",
    "lat": "48.67211",
    "lng": "2.39318"
  },
  {
    "country": "FR",
    "name": "Viry",
    "lat": "46.11717",
    "lng": "6.03717"
  },
  {
    "country": "FR",
    "name": "Viroflay",
    "lat": "48.80078",
    "lng": "2.16181"
  },
  {
    "country": "FR",
    "name": "Viriville",
    "lat": "45.31737",
    "lng": "5.20373"
  },
  {
    "country": "FR",
    "name": "Virieu-le-Grand",
    "lat": "45.84851",
    "lng": "5.64979"
  },
  {
    "country": "FR",
    "name": "Virieu",
    "lat": "45.48399",
    "lng": "5.47501"
  },
  {
    "country": "FR",
    "name": "Viriat",
    "lat": "46.25484",
    "lng": "5.21567"
  },
  {
    "country": "FR",
    "name": "Virey-le-Grand",
    "lat": "46.83333",
    "lng": "4.86667"
  },
  {
    "country": "FR",
    "name": "Vireux-Wallerand",
    "lat": "50.08196",
    "lng": "4.73017"
  },
  {
    "country": "FR",
    "name": "Vireux-Molhain",
    "lat": "50.07874",
    "lng": "4.72426"
  },
  {
    "country": "FR",
    "name": "Vire",
    "lat": "48.83333",
    "lng": "-0.88333"
  },
  {
    "country": "FR",
    "name": "Virazeil",
    "lat": "44.50705",
    "lng": "0.22177"
  },
  {
    "country": "FR",
    "name": "Vion",
    "lat": "47.81923",
    "lng": "-0.23916"
  },
  {
    "country": "FR",
    "name": "Violès",
    "lat": "44.16146",
    "lng": "4.95329"
  },
  {
    "country": "FR",
    "name": "Violay",
    "lat": "45.85283",
    "lng": "4.35724"
  },
  {
    "country": "FR",
    "name": "Violaines",
    "lat": "50.5416",
    "lng": "2.7886"
  },
  {
    "country": "FR",
    "name": "Vinsobres",
    "lat": "44.33315",
    "lng": "5.06208"
  },
  {
    "country": "FR",
    "name": "Vinon-sur-Verdon",
    "lat": "43.72451",
    "lng": "5.81081"
  },
  {
    "country": "FR",
    "name": "Vinneuf",
    "lat": "48.34795",
    "lng": "3.14013"
  },
  {
    "country": "FR",
    "name": "Vineuil-Saint-Firmin",
    "lat": "49.20024",
    "lng": "2.49567"
  },
  {
    "country": "FR",
    "name": "Vineuil",
    "lat": "47.5838",
    "lng": "1.37601"
  },
  {
    "country": "FR",
    "name": "Vineuil",
    "lat": "46.90038",
    "lng": "1.63543"
  },
  {
    "country": "FR",
    "name": "Vincey",
    "lat": "48.33749",
    "lng": "6.33134"
  },
  {
    "country": "FR",
    "name": "Vincennes",
    "lat": "48.8486",
    "lng": "2.43769"
  },
  {
    "country": "FR",
    "name": "Vinça",
    "lat": "42.64486",
    "lng": "2.5283"
  },
  {
    "country": "FR",
    "name": "Vinay",
    "lat": "45.21075",
    "lng": "5.40806"
  },
  {
    "country": "FR",
    "name": "Vinassan",
    "lat": "43.20443",
    "lng": "3.07463"
  },
  {
    "country": "FR",
    "name": "Vimy",
    "lat": "50.37243",
    "lng": "2.81034"
  },
  {
    "country": "FR",
    "name": "Vimoutiers",
    "lat": "48.92772",
    "lng": "0.19835"
  },
  {
    "country": "FR",
    "name": "Vimory",
    "lat": "47.94786",
    "lng": "2.68701"
  },
  {
    "country": "FR",
    "name": "Vimines",
    "lat": "45.54741",
    "lng": "5.86493"
  },
  {
    "country": "FR",
    "name": "Villiers-sur-Orge",
    "lat": "48.65953",
    "lng": "2.30002"
  },
  {
    "country": "FR",
    "name": "Villiers-sur-Morin",
    "lat": "48.86099",
    "lng": "2.87773"
  },
  {
    "country": "FR",
    "name": "Villiers-sur-Marne",
    "lat": "48.831",
    "lng": "2.54844"
  },
  {
    "country": "FR",
    "name": "Villiers-sur-Loir",
    "lat": "47.80507",
    "lng": "0.99774"
  },
  {
    "country": "FR",
    "name": "Villiers-Saint-Georges",
    "lat": "48.64998",
    "lng": "3.40754"
  },
  {
    "country": "FR",
    "name": "Villiers-Saint-Fréderic",
    "lat": "48.81667",
    "lng": "1.88333"
  },
  {
    "country": "FR",
    "name": "Villiers-le-Morhier",
    "lat": "48.62018",
    "lng": "1.56349"
  },
  {
    "country": "FR",
    "name": "Villiers-le-Bel",
    "lat": "49.00875",
    "lng": "2.39819"
  },
  {
    "country": "FR",
    "name": "Villiers-le-Bâcle",
    "lat": "48.72819",
    "lng": "2.11925"
  },
  {
    "country": "FR",
    "name": "Villiers-en-Plaine",
    "lat": "46.40895",
    "lng": "-0.53756"
  },
  {
    "country": "FR",
    "name": "Villiers-en-Lieu",
    "lat": "48.66785",
    "lng": "4.89755"
  },
  {
    "country": "FR",
    "name": "Villié-Morgon",
    "lat": "46.16229",
    "lng": "4.68056"
  },
  {
    "country": "FR",
    "name": "Villey-Saint-Étienne",
    "lat": "48.73136",
    "lng": "5.97841"
  },
  {
    "country": "FR",
    "name": "Villevocance",
    "lat": "45.22659",
    "lng": "4.59103"
  },
  {
    "country": "FR",
    "name": "Villevieille",
    "lat": "43.78795",
    "lng": "4.09756"
  },
  {
    "country": "FR",
    "name": "Villeveyrac",
    "lat": "43.50095",
    "lng": "3.60723"
  },
  {
    "country": "FR",
    "name": "Villevêque",
    "lat": "47.56095",
    "lng": "-0.42383"
  },
  {
    "country": "FR",
    "name": "Villevaudé",
    "lat": "48.91751",
    "lng": "2.65228"
  },
  {
    "country": "FR",
    "name": "Villeurbanne",
    "lat": "45.76667",
    "lng": "4.88333"
  },
  {
    "country": "FR",
    "name": "Villette-de-Vienne",
    "lat": "45.58908",
    "lng": "4.91398"
  },
  {
    "country": "FR",
    "name": "Villetelle",
    "lat": "43.73105",
    "lng": "4.13658"
  },
  {
    "country": "FR",
    "name": "Villetaneuse",
    "lat": "48.95833",
    "lng": "2.34167"
  },
  {
    "country": "FR",
    "name": "Villes-sur-Auzon",
    "lat": "44.05669",
    "lng": "5.2343"
  },
  {
    "country": "FR",
    "name": "Ville-sous-la-Ferté",
    "lat": "48.1206",
    "lng": "4.78957"
  },
  {
    "country": "FR",
    "name": "Ville-sous-Anjou",
    "lat": "45.37194",
    "lng": "4.85106"
  },
  {
    "country": "FR",
    "name": "Villerupt",
    "lat": "49.46737",
    "lng": "5.93285"
  },
  {
    "country": "FR",
    "name": "Villers-sur-Mer",
    "lat": "49.32264",
    "lng": "0.00027"
  },
  {
    "country": "FR",
    "name": "Villers-sur-Coudun",
    "lat": "49.48308",
    "lng": "2.80457"
  },
  {
    "country": "FR",
    "name": "Villers-sous-Saint-Leu",
    "lat": "49.21235",
    "lng": "2.39485"
  },
  {
    "country": "FR",
    "name": "Villers-Semeuse",
    "lat": "49.74201",
    "lng": "4.74697"
  },
  {
    "country": "FR",
    "name": "Villers-Saint-Paul",
    "lat": "49.28885",
    "lng": "2.48968"
  },
  {
    "country": "FR",
    "name": "Villers-Pol",
    "lat": "50.2846",
    "lng": "3.61449"
  },
  {
    "country": "FR",
    "name": "Villers-Outréaux",
    "lat": "50.0359",
    "lng": "3.29947"
  },
  {
    "country": "FR",
    "name": "Villers-lès-Nancy",
    "lat": "48.67103",
    "lng": "6.15083"
  },
  {
    "country": "FR",
    "name": "Villers-le-Lac",
    "lat": "47.06319",
    "lng": "6.66699"
  },
  {
    "country": "FR",
    "name": "Villers-la-Montagne",
    "lat": "49.47108",
    "lng": "5.82412"
  },
  {
    "country": "FR",
    "name": "Villersexel",
    "lat": "47.5507",
    "lng": "6.43273"
  },
  {
    "country": "FR",
    "name": "Villers-en-Cauchies",
    "lat": "50.22574",
    "lng": "3.40362"
  },
  {
    "country": "FR",
    "name": "Villers-Écalles",
    "lat": "49.54136",
    "lng": "0.91942"
  },
  {
    "country": "FR",
    "name": "Villers-Cotterêts",
    "lat": "49.25311",
    "lng": "3.09003"
  },
  {
    "country": "FR",
    "name": "Villers-Bretonneux",
    "lat": "49.86844",
    "lng": "2.51688"
  },
  {
    "country": "FR",
    "name": "Villers-Bocage",
    "lat": "49.9981",
    "lng": "2.31683"
  },
  {
    "country": "FR",
    "name": "Villers-Bocage",
    "lat": "49.0796",
    "lng": "-0.65412"
  },
  {
    "country": "FR",
    "name": "Villereversure",
    "lat": "46.18509",
    "lng": "5.38269"
  },
  {
    "country": "FR",
    "name": "Villerest",
    "lat": "46",
    "lng": "4.03333"
  },
  {
    "country": "FR",
    "name": "Villeréal",
    "lat": "44.63631",
    "lng": "0.74326"
  },
  {
    "country": "FR",
    "name": "Villepreux",
    "lat": "48.82815",
    "lng": "1.9976"
  },
  {
    "country": "FR",
    "name": "Villepinte",
    "lat": "48.96203",
    "lng": "2.53253"
  },
  {
    "country": "FR",
    "name": "Villepinte",
    "lat": "43.28213",
    "lng": "2.0876"
  },
  {
    "country": "FR",
    "name": "Villeparisis",
    "lat": "48.94208",
    "lng": "2.61463"
  },
  {
    "country": "FR",
    "name": "Villenoy",
    "lat": "48.94112",
    "lng": "2.8602"
  },
  {
    "country": "FR",
    "name": "Villenouvelle",
    "lat": "43.43581",
    "lng": "1.66279"
  },
  {
    "country": "FR",
    "name": "Villennes-sur-Seine",
    "lat": "48.94137",
    "lng": "1.99137"
  },
  {
    "country": "FR",
    "name": "Villeneuve-Tolosane",
    "lat": "43.52316",
    "lng": "1.34102"
  },
  {
    "country": "FR",
    "name": "Villeneuve-sur-Yonne",
    "lat": "48.08247",
    "lng": "3.29688"
  },
  {
    "country": "FR",
    "name": "Villeneuve-sur-Lot",
    "lat": "44.40854",
    "lng": "0.70415"
  },
  {
    "country": "FR",
    "name": "Villeneuve-sur-Bellot",
    "lat": "48.86203",
    "lng": "3.34143"
  },
  {
    "country": "FR",
    "name": "Villeneuve-Saint-Germain",
    "lat": "49.37976",
    "lng": "3.35952"
  },
  {
    "country": "FR",
    "name": "Villeneuve-Saint-Georges",
    "lat": "48.73219",
    "lng": "2.44925"
  },
  {
    "country": "FR",
    "name": "Villeneuve-Loubet",
    "lat": "43.66663",
    "lng": "7.1204"
  },
  {
    "country": "FR",
    "name": "Villeneuve-les-Sablons",
    "lat": "49.23753",
    "lng": "2.07782"
  },
  {
    "country": "FR",
    "name": "Villeneuve-lès-Maguelone",
    "lat": "43.53333",
    "lng": "3.86667"
  },
  {
    "country": "FR",
    "name": "Villeneuve-lès-Bouloc",
    "lat": "43.76769",
    "lng": "1.42278"
  },
  {
    "country": "FR",
    "name": "Villeneuve-lès-Béziers",
    "lat": "43.31517",
    "lng": "3.28059"
  },
  {
    "country": "FR",
    "name": "Villeneuve-lès-Avignon",
    "lat": "43.9684",
    "lng": "4.7963"
  },
  {
    "country": "FR",
    "name": "Villeneuve-le-Roi",
    "lat": "48.73684",
    "lng": "2.40081"
  },
  {
    "country": "FR",
    "name": "Villeneuve-le-Comte",
    "lat": "48.81413",
    "lng": "2.82953"
  },
  {
    "country": "FR",
    "name": "Villeneuve-la-Rivière",
    "lat": "42.69366",
    "lng": "2.80294"
  },
  {
    "country": "FR",
    "name": "Villeneuve-la-Guyard",
    "lat": "48.34093",
    "lng": "3.06176"
  },
  {
    "country": "FR",
    "name": "Villeneuve-la-Garenne",
    "lat": "48.93935",
    "lng": "2.31478"
  },
  {
    "country": "FR",
    "name": "Villeneuve-la-Comptal",
    "lat": "43.28833",
    "lng": "1.91773"
  },
  {
    "country": "FR",
    "name": "Villeneuve-d’Olmes",
    "lat": "42.9061",
    "lng": "1.81937"
  },
  {
    "country": "FR",
    "name": "Villeneuve-de-Rivière",
    "lat": "43.12829",
    "lng": "0.66351"
  },
  {
    "country": "FR",
    "name": "Villeneuve-de-Marsan",
    "lat": "43.88906",
    "lng": "-0.30926"
  },
  {
    "country": "FR",
    "name": "Villeneuve-de-la-Raho",
    "lat": "42.63596",
    "lng": "2.91651"
  },
  {
    "country": "FR",
    "name": "Villeneuve-de-Berg",
    "lat": "44.55732",
    "lng": "4.50265"
  },
  {
    "country": "FR",
    "name": "Villeneuve",
    "lat": "44.43333",
    "lng": "2.03333"
  },
  {
    "country": "FR",
    "name": "Villeneuve",
    "lat": "46.02141",
    "lng": "4.83611"
  },
  {
    "country": "FR",
    "name": "Villeneuve",
    "lat": "44.94488",
    "lng": "6.56545"
  },
  {
    "country": "FR",
    "name": "Villeneuve",
    "lat": "43.89431",
    "lng": "5.86184"
  },
  {
    "country": "FR",
    "name": "Villenave-d’Ornon",
    "lat": "44.77327",
    "lng": "-0.5442"
  },
  {
    "country": "FR",
    "name": "Villenauxe-la-Grande",
    "lat": "48.58333",
    "lng": "3.55"
  },
  {
    "country": "FR",
    "name": "Villemur-sur-Tarn",
    "lat": "43.86708",
    "lng": "1.50281"
  },
  {
    "country": "FR",
    "name": "Villemoustaussou",
    "lat": "43.25186",
    "lng": "2.36552"
  },
  {
    "country": "FR",
    "name": "Villemomble",
    "lat": "48.88333",
    "lng": "2.5"
  },
  {
    "country": "FR",
    "name": "Villemolaque",
    "lat": "42.58815",
    "lng": "2.8389"
  },
  {
    "country": "FR",
    "name": "Villemoisson-sur-Orge",
    "lat": "48.66632",
    "lng": "2.33657"
  },
  {
    "country": "FR",
    "name": "Villemoirieu",
    "lat": "45.71617",
    "lng": "5.22771"
  },
  {
    "country": "FR",
    "name": "Villemeux-sur-Eure",
    "lat": "48.67259",
    "lng": "1.4647"
  },
  {
    "country": "FR",
    "name": "Villemandeur",
    "lat": "47.98701",
    "lng": "2.71802"
  },
  {
    "country": "FR",
    "name": "Vilallonga dels Monts",
    "lat": "42.52557",
    "lng": "2.90434"
  },
  {
    "country": "FR",
    "name": "Villelongue-de-la-Salanque",
    "lat": "42.72637",
    "lng": "2.9824"
  },
  {
    "country": "FR",
    "name": "Villelaure",
    "lat": "43.71319",
    "lng": "5.43072"
  },
  {
    "country": "FR",
    "name": "Ville-la-Grand",
    "lat": "46.203",
    "lng": "6.2501"
  },
  {
    "country": "FR",
    "name": "Villejust",
    "lat": "48.68304",
    "lng": "2.2361"
  },
  {
    "country": "FR",
    "name": "Villejuif",
    "lat": "48.7939",
    "lng": "2.35992"
  },
  {
    "country": "FR",
    "name": "Villegouge",
    "lat": "44.96667",
    "lng": "-0.3"
  },
  {
    "country": "FR",
    "name": "Villegailhenc",
    "lat": "43.26867",
    "lng": "2.35469"
  },
  {
    "country": "FR",
    "name": "Villefranque",
    "lat": "43.43631",
    "lng": "-1.45324"
  },
  {
    "country": "FR",
    "name": "Villefranche-sur-Saône",
    "lat": "45.98333",
    "lng": "4.71667"
  },
  {
    "country": "FR",
    "name": "Villefranche-sur-Mer",
    "lat": "43.70392",
    "lng": "7.31088"
  },
  {
    "country": "FR",
    "name": "Villefranche-de-Rouergue",
    "lat": "44.35166",
    "lng": "2.03702"
  },
  {
    "country": "FR",
    "name": "Villefranche-de-Lauragais",
    "lat": "43.4",
    "lng": "1.71694"
  },
  {
    "country": "FR",
    "name": "Villefranche-d’Allier",
    "lat": "46.39715",
    "lng": "2.85677"
  },
  {
    "country": "FR",
    "name": "Villefranche-d'Albigeois",
    "lat": "43.89635",
    "lng": "2.33022"
  },
  {
    "country": "FR",
    "name": "Villefranche-sur-Cher",
    "lat": "47.3",
    "lng": "1.76667"
  },
  {
    "country": "FR",
    "name": "Villefontaine",
    "lat": "45.6125",
    "lng": "5.14558"
  },
  {
    "country": "FR",
    "name": "Villefagnan",
    "lat": "46.0114",
    "lng": "0.07936"
  },
  {
    "country": "FR",
    "name": "Villedômer",
    "lat": "47.54651",
    "lng": "0.88775"
  },
  {
    "country": "FR",
    "name": "Villedieu-sur-Indre",
    "lat": "46.84598",
    "lng": "1.53975"
  },
  {
    "country": "FR",
    "name": "Villedieu-les-Poêles",
    "lat": "48.83333",
    "lng": "-1.21667"
  },
  {
    "country": "FR",
    "name": "Villedieu-la-Blouère",
    "lat": "47.14738",
    "lng": "-1.06286"
  },
  {
    "country": "FR",
    "name": "Ville-d’Avray",
    "lat": "48.82358",
    "lng": "2.19311"
  },
  {
    "country": "FR",
    "name": "Villecroze",
    "lat": "43.58181",
    "lng": "6.27542"
  },
  {
    "country": "FR",
    "name": "Villecresnes",
    "lat": "48.72002",
    "lng": "2.5394"
  },
  {
    "country": "FR",
    "name": "Villebret",
    "lat": "46.26685",
    "lng": "2.63827"
  },
  {
    "country": "FR",
    "name": "Villebon-sur-Yvette",
    "lat": "48.70594",
    "lng": "2.24019"
  },
  {
    "country": "FR",
    "name": "Villebois",
    "lat": "45.84947",
    "lng": "5.43226"
  },
  {
    "country": "FR",
    "name": "Villeblevin",
    "lat": "48.32446",
    "lng": "3.08038"
  },
  {
    "country": "FR",
    "name": "Villebernier",
    "lat": "47.25374",
    "lng": "-0.03229"
  },
  {
    "country": "FR",
    "name": "Villebarou",
    "lat": "47.62344",
    "lng": "1.32252"
  },
  {
    "country": "FR",
    "name": "Villé",
    "lat": "48.3427",
    "lng": "7.3026"
  },
  {
    "country": "FR",
    "name": "Villaz",
    "lat": "45.95069",
    "lng": "6.18717"
  },
  {
    "country": "FR",
    "name": "Villaudric",
    "lat": "43.83044",
    "lng": "1.43166"
  },
  {
    "country": "FR",
    "name": "Villars-les-Dombes",
    "lat": "46.00227",
    "lng": "5.02905"
  },
  {
    "country": "FR",
    "name": "Villar-Saint-Pancrace",
    "lat": "44.87318",
    "lng": "6.62669"
  },
  {
    "country": "FR",
    "name": "Villars",
    "lat": "45.47118",
    "lng": "4.35447"
  },
  {
    "country": "FR",
    "name": "Villargondran",
    "lat": "45.27113",
    "lng": "6.3695"
  },
  {
    "country": "FR",
    "name": "Villard-de-Lans",
    "lat": "45.0707",
    "lng": "5.55281"
  },
  {
    "country": "FR",
    "name": "Villard-Bonnot",
    "lat": "45.24",
    "lng": "5.89015"
  },
  {
    "country": "FR",
    "name": "Villandry",
    "lat": "47.34019",
    "lng": "0.5105"
  },
  {
    "country": "FR",
    "name": "Villaines-la-Juhel",
    "lat": "48.34416",
    "lng": "-0.27734"
  },
  {
    "country": "FR",
    "name": "Village-Neuf",
    "lat": "47.59016",
    "lng": "7.57019"
  },
  {
    "country": "FR",
    "name": "Villabé",
    "lat": "48.58949",
    "lng": "2.45096"
  },
  {
    "country": "FR",
    "name": "Vihiers",
    "lat": "47.14631",
    "lng": "-0.53238"
  },
  {
    "country": "FR",
    "name": "Vigy",
    "lat": "49.20443",
    "lng": "6.29906"
  },
  {
    "country": "FR",
    "name": "Vigny",
    "lat": "49.07902",
    "lng": "1.92806"
  },
  {
    "country": "FR",
    "name": "Vignoux-sur-Barangeon",
    "lat": "47.20068",
    "lng": "2.17258"
  },
  {
    "country": "FR",
    "name": "Vignot",
    "lat": "48.77418",
    "lng": "5.60904"
  },
  {
    "country": "FR",
    "name": "Vignoc",
    "lat": "48.24842",
    "lng": "-1.78169"
  },
  {
    "country": "FR",
    "name": "Vigneux-sur-Seine",
    "lat": "48.70291",
    "lng": "2.41357"
  },
  {
    "country": "FR",
    "name": "Vigneux-de-Bretagne",
    "lat": "47.32547",
    "lng": "-1.73678"
  },
  {
    "country": "FR",
    "name": "Vigneulles-lès-Hattonchâtel",
    "lat": "48.98152",
    "lng": "5.70464"
  },
  {
    "country": "FR",
    "name": "Vignacourt",
    "lat": "50.01236",
    "lng": "2.19743"
  },
  {
    "country": "FR",
    "name": "Vigeois",
    "lat": "45.38014",
    "lng": "1.51635"
  },
  {
    "country": "FR",
    "name": "Vif",
    "lat": "45.05436",
    "lng": "5.67757"
  },
  {
    "country": "FR",
    "name": "Vieux-Thann",
    "lat": "47.80347",
    "lng": "7.12068"
  },
  {
    "country": "FR",
    "name": "Le Vieux-Marché",
    "lat": "48.6",
    "lng": "-3.45"
  },
  {
    "country": "FR",
    "name": "Vieux-Condé",
    "lat": "50.45944",
    "lng": "3.56738"
  },
  {
    "country": "FR",
    "name": "Vieux-Charmont",
    "lat": "47.5219",
    "lng": "6.83738"
  },
  {
    "country": "FR",
    "name": "Vieux-Boucau-les-Bains",
    "lat": "43.78947",
    "lng": "-1.39957"
  },
  {
    "country": "FR",
    "name": "Vieux-Berquin",
    "lat": "50.69489",
    "lng": "2.64444"
  },
  {
    "country": "FR",
    "name": "Viesly",
    "lat": "50.15345",
    "lng": "3.46236"
  },
  {
    "country": "FR",
    "name": "Vierzon",
    "lat": "47.21667",
    "lng": "2.08333"
  },
  {
    "country": "FR",
    "name": "Vienne-en-Val",
    "lat": "47.80036",
    "lng": "2.1346"
  },
  {
    "country": "FR",
    "name": "Vienne",
    "lat": "45.51667",
    "lng": "4.86667"
  },
  {
    "country": "FR",
    "name": "Viennay",
    "lat": "46.68711",
    "lng": "-0.24641"
  },
  {
    "country": "FR",
    "name": "Vielmur-sur-Agout",
    "lat": "43.61667",
    "lng": "2.1"
  },
  {
    "country": "FR",
    "name": "Vielle-Saint-Girons",
    "lat": "43.95",
    "lng": "-1.3"
  },
  {
    "country": "FR",
    "name": "Vieillevigne",
    "lat": "46.97214",
    "lng": "-1.43405"
  },
  {
    "country": "FR",
    "name": "Vieille-Toulouse",
    "lat": "43.52366",
    "lng": "1.4423"
  },
  {
    "country": "FR",
    "name": "Vieille-Église",
    "lat": "50.92823",
    "lng": "2.07671"
  },
  {
    "country": "FR",
    "name": "Vieille Chapelle",
    "lat": "43.24963",
    "lng": "5.38048"
  },
  {
    "country": "FR",
    "name": "Vieille-Brioude",
    "lat": "45.26648",
    "lng": "3.40272"
  },
  {
    "country": "FR",
    "name": "Vidauban",
    "lat": "43.4278",
    "lng": "6.4329"
  },
  {
    "country": "FR",
    "name": "Vic-sur-Seille",
    "lat": "48.78195",
    "lng": "6.53079"
  },
  {
    "country": "FR",
    "name": "Vic-sur-Cère",
    "lat": "44.97929",
    "lng": "2.62485"
  },
  {
    "country": "FR",
    "name": "Vic-sur-Aisne",
    "lat": "49.40609",
    "lng": "3.11223"
  },
  {
    "country": "FR",
    "name": "Vicq-sur-Breuilh",
    "lat": "45.64661",
    "lng": "1.38179"
  },
  {
    "country": "FR",
    "name": "Vicq",
    "lat": "50.40738",
    "lng": "3.60348"
  },
  {
    "country": "FR",
    "name": "Vic-le-Comte",
    "lat": "45.64317",
    "lng": "3.24638"
  },
  {
    "country": "FR",
    "name": "Vic-la-Gardiole",
    "lat": "43.4908",
    "lng": "3.7975"
  },
  {
    "country": "FR",
    "name": "Vichy",
    "lat": "46.11667",
    "lng": "3.41667"
  },
  {
    "country": "FR",
    "name": "Vic-Fezensac",
    "lat": "43.77183",
    "lng": "0.31368"
  },
  {
    "country": "FR",
    "name": "Vic-en-Bigorre",
    "lat": "43.38682",
    "lng": "0.05471"
  },
  {
    "country": "FR",
    "name": "Vibraye",
    "lat": "48.05607",
    "lng": "0.74171"
  },
  {
    "country": "FR",
    "name": "Vias",
    "lat": "43.31156",
    "lng": "3.41774"
  },
  {
    "country": "FR",
    "name": "Viarmes",
    "lat": "49.13082",
    "lng": "2.37074"
  },
  {
    "country": "FR",
    "name": "Vianne",
    "lat": "44.19658",
    "lng": "0.32104"
  },
  {
    "country": "FR",
    "name": "Vezins",
    "lat": "47.12015",
    "lng": "-0.70971"
  },
  {
    "country": "FR",
    "name": "Vezin-le-Coquet",
    "lat": "48.11857",
    "lng": "-1.75466"
  },
  {
    "country": "FR",
    "name": "Vézénobres",
    "lat": "44.0513",
    "lng": "4.13775"
  },
  {
    "country": "FR",
    "name": "Vézelise",
    "lat": "48.48682",
    "lng": "6.08894"
  },
  {
    "country": "FR",
    "name": "Veyrier-du-Lac",
    "lat": "45.8799",
    "lng": "6.17751"
  },
  {
    "country": "FR",
    "name": "Veyre-Monton",
    "lat": "45.66866",
    "lng": "3.17144"
  },
  {
    "country": "FR",
    "name": "Veyras",
    "lat": "44.73518",
    "lng": "4.56254"
  },
  {
    "country": "FR",
    "name": "Veyrac",
    "lat": "45.89521",
    "lng": "1.105"
  },
  {
    "country": "FR",
    "name": "Veynes",
    "lat": "44.53333",
    "lng": "5.81667"
  },
  {
    "country": "FR",
    "name": "Veurey-Voroize",
    "lat": "45.27307",
    "lng": "5.61319"
  },
  {
    "country": "FR",
    "name": "Vétraz-Monthoux",
    "lat": "46.1743",
    "lng": "6.25852"
  },
  {
    "country": "FR",
    "name": "Vestric-et-Candiac",
    "lat": "43.74061",
    "lng": "4.25914"
  },
  {
    "country": "FR",
    "name": "Vesseaux",
    "lat": "44.65136",
    "lng": "4.44259"
  },
  {
    "country": "FR",
    "name": "Vesoul",
    "lat": "47.62604",
    "lng": "6.14251"
  },
  {
    "country": "FR",
    "name": "Vescovato",
    "lat": "42.49278",
    "lng": "9.43916"
  },
  {
    "country": "FR",
    "name": "Verzy",
    "lat": "49.14576",
    "lng": "4.16409"
  },
  {
    "country": "FR",
    "name": "Verzenay",
    "lat": "49.15918",
    "lng": "4.14543"
  },
  {
    "country": "FR",
    "name": "Vervins",
    "lat": "49.83333",
    "lng": "3.9"
  },
  {
    "country": "FR",
    "name": "Vertus",
    "lat": "48.90609",
    "lng": "4.00216"
  },
  {
    "country": "FR",
    "name": "Vert-Saint-Denis",
    "lat": "48.56818",
    "lng": "2.62007"
  },
  {
    "country": "FR",
    "name": "Vertou",
    "lat": "47.16869",
    "lng": "-1.46929"
  },
  {
    "country": "FR",
    "name": "Verton",
    "lat": "50.40234",
    "lng": "1.64766"
  },
  {
    "country": "FR",
    "name": "Vert-le-Petit",
    "lat": "48.55163",
    "lng": "2.36526"
  },
  {
    "country": "FR",
    "name": "Vert-le-Grand",
    "lat": "48.57172",
    "lng": "2.35777"
  },
  {
    "country": "FR",
    "name": "Vertheuil",
    "lat": "45.25",
    "lng": "-0.83333"
  },
  {
    "country": "FR",
    "name": "Vert-en-Drouais",
    "lat": "48.76029",
    "lng": "1.2946"
  },
  {
    "country": "FR",
    "name": "Vertaizon",
    "lat": "45.77136",
    "lng": "3.28884"
  },
  {
    "country": "FR",
    "name": "Ver-sur-Mer",
    "lat": "49.32987",
    "lng": "-0.53118"
  },
  {
    "country": "FR",
    "name": "Ver-sur-Launette",
    "lat": "49.10495",
    "lng": "2.68409"
  },
  {
    "country": "FR",
    "name": "Versonnex",
    "lat": "45.92753",
    "lng": "5.92585"
  },
  {
    "country": "FR",
    "name": "Verson",
    "lat": "49.15432",
    "lng": "-0.45628"
  },
  {
    "country": "FR",
    "name": "Versailles",
    "lat": "48.80359",
    "lng": "2.13424"
  },
  {
    "country": "FR",
    "name": "Vers-Pont-du-Gard",
    "lat": "43.96667",
    "lng": "4.53333"
  },
  {
    "country": "FR",
    "name": "Verrières-le-Buisson",
    "lat": "48.74565",
    "lng": "2.26796"
  },
  {
    "country": "FR",
    "name": "Verrières",
    "lat": "48.23334",
    "lng": "4.14893"
  },
  {
    "country": "FR",
    "name": "Verquin",
    "lat": "50.5024",
    "lng": "2.63888"
  },
  {
    "country": "FR",
    "name": "Véron",
    "lat": "48.12853",
    "lng": "3.30773"
  },
  {
    "country": "FR",
    "name": "Verny",
    "lat": "49.00677",
    "lng": "6.2035"
  },
  {
    "country": "FR",
    "name": "Vern-sur-Seiche",
    "lat": "48.04514",
    "lng": "-1.60057"
  },
  {
    "country": "FR",
    "name": "Vernoux-en-Vivarais",
    "lat": "44.89563",
    "lng": "4.64643"
  },
  {
    "country": "FR",
    "name": "Vernou-la-Celle-sur-Seine",
    "lat": "48.38789",
    "lng": "2.84718"
  },
  {
    "country": "FR",
    "name": "Vernou-sur-Brenne",
    "lat": "47.41936",
    "lng": "0.84757"
  },
  {
    "country": "FR",
    "name": "Vernouillet",
    "lat": "48.97146",
    "lng": "1.98082"
  },
  {
    "country": "FR",
    "name": "Vernouillet",
    "lat": "48.7209",
    "lng": "1.36951"
  },
  {
    "country": "FR",
    "name": "Vernosc-lès-Annonay",
    "lat": "45.21676",
    "lng": "4.71252"
  },
  {
    "country": "FR",
    "name": "Vernon",
    "lat": "49.09292",
    "lng": "1.46332"
  },
  {
    "country": "FR",
    "name": "Vernoil-le-Fourrier",
    "lat": "47.38333",
    "lng": "0.08333"
  },
  {
    "country": "FR",
    "name": "Vernioz",
    "lat": "45.42682",
    "lng": "4.88188"
  },
  {
    "country": "FR",
    "name": "Verniolle",
    "lat": "43.08162",
    "lng": "1.64904"
  },
  {
    "country": "FR",
    "name": "Verneuil-sur-Vienne",
    "lat": "45.85524",
    "lng": "1.10133"
  },
  {
    "country": "FR",
    "name": "Verneuil-sur-Seine",
    "lat": "48.97388",
    "lng": "1.9648"
  },
  {
    "country": "FR",
    "name": "Verneuil-sur-Avre",
    "lat": "48.73949",
    "lng": "0.92731"
  },
  {
    "country": "FR",
    "name": "Verneuil-en-Halatte",
    "lat": "49.27914",
    "lng": "2.5241"
  },
  {
    "country": "FR",
    "name": "Vernet-les-Bains",
    "lat": "42.54834",
    "lng": "2.38717"
  },
  {
    "country": "FR",
    "name": "Vernègues",
    "lat": "43.68575",
    "lng": "5.17156"
  },
  {
    "country": "FR",
    "name": "Vern-d’Anjou",
    "lat": "47.60119",
    "lng": "-0.83357"
  },
  {
    "country": "FR",
    "name": "Vernantes",
    "lat": "47.3932",
    "lng": "0.05304"
  },
  {
    "country": "FR",
    "name": "Vernaison",
    "lat": "45.64693",
    "lng": "4.81249"
  },
  {
    "country": "FR",
    "name": "Vermenton",
    "lat": "47.66459",
    "lng": "3.73501"
  },
  {
    "country": "FR",
    "name": "Vermelles",
    "lat": "50.48949",
    "lng": "2.74739"
  },
  {
    "country": "FR",
    "name": "Vermand",
    "lat": "49.8755",
    "lng": "3.14959"
  },
  {
    "country": "FR",
    "name": "Verlinghem",
    "lat": "50.68291",
    "lng": "2.99907"
  },
  {
    "country": "FR",
    "name": "Vérines",
    "lat": "46.19372",
    "lng": "-0.96683"
  },
  {
    "country": "FR",
    "name": "Vergt",
    "lat": "45.02695",
    "lng": "0.7182"
  },
  {
    "country": "FR",
    "name": "Vergongheon",
    "lat": "45.37058",
    "lng": "3.31915"
  },
  {
    "country": "FR",
    "name": "Vergigny",
    "lat": "47.97059",
    "lng": "3.71861"
  },
  {
    "country": "FR",
    "name": "Vergèze",
    "lat": "43.74404",
    "lng": "4.22109"
  },
  {
    "country": "FR",
    "name": "Verfeil",
    "lat": "43.65781",
    "lng": "1.6634"
  },
  {
    "country": "FR",
    "name": "Véretz",
    "lat": "47.35706",
    "lng": "0.80575"
  },
  {
    "country": "FR",
    "name": "Verdun",
    "lat": "49.16667",
    "lng": "5.38333"
  },
  {
    "country": "FR",
    "name": "Verdun-sur-le-Doubs",
    "lat": "46.89692",
    "lng": "5.02127"
  },
  {
    "country": "FR",
    "name": "Verdun-sur-Garonne",
    "lat": "43.85446",
    "lng": "1.23425"
  },
  {
    "country": "FR",
    "name": "Vercel-Villedieu-le-Camp",
    "lat": "47.18318",
    "lng": "6.40082"
  },
  {
    "country": "FR",
    "name": "Verberie",
    "lat": "49.31115",
    "lng": "2.7321"
  },
  {
    "country": "FR",
    "name": "Ventiseri",
    "lat": "41.94169",
    "lng": "9.33173"
  },
  {
    "country": "FR",
    "name": "Ventabren",
    "lat": "43.53847",
    "lng": "5.29541"
  },
  {
    "country": "FR",
    "name": "Venoy",
    "lat": "47.80518",
    "lng": "3.63695"
  },
  {
    "country": "FR",
    "name": "Vennecy",
    "lat": "47.95465",
    "lng": "2.05459"
  },
  {
    "country": "FR",
    "name": "Venizel",
    "lat": "49.36583",
    "lng": "3.39321"
  },
  {
    "country": "FR",
    "name": "Vénissieux",
    "lat": "45.70254",
    "lng": "4.87147"
  },
  {
    "country": "FR",
    "name": "Veneux-les-Sablons",
    "lat": "48.37872",
    "lng": "2.79499"
  },
  {
    "country": "FR",
    "name": "Venette",
    "lat": "49.41705",
    "lng": "2.80317"
  },
  {
    "country": "FR",
    "name": "Venerque",
    "lat": "43.43457",
    "lng": "1.44588"
  },
  {
    "country": "FR",
    "name": "Venelles",
    "lat": "43.59839",
    "lng": "5.48529"
  },
  {
    "country": "FR",
    "name": "Vénéjan",
    "lat": "44.19729",
    "lng": "4.65422"
  },
  {
    "country": "FR",
    "name": "Vendres",
    "lat": "43.26977",
    "lng": "3.22341"
  },
  {
    "country": "FR",
    "name": "Vendrennes",
    "lat": "46.82523",
    "lng": "-1.12357"
  },
  {
    "country": "FR",
    "name": "Vendôme",
    "lat": "47.8",
    "lng": "1.06667"
  },
  {
    "country": "FR",
    "name": "Vendœuvres",
    "lat": "46.8",
    "lng": "1.35"
  },
  {
    "country": "FR",
    "name": "Vendin-le-Vieil",
    "lat": "50.47385",
    "lng": "2.86674"
  },
  {
    "country": "FR",
    "name": "Vendin-lès-Béthune",
    "lat": "50.54012",
    "lng": "2.60043"
  },
  {
    "country": "FR",
    "name": "Vendeville",
    "lat": "50.57693",
    "lng": "3.0787"
  },
  {
    "country": "FR",
    "name": "Vendeuvre-sur-Barse",
    "lat": "48.23786",
    "lng": "4.46905"
  },
  {
    "country": "FR",
    "name": "Vendeuvre-du-Poitou",
    "lat": "46.73579",
    "lng": "0.30996"
  },
  {
    "country": "FR",
    "name": "Vendenheim",
    "lat": "48.66948",
    "lng": "7.70983"
  },
  {
    "country": "FR",
    "name": "Vendegies-sur-Écaillon",
    "lat": "50.26224",
    "lng": "3.51256"
  },
  {
    "country": "FR",
    "name": "Vendays-Montalivet",
    "lat": "45.35492",
    "lng": "-1.06088"
  },
  {
    "country": "FR",
    "name": "Vendat",
    "lat": "46.16015",
    "lng": "3.35451"
  },
  {
    "country": "FR",
    "name": "Vendargues",
    "lat": "43.65833",
    "lng": "3.97"
  },
  {
    "country": "FR",
    "name": "Vence",
    "lat": "43.72254",
    "lng": "7.11183"
  },
  {
    "country": "FR",
    "name": "Venasque",
    "lat": "43.99214",
    "lng": "5.14895"
  },
  {
    "country": "FR",
    "name": "Venarey-les-Laumes",
    "lat": "47.54202",
    "lng": "4.46022"
  },
  {
    "country": "FR",
    "name": "Venansault",
    "lat": "46.68516",
    "lng": "-1.51415"
  },
  {
    "country": "FR",
    "name": "Vémars",
    "lat": "49.06942",
    "lng": "2.56643"
  },
  {
    "country": "FR",
    "name": "Velleron",
    "lat": "43.95759",
    "lng": "5.02879"
  },
  {
    "country": "FR",
    "name": "Vélizy-Villacoublay",
    "lat": "48.78198",
    "lng": "2.19395"
  },
  {
    "country": "FR",
    "name": "Vélines",
    "lat": "44.85",
    "lng": "0.11667"
  },
  {
    "country": "FR",
    "name": "Velaux",
    "lat": "43.52839",
    "lng": "5.25661"
  },
  {
    "country": "FR",
    "name": "Velars-sur-Ouche",
    "lat": "47.3196",
    "lng": "4.90594"
  },
  {
    "country": "FR",
    "name": "Velaines",
    "lat": "48.6988",
    "lng": "5.30483"
  },
  {
    "country": "FR",
    "name": "Velaine-en-Haye",
    "lat": "48.70383",
    "lng": "6.02122"
  },
  {
    "country": "FR",
    "name": "Veigy-Foncenex",
    "lat": "46.27044",
    "lng": "6.25419"
  },
  {
    "country": "FR",
    "name": "Veigné",
    "lat": "47.28556",
    "lng": "0.74079"
  },
  {
    "country": "FR",
    "name": "Vedène",
    "lat": "43.97744",
    "lng": "4.90428"
  },
  {
    "country": "FR",
    "name": "Vecoux",
    "lat": "47.97797",
    "lng": "6.63651"
  },
  {
    "country": "FR",
    "name": "Veauche",
    "lat": "45.56294",
    "lng": "4.29031"
  },
  {
    "country": "FR",
    "name": "Vayres",
    "lat": "44.9",
    "lng": "-0.31667"
  },
  {
    "country": "FR",
    "name": "Vayrac",
    "lat": "44.95337",
    "lng": "1.70358"
  },
  {
    "country": "FR",
    "name": "Vay",
    "lat": "47.55466",
    "lng": "-1.70095"
  },
  {
    "country": "FR",
    "name": "Vaux-sur-Seine",
    "lat": "49.01271",
    "lng": "1.96942"
  },
  {
    "country": "FR",
    "name": "Vaux-sur-Mer",
    "lat": "45.64606",
    "lng": "-1.05841"
  },
  {
    "country": "FR",
    "name": "Vaux-le-Pénil",
    "lat": "48.52803",
    "lng": "2.69165"
  },
  {
    "country": "FR",
    "name": "Vaux-en-Bugey",
    "lat": "45.92711",
    "lng": "5.35336"
  },
  {
    "country": "FR",
    "name": "Vauvert",
    "lat": "43.69529",
    "lng": "4.27705"
  },
  {
    "country": "FR",
    "name": "Vauréal",
    "lat": "49.03333",
    "lng": "2.03333"
  },
  {
    "country": "FR",
    "name": "Vaumoise",
    "lat": "49.23525",
    "lng": "2.98077"
  },
  {
    "country": "FR",
    "name": "Vaulx-Vraucourt",
    "lat": "50.1491",
    "lng": "2.9083"
  },
  {
    "country": "FR",
    "name": "Vaulx-Milieu",
    "lat": "45.61226",
    "lng": "5.181"
  },
  {
    "country": "FR",
    "name": "Vaulx-en-Velin",
    "lat": "45.7818",
    "lng": "4.92085"
  },
  {
    "country": "FR",
    "name": "Vaulnaveys-le-Haut",
    "lat": "45.11696",
    "lng": "5.81257"
  },
  {
    "country": "FR",
    "name": "Vaulnaveys-le-Bas",
    "lat": "45.1002",
    "lng": "5.82532"
  },
  {
    "country": "FR",
    "name": "Vaujours",
    "lat": "48.93022",
    "lng": "2.5711"
  },
  {
    "country": "FR",
    "name": "Vauhallan",
    "lat": "48.73354",
    "lng": "2.20277"
  },
  {
    "country": "FR",
    "name": "Vaugrigneuse",
    "lat": "48.60263",
    "lng": "2.12218"
  },
  {
    "country": "FR",
    "name": "Vaugneray",
    "lat": "45.73717",
    "lng": "4.65873"
  },
  {
    "country": "FR",
    "name": "Vaudry",
    "lat": "48.8413",
    "lng": "-0.85309"
  },
  {
    "country": "FR",
    "name": "Vaudelnay",
    "lat": "47.13813",
    "lng": "-0.20677"
  },
  {
    "country": "FR",
    "name": "Vaucresson",
    "lat": "48.84078",
    "lng": "2.15652"
  },
  {
    "country": "FR",
    "name": "Vaucouleurs",
    "lat": "48.60313",
    "lng": "5.66659"
  },
  {
    "country": "FR",
    "name": "Vauchrétien",
    "lat": "47.33234",
    "lng": "-0.47678"
  },
  {
    "country": "FR",
    "name": "Vatan",
    "lat": "47.07447",
    "lng": "1.8101"
  },
  {
    "country": "FR",
    "name": "Vassy",
    "lat": "48.85381",
    "lng": "-0.67485"
  },
  {
    "country": "FR",
    "name": "Vasselay",
    "lat": "47.15686",
    "lng": "2.38963"
  },
  {
    "country": "FR",
    "name": "Vasles",
    "lat": "46.57618",
    "lng": "-0.02638"
  },
  {
    "country": "FR",
    "name": "Varzy",
    "lat": "47.3581",
    "lng": "3.38619"
  },
  {
    "country": "FR",
    "name": "Vars",
    "lat": "45.76256",
    "lng": "0.12478"
  },
  {
    "country": "FR",
    "name": "Varreddes",
    "lat": "49.00305",
    "lng": "2.92788"
  },
  {
    "country": "FR",
    "name": "Varrains",
    "lat": "47.22305",
    "lng": "-0.06033"
  },
  {
    "country": "FR",
    "name": "Varois-et-Chaignot",
    "lat": "47.35059",
    "lng": "5.12838"
  },
  {
    "country": "FR",
    "name": "Varilhes",
    "lat": "43.04514",
    "lng": "1.62805"
  },
  {
    "country": "FR",
    "name": "Varetz",
    "lat": "45.1939",
    "lng": "1.45121"
  },
  {
    "country": "FR",
    "name": "Varennes-sur-Seine",
    "lat": "48.37304",
    "lng": "2.92571"
  },
  {
    "country": "FR",
    "name": "Varennes-sur-Loire",
    "lat": "47.23767",
    "lng": "0.0535"
  },
  {
    "country": "FR",
    "name": "Varennes-sur-Allier",
    "lat": "46.31472",
    "lng": "3.39846"
  },
  {
    "country": "FR",
    "name": "Varennes-Saint-Sauveur",
    "lat": "46.48226",
    "lng": "5.24349"
  },
  {
    "country": "FR",
    "name": "Varennes-le-Grand",
    "lat": "46.71868",
    "lng": "4.86872"
  },
  {
    "country": "FR",
    "name": "Varennes-Jarcy",
    "lat": "48.67914",
    "lng": "2.56152"
  },
  {
    "country": "FR",
    "name": "Varengeville-sur-Mer",
    "lat": "49.90475",
    "lng": "0.99479"
  },
  {
    "country": "FR",
    "name": "Varangéville",
    "lat": "48.63605",
    "lng": "6.32112"
  },
  {
    "country": "FR",
    "name": "Varades",
    "lat": "47.38458",
    "lng": "-1.02842"
  },
  {
    "country": "FR",
    "name": "Vanves",
    "lat": "48.82345",
    "lng": "2.29025"
  },
  {
    "country": "FR",
    "name": "Vannes",
    "lat": "47.6579",
    "lng": "-2.75574"
  },
  {
    "country": "FR",
    "name": "Vandœuvre-lès-Nancy",
    "lat": "48.65",
    "lng": "6.18333"
  },
  {
    "country": "FR",
    "name": "Vals-près-le-Puy",
    "lat": "45.03155",
    "lng": "3.87787"
  },
  {
    "country": "FR",
    "name": "Vals-les-Bains",
    "lat": "44.66387",
    "lng": "4.36861"
  },
  {
    "country": "FR",
    "name": "Valros",
    "lat": "43.41956",
    "lng": "3.36506"
  },
  {
    "country": "FR",
    "name": "Valréas",
    "lat": "44.38366",
    "lng": "4.99084"
  },
  {
    "country": "FR",
    "name": "Valras-Plage",
    "lat": "43.24808",
    "lng": "3.29032"
  },
  {
    "country": "FR",
    "name": "Valognes",
    "lat": "49.50881",
    "lng": "-1.47047"
  },
  {
    "country": "FR",
    "name": "Valmont",
    "lat": "49.0843",
    "lng": "6.69781"
  },
  {
    "country": "FR",
    "name": "Valmondois",
    "lat": "49.0973",
    "lng": "2.18996"
  },
  {
    "country": "FR",
    "name": "Vallon-Pont-d’Arc",
    "lat": "44.40558",
    "lng": "4.39254"
  },
  {
    "country": "FR",
    "name": "Vallon-en-Sully",
    "lat": "46.53676",
    "lng": "2.60828"
  },
  {
    "country": "FR",
    "name": "Valloire",
    "lat": "45.16565",
    "lng": "6.42994"
  },
  {
    "country": "FR",
    "name": "Valliquerville",
    "lat": "49.61385",
    "lng": "0.68703"
  },
  {
    "country": "FR",
    "name": "Vallières",
    "lat": "45.90262",
    "lng": "5.93811"
  },
  {
    "country": "FR",
    "name": "Vallet",
    "lat": "47.16227",
    "lng": "-1.26607"
  },
  {
    "country": "FR",
    "name": "Valleroy",
    "lat": "49.20905",
    "lng": "5.9383"
  },
  {
    "country": "FR",
    "name": "Valleraugue",
    "lat": "44.0813",
    "lng": "3.64154"
  },
  {
    "country": "FR",
    "name": "Valleiry",
    "lat": "46.11117",
    "lng": "5.97267"
  },
  {
    "country": "FR",
    "name": "Vallauris",
    "lat": "43.57803",
    "lng": "7.05451"
  },
  {
    "country": "FR",
    "name": "Vallabrègues",
    "lat": "43.85307",
    "lng": "4.62662"
  },
  {
    "country": "FR",
    "name": "Valframbert",
    "lat": "48.46465",
    "lng": "0.10828"
  },
  {
    "country": "FR",
    "name": "Valfin-lès-Saint-Claude",
    "lat": "46.43758",
    "lng": "5.85513"
  },
  {
    "country": "FR",
    "name": "Valff",
    "lat": "48.4214",
    "lng": "7.52058"
  },
  {
    "country": "FR",
    "name": "Valergues",
    "lat": "43.66824",
    "lng": "4.06124"
  },
  {
    "country": "FR",
    "name": "Valenton",
    "lat": "48.74527",
    "lng": "2.46467"
  },
  {
    "country": "FR",
    "name": "Valentigney",
    "lat": "47.46388",
    "lng": "6.83168"
  },
  {
    "country": "FR",
    "name": "Valensole",
    "lat": "43.83799",
    "lng": "5.98323"
  },
  {
    "country": "FR",
    "name": "Valencin",
    "lat": "45.61285",
    "lng": "5.01565"
  },
  {
    "country": "FR",
    "name": "Valenciennes",
    "lat": "50.35",
    "lng": "3.53333"
  },
  {
    "country": "FR",
    "name": "Valence-sur-Baïse",
    "lat": "43.8827",
    "lng": "0.38111"
  },
  {
    "country": "FR",
    "name": "Valence-d’Albigeois",
    "lat": "44.01928",
    "lng": "2.40534"
  },
  {
    "country": "FR",
    "name": "Valence",
    "lat": "44.92801",
    "lng": "4.8951"
  },
  {
    "country": "FR",
    "name": "Valence",
    "lat": "44.10823",
    "lng": "0.89101"
  },
  {
    "country": "FR",
    "name": "Valençay",
    "lat": "47.16207",
    "lng": "1.56852"
  },
  {
    "country": "FR",
    "name": "Valdoie",
    "lat": "47.66799",
    "lng": "6.84446"
  },
  {
    "country": "FR",
    "name": "Val-d’Isère",
    "lat": "45.44972",
    "lng": "6.9781"
  },
  {
    "country": "FR",
    "name": "Valbonne",
    "lat": "43.63292",
    "lng": "6.99911"
  },
  {
    "country": "FR",
    "name": "Valady",
    "lat": "44.45633",
    "lng": "2.42746"
  },
  {
    "country": "FR",
    "name": "Vaivre-et-Montoille",
    "lat": "47.63021",
    "lng": "6.10362"
  },
  {
    "country": "FR",
    "name": "Vaison-la-Romaine",
    "lat": "44.23896",
    "lng": "5.07461"
  },
  {
    "country": "FR",
    "name": "Vaires-sur-Marne",
    "lat": "48.87649",
    "lng": "2.63982"
  },
  {
    "country": "FR",
    "name": "Vairé",
    "lat": "46.60104",
    "lng": "-1.75538"
  },
  {
    "country": "FR",
    "name": "Vailly-sur-Aisne",
    "lat": "49.40834",
    "lng": "3.51631"
  },
  {
    "country": "FR",
    "name": "Vailhauquès",
    "lat": "43.67159",
    "lng": "3.72042"
  },
  {
    "country": "FR",
    "name": "Vaiges",
    "lat": "48.04025",
    "lng": "-0.47513"
  },
  {
    "country": "FR",
    "name": "Vagney",
    "lat": "48.00629",
    "lng": "6.7174"
  },
  {
    "country": "FR",
    "name": "Vacquiers",
    "lat": "43.77667",
    "lng": "1.48127"
  },
  {
    "country": "FR",
    "name": "Vacqueyras",
    "lat": "44.13735",
    "lng": "4.98281"
  },
  {
    "country": "FR",
    "name": "Vacon",
    "lat": "48.66865",
    "lng": "5.60024"
  },
  {
    "country": "FR",
    "name": "Vaas",
    "lat": "47.6689",
    "lng": "0.31677"
  },
  {
    "country": "FR",
    "name": "Uzès",
    "lat": "44.01362",
    "lng": "4.41529"
  },
  {
    "country": "FR",
    "name": "Uzerche",
    "lat": "45.4212",
    "lng": "1.56395"
  },
  {
    "country": "FR",
    "name": "Uzemain",
    "lat": "48.08572",
    "lng": "6.34443"
  },
  {
    "country": "FR",
    "name": "Uzein",
    "lat": "43.4",
    "lng": "-0.43333"
  },
  {
    "country": "FR",
    "name": "Uxem",
    "lat": "51.0217",
    "lng": "2.48376"
  },
  {
    "country": "FR",
    "name": "Uxegney",
    "lat": "48.19652",
    "lng": "6.36971"
  },
  {
    "country": "FR",
    "name": "Ustaritz",
    "lat": "43.3965",
    "lng": "-1.45603"
  },
  {
    "country": "FR",
    "name": "Usson-en-Forez",
    "lat": "45.38797",
    "lng": "3.93772"
  },
  {
    "country": "FR",
    "name": "Usson-du-Poitou",
    "lat": "46.27782",
    "lng": "0.52816"
  },
  {
    "country": "FR",
    "name": "Ussel",
    "lat": "45.55",
    "lng": "2.31667"
  },
  {
    "country": "FR",
    "name": "Ussac",
    "lat": "45.19389",
    "lng": "1.51337"
  },
  {
    "country": "FR",
    "name": "Us",
    "lat": "49.1",
    "lng": "1.96667"
  },
  {
    "country": "FR",
    "name": "Urzy",
    "lat": "47.04877",
    "lng": "3.20295"
  },
  {
    "country": "FR",
    "name": "Urville-Nacqueville",
    "lat": "49.67444",
    "lng": "-1.73664"
  },
  {
    "country": "FR",
    "name": "Urt",
    "lat": "43.49009",
    "lng": "-1.29744"
  },
  {
    "country": "FR",
    "name": "Urrugne",
    "lat": "43.36361",
    "lng": "-1.69921"
  },
  {
    "country": "FR",
    "name": "Urmatt",
    "lat": "48.52752",
    "lng": "7.32565"
  },
  {
    "country": "FR",
    "name": "Uriménil",
    "lat": "48.10079",
    "lng": "6.40046"
  },
  {
    "country": "FR",
    "name": "Urcuit",
    "lat": "43.48594",
    "lng": "-1.33668"
  },
  {
    "country": "FR",
    "name": "Upie",
    "lat": "44.80359",
    "lng": "4.97778"
  },
  {
    "country": "FR",
    "name": "Unverre",
    "lat": "48.19829",
    "lng": "1.09207"
  },
  {
    "country": "FR",
    "name": "Unieux",
    "lat": "45.4004",
    "lng": "4.27812"
  },
  {
    "country": "FR",
    "name": "Ungersheim",
    "lat": "47.87848",
    "lng": "7.30797"
  },
  {
    "country": "FR",
    "name": "Ully-Saint-Georges",
    "lat": "49.27914",
    "lng": "2.28094"
  },
  {
    "country": "FR",
    "name": "Ugine",
    "lat": "45.75084",
    "lng": "6.41611"
  },
  {
    "country": "FR",
    "name": "Uffholtz",
    "lat": "47.82082",
    "lng": "7.17785"
  },
  {
    "country": "FR",
    "name": "Uckange",
    "lat": "49.30304",
    "lng": "6.1492"
  },
  {
    "country": "FR",
    "name": "Uchaux",
    "lat": "44.21667",
    "lng": "4.8"
  },
  {
    "country": "FR",
    "name": "Uchaud",
    "lat": "43.75857",
    "lng": "4.26843"
  },
  {
    "country": "FR",
    "name": "Uberach",
    "lat": "48.8499",
    "lng": "7.62934"
  },
  {
    "country": "FR",
    "name": "Turretot",
    "lat": "49.60923",
    "lng": "0.23422"
  },
  {
    "country": "FR",
    "name": "Turckheim",
    "lat": "48.08748",
    "lng": "7.27707"
  },
  {
    "country": "FR",
    "name": "Tullins",
    "lat": "45.29861",
    "lng": "5.48609"
  },
  {
    "country": "FR",
    "name": "Tulle",
    "lat": "45.27001",
    "lng": "1.77309"
  },
  {
    "country": "FR",
    "name": "Tulette",
    "lat": "44.28527",
    "lng": "4.9296"
  },
  {
    "country": "FR",
    "name": "Tuffé",
    "lat": "48.11319",
    "lng": "0.51551"
  },
  {
    "country": "FR",
    "name": "Tucquegnieux",
    "lat": "49.3014",
    "lng": "5.88247"
  },
  {
    "country": "FR",
    "name": "Truyes",
    "lat": "47.27299",
    "lng": "0.85179"
  },
  {
    "country": "FR",
    "name": "Trun",
    "lat": "48.84268",
    "lng": "0.03268"
  },
  {
    "country": "FR",
    "name": "Truchtersheim",
    "lat": "48.66313",
    "lng": "7.60752"
  },
  {
    "country": "FR",
    "name": "Troyes",
    "lat": "48.30073",
    "lng": "4.08524"
  },
  {
    "country": "FR",
    "name": "Trouy",
    "lat": "47.01153",
    "lng": "2.36018"
  },
  {
    "country": "FR",
    "name": "Trouville-sur-Mer",
    "lat": "49.3657",
    "lng": "0.08041"
  },
  {
    "country": "FR",
    "name": "Trouillas",
    "lat": "42.61089",
    "lng": "2.80821"
  },
  {
    "country": "FR",
    "name": "Trosly-Breuil",
    "lat": "49.4",
    "lng": "2.96667"
  },
  {
    "country": "FR",
    "name": "Tronville-en-Barrois",
    "lat": "48.71977",
    "lng": "5.27808"
  },
  {
    "country": "FR",
    "name": "Troissereux",
    "lat": "49.47998",
    "lng": "2.04485"
  },
  {
    "country": "FR",
    "name": "Troarn",
    "lat": "49.17835",
    "lng": "-0.18169"
  },
  {
    "country": "FR",
    "name": "Trizay",
    "lat": "45.88276",
    "lng": "-0.89697"
  },
  {
    "country": "FR",
    "name": "Trith-Saint-Léger",
    "lat": "50.31667",
    "lng": "3.48333"
  },
  {
    "country": "FR",
    "name": "Trilport",
    "lat": "48.95685",
    "lng": "2.95076"
  },
  {
    "country": "FR",
    "name": "Triguères",
    "lat": "47.93975",
    "lng": "2.9857"
  },
  {
    "country": "FR",
    "name": "Trignac",
    "lat": "47.31809",
    "lng": "-2.18895"
  },
  {
    "country": "FR",
    "name": "Trieux",
    "lat": "49.32446",
    "lng": "5.93644"
  },
  {
    "country": "FR",
    "name": "Triel-sur-Seine",
    "lat": "48.97818",
    "lng": "2.00743"
  },
  {
    "country": "FR",
    "name": "Trie-Château",
    "lat": "49.2854",
    "lng": "1.82129"
  },
  {
    "country": "FR",
    "name": "Trie-sur-Baïse",
    "lat": "43.33333",
    "lng": "0.36667"
  },
  {
    "country": "FR",
    "name": "Tricot",
    "lat": "49.5608",
    "lng": "2.58789"
  },
  {
    "country": "FR",
    "name": "Triaize",
    "lat": "46.39265",
    "lng": "-1.19785"
  },
  {
    "country": "FR",
    "name": "Trévoux",
    "lat": "45.94111",
    "lng": "4.76727"
  },
  {
    "country": "FR",
    "name": "Trévou-Tréguignec",
    "lat": "48.81869",
    "lng": "-3.34132"
  },
  {
    "country": "FR",
    "name": "Trévol",
    "lat": "46.62886",
    "lng": "3.30457"
  },
  {
    "country": "FR",
    "name": "Trévé",
    "lat": "48.21147",
    "lng": "-2.79317"
  },
  {
    "country": "FR",
    "name": "Trets",
    "lat": "43.44818",
    "lng": "5.68328"
  },
  {
    "country": "FR",
    "name": "Tressin",
    "lat": "50.6175",
    "lng": "3.19354"
  },
  {
    "country": "FR",
    "name": "Tresses",
    "lat": "44.84781",
    "lng": "-0.46296"
  },
  {
    "country": "FR",
    "name": "Tresserve",
    "lat": "45.67785",
    "lng": "5.90153"
  },
  {
    "country": "FR",
    "name": "Tressange",
    "lat": "49.40271",
    "lng": "5.98084"
  },
  {
    "country": "FR",
    "name": "Tresques",
    "lat": "44.10689",
    "lng": "4.58739"
  },
  {
    "country": "FR",
    "name": "Tresbœuf",
    "lat": "47.88333",
    "lng": "-1.55"
  },
  {
    "country": "FR",
    "name": "Trept",
    "lat": "45.68561",
    "lng": "5.31617"
  },
  {
    "country": "FR",
    "name": "Tréon",
    "lat": "48.67709",
    "lng": "1.32668"
  },
  {
    "country": "FR",
    "name": "Trémuson",
    "lat": "48.52325",
    "lng": "-2.84833"
  },
  {
    "country": "FR",
    "name": "Tréméven",
    "lat": "47.9",
    "lng": "-3.53333"
  },
  {
    "country": "FR",
    "name": "Trémery",
    "lat": "49.2461",
    "lng": "6.22369"
  },
  {
    "country": "FR",
    "name": "Trémentines",
    "lat": "47.12357",
    "lng": "-0.785"
  },
  {
    "country": "FR",
    "name": "Tremblay-en-France",
    "lat": "48.94956",
    "lng": "2.5684"
  },
  {
    "country": "FR",
    "name": "Tremblay",
    "lat": "48.42216",
    "lng": "-1.47555"
  },
  {
    "country": "FR",
    "name": "Trélon",
    "lat": "50.05805",
    "lng": "4.102"
  },
  {
    "country": "FR",
    "name": "Trélivan",
    "lat": "48.43198",
    "lng": "-2.11748"
  },
  {
    "country": "FR",
    "name": "Trélissac",
    "lat": "45.19766",
    "lng": "0.78615"
  },
  {
    "country": "FR",
    "name": "Trélévern",
    "lat": "48.81071",
    "lng": "-3.37141"
  },
  {
    "country": "FR",
    "name": "Trélazé",
    "lat": "47.44565",
    "lng": "-0.4654"
  },
  {
    "country": "FR",
    "name": "Treize-Septiers",
    "lat": "46.98524",
    "lng": "-1.22921"
  },
  {
    "country": "FR",
    "name": "Treillières",
    "lat": "47.3306",
    "lng": "-1.61918"
  },
  {
    "country": "FR",
    "name": "Treignac",
    "lat": "45.53558",
    "lng": "1.79621"
  },
  {
    "country": "FR",
    "name": "Trégunc",
    "lat": "47.85",
    "lng": "-3.85"
  },
  {
    "country": "FR",
    "name": "Tréguier",
    "lat": "48.78333",
    "lng": "-3.23333"
  },
  {
    "country": "FR",
    "name": "Trégastel",
    "lat": "48.81667",
    "lng": "-3.5"
  },
  {
    "country": "FR",
    "name": "Treffort-Cuisiat",
    "lat": "46.26667",
    "lng": "5.36667"
  },
  {
    "country": "FR",
    "name": "Treffléan",
    "lat": "47.68163",
    "lng": "-2.61287"
  },
  {
    "country": "FR",
    "name": "Treffiagat",
    "lat": "47.81667",
    "lng": "-4.26667"
  },
  {
    "country": "FR",
    "name": "Trédrez-Locquémeau",
    "lat": "48.7",
    "lng": "-3.56667"
  },
  {
    "country": "FR",
    "name": "Trédarzec",
    "lat": "48.78583",
    "lng": "-3.201"
  },
  {
    "country": "FR",
    "name": "Trébeurden",
    "lat": "48.76667",
    "lng": "-3.56667"
  },
  {
    "country": "FR",
    "name": "Trèbes",
    "lat": "43.21064",
    "lng": "2.44165"
  },
  {
    "country": "FR",
    "name": "Trappes",
    "lat": "48.77413",
    "lng": "2.01781"
  },
  {
    "country": "FR",
    "name": "Trans-en-Provence",
    "lat": "43.505",
    "lng": "6.48571"
  },
  {
    "country": "FR",
    "name": "Trangé",
    "lat": "48.02706",
    "lng": "0.11054"
  },
  {
    "country": "FR",
    "name": "Tramoyes",
    "lat": "45.87627",
    "lng": "4.96568"
  },
  {
    "country": "FR",
    "name": "Traînou",
    "lat": "47.97353",
    "lng": "2.10399"
  },
  {
    "country": "FR",
    "name": "Tracy-le-Mont",
    "lat": "49.47225",
    "lng": "3.00939"
  },
  {
    "country": "FR",
    "name": "Touvre",
    "lat": "45.66667",
    "lng": "0.25"
  },
  {
    "country": "FR",
    "name": "Touvois",
    "lat": "46.90208",
    "lng": "-1.68333"
  },
  {
    "country": "FR",
    "name": "Toutlemonde",
    "lat": "47.05488",
    "lng": "-0.76548"
  },
  {
    "country": "FR",
    "name": "Toutainville",
    "lat": "49.36474",
    "lng": "0.46538"
  },
  {
    "country": "FR",
    "name": "Toussieu",
    "lat": "45.65371",
    "lng": "4.98618"
  },
  {
    "country": "FR",
    "name": "Toury",
    "lat": "48.19397",
    "lng": "1.93484"
  },
  {
    "country": "FR",
    "name": "Tourville-sur-Odon",
    "lat": "49.14154",
    "lng": "-0.50128"
  },
  {
    "country": "FR",
    "name": "Tourville-sur-Arques",
    "lat": "49.85926",
    "lng": "1.10238"
  },
  {
    "country": "FR",
    "name": "Tourville-la-Rivière",
    "lat": "49.32782",
    "lng": "1.10551"
  },
  {
    "country": "FR",
    "name": "Tourves",
    "lat": "43.40776",
    "lng": "5.92415"
  },
  {
    "country": "FR",
    "name": "Tours-sur-Marne",
    "lat": "49.04873",
    "lng": "4.1206"
  },
  {
    "country": "FR",
    "name": "Tours",
    "lat": "47.39484",
    "lng": "0.70398"
  },
  {
    "country": "FR",
    "name": "Tourrette-Levens",
    "lat": "43.78746",
    "lng": "7.27364"
  },
  {
    "country": "FR",
    "name": "Tourouvre",
    "lat": "48.58951",
    "lng": "0.65253"
  },
  {
    "country": "FR",
    "name": "Tournus",
    "lat": "46.56758",
    "lng": "4.90574"
  },
  {
    "country": "FR",
    "name": "Tournon-Saint-Martin",
    "lat": "46.73423",
    "lng": "0.95514"
  },
  {
    "country": "FR",
    "name": "Tournon-sur-Rhône",
    "lat": "45.06667",
    "lng": "4.83333"
  },
  {
    "country": "FR",
    "name": "Tournes",
    "lat": "49.797",
    "lng": "4.63856"
  },
  {
    "country": "FR",
    "name": "Tournehem-sur-la-Hem",
    "lat": "50.8",
    "lng": "2.05"
  },
  {
    "country": "FR",
    "name": "Tournefeuille",
    "lat": "43.58872",
    "lng": "1.31922"
  },
  {
    "country": "FR",
    "name": "Tournay",
    "lat": "43.18438",
    "lng": "0.24454"
  },
  {
    "country": "FR",
    "name": "Tournan-en-Brie",
    "lat": "48.74146",
    "lng": "2.772"
  },
  {
    "country": "FR",
    "name": "Tourlaville",
    "lat": "49.63829",
    "lng": "-1.56639"
  },
  {
    "country": "FR",
    "name": "Tourrettes-sur-Loup",
    "lat": "43.71667",
    "lng": "7.05"
  },
  {
    "country": "FR",
    "name": "Tourcoing",
    "lat": "50.72391",
    "lng": "3.16117"
  },
  {
    "country": "FR",
    "name": "Tourbes",
    "lat": "43.44615",
    "lng": "3.37852"
  },
  {
    "country": "FR",
    "name": "Touquin",
    "lat": "48.73498",
    "lng": "3.01222"
  },
  {
    "country": "FR",
    "name": "Touques",
    "lat": "49.34443",
    "lng": "0.10218"
  },
  {
    "country": "FR",
    "name": "Toulouse",
    "lat": "43.60426",
    "lng": "1.44367"
  },
  {
    "country": "FR",
    "name": "Toulouges",
    "lat": "42.66961",
    "lng": "2.83008"
  },
  {
    "country": "FR",
    "name": "Toulon-sur-Arroux",
    "lat": "46.69345",
    "lng": "4.13869"
  },
  {
    "country": "FR",
    "name": "Toulon-sur-Allier",
    "lat": "46.51845",
    "lng": "3.35989"
  },
  {
    "country": "FR",
    "name": "Toulon",
    "lat": "43.12442",
    "lng": "5.92836"
  },
  {
    "country": "FR",
    "name": "Toulenne",
    "lat": "44.55665",
    "lng": "-0.26328"
  },
  {
    "country": "FR",
    "name": "Toulaud",
    "lat": "44.90009",
    "lng": "4.81721"
  },
  {
    "country": "FR",
    "name": "Toul",
    "lat": "48.68333",
    "lng": "5.9"
  },
  {
    "country": "FR",
    "name": "Toufflers",
    "lat": "50.66039",
    "lng": "3.23358"
  },
  {
    "country": "FR",
    "name": "Toucy",
    "lat": "47.73602",
    "lng": "3.29502"
  },
  {
    "country": "FR",
    "name": "Tôtes",
    "lat": "49.68091",
    "lng": "1.04649"
  },
  {
    "country": "FR",
    "name": "Tossiat",
    "lat": "46.13989",
    "lng": "5.31139"
  },
  {
    "country": "FR",
    "name": "Tosse",
    "lat": "43.68916",
    "lng": "-1.33262"
  },
  {
    "country": "FR",
    "name": "Torreilles",
    "lat": "42.75433",
    "lng": "2.99292"
  },
  {
    "country": "FR",
    "name": "Torigni-sur-Vire",
    "lat": "49.03702",
    "lng": "-0.98214"
  },
  {
    "country": "FR",
    "name": "Torfou",
    "lat": "47.03682",
    "lng": "-1.11635"
  },
  {
    "country": "FR",
    "name": "Torcy",
    "lat": "48.85",
    "lng": "2.65"
  },
  {
    "country": "FR",
    "name": "Torcy",
    "lat": "46.76857",
    "lng": "4.45333"
  },
  {
    "country": "FR",
    "name": "Torcé",
    "lat": "48.0612",
    "lng": "-1.26708"
  },
  {
    "country": "FR",
    "name": "Tonquédec",
    "lat": "48.66886",
    "lng": "-3.39712"
  },
  {
    "country": "FR",
    "name": "Tonnerre",
    "lat": "47.85628",
    "lng": "3.97369"
  },
  {
    "country": "FR",
    "name": "Tonneins",
    "lat": "44.39206",
    "lng": "0.31241"
  },
  {
    "country": "FR",
    "name": "Tonnay-Charente",
    "lat": "45.949",
    "lng": "-0.8935"
  },
  {
    "country": "FR",
    "name": "Tonnay-Boutonne",
    "lat": "45.96815",
    "lng": "-0.70847"
  },
  {
    "country": "FR",
    "name": "Tomblaine",
    "lat": "48.68333",
    "lng": "6.21312"
  },
  {
    "country": "FR",
    "name": "Tollevast",
    "lat": "49.57437",
    "lng": "-1.62746"
  },
  {
    "country": "FR",
    "name": "Tocane-Saint-Apre",
    "lat": "45.25404",
    "lng": "0.49682"
  },
  {
    "country": "FR",
    "name": "Tinténiac",
    "lat": "48.3286",
    "lng": "-1.8363"
  },
  {
    "country": "FR",
    "name": "Tinqueux",
    "lat": "49.25",
    "lng": "3.98333"
  },
  {
    "country": "FR",
    "name": "Tinchebray",
    "lat": "48.76437",
    "lng": "-0.73333"
  },
  {
    "country": "FR",
    "name": "Tilques",
    "lat": "50.77712",
    "lng": "2.19948"
  },
  {
    "country": "FR",
    "name": "Tilly-sur-Seulles",
    "lat": "49.17598",
    "lng": "-0.62605"
  },
  {
    "country": "FR",
    "name": "Tilloy-lès-Mofflaines",
    "lat": "50.27519",
    "lng": "2.81456"
  },
  {
    "country": "FR",
    "name": "Tillières-sur-Avre",
    "lat": "48.75585",
    "lng": "1.05388"
  },
  {
    "country": "FR",
    "name": "Tillières",
    "lat": "47.14397",
    "lng": "-1.16334"
  },
  {
    "country": "FR",
    "name": "Tillé",
    "lat": "49.46415",
    "lng": "2.11038"
  },
  {
    "country": "FR",
    "name": "Tigy",
    "lat": "47.79365",
    "lng": "2.19767"
  },
  {
    "country": "FR",
    "name": "Tignieu-Jameyzieu",
    "lat": "45.73564",
    "lng": "5.18046"
  },
  {
    "country": "FR",
    "name": "Tignes",
    "lat": "45.49604",
    "lng": "6.92463"
  },
  {
    "country": "FR",
    "name": "Tigery",
    "lat": "48.64257",
    "lng": "2.50779"
  },
  {
    "country": "FR",
    "name": "Tiffauges",
    "lat": "47.0108",
    "lng": "-1.10999"
  },
  {
    "country": "FR",
    "name": "Tiercé",
    "lat": "47.61587",
    "lng": "-0.46609"
  },
  {
    "country": "FR",
    "name": "Thyez",
    "lat": "46.08249",
    "lng": "6.53777"
  },
  {
    "country": "FR",
    "name": "Thury-Harcourt",
    "lat": "48.98434",
    "lng": "-0.47519"
  },
  {
    "country": "FR",
    "name": "Thurins",
    "lat": "45.68093",
    "lng": "4.63968"
  },
  {
    "country": "FR",
    "name": "Thuré",
    "lat": "46.83221",
    "lng": "0.45797"
  },
  {
    "country": "FR",
    "name": "Thun-Saint-Amand",
    "lat": "50.47276",
    "lng": "3.45115"
  },
  {
    "country": "FR",
    "name": "Thumeries",
    "lat": "50.47662",
    "lng": "3.055"
  },
  {
    "country": "FR",
    "name": "Thuir",
    "lat": "42.6329",
    "lng": "2.75471"
  },
  {
    "country": "FR",
    "name": "Thueyts",
    "lat": "44.67828",
    "lng": "4.21916"
  },
  {
    "country": "FR",
    "name": "Thuellin",
    "lat": "45.63964",
    "lng": "5.5084"
  },
  {
    "country": "FR",
    "name": "Thourotte",
    "lat": "49.47591",
    "lng": "2.8821"
  },
  {
    "country": "FR",
    "name": "Thouars",
    "lat": "46.97602",
    "lng": "-0.21507"
  },
  {
    "country": "FR",
    "name": "Thouaré-sur-Loire",
    "lat": "47.26893",
    "lng": "-1.43834"
  },
  {
    "country": "FR",
    "name": "Thouarcé",
    "lat": "47.26734",
    "lng": "-0.50186"
  },
  {
    "country": "FR",
    "name": "Thorigny-sur-Oreuse",
    "lat": "48.29297",
    "lng": "3.40128"
  },
  {
    "country": "FR",
    "name": "Thorigny-sur-Marne",
    "lat": "48.88689",
    "lng": "2.71806"
  },
  {
    "country": "FR",
    "name": "Thorigné-sur-Dué",
    "lat": "48.0392",
    "lng": "0.53554"
  },
  {
    "country": "FR",
    "name": "Thorigné",
    "lat": "46.29149",
    "lng": "-0.25122"
  },
  {
    "country": "FR",
    "name": "Thorens-Glières",
    "lat": "45.99475",
    "lng": "6.24581"
  },
  {
    "country": "FR",
    "name": "Thonon-les-Bains",
    "lat": "46.36667",
    "lng": "6.48333"
  },
  {
    "country": "FR",
    "name": "Thônes",
    "lat": "45.88123",
    "lng": "6.32572"
  },
  {
    "country": "FR",
    "name": "Thomery",
    "lat": "48.40723",
    "lng": "2.78852"
  },
  {
    "country": "FR",
    "name": "Thoissey",
    "lat": "46.17405",
    "lng": "4.80331"
  },
  {
    "country": "FR",
    "name": "Thoiry",
    "lat": "48.86715",
    "lng": "1.7976"
  },
  {
    "country": "FR",
    "name": "Thoiry",
    "lat": "46.23762",
    "lng": "5.98111"
  },
  {
    "country": "FR",
    "name": "Thizy-les-Bourgs",
    "lat": "46.02995",
    "lng": "4.31299"
  },
  {
    "country": "FR",
    "name": "Thiviers",
    "lat": "45.41542",
    "lng": "0.91963"
  },
  {
    "country": "FR",
    "name": "Thiverval-Grignon",
    "lat": "48.84964",
    "lng": "1.91729"
  },
  {
    "country": "FR",
    "name": "Thiverny",
    "lat": "49.2518",
    "lng": "2.43609"
  },
  {
    "country": "FR",
    "name": "Thise",
    "lat": "47.28486",
    "lng": "6.08127"
  },
  {
    "country": "FR",
    "name": "Thiron Gardais",
    "lat": "48.31667",
    "lng": "0.98333"
  },
  {
    "country": "FR",
    "name": "Thionville",
    "lat": "49.36667",
    "lng": "6.16667"
  },
  {
    "country": "FR",
    "name": "Thilouze",
    "lat": "47.22415",
    "lng": "0.57963"
  },
  {
    "country": "FR",
    "name": "Thilay",
    "lat": "49.87345",
    "lng": "4.80772"
  },
  {
    "country": "FR",
    "name": "Thil",
    "lat": "49.47464",
    "lng": "5.90789"
  },
  {
    "country": "FR",
    "name": "Thil",
    "lat": "45.81416",
    "lng": "5.0219"
  },
  {
    "country": "FR",
    "name": "Thierville-sur-Meuse",
    "lat": "49.1705",
    "lng": "5.35266"
  },
  {
    "country": "FR",
    "name": "Thiers-sur-Thève",
    "lat": "49.15252",
    "lng": "2.57051"
  },
  {
    "country": "FR",
    "name": "Thiers",
    "lat": "45.85",
    "lng": "3.56667"
  },
  {
    "country": "FR",
    "name": "Thiberville",
    "lat": "49.13768",
    "lng": "0.45502"
  },
  {
    "country": "FR",
    "name": "Thiant",
    "lat": "50.3048",
    "lng": "3.44796"
  },
  {
    "country": "FR",
    "name": "Thiais",
    "lat": "48.76496",
    "lng": "2.3961"
  },
  {
    "country": "FR",
    "name": "Thézan-lès-Béziers",
    "lat": "43.41667",
    "lng": "3.16667"
  },
  {
    "country": "FR",
    "name": "Théza",
    "lat": "42.63797",
    "lng": "2.95108"
  },
  {
    "country": "FR",
    "name": "Theys",
    "lat": "45.30136",
    "lng": "5.99534"
  },
  {
    "country": "FR",
    "name": "Thésée",
    "lat": "47.32345",
    "lng": "1.30882"
  },
  {
    "country": "FR",
    "name": "Thérouanne",
    "lat": "50.63695",
    "lng": "2.25838"
  },
  {
    "country": "FR",
    "name": "Théoule-sur-Mer",
    "lat": "43.5078",
    "lng": "6.9408"
  },
  {
    "country": "FR",
    "name": "Thenon",
    "lat": "45.13897",
    "lng": "1.07211"
  },
  {
    "country": "FR",
    "name": "Thénezay",
    "lat": "46.71879",
    "lng": "-0.02883"
  },
  {
    "country": "FR",
    "name": "Thénac",
    "lat": "45.66705",
    "lng": "-0.65345"
  },
  {
    "country": "FR",
    "name": "Thélus",
    "lat": "50.35441",
    "lng": "2.80146"
  },
  {
    "country": "FR",
    "name": "Theizé",
    "lat": "45.94028",
    "lng": "4.61634"
  },
  {
    "country": "FR",
    "name": "Theix",
    "lat": "47.62916",
    "lng": "-2.65186"
  },
  {
    "country": "FR",
    "name": "Theillay",
    "lat": "47.31429",
    "lng": "2.04028"
  },
  {
    "country": "FR",
    "name": "Théding",
    "lat": "49.12847",
    "lng": "6.8922"
  },
  {
    "country": "FR",
    "name": "Thaon-les-Vosges",
    "lat": "48.25",
    "lng": "6.41667"
  },
  {
    "country": "FR",
    "name": "Thaon",
    "lat": "49.25796",
    "lng": "-0.45605"
  },
  {
    "country": "FR",
    "name": "Thann",
    "lat": "47.81667",
    "lng": "7.08333"
  },
  {
    "country": "FR",
    "name": "Thairé",
    "lat": "46.07341",
    "lng": "-1.0023"
  },
  {
    "country": "FR",
    "name": "Teyran",
    "lat": "43.68528",
    "lng": "3.92889"
  },
  {
    "country": "FR",
    "name": "Teting-sur-Nied",
    "lat": "49.05704",
    "lng": "6.66294"
  },
  {
    "country": "FR",
    "name": "Téteghem",
    "lat": "51.01859",
    "lng": "2.44454"
  },
  {
    "country": "FR",
    "name": "Tessy-sur-Vire",
    "lat": "48.97381",
    "lng": "-1.06087"
  },
  {
    "country": "FR",
    "name": "Tessé-la-Madeleine",
    "lat": "48.54963",
    "lng": "-0.42521"
  },
  {
    "country": "FR",
    "name": "Terville",
    "lat": "49.34668",
    "lng": "6.13346"
  },
  {
    "country": "FR",
    "name": "Terrasson-Lavilledieu",
    "lat": "45.13011",
    "lng": "1.30136"
  },
  {
    "country": "FR",
    "name": "Ternay",
    "lat": "45.60835",
    "lng": "4.81024"
  },
  {
    "country": "FR",
    "name": "Tergnier",
    "lat": "49.65607",
    "lng": "3.30107"
  },
  {
    "country": "FR",
    "name": "Tercis-les-Bains",
    "lat": "43.67048",
    "lng": "-1.10738"
  },
  {
    "country": "FR",
    "name": "Tercé",
    "lat": "46.51667",
    "lng": "0.56386"
  },
  {
    "country": "FR",
    "name": "Tenteling",
    "lat": "49.12544",
    "lng": "6.93751"
  },
  {
    "country": "FR",
    "name": "Tennie",
    "lat": "48.10769",
    "lng": "-0.07626"
  },
  {
    "country": "FR",
    "name": "Tende",
    "lat": "44.08571",
    "lng": "7.5934"
  },
  {
    "country": "FR",
    "name": "Tencin",
    "lat": "45.30953",
    "lng": "5.95818"
  },
  {
    "country": "FR",
    "name": "Tence",
    "lat": "45.11503",
    "lng": "4.29166"
  },
  {
    "country": "FR",
    "name": "Tenay",
    "lat": "45.919",
    "lng": "5.51041"
  },
  {
    "country": "FR",
    "name": "Templeuve",
    "lat": "50.52336",
    "lng": "3.17809"
  },
  {
    "country": "FR",
    "name": "Templemars",
    "lat": "50.57387",
    "lng": "3.05437"
  },
  {
    "country": "FR",
    "name": "Teloché",
    "lat": "47.88819",
    "lng": "0.27086"
  },
  {
    "country": "FR",
    "name": "Telgruc-sur-Mer",
    "lat": "48.23333",
    "lng": "-4.35"
  },
  {
    "country": "FR",
    "name": "Teillé",
    "lat": "47.4617",
    "lng": "-1.2781"
  },
  {
    "country": "FR",
    "name": "Tavers",
    "lat": "47.75921",
    "lng": "1.61267"
  },
  {
    "country": "FR",
    "name": "Taverny",
    "lat": "49.02542",
    "lng": "2.21691"
  },
  {
    "country": "FR",
    "name": "Tavel",
    "lat": "44.0127",
    "lng": "4.69835"
  },
  {
    "country": "FR",
    "name": "Tavaux",
    "lat": "47.03376",
    "lng": "5.405"
  },
  {
    "country": "FR",
    "name": "Tauxigny",
    "lat": "47.21337",
    "lng": "0.83479"
  },
  {
    "country": "FR",
    "name": "Tauriac",
    "lat": "45.04915",
    "lng": "-0.50048"
  },
  {
    "country": "FR",
    "name": "Taupont",
    "lat": "47.95961",
    "lng": "-2.43933"
  },
  {
    "country": "FR",
    "name": "Taulignan",
    "lat": "44.44425",
    "lng": "4.97971"
  },
  {
    "country": "FR",
    "name": "Taulé",
    "lat": "48.6",
    "lng": "-3.9"
  },
  {
    "country": "FR",
    "name": "Tatinghem",
    "lat": "50.74317",
    "lng": "2.20724"
  },
  {
    "country": "FR",
    "name": "Tassin-la-Demi-Lune",
    "lat": "45.75499",
    "lng": "4.78812"
  },
  {
    "country": "FR",
    "name": "Tartas",
    "lat": "43.83248",
    "lng": "-0.80895"
  },
  {
    "country": "FR",
    "name": "Tarnos",
    "lat": "43.5417",
    "lng": "-1.46281"
  },
  {
    "country": "FR",
    "name": "Targon",
    "lat": "44.73495",
    "lng": "-0.26351"
  },
  {
    "country": "FR",
    "name": "Tarbes",
    "lat": "43.23333",
    "lng": "0.08333"
  },
  {
    "country": "FR",
    "name": "Tarascon-sur-Ariège",
    "lat": "42.84545",
    "lng": "1.60332"
  },
  {
    "country": "FR",
    "name": "Tarascon",
    "lat": "43.80583",
    "lng": "4.66028"
  },
  {
    "country": "FR",
    "name": "Tarare",
    "lat": "45.89761",
    "lng": "4.43272"
  },
  {
    "country": "FR",
    "name": "Taradeau",
    "lat": "43.45428",
    "lng": "6.42776"
  },
  {
    "country": "FR",
    "name": "Taponnat-Fleurignac",
    "lat": "45.77868",
    "lng": "0.40932"
  },
  {
    "country": "FR",
    "name": "Tanneron",
    "lat": "43.59083",
    "lng": "6.87495"
  },
  {
    "country": "FR",
    "name": "Tanlay",
    "lat": "47.84488",
    "lng": "4.08504"
  },
  {
    "country": "FR",
    "name": "Taninges",
    "lat": "46.10883",
    "lng": "6.59231"
  },
  {
    "country": "FR",
    "name": "Tancarville",
    "lat": "49.4855",
    "lng": "0.45765"
  },
  {
    "country": "FR",
    "name": "Taluyers",
    "lat": "45.63991",
    "lng": "4.72194"
  },
  {
    "country": "FR",
    "name": "Talmas",
    "lat": "50.03049",
    "lng": "2.32554"
  },
  {
    "country": "FR",
    "name": "Talloires",
    "lat": "45.84036",
    "lng": "6.21416"
  },
  {
    "country": "FR",
    "name": "Tallende",
    "lat": "45.67126",
    "lng": "3.12799"
  },
  {
    "country": "FR",
    "name": "Tallard",
    "lat": "44.46128",
    "lng": "6.05504"
  },
  {
    "country": "FR",
    "name": "Talensac",
    "lat": "48.10847",
    "lng": "-1.92829"
  },
  {
    "country": "FR",
    "name": "Talence",
    "lat": "44.80477",
    "lng": "-0.59543"
  },
  {
    "country": "FR",
    "name": "Talant",
    "lat": "47.33693",
    "lng": "5.00888"
  },
  {
    "country": "FR",
    "name": "Talange",
    "lat": "49.23577",
    "lng": "6.17167"
  },
  {
    "country": "FR",
    "name": "Taissy",
    "lat": "49.21509",
    "lng": "4.09406"
  },
  {
    "country": "FR",
    "name": "Taintrux",
    "lat": "48.24944",
    "lng": "6.89963"
  },
  {
    "country": "FR",
    "name": "Tain-l’Hermitage",
    "lat": "45.07217",
    "lng": "4.83708"
  },
  {
    "country": "FR",
    "name": "Taillecourt",
    "lat": "47.49521",
    "lng": "6.85442"
  },
  {
    "country": "FR",
    "name": "Taillades",
    "lat": "43.83592",
    "lng": "5.09216"
  },
  {
    "country": "FR",
    "name": "Taden",
    "lat": "48.4753",
    "lng": "-2.01946"
  },
  {
    "country": "FR",
    "name": "Tacoignières",
    "lat": "48.83619",
    "lng": "1.67501"
  },
  {
    "country": "FR",
    "name": "Tabanac",
    "lat": "44.72059",
    "lng": "-0.40513"
  },
  {
    "country": "FR",
    "name": "Suze-la-Rousse",
    "lat": "44.28788",
    "lng": "4.84346"
  },
  {
    "country": "FR",
    "name": "Sussargues",
    "lat": "43.7125",
    "lng": "4.0031"
  },
  {
    "country": "FR",
    "name": "Surzur",
    "lat": "47.5785",
    "lng": "-2.62892"
  },
  {
    "country": "FR",
    "name": "Sury-le-Comtal",
    "lat": "45.5342",
    "lng": "4.18642"
  },
  {
    "country": "FR",
    "name": "Survilliers",
    "lat": "49.09712",
    "lng": "2.54449"
  },
  {
    "country": "FR",
    "name": "Surtainville",
    "lat": "49.45977",
    "lng": "-1.81298"
  },
  {
    "country": "FR",
    "name": "Surgères",
    "lat": "46.1082",
    "lng": "-0.75148"
  },
  {
    "country": "FR",
    "name": "Suresnes",
    "lat": "48.87143",
    "lng": "2.22929"
  },
  {
    "country": "FR",
    "name": "Surbourg",
    "lat": "48.91009",
    "lng": "7.84716"
  },
  {
    "country": "FR",
    "name": "Sundhouse",
    "lat": "48.2511",
    "lng": "7.60427"
  },
  {
    "country": "FR",
    "name": "Sundhoffen",
    "lat": "48.04263",
    "lng": "7.4132"
  },
  {
    "country": "FR",
    "name": "Sumène",
    "lat": "43.98057",
    "lng": "3.71575"
  },
  {
    "country": "FR",
    "name": "Sulniac",
    "lat": "47.67375",
    "lng": "-2.57136"
  },
  {
    "country": "FR",
    "name": "Sully-sur-Loire",
    "lat": "47.76372",
    "lng": "2.37238"
  },
  {
    "country": "FR",
    "name": "Suippes",
    "lat": "49.12886",
    "lng": "4.53446"
  },
  {
    "country": "FR",
    "name": "Suèvres",
    "lat": "47.66655",
    "lng": "1.46153"
  },
  {
    "country": "FR",
    "name": "Sucy-en-Brie",
    "lat": "48.76872",
    "lng": "2.53474"
  },
  {
    "country": "FR",
    "name": "Sucé-sur-Erdre",
    "lat": "47.33333",
    "lng": "-1.53333"
  },
  {
    "country": "FR",
    "name": "Strasbourg",
    "lat": "48.58392",
    "lng": "7.74553"
  },
  {
    "country": "FR",
    "name": "Stotzheim",
    "lat": "48.37868",
    "lng": "7.49235"
  },
  {
    "country": "FR",
    "name": "Stosswihr",
    "lat": "48.05108",
    "lng": "7.11001"
  },
  {
    "country": "FR",
    "name": "Stiring-Wendel",
    "lat": "49.20198",
    "lng": "6.9317"
  },
  {
    "country": "FR",
    "name": "Still",
    "lat": "48.54982",
    "lng": "7.40444"
  },
  {
    "country": "FR",
    "name": "Stenay",
    "lat": "49.49489",
    "lng": "5.18606"
  },
  {
    "country": "FR",
    "name": "Steinbourg",
    "lat": "48.77028",
    "lng": "7.41354"
  },
  {
    "country": "FR",
    "name": "Steinbach",
    "lat": "47.8214",
    "lng": "7.15279"
  },
  {
    "country": "FR",
    "name": "Steenwerck",
    "lat": "50.70199",
    "lng": "2.77829"
  },
  {
    "country": "FR",
    "name": "Steenvoorde",
    "lat": "50.81046",
    "lng": "2.58244"
  },
  {
    "country": "FR",
    "name": "Steene",
    "lat": "50.95228",
    "lng": "2.36813"
  },
  {
    "country": "FR",
    "name": "Steenbecque",
    "lat": "50.67421",
    "lng": "2.48442"
  },
  {
    "country": "FR",
    "name": "Stains",
    "lat": "48.95",
    "lng": "2.38333"
  },
  {
    "country": "FR",
    "name": "Staffelfelden",
    "lat": "47.82647",
    "lng": "7.25235"
  },
  {
    "country": "FR",
    "name": "Spycker",
    "lat": "50.96915",
    "lng": "2.32184"
  },
  {
    "country": "FR",
    "name": "Spicheren",
    "lat": "49.19252",
    "lng": "6.96611"
  },
  {
    "country": "FR",
    "name": "Spézet",
    "lat": "48.2",
    "lng": "-3.71667"
  },
  {
    "country": "FR",
    "name": "Spéracèdes",
    "lat": "43.64364",
    "lng": "6.85279"
  },
  {
    "country": "FR",
    "name": "Spay",
    "lat": "47.92384",
    "lng": "0.15258"
  },
  {
    "country": "FR",
    "name": "Soyons",
    "lat": "44.88613",
    "lng": "4.85059"
  },
  {
    "country": "FR",
    "name": "Soyaux",
    "lat": "45.65",
    "lng": "0.2"
  },
  {
    "country": "FR",
    "name": "Souvigny",
    "lat": "46.53352",
    "lng": "3.19247"
  },
  {
    "country": "FR",
    "name": "Soustons",
    "lat": "43.75328",
    "lng": "-1.3278"
  },
  {
    "country": "FR",
    "name": "Soussans",
    "lat": "45.05619",
    "lng": "-0.69916"
  },
  {
    "country": "FR",
    "name": "Sourzac",
    "lat": "45.04978",
    "lng": "0.39598"
  },
  {
    "country": "FR",
    "name": "Sours",
    "lat": "48.41043",
    "lng": "1.59889"
  },
  {
    "country": "FR",
    "name": "Sourdun",
    "lat": "48.53688",
    "lng": "3.352"
  },
  {
    "country": "FR",
    "name": "Sourdeval",
    "lat": "48.72312",
    "lng": "-0.92223"
  },
  {
    "country": "FR",
    "name": "Sourcieux-les-Mines",
    "lat": "45.80566",
    "lng": "4.62358"
  },
  {
    "country": "FR",
    "name": "Souraïde",
    "lat": "43.34154",
    "lng": "-1.47559"
  },
  {
    "country": "FR",
    "name": "Souprosse",
    "lat": "43.78869",
    "lng": "-0.71035"
  },
  {
    "country": "FR",
    "name": "Souppes-sur-Loing",
    "lat": "48.18297",
    "lng": "2.73521"
  },
  {
    "country": "FR",
    "name": "Soumoulou",
    "lat": "43.26667",
    "lng": "-0.18333"
  },
  {
    "country": "FR",
    "name": "Soultz-sous-Forêts",
    "lat": "48.93693",
    "lng": "7.8811"
  },
  {
    "country": "FR",
    "name": "Soultzmatt",
    "lat": "47.96188",
    "lng": "7.23759"
  },
  {
    "country": "FR",
    "name": "Soultz-Haut-Rhin",
    "lat": "47.8874",
    "lng": "7.23042"
  },
  {
    "country": "FR",
    "name": "Soultzeren",
    "lat": "48.06213",
    "lng": "7.10214"
  },
  {
    "country": "FR",
    "name": "Soullans",
    "lat": "46.79624",
    "lng": "-1.90106"
  },
  {
    "country": "FR",
    "name": "Souligné-sous-Ballon",
    "lat": "48.13758",
    "lng": "0.23572"
  },
  {
    "country": "FR",
    "name": "Soulgé-sur-Ouette",
    "lat": "48.06667",
    "lng": "-0.56667"
  },
  {
    "country": "FR",
    "name": "Soulaire-et-Bourg",
    "lat": "47.57896",
    "lng": "-0.55232"
  },
  {
    "country": "FR",
    "name": "Soulaines-sur-Aubance",
    "lat": "47.36381",
    "lng": "-0.52265"
  },
  {
    "country": "FR",
    "name": "Soulac-sur-Mer",
    "lat": "45.51068",
    "lng": "-1.12524"
  },
  {
    "country": "FR",
    "name": "Souillac",
    "lat": "44.8972",
    "lng": "1.47224"
  },
  {
    "country": "FR",
    "name": "Soufflenheim",
    "lat": "48.83026",
    "lng": "7.96268"
  },
  {
    "country": "FR",
    "name": "Souffelweyersheim",
    "lat": "48.6354",
    "lng": "7.74141"
  },
  {
    "country": "FR",
    "name": "Souesmes",
    "lat": "47.45638",
    "lng": "2.17495"
  },
  {
    "country": "FR",
    "name": "Soues",
    "lat": "43.20736",
    "lng": "0.09874"
  },
  {
    "country": "FR",
    "name": "Soudan",
    "lat": "47.73777",
    "lng": "-1.30566"
  },
  {
    "country": "FR",
    "name": "Soucy",
    "lat": "48.24956",
    "lng": "3.32385"
  },
  {
    "country": "FR",
    "name": "Soucieu-en-Jarrest",
    "lat": "45.68017",
    "lng": "4.70334"
  },
  {
    "country": "FR",
    "name": "Soucht",
    "lat": "48.95902",
    "lng": "7.33434"
  },
  {
    "country": "FR",
    "name": "Souchez",
    "lat": "50.39291",
    "lng": "2.73984"
  },
  {
    "country": "FR",
    "name": "Soucelles",
    "lat": "47.56848",
    "lng": "-0.41819"
  },
  {
    "country": "FR",
    "name": "Soubise",
    "lat": "45.92395",
    "lng": "-1.00938"
  },
  {
    "country": "FR",
    "name": "Soual",
    "lat": "43.5553",
    "lng": "2.11679"
  },
  {
    "country": "FR",
    "name": "Sotteville-lès-Rouen",
    "lat": "49.40972",
    "lng": "1.09005"
  },
  {
    "country": "FR",
    "name": "Sottevast",
    "lat": "49.52374",
    "lng": "-1.59169"
  },
  {
    "country": "FR",
    "name": "Sospel",
    "lat": "43.87847",
    "lng": "7.4484"
  },
  {
    "country": "FR",
    "name": "Sornay",
    "lat": "46.63023",
    "lng": "5.17999"
  },
  {
    "country": "FR",
    "name": "Sormiou",
    "lat": "43.20959",
    "lng": "5.41872"
  },
  {
    "country": "FR",
    "name": "Sorigny",
    "lat": "47.24329",
    "lng": "0.6952"
  },
  {
    "country": "FR",
    "name": "Sorgues",
    "lat": "44.01023",
    "lng": "4.87381"
  },
  {
    "country": "FR",
    "name": "Sorges",
    "lat": "45.30563",
    "lng": "0.87328"
  },
  {
    "country": "FR",
    "name": "Sorèze",
    "lat": "43.45241",
    "lng": "2.06799"
  },
  {
    "country": "FR",
    "name": "Sorel-Moussel",
    "lat": "48.83391",
    "lng": "1.36699"
  },
  {
    "country": "FR",
    "name": "Sorède",
    "lat": "42.53069",
    "lng": "2.95708"
  },
  {
    "country": "FR",
    "name": "Sorbiers",
    "lat": "45.48815",
    "lng": "4.44933"
  },
  {
    "country": "FR",
    "name": "Soorts-Hossegor",
    "lat": "43.6649",
    "lng": "-1.39717"
  },
  {
    "country": "FR",
    "name": "Sonzay",
    "lat": "47.52687",
    "lng": "0.46203"
  },
  {
    "country": "FR",
    "name": "Sonnaz",
    "lat": "45.6216",
    "lng": "5.9184"
  },
  {
    "country": "FR",
    "name": "Sonnay",
    "lat": "45.3557",
    "lng": "4.90637"
  },
  {
    "country": "FR",
    "name": "Songeons",
    "lat": "49.54916",
    "lng": "1.85361"
  },
  {
    "country": "FR",
    "name": "Sonchamp",
    "lat": "48.5759",
    "lng": "1.87753"
  },
  {
    "country": "FR",
    "name": "Sommières",
    "lat": "43.78534",
    "lng": "4.08973"
  },
  {
    "country": "FR",
    "name": "Somain",
    "lat": "50.35961",
    "lng": "3.28108"
  },
  {
    "country": "FR",
    "name": "Solre-le-Château",
    "lat": "50.17432",
    "lng": "4.08898"
  },
  {
    "country": "FR",
    "name": "Solliès-Ville",
    "lat": "43.18228",
    "lng": "6.03858"
  },
  {
    "country": "FR",
    "name": "Solliès-Toucas",
    "lat": "43.20821",
    "lng": "6.02496"
  },
  {
    "country": "FR",
    "name": "Solliès-Pont",
    "lat": "43.18978",
    "lng": "6.04321"
  },
  {
    "country": "FR",
    "name": "Solignac-sur-Loire",
    "lat": "44.96819",
    "lng": "3.88529"
  },
  {
    "country": "FR",
    "name": "Solignac",
    "lat": "45.75528",
    "lng": "1.27563"
  },
  {
    "country": "FR",
    "name": "Soliers",
    "lat": "49.1344",
    "lng": "-0.29613"
  },
  {
    "country": "FR",
    "name": "Solgne",
    "lat": "48.96543",
    "lng": "6.29429"
  },
  {
    "country": "FR",
    "name": "Solesmes",
    "lat": "50.18468",
    "lng": "3.49799"
  },
  {
    "country": "FR",
    "name": "Solesmes",
    "lat": "47.85009",
    "lng": "-0.29806"
  },
  {
    "country": "FR",
    "name": "Solers",
    "lat": "48.65919",
    "lng": "2.71617"
  },
  {
    "country": "FR",
    "name": "Solaize",
    "lat": "45.63333",
    "lng": "4.85"
  },
  {
    "country": "FR",
    "name": "Soisy-sur-Seine",
    "lat": "48.64875",
    "lng": "2.45223"
  },
  {
    "country": "FR",
    "name": "Soisy-sur-École",
    "lat": "48.47637",
    "lng": "2.49301"
  },
  {
    "country": "FR",
    "name": "Soisy-sous-Montmorency",
    "lat": "48.98813",
    "lng": "2.30156"
  },
  {
    "country": "FR",
    "name": "Soissons",
    "lat": "49.38167",
    "lng": "3.32361"
  },
  {
    "country": "FR",
    "name": "Soings-en-Sologne",
    "lat": "47.41289",
    "lng": "1.52452"
  },
  {
    "country": "FR",
    "name": "Soignolles-en-Brie",
    "lat": "48.6535",
    "lng": "2.69968"
  },
  {
    "country": "FR",
    "name": "Socx",
    "lat": "50.93571",
    "lng": "2.42422"
  },
  {
    "country": "FR",
    "name": "Sochaux",
    "lat": "47.50808",
    "lng": "6.82748"
  },
  {
    "country": "FR",
    "name": "Smarves",
    "lat": "46.51078",
    "lng": "0.3498"
  },
  {
    "country": "FR",
    "name": "Sizun",
    "lat": "48.4",
    "lng": "-4.08333"
  },
  {
    "country": "FR",
    "name": "Sixt-sur-Aff",
    "lat": "47.77648",
    "lng": "-2.07867"
  },
  {
    "country": "FR",
    "name": "Six-Fours-les-Plages",
    "lat": "43.1",
    "lng": "5.85"
  },
  {
    "country": "FR",
    "name": "Sisteron",
    "lat": "44.18758",
    "lng": "5.94623"
  },
  {
    "country": "FR",
    "name": "Sissonne",
    "lat": "49.57107",
    "lng": "3.89369"
  },
  {
    "country": "FR",
    "name": "Sisco",
    "lat": "42.8",
    "lng": "9.43333"
  },
  {
    "country": "FR",
    "name": "Sireuil",
    "lat": "45.61667",
    "lng": "0.01667"
  },
  {
    "country": "FR",
    "name": "Sion-les-Mines",
    "lat": "47.73476",
    "lng": "-1.5919"
  },
  {
    "country": "FR",
    "name": "Sin-le-Noble",
    "lat": "50.36159",
    "lng": "3.13113"
  },
  {
    "country": "FR",
    "name": "Sinceny",
    "lat": "49.59619",
    "lng": "3.24679"
  },
  {
    "country": "FR",
    "name": "Simiane-Collongue",
    "lat": "43.43067",
    "lng": "5.43454"
  },
  {
    "country": "FR",
    "name": "Simandres",
    "lat": "45.61979",
    "lng": "4.87087"
  },
  {
    "country": "FR",
    "name": "Simandre",
    "lat": "46.62364",
    "lng": "4.98777"
  },
  {
    "country": "FR",
    "name": "Silly-le-Long",
    "lat": "49.10749",
    "lng": "2.79226"
  },
  {
    "country": "FR",
    "name": "Sillingy",
    "lat": "45.94542",
    "lng": "6.03392"
  },
  {
    "country": "FR",
    "name": "Sillery",
    "lat": "49.19822",
    "lng": "4.13244"
  },
  {
    "country": "FR",
    "name": "Sillé-le-Guillaume",
    "lat": "48.18266",
    "lng": "-0.12642"
  },
  {
    "country": "FR",
    "name": "Sillans",
    "lat": "45.34068",
    "lng": "5.38859"
  },
  {
    "country": "FR",
    "name": "Sigolsheim",
    "lat": "48.13475",
    "lng": "7.30137"
  },
  {
    "country": "FR",
    "name": "Signy-le-Petit",
    "lat": "49.90277",
    "lng": "4.2799"
  },
  {
    "country": "FR",
    "name": "Signes",
    "lat": "43.2901",
    "lng": "5.86232"
  },
  {
    "country": "FR",
    "name": "Sigean",
    "lat": "43.02777",
    "lng": "2.97916"
  },
  {
    "country": "FR",
    "name": "Sierentz",
    "lat": "47.65852",
    "lng": "7.45426"
  },
  {
    "country": "FR",
    "name": "Sierck-les-Bains",
    "lat": "49.43942",
    "lng": "6.35816"
  },
  {
    "country": "FR",
    "name": "Sibiril",
    "lat": "48.66667",
    "lng": "-4.06667"
  },
  {
    "country": "FR",
    "name": "Sézanne",
    "lat": "48.72047",
    "lng": "3.72339"
  },
  {
    "country": "FR",
    "name": "Seyssuel",
    "lat": "45.56006",
    "lng": "4.8532"
  },
  {
    "country": "FR",
    "name": "Seyssins",
    "lat": "45.15513",
    "lng": "5.67921"
  },
  {
    "country": "FR",
    "name": "Seyssinet-Pariset",
    "lat": "45.17675",
    "lng": "5.69387"
  },
  {
    "country": "FR",
    "name": "Seysses",
    "lat": "43.49801",
    "lng": "1.31081"
  },
  {
    "country": "FR",
    "name": "Seynod",
    "lat": "45.88549",
    "lng": "6.08831"
  },
  {
    "country": "FR",
    "name": "Seyne-les-Alpes",
    "lat": "44.35042",
    "lng": "6.35634"
  },
  {
    "country": "FR",
    "name": "Sévrier",
    "lat": "45.86415",
    "lng": "6.14026"
  },
  {
    "country": "FR",
    "name": "Sevrey",
    "lat": "46.73825",
    "lng": "4.8403"
  },
  {
    "country": "FR",
    "name": "Sèvres-Anxaumont",
    "lat": "46.57036",
    "lng": "0.46603"
  },
  {
    "country": "FR",
    "name": "Sèvres",
    "lat": "48.82292",
    "lng": "2.21757"
  },
  {
    "country": "FR",
    "name": "Sevran",
    "lat": "48.94472",
    "lng": "2.52746"
  },
  {
    "country": "FR",
    "name": "Sévignac",
    "lat": "48.33297",
    "lng": "-2.33915"
  },
  {
    "country": "FR",
    "name": "Sévérac-le-Château",
    "lat": "44.32429",
    "lng": "3.05929"
  },
  {
    "country": "FR",
    "name": "Sévérac",
    "lat": "47.55008",
    "lng": "-2.07496"
  },
  {
    "country": "FR",
    "name": "Seurre",
    "lat": "46.99923",
    "lng": "5.15138"
  },
  {
    "country": "FR",
    "name": "Seugy",
    "lat": "49.12182",
    "lng": "2.39377"
  },
  {
    "country": "FR",
    "name": "Sète",
    "lat": "43.4028",
    "lng": "3.69278"
  },
  {
    "country": "FR",
    "name": "Sessenheim",
    "lat": "48.79652",
    "lng": "7.98719"
  },
  {
    "country": "FR",
    "name": "Servon-sur-Vilaine",
    "lat": "48.12114",
    "lng": "-1.45971"
  },
  {
    "country": "FR",
    "name": "Servon",
    "lat": "48.71662",
    "lng": "2.58737"
  },
  {
    "country": "FR",
    "name": "Servian",
    "lat": "43.42716",
    "lng": "3.30032"
  },
  {
    "country": "FR",
    "name": "Servas",
    "lat": "46.1329",
    "lng": "5.16538"
  },
  {
    "country": "FR",
    "name": "Serris",
    "lat": "48.84528",
    "lng": "2.78611"
  },
  {
    "country": "FR",
    "name": "Ladoix-Serrigny",
    "lat": "47.06667",
    "lng": "4.88333"
  },
  {
    "country": "FR",
    "name": "Serrières-de-Briord",
    "lat": "45.80701",
    "lng": "5.44831"
  },
  {
    "country": "FR",
    "name": "Serrières",
    "lat": "45.31885",
    "lng": "4.76342"
  },
  {
    "country": "FR",
    "name": "Serres-Castet",
    "lat": "43.38333",
    "lng": "-0.35"
  },
  {
    "country": "FR",
    "name": "Serres",
    "lat": "44.42865",
    "lng": "5.71581"
  },
  {
    "country": "FR",
    "name": "Serre-les-Sapins",
    "lat": "47.25",
    "lng": "5.93333"
  },
  {
    "country": "FR",
    "name": "Serquigny",
    "lat": "49.10943",
    "lng": "0.71016"
  },
  {
    "country": "FR",
    "name": "Serqueux",
    "lat": "49.63202",
    "lng": "1.54005"
  },
  {
    "country": "FR",
    "name": "Serques",
    "lat": "50.79338",
    "lng": "2.20134"
  },
  {
    "country": "FR",
    "name": "Serpaize",
    "lat": "45.55709",
    "lng": "4.92062"
  },
  {
    "country": "FR",
    "name": "Sernhac",
    "lat": "43.91116",
    "lng": "4.55039"
  },
  {
    "country": "FR",
    "name": "Sermoise-sur-Loire",
    "lat": "46.95",
    "lng": "3.18333"
  },
  {
    "country": "FR",
    "name": "Sermérieu",
    "lat": "45.6707",
    "lng": "5.40996"
  },
  {
    "country": "FR",
    "name": "Sermaize-les-Bains",
    "lat": "48.78507",
    "lng": "4.91169"
  },
  {
    "country": "FR",
    "name": "Sermaises",
    "lat": "48.2965",
    "lng": "2.20546"
  },
  {
    "country": "FR",
    "name": "Sérigné",
    "lat": "46.50107",
    "lng": "-0.84453"
  },
  {
    "country": "FR",
    "name": "Sérignan-du-Comtat",
    "lat": "44.1885",
    "lng": "4.84403"
  },
  {
    "country": "FR",
    "name": "Sérignan",
    "lat": "43.27873",
    "lng": "3.27712"
  },
  {
    "country": "FR",
    "name": "Sérifontaine",
    "lat": "49.3544",
    "lng": "1.76873"
  },
  {
    "country": "FR",
    "name": "Sergy",
    "lat": "46.25257",
    "lng": "6.00058"
  },
  {
    "country": "FR",
    "name": "Sergines",
    "lat": "48.34203",
    "lng": "3.26213"
  },
  {
    "country": "FR",
    "name": "Sérézin-du-Rhône",
    "lat": "45.62902",
    "lng": "4.82467"
  },
  {
    "country": "FR",
    "name": "Sérent",
    "lat": "47.82333",
    "lng": "-2.50571"
  },
  {
    "country": "FR",
    "name": "Serémange-Erzange",
    "lat": "49.32062",
    "lng": "6.09092"
  },
  {
    "country": "FR",
    "name": "Séreilhac",
    "lat": "45.76843",
    "lng": "1.08052"
  },
  {
    "country": "FR",
    "name": "Seraincourt",
    "lat": "49.03573",
    "lng": "1.86703"
  },
  {
    "country": "FR",
    "name": "Sequedin",
    "lat": "50.62575",
    "lng": "2.98276"
  },
  {
    "country": "FR",
    "name": "Septfonds",
    "lat": "44.17813",
    "lng": "1.61806"
  },
  {
    "country": "FR",
    "name": "Septeuil",
    "lat": "48.89245",
    "lng": "1.68357"
  },
  {
    "country": "FR",
    "name": "Septèmes-les-Vallons",
    "lat": "43.39834",
    "lng": "5.36596"
  },
  {
    "country": "FR",
    "name": "Septème",
    "lat": "45.55315",
    "lng": "5.00345"
  },
  {
    "country": "FR",
    "name": "Sentheim",
    "lat": "47.7556",
    "lng": "7.05305"
  },
  {
    "country": "FR",
    "name": "Sens-de-Bretagne",
    "lat": "48.33245",
    "lng": "-1.53535"
  },
  {
    "country": "FR",
    "name": "Sens",
    "lat": "48.2",
    "lng": "3.28333"
  },
  {
    "country": "FR",
    "name": "Senones",
    "lat": "48.39475",
    "lng": "6.97818"
  },
  {
    "country": "FR",
    "name": "Senonches",
    "lat": "48.55999",
    "lng": "1.03069"
  },
  {
    "country": "FR",
    "name": "Sennecey-lès-Dijon",
    "lat": "47.28984",
    "lng": "5.10485"
  },
  {
    "country": "FR",
    "name": "Sennecey-le-Grand",
    "lat": "46.64137",
    "lng": "4.86707"
  },
  {
    "country": "FR",
    "name": "Senlis",
    "lat": "49.2",
    "lng": "2.58333"
  },
  {
    "country": "FR",
    "name": "Séné",
    "lat": "47.619",
    "lng": "-2.737"
  },
  {
    "country": "FR",
    "name": "Sénas",
    "lat": "43.74375",
    "lng": "5.078"
  },
  {
    "country": "FR",
    "name": "Semussac",
    "lat": "45.6",
    "lng": "-0.91667"
  },
  {
    "country": "FR",
    "name": "Semur-en-Auxois",
    "lat": "47.48333",
    "lng": "4.33333"
  },
  {
    "country": "FR",
    "name": "Semoy",
    "lat": "47.93333",
    "lng": "1.95"
  },
  {
    "country": "FR",
    "name": "Séméac",
    "lat": "43.22915",
    "lng": "0.10602"
  },
  {
    "country": "FR",
    "name": "Semblançay",
    "lat": "47.5",
    "lng": "0.58333"
  },
  {
    "country": "FR",
    "name": "Sémalens",
    "lat": "43.59225",
    "lng": "2.11208"
  },
  {
    "country": "FR",
    "name": "Selvigny",
    "lat": "50.07971",
    "lng": "3.34899"
  },
  {
    "country": "FR",
    "name": "Seltz",
    "lat": "48.8952",
    "lng": "8.10757"
  },
  {
    "country": "FR",
    "name": "Selongey",
    "lat": "47.58846",
    "lng": "5.18483"
  },
  {
    "country": "FR",
    "name": "Seloncourt",
    "lat": "47.45989",
    "lng": "6.85535"
  },
  {
    "country": "FR",
    "name": "Selles-sur-Cher",
    "lat": "47.27904",
    "lng": "1.55387"
  },
  {
    "country": "FR",
    "name": "Selles-Saint-Denis",
    "lat": "47.38695",
    "lng": "1.92295"
  },
  {
    "country": "FR",
    "name": "Sélestat",
    "lat": "48.26667",
    "lng": "7.45"
  },
  {
    "country": "FR",
    "name": "Seissan",
    "lat": "43.49215",
    "lng": "0.5925"
  },
  {
    "country": "FR",
    "name": "Seingbouse",
    "lat": "49.11341",
    "lng": "6.83186"
  },
  {
    "country": "FR",
    "name": "Seine-Port",
    "lat": "48.55743",
    "lng": "2.55316"
  },
  {
    "country": "FR",
    "name": "Seillans",
    "lat": "43.635",
    "lng": "6.64666"
  },
  {
    "country": "FR",
    "name": "Seilhac",
    "lat": "45.36667",
    "lng": "1.71667"
  },
  {
    "country": "FR",
    "name": "Seilh",
    "lat": "43.69469",
    "lng": "1.35509"
  },
  {
    "country": "FR",
    "name": "Seigy",
    "lat": "47.25688",
    "lng": "1.39964"
  },
  {
    "country": "FR",
    "name": "Seignosse",
    "lat": "43.68774",
    "lng": "-1.37"
  },
  {
    "country": "FR",
    "name": "Seignelay",
    "lat": "47.90542",
    "lng": "3.60136"
  },
  {
    "country": "FR",
    "name": "Seiches-sur-le-Loir",
    "lat": "47.57351",
    "lng": "-0.35628"
  },
  {
    "country": "FR",
    "name": "Seichamps",
    "lat": "48.71114",
    "lng": "6.26186"
  },
  {
    "country": "FR",
    "name": "Segré",
    "lat": "47.68333",
    "lng": "-0.86667"
  },
  {
    "country": "FR",
    "name": "Segonzac",
    "lat": "45.61667",
    "lng": "-0.21667"
  },
  {
    "country": "FR",
    "name": "Ségny",
    "lat": "46.29601",
    "lng": "6.07536"
  },
  {
    "country": "FR",
    "name": "Séez",
    "lat": "45.62209",
    "lng": "6.79957"
  },
  {
    "country": "FR",
    "name": "Sées",
    "lat": "48.60403",
    "lng": "0.17244"
  },
  {
    "country": "FR",
    "name": "Sedan",
    "lat": "49.7",
    "lng": "4.95"
  },
  {
    "country": "FR",
    "name": "Secondigny",
    "lat": "46.61024",
    "lng": "-0.41679"
  },
  {
    "country": "FR",
    "name": "Seclin",
    "lat": "50.54873",
    "lng": "3.02731"
  },
  {
    "country": "FR",
    "name": "Sebourg",
    "lat": "50.34249",
    "lng": "3.64352"
  },
  {
    "country": "FR",
    "name": "Seboncourt",
    "lat": "49.95273",
    "lng": "3.47586"
  },
  {
    "country": "FR",
    "name": "Sébazac-Concourès",
    "lat": "44.40484",
    "lng": "2.60324"
  },
  {
    "country": "FR",
    "name": "Scy-Chazelles",
    "lat": "49.1134",
    "lng": "6.1147"
  },
  {
    "country": "FR",
    "name": "Scorbé-Clairvaux",
    "lat": "46.81061",
    "lng": "0.41369"
  },
  {
    "country": "FR",
    "name": "Scionzier",
    "lat": "46.05447",
    "lng": "6.55757"
  },
  {
    "country": "FR",
    "name": "Sciez",
    "lat": "46.32909",
    "lng": "6.37947"
  },
  {
    "country": "FR",
    "name": "Schwindratzheim",
    "lat": "48.75582",
    "lng": "7.59898"
  },
  {
    "country": "FR",
    "name": "Schweighouse-sur-Moder",
    "lat": "48.82009",
    "lng": "7.7281"
  },
  {
    "country": "FR",
    "name": "Schœneck",
    "lat": "49.21667",
    "lng": "6.91667"
  },
  {
    "country": "FR",
    "name": "Schnersheim",
    "lat": "48.65741",
    "lng": "7.56701"
  },
  {
    "country": "FR",
    "name": "Schirrhein",
    "lat": "48.80161",
    "lng": "7.90588"
  },
  {
    "country": "FR",
    "name": "Schirmeck",
    "lat": "48.48313",
    "lng": "7.22004"
  },
  {
    "country": "FR",
    "name": "Schiltigheim",
    "lat": "48.60749",
    "lng": "7.74931"
  },
  {
    "country": "FR",
    "name": "Scherwiller",
    "lat": "48.28713",
    "lng": "7.42135"
  },
  {
    "country": "FR",
    "name": "Scey-sur-Saône-et-Saint-Albin",
    "lat": "47.66398",
    "lng": "5.97451"
  },
  {
    "country": "FR",
    "name": "Sceaux",
    "lat": "48.77644",
    "lng": "2.29026"
  },
  {
    "country": "FR",
    "name": "Scaër",
    "lat": "48.03333",
    "lng": "-3.7"
  },
  {
    "country": "FR",
    "name": "Saze",
    "lat": "43.9434",
    "lng": "4.68096"
  },
  {
    "country": "FR",
    "name": "Sayat",
    "lat": "45.82754",
    "lng": "3.05206"
  },
  {
    "country": "FR",
    "name": "Savy-Berlette",
    "lat": "50.35249",
    "lng": "2.56456"
  },
  {
    "country": "FR",
    "name": "Savonnières",
    "lat": "47.34769",
    "lng": "0.54961"
  },
  {
    "country": "FR",
    "name": "Savigny-sur-Orge",
    "lat": "48.67677",
    "lng": "2.34835"
  },
  {
    "country": "FR",
    "name": "Savigny-sur-Braye",
    "lat": "47.87923",
    "lng": "0.80981"
  },
  {
    "country": "FR",
    "name": "Savigny-Lévescault",
    "lat": "46.53502",
    "lng": "0.47719"
  },
  {
    "country": "FR",
    "name": "Savigny-le-Temple",
    "lat": "48.57409",
    "lng": "2.58287"
  },
  {
    "country": "FR",
    "name": "Savigny-lès-Beaune",
    "lat": "47.06357",
    "lng": "4.81821"
  },
  {
    "country": "FR",
    "name": "Savigny-en-Véron",
    "lat": "47.20071",
    "lng": "0.14457"
  },
  {
    "country": "FR",
    "name": "Savigny-en-Sancerre",
    "lat": "47.44142",
    "lng": "2.80953"
  },
  {
    "country": "FR",
    "name": "Savigny",
    "lat": "45.81732",
    "lng": "4.57543"
  },
  {
    "country": "FR",
    "name": "Savigneux",
    "lat": "45.6167",
    "lng": "4.0833"
  },
  {
    "country": "FR",
    "name": "Savigné-sur-Lathan",
    "lat": "47.44483",
    "lng": "0.32093"
  },
  {
    "country": "FR",
    "name": "Savigné",
    "lat": "46.1595",
    "lng": "0.31937"
  },
  {
    "country": "FR",
    "name": "Saverne",
    "lat": "48.74164",
    "lng": "7.36221"
  },
  {
    "country": "FR",
    "name": "Saverdun",
    "lat": "43.23526",
    "lng": "1.57398"
  },
  {
    "country": "FR",
    "name": "Savennières",
    "lat": "47.38225",
    "lng": "-0.65708"
  },
  {
    "country": "FR",
    "name": "Savenay",
    "lat": "47.36072",
    "lng": "-1.94215"
  },
  {
    "country": "FR",
    "name": "Savasse",
    "lat": "44.60229",
    "lng": "4.77931"
  },
  {
    "country": "FR",
    "name": "Sauzé-Vaussais",
    "lat": "46.13369",
    "lng": "0.10673"
  },
  {
    "country": "FR",
    "name": "Sauzet",
    "lat": "44.60288",
    "lng": "4.81789"
  },
  {
    "country": "FR",
    "name": "Sauxillanges",
    "lat": "45.55267",
    "lng": "3.3738"
  },
  {
    "country": "FR",
    "name": "Sauvigny-les-Bois",
    "lat": "46.96676",
    "lng": "3.2719"
  },
  {
    "country": "FR",
    "name": "Sauviat-sur-Vige",
    "lat": "45.9072",
    "lng": "1.60827"
  },
  {
    "country": "FR",
    "name": "Sauvian",
    "lat": "43.29293",
    "lng": "3.26024"
  },
  {
    "country": "FR",
    "name": "Sauveterre-de-Guyenne",
    "lat": "44.693",
    "lng": "-0.08549"
  },
  {
    "country": "FR",
    "name": "Sauveterre",
    "lat": "44.02282",
    "lng": "4.79347"
  },
  {
    "country": "FR",
    "name": "Sauveterre-de-Béarn",
    "lat": "43.4",
    "lng": "-0.93333"
  },
  {
    "country": "FR",
    "name": "Sauverny",
    "lat": "46.31514",
    "lng": "6.11827"
  },
  {
    "country": "FR",
    "name": "Sauve",
    "lat": "43.9415",
    "lng": "3.94903"
  },
  {
    "country": "FR",
    "name": "Sauvagnon",
    "lat": "43.4",
    "lng": "-0.38333"
  },
  {
    "country": "FR",
    "name": "Sautron",
    "lat": "47.26274",
    "lng": "-1.67107"
  },
  {
    "country": "FR",
    "name": "Sausset-les-Pins",
    "lat": "43.33136",
    "lng": "5.10431"
  },
  {
    "country": "FR",
    "name": "Saussay",
    "lat": "48.85571",
    "lng": "1.40889"
  },
  {
    "country": "FR",
    "name": "Saussan",
    "lat": "43.5722",
    "lng": "3.775"
  },
  {
    "country": "FR",
    "name": "Sausheim",
    "lat": "47.78976",
    "lng": "7.37134"
  },
  {
    "country": "FR",
    "name": "Saumur",
    "lat": "47.26667",
    "lng": "-0.08333"
  },
  {
    "country": "FR",
    "name": "Saulzoir",
    "lat": "50.24057",
    "lng": "3.4443"
  },
  {
    "country": "FR",
    "name": "Saulxures-sur-Moselotte",
    "lat": "47.94894",
    "lng": "6.7704"
  },
  {
    "country": "FR",
    "name": "Saulxures-lès-Nancy",
    "lat": "48.68907",
    "lng": "6.24587"
  },
  {
    "country": "FR",
    "name": "Saulx-les-Chartreux",
    "lat": "48.69062",
    "lng": "2.26727"
  },
  {
    "country": "FR",
    "name": "Sault-lès-Rethel",
    "lat": "49.4998",
    "lng": "4.36227"
  },
  {
    "country": "FR",
    "name": "Sault",
    "lat": "44.08968",
    "lng": "5.40836"
  },
  {
    "country": "FR",
    "name": "Sault-Brénaz",
    "lat": "45.85431",
    "lng": "5.41424"
  },
  {
    "country": "FR",
    "name": "Saultain",
    "lat": "50.33676",
    "lng": "3.57723"
  },
  {
    "country": "FR",
    "name": "Saulny",
    "lat": "49.1577",
    "lng": "6.10929"
  },
  {
    "country": "FR",
    "name": "Saulnes",
    "lat": "49.53555",
    "lng": "5.82629"
  },
  {
    "country": "FR",
    "name": "Saulieu",
    "lat": "47.28023",
    "lng": "4.22857"
  },
  {
    "country": "FR",
    "name": "Saulgé",
    "lat": "46.37758",
    "lng": "0.87577"
  },
  {
    "country": "FR",
    "name": "Saulcy-sur-Meurthe",
    "lat": "48.23758",
    "lng": "6.96443"
  },
  {
    "country": "FR",
    "name": "Saulce-sur-Rhône",
    "lat": "44.7028",
    "lng": "4.80169"
  },
  {
    "country": "FR",
    "name": "Saujon",
    "lat": "45.67309",
    "lng": "-0.9262"
  },
  {
    "country": "FR",
    "name": "Saugues",
    "lat": "44.96039",
    "lng": "3.54784"
  },
  {
    "country": "FR",
    "name": "Saugnac-et-Cambran",
    "lat": "43.67098",
    "lng": "-0.99495"
  },
  {
    "country": "FR",
    "name": "Saucats",
    "lat": "44.65405",
    "lng": "-0.59643"
  },
  {
    "country": "FR",
    "name": "Saubrigues",
    "lat": "43.60989",
    "lng": "-1.31381"
  },
  {
    "country": "FR",
    "name": "Saubion",
    "lat": "43.6714",
    "lng": "-1.34821"
  },
  {
    "country": "FR",
    "name": "Saubens",
    "lat": "43.47984",
    "lng": "1.35189"
  },
  {
    "country": "FR",
    "name": "Satolas-et-Bonce",
    "lat": "45.69299",
    "lng": "5.13099"
  },
  {
    "country": "FR",
    "name": "Satillieu",
    "lat": "45.15035",
    "lng": "4.61493"
  },
  {
    "country": "FR",
    "name": "Sathonay-Village",
    "lat": "45.8327",
    "lng": "4.88121"
  },
  {
    "country": "FR",
    "name": "Sathonay-Camp",
    "lat": "45.8231",
    "lng": "4.86754"
  },
  {
    "country": "FR",
    "name": "Sassenay",
    "lat": "46.83074",
    "lng": "4.92523"
  },
  {
    "country": "FR",
    "name": "Sassenage",
    "lat": "45.20531",
    "lng": "5.66515"
  },
  {
    "country": "FR",
    "name": "Sarzeau",
    "lat": "47.52772",
    "lng": "-2.76933"
  },
  {
    "country": "FR",
    "name": "Sartrouville",
    "lat": "48.9482",
    "lng": "2.19169"
  },
  {
    "country": "FR",
    "name": "Sartilly",
    "lat": "48.75239",
    "lng": "-1.45678"
  },
  {
    "country": "FR",
    "name": "Sartène",
    "lat": "41.61667",
    "lng": "8.98333"
  },
  {
    "country": "FR",
    "name": "Sars-Poteries",
    "lat": "50.16928",
    "lng": "4.02676"
  },
  {
    "country": "FR",
    "name": "Sarry",
    "lat": "48.91852",
    "lng": "4.40621"
  },
  {
    "country": "FR",
    "name": "Sarrola-Carcopino",
    "lat": "42.01241",
    "lng": "8.85055"
  },
  {
    "country": "FR",
    "name": "Sarrians",
    "lat": "44.08401",
    "lng": "4.96965"
  },
  {
    "country": "FR",
    "name": "Sarrewerden",
    "lat": "48.92261",
    "lng": "7.08412"
  },
  {
    "country": "FR",
    "name": "Sarre-Union",
    "lat": "48.93818",
    "lng": "7.09373"
  },
  {
    "country": "FR",
    "name": "Sarreinsming",
    "lat": "49.09121",
    "lng": "7.11053"
  },
  {
    "country": "FR",
    "name": "Sarreguemines",
    "lat": "49.10995",
    "lng": "7.06747"
  },
  {
    "country": "FR",
    "name": "Sarrebourg",
    "lat": "48.73333",
    "lng": "7.05"
  },
  {
    "country": "FR",
    "name": "Sarras",
    "lat": "45.18679",
    "lng": "4.80004"
  },
  {
    "country": "FR",
    "name": "Sarralbe",
    "lat": "48.99858",
    "lng": "7.03074"
  },
  {
    "country": "FR",
    "name": "Sarlat-la-Canéda",
    "lat": "44.88902",
    "lng": "1.21656"
  },
  {
    "country": "FR",
    "name": "Sari-Solenzara",
    "lat": "41.83519",
    "lng": "9.3747"
  },
  {
    "country": "FR",
    "name": "Sargé-sur-Braye",
    "lat": "47.92352",
    "lng": "0.8534"
  },
  {
    "country": "FR",
    "name": "Sargé-lès-le-Mans",
    "lat": "48.03333",
    "lng": "0.23333"
  },
  {
    "country": "FR",
    "name": "Sare",
    "lat": "43.3126",
    "lng": "-1.58012"
  },
  {
    "country": "FR",
    "name": "Sarcelles",
    "lat": "49",
    "lng": "2.38333"
  },
  {
    "country": "FR",
    "name": "Sarbazan",
    "lat": "44.02029",
    "lng": "-0.31294"
  },
  {
    "country": "FR",
    "name": "Saran",
    "lat": "47.95013",
    "lng": "1.87601"
  },
  {
    "country": "FR",
    "name": "Saône",
    "lat": "47.22311",
    "lng": "6.11682"
  },
  {
    "country": "FR",
    "name": "Sanvignes-les-Mines",
    "lat": "46.66444",
    "lng": "4.29188"
  },
  {
    "country": "FR",
    "name": "Santes",
    "lat": "50.59316",
    "lng": "2.96289"
  },
  {
    "country": "FR",
    "name": "Santeny",
    "lat": "48.7273",
    "lng": "2.57346"
  },
  {
    "country": "FR",
    "name": "Santec",
    "lat": "48.7",
    "lng": "-4.03333"
  },
  {
    "country": "FR",
    "name": "Santa-Maria-di-Lota",
    "lat": "42.74783",
    "lng": "9.43202"
  },
  {
    "country": "FR",
    "name": "Santa-Lucia-di-Moriani",
    "lat": "42.38212",
    "lng": "9.52242"
  },
  {
    "country": "FR",
    "name": "Sansac-de-Marmiesse",
    "lat": "44.88485",
    "lng": "2.34701"
  },
  {
    "country": "FR",
    "name": "Sannois",
    "lat": "48.96667",
    "lng": "2.25"
  },
  {
    "country": "FR",
    "name": "San-Nicolao",
    "lat": "42.36939",
    "lng": "9.50943"
  },
  {
    "country": "FR",
    "name": "Sannerville",
    "lat": "49.18018",
    "lng": "-0.22434"
  },
  {
    "country": "FR",
    "name": "San-Martino-di-Lota",
    "lat": "42.73163",
    "lng": "9.43966"
  },
  {
    "country": "FR",
    "name": "Sanguinet",
    "lat": "44.4832",
    "lng": "-1.07457"
  },
  {
    "country": "FR",
    "name": "Sangatte",
    "lat": "50.94564",
    "lng": "1.75321"
  },
  {
    "country": "FR",
    "name": "Sandillon",
    "lat": "47.8451",
    "lng": "2.03155"
  },
  {
    "country": "FR",
    "name": "Sand",
    "lat": "48.38319",
    "lng": "7.61233"
  },
  {
    "country": "FR",
    "name": "Sancoins",
    "lat": "46.83314",
    "lng": "2.92238"
  },
  {
    "country": "FR",
    "name": "Sancey-le-Grand",
    "lat": "47.29489",
    "lng": "6.58287"
  },
  {
    "country": "FR",
    "name": "Sancerre",
    "lat": "47.32889",
    "lng": "2.83447"
  },
  {
    "country": "FR",
    "name": "Sancé",
    "lat": "46.33926",
    "lng": "4.83049"
  },
  {
    "country": "FR",
    "name": "Sanary-sur-Mer",
    "lat": "43.11783",
    "lng": "5.80007"
  },
  {
    "country": "FR",
    "name": "Samoreau",
    "lat": "48.42946",
    "lng": "2.75587"
  },
  {
    "country": "FR",
    "name": "Samois-sur-Seine",
    "lat": "48.45251",
    "lng": "2.7504"
  },
  {
    "country": "FR",
    "name": "Samoëns",
    "lat": "46.08282",
    "lng": "6.72647"
  },
  {
    "country": "FR",
    "name": "Sammeron",
    "lat": "48.94721",
    "lng": "3.08333"
  },
  {
    "country": "FR",
    "name": "Samer",
    "lat": "50.6384",
    "lng": "1.74628"
  },
  {
    "country": "FR",
    "name": "Saméon",
    "lat": "50.47135",
    "lng": "3.33544"
  },
  {
    "country": "FR",
    "name": "Samatan",
    "lat": "43.49286",
    "lng": "0.92976"
  },
  {
    "country": "FR",
    "name": "Samadet",
    "lat": "43.63761",
    "lng": "-0.48785"
  },
  {
    "country": "FR",
    "name": "Salviac",
    "lat": "44.6808",
    "lng": "1.26506"
  },
  {
    "country": "FR",
    "name": "Salouël",
    "lat": "49.86988",
    "lng": "2.2434"
  },
  {
    "country": "FR",
    "name": "Salon-de-Provence",
    "lat": "43.64074",
    "lng": "5.09545"
  },
  {
    "country": "FR",
    "name": "Salomé",
    "lat": "50.53352",
    "lng": "2.84709"
  },
  {
    "country": "FR",
    "name": "Salles-sur-Mer",
    "lat": "46.10543",
    "lng": "-1.05741"
  },
  {
    "country": "FR",
    "name": "Salles-la-Source",
    "lat": "44.43505",
    "lng": "2.51283"
  },
  {
    "country": "FR",
    "name": "Salles-Curan",
    "lat": "44.1822",
    "lng": "2.78821"
  },
  {
    "country": "FR",
    "name": "Salles",
    "lat": "44.55",
    "lng": "-0.86073"
  },
  {
    "country": "FR",
    "name": "Sallertaine",
    "lat": "46.86017",
    "lng": "-1.95522"
  },
  {
    "country": "FR",
    "name": "Sallebœuf",
    "lat": "44.83333",
    "lng": "-0.4"
  },
  {
    "country": "FR",
    "name": "Sallaumines",
    "lat": "50.41749",
    "lng": "2.86174"
  },
  {
    "country": "FR",
    "name": "Sallanches",
    "lat": "45.94423",
    "lng": "6.63162"
  },
  {
    "country": "FR",
    "name": "Salins-les-Thermes",
    "lat": "45.47169",
    "lng": "6.53051"
  },
  {
    "country": "FR",
    "name": "Salins-les-Bains",
    "lat": "46.94663",
    "lng": "5.87763"
  },
  {
    "country": "FR",
    "name": "Salins",
    "lat": "48.42156",
    "lng": "3.0213"
  },
  {
    "country": "FR",
    "name": "Salindres",
    "lat": "44.17174",
    "lng": "4.1602"
  },
  {
    "country": "FR",
    "name": "Saligny",
    "lat": "46.80833",
    "lng": "-1.42726"
  },
  {
    "country": "FR",
    "name": "Salignac",
    "lat": "45.01607",
    "lng": "-0.37964"
  },
  {
    "country": "FR",
    "name": "Salignac-Eyvigues",
    "lat": "44.97464",
    "lng": "1.32428"
  },
  {
    "country": "FR",
    "name": "Salies-du-Salat",
    "lat": "43.10074",
    "lng": "0.95866"
  },
  {
    "country": "FR",
    "name": "Salies-de-Béarn",
    "lat": "43.47422",
    "lng": "-0.92448"
  },
  {
    "country": "FR",
    "name": "Saleux",
    "lat": "49.8563",
    "lng": "2.23698"
  },
  {
    "country": "FR",
    "name": "Sales",
    "lat": "45.87576",
    "lng": "5.95998"
  },
  {
    "country": "FR",
    "name": "Salernes",
    "lat": "43.56349",
    "lng": "6.23398"
  },
  {
    "country": "FR",
    "name": "Saleilles",
    "lat": "42.65418",
    "lng": "2.95309"
  },
  {
    "country": "FR",
    "name": "Salses-le-Château",
    "lat": "42.83333",
    "lng": "2.91667"
  },
  {
    "country": "FR",
    "name": "Salbris",
    "lat": "47.4242",
    "lng": "2.05124"
  },
  {
    "country": "FR",
    "name": "Salbert",
    "lat": "47.67236",
    "lng": "6.82209"
  },
  {
    "country": "FR",
    "name": "Salaise-sur-Sanne",
    "lat": "45.34234",
    "lng": "4.81829"
  },
  {
    "country": "FR",
    "name": "Salagnon",
    "lat": "45.66713",
    "lng": "5.35809"
  },
  {
    "country": "FR",
    "name": "Saizerais",
    "lat": "48.79083",
    "lng": "6.04472"
  },
  {
    "country": "FR",
    "name": "Saïx",
    "lat": "43.58333",
    "lng": "2.18333"
  },
  {
    "country": "FR",
    "name": "Saivres",
    "lat": "46.43262",
    "lng": "-0.23677"
  },
  {
    "country": "FR",
    "name": "Saint-Zacharie",
    "lat": "43.38521",
    "lng": "5.70808"
  },
  {
    "country": "FR",
    "name": "Saint-Yzan-de-Soudiac",
    "lat": "45.14118",
    "lng": "-0.41078"
  },
  {
    "country": "FR",
    "name": "Saint-Yvi",
    "lat": "47.96667",
    "lng": "-3.93333"
  },
  {
    "country": "FR",
    "name": "Saint-Yrieix-sur-Charente",
    "lat": "45.68333",
    "lng": "0.11667"
  },
  {
    "country": "FR",
    "name": "Saint-Yrieix-la-Perche",
    "lat": "45.51604",
    "lng": "1.20569"
  },
  {
    "country": "FR",
    "name": "Saint-Yorre",
    "lat": "46.06057",
    "lng": "3.46813"
  },
  {
    "country": "FR",
    "name": "Saint-Yan",
    "lat": "46.41147",
    "lng": "4.03876"
  },
  {
    "country": "FR",
    "name": "Saint-Xandre",
    "lat": "46.20444",
    "lng": "-1.10267"
  },
  {
    "country": "FR",
    "name": "Saint-Witz",
    "lat": "49.091",
    "lng": "2.57122"
  },
  {
    "country": "FR",
    "name": "Saint-Wandrille-Rançon",
    "lat": "49.52658",
    "lng": "0.76497"
  },
  {
    "country": "FR",
    "name": "Saint-Vrain",
    "lat": "48.54302",
    "lng": "2.33331"
  },
  {
    "country": "FR",
    "name": "Saint-Vivien-de-Médoc",
    "lat": "45.42695",
    "lng": "-1.03377"
  },
  {
    "country": "FR",
    "name": "Saint-Vite",
    "lat": "44.47133",
    "lng": "0.93876"
  },
  {
    "country": "FR",
    "name": "Saint-Vit",
    "lat": "47.18333",
    "lng": "5.81667"
  },
  {
    "country": "FR",
    "name": "Saint-Vincent-sur-Oust",
    "lat": "47.7001",
    "lng": "-2.14657"
  },
  {
    "country": "FR",
    "name": "Saint-Vincent-sur-Graon",
    "lat": "46.5169",
    "lng": "-1.38881"
  },
  {
    "country": "FR",
    "name": "Saint-Vincent-de-Tyrosse",
    "lat": "43.66031",
    "lng": "-1.30799"
  },
  {
    "country": "FR",
    "name": "Saint-Vincent-des-Landes",
    "lat": "47.65695",
    "lng": "-1.49572"
  },
  {
    "country": "FR",
    "name": "Saint-Vincent-de-Paul",
    "lat": "44.95429",
    "lng": "-0.46751"
  },
  {
    "country": "FR",
    "name": "Saint-Vincent-de-Paul",
    "lat": "43.74431",
    "lng": "-1.00662"
  },
  {
    "country": "FR",
    "name": "Saint-Vincent-de-Mercuze",
    "lat": "45.37063",
    "lng": "5.95182"
  },
  {
    "country": "FR",
    "name": "Saint-Vigor-le-Grand",
    "lat": "49.28242",
    "lng": "-0.68579"
  },
  {
    "country": "FR",
    "name": "Saint-Victurnien",
    "lat": "45.87855",
    "lng": "1.01376"
  },
  {
    "country": "FR",
    "name": "Saint-Victor-la-Coste",
    "lat": "44.06295",
    "lng": "4.64238"
  },
  {
    "country": "FR",
    "name": "Saint-Victoret",
    "lat": "43.41957",
    "lng": "5.23396"
  },
  {
    "country": "FR",
    "name": "Saint-Victor-de-Cessieu",
    "lat": "45.55",
    "lng": "5.4"
  },
  {
    "country": "FR",
    "name": "Saint-Victor",
    "lat": "46.39467",
    "lng": "2.60858"
  },
  {
    "country": "FR",
    "name": "Saint-Viaud",
    "lat": "47.25619",
    "lng": "-2.01833"
  },
  {
    "country": "FR",
    "name": "Saint-Viâtre",
    "lat": "47.52438",
    "lng": "1.93276"
  },
  {
    "country": "FR",
    "name": "Saint-Viance",
    "lat": "45.21752",
    "lng": "1.45284"
  },
  {
    "country": "FR",
    "name": "Saint-Vérand",
    "lat": "45.91996",
    "lng": "4.52791"
  },
  {
    "country": "FR",
    "name": "Saint-Vérand",
    "lat": "45.17277",
    "lng": "5.33195"
  },
  {
    "country": "FR",
    "name": "Saint-Venant",
    "lat": "50.61955",
    "lng": "2.53946"
  },
  {
    "country": "FR",
    "name": "Saint-Vaury",
    "lat": "46.20417",
    "lng": "1.75654"
  },
  {
    "country": "FR",
    "name": "Saint-Varent",
    "lat": "46.88934",
    "lng": "-0.2321"
  },
  {
    "country": "FR",
    "name": "Saint-Vallier-de-Thiey",
    "lat": "43.69539",
    "lng": "6.8443"
  },
  {
    "country": "FR",
    "name": "Saint-Vallier",
    "lat": "46.64107",
    "lng": "4.37107"
  },
  {
    "country": "FR",
    "name": "Saint-Vallier",
    "lat": "45.17592",
    "lng": "4.81514"
  },
  {
    "country": "FR",
    "name": "Saint-Valery-sur-Somme",
    "lat": "50.18333",
    "lng": "1.63333"
  },
  {
    "country": "FR",
    "name": "Saint-Valery-en-Caux",
    "lat": "49.86667",
    "lng": "0.73333"
  },
  {
    "country": "FR",
    "name": "Saint-Valérien",
    "lat": "48.17805",
    "lng": "3.09523"
  },
  {
    "country": "FR",
    "name": "Saint-Vaast-la-Hougue",
    "lat": "49.58843",
    "lng": "-1.26931"
  },
  {
    "country": "FR",
    "name": "Saint-Uze",
    "lat": "45.18502",
    "lng": "4.86561"
  },
  {
    "country": "FR",
    "name": "Saint-Usuge",
    "lat": "46.679",
    "lng": "5.25089"
  },
  {
    "country": "FR",
    "name": "Saint-Usage",
    "lat": "47.11009",
    "lng": "5.26044"
  },
  {
    "country": "FR",
    "name": "Saint-Urbain",
    "lat": "48.4",
    "lng": "-4.23333"
  },
  {
    "country": "FR",
    "name": "Saint-Urbain",
    "lat": "46.87557",
    "lng": "-2.00961"
  },
  {
    "country": "FR",
    "name": "Saint-Tropez",
    "lat": "43.26932",
    "lng": "6.63981"
  },
  {
    "country": "FR",
    "name": "Saint-Trojan-les-Bains",
    "lat": "45.84134",
    "lng": "-1.20728"
  },
  {
    "country": "FR",
    "name": "Saint-Trivier-sur-Moignans",
    "lat": "46.07233",
    "lng": "4.89755"
  },
  {
    "country": "FR",
    "name": "Saint-Trivier-de-Courtes",
    "lat": "46.45904",
    "lng": "5.08047"
  },
  {
    "country": "FR",
    "name": "Saint-Thuriau",
    "lat": "48.01667",
    "lng": "-2.95"
  },
  {
    "country": "FR",
    "name": "Saint-Thurial",
    "lat": "48.02924",
    "lng": "-1.93181"
  },
  {
    "country": "FR",
    "name": "Saint-Thonan",
    "lat": "48.48333",
    "lng": "-4.33333"
  },
  {
    "country": "FR",
    "name": "Saint-Thibéry",
    "lat": "43.39657",
    "lng": "3.41774"
  },
  {
    "country": "FR",
    "name": "Saint-Thibault-des-Vignes",
    "lat": "48.87111",
    "lng": "2.68041"
  },
  {
    "country": "FR",
    "name": "Saint-Thégonnec",
    "lat": "48.51667",
    "lng": "-3.95"
  },
  {
    "country": "FR",
    "name": "Saint-Symphorien-sur-Coise",
    "lat": "45.632",
    "lng": "4.45811"
  },
  {
    "country": "FR",
    "name": "Saint-Symphorien-de-Lay",
    "lat": "45.94849",
    "lng": "4.21204"
  },
  {
    "country": "FR",
    "name": "Saint-Symphorien",
    "lat": "46.26442",
    "lng": "-0.4922"
  },
  {
    "country": "FR",
    "name": "Saint-Symphorien",
    "lat": "44.42941",
    "lng": "-0.49047"
  },
  {
    "country": "FR",
    "name": "Saint-Sylvestre-sur-Lot",
    "lat": "44.39667",
    "lng": "0.80441"
  },
  {
    "country": "FR",
    "name": "Saint-Sylvestre-Pragoulin",
    "lat": "46.05101",
    "lng": "3.39905"
  },
  {
    "country": "FR",
    "name": "Saint-Sylvestre-Cappel",
    "lat": "50.77625",
    "lng": "2.55622"
  },
  {
    "country": "FR",
    "name": "Saint-Sylvain",
    "lat": "49.05624",
    "lng": "-0.21758"
  },
  {
    "country": "FR",
    "name": "Saint-Sulpice-sur-Risle",
    "lat": "48.78063",
    "lng": "0.65739"
  },
  {
    "country": "FR",
    "name": "Saint-Sulpice-sur-Lèze",
    "lat": "43.33076",
    "lng": "1.32091"
  },
  {
    "country": "FR",
    "name": "Saint-Sulpice-les-Feuilles",
    "lat": "46.31868",
    "lng": "1.36792"
  },
  {
    "country": "FR",
    "name": "Saint-Sulpice-le-Guérétois",
    "lat": "46.20097",
    "lng": "1.82826"
  },
  {
    "country": "FR",
    "name": "Saint-Sulpice-la-Forêt",
    "lat": "48.21667",
    "lng": "-1.57972"
  },
  {
    "country": "FR",
    "name": "Saint-Sulpice-et-Cameyrac",
    "lat": "44.91131",
    "lng": "-0.39048"
  },
  {
    "country": "FR",
    "name": "Saint-Sulpice-de-Royan",
    "lat": "45.67035",
    "lng": "-1.01252"
  },
  {
    "country": "FR",
    "name": "Saint-Sulpice-de-Faleyrens",
    "lat": "44.86667",
    "lng": "-0.18333"
  },
  {
    "country": "FR",
    "name": "Saint-Sulpice-de-Cognac",
    "lat": "45.75978",
    "lng": "-0.38093"
  },
  {
    "country": "FR",
    "name": "Saint-Sulpice",
    "lat": "49.35049",
    "lng": "2.12314"
  },
  {
    "country": "FR",
    "name": "Saint-Sulpice-de-Pommeray",
    "lat": "47.6",
    "lng": "1.26667"
  },
  {
    "country": "FR",
    "name": "Saint-Sulpice-la-Pointe",
    "lat": "43.775",
    "lng": "1.68511"
  },
  {
    "country": "FR",
    "name": "Saint-Soupplets",
    "lat": "49.03866",
    "lng": "2.80723"
  },
  {
    "country": "FR",
    "name": "Saint-Souplet",
    "lat": "50.05639",
    "lng": "3.53179"
  },
  {
    "country": "FR",
    "name": "Saint-Sorlin-en-Valloire",
    "lat": "45.28986",
    "lng": "4.95205"
  },
  {
    "country": "FR",
    "name": "Saint-Sorlin-en-Bugey",
    "lat": "45.88468",
    "lng": "5.3711"
  },
  {
    "country": "FR",
    "name": "Saint-Simon",
    "lat": "44.96491",
    "lng": "2.4909"
  },
  {
    "country": "FR",
    "name": "Saint-Siméon-de-Bressieux",
    "lat": "45.3385",
    "lng": "5.26591"
  },
  {
    "country": "FR",
    "name": "Saint-Sever-Calvados",
    "lat": "48.84035",
    "lng": "-1.04773"
  },
  {
    "country": "FR",
    "name": "Saint-Sever",
    "lat": "43.75727",
    "lng": "-0.57357"
  },
  {
    "country": "FR",
    "name": "Saint-Seurin-sur-l’Isle",
    "lat": "45.01667",
    "lng": "0"
  },
  {
    "country": "FR",
    "name": "Saint-Sernin-du-Bois",
    "lat": "46.84074",
    "lng": "4.43271"
  },
  {
    "country": "FR",
    "name": "Saint-Sernin",
    "lat": "44.57208",
    "lng": "4.39163"
  },
  {
    "country": "FR",
    "name": "Saint-Senoux",
    "lat": "47.90552",
    "lng": "-1.78819"
  },
  {
    "country": "FR",
    "name": "Saint-Senier-sous-Avranches",
    "lat": "48.68399",
    "lng": "-1.33126"
  },
  {
    "country": "FR",
    "name": "Saint-Selve",
    "lat": "44.67095",
    "lng": "-0.47887"
  },
  {
    "country": "FR",
    "name": "Saint-Sébastien-sur-Loire",
    "lat": "47.20768",
    "lng": "-1.50332"
  },
  {
    "country": "FR",
    "name": "Saint-Sébastien-de-Morsent",
    "lat": "49.01096",
    "lng": "1.0873"
  },
  {
    "country": "FR",
    "name": "Saint-Savournin",
    "lat": "43.40848",
    "lng": "5.5269"
  },
  {
    "country": "FR",
    "name": "Saint-Savinien",
    "lat": "45.87711",
    "lng": "-0.67919"
  },
  {
    "country": "FR",
    "name": "Saint-Savin",
    "lat": "45.15",
    "lng": "-0.45"
  },
  {
    "country": "FR",
    "name": "Saint-Savin",
    "lat": "46.56528",
    "lng": "0.86709"
  },
  {
    "country": "FR",
    "name": "Saint-Savin",
    "lat": "45.6277",
    "lng": "5.30722"
  },
  {
    "country": "FR",
    "name": "Saint-Sauveur-sur-École",
    "lat": "48.4975",
    "lng": "2.54711"
  },
  {
    "country": "FR",
    "name": "Saint-Sauveur-le-Vicomte",
    "lat": "49.38547",
    "lng": "-1.5331"
  },
  {
    "country": "FR",
    "name": "Saint-Sauveur-Lendelin",
    "lat": "49.12988",
    "lng": "-1.41405"
  },
  {
    "country": "FR",
    "name": "Saint-Sauveur-en-Rue",
    "lat": "45.27021",
    "lng": "4.49529"
  },
  {
    "country": "FR",
    "name": "Saint-Sauveur-des-Landes",
    "lat": "48.34278",
    "lng": "-1.31248"
  },
  {
    "country": "FR",
    "name": "Saint-Sauveur-de-Montagut",
    "lat": "44.82142",
    "lng": "4.57993"
  },
  {
    "country": "FR",
    "name": "Saint-Sauveur-d’Aunis",
    "lat": "46.21716",
    "lng": "-0.8858"
  },
  {
    "country": "FR",
    "name": "Saint-Sauveur",
    "lat": "49.93792",
    "lng": "2.21162"
  },
  {
    "country": "FR",
    "name": "Saint-Sauveur",
    "lat": "49.31857",
    "lng": "2.78321"
  },
  {
    "country": "FR",
    "name": "Saint-Sauveur",
    "lat": "47.8053",
    "lng": "6.38583"
  },
  {
    "country": "FR",
    "name": "Saint-Sauveur",
    "lat": "46.80841",
    "lng": "0.62277"
  },
  {
    "country": "FR",
    "name": "Saint-Sauveur",
    "lat": "45.20272",
    "lng": "-0.83433"
  },
  {
    "country": "FR",
    "name": "Saint-Sauveur",
    "lat": "45.15335",
    "lng": "5.3528"
  },
  {
    "country": "FR",
    "name": "Saint-Sauveur",
    "lat": "43.7483",
    "lng": "1.40085"
  },
  {
    "country": "FR",
    "name": "Saint-Sauves-d'Auvergne",
    "lat": "45.6",
    "lng": "2.68333"
  },
  {
    "country": "FR",
    "name": "Saint-Sauvant",
    "lat": "46.35965",
    "lng": "0.05634"
  },
  {
    "country": "FR",
    "name": "Saint-Saulve",
    "lat": "50.37141",
    "lng": "3.55612"
  },
  {
    "country": "FR",
    "name": "Saint-Saturnin-sur-Loire",
    "lat": "47.39438",
    "lng": "-0.43565"
  },
  {
    "country": "FR",
    "name": "Saint-Saturnin-lès-Avignon",
    "lat": "43.95501",
    "lng": "4.92548"
  },
  {
    "country": "FR",
    "name": "Saint-Saturnin-lès-Apt",
    "lat": "43.93333",
    "lng": "5.38333"
  },
  {
    "country": "FR",
    "name": "Saint-Saturnin",
    "lat": "48.05795",
    "lng": "0.15218"
  },
  {
    "country": "FR",
    "name": "Saint-Saturnin",
    "lat": "45.66667",
    "lng": "0.05"
  },
  {
    "country": "FR",
    "name": "Saint-Saturnin",
    "lat": "45.65945",
    "lng": "3.09019"
  },
  {
    "country": "FR",
    "name": "Saint-Satur",
    "lat": "47.33914",
    "lng": "2.83734"
  },
  {
    "country": "FR",
    "name": "Saint-Samson-sur-Rance",
    "lat": "48.49252",
    "lng": "-2.02865"
  },
  {
    "country": "FR",
    "name": "Saint-Saëns",
    "lat": "49.67302",
    "lng": "1.28525"
  },
  {
    "country": "FR",
    "name": "Saints",
    "lat": "48.76066",
    "lng": "3.04645"
  },
  {
    "country": "FR",
    "name": "Saintry-sur-Seine",
    "lat": "48.5964",
    "lng": "2.49515"
  },
  {
    "country": "FR",
    "name": "Saint-Romans",
    "lat": "45.11507",
    "lng": "5.32751"
  },
  {
    "country": "FR",
    "name": "Saint-Romain-sur-Cher",
    "lat": "47.31877",
    "lng": "1.39956"
  },
  {
    "country": "FR",
    "name": "Saint-Romain-le-Puy",
    "lat": "45.5595",
    "lng": "4.12839"
  },
  {
    "country": "FR",
    "name": "Saint-Romain-la-Motte",
    "lat": "46.0846",
    "lng": "3.9816"
  },
  {
    "country": "FR",
    "name": "Saint-Romain-en-Gal",
    "lat": "45.53159",
    "lng": "4.86074"
  },
  {
    "country": "FR",
    "name": "Saint-Romain-de-Popey",
    "lat": "45.84763",
    "lng": "4.53082"
  },
  {
    "country": "FR",
    "name": "Saint-Romain-de-Jalionas",
    "lat": "45.75697",
    "lng": "5.21527"
  },
  {
    "country": "FR",
    "name": "Saint-Romain-de-Colbosc",
    "lat": "49.53093",
    "lng": "0.35719"
  },
  {
    "country": "FR",
    "name": "Saint-Romain-de-Benet",
    "lat": "45.6915",
    "lng": "-0.84765"
  },
  {
    "country": "FR",
    "name": "Saint-Rogatien",
    "lat": "46.15",
    "lng": "-1.06963"
  },
  {
    "country": "FR",
    "name": "Saint-Riquier",
    "lat": "50.13235",
    "lng": "1.94755"
  },
  {
    "country": "FR",
    "name": "Saint-Restitut",
    "lat": "44.33507",
    "lng": "4.79155"
  },
  {
    "country": "FR",
    "name": "Saint-Renan",
    "lat": "48.43333",
    "lng": "-4.61667"
  },
  {
    "country": "FR",
    "name": "Saint-Rémy-sur-Durolle",
    "lat": "45.88822",
    "lng": "3.59125"
  },
  {
    "country": "FR",
    "name": "Saint-Rémy-sur-Avre",
    "lat": "48.76143",
    "lng": "1.24532"
  },
  {
    "country": "FR",
    "name": "Saint-Rémy-lès-Chevreuse",
    "lat": "48.70708",
    "lng": "2.07692"
  },
  {
    "country": "FR",
    "name": "Saint-Rémy-en-Rollat",
    "lat": "46.18555",
    "lng": "3.39613"
  },
  {
    "country": "FR",
    "name": "Saint-Rémy-en-Mauges",
    "lat": "47.27202",
    "lng": "-1.07499"
  },
  {
    "country": "FR",
    "name": "Saint-Rémy-de-Provence",
    "lat": "43.78848",
    "lng": "4.83167"
  },
  {
    "country": "FR",
    "name": "Saint-Rémy",
    "lat": "48.94007",
    "lng": "-0.50344"
  },
  {
    "country": "FR",
    "name": "Saint-Rémy",
    "lat": "46.76334",
    "lng": "4.83928"
  },
  {
    "country": "FR",
    "name": "Saint-Rémy-de-Maurienne",
    "lat": "45.4",
    "lng": "6.26667"
  },
  {
    "country": "FR",
    "name": "Saint-Raphaël",
    "lat": "43.42332",
    "lng": "6.7735"
  },
  {
    "country": "FR",
    "name": "Saint-Rambert-en-Bugey",
    "lat": "45.94426",
    "lng": "5.43904"
  },
  {
    "country": "FR",
    "name": "Saint-Quentin-sur-le-Homme",
    "lat": "48.64751",
    "lng": "-1.31806"
  },
  {
    "country": "FR",
    "name": "Saint-Quentin-sur-Isère",
    "lat": "45.27881",
    "lng": "5.54221"
  },
  {
    "country": "FR",
    "name": "Saint-Quentin-la-Poterie",
    "lat": "44.04392",
    "lng": "4.44432"
  },
  {
    "country": "FR",
    "name": "Saint-Quentin-Fallavier",
    "lat": "45.6305",
    "lng": "5.10924"
  },
  {
    "country": "FR",
    "name": "Saint-Quentin-en-Mauges",
    "lat": "47.2913",
    "lng": "-0.91191"
  },
  {
    "country": "FR",
    "name": "Saint-Quentin-de-Baron",
    "lat": "44.81802",
    "lng": "-0.28636"
  },
  {
    "country": "FR",
    "name": "Saint-Quentin",
    "lat": "49.84889",
    "lng": "3.28757"
  },
  {
    "country": "FR",
    "name": "Saint-Quay-Portrieux",
    "lat": "48.64992",
    "lng": "-2.83059"
  },
  {
    "country": "FR",
    "name": "Saint-Quay-Perros",
    "lat": "48.78333",
    "lng": "-3.45"
  },
  {
    "country": "FR",
    "name": "Saint-Python",
    "lat": "50.19001",
    "lng": "3.48027"
  },
  {
    "country": "FR",
    "name": "Saint-Pryvé-Saint-Mesmin",
    "lat": "47.88177",
    "lng": "1.8695"
  },
  {
    "country": "FR",
    "name": "Saint-Prouant",
    "lat": "46.75822",
    "lng": "-0.95703"
  },
  {
    "country": "FR",
    "name": "Saint-Projet-Saint-Constant",
    "lat": "45.72802",
    "lng": "0.33851"
  },
  {
    "country": "FR",
    "name": "Saint-Prix",
    "lat": "49.01667",
    "lng": "2.26667"
  },
  {
    "country": "FR",
    "name": "Saint-Privat-la-Montagne",
    "lat": "49.18768",
    "lng": "6.03874"
  },
  {
    "country": "FR",
    "name": "Saint-Privat-des-Vieux",
    "lat": "44.14415",
    "lng": "4.12988"
  },
  {
    "country": "FR",
    "name": "Saint-Privat",
    "lat": "45.13857",
    "lng": "2.09869"
  },
  {
    "country": "FR",
    "name": "Saint-Privat",
    "lat": "44.63002",
    "lng": "4.41656"
  },
  {
    "country": "FR",
    "name": "Saint-Priest-Taurion",
    "lat": "45.88686",
    "lng": "1.40016"
  },
  {
    "country": "FR",
    "name": "Saint-Priest-sous-Aixe",
    "lat": "45.81667",
    "lng": "1.1"
  },
  {
    "country": "FR",
    "name": "Saint-Priest-en-Jarez",
    "lat": "45.47501",
    "lng": "4.37614"
  },
  {
    "country": "FR",
    "name": "Saint-Priest",
    "lat": "45.69613",
    "lng": "4.93891"
  },
  {
    "country": "FR",
    "name": "Saint-Priest",
    "lat": "44.71767",
    "lng": "4.5462"
  },
  {
    "country": "FR",
    "name": "Saint-Prest",
    "lat": "48.49107",
    "lng": "1.53034"
  },
  {
    "country": "FR",
    "name": "Saint-Pourçain-sur-Sioule",
    "lat": "46.30927",
    "lng": "3.28787"
  },
  {
    "country": "FR",
    "name": "Saint-Pouange",
    "lat": "48.22656",
    "lng": "4.03979"
  },
  {
    "country": "FR",
    "name": "Saint-Porquier",
    "lat": "44.00344",
    "lng": "1.17932"
  },
  {
    "country": "FR",
    "name": "Saint-Porchaire",
    "lat": "45.82075",
    "lng": "-0.78235"
  },
  {
    "country": "FR",
    "name": "Saint-Pons-de-Thomières",
    "lat": "43.48333",
    "lng": "2.76667"
  },
  {
    "country": "FR",
    "name": "Saint-Pol-sur-Ternoise",
    "lat": "50.38113",
    "lng": "2.33407"
  },
  {
    "country": "FR",
    "name": "Saint-Pol-sur-Mer",
    "lat": "51.03116",
    "lng": "2.33983"
  },
  {
    "country": "FR",
    "name": "Saint-Pol-de-Léon",
    "lat": "48.68333",
    "lng": "-3.98333"
  },
  {
    "country": "FR",
    "name": "Saint-Planchers",
    "lat": "48.82269",
    "lng": "-1.52598"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-sur-Dives",
    "lat": "49.01667",
    "lng": "-0.03333"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-Quiberon",
    "lat": "47.52061",
    "lng": "-3.13084"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-Montlimart",
    "lat": "47.26976",
    "lng": "-1.02738"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-lès-Nemours",
    "lat": "48.26733",
    "lng": "2.67966"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-lès-Elbeuf",
    "lat": "49.27901",
    "lng": "1.04305"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-le-Moûtier",
    "lat": "46.79277",
    "lng": "3.11657"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-la-Palud",
    "lat": "45.78956",
    "lng": "4.61291"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-la-Cour",
    "lat": "48.11258",
    "lng": "-1.02496"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-en-Val",
    "lat": "50.02168",
    "lng": "1.44707"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-Église",
    "lat": "49.66848",
    "lng": "-1.40358"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-du-Vauvray",
    "lat": "49.23208",
    "lng": "1.22125"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-du-Regard",
    "lat": "48.84286",
    "lng": "-0.54631"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-du-Perray",
    "lat": "48.61064",
    "lng": "2.49429"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-du-Mont",
    "lat": "43.88453",
    "lng": "-0.52185"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-du-Chemin",
    "lat": "46.69523",
    "lng": "-0.70095"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-d’Oléron",
    "lat": "45.9443",
    "lng": "-1.3063"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-de-Varengeville",
    "lat": "49.5024",
    "lng": "0.93118"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-des-Nids",
    "lat": "48.39826",
    "lng": "-0.09984"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-des-Fleurs",
    "lat": "49.25",
    "lng": "0.96667"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-des-Échaubrognes",
    "lat": "46.98988",
    "lng": "-0.74441"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-des-Corps",
    "lat": "47.38623",
    "lng": "0.74849"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-de-Plesguen",
    "lat": "48.44638",
    "lng": "-1.91278"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-de-Chandieu",
    "lat": "45.64558",
    "lng": "5.01128"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-de-Bœuf",
    "lat": "45.36667",
    "lng": "4.75"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre-d’Aurillac",
    "lat": "44.57168",
    "lng": "-0.18922"
  },
  {
    "country": "FR",
    "name": "Saint-Piat",
    "lat": "48.54668",
    "lng": "1.58363"
  },
  {
    "country": "FR",
    "name": "Saint-Philibert",
    "lat": "47.58821",
    "lng": "-2.99978"
  },
  {
    "country": "FR",
    "name": "Saint-Philbert-du-Peuple",
    "lat": "47.39314",
    "lng": "-0.0436"
  },
  {
    "country": "FR",
    "name": "Saint-Philbert-de-Grand-Lieu",
    "lat": "47.0358",
    "lng": "-1.6412"
  },
  {
    "country": "FR",
    "name": "Saint-Philbert-de-Bouaine",
    "lat": "46.98568",
    "lng": "-1.52022"
  },
  {
    "country": "FR",
    "name": "Saint-Perreux",
    "lat": "47.66952",
    "lng": "-2.10809"
  },
  {
    "country": "FR",
    "name": "Saint-Père-sur-Loire",
    "lat": "47.76667",
    "lng": "2.36667"
  },
  {
    "country": "FR",
    "name": "Saint-Père-en-Retz",
    "lat": "47.20559",
    "lng": "-2.04095"
  },
  {
    "country": "FR",
    "name": "Saint-Père",
    "lat": "48.58727",
    "lng": "-1.92413"
  },
  {
    "country": "FR",
    "name": "Saint-Perdon",
    "lat": "43.8656",
    "lng": "-0.59069"
  },
  {
    "country": "FR",
    "name": "Saint-Péray",
    "lat": "44.94799",
    "lng": "4.8463"
  },
  {
    "country": "FR",
    "name": "Saint-Pée-sur-Nivelle",
    "lat": "43.35564",
    "lng": "-1.55013"
  },
  {
    "country": "FR",
    "name": "Saint-Pé-de-Bigorre",
    "lat": "43.10369",
    "lng": "-0.15943"
  },
  {
    "country": "FR",
    "name": "Saint-Paul-Trois-Châteaux",
    "lat": "44.34909",
    "lng": "4.76574"
  },
  {
    "country": "FR",
    "name": "Saint-Paul-lès-Romans",
    "lat": "45.06946",
    "lng": "5.13575"
  },
  {
    "country": "FR",
    "name": "Saint-Paul-lès-Dax",
    "lat": "43.72715",
    "lng": "-1.05162"
  },
  {
    "country": "FR",
    "name": "Saint-Paulien",
    "lat": "45.1365",
    "lng": "3.81384"
  },
  {
    "country": "FR",
    "name": "Saint-Paulet-de-Caisson",
    "lat": "44.26055",
    "lng": "4.59785"
  },
  {
    "country": "FR",
    "name": "Saint-Paul-en-Pareds",
    "lat": "46.82214",
    "lng": "-0.98977"
  },
  {
    "country": "FR",
    "name": "Saint-Paul-en-Jarez",
    "lat": "45.48239",
    "lng": "4.57132"
  },
  {
    "country": "FR",
    "name": "Saint-Paul-en-Forêt",
    "lat": "43.56762",
    "lng": "6.69475"
  },
  {
    "country": "FR",
    "name": "Saint-Paul-en-Cornillon",
    "lat": "45.39647",
    "lng": "4.22694"
  },
  {
    "country": "FR",
    "name": "Saint-Paul-en-Chablais",
    "lat": "46.37569",
    "lng": "6.63711"
  },
  {
    "country": "FR",
    "name": "Saint-Paul-de-Varces",
    "lat": "45.07175",
    "lng": "5.64247"
  },
  {
    "country": "FR",
    "name": "Saint-Paul-de-Varax",
    "lat": "46.09848",
    "lng": "5.12897"
  },
  {
    "country": "FR",
    "name": "Saint-Paul-des-Landes",
    "lat": "44.94416",
    "lng": "2.3142"
  },
  {
    "country": "FR",
    "name": "Saint-Paul-de-Jarrat",
    "lat": "42.91404",
    "lng": "1.65437"
  },
  {
    "country": "FR",
    "name": "Saint-Paul-de-Fenouillet",
    "lat": "42.80938",
    "lng": "2.50374"
  },
  {
    "country": "FR",
    "name": "Saint-Paul-Cap-de-Joux",
    "lat": "43.64791",
    "lng": "1.97559"
  },
  {
    "country": "FR",
    "name": "Saint-Paul",
    "lat": "49.42962",
    "lng": "2.00755"
  },
  {
    "country": "FR",
    "name": "Saint-Paul",
    "lat": "45.75114",
    "lng": "1.43238"
  },
  {
    "country": "FR",
    "name": "Saint-Paul-de-Vence",
    "lat": "43.7",
    "lng": "7.11667"
  },
  {
    "country": "FR",
    "name": "Saint-Pathus",
    "lat": "49.07136",
    "lng": "2.79886"
  },
  {
    "country": "FR",
    "name": "Saint-Paterne-Racan",
    "lat": "47.60213",
    "lng": "0.48478"
  },
  {
    "country": "FR",
    "name": "Saint-Paterne",
    "lat": "48.41614",
    "lng": "0.11271"
  },
  {
    "country": "FR",
    "name": "Saint-Parres-aux-Tertres",
    "lat": "48.2978",
    "lng": "4.11752"
  },
  {
    "country": "FR",
    "name": "Saint-Parize-le-Châtel",
    "lat": "46.85447",
    "lng": "3.18267"
  },
  {
    "country": "FR",
    "name": "Saint-Pargoire",
    "lat": "43.52766",
    "lng": "3.5187"
  },
  {
    "country": "FR",
    "name": "Saint-Pardoux-la-Rivière",
    "lat": "45.49388",
    "lng": "0.74651"
  },
  {
    "country": "FR",
    "name": "Saint-Pardoux-Isaac",
    "lat": "44.6119",
    "lng": "0.37345"
  },
  {
    "country": "FR",
    "name": "Saint-Pardoux",
    "lat": "46.57155",
    "lng": "-0.30542"
  },
  {
    "country": "FR",
    "name": "Saint-Pantaléon-de-Larche",
    "lat": "45.14138",
    "lng": "1.44609"
  },
  {
    "country": "FR",
    "name": "Saint-Pal-de-Mons",
    "lat": "45.24628",
    "lng": "4.27412"
  },
  {
    "country": "FR",
    "name": "Saint-Palais-sur-Mer",
    "lat": "45.64255",
    "lng": "-1.0881"
  },
  {
    "country": "FR",
    "name": "Saint-Palais",
    "lat": "43.32867",
    "lng": "-1.03333"
  },
  {
    "country": "FR",
    "name": "Saint-Pair-sur-Mer",
    "lat": "48.81455",
    "lng": "-1.56761"
  },
  {
    "country": "FR",
    "name": "Saint-Paër",
    "lat": "49.51452",
    "lng": "0.87935"
  },
  {
    "country": "FR",
    "name": "Saint-Pabu",
    "lat": "48.56667",
    "lng": "-4.6"
  },
  {
    "country": "FR",
    "name": "Saint-Ours",
    "lat": "45.85003",
    "lng": "2.89321"
  },
  {
    "country": "FR",
    "name": "Saint-Ouen-l’Aumône",
    "lat": "49.04353",
    "lng": "2.12134"
  },
  {
    "country": "FR",
    "name": "Saint-Ouen-en-Belin",
    "lat": "47.83302",
    "lng": "0.20924"
  },
  {
    "country": "FR",
    "name": "Saint-Ouen-du-Tilleul",
    "lat": "49.29723",
    "lng": "0.9476"
  },
  {
    "country": "FR",
    "name": "Saint-Ouen-de-Thouberville",
    "lat": "49.35726",
    "lng": "0.88848"
  },
  {
    "country": "FR",
    "name": "Saint-Ouën-des-Toits",
    "lat": "48.13333",
    "lng": "-0.9"
  },
  {
    "country": "FR",
    "name": "Saint-Ouen-des-Alleux",
    "lat": "48.32805",
    "lng": "-1.4259"
  },
  {
    "country": "FR",
    "name": "Saint-Ouen",
    "lat": "50.03819",
    "lng": "2.12088"
  },
  {
    "country": "FR",
    "name": "Saint-Ouen",
    "lat": "48.90654",
    "lng": "2.33339"
  },
  {
    "country": "FR",
    "name": "Saint-Ouen",
    "lat": "47.81404",
    "lng": "1.08067"
  },
  {
    "country": "FR",
    "name": "Saint-Orens-de-Gameville",
    "lat": "43.55402",
    "lng": "1.53411"
  },
  {
    "country": "FR",
    "name": "Saint-Omer-en-Chaussée",
    "lat": "49.53142",
    "lng": "2.00335"
  },
  {
    "country": "FR",
    "name": "Saint-Omer",
    "lat": "50.75",
    "lng": "2.25"
  },
  {
    "country": "FR",
    "name": "Saint-Nom-la-Bretêche",
    "lat": "48.85942",
    "lng": "2.02233"
  },
  {
    "country": "FR",
    "name": "Saint-Nolff",
    "lat": "47.70365",
    "lng": "-2.65209"
  },
  {
    "country": "FR",
    "name": "Saint-Nizier-sous-Charlieu",
    "lat": "46.15351",
    "lng": "4.12279"
  },
  {
    "country": "FR",
    "name": "Saint-Nicolas-du-Pélem",
    "lat": "48.31222",
    "lng": "-3.16465"
  },
  {
    "country": "FR",
    "name": "Saint-Nicolas-de-Redon",
    "lat": "47.64343",
    "lng": "-2.06305"
  },
  {
    "country": "FR",
    "name": "Saint-Nicolas-de-Port",
    "lat": "48.63089",
    "lng": "6.30039"
  },
  {
    "country": "FR",
    "name": "Saint-Nicolas-de-la-Taille",
    "lat": "49.51085",
    "lng": "0.47405"
  },
  {
    "country": "FR",
    "name": "Saint-Nicolas-de-la-Grave",
    "lat": "44.06417",
    "lng": "1.0228"
  },
  {
    "country": "FR",
    "name": "Saint-Nicolas-de-Bourgueil",
    "lat": "47.28493",
    "lng": "0.12727"
  },
  {
    "country": "FR",
    "name": "Saint-Nicolas-d’Aliermont",
    "lat": "49.87857",
    "lng": "1.22486"
  },
  {
    "country": "FR",
    "name": "Saint-Nicolas",
    "lat": "50.30413",
    "lng": "2.77939"
  },
  {
    "country": "FR",
    "name": "Saint-Nazaire-d’Aude",
    "lat": "43.24518",
    "lng": "2.89443"
  },
  {
    "country": "FR",
    "name": "Saint-Nazaire",
    "lat": "47.28333",
    "lng": "-2.2"
  },
  {
    "country": "FR",
    "name": "Saint-Nazaire-les-Eymes",
    "lat": "45.24921",
    "lng": "5.85254"
  },
  {
    "country": "FR",
    "name": "Saint-Nazaire",
    "lat": "44.19833",
    "lng": "4.62413"
  },
  {
    "country": "FR",
    "name": "Saint-Nazaire",
    "lat": "42.6679",
    "lng": "2.99168"
  },
  {
    "country": "FR",
    "name": "Saint-Nauphary",
    "lat": "43.96712",
    "lng": "1.42549"
  },
  {
    "country": "FR",
    "name": "Saint-Nabord",
    "lat": "48.05171",
    "lng": "6.58248"
  },
  {
    "country": "FR",
    "name": "Saint-Morillon",
    "lat": "44.6506",
    "lng": "-0.50322"
  },
  {
    "country": "FR",
    "name": "Saint-Molf",
    "lat": "47.39167",
    "lng": "-2.42357"
  },
  {
    "country": "FR",
    "name": "Saint-Mitre-les-Remparts",
    "lat": "43.45488",
    "lng": "5.01702"
  },
  {
    "country": "FR",
    "name": "Saint-Mihiel",
    "lat": "48.88746",
    "lng": "5.55099"
  },
  {
    "country": "FR",
    "name": "Saint-Michel-sur-Orge",
    "lat": "48.63479",
    "lng": "2.30831"
  },
  {
    "country": "FR",
    "name": "Saint-Michel-sur-Meurthe",
    "lat": "48.32219",
    "lng": "6.89024"
  },
  {
    "country": "FR",
    "name": "Saint-Michel-Mont-Mercure",
    "lat": "46.82941",
    "lng": "-0.88298"
  },
  {
    "country": "FR",
    "name": "Saint-Michel-l’Observatoire",
    "lat": "43.90928",
    "lng": "5.71511"
  },
  {
    "country": "FR",
    "name": "Saint-Michel-le-Cloucq",
    "lat": "46.485",
    "lng": "-0.75262"
  },
  {
    "country": "FR",
    "name": "Saint-Michel-de-Maurienne",
    "lat": "45.21842",
    "lng": "6.47257"
  },
  {
    "country": "FR",
    "name": "Saint-Michel-Chef-Chef",
    "lat": "47.18072",
    "lng": "-2.14869"
  },
  {
    "country": "FR",
    "name": "Saint-Michel",
    "lat": "49.91952",
    "lng": "4.13278"
  },
  {
    "country": "FR",
    "name": "Saint-Michel",
    "lat": "45.65",
    "lng": "0.1"
  },
  {
    "country": "FR",
    "name": "Saint-Mexant",
    "lat": "45.28333",
    "lng": "1.65"
  },
  {
    "country": "FR",
    "name": "Saint-Mesmin",
    "lat": "46.79369",
    "lng": "-0.73262"
  },
  {
    "country": "FR",
    "name": "Saint-Menges",
    "lat": "49.73873",
    "lng": "4.92628"
  },
  {
    "country": "FR",
    "name": "Saint-Menet",
    "lat": "43.28997",
    "lng": "5.50427"
  },
  {
    "country": "FR",
    "name": "Saint-Memmie",
    "lat": "48.95247",
    "lng": "4.38409"
  },
  {
    "country": "FR",
    "name": "Saint-Même-le-Tenu",
    "lat": "47.02005",
    "lng": "-1.79459"
  },
  {
    "country": "FR",
    "name": "Saint-Même-les-Carrières",
    "lat": "45.65",
    "lng": "-0.15"
  },
  {
    "country": "FR",
    "name": "Saint-Méloir-des-Ondes",
    "lat": "48.6379",
    "lng": "-1.90448"
  },
  {
    "country": "FR",
    "name": "Saint-Melaine-sur-Aubance",
    "lat": "47.36667",
    "lng": "-0.5"
  },
  {
    "country": "FR",
    "name": "Saint-Méen-le-Grand",
    "lat": "48.18971",
    "lng": "-2.19486"
  },
  {
    "country": "FR",
    "name": "Saint-Médard-sur-Ille",
    "lat": "48.27202",
    "lng": "-1.65968"
  },
  {
    "country": "FR",
    "name": "Saint-Médard-en-Jalles",
    "lat": "44.89692",
    "lng": "-0.72136"
  },
  {
    "country": "FR",
    "name": "Saint-Médard-d’Eyrans",
    "lat": "44.71667",
    "lng": "-0.51667"
  },
  {
    "country": "FR",
    "name": "Saint-Médard-de-Mussidan",
    "lat": "45.03333",
    "lng": "0.35"
  },
  {
    "country": "FR",
    "name": "Saint-Médard-de-Guizières",
    "lat": "45.01667",
    "lng": "-0.05"
  },
  {
    "country": "FR",
    "name": "Saint-Maxire",
    "lat": "46.39911",
    "lng": "-0.47988"
  },
  {
    "country": "FR",
    "name": "Saint-Maximin-la-Sainte-Baume",
    "lat": "43.45214",
    "lng": "5.86219"
  },
  {
    "country": "FR",
    "name": "Saint-Maximin",
    "lat": "49.22182",
    "lng": "2.45359"
  },
  {
    "country": "FR",
    "name": "Saint-Max",
    "lat": "48.70429",
    "lng": "6.20999"
  },
  {
    "country": "FR",
    "name": "Saint-Maurice-sur-Moselle",
    "lat": "47.85889",
    "lng": "6.82477"
  },
  {
    "country": "FR",
    "name": "Saint-Maurice-sur-Fessard",
    "lat": "47.99231",
    "lng": "2.62157"
  },
  {
    "country": "FR",
    "name": "Saint-Maurice-sur-Dargoire",
    "lat": "45.58117",
    "lng": "4.63113"
  },
  {
    "country": "FR",
    "name": "Saint-Maurice-Montcouronne",
    "lat": "48.58288",
    "lng": "2.12504"
  },
  {
    "country": "FR",
    "name": "Saint-Maurice-la-Souterraine",
    "lat": "46.21388",
    "lng": "1.4313"
  },
  {
    "country": "FR",
    "name": "Saint-Maurice-la-Clouère",
    "lat": "46.37804",
    "lng": "0.41253"
  },
  {
    "country": "FR",
    "name": "Saint-Maurice-en-Gourgois",
    "lat": "45.40246",
    "lng": "4.18235"
  },
  {
    "country": "FR",
    "name": "Saint-Maurice-de-Lignon",
    "lat": "45.22431",
    "lng": "4.13911"
  },
  {
    "country": "FR",
    "name": "Saint-Maurice-de-Gourdans",
    "lat": "45.8214",
    "lng": "5.19464"
  },
  {
    "country": "FR",
    "name": "Saint-Maurice-de-Beynost",
    "lat": "45.8344",
    "lng": "4.9775"
  },
  {
    "country": "FR",
    "name": "Saint-Maurice",
    "lat": "48.82182",
    "lng": "2.42716"
  },
  {
    "country": "FR",
    "name": "Saint-Maur-des-Fossés",
    "lat": "48.79395",
    "lng": "2.49323"
  },
  {
    "country": "FR",
    "name": "Saint-Maur",
    "lat": "46.80657",
    "lng": "1.63904"
  },
  {
    "country": "FR",
    "name": "Saint-Mathurin-sur-Loire",
    "lat": "47.41667",
    "lng": "-0.31667"
  },
  {
    "country": "FR",
    "name": "Saint-Mathurin",
    "lat": "46.56493",
    "lng": "-1.71389"
  },
  {
    "country": "FR",
    "name": "Saint-Mathieu-de-Tréviers",
    "lat": "43.76795",
    "lng": "3.85814"
  },
  {
    "country": "FR",
    "name": "Saint-Mathieu",
    "lat": "45.70674",
    "lng": "0.75908"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-Vésubie",
    "lat": "44.07004",
    "lng": "7.25547"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-sur-Oust",
    "lat": "47.746",
    "lng": "-2.25343"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-sur-Ocre",
    "lat": "47.65942",
    "lng": "2.6581"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-sous-Mouzeuil",
    "lat": "46.45905",
    "lng": "-0.98893"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-Osmonville",
    "lat": "49.63873",
    "lng": "1.29952"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-Longueau",
    "lat": "49.34281",
    "lng": "2.60276"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-le-Vinoux",
    "lat": "45.203",
    "lng": "5.71667"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-le-Beau",
    "lat": "47.35566",
    "lng": "0.90953"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-la-Plaine",
    "lat": "45.54739",
    "lng": "4.59115"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-Lalande",
    "lat": "43.29928",
    "lng": "2.02004"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-Lacaussade",
    "lat": "45.14631",
    "lng": "-0.6431"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-en-Haut",
    "lat": "45.65969",
    "lng": "4.56153"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-en-Campagne",
    "lat": "49.95648",
    "lng": "1.22233"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-en-Bresse",
    "lat": "46.81725",
    "lng": "5.06027"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-du-Vivier",
    "lat": "49.46667",
    "lng": "1.16667"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-du-Var",
    "lat": "43.81812",
    "lng": "7.1903"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-du-Tertre",
    "lat": "49.10743",
    "lng": "2.34533"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-du-Tertre",
    "lat": "48.21659",
    "lng": "3.26151"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-du-Mont",
    "lat": "46.10247",
    "lng": "5.32834"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-du-Manoir",
    "lat": "49.53213",
    "lng": "0.23759"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-du-Frêne",
    "lat": "46.13857",
    "lng": "5.55302"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-du-Fouilloux",
    "lat": "47.4336",
    "lng": "-0.70357"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-d’Hères",
    "lat": "45.16528",
    "lng": "5.76337"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-de-Valgalgues",
    "lat": "44.16315",
    "lng": "4.08364"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-de-Valamas",
    "lat": "44.93648",
    "lng": "4.36557"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-des-Noyers",
    "lat": "46.72226",
    "lng": "-1.17727"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-de-Seignanx",
    "lat": "43.54283",
    "lng": "-1.38946"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-des-Champs",
    "lat": "48.66841",
    "lng": "-1.33393"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-des-Champs",
    "lat": "48.58333",
    "lng": "-3.83333"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-des-Besaces",
    "lat": "49.01091",
    "lng": "-0.845"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-de-Ré",
    "lat": "46.20311",
    "lng": "-1.36726"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-de-Queyrières",
    "lat": "44.82319",
    "lng": "6.57901"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-de-Nigelles",
    "lat": "48.61234",
    "lng": "1.6092"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-de-Londres",
    "lat": "43.7904",
    "lng": "3.73066"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-de-la-Place",
    "lat": "47.31747",
    "lng": "-0.14849"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-de-Landelles",
    "lat": "48.5453",
    "lng": "-1.1724"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-de-Hinx",
    "lat": "43.58238",
    "lng": "-1.26809"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-de-Fontenay",
    "lat": "49.11523",
    "lng": "-0.37391"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-de-Crau",
    "lat": "43.63955",
    "lng": "4.8127"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-de-Boscherville",
    "lat": "49.44377",
    "lng": "0.96271"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-de-Belleville",
    "lat": "45.38175",
    "lng": "6.50519"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-d’Auxigny",
    "lat": "47.20371",
    "lng": "2.41553"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-Boulogne",
    "lat": "50.72691",
    "lng": "1.61864"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-Bellevue",
    "lat": "45.96262",
    "lng": "6.15763"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-Belle-Roche",
    "lat": "46.38312",
    "lng": "4.85539"
  },
  {
    "country": "FR",
    "name": "Saint-Martin-au-Laërt",
    "lat": "50.75179",
    "lng": "2.24051"
  },
  {
    "country": "FR",
    "name": "Saint-Mars-la-Jaille",
    "lat": "47.52566",
    "lng": "-1.18483"
  },
  {
    "country": "FR",
    "name": "Saint-Mars-la-Brière",
    "lat": "48.03046",
    "lng": "0.37319"
  },
  {
    "country": "FR",
    "name": "Saint-Mars-du-Désert",
    "lat": "47.3656",
    "lng": "-1.40678"
  },
  {
    "country": "FR",
    "name": "Saint-Mars-d’Outillé",
    "lat": "47.87034",
    "lng": "0.33221"
  },
  {
    "country": "FR",
    "name": "Saint-Mars-de-Coutais",
    "lat": "47.11153",
    "lng": "-1.73437"
  },
  {
    "country": "FR",
    "name": "Saint-Mariens",
    "lat": "45.11631",
    "lng": "-0.40084"
  },
  {
    "country": "FR",
    "name": "Saint-Mard",
    "lat": "49.03701",
    "lng": "2.69645"
  },
  {
    "country": "FR",
    "name": "Saint-Marc-le-Blanc",
    "lat": "48.36498",
    "lng": "-1.40938"
  },
  {
    "country": "FR",
    "name": "Saint-Marc-Jaumegarde",
    "lat": "43.54599",
    "lng": "5.51272"
  },
  {
    "country": "FR",
    "name": "Saint-Marcellin-en-Forez",
    "lat": "45.49549",
    "lng": "4.16923"
  },
  {
    "country": "FR",
    "name": "Saint-Marcellin",
    "lat": "45.15192",
    "lng": "5.32388"
  },
  {
    "country": "FR",
    "name": "Saint-Marcel-lès-Valence",
    "lat": "44.97246",
    "lng": "4.96011"
  },
  {
    "country": "FR",
    "name": "Saint-Marcel-lès-Sauzet",
    "lat": "44.59501",
    "lng": "4.80623"
  },
  {
    "country": "FR",
    "name": "Saint-Marcel-lès-Annonay",
    "lat": "45.28555",
    "lng": "4.62474"
  },
  {
    "country": "FR",
    "name": "Saint-Marcel-d'Ardèche",
    "lat": "44.32726",
    "lng": "4.61769"
  },
  {
    "country": "FR",
    "name": "Saint-Marcel",
    "lat": "49.1",
    "lng": "1.45"
  },
  {
    "country": "FR",
    "name": "Saint-Marcel",
    "lat": "46.77371",
    "lng": "4.89205"
  },
  {
    "country": "FR",
    "name": "Saint-Marcel",
    "lat": "46.60193",
    "lng": "1.51324"
  },
  {
    "country": "FR",
    "name": "Saint-Marcel",
    "lat": "43.28745",
    "lng": "5.46604"
  },
  {
    "country": "FR",
    "name": "Saint-Marcel-sur-Aude",
    "lat": "43.25",
    "lng": "2.93333"
  },
  {
    "country": "FR",
    "name": "Saint-Manvieu",
    "lat": "49.18067",
    "lng": "-0.50211"
  },
  {
    "country": "FR",
    "name": "Saint-Mandrier-sur-Mer",
    "lat": "43.078",
    "lng": "5.929"
  },
  {
    "country": "FR",
    "name": "Saint-Mandé",
    "lat": "48.83864",
    "lng": "2.41579"
  },
  {
    "country": "FR",
    "name": "Saint-Mammès",
    "lat": "48.38458",
    "lng": "2.81578"
  },
  {
    "country": "FR",
    "name": "Saint-Mamet-la-Salvetat",
    "lat": "44.85765",
    "lng": "2.30616"
  },
  {
    "country": "FR",
    "name": "Saint-Mamert-du-Gard",
    "lat": "43.88835",
    "lng": "4.18725"
  },
  {
    "country": "FR",
    "name": "Saint-Malô-du-Bois",
    "lat": "46.93333",
    "lng": "-0.9"
  },
  {
    "country": "FR",
    "name": "Saint-Malo-de-Guersac",
    "lat": "47.35345",
    "lng": "-2.17773"
  },
  {
    "country": "FR",
    "name": "Saint-Malo",
    "lat": "48.65",
    "lng": "-2.01667"
  },
  {
    "country": "FR",
    "name": "Saint-Maixant",
    "lat": "44.57868",
    "lng": "-0.2592"
  },
  {
    "country": "FR",
    "name": "Saint-Macaire-en-Mauges",
    "lat": "47.12357",
    "lng": "-0.9912"
  },
  {
    "country": "FR",
    "name": "Saint-Macaire",
    "lat": "44.56527",
    "lng": "-0.22431"
  },
  {
    "country": "FR",
    "name": "Saint-Lys",
    "lat": "43.51127",
    "lng": "1.17557"
  },
  {
    "country": "FR",
    "name": "Saint-Lyphard",
    "lat": "47.39822",
    "lng": "-2.30642"
  },
  {
    "country": "FR",
    "name": "Saint-Lyé",
    "lat": "48.36502",
    "lng": "3.999"
  },
  {
    "country": "FR",
    "name": "Saint-Lupicin",
    "lat": "46.40034",
    "lng": "5.7922"
  },
  {
    "country": "FR",
    "name": "Saint-Lunaire",
    "lat": "48.63811",
    "lng": "-2.11392"
  },
  {
    "country": "FR",
    "name": "Saint-Lumine-de-Coutais",
    "lat": "47.05399",
    "lng": "-1.72777"
  },
  {
    "country": "FR",
    "name": "Saint-Lumine-de-Clisson",
    "lat": "47.08413",
    "lng": "-1.33524"
  },
  {
    "country": "FR",
    "name": "Saint-Lubin-des-Joncherets",
    "lat": "48.76667",
    "lng": "1.21667"
  },
  {
    "country": "FR",
    "name": "Saint-Loup-sur-Semouse",
    "lat": "47.88345",
    "lng": "6.2753"
  },
  {
    "country": "FR",
    "name": "Saint-Loup-Cammas",
    "lat": "43.69767",
    "lng": "1.48127"
  },
  {
    "country": "FR",
    "name": "Saint-Loup",
    "lat": "43.27766",
    "lng": "5.43133"
  },
  {
    "country": "FR",
    "name": "Saint-Louis-de-Montferrand",
    "lat": "44.95",
    "lng": "-0.53543"
  },
  {
    "country": "FR",
    "name": "Saint-Louis",
    "lat": "43.34809",
    "lng": "5.35463"
  },
  {
    "country": "FR",
    "name": "Saint-Louis",
    "lat": "47.58836",
    "lng": "7.56247"
  },
  {
    "country": "FR",
    "name": "Saint-Loubès",
    "lat": "44.91536",
    "lng": "-0.42703"
  },
  {
    "country": "FR",
    "name": "Saint-Lô",
    "lat": "49.11624",
    "lng": "-1.09031"
  },
  {
    "country": "FR",
    "name": "Saint-Lizier",
    "lat": "43.00183",
    "lng": "1.13686"
  },
  {
    "country": "FR",
    "name": "Saint-Leu-la-Forêt",
    "lat": "49.01667",
    "lng": "2.25"
  },
  {
    "country": "FR",
    "name": "Saint-Leu",
    "lat": "46.7306",
    "lng": "4.50083"
  },
  {
    "country": "FR",
    "name": "Saint-Léon-sur-l’Isle",
    "lat": "45.11491",
    "lng": "0.50444"
  },
  {
    "country": "FR",
    "name": "Saint-Léonard-de-Noblat",
    "lat": "45.83566",
    "lng": "1.49174"
  },
  {
    "country": "FR",
    "name": "Saint-Léonard",
    "lat": "50.69058",
    "lng": "1.62536"
  },
  {
    "country": "FR",
    "name": "Saint-Léonard",
    "lat": "49.74252",
    "lng": "0.35907"
  },
  {
    "country": "FR",
    "name": "Saint-Léonard",
    "lat": "48.21638",
    "lng": "6.94355"
  },
  {
    "country": "FR",
    "name": "Saint-Léger-sur-Roanne",
    "lat": "46.04126",
    "lng": "3.99764"
  },
  {
    "country": "FR",
    "name": "Saint-Léger-sur-Dheune",
    "lat": "46.84548",
    "lng": "4.63607"
  },
  {
    "country": "FR",
    "name": "Saint-Léger-sous-Cholet",
    "lat": "47.09405",
    "lng": "-0.91024"
  },
  {
    "country": "FR",
    "name": "Saint-Léger-les-Vignes",
    "lat": "47.13587",
    "lng": "-1.7306"
  },
  {
    "country": "FR",
    "name": "Saint-Léger-lès-Domart",
    "lat": "50.05208",
    "lng": "2.14067"
  },
  {
    "country": "FR",
    "name": "Saint-Léger-en-Yvelines",
    "lat": "48.72173",
    "lng": "1.76638"
  },
  {
    "country": "FR",
    "name": "Saint-Léger-du-Bourg-Denis",
    "lat": "49.43345",
    "lng": "1.15803"
  },
  {
    "country": "FR",
    "name": "Saint-Léger-des-Vignes",
    "lat": "46.84063",
    "lng": "3.45488"
  },
  {
    "country": "FR",
    "name": "Saint-Léger-des-Bois",
    "lat": "47.46238",
    "lng": "-0.70953"
  },
  {
    "country": "FR",
    "name": "Saint-Léger-de-Montbrun",
    "lat": "47",
    "lng": "-0.13333"
  },
  {
    "country": "FR",
    "name": "Saint-Laurent-sur-Sèvre",
    "lat": "46.95809",
    "lng": "-0.89392"
  },
  {
    "country": "FR",
    "name": "Saint-Laurent-sur-Saône",
    "lat": "46.30532",
    "lng": "4.84119"
  },
  {
    "country": "FR",
    "name": "Saint-Laurent-sur-Gorre",
    "lat": "45.77052",
    "lng": "0.95859"
  },
  {
    "country": "FR",
    "name": "Saint-Laurent-en-Royans",
    "lat": "45.02907",
    "lng": "5.32777"
  },
  {
    "country": "FR",
    "name": "Saint-Laurent-du-Var",
    "lat": "43.67097",
    "lng": "7.17606"
  },
  {
    "country": "FR",
    "name": "Saint-Laurent-du-Pont",
    "lat": "45.39009",
    "lng": "5.73521"
  },
  {
    "country": "FR",
    "name": "Saint-Laurent-du-Pape",
    "lat": "44.82428",
    "lng": "4.76127"
  },
  {
    "country": "FR",
    "name": "Saint-Laurent-en-Grandvaux",
    "lat": "46.58333",
    "lng": "5.95"
  },
  {
    "country": "FR",
    "name": "Saint-Laurent-Nouan",
    "lat": "47.71667",
    "lng": "1.6"
  },
  {
    "country": "FR",
    "name": "Saint-Laurent-des-Autels",
    "lat": "47.28524",
    "lng": "-1.18881"
  },
  {
    "country": "FR",
    "name": "Saint-Laurent-des-Arbres",
    "lat": "44.05493",
    "lng": "4.70026"
  },
  {
    "country": "FR",
    "name": "Saint-Laurent-de-Mure",
    "lat": "45.6887",
    "lng": "5.04656"
  },
  {
    "country": "FR",
    "name": "Saint-Laurent-de-la-Salanque",
    "lat": "42.7727",
    "lng": "2.98998"
  },
  {
    "country": "FR",
    "name": "Saint-Laurent-de-la-Prée",
    "lat": "45.98259",
    "lng": "-1.03625"
  },
  {
    "country": "FR",
    "name": "Saint-Laurent-de-la-Plaine",
    "lat": "47.31738",
    "lng": "-0.80333"
  },
  {
    "country": "FR",
    "name": "Saint-Laurent-de-Chamousset",
    "lat": "45.73932",
    "lng": "4.4634"
  },
  {
    "country": "FR",
    "name": "Sant Llorenç de Cerdans",
    "lat": "42.38473",
    "lng": "2.6132"
  },
  {
    "country": "FR",
    "name": "Saint-Laurent-de-Brévedent",
    "lat": "49.52564",
    "lng": "0.25458"
  },
  {
    "country": "FR",
    "name": "Saint-Laurent-Blangy",
    "lat": "50.29446",
    "lng": "2.80698"
  },
  {
    "country": "FR",
    "name": "Saint-Laurent",
    "lat": "49.76449",
    "lng": "4.77193"
  },
  {
    "country": "FR",
    "name": "Saint-Lattier",
    "lat": "45.08768",
    "lng": "5.19261"
  },
  {
    "country": "FR",
    "name": "Saint-Lary-Soulan",
    "lat": "42.81713",
    "lng": "0.32238"
  },
  {
    "country": "FR",
    "name": "Saint-Lambert-la-Potherie",
    "lat": "47.48289",
    "lng": "-0.67789"
  },
  {
    "country": "FR",
    "name": "Saint-Lambert-du-Lattay",
    "lat": "47.3025",
    "lng": "-0.63321"
  },
  {
    "country": "FR",
    "name": "Saint-Just-Saint-Rambert",
    "lat": "45.49973",
    "lng": "4.24141"
  },
  {
    "country": "FR",
    "name": "Saint-Just-Sauvage",
    "lat": "48.55478",
    "lng": "3.78449"
  },
  {
    "country": "FR",
    "name": "Saint-Just-Malmont",
    "lat": "45.33973",
    "lng": "4.31335"
  },
  {
    "country": "FR",
    "name": "Saint-Just-le-Martel",
    "lat": "45.86351",
    "lng": "1.38829"
  },
  {
    "country": "FR",
    "name": "Saint-Just-la-Pendue",
    "lat": "45.89532",
    "lng": "4.24276"
  },
  {
    "country": "FR",
    "name": "Saint-Just-en-Chevalet",
    "lat": "45.91396",
    "lng": "3.8446"
  },
  {
    "country": "FR",
    "name": "Saint-Just-en-Chaussée",
    "lat": "49.50503",
    "lng": "2.43285"
  },
  {
    "country": "FR",
    "name": "Saint-Just-de-Claix",
    "lat": "45.07391",
    "lng": "5.28783"
  },
  {
    "country": "FR",
    "name": "Saint-Just-Chaleyssin",
    "lat": "45.58534",
    "lng": "4.99888"
  },
  {
    "country": "FR",
    "name": "Saint-Just",
    "lat": "43.317",
    "lng": "5.40587"
  },
  {
    "country": "FR",
    "name": "Saint-Just",
    "lat": "49.10852",
    "lng": "1.44101"
  },
  {
    "country": "FR",
    "name": "Saint-Just",
    "lat": "47.76581",
    "lng": "-1.96096"
  },
  {
    "country": "FR",
    "name": "Saint-Just-Luzac",
    "lat": "45.8",
    "lng": "-1.03333"
  },
  {
    "country": "FR",
    "name": "Saint-Just-d'Ardèche",
    "lat": "44.3",
    "lng": "4.61667"
  },
  {
    "country": "FR",
    "name": "Saint-Just",
    "lat": "43.65806",
    "lng": "4.11472"
  },
  {
    "country": "FR",
    "name": "Saint-Junien",
    "lat": "45.88867",
    "lng": "0.90143"
  },
  {
    "country": "FR",
    "name": "Saint-Julien-Molin-Molette",
    "lat": "45.32335",
    "lng": "4.61394"
  },
  {
    "country": "FR",
    "name": "Saint-Julien-les-Villas",
    "lat": "48.27127",
    "lng": "4.09901"
  },
  {
    "country": "FR",
    "name": "Saint-Julien-lès-Metz",
    "lat": "49.13288",
    "lng": "6.2024"
  },
  {
    "country": "FR",
    "name": "Saint-Julien-en-Saint-Alban",
    "lat": "44.75417",
    "lng": "4.69678"
  },
  {
    "country": "FR",
    "name": "Saint-Julien-en-Genevois",
    "lat": "46.14434",
    "lng": "6.08256"
  },
  {
    "country": "FR",
    "name": "Saint-Julien-en-Born",
    "lat": "44.06311",
    "lng": "-1.22445"
  },
  {
    "country": "FR",
    "name": "Saint-Julien-du-Sault",
    "lat": "48.03188",
    "lng": "3.29556"
  },
  {
    "country": "FR",
    "name": "Saint-Julien-les-Rosiers",
    "lat": "44.17445",
    "lng": "4.10803"
  },
  {
    "country": "FR",
    "name": "Saint-Julien-des-Landes",
    "lat": "46.6394",
    "lng": "-1.71381"
  },
  {
    "country": "FR",
    "name": "Saint-Julien-de-Peyrolas",
    "lat": "44.28837",
    "lng": "4.56507"
  },
  {
    "country": "FR",
    "name": "Saint-Julien-de-Concelles",
    "lat": "47.25285",
    "lng": "-1.38428"
  },
  {
    "country": "FR",
    "name": "Saint-Julien-Chapteuil",
    "lat": "45.03397",
    "lng": "4.06229"
  },
  {
    "country": "FR",
    "name": "Saint-Julien",
    "lat": "48.45142",
    "lng": "-2.8125"
  },
  {
    "country": "FR",
    "name": "Saint-Julien",
    "lat": "47.40029",
    "lng": "5.14163"
  },
  {
    "country": "FR",
    "name": "Saint-Julien",
    "lat": "43.69478",
    "lng": "5.91582"
  },
  {
    "country": "FR",
    "name": "Saint-Julien",
    "lat": "43.31334",
    "lng": "5.44935"
  },
  {
    "country": "FR",
    "name": "Saint-Juéry",
    "lat": "43.95",
    "lng": "2.21667"
  },
  {
    "country": "FR",
    "name": "Saint-Jouvent",
    "lat": "45.9568",
    "lng": "1.205"
  },
  {
    "country": "FR",
    "name": "Saint-Jouin-Bruneval",
    "lat": "49.64275",
    "lng": "0.164"
  },
  {
    "country": "FR",
    "name": "Saint-Jouan-des-Guérets",
    "lat": "48.59932",
    "lng": "-1.97372"
  },
  {
    "country": "FR",
    "name": "Saint-Josse",
    "lat": "50.46801",
    "lng": "1.6618"
  },
  {
    "country": "FR",
    "name": "Saint-Joseph-de-Rivière",
    "lat": "45.37574",
    "lng": "5.69768"
  },
  {
    "country": "FR",
    "name": "Saint-Joseph",
    "lat": "45.55693",
    "lng": "4.61596"
  },
  {
    "country": "FR",
    "name": "Saint-Jory",
    "lat": "43.74146",
    "lng": "1.37089"
  },
  {
    "country": "FR",
    "name": "Saint-Jorioz",
    "lat": "45.83295",
    "lng": "6.16503"
  },
  {
    "country": "FR",
    "name": "Saint-Joachim",
    "lat": "47.38349",
    "lng": "-2.19239"
  },
  {
    "country": "FR",
    "name": "Saint-Jérôme",
    "lat": "43.33404",
    "lng": "5.41733"
  },
  {
    "country": "FR",
    "name": "Saint-Jeoire",
    "lat": "46.13777",
    "lng": "6.45886"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-sur-Veyle",
    "lat": "46.25876",
    "lng": "4.91751"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-sur-Mayenne",
    "lat": "48.13522",
    "lng": "-0.75613"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-sur-Couesnon",
    "lat": "48.29013",
    "lng": "-1.36835"
  },
  {
    "country": "FR",
    "name": "Sant Joan de Pladecorts",
    "lat": "42.51069",
    "lng": "2.79091"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-Pied-de-Port",
    "lat": "43.16363",
    "lng": "-1.23738"
  },
  {
    "country": "FR",
    "name": "Saint-Jeannet",
    "lat": "43.74723",
    "lng": "7.14284"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-le-Vieux",
    "lat": "46.02849",
    "lng": "5.38982"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-les-Deux-Jumeaux",
    "lat": "48.9514",
    "lng": "3.01959"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-le-Blanc",
    "lat": "47.89327",
    "lng": "1.9154"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-la-Poterie",
    "lat": "47.63581",
    "lng": "-2.1242"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-en-Royans",
    "lat": "45.01693",
    "lng": "5.29454"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-du-Gard",
    "lat": "44.10523",
    "lng": "3.88566"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-du-Falga",
    "lat": "43.08647",
    "lng": "1.6278"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-du-Cardonnay",
    "lat": "49.50455",
    "lng": "1.0114"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-de-Védas",
    "lat": "43.57759",
    "lng": "3.82603"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-de-Thouars",
    "lat": "46.96486",
    "lng": "-0.21114"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-de-Soudain",
    "lat": "45.57087",
    "lng": "5.43027"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-des-Mauvrets",
    "lat": "47.39857",
    "lng": "-0.44929"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-de-Sixt",
    "lat": "45.92216",
    "lng": "6.40991"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-des-Champs",
    "lat": "48.828",
    "lng": "-1.46487"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-des-Baisants",
    "lat": "49.09371",
    "lng": "-0.97289"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-de-Sauves",
    "lat": "46.8413",
    "lng": "0.09272"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-de-Niost",
    "lat": "45.83333",
    "lng": "5.21667"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-de-Muzols",
    "lat": "45.0804",
    "lng": "4.81421"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-de-Monts",
    "lat": "46.79088",
    "lng": "-2.08219"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-de-Moirans",
    "lat": "45.34262",
    "lng": "5.58615"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-de-Maurienne",
    "lat": "45.28333",
    "lng": "6.35"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-de-Luz",
    "lat": "43.38871",
    "lng": "-1.66267"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-de-Losne",
    "lat": "47.10247",
    "lng": "5.26556"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-de-Liversay",
    "lat": "46.26894",
    "lng": "-0.87385"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-de-la-Ruelle",
    "lat": "47.91127",
    "lng": "1.86483"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-de-Gonville",
    "lat": "46.21298",
    "lng": "5.95047"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-de-Fos",
    "lat": "43.701",
    "lng": "3.55171"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-de-Braye",
    "lat": "47.91303",
    "lng": "1.97705"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-de-Bournay",
    "lat": "45.50135",
    "lng": "5.13963"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-de-Boiseau",
    "lat": "47.19315",
    "lng": "-1.7234"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-d’Aulps",
    "lat": "46.23222",
    "lng": "6.64741"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-d'Angély",
    "lat": "45.95",
    "lng": "-0.51667"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-Cap-Ferrat",
    "lat": "43.68922",
    "lng": "7.33238"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-Brévelay",
    "lat": "47.84497",
    "lng": "-2.72231"
  },
  {
    "country": "FR",
    "name": "Saint-Jean-Bonnefonds",
    "lat": "45.45294",
    "lng": "4.45057"
  },
  {
    "country": "FR",
    "name": "Saint-Jean",
    "lat": "47.24553",
    "lng": "-0.38413"
  },
  {
    "country": "FR",
    "name": "Saint-Jean",
    "lat": "43.6642",
    "lng": "1.49941"
  },
  {
    "country": "FR",
    "name": "Saint-Jans-Cappel",
    "lat": "50.76387",
    "lng": "2.72227"
  },
  {
    "country": "FR",
    "name": "Saint-James",
    "lat": "48.5218",
    "lng": "-1.32629"
  },
  {
    "country": "FR",
    "name": "Saint-Jacut-les-Pins",
    "lat": "47.68581",
    "lng": "-2.21514"
  },
  {
    "country": "FR",
    "name": "Saint-Jacques-sur-Darnétal",
    "lat": "49.4398",
    "lng": "1.20359"
  },
  {
    "country": "FR",
    "name": "Saint-Jacques-de-la-Lande",
    "lat": "48.06514",
    "lng": "-1.72086"
  },
  {
    "country": "FR",
    "name": "Saint-Ismier",
    "lat": "45.24708",
    "lng": "5.82863"
  },
  {
    "country": "FR",
    "name": "Saint-Hippolyte-du-Fort",
    "lat": "43.96362",
    "lng": "3.85572"
  },
  {
    "country": "FR",
    "name": "Saint-Hippolyte",
    "lat": "48.23217",
    "lng": "7.36843"
  },
  {
    "country": "FR",
    "name": "Saint-Hippolyte",
    "lat": "47.3188",
    "lng": "6.81617"
  },
  {
    "country": "FR",
    "name": "Saint-Hippolyte",
    "lat": "45.91884",
    "lng": "-0.89183"
  },
  {
    "country": "FR",
    "name": "Saint-Hippolyte",
    "lat": "42.7855",
    "lng": "2.9662"
  },
  {
    "country": "FR",
    "name": "Saint-Hilaire-Saint-Mesmin",
    "lat": "47.86614",
    "lng": "1.83351"
  },
  {
    "country": "FR",
    "name": "Saint-Hilaire-Petitville",
    "lat": "49.3025",
    "lng": "-1.21995"
  },
  {
    "country": "FR",
    "name": "Saint-Hilaire-lez-Cambrai",
    "lat": "50.18419",
    "lng": "3.41327"
  },
  {
    "country": "FR",
    "name": "Saint-Hilaire-la-Palud",
    "lat": "46.26676",
    "lng": "-0.7138"
  },
  {
    "country": "FR",
    "name": "Saint-Hilaire-du-Rosier",
    "lat": "45.10038",
    "lng": "5.25012"
  },
  {
    "country": "FR",
    "name": "Saint-Hilaire-du-Harcouët",
    "lat": "48.577",
    "lng": "-1.09004"
  },
  {
    "country": "FR",
    "name": "Saint-Hilaire-de-Villefranche",
    "lat": "45.85091",
    "lng": "-0.52993"
  },
  {
    "country": "FR",
    "name": "Saint-Hilaire-de-Talmont",
    "lat": "46.47002",
    "lng": "-1.60359"
  },
  {
    "country": "FR",
    "name": "Saint-Hilaire-des-Loges",
    "lat": "46.4719",
    "lng": "-0.66393"
  },
  {
    "country": "FR",
    "name": "Saint-Hilaire-de-Riez",
    "lat": "46.71308",
    "lng": "-1.92583"
  },
  {
    "country": "FR",
    "name": "Saint-Hilaire-de-Loulay",
    "lat": "47.0019",
    "lng": "-1.33079"
  },
  {
    "country": "FR",
    "name": "Saint-Hilaire-de-la-Côte",
    "lat": "45.39098",
    "lng": "5.32287"
  },
  {
    "country": "FR",
    "name": "Saint-Hilaire-de-Clisson",
    "lat": "47.06222",
    "lng": "-1.30778"
  },
  {
    "country": "FR",
    "name": "Saint-Hilaire-de-Chaléons",
    "lat": "47.10196",
    "lng": "-1.8669"
  },
  {
    "country": "FR",
    "name": "Saint-Hilaire-de-Brethmas",
    "lat": "44.08003",
    "lng": "4.12478"
  },
  {
    "country": "FR",
    "name": "Saint-Hilaire",
    "lat": "45.3",
    "lng": "5.88333"
  },
  {
    "country": "FR",
    "name": "Saint-Hilaire",
    "lat": "44.53333",
    "lng": "0.71667"
  },
  {
    "country": "FR",
    "name": "Saint-Herblon",
    "lat": "47.40786",
    "lng": "-1.09738"
  },
  {
    "country": "FR",
    "name": "Saint-Herblain",
    "lat": "47.21765",
    "lng": "-1.64841"
  },
  {
    "country": "FR",
    "name": "Saint-Henri",
    "lat": "43.36151",
    "lng": "5.33069"
  },
  {
    "country": "FR",
    "name": "Saint-Hélen",
    "lat": "48.47002",
    "lng": "-1.95894"
  },
  {
    "country": "FR",
    "name": "Saint-Héand",
    "lat": "45.52817",
    "lng": "4.37377"
  },
  {
    "country": "FR",
    "name": "Saint-Grégoire",
    "lat": "48.15085",
    "lng": "-1.68706"
  },
  {
    "country": "FR",
    "name": "Saint-Gratien",
    "lat": "48.9735",
    "lng": "2.28729"
  },
  {
    "country": "FR",
    "name": "Saint-Gonnery",
    "lat": "48.12465",
    "lng": "-2.81848"
  },
  {
    "country": "FR",
    "name": "Saint-Gobain",
    "lat": "49.59572",
    "lng": "3.3775"
  },
  {
    "country": "FR",
    "name": "Saint-Girons",
    "lat": "42.98333",
    "lng": "1.15"
  },
  {
    "country": "FR",
    "name": "Saint-Gilles-Croix-de-Vie",
    "lat": "46.69761",
    "lng": "-1.94561"
  },
  {
    "country": "FR",
    "name": "Saint-Gilles",
    "lat": "48.15381",
    "lng": "-1.82477"
  },
  {
    "country": "FR",
    "name": "Saint-Gilles",
    "lat": "43.67656",
    "lng": "4.43024"
  },
  {
    "country": "FR",
    "name": "Saint-Gildas-des-Bois",
    "lat": "47.51622",
    "lng": "-2.03659"
  },
  {
    "country": "FR",
    "name": "Saint-Gildas-de-Rhuys",
    "lat": "47.5006",
    "lng": "-2.83825"
  },
  {
    "country": "FR",
    "name": "Saint-Gervasy",
    "lat": "43.87687",
    "lng": "4.46588"
  },
  {
    "country": "FR",
    "name": "Saint-Gervais-les-Trois-Clochers",
    "lat": "46.90067",
    "lng": "0.40766"
  },
  {
    "country": "FR",
    "name": "Saint-Gervais-les-Bains",
    "lat": "45.8929",
    "lng": "6.71381"
  },
  {
    "country": "FR",
    "name": "Saint-Gervais-la-Forêt",
    "lat": "47.56705",
    "lng": "1.35493"
  },
  {
    "country": "FR",
    "name": "Saint-Gervais-en-Belin",
    "lat": "47.8772",
    "lng": "0.2177"
  },
  {
    "country": "FR",
    "name": "Saint-Gervais-d’Auvergne",
    "lat": "46.02871",
    "lng": "2.8194"
  },
  {
    "country": "FR",
    "name": "Saint-Gervais",
    "lat": "46.90174",
    "lng": "-2.0021"
  },
  {
    "country": "FR",
    "name": "Saint-Gervais",
    "lat": "45.01583",
    "lng": "-0.45238"
  },
  {
    "country": "FR",
    "name": "Saint-Germer-de-Fly",
    "lat": "49.44281",
    "lng": "1.77986"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-Village",
    "lat": "49.34908",
    "lng": "0.50331"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-sur-Morin",
    "lat": "48.88257",
    "lng": "2.85127"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-sur-Moine",
    "lat": "47.11746",
    "lng": "-1.12223"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-Nuelles",
    "lat": "45.85242",
    "lng": "4.61182"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-sur-Avre",
    "lat": "48.76466",
    "lng": "1.26776"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-Lespinasse",
    "lat": "46.10165",
    "lng": "3.96204"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-lès-Corbeil",
    "lat": "48.62211",
    "lng": "2.48775"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-les-Belles",
    "lat": "45.61356",
    "lng": "1.4949"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-lès-Arpajon",
    "lat": "48.59733",
    "lng": "2.26481"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-Lembron",
    "lat": "45.45798",
    "lng": "3.2395"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-Laval",
    "lat": "48.39968",
    "lng": "2.99781"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-Laval",
    "lat": "45.83138",
    "lng": "4.01445"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-Laprade",
    "lat": "45.03862",
    "lng": "3.97004"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-la-Blanche-Herbe",
    "lat": "49.18327",
    "lng": "-0.40426"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-en-Laye",
    "lat": "48.9",
    "lng": "2.08333"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-en-Coglès",
    "lat": "48.40531",
    "lng": "-1.26369"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-du-Puy",
    "lat": "47.1",
    "lng": "2.48333"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-du-Puch",
    "lat": "44.85",
    "lng": "-0.31667"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-du-Plain",
    "lat": "46.69938",
    "lng": "4.9851"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-du-Corbéis",
    "lat": "48.42215",
    "lng": "0.06193"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-du-Bois",
    "lat": "46.75287",
    "lng": "5.2453"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-des-Prés",
    "lat": "47.95384",
    "lng": "2.84846"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-des-Prés",
    "lat": "47.40998",
    "lng": "-0.83342"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-des-Fossés",
    "lat": "46.20211",
    "lng": "3.43245"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-de-Prinçay",
    "lat": "46.72107",
    "lng": "-1.02153"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-de-Marencennes",
    "lat": "46.07733",
    "lng": "-0.79133"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-de-Lusignan",
    "lat": "45.45011",
    "lng": "-0.46147"
  },
  {
    "country": "FR",
    "name": "Saint-Germain-de-la-Grange",
    "lat": "48.83436",
    "lng": "1.89884"
  },
  {
    "country": "FR",
    "name": "Saint-Germain",
    "lat": "48.25736",
    "lng": "4.03264"
  },
  {
    "country": "FR",
    "name": "Saint-Germain",
    "lat": "47.72496",
    "lng": "6.53117"
  },
  {
    "country": "FR",
    "name": "Saint-Géréon",
    "lat": "47.36774",
    "lng": "-1.20262"
  },
  {
    "country": "FR",
    "name": "Saint-Gérand-le-Puy",
    "lat": "46.25758",
    "lng": "3.5122"
  },
  {
    "country": "FR",
    "name": "Saint-Geours-de-Maremne",
    "lat": "43.68936",
    "lng": "-1.22937"
  },
  {
    "country": "FR",
    "name": "Saint-Georges-sur-Loire",
    "lat": "47.40792",
    "lng": "-0.76194"
  },
  {
    "country": "FR",
    "name": "Saint-Georges-sur-Eure",
    "lat": "48.41869",
    "lng": "1.3546"
  },
  {
    "country": "FR",
    "name": "Saint-Georges-sur-Cher",
    "lat": "47.32996",
    "lng": "1.13261"
  },
  {
    "country": "FR",
    "name": "Saint-Georges-sur-Baulche",
    "lat": "47.80039",
    "lng": "3.53144"
  },
  {
    "country": "FR",
    "name": "Saint-Georges-sur-Allier",
    "lat": "45.71093",
    "lng": "3.24296"
  },
  {
    "country": "FR",
    "name": "Saint-Georges-les-Bains",
    "lat": "44.86222",
    "lng": "4.80758"
  },
  {
    "country": "FR",
    "name": "Saint-Georges-lès-Baillargeaux",
    "lat": "46.67017",
    "lng": "0.40209"
  },
  {
    "country": "FR",
    "name": "Saint-Georges-Haute-Ville",
    "lat": "45.55487",
    "lng": "4.09952"
  },
  {
    "country": "FR",
    "name": "Saint-Georges-du-Bois",
    "lat": "47.97242",
    "lng": "0.10113"
  },
  {
    "country": "FR",
    "name": "Saint-Georges-du-Bois",
    "lat": "46.14074",
    "lng": "-0.73393"
  },
  {
    "country": "FR",
    "name": "Saint-Georges-des-Groseillers",
    "lat": "48.76993",
    "lng": "-0.56768"
  },
  {
    "country": "FR",
    "name": "Saint-Georges-des-Coteaux",
    "lat": "45.76667",
    "lng": "-0.71667"
  },
  {
    "country": "FR",
    "name": "Saint-Georges-de-Reneins",
    "lat": "46.06034",
    "lng": "4.7256"
  },
  {
    "country": "FR",
    "name": "Saint-Georges-de-Reintembault",
    "lat": "48.50744",
    "lng": "-1.24328"
  },
  {
    "country": "FR",
    "name": "Saint-Georges-de-Pointindoux",
    "lat": "46.64462",
    "lng": "-1.62204"
  },
  {
    "country": "FR",
    "name": "Saint-Georges-de-Montaigu",
    "lat": "46.94655",
    "lng": "-1.29262"
  },
  {
    "country": "FR",
    "name": "Saint-Georges-de-Mons",
    "lat": "45.93994",
    "lng": "2.8406"
  },
  {
    "country": "FR",
    "name": "Saint-Georges-de-Luzençon",
    "lat": "44.06471",
    "lng": "2.98597"
  },
  {
    "country": "FR",
    "name": "Saint-Georges-de-Didonne",
    "lat": "45.60342",
    "lng": "-1.00487"
  },
  {
    "country": "FR",
    "name": "Saint-Georges-de-Commiers",
    "lat": "45.03854",
    "lng": "5.70226"
  },
  {
    "country": "FR",
    "name": "Saint-Georges-Buttavent",
    "lat": "48.31018",
    "lng": "-0.69372"
  },
  {
    "country": "FR",
    "name": "Saint-Geoire-en-Valdaine",
    "lat": "45.45699",
    "lng": "5.63415"
  },
  {
    "country": "FR",
    "name": "Saint-Genix-sur-Guiers",
    "lat": "45.59966",
    "lng": "5.63436"
  },
  {
    "country": "FR",
    "name": "Saint-Genis-Pouilly",
    "lat": "46.24356",
    "lng": "6.02119"
  },
  {
    "country": "FR",
    "name": "Saint-Genis-les-Ollières",
    "lat": "45.75719",
    "lng": "4.72892"
  },
  {
    "country": "FR",
    "name": "Saint-Genis-Laval",
    "lat": "45.69558",
    "lng": "4.7934"
  },
  {
    "country": "FR",
    "name": "Saint-Genis-de-Saintonge",
    "lat": "45.48107",
    "lng": "-0.56848"
  },
  {
    "country": "FR",
    "name": "Saint-Génis-des-Fontaines",
    "lat": "42.54325",
    "lng": "2.9206"
  },
  {
    "country": "FR",
    "name": "Saint-Geniez-d’Olt",
    "lat": "44.46561",
    "lng": "2.97261"
  },
  {
    "country": "FR",
    "name": "Saint-Geniès-de-Fontedit",
    "lat": "43.46667",
    "lng": "3.18333"
  },
  {
    "country": "FR",
    "name": "Saint-Geniès-des-Mourgues",
    "lat": "43.6978",
    "lng": "4.0361"
  },
  {
    "country": "FR",
    "name": "Saint-Geniès-de-Malgoirès",
    "lat": "43.95",
    "lng": "4.21667"
  },
  {
    "country": "FR",
    "name": "Saint-Geniès-de-Comolas",
    "lat": "44.06617",
    "lng": "4.72157"
  },
  {
    "country": "FR",
    "name": "Saint-Geniès-Bellevue",
    "lat": "43.68409",
    "lng": "1.48693"
  },
  {
    "country": "FR",
    "name": "Saint-Gengoux-le-National",
    "lat": "46.61476",
    "lng": "4.66261"
  },
  {
    "country": "FR",
    "name": "Saint-Genest-Malifaux",
    "lat": "45.34234",
    "lng": "4.41954"
  },
  {
    "country": "FR",
    "name": "Saint-Genest-Lerpt",
    "lat": "45.44529",
    "lng": "4.33622"
  },
  {
    "country": "FR",
    "name": "Saint-Genès-Champanelle",
    "lat": "45.71915",
    "lng": "3.01887"
  },
  {
    "country": "FR",
    "name": "Saint-Gence",
    "lat": "45.92198",
    "lng": "1.13726"
  },
  {
    "country": "FR",
    "name": "Saint-Gély-du-Fesc",
    "lat": "43.69272",
    "lng": "3.80492"
  },
  {
    "country": "FR",
    "name": "Saint-Gelais",
    "lat": "46.38234",
    "lng": "-0.39084"
  },
  {
    "country": "FR",
    "name": "Saint-Gaultier",
    "lat": "46.63518",
    "lng": "1.41289"
  },
  {
    "country": "FR",
    "name": "Saint-Gaudens",
    "lat": "43.11667",
    "lng": "0.73333"
  },
  {
    "country": "FR",
    "name": "Saint-Gatien-des-Bois",
    "lat": "49.35",
    "lng": "0.18333"
  },
  {
    "country": "FR",
    "name": "Saint-Galmier",
    "lat": "45.59199",
    "lng": "4.31743"
  },
  {
    "country": "FR",
    "name": "Saint-Fulgent",
    "lat": "46.85226",
    "lng": "-1.17798"
  },
  {
    "country": "FR",
    "name": "Saint-François",
    "lat": "46.41537",
    "lng": "3.90542"
  },
  {
    "country": "FR",
    "name": "Saint-Fort",
    "lat": "47.79928",
    "lng": "-0.72095"
  },
  {
    "country": "FR",
    "name": "Saint-Forgeux",
    "lat": "45.85979",
    "lng": "4.47486"
  },
  {
    "country": "FR",
    "name": "Saint-Fons",
    "lat": "45.7088",
    "lng": "4.86057"
  },
  {
    "country": "FR",
    "name": "Saint-Folquin",
    "lat": "50.94473",
    "lng": "2.12433"
  },
  {
    "country": "FR",
    "name": "Saint-Flour",
    "lat": "45.03333",
    "lng": "3.08333"
  },
  {
    "country": "FR",
    "name": "Saint-Florent-sur-Cher",
    "lat": "46.99552",
    "lng": "2.25076"
  },
  {
    "country": "FR",
    "name": "Saint-Florent-sur-Auzonnet",
    "lat": "44.24032",
    "lng": "4.11252"
  },
  {
    "country": "FR",
    "name": "Saint-Florent-le-Vieil",
    "lat": "47.36069",
    "lng": "-1.01515"
  },
  {
    "country": "FR",
    "name": "Saint-Florentin",
    "lat": "48.00057",
    "lng": "3.72489"
  },
  {
    "country": "FR",
    "name": "Saint-Florent-des-Bois",
    "lat": "46.59377",
    "lng": "-1.3158"
  },
  {
    "country": "FR",
    "name": "Saint-Florent",
    "lat": "42.6815",
    "lng": "9.30396"
  },
  {
    "country": "FR",
    "name": "Saint-Fiacre-sur-Maine",
    "lat": "47.14255",
    "lng": "-1.41714"
  },
  {
    "country": "FR",
    "name": "Saint-Félix-Lauragais",
    "lat": "43.44863",
    "lng": "1.88814"
  },
  {
    "country": "FR",
    "name": "Saint-Félix",
    "lat": "45.8023",
    "lng": "5.97105"
  },
  {
    "country": "FR",
    "name": "Saint-Féliu-d’Avall",
    "lat": "42.68117",
    "lng": "2.73813"
  },
  {
    "country": "FR",
    "name": "Saint-Félicien",
    "lat": "45.08458",
    "lng": "4.62718"
  },
  {
    "country": "FR",
    "name": "Saint-Fargeau-Ponthierry",
    "lat": "48.55713",
    "lng": "2.5284"
  },
  {
    "country": "FR",
    "name": "Saint-Fargeau",
    "lat": "47.64133",
    "lng": "3.07066"
  },
  {
    "country": "FR",
    "name": "Sainte-Verge",
    "lat": "47.00818",
    "lng": "-0.21033"
  },
  {
    "country": "FR",
    "name": "Saint-Évarzec",
    "lat": "47.93333",
    "lng": "-4.01667"
  },
  {
    "country": "FR",
    "name": "Saint-Eustache-la-Forêt",
    "lat": "49.55137",
    "lng": "0.45599"
  },
  {
    "country": "FR",
    "name": "Saint-Eusèbe",
    "lat": "46.71346",
    "lng": "4.46203"
  },
  {
    "country": "FR",
    "name": "Sainte-Tulle",
    "lat": "43.78845",
    "lng": "5.76736"
  },
  {
    "country": "FR",
    "name": "Saint-Étienne-sur-Chalaronne",
    "lat": "46.14781",
    "lng": "4.86555"
  },
  {
    "country": "FR",
    "name": "Saint-Étienne-lès-Remiremont",
    "lat": "48.02287",
    "lng": "6.60868"
  },
  {
    "country": "FR",
    "name": "Saint-Étienne-en-Coglès",
    "lat": "48.40172",
    "lng": "-1.32812"
  },
  {
    "country": "FR",
    "name": "Saint-Étienne-du-Rouvray",
    "lat": "49.37794",
    "lng": "1.10467"
  },
  {
    "country": "FR",
    "name": "Saint-Étienne-du-Grès",
    "lat": "43.78111",
    "lng": "4.72163"
  },
  {
    "country": "FR",
    "name": "Saint-Étienne-du-Bois",
    "lat": "46.83041",
    "lng": "-1.59714"
  },
  {
    "country": "FR",
    "name": "Saint-Étienne-du-Bois",
    "lat": "46.28766",
    "lng": "5.29481"
  },
  {
    "country": "FR",
    "name": "Saint-Etienne-de-Tulmont",
    "lat": "44.05",
    "lng": "1.46667"
  },
  {
    "country": "FR",
    "name": "Saint-Étienne-de-Tinée",
    "lat": "44.25",
    "lng": "6.91667"
  },
  {
    "country": "FR",
    "name": "Saint-Étienne-des-Oullières",
    "lat": "46.06755",
    "lng": "4.64761"
  },
  {
    "country": "FR",
    "name": "Saint-Étienne-de-Saint-Geoirs",
    "lat": "45.33931",
    "lng": "5.3449"
  },
  {
    "country": "FR",
    "name": "Saint-Étienne-de-Montluc",
    "lat": "47.2769",
    "lng": "-1.78072"
  },
  {
    "country": "FR",
    "name": "Saint-Étienne-de-Mer-Morte",
    "lat": "46.92848",
    "lng": "-1.74272"
  },
  {
    "country": "FR",
    "name": "Saint-Étienne-de-Fontbellon",
    "lat": "44.60175",
    "lng": "4.38581"
  },
  {
    "country": "FR",
    "name": "Saint-Etienne-de-Cuines",
    "lat": "45.35",
    "lng": "6.28333"
  },
  {
    "country": "FR",
    "name": "Saint-Étienne-de-Crossey",
    "lat": "45.37914",
    "lng": "5.64527"
  },
  {
    "country": "FR",
    "name": "Corcoué-sur-Logne",
    "lat": "46.96667",
    "lng": "-1.58333"
  },
  {
    "country": "FR",
    "name": "Saint-Étienne-de-Chigny",
    "lat": "47.38333",
    "lng": "0.53333"
  },
  {
    "country": "FR",
    "name": "Saint-Étienne-de-Baïgorry",
    "lat": "43.17533",
    "lng": "-1.3467"
  },
  {
    "country": "FR",
    "name": "Saint-Étienne-au-Mont",
    "lat": "50.67794",
    "lng": "1.63084"
  },
  {
    "country": "FR",
    "name": "Saint-Étienne",
    "lat": "45.43389",
    "lng": "4.39"
  },
  {
    "country": "FR",
    "name": "Sainte-Terre",
    "lat": "44.83333",
    "lng": "-0.11667"
  },
  {
    "country": "FR",
    "name": "Sainte-Suzanne",
    "lat": "48.09818",
    "lng": "-0.35439"
  },
  {
    "country": "FR",
    "name": "Sainte-Suzanne",
    "lat": "47.50017",
    "lng": "6.76775"
  },
  {
    "country": "FR",
    "name": "Saint-Estève",
    "lat": "42.71175",
    "lng": "2.8449"
  },
  {
    "country": "FR",
    "name": "Saint-Estèphe",
    "lat": "45.26252",
    "lng": "-0.77237"
  },
  {
    "country": "FR",
    "name": "Sainte-Soulle",
    "lat": "46.18847",
    "lng": "-1.01607"
  },
  {
    "country": "FR",
    "name": "Sainte-Solange",
    "lat": "47.13628",
    "lng": "2.55019"
  },
  {
    "country": "FR",
    "name": "Saintes-Maries-de-la-Mer",
    "lat": "43.45214",
    "lng": "4.42913"
  },
  {
    "country": "FR",
    "name": "Sainte-Sigolène",
    "lat": "45.24329",
    "lng": "4.23343"
  },
  {
    "country": "FR",
    "name": "Sainte-Savine",
    "lat": "48.29637",
    "lng": "4.04642"
  },
  {
    "country": "FR",
    "name": "Saintes",
    "lat": "45.75",
    "lng": "-0.63333"
  },
  {
    "country": "FR",
    "name": "Saint-Erme-Outre-et-Ramecourt",
    "lat": "49.51464",
    "lng": "3.8406"
  },
  {
    "country": "FR",
    "name": "Sainte-Reine-de-Bretagne",
    "lat": "47.44131",
    "lng": "-2.19238"
  },
  {
    "country": "FR",
    "name": "Saint-Erblon",
    "lat": "48.01895",
    "lng": "-1.65162"
  },
  {
    "country": "FR",
    "name": "Sainte-Radegonde",
    "lat": "46.98333",
    "lng": "-0.25"
  },
  {
    "country": "FR",
    "name": "Sainte-Radegonde",
    "lat": "44.33743",
    "lng": "2.62672"
  },
  {
    "country": "FR",
    "name": "Sainte-Pazanne",
    "lat": "47.10301",
    "lng": "-1.8095"
  },
  {
    "country": "FR",
    "name": "Saint-Épain",
    "lat": "47.14482",
    "lng": "0.53668"
  },
  {
    "country": "FR",
    "name": "Saint-Émilion",
    "lat": "44.88333",
    "lng": "-0.15"
  },
  {
    "country": "FR",
    "name": "Sainte-Mère-Église",
    "lat": "49.41",
    "lng": "-1.31726"
  },
  {
    "country": "FR",
    "name": "Sainte-Menehould",
    "lat": "49.08333",
    "lng": "4.9"
  },
  {
    "country": "FR",
    "name": "Sainte-Maxime",
    "lat": "43.30907",
    "lng": "6.63849"
  },
  {
    "country": "FR",
    "name": "Sainte-Maure-de-Touraine",
    "lat": "47.1113",
    "lng": "0.62236"
  },
  {
    "country": "FR",
    "name": "Sainte-Maure",
    "lat": "48.34729",
    "lng": "4.05962"
  },
  {
    "country": "FR",
    "name": "Sainte-Marthe",
    "lat": "43.33449",
    "lng": "5.39112"
  },
  {
    "country": "FR",
    "name": "Sainte-Marie-Plage",
    "lat": "42.72498",
    "lng": "3.03751"
  },
  {
    "country": "FR",
    "name": "Sainte-Marie-Kerque",
    "lat": "50.89917",
    "lng": "2.13664"
  },
  {
    "country": "FR",
    "name": "Sainte-Marie-des-Champs",
    "lat": "49.6212",
    "lng": "0.77904"
  },
  {
    "country": "FR",
    "name": "Sainte-Marie-de-Ré",
    "lat": "46.15237",
    "lng": "-1.31281"
  },
  {
    "country": "FR",
    "name": "Sainte-Marie-de-Gosse",
    "lat": "43.55",
    "lng": "-0.23333"
  },
  {
    "country": "FR",
    "name": "Sainte-Marie-aux-Mines",
    "lat": "48.2468",
    "lng": "7.18528"
  },
  {
    "country": "FR",
    "name": "Sainte-Marie-aux-Chênes",
    "lat": "49.19262",
    "lng": "6.0015"
  },
  {
    "country": "FR",
    "name": "Sainte-Marie",
    "lat": "47.69429",
    "lng": "-2.0019"
  },
  {
    "country": "FR",
    "name": "Sainte-Marguerite-sur-Duclair",
    "lat": "49.50852",
    "lng": "0.84362"
  },
  {
    "country": "FR",
    "name": "Sainte-Marguerite",
    "lat": "43.26196",
    "lng": "5.40125"
  },
  {
    "country": "FR",
    "name": "Sainte-Marguerite",
    "lat": "48.26735",
    "lng": "6.98439"
  },
  {
    "country": "FR",
    "name": "Sainte-Luce-sur-Loire",
    "lat": "47.25381",
    "lng": "-1.4843"
  },
  {
    "country": "FR",
    "name": "Saint-Éloy-les-Mines",
    "lat": "46.15793",
    "lng": "2.83623"
  },
  {
    "country": "FR",
    "name": "Saint-Éloy-de-Gy",
    "lat": "47.15552",
    "lng": "2.34267"
  },
  {
    "country": "FR",
    "name": "Saint-Éloi",
    "lat": "46.97342",
    "lng": "3.22228"
  },
  {
    "country": "FR",
    "name": "Sainte-Lizaigne",
    "lat": "47.00695",
    "lng": "2.02266"
  },
  {
    "country": "FR",
    "name": "Sainte-Livrade-sur-Lot",
    "lat": "44.39929",
    "lng": "0.5912"
  },
  {
    "country": "FR",
    "name": "Sainte-Jamme-sur-Sarthe",
    "lat": "48.14264",
    "lng": "0.16743"
  },
  {
    "country": "FR",
    "name": "Sainte-Honorine-du-Fay",
    "lat": "49.07775",
    "lng": "-0.49295"
  },
  {
    "country": "FR",
    "name": "Sainte-Hermine",
    "lat": "46.55619",
    "lng": "-1.05476"
  },
  {
    "country": "FR",
    "name": "Sainte-Hélène-sur-Isère",
    "lat": "45.61313",
    "lng": "6.32065"
  },
  {
    "country": "FR",
    "name": "Sainte-Hélène",
    "lat": "47.71976",
    "lng": "-3.20359"
  },
  {
    "country": "FR",
    "name": "Sainte-Hélène",
    "lat": "44.96667",
    "lng": "-0.88333"
  },
  {
    "country": "FR",
    "name": "Sainte-Geneviève-sur-Argence",
    "lat": "44.80222",
    "lng": "2.75954"
  },
  {
    "country": "FR",
    "name": "Sainte-Geneviève-des-Bois",
    "lat": "48.64682",
    "lng": "2.31965"
  },
  {
    "country": "FR",
    "name": "Sainte-Geneviève-des-Bois",
    "lat": "47.81777",
    "lng": "2.81652"
  },
  {
    "country": "FR",
    "name": "Sainte-Geneviève",
    "lat": "49.2892",
    "lng": "2.19904"
  },
  {
    "country": "FR",
    "name": "Sainte-Gemmes-sur-Loire",
    "lat": "47.4229",
    "lng": "-0.55684"
  },
  {
    "country": "FR",
    "name": "Sainte-Gemme-la-Plaine",
    "lat": "46.48286",
    "lng": "-1.11321"
  },
  {
    "country": "FR",
    "name": "Sainte-Gauburge-Sainte-Colombe",
    "lat": "48.71722",
    "lng": "0.43126"
  },
  {
    "country": "FR",
    "name": "Sainte-Foy-lès-Lyon",
    "lat": "45.73692",
    "lng": "4.79688"
  },
  {
    "country": "FR",
    "name": "Sainte-Foy-l’Argentière",
    "lat": "45.70832",
    "lng": "4.47266"
  },
  {
    "country": "FR",
    "name": "Sainte-Foy-la-Grande",
    "lat": "44.83333",
    "lng": "0.21667"
  },
  {
    "country": "FR",
    "name": "Sainte-Foy-de-Peyrolières",
    "lat": "43.49262",
    "lng": "1.14477"
  },
  {
    "country": "FR",
    "name": "Sainte-Foy",
    "lat": "46.54488",
    "lng": "-1.67265"
  },
  {
    "country": "FR",
    "name": "Sainte-Fortunade",
    "lat": "45.20805",
    "lng": "1.77181"
  },
  {
    "country": "FR",
    "name": "Sainte-Florine",
    "lat": "45.40546",
    "lng": "3.31995"
  },
  {
    "country": "FR",
    "name": "Sainte-Flaive-des-Loups",
    "lat": "46.61303",
    "lng": "-1.58082"
  },
  {
    "country": "FR",
    "name": "Sainte-Feyre",
    "lat": "46.139",
    "lng": "1.91517"
  },
  {
    "country": "FR",
    "name": "Sainte-Féréole",
    "lat": "45.22806",
    "lng": "1.58278"
  },
  {
    "country": "FR",
    "name": "Sainte-Euphémie",
    "lat": "45.97196",
    "lng": "4.79437"
  },
  {
    "country": "FR",
    "name": "Sainte-Eulalie",
    "lat": "44.90667",
    "lng": "-0.47417"
  },
  {
    "country": "FR",
    "name": "Saint-Égrève",
    "lat": "45.23333",
    "lng": "5.68333"
  },
  {
    "country": "FR",
    "name": "Sainte-Croix-en-Plaine",
    "lat": "48.00876",
    "lng": "7.38556"
  },
  {
    "country": "FR",
    "name": "Sainte-Croix-aux-Mines",
    "lat": "48.26124",
    "lng": "7.22445"
  },
  {
    "country": "FR",
    "name": "Sainte-Consorce",
    "lat": "45.77706",
    "lng": "4.69735"
  },
  {
    "country": "FR",
    "name": "Sainte-Colombe-en-Bruilhois",
    "lat": "44.17822",
    "lng": "0.51572"
  },
  {
    "country": "FR",
    "name": "Sainte-Colombe",
    "lat": "48.53047",
    "lng": "3.25517"
  },
  {
    "country": "FR",
    "name": "Sainte-Colombe",
    "lat": "45.52474",
    "lng": "4.86136"
  },
  {
    "country": "FR",
    "name": "Sainte-Cécile-les-Vignes",
    "lat": "44.24506",
    "lng": "4.8839"
  },
  {
    "country": "FR",
    "name": "Sainte-Cécile",
    "lat": "46.74286",
    "lng": "-1.11429"
  },
  {
    "country": "FR",
    "name": "Sainte-Catherine",
    "lat": "50.30757",
    "lng": "2.76404"
  },
  {
    "country": "FR",
    "name": "Sainte-Bazeille",
    "lat": "44.53073",
    "lng": "0.0974"
  },
  {
    "country": "FR",
    "name": "Sainte-Anne-sur-Brivet",
    "lat": "47.46071",
    "lng": "-2.00415"
  },
  {
    "country": "FR",
    "name": "Sainte-Anne-d'Auray",
    "lat": "47.7",
    "lng": "-2.95"
  },
  {
    "country": "FR",
    "name": "Sainte-Anne",
    "lat": "43.2572",
    "lng": "5.39377"
  },
  {
    "country": "FR",
    "name": "Sainte-Anastasie-sur-Issole",
    "lat": "43.34211",
    "lng": "6.12359"
  },
  {
    "country": "FR",
    "name": "Sainte-Agnès",
    "lat": "43.79943",
    "lng": "7.46595"
  },
  {
    "country": "FR",
    "name": "Sainte-Adresse",
    "lat": "49.5089",
    "lng": "0.08446"
  },
  {
    "country": "FR",
    "name": "Saint-Dyé-sur-Loire",
    "lat": "47.65595",
    "lng": "1.48847"
  },
  {
    "country": "FR",
    "name": "Saint-Drézéry",
    "lat": "43.72991",
    "lng": "3.9762"
  },
  {
    "country": "FR",
    "name": "Saint-Doulchard",
    "lat": "47.10371",
    "lng": "2.352"
  },
  {
    "country": "FR",
    "name": "Saint-Donan",
    "lat": "48.46958",
    "lng": "-2.88442"
  },
  {
    "country": "FR",
    "name": "Saint-Domineuc",
    "lat": "48.37191",
    "lng": "-1.87544"
  },
  {
    "country": "FR",
    "name": "Saint-Dolay",
    "lat": "47.54476",
    "lng": "-2.15466"
  },
  {
    "country": "FR",
    "name": "Saint-Dizier",
    "lat": "48.63333",
    "lng": "4.95"
  },
  {
    "country": "FR",
    "name": "Saint-Dié-des-Vosges",
    "lat": "48.28333",
    "lng": "6.95"
  },
  {
    "country": "FR",
    "name": "Saint-Didier-sur-Chalaronne",
    "lat": "46.17751",
    "lng": "4.81719"
  },
  {
    "country": "FR",
    "name": "Saint-Didier-sous-Riverie",
    "lat": "45.59627",
    "lng": "4.6065"
  },
  {
    "country": "FR",
    "name": "Saint-Didier-en-Velay",
    "lat": "45.30234",
    "lng": "4.27561"
  },
  {
    "country": "FR",
    "name": "Saint-Didier-de-la-Tour",
    "lat": "45.55548",
    "lng": "5.48314"
  },
  {
    "country": "FR",
    "name": "Saint-Didier-de-Formans",
    "lat": "45.95361",
    "lng": "4.78485"
  },
  {
    "country": "FR",
    "name": "Saint-Didier",
    "lat": "48.09506",
    "lng": "-1.37276"
  },
  {
    "country": "FR",
    "name": "Saint-Didier",
    "lat": "44.00424",
    "lng": "5.11053"
  },
  {
    "country": "FR",
    "name": "Saint-Désir",
    "lat": "49.14056",
    "lng": "0.21398"
  },
  {
    "country": "FR",
    "name": "Saint-Denis-sur-Sarthon",
    "lat": "48.4532",
    "lng": "-0.0472"
  },
  {
    "country": "FR",
    "name": "Saint-Denis-les-Ponts",
    "lat": "48.06692",
    "lng": "1.29764"
  },
  {
    "country": "FR",
    "name": "Saint-Denis-lès-Bourg",
    "lat": "46.20217",
    "lng": "5.18924"
  },
  {
    "country": "FR",
    "name": "Saint-Denis-la-Chevasse",
    "lat": "46.82273",
    "lng": "-1.35749"
  },
  {
    "country": "FR",
    "name": "Saint-Denis-en-Val",
    "lat": "47.87321",
    "lng": "1.96601"
  },
  {
    "country": "FR",
    "name": "Saint-Denis-en-Bugey",
    "lat": "45.9489",
    "lng": "5.32808"
  },
  {
    "country": "FR",
    "name": "Saint-Denis-d’Oléron",
    "lat": "46.03496",
    "lng": "-1.37867"
  },
  {
    "country": "FR",
    "name": "Saint-Denis-de-Pile",
    "lat": "45",
    "lng": "-0.2"
  },
  {
    "country": "FR",
    "name": "Saint-Denis-de-Gastines",
    "lat": "48.3421",
    "lng": "-0.85869"
  },
  {
    "country": "FR",
    "name": "Saint-Denis-de-Cabanne",
    "lat": "46.17348",
    "lng": "4.21091"
  },
  {
    "country": "FR",
    "name": "Saint-Denis",
    "lat": "48.93333",
    "lng": "2.36667"
  },
  {
    "country": "FR",
    "name": "Saint-Cyr-sur-Morin",
    "lat": "48.90664",
    "lng": "3.18016"
  },
  {
    "country": "FR",
    "name": "Saint-Cyr-sur-Mer",
    "lat": "43.18352",
    "lng": "5.70914"
  },
  {
    "country": "FR",
    "name": "Saint-Cyr-sur-Menthon",
    "lat": "46.27549",
    "lng": "4.97229"
  },
  {
    "country": "FR",
    "name": "Saint-Cyr-sur-Loire",
    "lat": "47.4",
    "lng": "0.66667"
  },
  {
    "country": "FR",
    "name": "Saint-Cyr-sur-le-Rhône",
    "lat": "45.51537",
    "lng": "4.85002"
  },
  {
    "country": "FR",
    "name": "Saint-Cyr-sous-Dourdan",
    "lat": "48.56667",
    "lng": "2.03333"
  },
  {
    "country": "FR",
    "name": "Saint-Cyr-l’École",
    "lat": "48.79865",
    "lng": "2.06814"
  },
  {
    "country": "FR",
    "name": "Saint-Cyr-en-Val",
    "lat": "47.83182",
    "lng": "1.96672"
  },
  {
    "country": "FR",
    "name": "Saint-Cyr-en-Bourg",
    "lat": "47.1952",
    "lng": "-0.06085"
  },
  {
    "country": "FR",
    "name": "Saint-Cyr",
    "lat": "45.25243",
    "lng": "4.73074"
  },
  {
    "country": "FR",
    "name": "Saint-Cyprien-Plage",
    "lat": "42.63229",
    "lng": "3.03333"
  },
  {
    "country": "FR",
    "name": "Saint-Cyprien",
    "lat": "45.53375",
    "lng": "4.23311"
  },
  {
    "country": "FR",
    "name": "Saint-Cyprien",
    "lat": "44.86924",
    "lng": "1.04156"
  },
  {
    "country": "FR",
    "name": "Saint-Crespin-sur-Moine",
    "lat": "47.09968",
    "lng": "-1.18651"
  },
  {
    "country": "FR",
    "name": "Saint-Crépin-Ibouvillers",
    "lat": "49.26283",
    "lng": "2.07793"
  },
  {
    "country": "FR",
    "name": "Saint-Coulomb",
    "lat": "48.67465",
    "lng": "-1.91092"
  },
  {
    "country": "FR",
    "name": "Saint-Cosme-en-Vairais",
    "lat": "48.26667",
    "lng": "0.46667"
  },
  {
    "country": "FR",
    "name": "Saint-Contest",
    "lat": "49.21401",
    "lng": "-0.40221"
  },
  {
    "country": "FR",
    "name": "Saint-Cloud",
    "lat": "48.84598",
    "lng": "2.20289"
  },
  {
    "country": "FR",
    "name": "Saint-Clément-des-Levées",
    "lat": "47.33333",
    "lng": "-0.18222"
  },
  {
    "country": "FR",
    "name": "Saint-Clément-de-la-Place",
    "lat": "47.52744",
    "lng": "-0.74545"
  },
  {
    "country": "FR",
    "name": "Saint-Clément",
    "lat": "48.21724",
    "lng": "3.29609"
  },
  {
    "country": "FR",
    "name": "Saint-Clément",
    "lat": "45.34188",
    "lng": "1.68573"
  },
  {
    "country": "FR",
    "name": "Saint-Clément-de-Rivière",
    "lat": "43.68333",
    "lng": "3.83333"
  },
  {
    "country": "FR",
    "name": "Saint-Claude-de-Diray",
    "lat": "47.61651",
    "lng": "1.41798"
  },
  {
    "country": "FR",
    "name": "Saint-Claude",
    "lat": "46.38679",
    "lng": "5.86473"
  },
  {
    "country": "FR",
    "name": "Saint-Claud",
    "lat": "45.89526",
    "lng": "0.46454"
  },
  {
    "country": "FR",
    "name": "Saint-Clair-du-Rhône",
    "lat": "45.43909",
    "lng": "4.77178"
  },
  {
    "country": "FR",
    "name": "Saint-Clair-de-la-Tour",
    "lat": "45.57343",
    "lng": "5.48332"
  },
  {
    "country": "FR",
    "name": "Saint-Ciers-sur-Gironde",
    "lat": "45.28855",
    "lng": "-0.60794"
  },
  {
    "country": "FR",
    "name": "Saint-Ciers-d’Abzac",
    "lat": "45.03333",
    "lng": "-0.26667"
  },
  {
    "country": "FR",
    "name": "Saint-Christophe-Vallon",
    "lat": "44.47072",
    "lng": "2.41184"
  },
  {
    "country": "FR",
    "name": "Saint-Christophe-sur-le-Nais",
    "lat": "47.6172",
    "lng": "0.47801"
  },
  {
    "country": "FR",
    "name": "Saint-Christophe-du-Ligneron",
    "lat": "46.82478",
    "lng": "-1.76586"
  },
  {
    "country": "FR",
    "name": "Saint-Christophe-du-Bois",
    "lat": "47.03012",
    "lng": "-0.94441"
  },
  {
    "country": "FR",
    "name": "Saint-Christoly-de-Blaye",
    "lat": "45.13179",
    "lng": "-0.5076"
  },
  {
    "country": "FR",
    "name": "Saint-Christol-lès-Alès",
    "lat": "44.08256",
    "lng": "4.07506"
  },
  {
    "country": "FR",
    "name": "Saint-Christol",
    "lat": "43.72805",
    "lng": "4.07991"
  },
  {
    "country": "FR",
    "name": "Saint-Christo-en-Jarez",
    "lat": "45.54316",
    "lng": "4.48474"
  },
  {
    "country": "FR",
    "name": "Saint-Chinian",
    "lat": "43.42238",
    "lng": "2.94643"
  },
  {
    "country": "FR",
    "name": "Saint-Chéron",
    "lat": "48.55433",
    "lng": "2.12403"
  },
  {
    "country": "FR",
    "name": "Saint-Chef",
    "lat": "45.63385",
    "lng": "5.36518"
  },
  {
    "country": "FR",
    "name": "Saint-Chaptes",
    "lat": "43.97172",
    "lng": "4.27812"
  },
  {
    "country": "FR",
    "name": "Saint-Chamond",
    "lat": "45.4759",
    "lng": "4.51294"
  },
  {
    "country": "FR",
    "name": "Saint-Chamas",
    "lat": "43.54946",
    "lng": "5.03324"
  },
  {
    "country": "FR",
    "name": "Saint-Chaffrey",
    "lat": "44.92555",
    "lng": "6.60768"
  },
  {
    "country": "FR",
    "name": "Saint-Cézaire-sur-Siagne",
    "lat": "43.64884",
    "lng": "6.79384"
  },
  {
    "country": "FR",
    "name": "Saint-Cernin",
    "lat": "45.0573",
    "lng": "2.42232"
  },
  {
    "country": "FR",
    "name": "Saint-Cergues",
    "lat": "46.23349",
    "lng": "6.31954"
  },
  {
    "country": "FR",
    "name": "Saint-Céré",
    "lat": "44.85726",
    "lng": "1.89415"
  },
  {
    "country": "FR",
    "name": "Saint-Cast-le-Guildo",
    "lat": "48.63028",
    "lng": "-2.25777"
  },
  {
    "country": "FR",
    "name": "Saint-Cassien",
    "lat": "45.35971",
    "lng": "5.55321"
  },
  {
    "country": "FR",
    "name": "Saint-Carreuc",
    "lat": "48.39889",
    "lng": "-2.73056"
  },
  {
    "country": "FR",
    "name": "Saint-Caradec",
    "lat": "48.19429",
    "lng": "-2.84386"
  },
  {
    "country": "FR",
    "name": "Saint-Caprais-de-Bordeaux",
    "lat": "44.74786",
    "lng": "-0.43192"
  },
  {
    "country": "FR",
    "name": "Saint-Cannat",
    "lat": "43.62089",
    "lng": "5.2969"
  },
  {
    "country": "FR",
    "name": "Saint-Calais",
    "lat": "47.92211",
    "lng": "0.74587"
  },
  {
    "country": "FR",
    "name": "Saint-Broladre",
    "lat": "48.58677",
    "lng": "-1.65769"
  },
  {
    "country": "FR",
    "name": "Saint-Brisson-sur-Loire",
    "lat": "47.64686",
    "lng": "2.68229"
  },
  {
    "country": "FR",
    "name": "Saint-Bris-le-Vineux",
    "lat": "47.74396",
    "lng": "3.64922"
  },
  {
    "country": "FR",
    "name": "Saint-Brieuc",
    "lat": "48.51513",
    "lng": "-2.76838"
  },
  {
    "country": "FR",
    "name": "Saint-Brice-sur-Vienne",
    "lat": "45.87852",
    "lng": "0.95594"
  },
  {
    "country": "FR",
    "name": "Saint-Brice-sous-Forêt",
    "lat": "49.00132",
    "lng": "2.35361"
  },
  {
    "country": "FR",
    "name": "Saint-Brice-Courcelles",
    "lat": "49.26667",
    "lng": "3.98333"
  },
  {
    "country": "FR",
    "name": "Saint-Brice-en-Coglès",
    "lat": "48.41157",
    "lng": "-1.37019"
  },
  {
    "country": "FR",
    "name": "Saint-Brice",
    "lat": "45.68333",
    "lng": "-0.28333"
  },
  {
    "country": "FR",
    "name": "Saint-Briac-sur-Mer",
    "lat": "48.62189",
    "lng": "-2.13435"
  },
  {
    "country": "FR",
    "name": "Saint-Brevin-les-Pins",
    "lat": "47.25",
    "lng": "-2.16667"
  },
  {
    "country": "FR",
    "name": "Saint-Brès",
    "lat": "43.66742",
    "lng": "4.03105"
  },
  {
    "country": "FR",
    "name": "Saint-Brandan",
    "lat": "48.39008",
    "lng": "-2.86875"
  },
  {
    "country": "FR",
    "name": "Saint-Branchs",
    "lat": "47.22655",
    "lng": "0.77306"
  },
  {
    "country": "FR",
    "name": "Saint-Bon-Tarentaise",
    "lat": "45.43373",
    "lng": "6.63686"
  },
  {
    "country": "FR",
    "name": "Saint-Bonnet-près-Riom",
    "lat": "45.92895",
    "lng": "3.11162"
  },
  {
    "country": "FR",
    "name": "Saint-Bonnet-les-Oules",
    "lat": "45.5425",
    "lng": "4.33145"
  },
  {
    "country": "FR",
    "name": "Saint-Bonnet-le-Château",
    "lat": "45.42338",
    "lng": "4.06673"
  },
  {
    "country": "FR",
    "name": "Saint-Bonnet-de-Mure",
    "lat": "45.69958",
    "lng": "5.02026"
  },
  {
    "country": "FR",
    "name": "Saint-Bonnet-en-Champsaur",
    "lat": "44.68333",
    "lng": "6.08333"
  },
  {
    "country": "FR",
    "name": "Saint-Berthevin",
    "lat": "48.06667",
    "lng": "-0.83333"
  },
  {
    "country": "FR",
    "name": "Saint-Béron",
    "lat": "45.50141",
    "lng": "5.73012"
  },
  {
    "country": "FR",
    "name": "Saint-Berain-sous-Sanvignes",
    "lat": "46.70678",
    "lng": "4.29405"
  },
  {
    "country": "FR",
    "name": "Saint-Benoît-sur-Loire",
    "lat": "47.80561",
    "lng": "2.31274"
  },
  {
    "country": "FR",
    "name": "Saint-Benoît-de-Carmaux",
    "lat": "44.05037",
    "lng": "2.12911"
  },
  {
    "country": "FR",
    "name": "Saint-Benoît",
    "lat": "46.55315",
    "lng": "0.3419"
  },
  {
    "country": "FR",
    "name": "Saint-Benin-d’Azy",
    "lat": "46.99914",
    "lng": "3.39267"
  },
  {
    "country": "FR",
    "name": "Saint-Beauzire",
    "lat": "45.84934",
    "lng": "3.17913"
  },
  {
    "country": "FR",
    "name": "Saint-Bauzille-de-Putois",
    "lat": "43.89454",
    "lng": "3.7358"
  },
  {
    "country": "FR",
    "name": "Saint-Baudelle",
    "lat": "48.28081",
    "lng": "-0.63728"
  },
  {
    "country": "FR",
    "name": "Saint-Barthélemy-de-Vals",
    "lat": "45.16729",
    "lng": "4.86977"
  },
  {
    "country": "FR",
    "name": "Saint-Barnabé",
    "lat": "43.3",
    "lng": "5.41667"
  },
  {
    "country": "FR",
    "name": "Saint-Barnabé",
    "lat": "48.13712",
    "lng": "-2.70483"
  },
  {
    "country": "FR",
    "name": "Saint-Baldoph",
    "lat": "45.5312",
    "lng": "5.95217"
  },
  {
    "country": "FR",
    "name": "Saint-Ay",
    "lat": "47.8589",
    "lng": "1.75137"
  },
  {
    "country": "FR",
    "name": "Saint-Avold",
    "lat": "49.10465",
    "lng": "6.70402"
  },
  {
    "country": "FR",
    "name": "Saint-Avertin",
    "lat": "47.36357",
    "lng": "0.73993"
  },
  {
    "country": "FR",
    "name": "Saint-Avé",
    "lat": "47.69085",
    "lng": "-2.74648"
  },
  {
    "country": "FR",
    "name": "Saint-Aupre",
    "lat": "45.38333",
    "lng": "5.66667"
  },
  {
    "country": "FR",
    "name": "Saint-Aunès",
    "lat": "43.64083",
    "lng": "3.96583"
  },
  {
    "country": "FR",
    "name": "Saint-Aulaye",
    "lat": "45.2",
    "lng": "0.13333"
  },
  {
    "country": "FR",
    "name": "Saint-Augustin",
    "lat": "48.78333",
    "lng": "3.03016"
  },
  {
    "country": "FR",
    "name": "Saint-Aubin-sur-Scie",
    "lat": "49.87162",
    "lng": "1.06823"
  },
  {
    "country": "FR",
    "name": "Saint-Aubin-sur-Mer",
    "lat": "49.32787",
    "lng": "-0.38696"
  },
  {
    "country": "FR",
    "name": "Saint-Aubin-sur-Gaillon",
    "lat": "49.14701",
    "lng": "1.32914"
  },
  {
    "country": "FR",
    "name": "Saint-Aubin-Routot",
    "lat": "49.52341",
    "lng": "0.32602"
  },
  {
    "country": "FR",
    "name": "Saint-Aubin-lès-Elbeuf",
    "lat": "49.3036",
    "lng": "1.01056"
  },
  {
    "country": "FR",
    "name": "Saint-Aubin-le-Cloud",
    "lat": "46.65308",
    "lng": "-0.35258"
  },
  {
    "country": "FR",
    "name": "Saint-Aubin-en-Bray",
    "lat": "49.42051",
    "lng": "1.87782"
  },
  {
    "country": "FR",
    "name": "Saint-Aubin-du-Cormier",
    "lat": "48.25843",
    "lng": "-1.40252"
  },
  {
    "country": "FR",
    "name": "Saint-Aubin-des-Ormeaux",
    "lat": "46.99238",
    "lng": "-1.04274"
  },
  {
    "country": "FR",
    "name": "Saint-Aubin-des-Châteaux",
    "lat": "47.72047",
    "lng": "-1.48876"
  },
  {
    "country": "FR",
    "name": "Saint-Aubin-des-Bois",
    "lat": "48.46549",
    "lng": "1.35784"
  },
  {
    "country": "FR",
    "name": "Saint-Aubin-de-Médoc",
    "lat": "44.9118",
    "lng": "-0.7246"
  },
  {
    "country": "FR",
    "name": "Saint-Aubin",
    "lat": "47.03336",
    "lng": "5.32666"
  },
  {
    "country": "FR",
    "name": "Saint-Aubert",
    "lat": "50.20805",
    "lng": "3.41727"
  },
  {
    "country": "FR",
    "name": "Saint-Astier",
    "lat": "45.14582",
    "lng": "0.52898"
  },
  {
    "country": "FR",
    "name": "Saint-Arnoult-en-Yvelines",
    "lat": "48.57111",
    "lng": "1.9395"
  },
  {
    "country": "FR",
    "name": "Saint-Arnoult",
    "lat": "49.52676",
    "lng": "0.67117"
  },
  {
    "country": "FR",
    "name": "Saint-Armel",
    "lat": "48.01305",
    "lng": "-1.59152"
  },
  {
    "country": "FR",
    "name": "Saint-Apollinaire",
    "lat": "47.33333",
    "lng": "5.08333"
  },
  {
    "country": "FR",
    "name": "Saint-Antoine-du-Rocher",
    "lat": "47.49677",
    "lng": "0.62997"
  },
  {
    "country": "FR",
    "name": "Saint-Antoine-de-Breuilh",
    "lat": "44.83333",
    "lng": "0.16667"
  },
  {
    "country": "FR",
    "name": "Saint-Antoine-l'Abbaye",
    "lat": "45.16667",
    "lng": "5.21667"
  },
  {
    "country": "FR",
    "name": "Saint-Antoine",
    "lat": "43.37087",
    "lng": "5.35888"
  },
  {
    "country": "FR",
    "name": "Saint-André-Treize-Voies",
    "lat": "46.93369",
    "lng": "-1.41274"
  },
  {
    "country": "FR",
    "name": "Saint-André-sur-Vieux-Jonc",
    "lat": "46.15",
    "lng": "5.06667"
  },
  {
    "country": "FR",
    "name": "Saint-André-sur-Orne",
    "lat": "49.11741",
    "lng": "-0.38227"
  },
  {
    "country": "FR",
    "name": "Saint-André-les-Vergers",
    "lat": "48.28527",
    "lng": "4.0521"
  },
  {
    "country": "FR",
    "name": "Saint-André-le-Puy",
    "lat": "45.64458",
    "lng": "4.25744"
  },
  {
    "country": "FR",
    "name": "Saint-André-le-Gaz",
    "lat": "45.54943",
    "lng": "5.53503"
  },
  {
    "country": "FR",
    "name": "Saint-André-de-Seignanx",
    "lat": "43.558",
    "lng": "-1.35183"
  },
  {
    "country": "FR",
    "name": "Saint-André-des-Eaux",
    "lat": "47.31461",
    "lng": "-2.31105"
  },
  {
    "country": "FR",
    "name": "Saint-André-de-Sangonis",
    "lat": "43.64753",
    "lng": "3.50209"
  },
  {
    "country": "FR",
    "name": "Saint-André-de-la-Marche",
    "lat": "47.09952",
    "lng": "-0.99441"
  },
  {
    "country": "FR",
    "name": "Saint-André-de-Corcy",
    "lat": "45.9259",
    "lng": "4.95166"
  },
  {
    "country": "FR",
    "name": "Saint-André-lez-Lille",
    "lat": "50.66667",
    "lng": "3.05"
  },
  {
    "country": "FR",
    "name": "Saint-André-de-la-Roche",
    "lat": "43.73333",
    "lng": "7.28333"
  },
  {
    "country": "FR",
    "name": "Saint-André",
    "lat": "43.3563",
    "lng": "5.34335"
  },
  {
    "country": "FR",
    "name": "Sant Andreu de Sureda",
    "lat": "42.55201",
    "lng": "2.97129"
  },
  {
    "country": "FR",
    "name": "Saint-Andiol",
    "lat": "43.83484",
    "lng": "4.94453"
  },
  {
    "country": "FR",
    "name": "Saint-Andéol-le-Château",
    "lat": "45.58703",
    "lng": "4.69495"
  },
  {
    "country": "FR",
    "name": "Saint-Amour",
    "lat": "46.43638",
    "lng": "5.34416"
  },
  {
    "country": "FR",
    "name": "Saint-Amé",
    "lat": "48.02388",
    "lng": "6.66416"
  },
  {
    "country": "FR",
    "name": "Saint-Ambroix",
    "lat": "44.25893",
    "lng": "4.19833"
  },
  {
    "country": "FR",
    "name": "Saint-Amarin",
    "lat": "47.87335",
    "lng": "7.03193"
  },
  {
    "country": "FR",
    "name": "Saint-Amant-Tallende",
    "lat": "45.66839",
    "lng": "3.1101"
  },
  {
    "country": "FR",
    "name": "Saint-Amant-de-Boixe",
    "lat": "45.7979",
    "lng": "0.13524"
  },
  {
    "country": "FR",
    "name": "Saint-Amans-Valtoret",
    "lat": "43.48071",
    "lng": "2.49095"
  },
  {
    "country": "FR",
    "name": "Saint-Amans-Soult",
    "lat": "43.47697",
    "lng": "2.49076"
  },
  {
    "country": "FR",
    "name": "Saint-Amand-sur-Sèvre",
    "lat": "46.86905",
    "lng": "-0.79441"
  },
  {
    "country": "FR",
    "name": "Saint-Amand-Montrond",
    "lat": "46.71667",
    "lng": "2.51667"
  },
  {
    "country": "FR",
    "name": "Saint-Amand-les-Eaux",
    "lat": "50.44718",
    "lng": "3.43076"
  },
  {
    "country": "FR",
    "name": "Saint-Amand-en-Puisaye",
    "lat": "47.52913",
    "lng": "3.074"
  },
  {
    "country": "FR",
    "name": "Saint-Amand-Longpré",
    "lat": "47.68333",
    "lng": "1.01667"
  },
  {
    "country": "FR",
    "name": "Saint-Amand",
    "lat": "49.04338",
    "lng": "-0.96491"
  },
  {
    "country": "FR",
    "name": "Saint-Alexandre",
    "lat": "44.22741",
    "lng": "4.62081"
  },
  {
    "country": "FR",
    "name": "Saint-Alban-sur-Limagnole",
    "lat": "44.781",
    "lng": "3.38793"
  },
  {
    "country": "FR",
    "name": "Saint-Alban-de-Roche",
    "lat": "45.59526",
    "lng": "5.22304"
  },
  {
    "country": "FR",
    "name": "Saint-Alban",
    "lat": "48.5563",
    "lng": "-2.54013"
  },
  {
    "country": "FR",
    "name": "Saint-Alban-Leysse",
    "lat": "45.58333",
    "lng": "5.95"
  },
  {
    "country": "FR",
    "name": "Saint-Alban",
    "lat": "43.6927",
    "lng": "1.4102"
  },
  {
    "country": "FR",
    "name": "Saint-Aigulin",
    "lat": "45.15735",
    "lng": "-0.00863"
  },
  {
    "country": "FR",
    "name": "Saint-Aignan",
    "lat": "47.26892",
    "lng": "1.37614"
  },
  {
    "country": "FR",
    "name": "Saint-Agrève",
    "lat": "45.00993",
    "lng": "4.39375"
  },
  {
    "country": "FR",
    "name": "Saint-Agnant-de-Versillat",
    "lat": "46.278",
    "lng": "1.50962"
  },
  {
    "country": "FR",
    "name": "Saint-Agnant",
    "lat": "45.87354",
    "lng": "-0.96119"
  },
  {
    "country": "FR",
    "name": "Saint-Agathon",
    "lat": "48.55867",
    "lng": "-3.10525"
  },
  {
    "country": "FR",
    "name": "Saint-Affrique",
    "lat": "43.95575",
    "lng": "2.88915"
  },
  {
    "country": "FR",
    "name": "Sains-en-Gohelle",
    "lat": "50.44512",
    "lng": "2.68301"
  },
  {
    "country": "FR",
    "name": "Sains-en-Amiénois",
    "lat": "49.81716",
    "lng": "2.31862"
  },
  {
    "country": "FR",
    "name": "Sains-du-Nord",
    "lat": "50.09377",
    "lng": "4.00898"
  },
  {
    "country": "FR",
    "name": "Sainghin-en-Weppes",
    "lat": "50.56407",
    "lng": "2.89804"
  },
  {
    "country": "FR",
    "name": "Sainghin-en-Mélantois",
    "lat": "50.58836",
    "lng": "3.16619"
  },
  {
    "country": "FR",
    "name": "Sain-Bel",
    "lat": "45.8107",
    "lng": "4.59815"
  },
  {
    "country": "FR",
    "name": "Sail-sous-Couzan",
    "lat": "45.73482",
    "lng": "3.96898"
  },
  {
    "country": "FR",
    "name": "Sailly-sur-la-Lys",
    "lat": "50.6582",
    "lng": "2.76872"
  },
  {
    "country": "FR",
    "name": "Sailly-lez-Lannoy",
    "lat": "50.65",
    "lng": "3.21667"
  },
  {
    "country": "FR",
    "name": "Sailly-Labourse",
    "lat": "50.5012",
    "lng": "2.69708"
  },
  {
    "country": "FR",
    "name": "Sailly-Flibeaucourt",
    "lat": "50.18419",
    "lng": "1.7718"
  },
  {
    "country": "FR",
    "name": "Saignon",
    "lat": "43.86182",
    "lng": "5.42782"
  },
  {
    "country": "FR",
    "name": "Sahurs",
    "lat": "49.35863",
    "lng": "0.94256"
  },
  {
    "country": "FR",
    "name": "Sagy",
    "lat": "49.04988",
    "lng": "1.95216"
  },
  {
    "country": "FR",
    "name": "Sagy",
    "lat": "46.60129",
    "lng": "5.31045"
  },
  {
    "country": "FR",
    "name": "Saffré",
    "lat": "47.50143",
    "lng": "-1.57856"
  },
  {
    "country": "FR",
    "name": "Sadirac",
    "lat": "44.78179",
    "lng": "-0.41334"
  },
  {
    "country": "FR",
    "name": "Sacy-le-Grand",
    "lat": "49.35479",
    "lng": "2.54461"
  },
  {
    "country": "FR",
    "name": "Saclay",
    "lat": "48.7326",
    "lng": "2.16923"
  },
  {
    "country": "FR",
    "name": "Saclas",
    "lat": "48.35845",
    "lng": "2.12349"
  },
  {
    "country": "FR",
    "name": "Saché",
    "lat": "47.24707",
    "lng": "0.54455"
  },
  {
    "country": "FR",
    "name": "Sabres",
    "lat": "44.14896",
    "lng": "-0.74123"
  },
  {
    "country": "FR",
    "name": "Sabran",
    "lat": "44.1504",
    "lng": "4.5482"
  },
  {
    "country": "FR",
    "name": "Sablons",
    "lat": "45.32073",
    "lng": "4.77501"
  },
  {
    "country": "FR",
    "name": "Sablons",
    "lat": "45.03333",
    "lng": "-0.18333"
  },
  {
    "country": "FR",
    "name": "Sablonceaux",
    "lat": "45.70963",
    "lng": "-0.88806"
  },
  {
    "country": "FR",
    "name": "Sablet",
    "lat": "44.19056",
    "lng": "5.00613"
  },
  {
    "country": "FR",
    "name": "Sablé-sur-Sarthe",
    "lat": "47.83765",
    "lng": "-0.33294"
  },
  {
    "country": "FR",
    "name": "Saâcy-sur-Marne",
    "lat": "48.9621",
    "lng": "3.21083"
  },
  {
    "country": "FR",
    "name": "Ruy",
    "lat": "45.58772",
    "lng": "5.3189"
  },
  {
    "country": "FR",
    "name": "Russange",
    "lat": "49.48283",
    "lng": "5.95204"
  },
  {
    "country": "FR",
    "name": "Russ",
    "lat": "48.496",
    "lng": "7.25911"
  },
  {
    "country": "FR",
    "name": "Rurange-lès-Thionville",
    "lat": "49.27599",
    "lng": "6.23184"
  },
  {
    "country": "FR",
    "name": "Rupt-sur-Moselle",
    "lat": "47.92271",
    "lng": "6.66291"
  },
  {
    "country": "FR",
    "name": "Ruoms",
    "lat": "44.45351",
    "lng": "4.34265"
  },
  {
    "country": "FR",
    "name": "Rungis",
    "lat": "48.74607",
    "lng": "2.35275"
  },
  {
    "country": "FR",
    "name": "Ruminghem",
    "lat": "50.85922",
    "lng": "2.15838"
  },
  {
    "country": "FR",
    "name": "Rumilly-en-Cambrésis",
    "lat": "50.12691",
    "lng": "3.21874"
  },
  {
    "country": "FR",
    "name": "Rumilly",
    "lat": "45.86873",
    "lng": "5.93652"
  },
  {
    "country": "FR",
    "name": "Rumersheim-le-Haut",
    "lat": "47.85127",
    "lng": "7.52133"
  },
  {
    "country": "FR",
    "name": "Rumegies",
    "lat": "50.48877",
    "lng": "3.35131"
  },
  {
    "country": "FR",
    "name": "Rully",
    "lat": "46.87499",
    "lng": "4.74322"
  },
  {
    "country": "FR",
    "name": "Ruitz",
    "lat": "50.46643",
    "lng": "2.58876"
  },
  {
    "country": "FR",
    "name": "Ruillé-sur-Loir",
    "lat": "47.75075",
    "lng": "0.62058"
  },
  {
    "country": "FR",
    "name": "Rugles",
    "lat": "48.82212",
    "lng": "0.70979"
  },
  {
    "country": "FR",
    "name": "Ruffiac",
    "lat": "47.81866",
    "lng": "-2.28238"
  },
  {
    "country": "FR",
    "name": "Ruffey-lès-Echirey",
    "lat": "47.36667",
    "lng": "5.08333"
  },
  {
    "country": "FR",
    "name": "Ruffec",
    "lat": "46.02877",
    "lng": "0.19821"
  },
  {
    "country": "FR",
    "name": "Ruelle-sur-Touvre",
    "lat": "45.68333",
    "lng": "0.23333"
  },
  {
    "country": "FR",
    "name": "Ruelisheim",
    "lat": "47.82306",
    "lng": "7.3594"
  },
  {
    "country": "FR",
    "name": "Rueil-Malmaison",
    "lat": "48.8765",
    "lng": "2.18967"
  },
  {
    "country": "FR",
    "name": "Rue",
    "lat": "50.2715",
    "lng": "1.67163"
  },
  {
    "country": "FR",
    "name": "Rubelles",
    "lat": "48.55327",
    "lng": "2.67593"
  },
  {
    "country": "FR",
    "name": "Ruaudin",
    "lat": "47.94509",
    "lng": "0.2676"
  },
  {
    "country": "FR",
    "name": "Roz-sur-Couesnon",
    "lat": "48.58867",
    "lng": "-1.59213"
  },
  {
    "country": "FR",
    "name": "Rozoy-sur-Serre",
    "lat": "49.70956",
    "lng": "4.12902"
  },
  {
    "country": "FR",
    "name": "Roz-Landrieux",
    "lat": "48.54337",
    "lng": "-1.81586"
  },
  {
    "country": "FR",
    "name": "Rozier-en-Donzy",
    "lat": "45.7965",
    "lng": "4.27344"
  },
  {
    "country": "FR",
    "name": "Rozérieulles",
    "lat": "49.10668",
    "lng": "6.08198"
  },
  {
    "country": "FR",
    "name": "Rozay-en-Brie",
    "lat": "48.68333",
    "lng": "2.95816"
  },
  {
    "country": "FR",
    "name": "Roye",
    "lat": "49.70038",
    "lng": "2.78959"
  },
  {
    "country": "FR",
    "name": "Roye",
    "lat": "47.66995",
    "lng": "6.54139"
  },
  {
    "country": "FR",
    "name": "Roybon",
    "lat": "45.25966",
    "lng": "5.24455"
  },
  {
    "country": "FR",
    "name": "Royat",
    "lat": "45.76379",
    "lng": "3.04955"
  },
  {
    "country": "FR",
    "name": "Royan",
    "lat": "45.62846",
    "lng": "-1.0281"
  },
  {
    "country": "FR",
    "name": "Rouziers-de-Touraine",
    "lat": "47.5172",
    "lng": "0.64848"
  },
  {
    "country": "FR",
    "name": "Rouxmesnil-Bouteilles",
    "lat": "49.90633",
    "lng": "1.07976"
  },
  {
    "country": "FR",
    "name": "Rouvroy",
    "lat": "50.39247",
    "lng": "2.90396"
  },
  {
    "country": "FR",
    "name": "Routot",
    "lat": "49.378",
    "lng": "0.73346"
  },
  {
    "country": "FR",
    "name": "Rousson",
    "lat": "44.19136",
    "lng": "4.14786"
  },
  {
    "country": "FR",
    "name": "Roussillon",
    "lat": "45.37302",
    "lng": "4.80725"
  },
  {
    "country": "FR",
    "name": "Roussillon",
    "lat": "43.90084",
    "lng": "5.2947"
  },
  {
    "country": "FR",
    "name": "Rousset",
    "lat": "43.48307",
    "lng": "5.61959"
  },
  {
    "country": "FR",
    "name": "Roussay",
    "lat": "47.09011",
    "lng": "-1.06417"
  },
  {
    "country": "FR",
    "name": "Rousies",
    "lat": "50.27346",
    "lng": "4.00382"
  },
  {
    "country": "FR",
    "name": "Roumazières-Loubert",
    "lat": "45.8869",
    "lng": "0.58125"
  },
  {
    "country": "FR",
    "name": "Roumare",
    "lat": "49.51008",
    "lng": "0.97422"
  },
  {
    "country": "FR",
    "name": "Roullet-Saint-Estèphe",
    "lat": "45.58333",
    "lng": "0.05"
  },
  {
    "country": "FR",
    "name": "Roulans",
    "lat": "47.31553",
    "lng": "6.22901"
  },
  {
    "country": "FR",
    "name": "Roujan",
    "lat": "43.50489",
    "lng": "3.31071"
  },
  {
    "country": "FR",
    "name": "Rouillon",
    "lat": "48.00629",
    "lng": "0.13527"
  },
  {
    "country": "FR",
    "name": "Rouillé",
    "lat": "46.42024",
    "lng": "0.04073"
  },
  {
    "country": "FR",
    "name": "Rouillac",
    "lat": "45.77582",
    "lng": "-0.0638"
  },
  {
    "country": "FR",
    "name": "Rouhling",
    "lat": "49.13888",
    "lng": "7.00446"
  },
  {
    "country": "FR",
    "name": "Rougiers",
    "lat": "43.39233",
    "lng": "5.85144"
  },
  {
    "country": "FR",
    "name": "Rougemont-le-Château",
    "lat": "47.73389",
    "lng": "6.96899"
  },
  {
    "country": "FR",
    "name": "Rougemont",
    "lat": "47.48211",
    "lng": "6.35574"
  },
  {
    "country": "FR",
    "name": "Rougé",
    "lat": "47.78367",
    "lng": "-1.44763"
  },
  {
    "country": "FR",
    "name": "Rouffignac-Saint-Cernin-de-Reilhac",
    "lat": "45.05",
    "lng": "0.96667"
  },
  {
    "country": "FR",
    "name": "Rouffiac-Tolosan",
    "lat": "43.66576",
    "lng": "1.52521"
  },
  {
    "country": "FR",
    "name": "Rouffach",
    "lat": "47.95786",
    "lng": "7.30016"
  },
  {
    "country": "FR",
    "name": "Rouen",
    "lat": "49.44313",
    "lng": "1.09932"
  },
  {
    "country": "FR",
    "name": "Roubaix",
    "lat": "50.69421",
    "lng": "3.17456"
  },
  {
    "country": "FR",
    "name": "Rouans",
    "lat": "47.18321",
    "lng": "-1.85929"
  },
  {
    "country": "FR",
    "name": "Rots",
    "lat": "49.21235",
    "lng": "-0.47319"
  },
  {
    "country": "FR",
    "name": "Rothau",
    "lat": "48.45687",
    "lng": "7.20772"
  },
  {
    "country": "FR",
    "name": "Rosult",
    "lat": "50.45888",
    "lng": "3.35902"
  },
  {
    "country": "FR",
    "name": "Rostrenen",
    "lat": "48.23696",
    "lng": "-3.31442"
  },
  {
    "country": "FR",
    "name": "Rosselange",
    "lat": "49.2578",
    "lng": "6.0689"
  },
  {
    "country": "FR",
    "name": "Rosporden",
    "lat": "47.96667",
    "lng": "-3.83333"
  },
  {
    "country": "FR",
    "name": "Rospez",
    "lat": "48.7294",
    "lng": "-3.38364"
  },
  {
    "country": "FR",
    "name": "Rosny-sur-Seine",
    "lat": "48.99808",
    "lng": "1.6313"
  },
  {
    "country": "FR",
    "name": "Rosny-sous-Bois",
    "lat": "48.87017",
    "lng": "2.4991"
  },
  {
    "country": "FR",
    "name": "Rosières-près-Troyes",
    "lat": "48.26182",
    "lng": "4.07396"
  },
  {
    "country": "FR",
    "name": "Rosières-en-Santerre",
    "lat": "49.81433",
    "lng": "2.70095"
  },
  {
    "country": "FR",
    "name": "Rosières-aux-Salines",
    "lat": "48.5929",
    "lng": "6.33208"
  },
  {
    "country": "FR",
    "name": "Rosières",
    "lat": "45.13233",
    "lng": "3.98768"
  },
  {
    "country": "FR",
    "name": "Rosières",
    "lat": "44.48307",
    "lng": "4.25598"
  },
  {
    "country": "FR",
    "name": "Rosheim",
    "lat": "48.4971",
    "lng": "7.47105"
  },
  {
    "country": "FR",
    "name": "Rosenau",
    "lat": "47.63471",
    "lng": "7.54099"
  },
  {
    "country": "FR",
    "name": "Roscoff",
    "lat": "48.72381",
    "lng": "-3.98709"
  },
  {
    "country": "FR",
    "name": "Roscanvel",
    "lat": "48.3152",
    "lng": "-4.54937"
  },
  {
    "country": "FR",
    "name": "Roquevaire",
    "lat": "43.35021",
    "lng": "5.60414"
  },
  {
    "country": "FR",
    "name": "Roquettes",
    "lat": "43.49733",
    "lng": "1.36848"
  },
  {
    "country": "FR",
    "name": "Roquetoire",
    "lat": "50.67029",
    "lng": "2.34307"
  },
  {
    "country": "FR",
    "name": "Roquemaure",
    "lat": "44.04944",
    "lng": "4.7774"
  },
  {
    "country": "FR",
    "name": "Roquefort-la-Bédoule",
    "lat": "43.24883",
    "lng": "5.59015"
  },
  {
    "country": "FR",
    "name": "Roquefort",
    "lat": "44.1753",
    "lng": "0.56107"
  },
  {
    "country": "FR",
    "name": "Roquefort",
    "lat": "44.035",
    "lng": "-0.32323"
  },
  {
    "country": "FR",
    "name": "Roquecourbe",
    "lat": "43.66442",
    "lng": "2.29264"
  },
  {
    "country": "FR",
    "name": "Roquebrune-sur-Argens",
    "lat": "43.43333",
    "lng": "6.63333"
  },
  {
    "country": "FR",
    "name": "Roquebrune-Cap-Martin",
    "lat": "43.76408",
    "lng": "7.48207"
  },
  {
    "country": "FR",
    "name": "Roquebillière",
    "lat": "44.0125",
    "lng": "7.30748"
  },
  {
    "country": "FR",
    "name": "Roost-Warendin",
    "lat": "50.4192",
    "lng": "3.10374"
  },
  {
    "country": "FR",
    "name": "Roncq",
    "lat": "50.7533",
    "lng": "3.12131"
  },
  {
    "country": "FR",
    "name": "Ronchin",
    "lat": "50.59883",
    "lng": "3.09056"
  },
  {
    "country": "FR",
    "name": "Roncherolles-sur-le-Vivier",
    "lat": "49.46667",
    "lng": "1.18333"
  },
  {
    "country": "FR",
    "name": "Ronchamp",
    "lat": "47.70063",
    "lng": "6.63591"
  },
  {
    "country": "FR",
    "name": "Romorantin-Lanthenay",
    "lat": "47.36667",
    "lng": "1.75"
  },
  {
    "country": "FR",
    "name": "Romilly-sur-Seine",
    "lat": "48.51085",
    "lng": "3.72634"
  },
  {
    "country": "FR",
    "name": "Romilly-sur-Andelle",
    "lat": "49.3319",
    "lng": "1.26127"
  },
  {
    "country": "FR",
    "name": "Romillé",
    "lat": "48.21619",
    "lng": "-1.89229"
  },
  {
    "country": "FR",
    "name": "Romenay",
    "lat": "46.50208",
    "lng": "5.06904"
  },
  {
    "country": "FR",
    "name": "Rombas",
    "lat": "49.24946",
    "lng": "6.09398"
  },
  {
    "country": "FR",
    "name": "Romanswiller",
    "lat": "48.64556",
    "lng": "7.40762"
  },
  {
    "country": "FR",
    "name": "Romans-sur-Isère",
    "lat": "45.04639",
    "lng": "5.0562"
  },
  {
    "country": "FR",
    "name": "Romanèche-Thorins",
    "lat": "46.18402",
    "lng": "4.74242"
  },
  {
    "country": "FR",
    "name": "Romainville",
    "lat": "48.8854",
    "lng": "2.43482"
  },
  {
    "country": "FR",
    "name": "Romagny",
    "lat": "48.63931",
    "lng": "-0.96605"
  },
  {
    "country": "FR",
    "name": "Romagnieu",
    "lat": "45.5704",
    "lng": "5.64002"
  },
  {
    "country": "FR",
    "name": "Romagné",
    "lat": "48.34019",
    "lng": "-1.27751"
  },
  {
    "country": "FR",
    "name": "Romagnat",
    "lat": "45.72878",
    "lng": "3.09893"
  },
  {
    "country": "FR",
    "name": "Rolleville",
    "lat": "49.58232",
    "lng": "0.21177"
  },
  {
    "country": "FR",
    "name": "Rolampont",
    "lat": "47.94951",
    "lng": "5.2856"
  },
  {
    "country": "FR",
    "name": "Roissy-en-France",
    "lat": "49.00443",
    "lng": "2.51703"
  },
  {
    "country": "FR",
    "name": "Roissy-en-Brie",
    "lat": "48.79159",
    "lng": "2.64747"
  },
  {
    "country": "FR",
    "name": "Roisel",
    "lat": "49.94768",
    "lng": "3.09973"
  },
  {
    "country": "FR",
    "name": "Roiffieux",
    "lat": "45.22647",
    "lng": "4.65502"
  },
  {
    "country": "FR",
    "name": "Rohrbach-lès-Bitche",
    "lat": "49.04424",
    "lng": "7.26759"
  },
  {
    "country": "FR",
    "name": "Rohan",
    "lat": "48.06833",
    "lng": "-2.7512"
  },
  {
    "country": "FR",
    "name": "Rognonas",
    "lat": "43.89993",
    "lng": "4.80369"
  },
  {
    "country": "FR",
    "name": "Rognes",
    "lat": "43.66418",
    "lng": "5.34801"
  },
  {
    "country": "FR",
    "name": "Rognac",
    "lat": "43.48761",
    "lng": "5.23387"
  },
  {
    "country": "FR",
    "name": "Rogerville",
    "lat": "49.50296",
    "lng": "0.26516"
  },
  {
    "country": "FR",
    "name": "Roézé-sur-Sarthe",
    "lat": "47.89546",
    "lng": "0.06723"
  },
  {
    "country": "FR",
    "name": "Rœux",
    "lat": "50.29526",
    "lng": "2.90073"
  },
  {
    "country": "FR",
    "name": "Rœulx",
    "lat": "50.3",
    "lng": "3.33333"
  },
  {
    "country": "FR",
    "name": "Roeschwoog",
    "lat": "48.82676",
    "lng": "8.03684"
  },
  {
    "country": "FR",
    "name": "Rodilhan",
    "lat": "43.82725",
    "lng": "4.43088"
  },
  {
    "country": "FR",
    "name": "Rodez",
    "lat": "44.35258",
    "lng": "2.57338"
  },
  {
    "country": "FR",
    "name": "Rocroi",
    "lat": "49.9261",
    "lng": "4.5222"
  },
  {
    "country": "FR",
    "name": "Rocquencourt",
    "lat": "48.83783",
    "lng": "2.10228"
  },
  {
    "country": "FR",
    "name": "Rochetaillée-sur-Saône",
    "lat": "45.85",
    "lng": "4.85"
  },
  {
    "country": "FR",
    "name": "Roches-Prémarie-Andillé",
    "lat": "46.48251",
    "lng": "0.37106"
  },
  {
    "country": "FR",
    "name": "Rocheservière",
    "lat": "46.93765",
    "lng": "-1.51143"
  },
  {
    "country": "FR",
    "name": "Rochemaure",
    "lat": "44.58747",
    "lng": "4.70507"
  },
  {
    "country": "FR",
    "name": "Roche-lez-Beaupré",
    "lat": "47.28333",
    "lng": "6.11667"
  },
  {
    "country": "FR",
    "name": "Roche-la-Molière",
    "lat": "45.43408",
    "lng": "4.32277"
  },
  {
    "country": "FR",
    "name": "Rochegude",
    "lat": "44.24859",
    "lng": "4.82922"
  },
  {
    "country": "FR",
    "name": "Rochefort-sur-Loire",
    "lat": "47.35705",
    "lng": "-0.65696"
  },
  {
    "country": "FR",
    "name": "Rochefort-du-Gard",
    "lat": "43.97652",
    "lng": "4.69023"
  },
  {
    "country": "FR",
    "name": "Rochefort",
    "lat": "45.93333",
    "lng": "-0.98333"
  },
  {
    "country": "FR",
    "name": "Rochecorbon",
    "lat": "47.41658",
    "lng": "0.75521"
  },
  {
    "country": "FR",
    "name": "Rochechouart",
    "lat": "45.81667",
    "lng": "0.81667"
  },
  {
    "country": "FR",
    "name": "Roche",
    "lat": "45.58709",
    "lng": "5.15965"
  },
  {
    "country": "FR",
    "name": "Rocbaron",
    "lat": "43.30449",
    "lng": "6.09059"
  },
  {
    "country": "FR",
    "name": "Robion",
    "lat": "43.84707",
    "lng": "5.10975"
  },
  {
    "country": "FR",
    "name": "Robecq",
    "lat": "50.59608",
    "lng": "2.56262"
  },
  {
    "country": "FR",
    "name": "Roanne",
    "lat": "46.03333",
    "lng": "4.06667"
  },
  {
    "country": "FR",
    "name": "Rixheim",
    "lat": "47.7514",
    "lng": "7.40091"
  },
  {
    "country": "FR",
    "name": "Rivière-Saas-et-Gourby",
    "lat": "43.6799",
    "lng": "-1.14986"
  },
  {
    "country": "FR",
    "name": "Rivières",
    "lat": "45.75295",
    "lng": "0.36128"
  },
  {
    "country": "FR",
    "name": "Rivière",
    "lat": "50.23316",
    "lng": "2.692"
  },
  {
    "country": "FR",
    "name": "Rivesaltes",
    "lat": "42.76945",
    "lng": "2.87239"
  },
  {
    "country": "FR",
    "name": "Rives",
    "lat": "45.35505",
    "lng": "5.49927"
  },
  {
    "country": "FR",
    "name": "Rivery",
    "lat": "49.90328",
    "lng": "2.32235"
  },
  {
    "country": "FR",
    "name": "Rivedoux-Plage",
    "lat": "46.15854",
    "lng": "-1.27093"
  },
  {
    "country": "FR",
    "name": "Rive-de-Gier",
    "lat": "45.52755",
    "lng": "4.61589"
  },
  {
    "country": "FR",
    "name": "Ris-Orangis",
    "lat": "48.6511",
    "lng": "2.41406"
  },
  {
    "country": "FR",
    "name": "Riscle",
    "lat": "43.65633",
    "lng": "-0.08607"
  },
  {
    "country": "FR",
    "name": "Riquewihr",
    "lat": "48.16672",
    "lng": "7.29707"
  },
  {
    "country": "FR",
    "name": "Rioz",
    "lat": "47.42521",
    "lng": "6.06598"
  },
  {
    "country": "FR",
    "name": "Riotord",
    "lat": "45.23226",
    "lng": "4.40376"
  },
  {
    "country": "FR",
    "name": "Riorges",
    "lat": "46.04179",
    "lng": "4.04965"
  },
  {
    "country": "FR",
    "name": "Rions",
    "lat": "44.66378",
    "lng": "-0.35113"
  },
  {
    "country": "FR",
    "name": "Rion-des-Landes",
    "lat": "43.93449",
    "lng": "-0.92388"
  },
  {
    "country": "FR",
    "name": "Riom-ès-Montagnes",
    "lat": "45.28333",
    "lng": "2.66667"
  },
  {
    "country": "FR",
    "name": "Riom",
    "lat": "45.9",
    "lng": "3.11667"
  },
  {
    "country": "FR",
    "name": "Rinxent",
    "lat": "50.80714",
    "lng": "1.72899"
  },
  {
    "country": "FR",
    "name": "Rimogne",
    "lat": "49.84075",
    "lng": "4.53941"
  },
  {
    "country": "FR",
    "name": "Rilly-la-Montagne",
    "lat": "49.16553",
    "lng": "4.04568"
  },
  {
    "country": "FR",
    "name": "Rillieux-la-Pape",
    "lat": "45.81667",
    "lng": "4.9"
  },
  {
    "country": "FR",
    "name": "Rilhac-Rancon",
    "lat": "45.9",
    "lng": "1.31667"
  },
  {
    "country": "FR",
    "name": "Rignac",
    "lat": "44.40853",
    "lng": "2.29001"
  },
  {
    "country": "FR",
    "name": "Riez",
    "lat": "43.81793",
    "lng": "6.09295"
  },
  {
    "country": "FR",
    "name": "Rieux-Minervois",
    "lat": "43.28194",
    "lng": "2.58687"
  },
  {
    "country": "FR",
    "name": "Rieux-en-Cambrésis",
    "lat": "50.20069",
    "lng": "3.35232"
  },
  {
    "country": "FR",
    "name": "Rieux",
    "lat": "49.3",
    "lng": "2.51667"
  },
  {
    "country": "FR",
    "name": "Rieux",
    "lat": "47.59781",
    "lng": "-2.10828"
  },
  {
    "country": "FR",
    "name": "Rieux-Volvestre",
    "lat": "43.25",
    "lng": "1.2"
  },
  {
    "country": "FR",
    "name": "Rieupeyroux",
    "lat": "44.30799",
    "lng": "2.23819"
  },
  {
    "country": "FR",
    "name": "Rieumes",
    "lat": "43.41143",
    "lng": "1.11702"
  },
  {
    "country": "FR",
    "name": "Rieulay",
    "lat": "50.37856",
    "lng": "3.25284"
  },
  {
    "country": "FR",
    "name": "Riedisheim",
    "lat": "47.74757",
    "lng": "7.36665"
  },
  {
    "country": "FR",
    "name": "Riec-sur-Belon",
    "lat": "47.83333",
    "lng": "-3.7"
  },
  {
    "country": "FR",
    "name": "Richwiller",
    "lat": "47.77948",
    "lng": "7.28225"
  },
  {
    "country": "FR",
    "name": "Richemont",
    "lat": "49.27723",
    "lng": "6.16372"
  },
  {
    "country": "FR",
    "name": "Richelieu",
    "lat": "47.01389",
    "lng": "0.32406"
  },
  {
    "country": "FR",
    "name": "Richebourg",
    "lat": "50.58333",
    "lng": "2.73333"
  },
  {
    "country": "FR",
    "name": "Richebourg-l'Avoué",
    "lat": "50.56999",
    "lng": "2.74884"
  },
  {
    "country": "FR",
    "name": "Richardménil",
    "lat": "48.59851",
    "lng": "6.16992"
  },
  {
    "country": "FR",
    "name": "Ribérac",
    "lat": "45.25",
    "lng": "0.33333"
  },
  {
    "country": "FR",
    "name": "Ribemont",
    "lat": "49.7954",
    "lng": "3.45893"
  },
  {
    "country": "FR",
    "name": "Ribeauvillé",
    "lat": "48.1951",
    "lng": "7.31938"
  },
  {
    "country": "FR",
    "name": "Ribaute-les-Tavernes",
    "lat": "44.03724",
    "lng": "4.08046"
  },
  {
    "country": "FR",
    "name": "Riantec",
    "lat": "47.71093",
    "lng": "-3.31629"
  },
  {
    "country": "FR",
    "name": "Rians",
    "lat": "47.17875",
    "lng": "2.61359"
  },
  {
    "country": "FR",
    "name": "Rians",
    "lat": "43.60659",
    "lng": "5.75589"
  },
  {
    "country": "FR",
    "name": "Riaillé",
    "lat": "47.51797",
    "lng": "-1.29404"
  },
  {
    "country": "FR",
    "name": "Ria-Sirach",
    "lat": "42.61667",
    "lng": "2.4"
  },
  {
    "country": "FR",
    "name": "Rhinau",
    "lat": "48.32017",
    "lng": "7.70527"
  },
  {
    "country": "FR",
    "name": "Rezé",
    "lat": "47.18144",
    "lng": "-1.54965"
  },
  {
    "country": "FR",
    "name": "Reyrieux",
    "lat": "45.93306",
    "lng": "4.82394"
  },
  {
    "country": "FR",
    "name": "Reynès",
    "lat": "42.47702",
    "lng": "2.7068"
  },
  {
    "country": "FR",
    "name": "Rexpoëde",
    "lat": "50.93926",
    "lng": "2.53914"
  },
  {
    "country": "FR",
    "name": "Revin",
    "lat": "49.94039",
    "lng": "4.63503"
  },
  {
    "country": "FR",
    "name": "Réville",
    "lat": "49.61906",
    "lng": "-1.25868"
  },
  {
    "country": "FR",
    "name": "Revigny-sur-Ornain",
    "lat": "48.83016",
    "lng": "4.98558"
  },
  {
    "country": "FR",
    "name": "Reventin-Vaugris",
    "lat": "45.4638",
    "lng": "4.83769"
  },
  {
    "country": "FR",
    "name": "Revel",
    "lat": "45.18646",
    "lng": "5.86852"
  },
  {
    "country": "FR",
    "name": "Revel",
    "lat": "43.45812",
    "lng": "2.00469"
  },
  {
    "country": "FR",
    "name": "Reuilly",
    "lat": "47.08476",
    "lng": "2.04305"
  },
  {
    "country": "FR",
    "name": "Reugny",
    "lat": "47.48208",
    "lng": "0.88468"
  },
  {
    "country": "FR",
    "name": "Rety",
    "lat": "50.8",
    "lng": "1.76667"
  },
  {
    "country": "FR",
    "name": "Retournac",
    "lat": "45.20629",
    "lng": "4.03554"
  },
  {
    "country": "FR",
    "name": "Retonfey",
    "lat": "49.13648",
    "lng": "6.30634"
  },
  {
    "country": "FR",
    "name": "Retiers",
    "lat": "47.91392",
    "lng": "-1.37967"
  },
  {
    "country": "FR",
    "name": "Rethel",
    "lat": "49.51667",
    "lng": "4.36667"
  },
  {
    "country": "FR",
    "name": "Restinclières",
    "lat": "43.72252",
    "lng": "4.03476"
  },
  {
    "country": "FR",
    "name": "Restigné",
    "lat": "47.28224",
    "lng": "0.22788"
  },
  {
    "country": "FR",
    "name": "Ressons-sur-Matz",
    "lat": "49.53858",
    "lng": "2.74416"
  },
  {
    "country": "FR",
    "name": "Réquista",
    "lat": "44.03325",
    "lng": "2.53554"
  },
  {
    "country": "FR",
    "name": "Requeil",
    "lat": "47.78371",
    "lng": "0.16105"
  },
  {
    "country": "FR",
    "name": "Replonges",
    "lat": "46.31111",
    "lng": "4.87964"
  },
  {
    "country": "FR",
    "name": "Renwez",
    "lat": "49.83839",
    "lng": "4.60334"
  },
  {
    "country": "FR",
    "name": "Rennes",
    "lat": "48.11198",
    "lng": "-1.67429"
  },
  {
    "country": "FR",
    "name": "Renescure",
    "lat": "50.72754",
    "lng": "2.36801"
  },
  {
    "country": "FR",
    "name": "Renazé",
    "lat": "47.7934",
    "lng": "-1.05437"
  },
  {
    "country": "FR",
    "name": "Renaison",
    "lat": "46.05179",
    "lng": "3.92568"
  },
  {
    "country": "FR",
    "name": "Renage",
    "lat": "45.33529",
    "lng": "5.48528"
  },
  {
    "country": "FR",
    "name": "Remy",
    "lat": "49.43333",
    "lng": "2.71667"
  },
  {
    "country": "FR",
    "name": "Remoulins",
    "lat": "43.93949",
    "lng": "4.56799"
  },
  {
    "country": "FR",
    "name": "Remouillé",
    "lat": "47.05587",
    "lng": "-1.37682"
  },
  {
    "country": "FR",
    "name": "Remiremont",
    "lat": "48.01754",
    "lng": "6.5882"
  },
  {
    "country": "FR",
    "name": "Rémilly",
    "lat": "49.01359",
    "lng": "6.39219"
  },
  {
    "country": "FR",
    "name": "Rémelfing",
    "lat": "49.08947",
    "lng": "7.0882"
  },
  {
    "country": "FR",
    "name": "Rémalard",
    "lat": "48.42867",
    "lng": "0.77185"
  },
  {
    "country": "FR",
    "name": "Reiningue",
    "lat": "47.75054",
    "lng": "7.2325"
  },
  {
    "country": "FR",
    "name": "Reims",
    "lat": "49.25",
    "lng": "4.03333"
  },
  {
    "country": "FR",
    "name": "Reillanne",
    "lat": "43.88131",
    "lng": "5.65736"
  },
  {
    "country": "FR",
    "name": "Reignier-Ésery",
    "lat": "46.13333",
    "lng": "6.26667"
  },
  {
    "country": "FR",
    "name": "Reignac-sur-Indre",
    "lat": "47.22662",
    "lng": "0.91587"
  },
  {
    "country": "FR",
    "name": "Reignac",
    "lat": "45.23393",
    "lng": "-0.50627"
  },
  {
    "country": "FR",
    "name": "Reichstett",
    "lat": "48.64856",
    "lng": "7.75455"
  },
  {
    "country": "FR",
    "name": "Reichshoffen",
    "lat": "48.93287",
    "lng": "7.66561"
  },
  {
    "country": "FR",
    "name": "Réhon",
    "lat": "49.50477",
    "lng": "5.74755"
  },
  {
    "country": "FR",
    "name": "Régusse",
    "lat": "43.65724",
    "lng": "6.12972"
  },
  {
    "country": "FR",
    "name": "Réguisheim",
    "lat": "47.9",
    "lng": "7.35"
  },
  {
    "country": "FR",
    "name": "Réguiny",
    "lat": "47.97649",
    "lng": "-2.74478"
  },
  {
    "country": "FR",
    "name": "Régny",
    "lat": "45.98333",
    "lng": "4.21667"
  },
  {
    "country": "FR",
    "name": "Redon",
    "lat": "47.65",
    "lng": "-2.08333"
  },
  {
    "country": "FR",
    "name": "Réding",
    "lat": "48.75177",
    "lng": "7.10747"
  },
  {
    "country": "FR",
    "name": "Redessan",
    "lat": "43.83117",
    "lng": "4.49771"
  },
  {
    "country": "FR",
    "name": "Rédené",
    "lat": "47.85",
    "lng": "-3.46667"
  },
  {
    "country": "FR",
    "name": "Recquignies",
    "lat": "50.28396",
    "lng": "4.03722"
  },
  {
    "country": "FR",
    "name": "Rebréchien",
    "lat": "47.98727",
    "lng": "2.04432"
  },
  {
    "country": "FR",
    "name": "Rebais",
    "lat": "48.84721",
    "lng": "3.23232"
  },
  {
    "country": "FR",
    "name": "Réalville",
    "lat": "44.11452",
    "lng": "1.47998"
  },
  {
    "country": "FR",
    "name": "Réalmont",
    "lat": "43.77754",
    "lng": "2.18885"
  },
  {
    "country": "FR",
    "name": "Razès",
    "lat": "46.03219",
    "lng": "1.33676"
  },
  {
    "country": "FR",
    "name": "Razac-sur-l’Isle",
    "lat": "45.16332",
    "lng": "0.60085"
  },
  {
    "country": "FR",
    "name": "Ravières",
    "lat": "47.73475",
    "lng": "4.22777"
  },
  {
    "country": "FR",
    "name": "Ravenel",
    "lat": "49.51523",
    "lng": "2.50192"
  },
  {
    "country": "FR",
    "name": "Rauzan",
    "lat": "44.77838",
    "lng": "-0.12465"
  },
  {
    "country": "FR",
    "name": "Raon-aux-Bois",
    "lat": "48.05686",
    "lng": "6.52098"
  },
  {
    "country": "FR",
    "name": "Ranville",
    "lat": "49.23071",
    "lng": "-0.2556"
  },
  {
    "country": "FR",
    "name": "Rantigny",
    "lat": "49.32758",
    "lng": "2.44244"
  },
  {
    "country": "FR",
    "name": "Rannée",
    "lat": "47.92383",
    "lng": "-1.24124"
  },
  {
    "country": "FR",
    "name": "Rang-du-Fliers",
    "lat": "50.41708",
    "lng": "1.64431"
  },
  {
    "country": "FR",
    "name": "Randan",
    "lat": "46.01595",
    "lng": "3.35522"
  },
  {
    "country": "FR",
    "name": "Ranchicourt",
    "lat": "50.43559",
    "lng": "2.5569"
  },
  {
    "country": "FR",
    "name": "Ramonville-Saint-Agne",
    "lat": "43.54618",
    "lng": "1.47491"
  },
  {
    "country": "FR",
    "name": "Ramonchamp",
    "lat": "47.89429",
    "lng": "6.74171"
  },
  {
    "country": "FR",
    "name": "Rambouillet",
    "lat": "48.65",
    "lng": "1.83333"
  },
  {
    "country": "FR",
    "name": "Rambervillers",
    "lat": "48.3424",
    "lng": "6.6358"
  },
  {
    "country": "FR",
    "name": "Ramatuelle",
    "lat": "43.21696",
    "lng": "6.61137"
  },
  {
    "country": "FR",
    "name": "Rai",
    "lat": "48.75",
    "lng": "0.58333"
  },
  {
    "country": "FR",
    "name": "Raismes",
    "lat": "50.38333",
    "lng": "3.48333"
  },
  {
    "country": "FR",
    "name": "Raimbeaucourt",
    "lat": "50.43466",
    "lng": "3.09333"
  },
  {
    "country": "FR",
    "name": "Raillencourt-Sainte-Olle",
    "lat": "50.18333",
    "lng": "3.16667"
  },
  {
    "country": "FR",
    "name": "Raedersheim",
    "lat": "47.88895",
    "lng": "7.28222"
  },
  {
    "country": "FR",
    "name": "Radon",
    "lat": "48.50246",
    "lng": "0.10278"
  },
  {
    "country": "FR",
    "name": "Radinghem-en-Weppes",
    "lat": "50.61884",
    "lng": "2.90924"
  },
  {
    "country": "FR",
    "name": "Racquinghem",
    "lat": "50.69245",
    "lng": "2.35736"
  },
  {
    "country": "FR",
    "name": "Râches",
    "lat": "50.41706",
    "lng": "3.13635"
  },
  {
    "country": "FR",
    "name": "Rabastens-de-Bigorre",
    "lat": "43.38769",
    "lng": "0.15122"
  },
  {
    "country": "FR",
    "name": "Rabastens",
    "lat": "43.82512",
    "lng": "1.72382"
  },
  {
    "country": "FR",
    "name": "Quistinic",
    "lat": "47.9041",
    "lng": "-3.134"
  },
  {
    "country": "FR",
    "name": "Quissac",
    "lat": "43.91341",
    "lng": "3.9992"
  },
  {
    "country": "FR",
    "name": "Quintin",
    "lat": "48.40342",
    "lng": "-2.9105"
  },
  {
    "country": "FR",
    "name": "Quintenas",
    "lat": "45.18966",
    "lng": "4.68732"
  },
  {
    "country": "FR",
    "name": "Quinssaines",
    "lat": "46.33333",
    "lng": "2.51667"
  },
  {
    "country": "FR",
    "name": "Quinsac",
    "lat": "44.75535",
    "lng": "-0.48697"
  },
  {
    "country": "FR",
    "name": "Quingey",
    "lat": "47.1025",
    "lng": "5.88312"
  },
  {
    "country": "FR",
    "name": "Quincy-Voisins",
    "lat": "48.90114",
    "lng": "2.87559"
  },
  {
    "country": "FR",
    "name": "Quincy-sous-Sénart",
    "lat": "48.67294",
    "lng": "2.53419"
  },
  {
    "country": "FR",
    "name": "Quincieux",
    "lat": "45.91036",
    "lng": "4.77823"
  },
  {
    "country": "FR",
    "name": "Quincié-en-Beaujolais",
    "lat": "46.12178",
    "lng": "4.62342"
  },
  {
    "country": "FR",
    "name": "Quincey",
    "lat": "47.61165",
    "lng": "6.18556"
  },
  {
    "country": "FR",
    "name": "Quincampoix",
    "lat": "49.5271",
    "lng": "1.18849"
  },
  {
    "country": "FR",
    "name": "Quimperlé",
    "lat": "47.86667",
    "lng": "-3.55"
  },
  {
    "country": "FR",
    "name": "Quimper",
    "lat": "48",
    "lng": "-4.1"
  },
  {
    "country": "FR",
    "name": "Quilly",
    "lat": "47.46131",
    "lng": "-1.95274"
  },
  {
    "country": "FR",
    "name": "Quillebeuf-sur-Seine",
    "lat": "49.46934",
    "lng": "0.52793"
  },
  {
    "country": "FR",
    "name": "Quillan",
    "lat": "42.87579",
    "lng": "2.18176"
  },
  {
    "country": "FR",
    "name": "Quiévy",
    "lat": "50.16804",
    "lng": "3.42834"
  },
  {
    "country": "FR",
    "name": "Quiévrechain",
    "lat": "50.39172",
    "lng": "3.66815"
  },
  {
    "country": "FR",
    "name": "Quiers-sur-Bézonde",
    "lat": "47.99615",
    "lng": "2.44141"
  },
  {
    "country": "FR",
    "name": "Quiberon",
    "lat": "47.48412",
    "lng": "-3.11963"
  },
  {
    "country": "FR",
    "name": "Quévert",
    "lat": "48.46402",
    "lng": "-2.08745"
  },
  {
    "country": "FR",
    "name": "Quéven",
    "lat": "47.78333",
    "lng": "-3.41667"
  },
  {
    "country": "FR",
    "name": "Quevauvillers",
    "lat": "49.82376",
    "lng": "2.08431"
  },
  {
    "country": "FR",
    "name": "Quettreville-sur-Sienne",
    "lat": "48.96802",
    "lng": "-1.46782"
  },
  {
    "country": "FR",
    "name": "Quettehou",
    "lat": "49.59308",
    "lng": "-1.30352"
  },
  {
    "country": "FR",
    "name": "Quetigny",
    "lat": "47.31667",
    "lng": "5.11667"
  },
  {
    "country": "FR",
    "name": "Questembert",
    "lat": "47.66296",
    "lng": "-2.4522"
  },
  {
    "country": "FR",
    "name": "Quessoy",
    "lat": "48.42208",
    "lng": "-2.66089"
  },
  {
    "country": "FR",
    "name": "Quesnoy-sur-Deûle",
    "lat": "50.71359",
    "lng": "2.99996"
  },
  {
    "country": "FR",
    "name": "Querrien",
    "lat": "47.96667",
    "lng": "-3.53333"
  },
  {
    "country": "FR",
    "name": "Querqueville",
    "lat": "49.66251",
    "lng": "-1.69119"
  },
  {
    "country": "FR",
    "name": "Quend",
    "lat": "50.31584",
    "lng": "1.63609"
  },
  {
    "country": "FR",
    "name": "Quemper-Guézennec",
    "lat": "48.70378",
    "lng": "-3.10522"
  },
  {
    "country": "FR",
    "name": "Quéménéven",
    "lat": "48.11667",
    "lng": "-4.11667"
  },
  {
    "country": "FR",
    "name": "Quelaines-Saint-Gault",
    "lat": "47.93333",
    "lng": "-0.8"
  },
  {
    "country": "FR",
    "name": "Quédillac",
    "lat": "48.24904",
    "lng": "-2.14241"
  },
  {
    "country": "FR",
    "name": "Québriac",
    "lat": "48.34444",
    "lng": "-1.82723"
  },
  {
    "country": "FR",
    "name": "Quarouble",
    "lat": "50.38634",
    "lng": "3.62306"
  },
  {
    "country": "FR",
    "name": "Quarante",
    "lat": "43.34711",
    "lng": "2.96228"
  },
  {
    "country": "FR",
    "name": "Quaëdypre",
    "lat": "50.93527",
    "lng": "2.45445"
  },
  {
    "country": "FR",
    "name": "Puyoô",
    "lat": "43.52502",
    "lng": "-0.91283"
  },
  {
    "country": "FR",
    "name": "Puymoyen",
    "lat": "45.61667",
    "lng": "0.18333"
  },
  {
    "country": "FR",
    "name": "Puyloubier",
    "lat": "43.52522",
    "lng": "5.6765"
  },
  {
    "country": "FR",
    "name": "Puy-l’Évêque",
    "lat": "44.50483",
    "lng": "1.14015"
  },
  {
    "country": "FR",
    "name": "Puylaurens",
    "lat": "43.57202",
    "lng": "2.01227"
  },
  {
    "country": "FR",
    "name": "Puy-Guillaume",
    "lat": "45.95985",
    "lng": "3.47143"
  },
  {
    "country": "FR",
    "name": "Puygouzon",
    "lat": "43.9",
    "lng": "2.16667"
  },
  {
    "country": "FR",
    "name": "Puteaux",
    "lat": "48.88341",
    "lng": "2.23894"
  },
  {
    "country": "FR",
    "name": "Putanges-Pont-Écrepin",
    "lat": "48.76667",
    "lng": "-0.25"
  },
  {
    "country": "FR",
    "name": "Pussay",
    "lat": "48.34908",
    "lng": "1.99182"
  },
  {
    "country": "FR",
    "name": "Pusignan",
    "lat": "45.75814",
    "lng": "5.06724"
  },
  {
    "country": "FR",
    "name": "Pusey",
    "lat": "47.65243",
    "lng": "6.12615"
  },
  {
    "country": "FR",
    "name": "Pulversheim",
    "lat": "47.83753",
    "lng": "7.30119"
  },
  {
    "country": "FR",
    "name": "Pulnoy",
    "lat": "48.70292",
    "lng": "6.25792"
  },
  {
    "country": "FR",
    "name": "Pulligny",
    "lat": "48.54222",
    "lng": "6.14219"
  },
  {
    "country": "FR",
    "name": "Pujols",
    "lat": "44.39424",
    "lng": "0.6881"
  },
  {
    "country": "FR",
    "name": "Pujaut",
    "lat": "44.00404",
    "lng": "4.77575"
  },
  {
    "country": "FR",
    "name": "Pujaudran",
    "lat": "43.58954",
    "lng": "1.14977"
  },
  {
    "country": "FR",
    "name": "Puisserguier",
    "lat": "43.36767",
    "lng": "3.04047"
  },
  {
    "country": "FR",
    "name": "Puissalicon",
    "lat": "43.45828",
    "lng": "3.2369"
  },
  {
    "country": "FR",
    "name": "Puiseux-en-France",
    "lat": "49.05552",
    "lng": "2.50035"
  },
  {
    "country": "FR",
    "name": "Puiseaux",
    "lat": "48.09234",
    "lng": "2.05967"
  },
  {
    "country": "FR",
    "name": "Puilboreau",
    "lat": "46.1862",
    "lng": "-1.11797"
  },
  {
    "country": "FR",
    "name": "Puicheric",
    "lat": "43.2238",
    "lng": "2.62455"
  },
  {
    "country": "FR",
    "name": "Pugnac",
    "lat": "45.0819",
    "lng": "-0.49618"
  },
  {
    "country": "FR",
    "name": "Puget-Ville",
    "lat": "43.28944",
    "lng": "6.13612"
  },
  {
    "country": "FR",
    "name": "Puget-Théniers",
    "lat": "43.95464",
    "lng": "6.89115"
  },
  {
    "country": "FR",
    "name": "Puget-sur-Argens",
    "lat": "43.45",
    "lng": "6.68333"
  },
  {
    "country": "FR",
    "name": "Publier",
    "lat": "46.38773",
    "lng": "6.54356"
  },
  {
    "country": "FR",
    "name": "Pruniers-en-Sologne",
    "lat": "47.31667",
    "lng": "1.66667"
  },
  {
    "country": "FR",
    "name": "Prunelli-di-Fiumorbo",
    "lat": "42.01047",
    "lng": "9.32473"
  },
  {
    "country": "FR",
    "name": "Pruillé-le-Chétif",
    "lat": "47.99383",
    "lng": "0.10677"
  },
  {
    "country": "FR",
    "name": "Provins",
    "lat": "48.55",
    "lng": "3.3"
  },
  {
    "country": "FR",
    "name": "Provin",
    "lat": "50.5143",
    "lng": "2.90794"
  },
  {
    "country": "FR",
    "name": "Proville",
    "lat": "50.16137",
    "lng": "3.20629"
  },
  {
    "country": "FR",
    "name": "Prouvy",
    "lat": "50.31793",
    "lng": "3.45096"
  },
  {
    "country": "FR",
    "name": "Propriano",
    "lat": "41.67525",
    "lng": "8.90302"
  },
  {
    "country": "FR",
    "name": "Priziac",
    "lat": "48.06667",
    "lng": "-3.41667"
  },
  {
    "country": "FR",
    "name": "Prix-lès-Mézières",
    "lat": "49.75549",
    "lng": "4.69113"
  },
  {
    "country": "FR",
    "name": "Privas",
    "lat": "44.73394",
    "lng": "4.59701"
  },
  {
    "country": "FR",
    "name": "Prissé",
    "lat": "46.3213",
    "lng": "4.74469"
  },
  {
    "country": "FR",
    "name": "Prinquiau",
    "lat": "47.36215",
    "lng": "-2.00952"
  },
  {
    "country": "FR",
    "name": "Pringy",
    "lat": "48.51815",
    "lng": "2.56333"
  },
  {
    "country": "FR",
    "name": "Pringy",
    "lat": "45.94622",
    "lng": "6.12608"
  },
  {
    "country": "FR",
    "name": "Prigonrieux",
    "lat": "44.85451",
    "lng": "0.40275"
  },
  {
    "country": "FR",
    "name": "Priay",
    "lat": "46.00188",
    "lng": "5.28775"
  },
  {
    "country": "FR",
    "name": "Preuilly-sur-Claise",
    "lat": "46.85424",
    "lng": "0.92954"
  },
  {
    "country": "FR",
    "name": "Précieux",
    "lat": "45.58333",
    "lng": "4.15"
  },
  {
    "country": "FR",
    "name": "Presles-en-Brie",
    "lat": "48.71527",
    "lng": "2.74112"
  },
  {
    "country": "FR",
    "name": "Préseau",
    "lat": "50.31122",
    "lng": "3.57434"
  },
  {
    "country": "FR",
    "name": "Prémilhat",
    "lat": "46.31667",
    "lng": "2.53333"
  },
  {
    "country": "FR",
    "name": "Prémesques",
    "lat": "50.65572",
    "lng": "2.95162"
  },
  {
    "country": "FR",
    "name": "Prémery",
    "lat": "47.16952",
    "lng": "3.32743"
  },
  {
    "country": "FR",
    "name": "Preignan",
    "lat": "43.71177",
    "lng": "0.62608"
  },
  {
    "country": "FR",
    "name": "Preignac",
    "lat": "44.58438",
    "lng": "-0.29423"
  },
  {
    "country": "FR",
    "name": "Préfailles",
    "lat": "47.12839",
    "lng": "-2.21693"
  },
  {
    "country": "FR",
    "name": "Pré-en-Pail",
    "lat": "48.45993",
    "lng": "-0.19814"
  },
  {
    "country": "FR",
    "name": "Précy-sur-Oise",
    "lat": "49.20779",
    "lng": "2.37266"
  },
  {
    "country": "FR",
    "name": "Précigné",
    "lat": "47.76692",
    "lng": "-0.32491"
  },
  {
    "country": "FR",
    "name": "Préchac",
    "lat": "44.39883",
    "lng": "-0.35387"
  },
  {
    "country": "FR",
    "name": "Préaux",
    "lat": "49.49136",
    "lng": "1.21583"
  },
  {
    "country": "FR",
    "name": "Praz-sur-Arly",
    "lat": "45.83661",
    "lng": "6.5732"
  },
  {
    "country": "FR",
    "name": "Prayssac",
    "lat": "44.5044",
    "lng": "1.18862"
  },
  {
    "country": "FR",
    "name": "Prats de Molló",
    "lat": "42.40404",
    "lng": "2.47928"
  },
  {
    "country": "FR",
    "name": "Prat",
    "lat": "48.67677",
    "lng": "-3.29707"
  },
  {
    "country": "FR",
    "name": "Prahecq",
    "lat": "46.25897",
    "lng": "-0.34425"
  },
  {
    "country": "FR",
    "name": "Pradines",
    "lat": "44.48341",
    "lng": "1.40105"
  },
  {
    "country": "FR",
    "name": "Prades-le-Lez",
    "lat": "43.69754",
    "lng": "3.86463"
  },
  {
    "country": "FR",
    "name": "Prades",
    "lat": "42.61667",
    "lng": "2.43333"
  },
  {
    "country": "FR",
    "name": "Pouzauges",
    "lat": "46.77941",
    "lng": "-0.83619"
  },
  {
    "country": "FR",
    "name": "Pouzac",
    "lat": "43.08606",
    "lng": "0.13522"
  },
  {
    "country": "FR",
    "name": "Pouxeux",
    "lat": "48.10621",
    "lng": "6.57299"
  },
  {
    "country": "FR",
    "name": "Poussan",
    "lat": "43.48944",
    "lng": "3.67083"
  },
  {
    "country": "FR",
    "name": "Pouru-Saint-Remy",
    "lat": "49.68333",
    "lng": "5.08333"
  },
  {
    "country": "FR",
    "name": "Pourrières",
    "lat": "43.50611",
    "lng": "5.73452"
  },
  {
    "country": "FR",
    "name": "Pourrain",
    "lat": "47.75615",
    "lng": "3.41193"
  },
  {
    "country": "FR",
    "name": "Poulx",
    "lat": "43.90798",
    "lng": "4.41629"
  },
  {
    "country": "FR",
    "name": "Poullaouen",
    "lat": "48.33333",
    "lng": "-3.65"
  },
  {
    "country": "FR",
    "name": "Poullan-sur-Mer",
    "lat": "48.08333",
    "lng": "-4.41667"
  },
  {
    "country": "FR",
    "name": "Pouligny-Saint-Pierre",
    "lat": "46.68095",
    "lng": "1.03877"
  },
  {
    "country": "FR",
    "name": "Pouldreuzic",
    "lat": "47.95",
    "lng": "-4.36667"
  },
  {
    "country": "FR",
    "name": "Pouldergat",
    "lat": "48.05",
    "lng": "-4.33333"
  },
  {
    "country": "FR",
    "name": "Poulainville",
    "lat": "49.94745",
    "lng": "2.31373"
  },
  {
    "country": "FR",
    "name": "Pouilly-sur-Loire",
    "lat": "47.28377",
    "lng": "2.95442"
  },
  {
    "country": "FR",
    "name": "Pouilly-sous-Charlieu",
    "lat": "46.14566",
    "lng": "4.1089"
  },
  {
    "country": "FR",
    "name": "Pouilly-les-Nonains",
    "lat": "46.0382",
    "lng": "3.98198"
  },
  {
    "country": "FR",
    "name": "Pouilly-lès-Feurs",
    "lat": "45.8",
    "lng": "4.23333"
  },
  {
    "country": "FR",
    "name": "Pouilly-en-Auxois",
    "lat": "47.26238",
    "lng": "4.55583"
  },
  {
    "country": "FR",
    "name": "Pouillon",
    "lat": "43.6048",
    "lng": "-0.99947"
  },
  {
    "country": "FR",
    "name": "Pouilley-les-Vignes",
    "lat": "47.2577",
    "lng": "5.93581"
  },
  {
    "country": "FR",
    "name": "Pougues-les-Eaux",
    "lat": "47.07518",
    "lng": "3.1015"
  },
  {
    "country": "FR",
    "name": "Pouancé",
    "lat": "47.74167",
    "lng": "-1.17366"
  },
  {
    "country": "FR",
    "name": "Potigny",
    "lat": "48.96925",
    "lng": "-0.24166"
  },
  {
    "country": "FR",
    "name": "Poses",
    "lat": "49.30539",
    "lng": "1.24353"
  },
  {
    "country": "FR",
    "name": "Portvendres",
    "lat": "42.51792",
    "lng": "3.10553"
  },
  {
    "country": "FR",
    "name": "Port-sur-Saône",
    "lat": "47.68774",
    "lng": "6.05011"
  },
  {
    "country": "FR",
    "name": "Port-Saint-Père",
    "lat": "47.13294",
    "lng": "-1.7485"
  },
  {
    "country": "FR",
    "name": "Port-Saint-Louis-du-Rhône",
    "lat": "43.38734",
    "lng": "4.82609"
  },
  {
    "country": "FR",
    "name": "Port-Sainte-Marie",
    "lat": "44.25158",
    "lng": "0.39134"
  },
  {
    "country": "FR",
    "name": "Port-Sainte-Foy-et-Ponchapt",
    "lat": "44.83333",
    "lng": "0.2"
  },
  {
    "country": "FR",
    "name": "Porto-Vecchio",
    "lat": "41.59101",
    "lng": "9.27947"
  },
  {
    "country": "FR",
    "name": "Port-Louis",
    "lat": "47.70704",
    "lng": "-3.35484"
  },
  {
    "country": "FR",
    "name": "Port-la-Nouvelle",
    "lat": "43.01991",
    "lng": "3.04366"
  },
  {
    "country": "FR",
    "name": "Portiragnes",
    "lat": "43.3046",
    "lng": "3.33365"
  },
  {
    "country": "FR",
    "name": "Portieux",
    "lat": "48.34466",
    "lng": "6.34465"
  },
  {
    "country": "FR",
    "name": "Portet-sur-Garonne",
    "lat": "43.52333",
    "lng": "1.40651"
  },
  {
    "country": "FR",
    "name": "Portets",
    "lat": "44.69679",
    "lng": "-0.42452"
  },
  {
    "country": "FR",
    "name": "Portes-lès-Valence",
    "lat": "44.8737",
    "lng": "4.881"
  },
  {
    "country": "FR",
    "name": "Port-en-Bessin-Huppain",
    "lat": "49.3446",
    "lng": "-0.75557"
  },
  {
    "country": "FR",
    "name": "Portel-des-Corbières",
    "lat": "43.05",
    "lng": "2.91667"
  },
  {
    "country": "FR",
    "name": "Port-de-Bouc",
    "lat": "43.40657",
    "lng": "4.9809"
  },
  {
    "country": "FR",
    "name": "Port-Brillet",
    "lat": "48.11315",
    "lng": "-0.9708"
  },
  {
    "country": "FR",
    "name": "Portbail",
    "lat": "49.33571",
    "lng": "-1.6956"
  },
  {
    "country": "FR",
    "name": "Port à Binson",
    "lat": "49.08202",
    "lng": "3.75989"
  },
  {
    "country": "FR",
    "name": "Porspoder",
    "lat": "48.5",
    "lng": "-4.76667"
  },
  {
    "country": "FR",
    "name": "Pornichet",
    "lat": "47.26682",
    "lng": "-2.33794"
  },
  {
    "country": "FR",
    "name": "Pornic",
    "lat": "47.11205",
    "lng": "-2.08888"
  },
  {
    "country": "FR",
    "name": "Pordic",
    "lat": "48.57051",
    "lng": "-2.81783"
  },
  {
    "country": "FR",
    "name": "Porcieu-Amblagnieu",
    "lat": "45.83443",
    "lng": "5.40218"
  },
  {
    "country": "FR",
    "name": "Porcheville",
    "lat": "48.97254",
    "lng": "1.77973"
  },
  {
    "country": "FR",
    "name": "Porcelette",
    "lat": "49.15657",
    "lng": "6.65513"
  },
  {
    "country": "FR",
    "name": "Pontvallain",
    "lat": "47.75169",
    "lng": "0.19145"
  },
  {
    "country": "FR",
    "name": "Pont-sur-Yonne",
    "lat": "48.28297",
    "lng": "3.20198"
  },
  {
    "country": "FR",
    "name": "Pont-sur-Sambre",
    "lat": "50.22195",
    "lng": "3.84693"
  },
  {
    "country": "FR",
    "name": "Pont-Scorff",
    "lat": "47.83343",
    "lng": "-3.40251"
  },
  {
    "country": "FR",
    "name": "Pont-Salomon",
    "lat": "45.33924",
    "lng": "4.2481"
  },
  {
    "country": "FR",
    "name": "Pont-Saint-Vincent",
    "lat": "48.60298",
    "lng": "6.09942"
  },
  {
    "country": "FR",
    "name": "Pont-Saint-Pierre",
    "lat": "49.33561",
    "lng": "1.27601"
  },
  {
    "country": "FR",
    "name": "Pont-Saint-Martin",
    "lat": "47.12338",
    "lng": "-1.58455"
  },
  {
    "country": "FR",
    "name": "Pont-Saint-Esprit",
    "lat": "44.25494",
    "lng": "4.64736"
  },
  {
    "country": "FR",
    "name": "Pont-Sainte-Maxence",
    "lat": "49.30168",
    "lng": "2.60467"
  },
  {
    "country": "FR",
    "name": "Pont-Sainte-Marie",
    "lat": "48.31848",
    "lng": "4.09447"
  },
  {
    "country": "FR",
    "name": "Pontrieux",
    "lat": "48.70111",
    "lng": "-3.15967"
  },
  {
    "country": "FR",
    "name": "Pont-Remy",
    "lat": "50.05",
    "lng": "1.91667"
  },
  {
    "country": "FR",
    "name": "Pontpoint",
    "lat": "49.3",
    "lng": "2.65"
  },
  {
    "country": "FR",
    "name": "Pontorson",
    "lat": "48.55316",
    "lng": "-1.50754"
  },
  {
    "country": "FR",
    "name": "Pontonx-sur-l'Adour",
    "lat": "43.78783",
    "lng": "-0.92508"
  },
  {
    "country": "FR",
    "name": "Pontoise",
    "lat": "49.05",
    "lng": "2.1"
  },
  {
    "country": "FR",
    "name": "Pontlevoy",
    "lat": "47.39002",
    "lng": "1.25465"
  },
  {
    "country": "FR",
    "name": "Pont-l’Abbé-d’Arnoult",
    "lat": "45.82875",
    "lng": "-0.87499"
  },
  {
    "country": "FR",
    "name": "Pontivy",
    "lat": "48.06667",
    "lng": "-2.98333"
  },
  {
    "country": "FR",
    "name": "Ponthierry",
    "lat": "48.53366",
    "lng": "2.54419"
  },
  {
    "country": "FR",
    "name": "Pont-Hébert",
    "lat": "49.16714",
    "lng": "-1.13428"
  },
  {
    "country": "FR",
    "name": "Pontfaverger-Moronvilliers",
    "lat": "49.29702",
    "lng": "4.31657"
  },
  {
    "country": "FR",
    "name": "Pont-Évêque",
    "lat": "45.52691",
    "lng": "4.91432"
  },
  {
    "country": "FR",
    "name": "Pontenx-les-Forges",
    "lat": "44.24134",
    "lng": "-1.12095"
  },
  {
    "country": "FR",
    "name": "Pont-en-Royans",
    "lat": "45.06361",
    "lng": "5.34136"
  },
  {
    "country": "FR",
    "name": "Ponteilla",
    "lat": "42.62594",
    "lng": "2.81335"
  },
  {
    "country": "FR",
    "name": "Pont-Écrepin",
    "lat": "48.76425",
    "lng": "-0.24455"
  },
  {
    "country": "FR",
    "name": "Pont-du-Château",
    "lat": "45.80078",
    "lng": "3.25008"
  },
  {
    "country": "FR",
    "name": "Pont-du-Casse",
    "lat": "44.22867",
    "lng": "0.67924"
  },
  {
    "country": "FR",
    "name": "Pont de Vivaux",
    "lat": "43.27604",
    "lng": "5.41586"
  },
  {
    "country": "FR",
    "name": "Pont-de-Veyle",
    "lat": "46.26248",
    "lng": "4.88717"
  },
  {
    "country": "FR",
    "name": "Pont-de-Vaux",
    "lat": "46.43171",
    "lng": "4.94012"
  },
  {
    "country": "FR",
    "name": "Pont-de-Salars",
    "lat": "44.2808",
    "lng": "2.72783"
  },
  {
    "country": "FR",
    "name": "Pont-de-Roide",
    "lat": "47.38738",
    "lng": "6.7684"
  },
  {
    "country": "FR",
    "name": "Pont-de-Metz",
    "lat": "49.8782",
    "lng": "2.24266"
  },
  {
    "country": "FR",
    "name": "Pont-de-Larn",
    "lat": "43.50412",
    "lng": "2.40786"
  },
  {
    "country": "FR",
    "name": "Pont-de-Chéruy",
    "lat": "45.75166",
    "lng": "5.18488"
  },
  {
    "country": "FR",
    "name": "Pont-d’Ain",
    "lat": "46.04789",
    "lng": "5.3368"
  },
  {
    "country": "FR",
    "name": "Pont-Croix",
    "lat": "48.04088",
    "lng": "-4.48714"
  },
  {
    "country": "FR",
    "name": "Pontchâteau",
    "lat": "47.43797",
    "lng": "-2.09011"
  },
  {
    "country": "FR",
    "name": "Pontcharra-sur-Turdine",
    "lat": "45.8774",
    "lng": "4.48993"
  },
  {
    "country": "FR",
    "name": "Pontcharra",
    "lat": "45.4329",
    "lng": "6.01424"
  },
  {
    "country": "FR",
    "name": "Pontcarré",
    "lat": "48.79772",
    "lng": "2.70508"
  },
  {
    "country": "FR",
    "name": "Pont-à-Vendin",
    "lat": "50.47358",
    "lng": "2.88884"
  },
  {
    "country": "FR",
    "name": "Pont-Aven",
    "lat": "47.85",
    "lng": "-3.75"
  },
  {
    "country": "FR",
    "name": "Pont-Audemer",
    "lat": "49.35",
    "lng": "0.51667"
  },
  {
    "country": "FR",
    "name": "Pontarlier",
    "lat": "46.90347",
    "lng": "6.35542"
  },
  {
    "country": "FR",
    "name": "Pont-à-Mousson",
    "lat": "48.90786",
    "lng": "6.0589"
  },
  {
    "country": "FR",
    "name": "Pont-à-Marcq",
    "lat": "50.52213",
    "lng": "3.11441"
  },
  {
    "country": "FR",
    "name": "Pontailler-sur-Saône",
    "lat": "47.30455",
    "lng": "5.41479"
  },
  {
    "country": "FR",
    "name": "Pontacq",
    "lat": "43.18333",
    "lng": "-0.11667"
  },
  {
    "country": "FR",
    "name": "Pons",
    "lat": "45.57988",
    "lng": "-0.54783"
  },
  {
    "country": "FR",
    "name": "Poncin",
    "lat": "46.08384",
    "lng": "5.40966"
  },
  {
    "country": "FR",
    "name": "Ponchon",
    "lat": "49.34652",
    "lng": "2.19677"
  },
  {
    "country": "FR",
    "name": "Pomponne",
    "lat": "48.8813",
    "lng": "2.68232"
  },
  {
    "country": "FR",
    "name": "Pompignan",
    "lat": "43.81768",
    "lng": "1.31209"
  },
  {
    "country": "FR",
    "name": "Pompignac",
    "lat": "44.85114",
    "lng": "-0.43705"
  },
  {
    "country": "FR",
    "name": "Pompey",
    "lat": "48.76653",
    "lng": "6.12162"
  },
  {
    "country": "FR",
    "name": "Pompertuzat",
    "lat": "43.49277",
    "lng": "1.51531"
  },
  {
    "country": "FR",
    "name": "Pompaire",
    "lat": "46.60727",
    "lng": "-0.23237"
  },
  {
    "country": "FR",
    "name": "Pommiers",
    "lat": "45.95594",
    "lng": "4.69353"
  },
  {
    "country": "FR",
    "name": "Pommeuse",
    "lat": "48.81667",
    "lng": "3.01667"
  },
  {
    "country": "FR",
    "name": "Pommerit-le-Vicomte",
    "lat": "48.61989",
    "lng": "-3.09"
  },
  {
    "country": "FR",
    "name": "Pommerit-Jaudy",
    "lat": "48.73058",
    "lng": "-3.24208"
  },
  {
    "country": "FR",
    "name": "Pommeret",
    "lat": "48.46378",
    "lng": "-2.62689"
  },
  {
    "country": "FR",
    "name": "Pomérols",
    "lat": "43.39139",
    "lng": "3.49944"
  },
  {
    "country": "FR",
    "name": "Pomarez",
    "lat": "43.62971",
    "lng": "-0.82934"
  },
  {
    "country": "FR",
    "name": "Polminhac",
    "lat": "44.95223",
    "lng": "2.57846"
  },
  {
    "country": "FR",
    "name": "Pollionnay",
    "lat": "45.76473",
    "lng": "4.66099"
  },
  {
    "country": "FR",
    "name": "Polliat",
    "lat": "46.24849",
    "lng": "5.12658"
  },
  {
    "country": "FR",
    "name": "Pollestres",
    "lat": "42.642",
    "lng": "2.87116"
  },
  {
    "country": "FR",
    "name": "Poligny",
    "lat": "46.83712",
    "lng": "5.70505"
  },
  {
    "country": "FR",
    "name": "Polignac",
    "lat": "45.0709",
    "lng": "3.86031"
  },
  {
    "country": "FR",
    "name": "Poix-du-Nord",
    "lat": "50.18927",
    "lng": "3.60956"
  },
  {
    "country": "FR",
    "name": "Poix-de-Picardie",
    "lat": "49.78333",
    "lng": "1.98333"
  },
  {
    "country": "FR",
    "name": "Poitiers",
    "lat": "46.58333",
    "lng": "0.33333"
  },
  {
    "country": "FR",
    "name": "Poisy",
    "lat": "45.92305",
    "lng": "6.06435"
  },
  {
    "country": "FR",
    "name": "Poissy",
    "lat": "48.92902",
    "lng": "2.04952"
  },
  {
    "country": "FR",
    "name": "Poisat",
    "lat": "45.15863",
    "lng": "5.76188"
  },
  {
    "country": "FR",
    "name": "Poilly-lez-Gien",
    "lat": "47.67724",
    "lng": "2.59743"
  },
  {
    "country": "FR",
    "name": "Poey-de-Lescar",
    "lat": "43.35",
    "lng": "-0.46667"
  },
  {
    "country": "FR",
    "name": "Podensac",
    "lat": "44.65038",
    "lng": "-0.35508"
  },
  {
    "country": "FR",
    "name": "Pocé-sur-Cisse",
    "lat": "47.4433",
    "lng": "0.99142"
  },
  {
    "country": "FR",
    "name": "Pocé-les-Bois",
    "lat": "48.11626",
    "lng": "-1.25168"
  },
  {
    "country": "FR",
    "name": "Pluzunet",
    "lat": "48.64076",
    "lng": "-3.37113"
  },
  {
    "country": "FR",
    "name": "Pluvigner",
    "lat": "47.77627",
    "lng": "-3.01013"
  },
  {
    "country": "FR",
    "name": "Plurien",
    "lat": "48.62559",
    "lng": "-2.40423"
  },
  {
    "country": "FR",
    "name": "Pluneret",
    "lat": "47.67525",
    "lng": "-2.95782"
  },
  {
    "country": "FR",
    "name": "Plumieux",
    "lat": "48.10303",
    "lng": "-2.58382"
  },
  {
    "country": "FR",
    "name": "Plumergat",
    "lat": "47.74134",
    "lng": "-2.91501"
  },
  {
    "country": "FR",
    "name": "Plumelin",
    "lat": "47.86036",
    "lng": "-2.88754"
  },
  {
    "country": "FR",
    "name": "Pluméliau",
    "lat": "47.95769",
    "lng": "-2.97494"
  },
  {
    "country": "FR",
    "name": "Plumelec",
    "lat": "47.83754",
    "lng": "-2.63987"
  },
  {
    "country": "FR",
    "name": "Plumaugat",
    "lat": "48.25479",
    "lng": "-2.23843"
  },
  {
    "country": "FR",
    "name": "Pluherlin",
    "lat": "47.69632",
    "lng": "-2.36349"
  },
  {
    "country": "FR",
    "name": "Pluguffan",
    "lat": "47.98333",
    "lng": "-4.18333"
  },
  {
    "country": "FR",
    "name": "Pluduno",
    "lat": "48.5311",
    "lng": "-2.26848"
  },
  {
    "country": "FR",
    "name": "Plozévet",
    "lat": "47.98333",
    "lng": "-4.41667"
  },
  {
    "country": "FR",
    "name": "Plouzévédé",
    "lat": "48.6",
    "lng": "-4.11667"
  },
  {
    "country": "FR",
    "name": "Plouzané",
    "lat": "48.38333",
    "lng": "-4.61667"
  },
  {
    "country": "FR",
    "name": "Plouvorn",
    "lat": "48.58333",
    "lng": "-4.03333"
  },
  {
    "country": "FR",
    "name": "Plouvien",
    "lat": "48.53333",
    "lng": "-4.45"
  },
  {
    "country": "FR",
    "name": "Plourivo",
    "lat": "48.7455",
    "lng": "-3.07075"
  },
  {
    "country": "FR",
    "name": "Plourin-lès-Morlaix",
    "lat": "48.53333",
    "lng": "-3.78333"
  },
  {
    "country": "FR",
    "name": "Plouray",
    "lat": "48.1458",
    "lng": "-3.38671"
  },
  {
    "country": "FR",
    "name": "Plounévez-Quintin",
    "lat": "48.28333",
    "lng": "-3.23333"
  },
  {
    "country": "FR",
    "name": "Plounévez-Moëdec",
    "lat": "48.56667",
    "lng": "-3.45"
  },
  {
    "country": "FR",
    "name": "Plounévez-Lochrist",
    "lat": "48.61667",
    "lng": "-4.21667"
  },
  {
    "country": "FR",
    "name": "Plounévézel",
    "lat": "48.3",
    "lng": "-3.6"
  },
  {
    "country": "FR",
    "name": "Plounéventer",
    "lat": "48.51667",
    "lng": "-4.21667"
  },
  {
    "country": "FR",
    "name": "Plounéour-Trez",
    "lat": "48.65",
    "lng": "-4.31667"
  },
  {
    "country": "FR",
    "name": "Plounéour-Ménez",
    "lat": "48.45",
    "lng": "-3.88333"
  },
  {
    "country": "FR",
    "name": "Ploumoguer",
    "lat": "48.4",
    "lng": "-4.71667"
  },
  {
    "country": "FR",
    "name": "Ploumilliau",
    "lat": "48.68333",
    "lng": "-3.51667"
  },
  {
    "country": "FR",
    "name": "Ploumagoar",
    "lat": "48.54509",
    "lng": "-3.13233"
  },
  {
    "country": "FR",
    "name": "Plouisy",
    "lat": "48.57817",
    "lng": "-3.18434"
  },
  {
    "country": "FR",
    "name": "Plouigneau",
    "lat": "48.56667",
    "lng": "-3.7"
  },
  {
    "country": "FR",
    "name": "Plouider",
    "lat": "48.61667",
    "lng": "-4.3"
  },
  {
    "country": "FR",
    "name": "Plouhinec",
    "lat": "48.01667",
    "lng": "-4.48333"
  },
  {
    "country": "FR",
    "name": "Plouharnel",
    "lat": "47.59804",
    "lng": "-3.11274"
  },
  {
    "country": "FR",
    "name": "Plouha",
    "lat": "48.6765",
    "lng": "-2.92842"
  },
  {
    "country": "FR",
    "name": "Plouguin",
    "lat": "48.53333",
    "lng": "-4.6"
  },
  {
    "country": "FR",
    "name": "Plouguiel",
    "lat": "48.79742",
    "lng": "-3.23883"
  },
  {
    "country": "FR",
    "name": "Plouguernével",
    "lat": "48.2394",
    "lng": "-3.25071"
  },
  {
    "country": "FR",
    "name": "Plouguerneau",
    "lat": "48.6",
    "lng": "-4.5"
  },
  {
    "country": "FR",
    "name": "Plouguenast",
    "lat": "48.28208",
    "lng": "-2.70443"
  },
  {
    "country": "FR",
    "name": "Plougrescant",
    "lat": "48.84026",
    "lng": "-3.22886"
  },
  {
    "country": "FR",
    "name": "Plougourvest",
    "lat": "48.55",
    "lng": "-4.08333"
  },
  {
    "country": "FR",
    "name": "Plougoumelen",
    "lat": "47.6507",
    "lng": "-2.91716"
  },
  {
    "country": "FR",
    "name": "Plougoulm",
    "lat": "48.66667",
    "lng": "-4.05"
  },
  {
    "country": "FR",
    "name": "Plougonven",
    "lat": "48.51667",
    "lng": "-3.71667"
  },
  {
    "country": "FR",
    "name": "Plougonvelin",
    "lat": "48.34059",
    "lng": "-4.71846"
  },
  {
    "country": "FR",
    "name": "Plougastel-Daoulas",
    "lat": "48.36667",
    "lng": "-4.36667"
  },
  {
    "country": "FR",
    "name": "Plougasnou",
    "lat": "48.7",
    "lng": "-3.8"
  },
  {
    "country": "FR",
    "name": "Ploufragan",
    "lat": "48.49141",
    "lng": "-2.79458"
  },
  {
    "country": "FR",
    "name": "Plouezoc'h",
    "lat": "48.63333",
    "lng": "-3.81667"
  },
  {
    "country": "FR",
    "name": "Plouézec",
    "lat": "48.75122",
    "lng": "-2.98467"
  },
  {
    "country": "FR",
    "name": "Plouescat",
    "lat": "48.66667",
    "lng": "-4.16667"
  },
  {
    "country": "FR",
    "name": "Plouër-sur-Rance",
    "lat": "48.52669",
    "lng": "-2.00298"
  },
  {
    "country": "FR",
    "name": "Plouénan",
    "lat": "48.63333",
    "lng": "-4"
  },
  {
    "country": "FR",
    "name": "Plouédern",
    "lat": "48.48333",
    "lng": "-4.25"
  },
  {
    "country": "FR",
    "name": "Plouëc-du-Trieux",
    "lat": "48.68333",
    "lng": "-3.2"
  },
  {
    "country": "FR",
    "name": "Ploudaniel",
    "lat": "48.53333",
    "lng": "-4.31667"
  },
  {
    "country": "FR",
    "name": "Ploudalmézeau",
    "lat": "48.53333",
    "lng": "-4.65"
  },
  {
    "country": "FR",
    "name": "Ploubezre",
    "lat": "48.7",
    "lng": "-3.45"
  },
  {
    "country": "FR",
    "name": "Ploubazlanec",
    "lat": "48.8",
    "lng": "-3.03333"
  },
  {
    "country": "FR",
    "name": "Ploubalay",
    "lat": "48.58109",
    "lng": "-2.14069"
  },
  {
    "country": "FR",
    "name": "Plouay",
    "lat": "47.91444",
    "lng": "-3.33384"
  },
  {
    "country": "FR",
    "name": "Plouasne",
    "lat": "48.30081",
    "lng": "-2.00698"
  },
  {
    "country": "FR",
    "name": "Plouarzel",
    "lat": "48.43333",
    "lng": "-4.73333"
  },
  {
    "country": "FR",
    "name": "Plouaret",
    "lat": "48.61667",
    "lng": "-3.46667"
  },
  {
    "country": "FR",
    "name": "Plouagat",
    "lat": "48.53611",
    "lng": "-2.99956"
  },
  {
    "country": "FR",
    "name": "Plonévez-Porzay",
    "lat": "48.1",
    "lng": "-4.21667"
  },
  {
    "country": "FR",
    "name": "Plonévez-du-Faou",
    "lat": "48.25",
    "lng": "-3.83333"
  },
  {
    "country": "FR",
    "name": "Plonéour-Lanvern",
    "lat": "47.9",
    "lng": "-4.28333"
  },
  {
    "country": "FR",
    "name": "Plonéis",
    "lat": "48.01667",
    "lng": "-4.21667"
  },
  {
    "country": "FR",
    "name": "Plomodiern",
    "lat": "48.18333",
    "lng": "-4.23333"
  },
  {
    "country": "FR",
    "name": "Plomeur",
    "lat": "47.83333",
    "lng": "-4.28333"
  },
  {
    "country": "FR",
    "name": "Plomelin",
    "lat": "47.93333",
    "lng": "-4.15"
  },
  {
    "country": "FR",
    "name": "Plombières-lès-Dijon",
    "lat": "47.33333",
    "lng": "4.96667"
  },
  {
    "country": "FR",
    "name": "Plombières-les-Bains",
    "lat": "47.96337",
    "lng": "6.45758"
  },
  {
    "country": "FR",
    "name": "Plogonnec",
    "lat": "48.08333",
    "lng": "-4.18333"
  },
  {
    "country": "FR",
    "name": "Plogoff",
    "lat": "48.037",
    "lng": "-4.66606"
  },
  {
    "country": "FR",
    "name": "Plogastel-Saint-Germain",
    "lat": "47.98333",
    "lng": "-4.26667"
  },
  {
    "country": "FR",
    "name": "Ploëzal",
    "lat": "48.71534",
    "lng": "-3.20333"
  },
  {
    "country": "FR",
    "name": "Plœuc-sur-Lié",
    "lat": "48.35",
    "lng": "-2.75"
  },
  {
    "country": "FR",
    "name": "Ploërmel",
    "lat": "47.93172",
    "lng": "-2.39781"
  },
  {
    "country": "FR",
    "name": "Ploeren",
    "lat": "47.65713",
    "lng": "-2.86397"
  },
  {
    "country": "FR",
    "name": "Ploërdut",
    "lat": "48.08742",
    "lng": "-3.2855"
  },
  {
    "country": "FR",
    "name": "Ploemeur",
    "lat": "47.73333",
    "lng": "-3.43333"
  },
  {
    "country": "FR",
    "name": "Ploemel",
    "lat": "47.65153",
    "lng": "-3.0703"
  },
  {
    "country": "FR",
    "name": "Plobsheim",
    "lat": "48.46979",
    "lng": "7.72442"
  },
  {
    "country": "FR",
    "name": "Plobannalec-Lesconil",
    "lat": "47.81667",
    "lng": "-4.21667"
  },
  {
    "country": "FR",
    "name": "Pleyber-Christ",
    "lat": "48.5",
    "lng": "-3.86667"
  },
  {
    "country": "FR",
    "name": "Pleyben",
    "lat": "48.23333",
    "lng": "-3.96667"
  },
  {
    "country": "FR",
    "name": "Pleuven",
    "lat": "47.9",
    "lng": "-4.03333"
  },
  {
    "country": "FR",
    "name": "Pleurtuit",
    "lat": "48.57858",
    "lng": "-2.05805"
  },
  {
    "country": "FR",
    "name": "Pleumeur-Gautier",
    "lat": "48.80044",
    "lng": "-3.15578"
  },
  {
    "country": "FR",
    "name": "Pleumeur-Bodou",
    "lat": "48.76667",
    "lng": "-3.51667"
  },
  {
    "country": "FR",
    "name": "Pleumeleuc",
    "lat": "48.18438",
    "lng": "-1.91962"
  },
  {
    "country": "FR",
    "name": "Pleumartin",
    "lat": "46.73786",
    "lng": "0.769"
  },
  {
    "country": "FR",
    "name": "Pleugueneuc",
    "lat": "48.39735",
    "lng": "-1.90301"
  },
  {
    "country": "FR",
    "name": "Pleugriffet",
    "lat": "47.98594",
    "lng": "-2.68454"
  },
  {
    "country": "FR",
    "name": "Pleudihen-sur-Rance",
    "lat": "48.51667",
    "lng": "-1.96667"
  },
  {
    "country": "FR",
    "name": "Pleudaniel",
    "lat": "48.76644",
    "lng": "-3.14033"
  },
  {
    "country": "FR",
    "name": "Pleucadeuc",
    "lat": "47.75876",
    "lng": "-2.37362"
  },
  {
    "country": "FR",
    "name": "Pleubian",
    "lat": "48.84267",
    "lng": "-3.139"
  },
  {
    "country": "FR",
    "name": "Plestin-les-Grèves",
    "lat": "48.65844",
    "lng": "-3.63056"
  },
  {
    "country": "FR",
    "name": "Plestan",
    "lat": "48.42266",
    "lng": "-2.44777"
  },
  {
    "country": "FR",
    "name": "Plessé",
    "lat": "47.5418",
    "lng": "-1.88609"
  },
  {
    "country": "FR",
    "name": "Plessala",
    "lat": "48.27642",
    "lng": "-2.61876"
  },
  {
    "country": "FR",
    "name": "Pleslin-Trigavou",
    "lat": "48.53333",
    "lng": "-2.06667"
  },
  {
    "country": "FR",
    "name": "Plescop",
    "lat": "47.69726",
    "lng": "-2.8056"
  },
  {
    "country": "FR",
    "name": "Plérin",
    "lat": "48.54249",
    "lng": "-2.77983"
  },
  {
    "country": "FR",
    "name": "Plerguer",
    "lat": "48.52676",
    "lng": "-1.84769"
  },
  {
    "country": "FR",
    "name": "Pléneuf-Val-André",
    "lat": "48.593",
    "lng": "-2.54675"
  },
  {
    "country": "FR",
    "name": "Plénée-Jugon",
    "lat": "48.36462",
    "lng": "-2.40036"
  },
  {
    "country": "FR",
    "name": "Plémy",
    "lat": "48.33644",
    "lng": "-2.68244"
  },
  {
    "country": "FR",
    "name": "Plémet",
    "lat": "48.17601",
    "lng": "-2.59325"
  },
  {
    "country": "FR",
    "name": "Plélo",
    "lat": "48.55534",
    "lng": "-2.94634"
  },
  {
    "country": "FR",
    "name": "Plélan-le-Petit",
    "lat": "48.43157",
    "lng": "-2.2174"
  },
  {
    "country": "FR",
    "name": "Plélan-le-Grand",
    "lat": "48.00124",
    "lng": "-2.09914"
  },
  {
    "country": "FR",
    "name": "Pleine-Fougères",
    "lat": "48.53308",
    "lng": "-1.56534"
  },
  {
    "country": "FR",
    "name": "Fréhel",
    "lat": "48.63333",
    "lng": "-2.36667"
  },
  {
    "country": "FR",
    "name": "Pléhédel",
    "lat": "48.69645",
    "lng": "-3.00833"
  },
  {
    "country": "FR",
    "name": "Pléguien",
    "lat": "48.63525",
    "lng": "-2.94001"
  },
  {
    "country": "FR",
    "name": "Plédran",
    "lat": "48.446",
    "lng": "-2.74667"
  },
  {
    "country": "FR",
    "name": "Plédéliac",
    "lat": "48.45",
    "lng": "-2.38333"
  },
  {
    "country": "FR",
    "name": "Pléchâtel",
    "lat": "47.89496",
    "lng": "-1.74876"
  },
  {
    "country": "FR",
    "name": "Pleaux",
    "lat": "45.13333",
    "lng": "2.23333"
  },
  {
    "country": "FR",
    "name": "Plauzat",
    "lat": "45.62171",
    "lng": "3.14896"
  },
  {
    "country": "FR",
    "name": "Plaudren",
    "lat": "47.77868",
    "lng": "-2.69331"
  },
  {
    "country": "FR",
    "name": "Plappeville",
    "lat": "49.13019",
    "lng": "6.12471"
  },
  {
    "country": "FR",
    "name": "Planguenoual",
    "lat": "48.533",
    "lng": "-2.57642"
  },
  {
    "country": "FR",
    "name": "Le Plan-de-la-Tour",
    "lat": "43.33333",
    "lng": "6.55"
  },
  {
    "country": "FR",
    "name": "Plan-de-Cuques",
    "lat": "43.34753",
    "lng": "5.46398"
  },
  {
    "country": "FR",
    "name": "Plan-d'Aups-Sainte-Baume",
    "lat": "43.33333",
    "lng": "5.71667"
  },
  {
    "country": "FR",
    "name": "Plancoët",
    "lat": "48.52199",
    "lng": "-2.2354"
  },
  {
    "country": "FR",
    "name": "Plancher-les-Mines",
    "lat": "47.7615",
    "lng": "6.74308"
  },
  {
    "country": "FR",
    "name": "Plancher-Bas",
    "lat": "47.71977",
    "lng": "6.73041"
  },
  {
    "country": "FR",
    "name": "Plaisir",
    "lat": "48.82319",
    "lng": "1.9541"
  },
  {
    "country": "FR",
    "name": "Plaisance-du-Touch",
    "lat": "43.56566",
    "lng": "1.29749"
  },
  {
    "country": "FR",
    "name": "Plaisance",
    "lat": "43.60436",
    "lng": "0.04615"
  },
  {
    "country": "FR",
    "name": "Plaintel",
    "lat": "48.40733",
    "lng": "-2.81733"
  },
  {
    "country": "FR",
    "name": "Plainfaing",
    "lat": "48.17284",
    "lng": "7.01539"
  },
  {
    "country": "FR",
    "name": "Plaine-Haute",
    "lat": "48.44442",
    "lng": "-2.85416"
  },
  {
    "country": "FR",
    "name": "Plaimpied-Givaudins",
    "lat": "46.998",
    "lng": "2.45428"
  },
  {
    "country": "FR",
    "name": "Plailly",
    "lat": "49.10288",
    "lng": "2.58549"
  },
  {
    "country": "FR",
    "name": "Plabennec",
    "lat": "48.50244",
    "lng": "-4.42656"
  },
  {
    "country": "FR",
    "name": "Pîtres",
    "lat": "49.31667",
    "lng": "1.23333"
  },
  {
    "country": "FR",
    "name": "Pithiviers-le-Vieil",
    "lat": "48.16313",
    "lng": "2.20922"
  },
  {
    "country": "FR",
    "name": "Pithiviers",
    "lat": "48.16667",
    "lng": "2.25"
  },
  {
    "country": "FR",
    "name": "Pissy-Pôville",
    "lat": "49.52986",
    "lng": "0.99281"
  },
  {
    "country": "FR",
    "name": "Pissotte",
    "lat": "46.49725",
    "lng": "-0.80666"
  },
  {
    "country": "FR",
    "name": "Pissos",
    "lat": "44.30833",
    "lng": "-0.77963"
  },
  {
    "country": "FR",
    "name": "Pirou",
    "lat": "49.18089",
    "lng": "-1.57384"
  },
  {
    "country": "FR",
    "name": "Piriac-sur-Mer",
    "lat": "47.37938",
    "lng": "-2.54616"
  },
  {
    "country": "FR",
    "name": "Pirey",
    "lat": "47.26136",
    "lng": "5.96466"
  },
  {
    "country": "FR",
    "name": "Piré-sur-Seiche",
    "lat": "48.00958",
    "lng": "-1.42909"
  },
  {
    "country": "FR",
    "name": "Pipriac",
    "lat": "47.80953",
    "lng": "-1.94638"
  },
  {
    "country": "FR",
    "name": "Pionsat",
    "lat": "46.10949",
    "lng": "2.69362"
  },
  {
    "country": "FR",
    "name": "Piolenc",
    "lat": "44.17945",
    "lng": "4.76408"
  },
  {
    "country": "FR",
    "name": "Pinsaguel",
    "lat": "43.5104",
    "lng": "1.38831"
  },
  {
    "country": "FR",
    "name": "Pinon",
    "lat": "49.48916",
    "lng": "3.44703"
  },
  {
    "country": "FR",
    "name": "Piney",
    "lat": "48.36366",
    "lng": "4.33325"
  },
  {
    "country": "FR",
    "name": "Pinet",
    "lat": "43.40556",
    "lng": "3.51"
  },
  {
    "country": "FR",
    "name": "Pignans",
    "lat": "43.30128",
    "lng": "6.22748"
  },
  {
    "country": "FR",
    "name": "Pignan",
    "lat": "43.58365",
    "lng": "3.75981"
  },
  {
    "country": "FR",
    "name": "Pietrosella",
    "lat": "41.83618",
    "lng": "8.84578"
  },
  {
    "country": "FR",
    "name": "Pietranera",
    "lat": "42.72338",
    "lng": "9.45621"
  },
  {
    "country": "FR",
    "name": "Pierry",
    "lat": "49.02024",
    "lng": "3.94071"
  },
  {
    "country": "FR",
    "name": "Pierrevillers",
    "lat": "49.22468",
    "lng": "6.10337"
  },
  {
    "country": "FR",
    "name": "Pierrevert",
    "lat": "43.81634",
    "lng": "5.74638"
  },
  {
    "country": "FR",
    "name": "Pierres",
    "lat": "48.59209",
    "lng": "1.56444"
  },
  {
    "country": "FR",
    "name": "Pierrepont",
    "lat": "49.41614",
    "lng": "5.714"
  },
  {
    "country": "FR",
    "name": "Pierrelaye",
    "lat": "49.0211",
    "lng": "2.15481"
  },
  {
    "country": "FR",
    "name": "Pierrelatte",
    "lat": "44.37756",
    "lng": "4.70198"
  },
  {
    "country": "FR",
    "name": "Pierrefort",
    "lat": "44.92203",
    "lng": "2.839"
  },
  {
    "country": "FR",
    "name": "Pierrefontaine-les-Varans",
    "lat": "47.21601",
    "lng": "6.5403"
  },
  {
    "country": "FR",
    "name": "Pierrefonds",
    "lat": "49.34878",
    "lng": "2.9779"
  },
  {
    "country": "FR",
    "name": "Pierrefitte-sur-Seine",
    "lat": "48.96691",
    "lng": "2.36104"
  },
  {
    "country": "FR",
    "name": "Pierrefitte-Nestalas",
    "lat": "42.96667",
    "lng": "-0.06667"
  },
  {
    "country": "FR",
    "name": "Pierrefeu-du-Var",
    "lat": "43.22448",
    "lng": "6.14329"
  },
  {
    "country": "FR",
    "name": "Pierre-Châtel",
    "lat": "44.95654",
    "lng": "5.77729"
  },
  {
    "country": "FR",
    "name": "Pierre-Buffière",
    "lat": "45.69193",
    "lng": "1.36193"
  },
  {
    "country": "FR",
    "name": "Pierre-Bénite",
    "lat": "45.7009",
    "lng": "4.82511"
  },
  {
    "country": "FR",
    "name": "Pierre-de-Bresse",
    "lat": "46.88333",
    "lng": "5.25"
  },
  {
    "country": "FR",
    "name": "Piennes",
    "lat": "49.30591",
    "lng": "5.78836"
  },
  {
    "country": "FR",
    "name": "Piégut-Pluviers",
    "lat": "45.62297",
    "lng": "0.69013"
  },
  {
    "country": "FR",
    "name": "Picquigny",
    "lat": "49.94413",
    "lng": "2.14376"
  },
  {
    "country": "FR",
    "name": "Picauville",
    "lat": "49.3781",
    "lng": "-1.40048"
  },
  {
    "country": "FR",
    "name": "Pibrac",
    "lat": "43.62042",
    "lng": "1.2854"
  },
  {
    "country": "FR",
    "name": "Pia",
    "lat": "42.7449",
    "lng": "2.9193"
  },
  {
    "country": "FR",
    "name": "Phalsbourg",
    "lat": "48.76771",
    "lng": "7.2582"
  },
  {
    "country": "FR",
    "name": "Phalempin",
    "lat": "50.51691",
    "lng": "3.01584"
  },
  {
    "country": "FR",
    "name": "Pfulgriesheim",
    "lat": "48.64403",
    "lng": "7.67086"
  },
  {
    "country": "FR",
    "name": "Pfetterhouse",
    "lat": "47.50061",
    "lng": "7.16535"
  },
  {
    "country": "FR",
    "name": "Pfastatt",
    "lat": "47.77044",
    "lng": "7.30103"
  },
  {
    "country": "FR",
    "name": "Pfaffenhoffen",
    "lat": "48.8422",
    "lng": "7.60714"
  },
  {
    "country": "FR",
    "name": "Pfaffenheim",
    "lat": "47.98438",
    "lng": "7.28857"
  },
  {
    "country": "FR",
    "name": "Pézilla-la-Rivière",
    "lat": "42.69536",
    "lng": "2.77115"
  },
  {
    "country": "FR",
    "name": "Pezens",
    "lat": "43.25446",
    "lng": "2.26868"
  },
  {
    "country": "FR",
    "name": "Pézenas",
    "lat": "43.45953",
    "lng": "3.42384"
  },
  {
    "country": "FR",
    "name": "Peyruis",
    "lat": "44.02959",
    "lng": "5.94262"
  },
  {
    "country": "FR",
    "name": "Peyrolles-en-Provence",
    "lat": "43.64532",
    "lng": "5.58347"
  },
  {
    "country": "FR",
    "name": "Peyrins",
    "lat": "45.09241",
    "lng": "5.04767"
  },
  {
    "country": "FR",
    "name": "Peyrilhac",
    "lat": "45.95043",
    "lng": "1.13503"
  },
  {
    "country": "FR",
    "name": "Peyriac-Minervois",
    "lat": "43.29068",
    "lng": "2.56613"
  },
  {
    "country": "FR",
    "name": "Peyriac-de-Mer",
    "lat": "43.0872",
    "lng": "2.95831"
  },
  {
    "country": "FR",
    "name": "Peyrestortes",
    "lat": "42.7548",
    "lng": "2.85232"
  },
  {
    "country": "FR",
    "name": "Peyrehorade",
    "lat": "43.54886",
    "lng": "-1.11574"
  },
  {
    "country": "FR",
    "name": "Peyrat-de-Bellac",
    "lat": "46.14087",
    "lng": "1.03661"
  },
  {
    "country": "FR",
    "name": "Peypin",
    "lat": "43.38503",
    "lng": "5.57788"
  },
  {
    "country": "FR",
    "name": "Peynier",
    "lat": "43.44837",
    "lng": "5.64139"
  },
  {
    "country": "FR",
    "name": "Peymeinade",
    "lat": "43.63636",
    "lng": "6.87776"
  },
  {
    "country": "FR",
    "name": "Peujard",
    "lat": "45.03619",
    "lng": "-0.44096"
  },
  {
    "country": "FR",
    "name": "Petiville",
    "lat": "49.46078",
    "lng": "0.5874"
  },
  {
    "country": "FR",
    "name": "Petit-Réderching",
    "lat": "49.05494",
    "lng": "7.3064"
  },
  {
    "country": "FR",
    "name": "Petit-Noir",
    "lat": "46.93333",
    "lng": "5.33333"
  },
  {
    "country": "FR",
    "name": "Petit-Mars",
    "lat": "47.39512",
    "lng": "-1.45262"
  },
  {
    "country": "FR",
    "name": "Petite-Rosselle",
    "lat": "49.21177",
    "lng": "6.85607"
  },
  {
    "country": "FR",
    "name": "Petite-Forêt",
    "lat": "50.36667",
    "lng": "3.48333"
  },
  {
    "country": "FR",
    "name": "Pessac",
    "lat": "44.81011",
    "lng": "-0.64129"
  },
  {
    "country": "FR",
    "name": "Pesmes",
    "lat": "47.28008",
    "lng": "5.56698"
  },
  {
    "country": "FR",
    "name": "Peschadoires",
    "lat": "45.82391",
    "lng": "3.50243"
  },
  {
    "country": "FR",
    "name": "Pertuis",
    "lat": "43.69252",
    "lng": "5.50285"
  },
  {
    "country": "FR",
    "name": "Perthes",
    "lat": "48.47821",
    "lng": "2.55509"
  },
  {
    "country": "FR",
    "name": "Pers-Jussy",
    "lat": "46.10625",
    "lng": "6.26749"
  },
  {
    "country": "FR",
    "name": "Persan",
    "lat": "49.15335",
    "lng": "2.27218"
  },
  {
    "country": "FR",
    "name": "Perrusson",
    "lat": "47.09873",
    "lng": "1.01438"
  },
  {
    "country": "FR",
    "name": "Perros-Guirec",
    "lat": "48.81454",
    "lng": "-3.43963"
  },
  {
    "country": "FR",
    "name": "Perrigny-lès-Dijon",
    "lat": "47.26648",
    "lng": "5.00628"
  },
  {
    "country": "FR",
    "name": "Perrigny",
    "lat": "46.66744",
    "lng": "5.58456"
  },
  {
    "country": "FR",
    "name": "Perrignier",
    "lat": "46.3064",
    "lng": "6.44465"
  },
  {
    "country": "FR",
    "name": "Perriers-sur-Andelle",
    "lat": "49.41487",
    "lng": "1.37098"
  },
  {
    "country": "FR",
    "name": "Perreux",
    "lat": "46.03838",
    "lng": "4.12205"
  },
  {
    "country": "FR",
    "name": "Perrecy-les-Forges",
    "lat": "46.61453",
    "lng": "4.2138"
  },
  {
    "country": "FR",
    "name": "Perpignan",
    "lat": "42.69764",
    "lng": "2.89541"
  },
  {
    "country": "FR",
    "name": "Péroy-les-Gombries",
    "lat": "49.16248",
    "lng": "2.84556"
  },
  {
    "country": "FR",
    "name": "Pérouges",
    "lat": "45.90735",
    "lng": "5.17273"
  },
  {
    "country": "FR",
    "name": "Péronne",
    "lat": "49.93333",
    "lng": "2.93333"
  },
  {
    "country": "FR",
    "name": "Péronnas",
    "lat": "46.19073",
    "lng": "5.20819"
  },
  {
    "country": "FR",
    "name": "Péron",
    "lat": "46.19053",
    "lng": "5.92524"
  },
  {
    "country": "FR",
    "name": "Pérols",
    "lat": "43.56313",
    "lng": "3.95203"
  },
  {
    "country": "FR",
    "name": "Pernes-les-Fontaines",
    "lat": "44.00028",
    "lng": "5.05141"
  },
  {
    "country": "FR",
    "name": "Pernes",
    "lat": "50.48437",
    "lng": "2.41253"
  },
  {
    "country": "FR",
    "name": "Périgueux",
    "lat": "45.18333",
    "lng": "0.71667"
  },
  {
    "country": "FR",
    "name": "Périgny",
    "lat": "48.69656",
    "lng": "2.55537"
  },
  {
    "country": "FR",
    "name": "Périgny",
    "lat": "46.15519",
    "lng": "-1.09822"
  },
  {
    "country": "FR",
    "name": "Périgneux",
    "lat": "45.44001",
    "lng": "4.15655"
  },
  {
    "country": "FR",
    "name": "Pérignat-sur-Allier",
    "lat": "45.72904",
    "lng": "3.2348"
  },
  {
    "country": "FR",
    "name": "Pérignat-lès-Sarliève",
    "lat": "45.73571",
    "lng": "3.14024"
  },
  {
    "country": "FR",
    "name": "Pérignac",
    "lat": "45.62306",
    "lng": "-0.46488"
  },
  {
    "country": "FR",
    "name": "Périers",
    "lat": "49.18667",
    "lng": "-1.40762"
  },
  {
    "country": "FR",
    "name": "Peri",
    "lat": "42.00394",
    "lng": "8.92096"
  },
  {
    "country": "FR",
    "name": "Pérenchies",
    "lat": "50.67013",
    "lng": "2.97024"
  },
  {
    "country": "FR",
    "name": "Percy",
    "lat": "48.91714",
    "lng": "-1.18916"
  },
  {
    "country": "FR",
    "name": "Pépieux",
    "lat": "43.29735",
    "lng": "2.67952"
  },
  {
    "country": "FR",
    "name": "Penvénan",
    "lat": "48.81182",
    "lng": "-3.2955"
  },
  {
    "country": "FR",
    "name": "Penta-di-Casinca",
    "lat": "42.46687",
    "lng": "9.45902"
  },
  {
    "country": "FR",
    "name": "Pennautier",
    "lat": "43.24513",
    "lng": "2.31892"
  },
  {
    "country": "FR",
    "name": "Pénestin",
    "lat": "47.48226",
    "lng": "-2.47275"
  },
  {
    "country": "FR",
    "name": "Pendé",
    "lat": "50.16055",
    "lng": "1.58541"
  },
  {
    "country": "FR",
    "name": "Pencran",
    "lat": "48.43333",
    "lng": "-4.23333"
  },
  {
    "country": "FR",
    "name": "Pélussin",
    "lat": "45.41808",
    "lng": "4.68248"
  },
  {
    "country": "FR",
    "name": "Peltre",
    "lat": "49.0748",
    "lng": "6.22721"
  },
  {
    "country": "FR",
    "name": "Pelousey",
    "lat": "47.27538",
    "lng": "5.92263"
  },
  {
    "country": "FR",
    "name": "Pellouailles-les-Vignes",
    "lat": "47.52172",
    "lng": "-0.43954"
  },
  {
    "country": "FR",
    "name": "Pellegrue",
    "lat": "44.74355",
    "lng": "0.07595"
  },
  {
    "country": "FR",
    "name": "Pélissanne",
    "lat": "43.63512",
    "lng": "5.15131"
  },
  {
    "country": "FR",
    "name": "Peipin",
    "lat": "44.13778",
    "lng": "5.95722"
  },
  {
    "country": "FR",
    "name": "Peillonnex",
    "lat": "46.13215",
    "lng": "6.3758"
  },
  {
    "country": "FR",
    "name": "Peillon",
    "lat": "43.77861",
    "lng": "7.38278"
  },
  {
    "country": "FR",
    "name": "Peille",
    "lat": "43.80587",
    "lng": "7.40429"
  },
  {
    "country": "FR",
    "name": "Peillac",
    "lat": "47.71391",
    "lng": "-2.21971"
  },
  {
    "country": "FR",
    "name": "Pégomas",
    "lat": "43.5985",
    "lng": "6.93032"
  },
  {
    "country": "FR",
    "name": "Pédernec",
    "lat": "48.59682",
    "lng": "-3.26948"
  },
  {
    "country": "FR",
    "name": "Pecquencourt",
    "lat": "50.3785",
    "lng": "3.21277"
  },
  {
    "country": "FR",
    "name": "Pechbonnieu",
    "lat": "43.70242",
    "lng": "1.46538"
  },
  {
    "country": "FR",
    "name": "Péchabou",
    "lat": "43.50241",
    "lng": "1.50934"
  },
  {
    "country": "FR",
    "name": "Péaule",
    "lat": "47.57972",
    "lng": "-2.35601"
  },
  {
    "country": "FR",
    "name": "Peaugres",
    "lat": "45.28771",
    "lng": "4.7291"
  },
  {
    "country": "FR",
    "name": "Payzac",
    "lat": "45.4",
    "lng": "1.21667"
  },
  {
    "country": "FR",
    "name": "Payrin-Augmontel",
    "lat": "43.5445",
    "lng": "2.35406"
  },
  {
    "country": "FR",
    "name": "Payns",
    "lat": "48.38255",
    "lng": "3.97755"
  },
  {
    "country": "FR",
    "name": "Pavilly",
    "lat": "49.56703",
    "lng": "0.95445"
  },
  {
    "country": "FR",
    "name": "Pavie",
    "lat": "43.60969",
    "lng": "0.59143"
  },
  {
    "country": "FR",
    "name": "Paulx",
    "lat": "46.96181",
    "lng": "-1.7552"
  },
  {
    "country": "FR",
    "name": "Paulhan",
    "lat": "43.53944",
    "lng": "3.4576"
  },
  {
    "country": "FR",
    "name": "Paulhaguet",
    "lat": "45.20782",
    "lng": "3.51417"
  },
  {
    "country": "FR",
    "name": "Paulhac",
    "lat": "43.75639",
    "lng": "1.55667"
  },
  {
    "country": "FR",
    "name": "Pauillac",
    "lat": "45.19644",
    "lng": "-0.74873"
  },
  {
    "country": "FR",
    "name": "Pau",
    "lat": "43.3",
    "lng": "-0.36667"
  },
  {
    "country": "FR",
    "name": "Patay",
    "lat": "48.04833",
    "lng": "1.695"
  },
  {
    "country": "FR",
    "name": "Passy",
    "lat": "45.92028",
    "lng": "6.68765"
  },
  {
    "country": "FR",
    "name": "Pasly",
    "lat": "49.40167",
    "lng": "3.29631"
  },
  {
    "country": "FR",
    "name": "Paslières",
    "lat": "45.92844",
    "lng": "3.49352"
  },
  {
    "country": "FR",
    "name": "Parthenay",
    "lat": "46.65",
    "lng": "-0.25"
  },
  {
    "country": "FR",
    "name": "Paron",
    "lat": "48.17888",
    "lng": "3.25075"
  },
  {
    "country": "FR",
    "name": "Parmain",
    "lat": "49.11247",
    "lng": "2.21487"
  },
  {
    "country": "FR",
    "name": "Paris",
    "lat": "48.85341",
    "lng": "2.3488"
  },
  {
    "country": "FR",
    "name": "Parigny",
    "lat": "48.5945",
    "lng": "-1.07925"
  },
  {
    "country": "FR",
    "name": "Parigné-le-Pôlin",
    "lat": "47.84987",
    "lng": "0.10705"
  },
  {
    "country": "FR",
    "name": "Parigné",
    "lat": "48.42727",
    "lng": "-1.1921"
  },
  {
    "country": "FR",
    "name": "Pargny-sur-Saulx",
    "lat": "48.76866",
    "lng": "4.83758"
  },
  {
    "country": "FR",
    "name": "Parentis-en-Born",
    "lat": "44.35274",
    "lng": "-1.07095"
  },
  {
    "country": "FR",
    "name": "Parempuyre",
    "lat": "44.95038",
    "lng": "-0.60453"
  },
  {
    "country": "FR",
    "name": "Parcé-sur-Sarthe",
    "lat": "47.84356",
    "lng": "-0.20104"
  },
  {
    "country": "FR",
    "name": "Parçay-Meslay",
    "lat": "47.44195",
    "lng": "0.74847"
  },
  {
    "country": "FR",
    "name": "Parçay-les-Pins",
    "lat": "47.43668",
    "lng": "0.16312"
  },
  {
    "country": "FR",
    "name": "Paray-Vieille-Poste",
    "lat": "48.71402",
    "lng": "2.36283"
  },
  {
    "country": "FR",
    "name": "Paray-le-Monial",
    "lat": "46.45457",
    "lng": "4.11584"
  },
  {
    "country": "FR",
    "name": "Paradou",
    "lat": "43.71729",
    "lng": "4.78458"
  },
  {
    "country": "FR",
    "name": "Pantin",
    "lat": "48.89437",
    "lng": "2.40935"
  },
  {
    "country": "FR",
    "name": "Pannes",
    "lat": "48.01937",
    "lng": "2.66755"
  },
  {
    "country": "FR",
    "name": "Pannecé",
    "lat": "47.48583",
    "lng": "-1.2394"
  },
  {
    "country": "FR",
    "name": "Panissières",
    "lat": "45.79282",
    "lng": "4.33955"
  },
  {
    "country": "FR",
    "name": "Pancé",
    "lat": "47.88181",
    "lng": "-1.65953"
  },
  {
    "country": "FR",
    "name": "Panazol",
    "lat": "45.83465",
    "lng": "1.32759"
  },
  {
    "country": "FR",
    "name": "Pamproux",
    "lat": "46.39578",
    "lng": "-0.05327"
  },
  {
    "country": "FR",
    "name": "Pamiers",
    "lat": "43.11667",
    "lng": "1.6"
  },
  {
    "country": "FR",
    "name": "Palinges",
    "lat": "46.55357",
    "lng": "4.21964"
  },
  {
    "country": "FR",
    "name": "Palavas-les-Flots",
    "lat": "43.52805",
    "lng": "3.92705"
  },
  {
    "country": "FR",
    "name": "Palau-del-Vidre",
    "lat": "42.57162",
    "lng": "2.96033"
  },
  {
    "country": "FR",
    "name": "Palaja",
    "lat": "43.17363",
    "lng": "2.38462"
  },
  {
    "country": "FR",
    "name": "Palaiseau",
    "lat": "48.71667",
    "lng": "2.25"
  },
  {
    "country": "FR",
    "name": "Paimpont",
    "lat": "48.01809",
    "lng": "-2.17105"
  },
  {
    "country": "FR",
    "name": "Paimpol",
    "lat": "48.77841",
    "lng": "-3.04375"
  },
  {
    "country": "FR",
    "name": "Paimboeuf",
    "lat": "47.28654",
    "lng": "-2.03048"
  },
  {
    "country": "FR",
    "name": "Paillet",
    "lat": "44.68512",
    "lng": "-0.365"
  },
  {
    "country": "FR",
    "name": "Pagny-sur-Moselle",
    "lat": "48.98349",
    "lng": "6.02084"
  },
  {
    "country": "FR",
    "name": "Pacy-sur-Eure",
    "lat": "49.01667",
    "lng": "1.38333"
  },
  {
    "country": "FR",
    "name": "Pacé",
    "lat": "48.14848",
    "lng": "-1.77327"
  },
  {
    "country": "FR",
    "name": "Pabu",
    "lat": "48.58608",
    "lng": "-3.13608"
  },
  {
    "country": "FR",
    "name": "Ozouer-le-Voulgis",
    "lat": "48.66012",
    "lng": "2.77409"
  },
  {
    "country": "FR",
    "name": "Ozoir-la-Ferrière",
    "lat": "48.76699",
    "lng": "2.66871"
  },
  {
    "country": "FR",
    "name": "Oytier-Saint-Oblas",
    "lat": "45.56104",
    "lng": "5.02065"
  },
  {
    "country": "FR",
    "name": "Oyonnax",
    "lat": "46.25917",
    "lng": "5.65727"
  },
  {
    "country": "FR",
    "name": "Oye-Plage",
    "lat": "50.97713",
    "lng": "2.04276"
  },
  {
    "country": "FR",
    "name": "Ouzouer-sur-Trézée",
    "lat": "47.67266",
    "lng": "2.808"
  },
  {
    "country": "FR",
    "name": "Ouzouer-sur-Loire",
    "lat": "47.76638",
    "lng": "2.48038"
  },
  {
    "country": "FR",
    "name": "Ouzouer-le-Marché",
    "lat": "47.91055",
    "lng": "1.52607"
  },
  {
    "country": "FR",
    "name": "Ouveillan",
    "lat": "43.28915",
    "lng": "2.97124"
  },
  {
    "country": "FR",
    "name": "Outreau",
    "lat": "50.70535",
    "lng": "1.5897"
  },
  {
    "country": "FR",
    "name": "Outarville",
    "lat": "48.21393",
    "lng": "2.02198"
  },
  {
    "country": "FR",
    "name": "Ousse",
    "lat": "43.28333",
    "lng": "-0.26667"
  },
  {
    "country": "FR",
    "name": "Ourville-en-Caux",
    "lat": "49.72854",
    "lng": "0.6046"
  },
  {
    "country": "FR",
    "name": "Oursbelille",
    "lat": "43.28508",
    "lng": "0.03473"
  },
  {
    "country": "FR",
    "name": "Ouroux-sur-Saône",
    "lat": "46.72147",
    "lng": "4.95262"
  },
  {
    "country": "FR",
    "name": "Oullins",
    "lat": "45.71774",
    "lng": "4.80382"
  },
  {
    "country": "FR",
    "name": "Oulins",
    "lat": "48.86451",
    "lng": "1.47038"
  },
  {
    "country": "FR",
    "name": "Ouistreham",
    "lat": "49.27566",
    "lng": "-0.2591"
  },
  {
    "country": "FR",
    "name": "Ouges",
    "lat": "47.26164",
    "lng": "5.07395"
  },
  {
    "country": "FR",
    "name": "Oudon",
    "lat": "47.34774",
    "lng": "-1.285"
  },
  {
    "country": "FR",
    "name": "Oucques",
    "lat": "47.82252",
    "lng": "1.29383"
  },
  {
    "country": "FR",
    "name": "Ouches",
    "lat": "46.01657",
    "lng": "3.98824"
  },
  {
    "country": "FR",
    "name": "Ottrott",
    "lat": "48.45642",
    "lng": "7.42556"
  },
  {
    "country": "FR",
    "name": "Ottmarsheim",
    "lat": "47.78655",
    "lng": "7.50935"
  },
  {
    "country": "FR",
    "name": "Otterswiller",
    "lat": "48.72568",
    "lng": "7.37878"
  },
  {
    "country": "FR",
    "name": "Ottange",
    "lat": "49.44307",
    "lng": "6.01988"
  },
  {
    "country": "FR",
    "name": "Othis",
    "lat": "49.07387",
    "lng": "2.67502"
  },
  {
    "country": "FR",
    "name": "Ostwald",
    "lat": "48.54369",
    "lng": "7.71099"
  },
  {
    "country": "FR",
    "name": "Ostricourt",
    "lat": "50.45145",
    "lng": "3.03417"
  },
  {
    "country": "FR",
    "name": "Ostheim",
    "lat": "48.15999",
    "lng": "7.36982"
  },
  {
    "country": "FR",
    "name": "Ossun",
    "lat": "43.18333",
    "lng": "-0.03333"
  },
  {
    "country": "FR",
    "name": "Osséja",
    "lat": "42.41383",
    "lng": "1.98192"
  },
  {
    "country": "FR",
    "name": "Ossé",
    "lat": "48.05542",
    "lng": "-1.45029"
  },
  {
    "country": "FR",
    "name": "Osny",
    "lat": "49.0701",
    "lng": "2.06277"
  },
  {
    "country": "FR",
    "name": "Orvault",
    "lat": "47.27095",
    "lng": "-1.6219"
  },
  {
    "country": "FR",
    "name": "Orval",
    "lat": "46.72581",
    "lng": "2.47144"
  },
  {
    "country": "FR",
    "name": "Orthez",
    "lat": "43.48839",
    "lng": "-0.77244"
  },
  {
    "country": "FR",
    "name": "Ortaffa",
    "lat": "42.57977",
    "lng": "2.92653"
  },
  {
    "country": "FR",
    "name": "Orsay",
    "lat": "48.69572",
    "lng": "2.18727"
  },
  {
    "country": "FR",
    "name": "Orsan",
    "lat": "44.13106",
    "lng": "4.6652"
  },
  {
    "country": "FR",
    "name": "Orry-la-Ville",
    "lat": "49.13345",
    "lng": "2.51139"
  },
  {
    "country": "FR",
    "name": "Ornex",
    "lat": "46.2727",
    "lng": "6.09982"
  },
  {
    "country": "FR",
    "name": "Ornans",
    "lat": "47.10749",
    "lng": "6.14306"
  },
  {
    "country": "FR",
    "name": "Ornaisons",
    "lat": "43.1804",
    "lng": "2.83689"
  },
  {
    "country": "FR",
    "name": "Ormoy",
    "lat": "48.57489",
    "lng": "2.45206"
  },
  {
    "country": "FR",
    "name": "Ormesson-sur-Marne",
    "lat": "48.7863",
    "lng": "2.54471"
  },
  {
    "country": "FR",
    "name": "Ormes",
    "lat": "47.94152",
    "lng": "1.81823"
  },
  {
    "country": "FR",
    "name": "Orly",
    "lat": "48.74792",
    "lng": "2.39253"
  },
  {
    "country": "FR",
    "name": "Orliénas",
    "lat": "45.65859",
    "lng": "4.71707"
  },
  {
    "country": "FR",
    "name": "Orleix",
    "lat": "43.27932",
    "lng": "0.12033"
  },
  {
    "country": "FR",
    "name": "Orléat",
    "lat": "45.86163",
    "lng": "3.42194"
  },
  {
    "country": "FR",
    "name": "Orléans",
    "lat": "47.90289",
    "lng": "1.90389"
  },
  {
    "country": "FR",
    "name": "Orival",
    "lat": "49.72429",
    "lng": "1.20512"
  },
  {
    "country": "FR",
    "name": "Origny-Sainte-Benoite",
    "lat": "49.83333",
    "lng": "3.5"
  },
  {
    "country": "FR",
    "name": "Origny-en-Thiérache",
    "lat": "49.89327",
    "lng": "4.01644"
  },
  {
    "country": "FR",
    "name": "Orgueil",
    "lat": "43.90618",
    "lng": "1.41071"
  },
  {
    "country": "FR",
    "name": "Orgon",
    "lat": "43.79108",
    "lng": "5.03869"
  },
  {
    "country": "FR",
    "name": "Orgeval",
    "lat": "48.92162",
    "lng": "1.9779"
  },
  {
    "country": "FR",
    "name": "Orgerus",
    "lat": "48.83851",
    "lng": "1.70132"
  },
  {
    "country": "FR",
    "name": "Orgères-en-Beauce",
    "lat": "48.14636",
    "lng": "1.6838"
  },
  {
    "country": "FR",
    "name": "Orgères",
    "lat": "47.99886",
    "lng": "-1.66781"
  },
  {
    "country": "FR",
    "name": "Orgelet",
    "lat": "46.52096",
    "lng": "5.61049"
  },
  {
    "country": "FR",
    "name": "Orcines",
    "lat": "45.7838",
    "lng": "3.0122"
  },
  {
    "country": "FR",
    "name": "Orchies",
    "lat": "50.46667",
    "lng": "3.23333"
  },
  {
    "country": "FR",
    "name": "Orchamps-Vennes",
    "lat": "47.13042",
    "lng": "6.52468"
  },
  {
    "country": "FR",
    "name": "Orchamps",
    "lat": "47.14751",
    "lng": "5.65873"
  },
  {
    "country": "FR",
    "name": "Orcet",
    "lat": "45.70351",
    "lng": "3.16807"
  },
  {
    "country": "FR",
    "name": "Orbey",
    "lat": "48.12651",
    "lng": "7.16455"
  },
  {
    "country": "FR",
    "name": "Orbec",
    "lat": "49.01667",
    "lng": "0.41667"
  },
  {
    "country": "FR",
    "name": "Orange",
    "lat": "44.1392",
    "lng": "4.80791"
  },
  {
    "country": "FR",
    "name": "Oraison",
    "lat": "43.91609",
    "lng": "5.91756"
  },
  {
    "country": "FR",
    "name": "Oradour-sur-Vayres",
    "lat": "45.73286",
    "lng": "0.86457"
  },
  {
    "country": "FR",
    "name": "Oradour-sur-Glane",
    "lat": "45.93405",
    "lng": "1.0317"
  },
  {
    "country": "FR",
    "name": "Oppède",
    "lat": "43.82865",
    "lng": "5.16161"
  },
  {
    "country": "FR",
    "name": "Opio",
    "lat": "43.66862",
    "lng": "6.98212"
  },
  {
    "country": "FR",
    "name": "Onzain",
    "lat": "47.49956",
    "lng": "1.17701"
  },
  {
    "country": "FR",
    "name": "Ons-en-Bray",
    "lat": "49.41631",
    "lng": "1.92302"
  },
  {
    "country": "FR",
    "name": "Onnaing",
    "lat": "50.38584",
    "lng": "3.59963"
  },
  {
    "country": "FR",
    "name": "Onesse-Laharie",
    "lat": "44.06146",
    "lng": "-1.06984"
  },
  {
    "country": "FR",
    "name": "Ondres",
    "lat": "43.56461",
    "lng": "-1.44449"
  },
  {
    "country": "FR",
    "name": "Ondes",
    "lat": "43.7825",
    "lng": "1.30823"
  },
  {
    "country": "FR",
    "name": "Omissy",
    "lat": "49.8776",
    "lng": "3.31235"
  },
  {
    "country": "FR",
    "name": "Oloron-Sainte-Marie",
    "lat": "43.19441",
    "lng": "-0.61069"
  },
  {
    "country": "FR",
    "name": "Olonzac",
    "lat": "43.28294",
    "lng": "2.73098"
  },
  {
    "country": "FR",
    "name": "Olonne-sur-Mer",
    "lat": "46.53524",
    "lng": "-1.77293"
  },
  {
    "country": "FR",
    "name": "Olmeto",
    "lat": "41.71885",
    "lng": "8.92023"
  },
  {
    "country": "FR",
    "name": "Ollioules",
    "lat": "43.13517",
    "lng": "5.848"
  },
  {
    "country": "FR",
    "name": "Ollainville",
    "lat": "48.59081",
    "lng": "2.21936"
  },
  {
    "country": "FR",
    "name": "Olivet",
    "lat": "47.86219",
    "lng": "1.8991"
  },
  {
    "country": "FR",
    "name": "Oletta",
    "lat": "42.63237",
    "lng": "9.356"
  },
  {
    "country": "FR",
    "name": "Olemps",
    "lat": "44.34638",
    "lng": "2.5514"
  },
  {
    "country": "FR",
    "name": "Oisy-le-Verger",
    "lat": "50.25047",
    "lng": "3.1233"
  },
  {
    "country": "FR",
    "name": "Oissery",
    "lat": "49.07047",
    "lng": "2.81819"
  },
  {
    "country": "FR",
    "name": "Oissel",
    "lat": "49.33309",
    "lng": "1.09413"
  },
  {
    "country": "FR",
    "name": "Oisseau",
    "lat": "48.35559",
    "lng": "-0.67148"
  },
  {
    "country": "FR",
    "name": "Oisemont",
    "lat": "49.95587",
    "lng": "1.76703"
  },
  {
    "country": "FR",
    "name": "Oinville-sur-Montcient",
    "lat": "49.02722",
    "lng": "1.84928"
  },
  {
    "country": "FR",
    "name": "Oignies",
    "lat": "50.46331",
    "lng": "2.99376"
  },
  {
    "country": "FR",
    "name": "Ohlungen",
    "lat": "48.81352",
    "lng": "7.70225"
  },
  {
    "country": "FR",
    "name": "Ognes",
    "lat": "49.61244",
    "lng": "3.1934"
  },
  {
    "country": "FR",
    "name": "Ogeu-les-Bains",
    "lat": "43.15",
    "lng": "-0.5"
  },
  {
    "country": "FR",
    "name": "Offranville",
    "lat": "49.87208",
    "lng": "1.04817"
  },
  {
    "country": "FR",
    "name": "Offenheim",
    "lat": "48.63208",
    "lng": "7.61668"
  },
  {
    "country": "FR",
    "name": "Offemont",
    "lat": "47.66416",
    "lng": "6.88056"
  },
  {
    "country": "FR",
    "name": "Oeyreluy",
    "lat": "43.66876",
    "lng": "-1.08276"
  },
  {
    "country": "FR",
    "name": "Œting",
    "lat": "49.17291",
    "lng": "6.91472"
  },
  {
    "country": "FR",
    "name": "Oermingen",
    "lat": "49.00043",
    "lng": "7.129"
  },
  {
    "country": "FR",
    "name": "Odos",
    "lat": "43.19622",
    "lng": "0.05693"
  },
  {
    "country": "FR",
    "name": "Oderen",
    "lat": "47.91053",
    "lng": "6.97475"
  },
  {
    "country": "FR",
    "name": "Octeville-sur-Mer",
    "lat": "49.55496",
    "lng": "0.1166"
  },
  {
    "country": "FR",
    "name": "Octeville",
    "lat": "49.62612",
    "lng": "-1.64349"
  },
  {
    "country": "FR",
    "name": "Objat",
    "lat": "45.26238",
    "lng": "1.40781"
  },
  {
    "country": "FR",
    "name": "Oberschaeffolsheim",
    "lat": "48.58643",
    "lng": "7.65018"
  },
  {
    "country": "FR",
    "name": "Obernai",
    "lat": "48.46313",
    "lng": "7.481"
  },
  {
    "country": "FR",
    "name": "Obermodern-Zutzendorf",
    "lat": "48.85",
    "lng": "7.53333"
  },
  {
    "country": "FR",
    "name": "Oberhoffen-sur-Moder",
    "lat": "48.78366",
    "lng": "7.86347"
  },
  {
    "country": "FR",
    "name": "Oberhergheim",
    "lat": "47.96849",
    "lng": "7.39609"
  },
  {
    "country": "FR",
    "name": "Oberhausbergen",
    "lat": "48.60607",
    "lng": "7.68846"
  },
  {
    "country": "FR",
    "name": "Oberhaslach",
    "lat": "48.55039",
    "lng": "7.33213"
  },
  {
    "country": "FR",
    "name": "Oberbronn",
    "lat": "48.9402",
    "lng": "7.607"
  },
  {
    "country": "FR",
    "name": "Betschdorf",
    "lat": "48.89825",
    "lng": "7.90196"
  },
  {
    "country": "FR",
    "name": "Obenheim",
    "lat": "48.35975",
    "lng": "7.692"
  },
  {
    "country": "FR",
    "name": "Nyons",
    "lat": "44.36667",
    "lng": "5.13333"
  },
  {
    "country": "FR",
    "name": "Nyoiseau",
    "lat": "47.71667",
    "lng": "-0.91667"
  },
  {
    "country": "FR",
    "name": "Nuits-Saint-Georges",
    "lat": "47.13683",
    "lng": "4.949"
  },
  {
    "country": "FR",
    "name": "Nuillé-sur-Vicoin",
    "lat": "47.98556",
    "lng": "-0.78351"
  },
  {
    "country": "FR",
    "name": "Nueil-sur-Layon",
    "lat": "47.11811",
    "lng": "-0.36573"
  },
  {
    "country": "FR",
    "name": "Nueil-les-Aubiers",
    "lat": "46.93333",
    "lng": "-0.58333"
  },
  {
    "country": "FR",
    "name": "Nuaillé",
    "lat": "47.09524",
    "lng": "-0.79477"
  },
  {
    "country": "FR",
    "name": "Nozay",
    "lat": "48.65921",
    "lng": "2.24151"
  },
  {
    "country": "FR",
    "name": "Nozay",
    "lat": "47.56495",
    "lng": "-1.62629"
  },
  {
    "country": "FR",
    "name": "Noyon",
    "lat": "49.58333",
    "lng": "3"
  },
  {
    "country": "FR",
    "name": "Noyers-sur-Cher",
    "lat": "47.27701",
    "lng": "1.4032"
  },
  {
    "country": "FR",
    "name": "Noyen-sur-Sarthe",
    "lat": "47.87187",
    "lng": "-0.09916"
  },
  {
    "country": "FR",
    "name": "Noyelles-sous-Lens",
    "lat": "50.43084",
    "lng": "2.87221"
  },
  {
    "country": "FR",
    "name": "Noyelles-lès-Vermelles",
    "lat": "50.49001",
    "lng": "2.72628"
  },
  {
    "country": "FR",
    "name": "Noyelles-Godault",
    "lat": "50.41753",
    "lng": "2.99306"
  },
  {
    "country": "FR",
    "name": "Noyarey",
    "lat": "45.2476",
    "lng": "5.62837"
  },
  {
    "country": "FR",
    "name": "Noyant-la-Gravoyère",
    "lat": "47.70348",
    "lng": "-0.9573"
  },
  {
    "country": "FR",
    "name": "Noyant",
    "lat": "47.51048",
    "lng": "0.11771"
  },
  {
    "country": "FR",
    "name": "Noyal-sur-Vilaine",
    "lat": "48.11219",
    "lng": "-1.52333"
  },
  {
    "country": "FR",
    "name": "Noyal-Pontivy",
    "lat": "48.06667",
    "lng": "-2.88333"
  },
  {
    "country": "FR",
    "name": "Noyal-Muzillac",
    "lat": "47.59169",
    "lng": "-2.45557"
  },
  {
    "country": "FR",
    "name": "Novillars",
    "lat": "47.28465",
    "lng": "6.12878"
  },
  {
    "country": "FR",
    "name": "Noves",
    "lat": "43.87736",
    "lng": "4.90248"
  },
  {
    "country": "FR",
    "name": "Novéant-sur-Moselle",
    "lat": "49.02366",
    "lng": "6.04795"
  },
  {
    "country": "FR",
    "name": "Novalaise",
    "lat": "45.59693",
    "lng": "5.76591"
  },
  {
    "country": "FR",
    "name": "Nouzonville",
    "lat": "49.81369",
    "lng": "4.74736"
  },
  {
    "country": "FR",
    "name": "Nouzilly",
    "lat": "47.54499",
    "lng": "0.74623"
  },
  {
    "country": "FR",
    "name": "Nouvoitou",
    "lat": "48.04105",
    "lng": "-1.54714"
  },
  {
    "country": "FR",
    "name": "Nouvion-sur-Meuse",
    "lat": "49.69949",
    "lng": "4.79562"
  },
  {
    "country": "FR",
    "name": "Nouvion",
    "lat": "50.2",
    "lng": "1.78333"
  },
  {
    "country": "FR",
    "name": "Nousty",
    "lat": "43.26667",
    "lng": "-0.21667"
  },
  {
    "country": "FR",
    "name": "Nouan-le-Fuzelier",
    "lat": "47.536",
    "lng": "2.03647"
  },
  {
    "country": "FR",
    "name": "Nouaillé-Maupertuis",
    "lat": "46.51113",
    "lng": "0.41667"
  },
  {
    "country": "FR",
    "name": "Notre-Dame-des-Landes",
    "lat": "47.38048",
    "lng": "-1.70904"
  },
  {
    "country": "FR",
    "name": "Notre-Dame-de-Sanilhac",
    "lat": "45.12121",
    "lng": "0.71157"
  },
  {
    "country": "FR",
    "name": "Notre-Dame-de-Riez",
    "lat": "46.74445",
    "lng": "-1.90857"
  },
  {
    "country": "FR",
    "name": "Notre-Dame-de-Monts",
    "lat": "46.831",
    "lng": "-2.131"
  },
  {
    "country": "FR",
    "name": "Notre-Dame-de-Mésage",
    "lat": "45.06241",
    "lng": "5.7588"
  },
  {
    "country": "FR",
    "name": "Notre-Dame-de-Gravenchon",
    "lat": "49.4894",
    "lng": "0.57188"
  },
  {
    "country": "FR",
    "name": "Notre-Dame-de-Bondeville",
    "lat": "49.48333",
    "lng": "1.05"
  },
  {
    "country": "FR",
    "name": "Nostang",
    "lat": "47.7487",
    "lng": "-3.18639"
  },
  {
    "country": "FR",
    "name": "Nort-sur-Erdre",
    "lat": "47.43881",
    "lng": "-1.49833"
  },
  {
    "country": "FR",
    "name": "Nortkerque",
    "lat": "50.87519",
    "lng": "2.02464"
  },
  {
    "country": "FR",
    "name": "Norroy-lès-Pont-à-Mousson",
    "lat": "48.9346",
    "lng": "6.02806"
  },
  {
    "country": "FR",
    "name": "Norrent-Fontes",
    "lat": "50.58333",
    "lng": "2.4"
  },
  {
    "country": "FR",
    "name": "Normanville",
    "lat": "49.07868",
    "lng": "1.15915"
  },
  {
    "country": "FR",
    "name": "Nordhouse",
    "lat": "48.44833",
    "lng": "7.67326"
  },
  {
    "country": "FR",
    "name": "Nontron",
    "lat": "45.53333",
    "lng": "0.66667"
  },
  {
    "country": "FR",
    "name": "Nonancourt",
    "lat": "48.77086",
    "lng": "1.19799"
  },
  {
    "country": "FR",
    "name": "Nommay",
    "lat": "47.5378",
    "lng": "6.84219"
  },
  {
    "country": "FR",
    "name": "Nomexy",
    "lat": "48.30741",
    "lng": "6.38572"
  },
  {
    "country": "FR",
    "name": "Nomeny",
    "lat": "48.9",
    "lng": "6.23333"
  },
  {
    "country": "FR",
    "name": "Nomain",
    "lat": "50.49857",
    "lng": "3.24991"
  },
  {
    "country": "FR",
    "name": "Nolay",
    "lat": "46.95202",
    "lng": "4.63405"
  },
  {
    "country": "FR",
    "name": "Noizay",
    "lat": "47.42188",
    "lng": "0.89201"
  },
  {
    "country": "FR",
    "name": "Noisy-sur-École",
    "lat": "48.36701",
    "lng": "2.50804"
  },
  {
    "country": "FR",
    "name": "Noisy-le-Sec",
    "lat": "48.89148",
    "lng": "2.46451"
  },
  {
    "country": "FR",
    "name": "Noisy-le-Roi",
    "lat": "48.84445",
    "lng": "2.06345"
  },
  {
    "country": "FR",
    "name": "Noisy-le-Grand",
    "lat": "48.84979",
    "lng": "2.56266"
  },
  {
    "country": "FR",
    "name": "Noisiel",
    "lat": "48.84868",
    "lng": "2.62435"
  },
  {
    "country": "FR",
    "name": "Noiseau",
    "lat": "48.77589",
    "lng": "2.54892"
  },
  {
    "country": "FR",
    "name": "Noirmoutier-en-l’Île",
    "lat": "46.99733",
    "lng": "-2.27374"
  },
  {
    "country": "FR",
    "name": "Noirétable",
    "lat": "45.818",
    "lng": "3.76276"
  },
  {
    "country": "FR",
    "name": "Nointot",
    "lat": "49.59822",
    "lng": "0.47674"
  },
  {
    "country": "FR",
    "name": "Noidans-lès-Vesoul",
    "lat": "47.61299",
    "lng": "6.12571"
  },
  {
    "country": "FR",
    "name": "Nohic",
    "lat": "43.8897",
    "lng": "1.43741"
  },
  {
    "country": "FR",
    "name": "Nohanent",
    "lat": "45.81003",
    "lng": "3.05658"
  },
  {
    "country": "FR",
    "name": "Nogent-sur-Vernisson",
    "lat": "47.84603",
    "lng": "2.74267"
  },
  {
    "country": "FR",
    "name": "Nogent-sur-Seine",
    "lat": "48.48333",
    "lng": "3.5"
  },
  {
    "country": "FR",
    "name": "Nogent-sur-Oise",
    "lat": "49.27158",
    "lng": "2.47074"
  },
  {
    "country": "FR",
    "name": "Nogent-sur-Marne",
    "lat": "48.83333",
    "lng": "2.48333"
  },
  {
    "country": "FR",
    "name": "Nogent-le-Rotrou",
    "lat": "48.31667",
    "lng": "0.83333"
  },
  {
    "country": "FR",
    "name": "Nogent-le-Roi",
    "lat": "48.64785",
    "lng": "1.52933"
  },
  {
    "country": "FR",
    "name": "Nogent-le-Phaye",
    "lat": "48.44528",
    "lng": "1.57777"
  },
  {
    "country": "FR",
    "name": "Nogent-le-Bas",
    "lat": "48.01974",
    "lng": "5.33323"
  },
  {
    "country": "FR",
    "name": "Nogent-l’Artaud",
    "lat": "48.9656",
    "lng": "3.32178"
  },
  {
    "country": "FR",
    "name": "Nogentel",
    "lat": "49.0175",
    "lng": "3.4025"
  },
  {
    "country": "FR",
    "name": "Nogaro",
    "lat": "43.75856",
    "lng": "-0.03293"
  },
  {
    "country": "FR",
    "name": "Nœux-les-Mines",
    "lat": "50.48333",
    "lng": "2.66667"
  },
  {
    "country": "FR",
    "name": "Noé",
    "lat": "43.35814",
    "lng": "1.27709"
  },
  {
    "country": "FR",
    "name": "Noailles",
    "lat": "49.32866",
    "lng": "2.20024"
  },
  {
    "country": "FR",
    "name": "Noaillan",
    "lat": "44.48057",
    "lng": "-0.3664"
  },
  {
    "country": "FR",
    "name": "Nivolas-Vermelle",
    "lat": "45.55518",
    "lng": "5.30682"
  },
  {
    "country": "FR",
    "name": "Nivillac",
    "lat": "47.53371",
    "lng": "-2.28298"
  },
  {
    "country": "FR",
    "name": "Nissan-lez-Enserune",
    "lat": "43.28961",
    "lng": "3.12705"
  },
  {
    "country": "FR",
    "name": "Niort",
    "lat": "46.32313",
    "lng": "-0.45877"
  },
  {
    "country": "FR",
    "name": "Nîmes",
    "lat": "43.83378",
    "lng": "4.35962"
  },
  {
    "country": "FR",
    "name": "Nilvange",
    "lat": "49.34224",
    "lng": "6.04964"
  },
  {
    "country": "FR",
    "name": "Niherne",
    "lat": "46.82768",
    "lng": "1.56384"
  },
  {
    "country": "FR",
    "name": "Niévroz",
    "lat": "45.83333",
    "lng": "5.06667"
  },
  {
    "country": "FR",
    "name": "Nieul-sur-Mer",
    "lat": "46.20583",
    "lng": "-1.16449"
  },
  {
    "country": "FR",
    "name": "Nieul-lès-Saintes",
    "lat": "45.76021",
    "lng": "-0.73137"
  },
  {
    "country": "FR",
    "name": "Nieul-le-Dolent",
    "lat": "46.57379",
    "lng": "-1.50808"
  },
  {
    "country": "FR",
    "name": "Nieul",
    "lat": "45.92668",
    "lng": "1.17494"
  },
  {
    "country": "FR",
    "name": "Nieppe",
    "lat": "50.70425",
    "lng": "2.83506"
  },
  {
    "country": "FR",
    "name": "Niederschaeffolsheim",
    "lat": "48.77241",
    "lng": "7.73862"
  },
  {
    "country": "FR",
    "name": "Niedernai",
    "lat": "48.45101",
    "lng": "7.51635"
  },
  {
    "country": "FR",
    "name": "Niederhausbergen",
    "lat": "48.624",
    "lng": "7.7021"
  },
  {
    "country": "FR",
    "name": "Niederhaslach",
    "lat": "48.54264",
    "lng": "7.34282"
  },
  {
    "country": "FR",
    "name": "Niederbronn-les-Bains",
    "lat": "48.95165",
    "lng": "7.64271"
  },
  {
    "country": "FR",
    "name": "Niderviller",
    "lat": "48.71294",
    "lng": "7.10627"
  },
  {
    "country": "FR",
    "name": "Nice",
    "lat": "43.70313",
    "lng": "7.26608"
  },
  {
    "country": "FR",
    "name": "Neydens",
    "lat": "46.12162",
    "lng": "6.10436"
  },
  {
    "country": "FR",
    "name": "Nexon",
    "lat": "45.67962",
    "lng": "1.18555"
  },
  {
    "country": "FR",
    "name": "Nevoy",
    "lat": "47.71591",
    "lng": "2.57791"
  },
  {
    "country": "FR",
    "name": "Néville",
    "lat": "49.82472",
    "lng": "0.70862"
  },
  {
    "country": "FR",
    "name": "Névian",
    "lat": "43.21238",
    "lng": "2.90286"
  },
  {
    "country": "FR",
    "name": "Névez",
    "lat": "47.81924",
    "lng": "-3.79225"
  },
  {
    "country": "FR",
    "name": "Nevers",
    "lat": "46.98956",
    "lng": "3.159"
  },
  {
    "country": "FR",
    "name": "Neuwiller-lès-Saverne",
    "lat": "48.82506",
    "lng": "7.40513"
  },
  {
    "country": "FR",
    "name": "Neuvy-sur-Loire",
    "lat": "47.52323",
    "lng": "2.88333"
  },
  {
    "country": "FR",
    "name": "Neuvy-sur-Barangeon",
    "lat": "47.31495",
    "lng": "2.25343"
  },
  {
    "country": "FR",
    "name": "Neuvy-Sautour",
    "lat": "48.0419",
    "lng": "3.79472"
  },
  {
    "country": "FR",
    "name": "Neuvy-Saint-Sépulchre",
    "lat": "46.59781",
    "lng": "1.80601"
  },
  {
    "country": "FR",
    "name": "Neuvy-Pailloux",
    "lat": "46.88486",
    "lng": "1.86152"
  },
  {
    "country": "FR",
    "name": "Neuvy-le-Roi",
    "lat": "47.60386",
    "lng": "0.59472"
  },
  {
    "country": "FR",
    "name": "Neuvy",
    "lat": "46.56037",
    "lng": "3.2899"
  },
  {
    "country": "FR",
    "name": "Neuville-sur-Sarthe",
    "lat": "48.07615",
    "lng": "0.19264"
  },
  {
    "country": "FR",
    "name": "Neuville-sur-Saône",
    "lat": "45.87704",
    "lng": "4.8492"
  },
  {
    "country": "FR",
    "name": "Neuville-sur-Oise",
    "lat": "49.01667",
    "lng": "2.06667"
  },
  {
    "country": "FR",
    "name": "Neuville-sur-Escaut",
    "lat": "50.3",
    "lng": "3.35"
  },
  {
    "country": "FR",
    "name": "Neuville-sur-Ain",
    "lat": "46.08074",
    "lng": "5.37764"
  },
  {
    "country": "FR",
    "name": "Neuville-Saint-Vaast",
    "lat": "50.35756",
    "lng": "2.76261"
  },
  {
    "country": "FR",
    "name": "Neuville-Saint-Rémy",
    "lat": "50.18618",
    "lng": "3.22404"
  },
  {
    "country": "FR",
    "name": "Neuville-les-Dames",
    "lat": "46.16228",
    "lng": "5.00399"
  },
  {
    "country": "FR",
    "name": "Neuville-en-Ferrain",
    "lat": "50.74839",
    "lng": "3.15676"
  },
  {
    "country": "FR",
    "name": "Neuville-de-Poitou",
    "lat": "46.68333",
    "lng": "0.25"
  },
  {
    "country": "FR",
    "name": "Neuville-aux-Bois",
    "lat": "48.06813",
    "lng": "2.05372"
  },
  {
    "country": "FR",
    "name": "Neuvic-Entier",
    "lat": "45.72206",
    "lng": "1.61303"
  },
  {
    "country": "FR",
    "name": "Neuvic",
    "lat": "45.38333",
    "lng": "2.28333"
  },
  {
    "country": "FR",
    "name": "Neuvic",
    "lat": "45.10033",
    "lng": "0.46901"
  },
  {
    "country": "FR",
    "name": "Neuves-Maisons",
    "lat": "48.62029",
    "lng": "6.10698"
  },
  {
    "country": "FR",
    "name": "Neuvéglise",
    "lat": "44.92787",
    "lng": "2.98343"
  },
  {
    "country": "FR",
    "name": "Neuvecelle",
    "lat": "46.39502",
    "lng": "6.61257"
  },
  {
    "country": "FR",
    "name": "Neussargues-Moissac",
    "lat": "45.1326",
    "lng": "2.97985"
  },
  {
    "country": "FR",
    "name": "Neung-sur-Beuvron",
    "lat": "47.53486",
    "lng": "1.80514"
  },
  {
    "country": "FR",
    "name": "Neulliac",
    "lat": "48.12836",
    "lng": "-2.98289"
  },
  {
    "country": "FR",
    "name": "Neulise",
    "lat": "45.90279",
    "lng": "4.18094"
  },
  {
    "country": "FR",
    "name": "Neuilly-sur-Seine",
    "lat": "48.8846",
    "lng": "2.26965"
  },
  {
    "country": "FR",
    "name": "Neuilly-sur-Marne",
    "lat": "48.85373",
    "lng": "2.54903"
  },
  {
    "country": "FR",
    "name": "Neuilly-sous-Clermont",
    "lat": "49.34437",
    "lng": "2.4103"
  },
  {
    "country": "FR",
    "name": "Neuilly-Saint-Front",
    "lat": "49.17012",
    "lng": "3.26393"
  },
  {
    "country": "FR",
    "name": "Neuilly-Plaisance",
    "lat": "48.86342",
    "lng": "2.506"
  },
  {
    "country": "FR",
    "name": "Neuilly-lès-Dijon",
    "lat": "47.27943",
    "lng": "5.10645"
  },
  {
    "country": "FR",
    "name": "Neuilly-le-Réal",
    "lat": "46.46466",
    "lng": "3.43161"
  },
  {
    "country": "FR",
    "name": "Neuilly-en-Thelle",
    "lat": "49.22445",
    "lng": "2.28525"
  },
  {
    "country": "FR",
    "name": "Neuillé-Pont-Pierre",
    "lat": "47.5484",
    "lng": "0.54962"
  },
  {
    "country": "FR",
    "name": "Neufmoutiers-en-Brie",
    "lat": "48.76882",
    "lng": "2.83156"
  },
  {
    "country": "FR",
    "name": "Neufmanil",
    "lat": "49.81096",
    "lng": "4.79673"
  },
  {
    "country": "FR",
    "name": "Neufgrange",
    "lat": "49.07679",
    "lng": "7.06526"
  },
  {
    "country": "FR",
    "name": "Neufchef",
    "lat": "49.31678",
    "lng": "6.02416"
  },
  {
    "country": "FR",
    "name": "Neufchâtel-Hardelot",
    "lat": "50.62018",
    "lng": "1.64223"
  },
  {
    "country": "FR",
    "name": "Neufchâtel-en-Bray",
    "lat": "49.73315",
    "lng": "1.43956"
  },
  {
    "country": "FR",
    "name": "Neufchâteau",
    "lat": "48.35",
    "lng": "5.7"
  },
  {
    "country": "FR",
    "name": "Neuf-Brisach",
    "lat": "48.01783",
    "lng": "7.52795"
  },
  {
    "country": "FR",
    "name": "Neuf-Berquin",
    "lat": "50.66065",
    "lng": "2.67213"
  },
  {
    "country": "FR",
    "name": "Nesmy",
    "lat": "46.59078",
    "lng": "-1.40074"
  },
  {
    "country": "FR",
    "name": "Nesles-la-Vallée",
    "lat": "49.13202",
    "lng": "2.17099"
  },
  {
    "country": "FR",
    "name": "Nesles-la-Montagne",
    "lat": "49.01964",
    "lng": "3.42607"
  },
  {
    "country": "FR",
    "name": "Nesles",
    "lat": "50.62588",
    "lng": "1.65641"
  },
  {
    "country": "FR",
    "name": "Nesle",
    "lat": "49.75888",
    "lng": "2.91133"
  },
  {
    "country": "FR",
    "name": "Nersac",
    "lat": "45.63333",
    "lng": "0.05"
  },
  {
    "country": "FR",
    "name": "Nérondes",
    "lat": "46.99758",
    "lng": "2.81834"
  },
  {
    "country": "FR",
    "name": "Néris-les-Bains",
    "lat": "46.28688",
    "lng": "2.65869"
  },
  {
    "country": "FR",
    "name": "Nercillac",
    "lat": "45.71667",
    "lng": "-0.25"
  },
  {
    "country": "FR",
    "name": "Nérac",
    "lat": "44.13333",
    "lng": "0.35"
  },
  {
    "country": "FR",
    "name": "Néoules",
    "lat": "43.31034",
    "lng": "6.01298"
  },
  {
    "country": "FR",
    "name": "Nemours",
    "lat": "48.27511",
    "lng": "2.69078"
  },
  {
    "country": "FR",
    "name": "Nègrepelisse",
    "lat": "44.07436",
    "lng": "1.51978"
  },
  {
    "country": "FR",
    "name": "Nébian",
    "lat": "43.60657",
    "lng": "3.43133"
  },
  {
    "country": "FR",
    "name": "Neauphle-le-Château",
    "lat": "48.81418",
    "lng": "1.90567"
  },
  {
    "country": "FR",
    "name": "Neaufles-Saint-Martin",
    "lat": "49.2765",
    "lng": "1.72794"
  },
  {
    "country": "FR",
    "name": "Nazelles-Négron",
    "lat": "47.43333",
    "lng": "0.95"
  },
  {
    "country": "FR",
    "name": "Nay",
    "lat": "43.18333",
    "lng": "-0.26667"
  },
  {
    "country": "FR",
    "name": "Naves",
    "lat": "45.31395",
    "lng": "1.76708"
  },
  {
    "country": "FR",
    "name": "Navenne",
    "lat": "47.60873",
    "lng": "6.16176"
  },
  {
    "country": "FR",
    "name": "Naveil",
    "lat": "47.79576",
    "lng": "1.03222"
  },
  {
    "country": "FR",
    "name": "Navarrenx",
    "lat": "43.32135",
    "lng": "-0.75927"
  },
  {
    "country": "FR",
    "name": "Navailles-Angos",
    "lat": "43.41667",
    "lng": "-0.33333"
  },
  {
    "country": "FR",
    "name": "Naucelles",
    "lat": "44.95782",
    "lng": "2.41889"
  },
  {
    "country": "FR",
    "name": "Naucelle",
    "lat": "44.1981",
    "lng": "2.3431"
  },
  {
    "country": "FR",
    "name": "Nassandres",
    "lat": "49.12632",
    "lng": "0.73597"
  },
  {
    "country": "FR",
    "name": "Narrosse",
    "lat": "43.70381",
    "lng": "-1.00742"
  },
  {
    "country": "FR",
    "name": "Nargis",
    "lat": "48.11106",
    "lng": "2.75597"
  },
  {
    "country": "FR",
    "name": "Narbonne",
    "lat": "43.18396",
    "lng": "3.00141"
  },
  {
    "country": "FR",
    "name": "Naours",
    "lat": "50.03682",
    "lng": "2.27691"
  },
  {
    "country": "FR",
    "name": "Nantua",
    "lat": "46.15",
    "lng": "5.61667"
  },
  {
    "country": "FR",
    "name": "Nantiat",
    "lat": "46.0091",
    "lng": "1.17308"
  },
  {
    "country": "FR",
    "name": "Nanteuil-lès-Meaux",
    "lat": "48.9294",
    "lng": "2.89594"
  },
  {
    "country": "FR",
    "name": "Nanteuil-le-Haudouin",
    "lat": "49.14082",
    "lng": "2.81142"
  },
  {
    "country": "FR",
    "name": "Nanteuil-en-Vallée",
    "lat": "46.00089",
    "lng": "0.32206"
  },
  {
    "country": "FR",
    "name": "Nanteuil",
    "lat": "46.41172",
    "lng": "-0.17461"
  },
  {
    "country": "FR",
    "name": "Nantes",
    "lat": "47.21725",
    "lng": "-1.55336"
  },
  {
    "country": "FR",
    "name": "Nanterre",
    "lat": "48.89198",
    "lng": "2.20675"
  },
  {
    "country": "FR",
    "name": "Nans-les-Pins",
    "lat": "43.37035",
    "lng": "5.7834"
  },
  {
    "country": "FR",
    "name": "Nangis",
    "lat": "48.55535",
    "lng": "3.01306"
  },
  {
    "country": "FR",
    "name": "Nandy",
    "lat": "48.58301",
    "lng": "2.56292"
  },
  {
    "country": "FR",
    "name": "Nancy",
    "lat": "48.68439",
    "lng": "6.18496"
  },
  {
    "country": "FR",
    "name": "Nancray",
    "lat": "47.24536",
    "lng": "6.18283"
  },
  {
    "country": "FR",
    "name": "Nalliers",
    "lat": "46.47071",
    "lng": "-1.02774"
  },
  {
    "country": "FR",
    "name": "Naizin",
    "lat": "47.98993",
    "lng": "-2.83287"
  },
  {
    "country": "FR",
    "name": "Naintré",
    "lat": "46.76354",
    "lng": "0.48683"
  },
  {
    "country": "FR",
    "name": "Nailloux",
    "lat": "43.35718",
    "lng": "1.62302"
  },
  {
    "country": "FR",
    "name": "Nages-et-Solorgues",
    "lat": "43.7901",
    "lng": "4.23027"
  },
  {
    "country": "FR",
    "name": "Muzillac",
    "lat": "47.55451",
    "lng": "-2.48041"
  },
  {
    "country": "FR",
    "name": "Mutzig",
    "lat": "48.53974",
    "lng": "7.45594"
  },
  {
    "country": "FR",
    "name": "Muttersholtz",
    "lat": "48.26761",
    "lng": "7.53567"
  },
  {
    "country": "FR",
    "name": "Mussy-sur-Seine",
    "lat": "47.97791",
    "lng": "4.49743"
  },
  {
    "country": "FR",
    "name": "Mussig",
    "lat": "48.22993",
    "lng": "7.51963"
  },
  {
    "country": "FR",
    "name": "Mussidan",
    "lat": "45.03542",
    "lng": "0.3629"
  },
  {
    "country": "FR",
    "name": "Mus",
    "lat": "43.73919",
    "lng": "4.20257"
  },
  {
    "country": "FR",
    "name": "Murviel-lès-Montpellier",
    "lat": "43.60528",
    "lng": "3.7375"
  },
  {
    "country": "FR",
    "name": "Murviel-lès-Béziers",
    "lat": "43.43333",
    "lng": "3.13333"
  },
  {
    "country": "FR",
    "name": "Mûrs-Erigné",
    "lat": "47.4",
    "lng": "-0.55"
  },
  {
    "country": "FR",
    "name": "Muron",
    "lat": "46.03444",
    "lng": "-0.82867"
  },
  {
    "country": "FR",
    "name": "Muret",
    "lat": "43.46667",
    "lng": "1.35"
  },
  {
    "country": "FR",
    "name": "Mur-de-Sologne",
    "lat": "47.41239",
    "lng": "1.60832"
  },
  {
    "country": "FR",
    "name": "Mûr-de-Bretagne",
    "lat": "48.2",
    "lng": "-2.98333"
  },
  {
    "country": "FR",
    "name": "Murat",
    "lat": "45.10797",
    "lng": "2.86665"
  },
  {
    "country": "FR",
    "name": "Munster",
    "lat": "48.04089",
    "lng": "7.13338"
  },
  {
    "country": "FR",
    "name": "Mundolsheim",
    "lat": "48.64215",
    "lng": "7.71378"
  },
  {
    "country": "FR",
    "name": "Munchhouse",
    "lat": "47.8678",
    "lng": "7.45167"
  },
  {
    "country": "FR",
    "name": "Mulsanne",
    "lat": "47.91172",
    "lng": "0.24938"
  },
  {
    "country": "FR",
    "name": "Mulhouse",
    "lat": "47.75",
    "lng": "7.33333"
  },
  {
    "country": "FR",
    "name": "Muizon",
    "lat": "49.27499",
    "lng": "3.89083"
  },
  {
    "country": "FR",
    "name": "Muides-sur-Loire",
    "lat": "47.66958",
    "lng": "1.52694"
  },
  {
    "country": "FR",
    "name": "Mugron",
    "lat": "43.74952",
    "lng": "-0.75179"
  },
  {
    "country": "FR",
    "name": "Mudaison",
    "lat": "43.63333",
    "lng": "4.03333"
  },
  {
    "country": "FR",
    "name": "Mozé-sur-Louet",
    "lat": "47.35856",
    "lng": "-0.55295"
  },
  {
    "country": "FR",
    "name": "Mozac",
    "lat": "45.89166",
    "lng": "3.09095"
  },
  {
    "country": "FR",
    "name": "Moyrazès",
    "lat": "44.34204",
    "lng": "2.43933"
  },
  {
    "country": "FR",
    "name": "Moyeuvre-Grande",
    "lat": "49.25294",
    "lng": "6.04467"
  },
  {
    "country": "FR",
    "name": "Moyenmoutier",
    "lat": "48.3773",
    "lng": "6.90047"
  },
  {
    "country": "FR",
    "name": "Moye",
    "lat": "45.87911",
    "lng": "5.91435"
  },
  {
    "country": "FR",
    "name": "Moyaux",
    "lat": "49.19511",
    "lng": "0.35603"
  },
  {
    "country": "FR",
    "name": "Mouzon",
    "lat": "49.60706",
    "lng": "5.07569"
  },
  {
    "country": "FR",
    "name": "Mouzillon",
    "lat": "47.14096",
    "lng": "-1.28191"
  },
  {
    "country": "FR",
    "name": "Mouzeil",
    "lat": "47.44738",
    "lng": "-1.34786"
  },
  {
    "country": "FR",
    "name": "Mouy",
    "lat": "49.31535",
    "lng": "2.31954"
  },
  {
    "country": "FR",
    "name": "Mouxy",
    "lat": "45.68399",
    "lng": "5.93538"
  },
  {
    "country": "FR",
    "name": "Mouvaux",
    "lat": "50.69944",
    "lng": "3.13429"
  },
  {
    "country": "FR",
    "name": "Moutiers",
    "lat": "49.23369",
    "lng": "5.96498"
  },
  {
    "country": "FR",
    "name": "Moûtiers",
    "lat": "45.48333",
    "lng": "6.53333"
  },
  {
    "country": "FR",
    "name": "Mouthiers-sur-Boëme",
    "lat": "45.55",
    "lng": "0.11667"
  },
  {
    "country": "FR",
    "name": "Moustoir-Ac",
    "lat": "47.85461",
    "lng": "-2.83481"
  },
  {
    "country": "FR",
    "name": "Moussy-le-Vieux",
    "lat": "49.04712",
    "lng": "2.62493"
  },
  {
    "country": "FR",
    "name": "Moussy-le-Neuf",
    "lat": "49.06427",
    "lng": "2.60252"
  },
  {
    "country": "FR",
    "name": "Moussan",
    "lat": "43.23091",
    "lng": "2.95"
  },
  {
    "country": "FR",
    "name": "Moussac",
    "lat": "43.98119",
    "lng": "4.22647"
  },
  {
    "country": "FR",
    "name": "Mours-Saint-Eusèbe",
    "lat": "45.06829",
    "lng": "5.05752"
  },
  {
    "country": "FR",
    "name": "Mours",
    "lat": "49.13077",
    "lng": "2.26761"
  },
  {
    "country": "FR",
    "name": "Mouroux",
    "lat": "48.82263",
    "lng": "3.03879"
  },
  {
    "country": "FR",
    "name": "Mourmelon-le-Grand",
    "lat": "49.13256",
    "lng": "4.3642"
  },
  {
    "country": "FR",
    "name": "Mouriès",
    "lat": "43.68997",
    "lng": "4.87089"
  },
  {
    "country": "FR",
    "name": "Mouret",
    "lat": "43.36126",
    "lng": "5.43006"
  },
  {
    "country": "FR",
    "name": "Mourenx",
    "lat": "43.38333",
    "lng": "-0.6"
  },
  {
    "country": "FR",
    "name": "Moult",
    "lat": "49.11494",
    "lng": "-0.16472"
  },
  {
    "country": "FR",
    "name": "Moulis-en-Médoc",
    "lat": "45.05938",
    "lng": "-0.77033"
  },
  {
    "country": "FR",
    "name": "Moulins-lès-Metz",
    "lat": "49.10434",
    "lng": "6.10832"
  },
  {
    "country": "FR",
    "name": "Moulins-Engilbert",
    "lat": "46.98821",
    "lng": "3.81084"
  },
  {
    "country": "FR",
    "name": "Moulins",
    "lat": "46.56667",
    "lng": "3.33333"
  },
  {
    "country": "FR",
    "name": "Mouliets-et-Villemartin",
    "lat": "44.83333",
    "lng": "-0.01667"
  },
  {
    "country": "FR",
    "name": "Mouleydier",
    "lat": "44.85572",
    "lng": "0.59759"
  },
  {
    "country": "FR",
    "name": "Moulay",
    "lat": "48.27245",
    "lng": "-0.62734"
  },
  {
    "country": "FR",
    "name": "Mouilleron-le-Captif",
    "lat": "46.71898",
    "lng": "-1.45463"
  },
  {
    "country": "FR",
    "name": "Mouilleron-en-Pareds",
    "lat": "46.6763",
    "lng": "-0.8494"
  },
  {
    "country": "FR",
    "name": "Mouguerre",
    "lat": "43.46795",
    "lng": "-1.41824"
  },
  {
    "country": "FR",
    "name": "Mougon",
    "lat": "46.29561",
    "lng": "-0.28659"
  },
  {
    "country": "FR",
    "name": "Mougins",
    "lat": "43.59873",
    "lng": "7.00434"
  },
  {
    "country": "FR",
    "name": "Mouen",
    "lat": "49.14696",
    "lng": "-0.48366"
  },
  {
    "country": "FR",
    "name": "Mouchin",
    "lat": "50.51639",
    "lng": "3.29627"
  },
  {
    "country": "FR",
    "name": "Mouchard",
    "lat": "46.97259",
    "lng": "5.79626"
  },
  {
    "country": "FR",
    "name": "Mouchamps",
    "lat": "46.78131",
    "lng": "-1.06179"
  },
  {
    "country": "FR",
    "name": "Mouans-Sartoux",
    "lat": "43.62224",
    "lng": "6.97312"
  },
  {
    "country": "FR",
    "name": "Morzine",
    "lat": "46.18149",
    "lng": "6.70664"
  },
  {
    "country": "FR",
    "name": "Morvillars",
    "lat": "47.54874",
    "lng": "6.93439"
  },
  {
    "country": "FR",
    "name": "Mortrée",
    "lat": "48.63899",
    "lng": "0.07909"
  },
  {
    "country": "FR",
    "name": "Morteau",
    "lat": "47.05784",
    "lng": "6.60716"
  },
  {
    "country": "FR",
    "name": "Mortcerf",
    "lat": "48.78879",
    "lng": "2.91692"
  },
  {
    "country": "FR",
    "name": "Mortain",
    "lat": "48.64782",
    "lng": "-0.94055"
  },
  {
    "country": "FR",
    "name": "Mortagne-sur-Sèvre",
    "lat": "46.99203",
    "lng": "-0.94738"
  },
  {
    "country": "FR",
    "name": "Mortagne-sur-Gironde",
    "lat": "45.48139",
    "lng": "-0.78702"
  },
  {
    "country": "FR",
    "name": "Mortagne-du-Nord",
    "lat": "50.50352",
    "lng": "3.45352"
  },
  {
    "country": "FR",
    "name": "Mortagne-au-Perche",
    "lat": "48.51667",
    "lng": "0.55"
  },
  {
    "country": "FR",
    "name": "Morschwiller-le-Bas",
    "lat": "47.73609",
    "lng": "7.26687"
  },
  {
    "country": "FR",
    "name": "Morsbach",
    "lat": "49.16806",
    "lng": "6.8719"
  },
  {
    "country": "FR",
    "name": "Morsang-sur-Orge",
    "lat": "48.66181",
    "lng": "2.35338"
  },
  {
    "country": "FR",
    "name": "Morre",
    "lat": "47.22595",
    "lng": "6.07512"
  },
  {
    "country": "FR",
    "name": "Morosaglia",
    "lat": "42.436",
    "lng": "9.30694"
  },
  {
    "country": "FR",
    "name": "Mornas",
    "lat": "44.20025",
    "lng": "4.72902"
  },
  {
    "country": "FR",
    "name": "Mornant",
    "lat": "45.61897",
    "lng": "4.6737"
  },
  {
    "country": "FR",
    "name": "Mornac",
    "lat": "45.68333",
    "lng": "0.26667"
  },
  {
    "country": "FR",
    "name": "Mormoiron",
    "lat": "44.06783",
    "lng": "5.17885"
  },
  {
    "country": "FR",
    "name": "Mormant",
    "lat": "48.60901",
    "lng": "2.89025"
  },
  {
    "country": "FR",
    "name": "Morlaix",
    "lat": "48.58333",
    "lng": "-3.83333"
  },
  {
    "country": "FR",
    "name": "Morlaas",
    "lat": "43.35",
    "lng": "-0.26667"
  },
  {
    "country": "FR",
    "name": "Morigny-Champigny",
    "lat": "48.44685",
    "lng": "2.18351"
  },
  {
    "country": "FR",
    "name": "Morières-lès-Avignon",
    "lat": "43.9403",
    "lng": "4.9011"
  },
  {
    "country": "FR",
    "name": "Morienval",
    "lat": "49.2977",
    "lng": "2.92078"
  },
  {
    "country": "FR",
    "name": "Morhange",
    "lat": "48.92359",
    "lng": "6.64163"
  },
  {
    "country": "FR",
    "name": "Morez",
    "lat": "46.5254",
    "lng": "6.02589"
  },
  {
    "country": "FR",
    "name": "Moreuil",
    "lat": "49.77457",
    "lng": "2.48273"
  },
  {
    "country": "FR",
    "name": "Moret-sur-Loing",
    "lat": "48.37239",
    "lng": "2.81713"
  },
  {
    "country": "FR",
    "name": "Morestel",
    "lat": "45.676",
    "lng": "5.47079"
  },
  {
    "country": "FR",
    "name": "Morée",
    "lat": "47.90397",
    "lng": "1.23421"
  },
  {
    "country": "FR",
    "name": "Moréac",
    "lat": "47.91967",
    "lng": "-2.81934"
  },
  {
    "country": "FR",
    "name": "Mordelles",
    "lat": "48.07571",
    "lng": "-1.84286"
  },
  {
    "country": "FR",
    "name": "Morcenx",
    "lat": "44.03536",
    "lng": "-0.91375"
  },
  {
    "country": "FR",
    "name": "Morbier",
    "lat": "46.53693",
    "lng": "6.01532"
  },
  {
    "country": "FR",
    "name": "Morbecque",
    "lat": "50.69365",
    "lng": "2.51787"
  },
  {
    "country": "FR",
    "name": "Morannes",
    "lat": "47.74364",
    "lng": "-0.41604"
  },
  {
    "country": "FR",
    "name": "Morangis",
    "lat": "48.70383",
    "lng": "2.33908"
  },
  {
    "country": "FR",
    "name": "Morancez",
    "lat": "48.40051",
    "lng": "1.49388"
  },
  {
    "country": "FR",
    "name": "Morancé",
    "lat": "45.89781",
    "lng": "4.70041"
  },
  {
    "country": "FR",
    "name": "Morainvilliers",
    "lat": "48.92902",
    "lng": "1.93621"
  },
  {
    "country": "FR",
    "name": "Moosch",
    "lat": "47.85968",
    "lng": "7.05007"
  },
  {
    "country": "FR",
    "name": "Montussan",
    "lat": "44.88057",
    "lng": "-0.42181"
  },
  {
    "country": "FR",
    "name": "Montsûrs",
    "lat": "48.13604",
    "lng": "-0.55413"
  },
  {
    "country": "FR",
    "name": "Mont-sous-Vaudrey",
    "lat": "46.97874",
    "lng": "5.60295"
  },
  {
    "country": "FR",
    "name": "Montsoult",
    "lat": "49.06942",
    "lng": "2.31966"
  },
  {
    "country": "FR",
    "name": "Montségur-sur-Lauzon",
    "lat": "44.36135",
    "lng": "4.85926"
  },
  {
    "country": "FR",
    "name": "Mont-Saxonnex",
    "lat": "46.05459",
    "lng": "6.48788"
  },
  {
    "country": "FR",
    "name": "Mont-Saint-Martin",
    "lat": "49.54669",
    "lng": "5.79375"
  },
  {
    "country": "FR",
    "name": "Mont-Saint-Éloi",
    "lat": "50.35105",
    "lng": "2.69249"
  },
  {
    "country": "FR",
    "name": "Mont-Saint-Aignan",
    "lat": "49.46307",
    "lng": "1.09364"
  },
  {
    "country": "FR",
    "name": "Monts",
    "lat": "47.27723",
    "lng": "0.62473"
  },
  {
    "country": "FR",
    "name": "Montry",
    "lat": "48.88409",
    "lng": "2.82915"
  },
  {
    "country": "FR",
    "name": "Montrouge",
    "lat": "48.8162",
    "lng": "2.31393"
  },
  {
    "country": "FR",
    "name": "Montrottier",
    "lat": "45.79142",
    "lng": "4.46627"
  },
  {
    "country": "FR",
    "name": "Montrond-les-Bains",
    "lat": "45.65098",
    "lng": "4.23187"
  },
  {
    "country": "FR",
    "name": "Montrodat",
    "lat": "44.55038",
    "lng": "3.32929"
  },
  {
    "country": "FR",
    "name": "Montricoux",
    "lat": "44.07589",
    "lng": "1.61946"
  },
  {
    "country": "FR",
    "name": "Montrichard",
    "lat": "47.3431",
    "lng": "1.18653"
  },
  {
    "country": "FR",
    "name": "Montrevel-en-Bresse",
    "lat": "46.33664",
    "lng": "5.1234"
  },
  {
    "country": "FR",
    "name": "Montrevault",
    "lat": "47.25965",
    "lng": "-1.04679"
  },
  {
    "country": "FR",
    "name": "Montreux-Château",
    "lat": "47.60857",
    "lng": "7.00423"
  },
  {
    "country": "FR",
    "name": "Montreuil",
    "lat": "50.46667",
    "lng": "1.76667"
  },
  {
    "country": "FR",
    "name": "Montreuil-sur-Ille",
    "lat": "48.30788",
    "lng": "-1.6688"
  },
  {
    "country": "FR",
    "name": "Montreuil-sous-Pérouse",
    "lat": "48.15176",
    "lng": "-1.23946"
  },
  {
    "country": "FR",
    "name": "Montreuil-le-Gast",
    "lat": "48.24647",
    "lng": "-1.72498"
  },
  {
    "country": "FR",
    "name": "Montreuil-Bellay",
    "lat": "47.13106",
    "lng": "-0.15209"
  },
  {
    "country": "FR",
    "name": "Montreuil-aux-Lions",
    "lat": "49.02124",
    "lng": "3.19543"
  },
  {
    "country": "FR",
    "name": "Montreuil",
    "lat": "48.86415",
    "lng": "2.44322"
  },
  {
    "country": "FR",
    "name": "Montrem",
    "lat": "45.13417",
    "lng": "0.59029"
  },
  {
    "country": "FR",
    "name": "Montréjeau",
    "lat": "43.08555",
    "lng": "0.5647"
  },
  {
    "country": "FR",
    "name": "Montredon-Labessonnié",
    "lat": "43.71723",
    "lng": "2.32454"
  },
  {
    "country": "FR",
    "name": "Montredon",
    "lat": "43.24016",
    "lng": "5.36629"
  },
  {
    "country": "FR",
    "name": "Montréal-la-Cluse",
    "lat": "46.18333",
    "lng": "5.58333"
  },
  {
    "country": "FR",
    "name": "Montréal",
    "lat": "43.95016",
    "lng": "0.20358"
  },
  {
    "country": "FR",
    "name": "Montréal",
    "lat": "43.1998",
    "lng": "2.14122"
  },
  {
    "country": "FR",
    "name": "Montrabé",
    "lat": "43.64477",
    "lng": "1.52384"
  },
  {
    "country": "FR",
    "name": "Mont-près-Chambord",
    "lat": "47.56235",
    "lng": "1.45712"
  },
  {
    "country": "FR",
    "name": "Montpont-en-Bresse",
    "lat": "46.5563",
    "lng": "5.16459"
  },
  {
    "country": "FR",
    "name": "Montpon-Ménestérol",
    "lat": "45",
    "lng": "0.16667"
  },
  {
    "country": "FR",
    "name": "Montpezat-de-Quercy",
    "lat": "44.23876",
    "lng": "1.47682"
  },
  {
    "country": "FR",
    "name": "Montpeyroux",
    "lat": "43.6959",
    "lng": "3.50542"
  },
  {
    "country": "FR",
    "name": "Montpellier",
    "lat": "43.61092",
    "lng": "3.87723"
  },
  {
    "country": "FR",
    "name": "Montournais",
    "lat": "46.74191",
    "lng": "-0.76464"
  },
  {
    "country": "FR",
    "name": "Montoison",
    "lat": "44.79693",
    "lng": "4.94186"
  },
  {
    "country": "FR",
    "name": "Montois-la-Montagne",
    "lat": "49.2168",
    "lng": "6.02137"
  },
  {
    "country": "FR",
    "name": "Montoire-sur-le-Loir",
    "lat": "47.75316",
    "lng": "0.86525"
  },
  {
    "country": "FR",
    "name": "Montoir-de-Bretagne",
    "lat": "47.33012",
    "lng": "-2.15107"
  },
  {
    "country": "FR",
    "name": "Montmorot",
    "lat": "46.67541",
    "lng": "5.52283"
  },
  {
    "country": "FR",
    "name": "Montmorillon",
    "lat": "46.43333",
    "lng": "0.86667"
  },
  {
    "country": "FR",
    "name": "Montmorency",
    "lat": "48.98826",
    "lng": "2.3434"
  },
  {
    "country": "FR",
    "name": "Montmoreau-Saint-Cybard",
    "lat": "45.4",
    "lng": "0.13333"
  },
  {
    "country": "FR",
    "name": "Montmirail",
    "lat": "48.87214",
    "lng": "3.53797"
  },
  {
    "country": "FR",
    "name": "Montmeyran",
    "lat": "44.8332",
    "lng": "4.97473"
  },
  {
    "country": "FR",
    "name": "Montmerle-sur-Saône",
    "lat": "46.08333",
    "lng": "4.76667"
  },
  {
    "country": "FR",
    "name": "Montmélian",
    "lat": "45.49994",
    "lng": "6.05047"
  },
  {
    "country": "FR",
    "name": "Montmédy",
    "lat": "49.52096",
    "lng": "5.36835"
  },
  {
    "country": "FR",
    "name": "Montmartin-sur-Mer",
    "lat": "48.98861",
    "lng": "-1.5253"
  },
  {
    "country": "FR",
    "name": "Montmarault",
    "lat": "46.31668",
    "lng": "2.95613"
  },
  {
    "country": "FR",
    "name": "Montmain",
    "lat": "49.40996",
    "lng": "1.23742"
  },
  {
    "country": "FR",
    "name": "Montmagny",
    "lat": "48.97338",
    "lng": "2.34688"
  },
  {
    "country": "FR",
    "name": "Montmacq",
    "lat": "49.48181",
    "lng": "2.90257"
  },
  {
    "country": "FR",
    "name": "Montluel",
    "lat": "45.8519",
    "lng": "5.0578"
  },
  {
    "country": "FR",
    "name": "Montluçon",
    "lat": "46.33333",
    "lng": "2.6"
  },
  {
    "country": "FR",
    "name": "Montlouis-sur-Loire",
    "lat": "47.38845",
    "lng": "0.83208"
  },
  {
    "country": "FR",
    "name": "Montlivault",
    "lat": "47.63987",
    "lng": "1.44487"
  },
  {
    "country": "FR",
    "name": "Montlignon",
    "lat": "49.00636",
    "lng": "2.28705"
  },
  {
    "country": "FR",
    "name": "Montlieu-la-Garde",
    "lat": "45.25",
    "lng": "-0.25"
  },
  {
    "country": "FR",
    "name": "Montlhéry",
    "lat": "48.64004",
    "lng": "2.27465"
  },
  {
    "country": "FR",
    "name": "Montlebon",
    "lat": "47.03778",
    "lng": "6.61111"
  },
  {
    "country": "FR",
    "name": "Montlaur",
    "lat": "43.48935",
    "lng": "1.56807"
  },
  {
    "country": "FR",
    "name": "Montjoire",
    "lat": "43.76899",
    "lng": "1.53362"
  },
  {
    "country": "FR",
    "name": "Montjoie-en-Couserans",
    "lat": "43.0025",
    "lng": "1.16"
  },
  {
    "country": "FR",
    "name": "Montjean-sur-Loire",
    "lat": "47.38842",
    "lng": "-0.85873"
  },
  {
    "country": "FR",
    "name": "Montivilliers",
    "lat": "49.54518",
    "lng": "0.18769"
  },
  {
    "country": "FR",
    "name": "Montigny-sur-Loing",
    "lat": "48.33575",
    "lng": "2.74423"
  },
  {
    "country": "FR",
    "name": "Montigny-lès-Metz",
    "lat": "49.0956",
    "lng": "6.15271"
  },
  {
    "country": "FR",
    "name": "Montigny-lès-Cormeilles",
    "lat": "48.98201",
    "lng": "2.20035"
  },
  {
    "country": "FR",
    "name": "Val-de-Meuse",
    "lat": "48",
    "lng": "5.5"
  },
  {
    "country": "FR",
    "name": "Montigny-Lencoup",
    "lat": "48.45162",
    "lng": "3.06503"
  },
  {
    "country": "FR",
    "name": "Montigny-le-Bretonneux",
    "lat": "48.76636",
    "lng": "2.03405"
  },
  {
    "country": "FR",
    "name": "Montigny-en-Ostrevent",
    "lat": "50.36667",
    "lng": "3.18333"
  },
  {
    "country": "FR",
    "name": "Montigny-en-Gohelle",
    "lat": "50.4254",
    "lng": "2.93902"
  },
  {
    "country": "FR",
    "name": "Montigny",
    "lat": "49.4596",
    "lng": "1.00168"
  },
  {
    "country": "FR",
    "name": "Montigné-le-Brillant",
    "lat": "48.00872",
    "lng": "-0.81488"
  },
  {
    "country": "FR",
    "name": "Montignac",
    "lat": "45.06429",
    "lng": "1.16196"
  },
  {
    "country": "FR",
    "name": "Montier-en-Der",
    "lat": "48.47823",
    "lng": "4.77073"
  },
  {
    "country": "FR",
    "name": "Montierchaume",
    "lat": "46.86362",
    "lng": "1.77181"
  },
  {
    "country": "FR",
    "name": "Monticello",
    "lat": "42.61705",
    "lng": "8.95477"
  },
  {
    "country": "FR",
    "name": "Monthyon",
    "lat": "49.00753",
    "lng": "2.8261"
  },
  {
    "country": "FR",
    "name": "Monthermé",
    "lat": "49.88465",
    "lng": "4.73013"
  },
  {
    "country": "FR",
    "name": "Montguyon",
    "lat": "45.21667",
    "lng": "-0.18333"
  },
  {
    "country": "FR",
    "name": "Montgivray",
    "lat": "46.60324",
    "lng": "1.98162"
  },
  {
    "country": "FR",
    "name": "Montgiscard",
    "lat": "43.46072",
    "lng": "1.56739"
  },
  {
    "country": "FR",
    "name": "Montgeron",
    "lat": "48.70543",
    "lng": "2.45039"
  },
  {
    "country": "FR",
    "name": "Montgermont",
    "lat": "48.15592",
    "lng": "-1.71464"
  },
  {
    "country": "FR",
    "name": "Montgaillard",
    "lat": "42.93333",
    "lng": "1.63333"
  },
  {
    "country": "FR",
    "name": "Montfrin",
    "lat": "43.87596",
    "lng": "4.59959"
  },
  {
    "country": "FR",
    "name": "Montfort-sur-Meu",
    "lat": "48.13542",
    "lng": "-1.95201"
  },
  {
    "country": "FR",
    "name": "Montfort-le-Gesnois",
    "lat": "48.05",
    "lng": "0.41667"
  },
  {
    "country": "FR",
    "name": "Montfort-en-Chalosse",
    "lat": "43.71124",
    "lng": "-0.83947"
  },
  {
    "country": "FR",
    "name": "Montferrier-sur-Lez",
    "lat": "43.66742",
    "lng": "3.85439"
  },
  {
    "country": "FR",
    "name": "Montferrat",
    "lat": "45.48591",
    "lng": "5.59072"
  },
  {
    "country": "FR",
    "name": "Montferrat",
    "lat": "43.61072",
    "lng": "6.48238"
  },
  {
    "country": "FR",
    "name": "Montferrand-le-Château",
    "lat": "47.17536",
    "lng": "5.91534"
  },
  {
    "country": "FR",
    "name": "Montfermeil",
    "lat": "48.8982",
    "lng": "2.57913"
  },
  {
    "country": "FR",
    "name": "Montfavet",
    "lat": "43.93335",
    "lng": "4.87342"
  },
  {
    "country": "FR",
    "name": "Montfaucon",
    "lat": "47.23562",
    "lng": "6.08162"
  },
  {
    "country": "FR",
    "name": "Montfaucon-Montigné",
    "lat": "47.1",
    "lng": "-1.11667"
  },
  {
    "country": "FR",
    "name": "Montfaucon-en-Velay",
    "lat": "45.18561",
    "lng": "4.31376"
  },
  {
    "country": "FR",
    "name": "Montfaucon",
    "lat": "44.07245",
    "lng": "4.75504"
  },
  {
    "country": "FR",
    "name": "Montévrain",
    "lat": "48.87415",
    "lng": "2.75114"
  },
  {
    "country": "FR",
    "name": "Monteux",
    "lat": "44.0348",
    "lng": "4.99719"
  },
  {
    "country": "FR",
    "name": "Montesson",
    "lat": "48.90924",
    "lng": "2.13754"
  },
  {
    "country": "FR",
    "name": "Montesquieu-Volvestre",
    "lat": "43.20725",
    "lng": "1.22862"
  },
  {
    "country": "FR",
    "name": "Montesquiu d'Albera",
    "lat": "42.51798",
    "lng": "2.88243"
  },
  {
    "country": "FR",
    "name": "Montescourt-Lizerolles",
    "lat": "49.73828",
    "lng": "3.25736"
  },
  {
    "country": "FR",
    "name": "Montescot",
    "lat": "42.60692",
    "lng": "2.93318"
  },
  {
    "country": "FR",
    "name": "Monterfil",
    "lat": "48.06733",
    "lng": "-1.97905"
  },
  {
    "country": "FR",
    "name": "Montereau-Fault-Yonne",
    "lat": "48.38333",
    "lng": "2.95"
  },
  {
    "country": "FR",
    "name": "Monterblanc",
    "lat": "47.74211",
    "lng": "-2.6795"
  },
  {
    "country": "FR",
    "name": "Montenois",
    "lat": "47.49222",
    "lng": "6.66561"
  },
  {
    "country": "FR",
    "name": "Montendre",
    "lat": "45.28469",
    "lng": "-0.40627"
  },
  {
    "country": "FR",
    "name": "Montenay",
    "lat": "48.28787",
    "lng": "-0.89373"
  },
  {
    "country": "FR",
    "name": "Montélimar",
    "lat": "44.55838",
    "lng": "4.75094"
  },
  {
    "country": "FR",
    "name": "Montélier",
    "lat": "44.93726",
    "lng": "5.03118"
  },
  {
    "country": "FR",
    "name": "Montéléger",
    "lat": "44.85522",
    "lng": "4.93181"
  },
  {
    "country": "FR",
    "name": "Monteils",
    "lat": "44.16862",
    "lng": "1.57608"
  },
  {
    "country": "FR",
    "name": "Montech",
    "lat": "43.95816",
    "lng": "1.23204"
  },
  {
    "country": "FR",
    "name": "Montebourg",
    "lat": "49.48774",
    "lng": "-1.38036"
  },
  {
    "country": "FR",
    "name": "Montdidier",
    "lat": "49.65",
    "lng": "2.56667"
  },
  {
    "country": "FR",
    "name": "Mont-de-Marsan",
    "lat": "43.89022",
    "lng": "-0.49713"
  },
  {
    "country": "FR",
    "name": "Mont-de-Lans",
    "lat": "45.03626",
    "lng": "6.13141"
  },
  {
    "country": "FR",
    "name": "Montcy-Notre-Dame",
    "lat": "49.77507",
    "lng": "4.74245"
  },
  {
    "country": "FR",
    "name": "Montcuq",
    "lat": "44.33838",
    "lng": "1.2085"
  },
  {
    "country": "FR",
    "name": "Montcresson",
    "lat": "47.90561",
    "lng": "2.80796"
  },
  {
    "country": "FR",
    "name": "Montcourt-Fromonville",
    "lat": "48.30672",
    "lng": "2.7046"
  },
  {
    "country": "FR",
    "name": "Montcornet",
    "lat": "49.69526",
    "lng": "4.01667"
  },
  {
    "country": "FR",
    "name": "Montchanin",
    "lat": "46.74964",
    "lng": "4.4707"
  },
  {
    "country": "FR",
    "name": "Montcenis",
    "lat": "46.78785",
    "lng": "4.38738"
  },
  {
    "country": "FR",
    "name": "Montceau-les-Mines",
    "lat": "46.66667",
    "lng": "4.36667"
  },
  {
    "country": "FR",
    "name": "Montcaret",
    "lat": "44.85",
    "lng": "0.06667"
  },
  {
    "country": "FR",
    "name": "Montbronn",
    "lat": "48.99243",
    "lng": "7.31075"
  },
  {
    "country": "FR",
    "name": "Montbron",
    "lat": "45.66667",
    "lng": "0.5"
  },
  {
    "country": "FR",
    "name": "Montbrison",
    "lat": "45.6",
    "lng": "4.05"
  },
  {
    "country": "FR",
    "name": "Montboucher-sur-Jabron",
    "lat": "44.55036",
    "lng": "4.80245"
  },
  {
    "country": "FR",
    "name": "Montbonnot-Saint-Martin",
    "lat": "45.22236",
    "lng": "5.80353"
  },
  {
    "country": "FR",
    "name": "Montblanc",
    "lat": "43.39486",
    "lng": "3.36752"
  },
  {
    "country": "FR",
    "name": "Montbizot",
    "lat": "48.14995",
    "lng": "0.18384"
  },
  {
    "country": "FR",
    "name": "Montbeton",
    "lat": "44.01667",
    "lng": "1.3"
  },
  {
    "country": "FR",
    "name": "Montbert",
    "lat": "47.05613",
    "lng": "-1.4889"
  },
  {
    "country": "FR",
    "name": "Montberon",
    "lat": "43.71586",
    "lng": "1.47968"
  },
  {
    "country": "FR",
    "name": "Mont-Bernanchon",
    "lat": "50.58333",
    "lng": "2.58333"
  },
  {
    "country": "FR",
    "name": "Montbéliard",
    "lat": "47.51667",
    "lng": "6.8"
  },
  {
    "country": "FR",
    "name": "Montbazon",
    "lat": "47.28348",
    "lng": "0.69988"
  },
  {
    "country": "FR",
    "name": "Montbazin",
    "lat": "43.51667",
    "lng": "3.69667"
  },
  {
    "country": "FR",
    "name": "Montbazens",
    "lat": "44.47807",
    "lng": "2.2298"
  },
  {
    "country": "FR",
    "name": "Montbard",
    "lat": "47.61667",
    "lng": "4.33333"
  },
  {
    "country": "FR",
    "name": "Montayral",
    "lat": "44.47513",
    "lng": "0.98769"
  },
  {
    "country": "FR",
    "name": "Montauville",
    "lat": "48.90014",
    "lng": "6.02055"
  },
  {
    "country": "FR",
    "name": "Montaut",
    "lat": "43.13333",
    "lng": "-0.2"
  },
  {
    "country": "FR",
    "name": "Montauroux",
    "lat": "43.61905",
    "lng": "6.77499"
  },
  {
    "country": "FR",
    "name": "Montaure",
    "lat": "49.23417",
    "lng": "1.08837"
  },
  {
    "country": "FR",
    "name": "Montauban-de-Bretagne",
    "lat": "48.19933",
    "lng": "-2.04476"
  },
  {
    "country": "FR",
    "name": "Montauban",
    "lat": "44.01819",
    "lng": "1.36432"
  },
  {
    "country": "FR",
    "name": "Montataire",
    "lat": "49.259",
    "lng": "2.43777"
  },
  {
    "country": "FR",
    "name": "Montastruc-la-Conseillère",
    "lat": "43.71982",
    "lng": "1.59019"
  },
  {
    "country": "FR",
    "name": "Montarnaud",
    "lat": "43.64743",
    "lng": "3.6969"
  },
  {
    "country": "FR",
    "name": "Montargis",
    "lat": "48",
    "lng": "2.75"
  },
  {
    "country": "FR",
    "name": "Montaren-et-Saint-Médiers",
    "lat": "44.02869",
    "lng": "4.3803"
  },
  {
    "country": "FR",
    "name": "Montardon",
    "lat": "43.36667",
    "lng": "-0.35"
  },
  {
    "country": "FR",
    "name": "Montans",
    "lat": "43.867",
    "lng": "1.88568"
  },
  {
    "country": "FR",
    "name": "Montanay",
    "lat": "45.87818",
    "lng": "4.86303"
  },
  {
    "country": "FR",
    "name": "Montamisé",
    "lat": "46.62181",
    "lng": "0.42442"
  },
  {
    "country": "FR",
    "name": "Montalieu-Vercieu",
    "lat": "45.81577",
    "lng": "5.40393"
  },
  {
    "country": "FR",
    "name": "Montaigut-sur-Save",
    "lat": "43.68947",
    "lng": "1.23133"
  },
  {
    "country": "FR",
    "name": "Montaigut-en-Combraille",
    "lat": "46.17984",
    "lng": "2.80847"
  },
  {
    "country": "FR",
    "name": "Montaigut",
    "lat": "45.61267",
    "lng": "3.44775"
  },
  {
    "country": "FR",
    "name": "Montaigu-de-Quercy",
    "lat": "44.33964",
    "lng": "1.0169"
  },
  {
    "country": "FR",
    "name": "Montaigu",
    "lat": "46.97667",
    "lng": "-1.30846"
  },
  {
    "country": "FR",
    "name": "Montagny",
    "lat": "45.62699",
    "lng": "4.75781"
  },
  {
    "country": "FR",
    "name": "Montagne",
    "lat": "44.93333",
    "lng": "-0.13333"
  },
  {
    "country": "FR",
    "name": "Montagnat",
    "lat": "46.17048",
    "lng": "5.29052"
  },
  {
    "country": "FR",
    "name": "Montagnac",
    "lat": "43.48087",
    "lng": "3.48312"
  },
  {
    "country": "FR",
    "name": "Montady",
    "lat": "43.3359",
    "lng": "3.1278"
  },
  {
    "country": "FR",
    "name": "Mont",
    "lat": "43.43333",
    "lng": "-0.65"
  },
  {
    "country": "FR",
    "name": "Monswiller",
    "lat": "48.75511",
    "lng": "7.37732"
  },
  {
    "country": "FR",
    "name": "Mons-en-Pévèle",
    "lat": "50.47926",
    "lng": "3.09767"
  },
  {
    "country": "FR",
    "name": "Mons-en-Barœul",
    "lat": "50.63333",
    "lng": "3.11667"
  },
  {
    "country": "FR",
    "name": "Monsempron-Libos",
    "lat": "44.49004",
    "lng": "0.9409"
  },
  {
    "country": "FR",
    "name": "Monségur",
    "lat": "44.6504",
    "lng": "0.08047"
  },
  {
    "country": "FR",
    "name": "Mons",
    "lat": "44.1148",
    "lng": "4.17325"
  },
  {
    "country": "FR",
    "name": "Mons",
    "lat": "43.6124",
    "lng": "1.57207"
  },
  {
    "country": "FR",
    "name": "Monnières",
    "lat": "47.13301",
    "lng": "-1.35317"
  },
  {
    "country": "FR",
    "name": "Monnetier-Mornex",
    "lat": "46.1603",
    "lng": "6.20667"
  },
  {
    "country": "FR",
    "name": "Monnaie",
    "lat": "47.50162",
    "lng": "0.78872"
  },
  {
    "country": "FR",
    "name": "Monistrol-sur-Loire",
    "lat": "45.29335",
    "lng": "4.17161"
  },
  {
    "country": "FR",
    "name": "Monflanquin",
    "lat": "44.52966",
    "lng": "0.76772"
  },
  {
    "country": "FR",
    "name": "Monéteau",
    "lat": "47.84923",
    "lng": "3.58178"
  },
  {
    "country": "FR",
    "name": "Monestiés",
    "lat": "44.06667",
    "lng": "2.1"
  },
  {
    "country": "FR",
    "name": "Monein",
    "lat": "43.33333",
    "lng": "-0.58333"
  },
  {
    "country": "FR",
    "name": "Mondragon",
    "lat": "44.23858",
    "lng": "4.71005"
  },
  {
    "country": "FR",
    "name": "Mondoubleau",
    "lat": "47.98061",
    "lng": "0.89782"
  },
  {
    "country": "FR",
    "name": "Mondonville",
    "lat": "43.67296",
    "lng": "1.28592"
  },
  {
    "country": "FR",
    "name": "Mondeville",
    "lat": "49.17497",
    "lng": "-0.32238"
  },
  {
    "country": "FR",
    "name": "Mondelange",
    "lat": "49.26145",
    "lng": "6.16503"
  },
  {
    "country": "FR",
    "name": "Moncoutant",
    "lat": "46.72547",
    "lng": "-0.58797"
  },
  {
    "country": "FR",
    "name": "Moncontour",
    "lat": "46.88086",
    "lng": "-0.01996"
  },
  {
    "country": "FR",
    "name": "Monclar-de-Quercy",
    "lat": "43.96554",
    "lng": "1.58587"
  },
  {
    "country": "FR",
    "name": "Monchy-Saint-Éloi",
    "lat": "49.29042",
    "lng": "2.46739"
  },
  {
    "country": "FR",
    "name": "Monchecourt",
    "lat": "50.30413",
    "lng": "3.21029"
  },
  {
    "country": "FR",
    "name": "Moncé-en-Belin",
    "lat": "47.89442",
    "lng": "0.19809"
  },
  {
    "country": "FR",
    "name": "Monbazillac",
    "lat": "44.79374",
    "lng": "0.49256"
  },
  {
    "country": "FR",
    "name": "Mommenheim",
    "lat": "48.75782",
    "lng": "7.64494"
  },
  {
    "country": "FR",
    "name": "Molsheim",
    "lat": "48.54042",
    "lng": "7.49199"
  },
  {
    "country": "FR",
    "name": "Mollégès",
    "lat": "43.80703",
    "lng": "4.94934"
  },
  {
    "country": "FR",
    "name": "Molinet",
    "lat": "46.46836",
    "lng": "3.94161"
  },
  {
    "country": "FR",
    "name": "Molières-sur-Cèze",
    "lat": "44.25989",
    "lng": "4.15836"
  },
  {
    "country": "FR",
    "name": "Molières",
    "lat": "44.19305",
    "lng": "1.36318"
  },
  {
    "country": "FR",
    "name": "Molac",
    "lat": "47.73011",
    "lng": "-2.43484"
  },
  {
    "country": "FR",
    "name": "Moissy-Cramayel",
    "lat": "48.62605",
    "lng": "2.60125"
  },
  {
    "country": "FR",
    "name": "Moisselles",
    "lat": "49.05",
    "lng": "2.33597"
  },
  {
    "country": "FR",
    "name": "Moissac",
    "lat": "44.10236",
    "lng": "1.0945"
  },
  {
    "country": "FR",
    "name": "Moislains",
    "lat": "49.9882",
    "lng": "2.96404"
  },
  {
    "country": "FR",
    "name": "Moisenay",
    "lat": "48.56266",
    "lng": "2.73527"
  },
  {
    "country": "FR",
    "name": "Moisdon-la-Rivière",
    "lat": "47.62175",
    "lng": "-1.37258"
  },
  {
    "country": "FR",
    "name": "Moirans-en-Montagne",
    "lat": "46.43381",
    "lng": "5.72643"
  },
  {
    "country": "FR",
    "name": "Moirans",
    "lat": "45.3283",
    "lng": "5.55342"
  },
  {
    "country": "FR",
    "name": "Moigny-sur-École",
    "lat": "48.43262",
    "lng": "2.45802"
  },
  {
    "country": "FR",
    "name": "Moidieu-Détourbe",
    "lat": "45.50988",
    "lng": "5.01613"
  },
  {
    "country": "FR",
    "name": "Mogneville",
    "lat": "49.31535",
    "lng": "2.4717"
  },
  {
    "country": "FR",
    "name": "Moëlan-sur-Mer",
    "lat": "47.81418",
    "lng": "-3.62892"
  },
  {
    "country": "FR",
    "name": "Modane",
    "lat": "45.2",
    "lng": "6.66667"
  },
  {
    "country": "FR",
    "name": "Mittelhausbergen",
    "lat": "48.61436",
    "lng": "7.69009"
  },
  {
    "country": "FR",
    "name": "Mitry-Mory",
    "lat": "48.98333",
    "lng": "2.61667"
  },
  {
    "country": "FR",
    "name": "Missillac",
    "lat": "47.48155",
    "lng": "-2.16"
  },
  {
    "country": "FR",
    "name": "Misérieux",
    "lat": "45.97309",
    "lng": "4.81231"
  },
  {
    "country": "FR",
    "name": "Miserey-Salines",
    "lat": "47.28638",
    "lng": "5.97387"
  },
  {
    "country": "FR",
    "name": "Miribel-les-Échelles",
    "lat": "45.42906",
    "lng": "5.70835"
  },
  {
    "country": "FR",
    "name": "Miribel",
    "lat": "45.8258",
    "lng": "4.9544"
  },
  {
    "country": "FR",
    "name": "Mireval",
    "lat": "43.5086",
    "lng": "3.8017"
  },
  {
    "country": "FR",
    "name": "Mirepoix",
    "lat": "43.08773",
    "lng": "1.8735"
  },
  {
    "country": "FR",
    "name": "Mirepeix",
    "lat": "43.18333",
    "lng": "-0.25"
  },
  {
    "country": "FR",
    "name": "Miremont",
    "lat": "43.36995",
    "lng": "1.41724"
  },
  {
    "country": "FR",
    "name": "Mirefleurs",
    "lat": "45.69346",
    "lng": "3.22441"
  },
  {
    "country": "FR",
    "name": "Mirecourt",
    "lat": "48.30089",
    "lng": "6.13282"
  },
  {
    "country": "FR",
    "name": "Mirebeau-sur-Bèze",
    "lat": "47.39828",
    "lng": "5.32093"
  },
  {
    "country": "FR",
    "name": "Mirebeau",
    "lat": "46.78743",
    "lng": "0.18341"
  },
  {
    "country": "FR",
    "name": "Miré",
    "lat": "47.75759",
    "lng": "-0.49157"
  },
  {
    "country": "FR",
    "name": "Mirandol-Bourgnounac",
    "lat": "44.14273",
    "lng": "2.16857"
  },
  {
    "country": "FR",
    "name": "Mirande",
    "lat": "43.51667",
    "lng": "0.41667"
  },
  {
    "country": "FR",
    "name": "Miramont-de-Guyenne",
    "lat": "44.60157",
    "lng": "0.36247"
  },
  {
    "country": "FR",
    "name": "Mirambeau",
    "lat": "45.3731",
    "lng": "-0.57067"
  },
  {
    "country": "FR",
    "name": "Miramas",
    "lat": "43.58666",
    "lng": "5.00464"
  },
  {
    "country": "FR",
    "name": "Mirabel-aux-Baronnies",
    "lat": "44.31133",
    "lng": "5.09846"
  },
  {
    "country": "FR",
    "name": "Mios",
    "lat": "44.60489",
    "lng": "-0.93329"
  },
  {
    "country": "FR",
    "name": "Mions",
    "lat": "45.66432",
    "lng": "4.94994"
  },
  {
    "country": "FR",
    "name": "Mionnay",
    "lat": "45.89557",
    "lng": "4.93074"
  },
  {
    "country": "FR",
    "name": "Minihy-Tréguier",
    "lat": "48.77746",
    "lng": "-3.22883"
  },
  {
    "country": "FR",
    "name": "Miniac-Morvan",
    "lat": "48.51477",
    "lng": "-1.89955"
  },
  {
    "country": "FR",
    "name": "Mimizan",
    "lat": "44.20057",
    "lng": "-1.22886"
  },
  {
    "country": "FR",
    "name": "Mimet",
    "lat": "43.41393",
    "lng": "5.50495"
  },
  {
    "country": "FR",
    "name": "Mimbaste",
    "lat": "43.64887",
    "lng": "-0.97383"
  },
  {
    "country": "FR",
    "name": "Milly-sur-Thérain",
    "lat": "49.5024",
    "lng": "1.99605"
  },
  {
    "country": "FR",
    "name": "Milly-la-Forêt",
    "lat": "48.404",
    "lng": "2.47015"
  },
  {
    "country": "FR",
    "name": "Millery",
    "lat": "45.63174",
    "lng": "4.78628"
  },
  {
    "country": "FR",
    "name": "Millau",
    "lat": "44.1",
    "lng": "3.08333"
  },
  {
    "country": "FR",
    "name": "Millas",
    "lat": "42.69203",
    "lng": "2.69508"
  },
  {
    "country": "FR",
    "name": "Milizac",
    "lat": "48.46667",
    "lng": "-4.56667"
  },
  {
    "country": "FR",
    "name": "Milhaud",
    "lat": "43.78977",
    "lng": "4.31035"
  },
  {
    "country": "FR",
    "name": "Migné-Auxances",
    "lat": "46.62745",
    "lng": "0.31458"
  },
  {
    "country": "FR",
    "name": "Mignaloux-Beauvoir",
    "lat": "46.54157",
    "lng": "0.41538"
  },
  {
    "country": "FR",
    "name": "Migennes",
    "lat": "47.96548",
    "lng": "3.51787"
  },
  {
    "country": "FR",
    "name": "Mieussy",
    "lat": "46.13369",
    "lng": "6.52416"
  },
  {
    "country": "FR",
    "name": "Miélan",
    "lat": "43.43054",
    "lng": "0.30794"
  },
  {
    "country": "FR",
    "name": "Mézy-sur-Seine",
    "lat": "49",
    "lng": "1.88333"
  },
  {
    "country": "FR",
    "name": "Méziré",
    "lat": "47.53209",
    "lng": "6.91872"
  },
  {
    "country": "FR",
    "name": "Mézin",
    "lat": "44.05668",
    "lng": "0.25874"
  },
  {
    "country": "FR",
    "name": "Mézières-sur-Seine",
    "lat": "48.96128",
    "lng": "1.79245"
  },
  {
    "country": "FR",
    "name": "Mézières-en-Drouais",
    "lat": "48.72413",
    "lng": "1.4244"
  },
  {
    "country": "FR",
    "name": "Mézières-en-Brenne",
    "lat": "46.81979",
    "lng": "1.21123"
  },
  {
    "country": "FR",
    "name": "Mézériat",
    "lat": "46.23431",
    "lng": "5.04806"
  },
  {
    "country": "FR",
    "name": "Mézeray",
    "lat": "47.82682",
    "lng": "-0.0177"
  },
  {
    "country": "FR",
    "name": "Mezel",
    "lat": "45.75519",
    "lng": "3.24315"
  },
  {
    "country": "FR",
    "name": "Mèze",
    "lat": "43.42504",
    "lng": "3.6059"
  },
  {
    "country": "FR",
    "name": "Meyzieu",
    "lat": "45.76667",
    "lng": "5"
  },
  {
    "country": "FR",
    "name": "Meythet",
    "lat": "45.91836",
    "lng": "6.09422"
  },
  {
    "country": "FR",
    "name": "Meysse",
    "lat": "44.61028",
    "lng": "4.72306"
  },
  {
    "country": "FR",
    "name": "Meyssac",
    "lat": "45.05571",
    "lng": "1.67386"
  },
  {
    "country": "FR",
    "name": "Meyrueis",
    "lat": "44.17737",
    "lng": "3.43083"
  },
  {
    "country": "FR",
    "name": "Meyreuil",
    "lat": "43.4878",
    "lng": "5.49574"
  },
  {
    "country": "FR",
    "name": "Meyrargues",
    "lat": "43.63806",
    "lng": "5.52611"
  },
  {
    "country": "FR",
    "name": "Meynes",
    "lat": "43.87974",
    "lng": "4.55958"
  },
  {
    "country": "FR",
    "name": "Meymac",
    "lat": "45.53487",
    "lng": "2.14502"
  },
  {
    "country": "FR",
    "name": "Meylan",
    "lat": "45.21988",
    "lng": "5.79007"
  },
  {
    "country": "FR",
    "name": "Meyenheim",
    "lat": "47.91364",
    "lng": "7.3556"
  },
  {
    "country": "FR",
    "name": "Mexy",
    "lat": "49.50149",
    "lng": "5.7807"
  },
  {
    "country": "FR",
    "name": "Meximieux",
    "lat": "45.90841",
    "lng": "5.19527"
  },
  {
    "country": "FR",
    "name": "Meursault",
    "lat": "46.97822",
    "lng": "4.76952"
  },
  {
    "country": "FR",
    "name": "Meursac",
    "lat": "45.6489",
    "lng": "-0.80801"
  },
  {
    "country": "FR",
    "name": "Meurchin",
    "lat": "50.49831",
    "lng": "2.89318"
  },
  {
    "country": "FR",
    "name": "Meung-sur-Loire",
    "lat": "47.83124",
    "lng": "1.69582"
  },
  {
    "country": "FR",
    "name": "Meulan-en-Yvelines",
    "lat": "49.00768",
    "lng": "1.90602"
  },
  {
    "country": "FR",
    "name": "Meudon",
    "lat": "48.81381",
    "lng": "2.235"
  },
  {
    "country": "FR",
    "name": "Meucon",
    "lat": "47.71648",
    "lng": "-2.7617"
  },
  {
    "country": "FR",
    "name": "Metz-Tessy",
    "lat": "45.93406",
    "lng": "6.10826"
  },
  {
    "country": "FR",
    "name": "Metzervisse",
    "lat": "49.31476",
    "lng": "6.28277"
  },
  {
    "country": "FR",
    "name": "Metzeral",
    "lat": "48.01044",
    "lng": "7.07088"
  },
  {
    "country": "FR",
    "name": "Metz",
    "lat": "49.11911",
    "lng": "6.17269"
  },
  {
    "country": "FR",
    "name": "Mettray",
    "lat": "47.45251",
    "lng": "0.64939"
  },
  {
    "country": "FR",
    "name": "Méteren",
    "lat": "50.73333",
    "lng": "2.7"
  },
  {
    "country": "FR",
    "name": "Messimy",
    "lat": "45.69741",
    "lng": "4.67291"
  },
  {
    "country": "FR",
    "name": "Messigny-et-Vantoux",
    "lat": "47.40666",
    "lng": "5.01715"
  },
  {
    "country": "FR",
    "name": "Messery",
    "lat": "46.35034",
    "lng": "6.2959"
  },
  {
    "country": "FR",
    "name": "Messeix",
    "lat": "45.61667",
    "lng": "2.55"
  },
  {
    "country": "FR",
    "name": "Messei",
    "lat": "48.71157",
    "lng": "-0.53739"
  },
  {
    "country": "FR",
    "name": "Messein",
    "lat": "48.61129",
    "lng": "6.14073"
  },
  {
    "country": "FR",
    "name": "Messac",
    "lat": "47.82399",
    "lng": "-1.81085"
  },
  {
    "country": "FR",
    "name": "Mesquer",
    "lat": "47.39919",
    "lng": "-2.45986"
  },
  {
    "country": "FR",
    "name": "Mesnières-en-Bray",
    "lat": "49.76172",
    "lng": "1.38187"
  },
  {
    "country": "FR",
    "name": "Meslay-du-Maine",
    "lat": "47.95116",
    "lng": "-0.55428"
  },
  {
    "country": "FR",
    "name": "Meslan",
    "lat": "47.99502",
    "lng": "-3.43285"
  },
  {
    "country": "FR",
    "name": "Meschers-sur-Gironde",
    "lat": "45.56037",
    "lng": "-0.9547"
  },
  {
    "country": "FR",
    "name": "Mésanger",
    "lat": "47.43131",
    "lng": "-1.22798"
  },
  {
    "country": "FR",
    "name": "Méry-sur-Seine",
    "lat": "48.50937",
    "lng": "3.89129"
  },
  {
    "country": "FR",
    "name": "Méry-sur-Oise",
    "lat": "49.05876",
    "lng": "2.19113"
  },
  {
    "country": "FR",
    "name": "Méry",
    "lat": "45.64325",
    "lng": "5.93782"
  },
  {
    "country": "FR",
    "name": "Merxheim",
    "lat": "47.91128",
    "lng": "7.29492"
  },
  {
    "country": "FR",
    "name": "Merville-Franceville-Plage",
    "lat": "49.27218",
    "lng": "-0.19616"
  },
  {
    "country": "FR",
    "name": "Merville",
    "lat": "50.64329",
    "lng": "2.64125"
  },
  {
    "country": "FR",
    "name": "Merville",
    "lat": "43.72354",
    "lng": "1.29656"
  },
  {
    "country": "FR",
    "name": "Mervent",
    "lat": "46.52239",
    "lng": "-0.75654"
  },
  {
    "country": "FR",
    "name": "Mervans",
    "lat": "46.79923",
    "lng": "5.1843"
  },
  {
    "country": "FR",
    "name": "Méru",
    "lat": "49.23333",
    "lng": "2.13333"
  },
  {
    "country": "FR",
    "name": "Mertzwiller",
    "lat": "48.86558",
    "lng": "7.68136"
  },
  {
    "country": "FR",
    "name": "Merten",
    "lat": "49.24903",
    "lng": "6.66465"
  },
  {
    "country": "FR",
    "name": "Mers-les-Bains",
    "lat": "50.06538",
    "lng": "1.3881"
  },
  {
    "country": "FR",
    "name": "Merlimont",
    "lat": "50.4559",
    "lng": "1.61315"
  },
  {
    "country": "FR",
    "name": "Merlevenez",
    "lat": "47.73563",
    "lng": "-3.23047"
  },
  {
    "country": "FR",
    "name": "Mérindol",
    "lat": "43.75516",
    "lng": "5.20357"
  },
  {
    "country": "FR",
    "name": "Mérignies",
    "lat": "50.50609",
    "lng": "3.11043"
  },
  {
    "country": "FR",
    "name": "Mérignac",
    "lat": "44.83248",
    "lng": "-0.63381"
  },
  {
    "country": "FR",
    "name": "Mériel",
    "lat": "49.07614",
    "lng": "2.21054"
  },
  {
    "country": "FR",
    "name": "Méricourt",
    "lat": "50.40116",
    "lng": "2.86246"
  },
  {
    "country": "FR",
    "name": "Méribel",
    "lat": "45.41497",
    "lng": "6.565"
  },
  {
    "country": "FR",
    "name": "Méréville",
    "lat": "48.59138",
    "lng": "6.15085"
  },
  {
    "country": "FR",
    "name": "Méréville",
    "lat": "48.31476",
    "lng": "2.08609"
  },
  {
    "country": "FR",
    "name": "Méreau",
    "lat": "47.16295",
    "lng": "2.05086"
  },
  {
    "country": "FR",
    "name": "Méré",
    "lat": "48.78445",
    "lng": "1.81247"
  },
  {
    "country": "FR",
    "name": "Merdrignac",
    "lat": "48.19372",
    "lng": "-2.41533"
  },
  {
    "country": "FR",
    "name": "Mercy-le-Bas",
    "lat": "49.38302",
    "lng": "5.75044"
  },
  {
    "country": "FR",
    "name": "Mercus-Garrabet",
    "lat": "42.8779",
    "lng": "1.629"
  },
  {
    "country": "FR",
    "name": "Mercury",
    "lat": "45.67452",
    "lng": "6.33688"
  },
  {
    "country": "FR",
    "name": "Mercurol-Veaunes",
    "lat": "45.07437",
    "lng": "4.89279"
  },
  {
    "country": "FR",
    "name": "Mer",
    "lat": "47.70555",
    "lng": "1.50621"
  },
  {
    "country": "FR",
    "name": "Méounes-lès-Montrieux",
    "lat": "43.27966",
    "lng": "5.97012"
  },
  {
    "country": "FR",
    "name": "Menucourt",
    "lat": "49.02841",
    "lng": "1.98046"
  },
  {
    "country": "FR",
    "name": "Menton",
    "lat": "43.77649",
    "lng": "7.50435"
  },
  {
    "country": "FR",
    "name": "Menthon-Saint-Bernard",
    "lat": "45.85995",
    "lng": "6.19552"
  },
  {
    "country": "FR",
    "name": "Mensignac",
    "lat": "45.22505",
    "lng": "0.56214"
  },
  {
    "country": "FR",
    "name": "Mens",
    "lat": "44.81753",
    "lng": "5.75137"
  },
  {
    "country": "FR",
    "name": "Menneval",
    "lat": "49.1",
    "lng": "0.61667"
  },
  {
    "country": "FR",
    "name": "Mennecy",
    "lat": "48.56903",
    "lng": "2.44384"
  },
  {
    "country": "FR",
    "name": "Ménilles",
    "lat": "49.03333",
    "lng": "1.36667"
  },
  {
    "country": "FR",
    "name": "Ménétrol",
    "lat": "45.87184",
    "lng": "3.12741"
  },
  {
    "country": "FR",
    "name": "Menetou-Salon",
    "lat": "47.23172",
    "lng": "2.48715"
  },
  {
    "country": "FR",
    "name": "Ménestreau-en-Villette",
    "lat": "47.69962",
    "lng": "2.02333"
  },
  {
    "country": "FR",
    "name": "Ménesplet",
    "lat": "45.01667",
    "lng": "0.11667"
  },
  {
    "country": "FR",
    "name": "Ménerbes",
    "lat": "43.83242",
    "lng": "5.20597"
  },
  {
    "country": "FR",
    "name": "Ménéac",
    "lat": "48.13972",
    "lng": "-2.46134"
  },
  {
    "country": "FR",
    "name": "Mende",
    "lat": "44.51849",
    "lng": "3.50372"
  },
  {
    "country": "FR",
    "name": "Melun",
    "lat": "48.5457",
    "lng": "2.65356"
  },
  {
    "country": "FR",
    "name": "Melrand",
    "lat": "47.98002",
    "lng": "-3.10941"
  },
  {
    "country": "FR",
    "name": "Mellecey",
    "lat": "46.81084",
    "lng": "4.72822"
  },
  {
    "country": "FR",
    "name": "Melle",
    "lat": "46.22285",
    "lng": "-0.14216"
  },
  {
    "country": "FR",
    "name": "Mellac",
    "lat": "47.90345",
    "lng": "-3.57675"
  },
  {
    "country": "FR",
    "name": "Mélisey",
    "lat": "47.75229",
    "lng": "6.58014"
  },
  {
    "country": "FR",
    "name": "Melgven",
    "lat": "47.90626",
    "lng": "-3.83518"
  },
  {
    "country": "FR",
    "name": "Melesse",
    "lat": "48.21771",
    "lng": "-1.69496"
  },
  {
    "country": "FR",
    "name": "Melay",
    "lat": "47.18333",
    "lng": "-0.69429"
  },
  {
    "country": "FR",
    "name": "Meistratzheim",
    "lat": "48.44853",
    "lng": "7.5435"
  },
  {
    "country": "FR",
    "name": "Meillonnas",
    "lat": "46.24342",
    "lng": "5.34929"
  },
  {
    "country": "FR",
    "name": "Meillac",
    "lat": "48.41174",
    "lng": "-1.81378"
  },
  {
    "country": "FR",
    "name": "Meilhan-sur-Garonne",
    "lat": "44.52131",
    "lng": "0.03472"
  },
  {
    "country": "FR",
    "name": "Meilhan",
    "lat": "43.86436",
    "lng": "-0.70587"
  },
  {
    "country": "FR",
    "name": "Mehun-sur-Yèvre",
    "lat": "47.13782",
    "lng": "2.21105"
  },
  {
    "country": "FR",
    "name": "Megève",
    "lat": "45.85233",
    "lng": "6.61286"
  },
  {
    "country": "FR",
    "name": "Mées",
    "lat": "43.70452",
    "lng": "-1.10952"
  },
  {
    "country": "FR",
    "name": "Médréac",
    "lat": "48.26703",
    "lng": "-2.06618"
  },
  {
    "country": "FR",
    "name": "Médis",
    "lat": "45.64337",
    "lng": "-0.96298"
  },
  {
    "country": "FR",
    "name": "Médan",
    "lat": "48.95539",
    "lng": "1.99494"
  },
  {
    "country": "FR",
    "name": "Mécleuves",
    "lat": "49.04429",
    "lng": "6.27051"
  },
  {
    "country": "FR",
    "name": "Meaux",
    "lat": "48.96014",
    "lng": "2.87885"
  },
  {
    "country": "FR",
    "name": "Méaulte",
    "lat": "49.98167",
    "lng": "2.66121"
  },
  {
    "country": "FR",
    "name": "Méaudre",
    "lat": "45.12695",
    "lng": "5.52707"
  },
  {
    "country": "FR",
    "name": "Mazingarbe",
    "lat": "50.47109",
    "lng": "2.71544"
  },
  {
    "country": "FR",
    "name": "Mazières-en-Mauges",
    "lat": "47.04536",
    "lng": "-0.81702"
  },
  {
    "country": "FR",
    "name": "Mazières-de-Touraine",
    "lat": "47.38326",
    "lng": "0.42548"
  },
  {
    "country": "FR",
    "name": "Mazet-Saint-Voy",
    "lat": "45.04788",
    "lng": "4.24499"
  },
  {
    "country": "FR",
    "name": "Mazères-Lezons",
    "lat": "43.26667",
    "lng": "-0.35"
  },
  {
    "country": "FR",
    "name": "Mazères",
    "lat": "43.25055",
    "lng": "1.67728"
  },
  {
    "country": "FR",
    "name": "Mazé",
    "lat": "47.45632",
    "lng": "-0.27106"
  },
  {
    "country": "FR",
    "name": "Mazargues",
    "lat": "43.24622",
    "lng": "5.39788"
  },
  {
    "country": "FR",
    "name": "Mazan",
    "lat": "44.0568",
    "lng": "5.12747"
  },
  {
    "country": "FR",
    "name": "Mazamet",
    "lat": "43.49001",
    "lng": "2.37304"
  },
  {
    "country": "FR",
    "name": "May-sur-Orne",
    "lat": "49.10107",
    "lng": "-0.37471"
  },
  {
    "country": "FR",
    "name": "Mayet",
    "lat": "47.75968",
    "lng": "0.27468"
  },
  {
    "country": "FR",
    "name": "Mayenne",
    "lat": "48.3",
    "lng": "-0.61667"
  },
  {
    "country": "FR",
    "name": "Maxilly-sur-Léman",
    "lat": "46.40027",
    "lng": "6.64617"
  },
  {
    "country": "FR",
    "name": "Maxéville",
    "lat": "48.70816",
    "lng": "6.1696"
  },
  {
    "country": "FR",
    "name": "Maxent",
    "lat": "47.98333",
    "lng": "-2.03333"
  },
  {
    "country": "FR",
    "name": "Mauzé-Thouarsais",
    "lat": "46.97611",
    "lng": "-0.27846"
  },
  {
    "country": "FR",
    "name": "Mauzé-sur-le-Mignon",
    "lat": "46.19516",
    "lng": "-0.67032"
  },
  {
    "country": "FR",
    "name": "Mauvezin",
    "lat": "43.73048",
    "lng": "0.8781"
  },
  {
    "country": "FR",
    "name": "Mauves-sur-Loire",
    "lat": "47.29738",
    "lng": "-1.38763"
  },
  {
    "country": "FR",
    "name": "Mauves",
    "lat": "45.03525",
    "lng": "4.83"
  },
  {
    "country": "FR",
    "name": "Maussane-les-Alpilles",
    "lat": "43.72236",
    "lng": "4.80497"
  },
  {
    "country": "FR",
    "name": "Maurs",
    "lat": "44.71117",
    "lng": "2.19832"
  },
  {
    "country": "FR",
    "name": "Mauron",
    "lat": "48.08257",
    "lng": "-2.28477"
  },
  {
    "country": "FR",
    "name": "Mauriac",
    "lat": "45.21667",
    "lng": "2.33333"
  },
  {
    "country": "FR",
    "name": "Maurepas",
    "lat": "48.76486",
    "lng": "1.92923"
  },
  {
    "country": "FR",
    "name": "Maureillas-las-Illas",
    "lat": "42.49014",
    "lng": "2.80752"
  },
  {
    "country": "FR",
    "name": "Maureilhan",
    "lat": "43.35",
    "lng": "3.11667"
  },
  {
    "country": "FR",
    "name": "Maure-de-Bretagne",
    "lat": "47.89239",
    "lng": "-1.99104"
  },
  {
    "country": "FR",
    "name": "Maurecourt",
    "lat": "48.99614",
    "lng": "2.06155"
  },
  {
    "country": "FR",
    "name": "Maulévrier",
    "lat": "47.00929",
    "lng": "-0.74239"
  },
  {
    "country": "FR",
    "name": "Mauléon-Licharre",
    "lat": "43.22684",
    "lng": "-0.88038"
  },
  {
    "country": "FR",
    "name": "Maule",
    "lat": "48.91056",
    "lng": "1.85264"
  },
  {
    "country": "FR",
    "name": "Mauguio",
    "lat": "43.6181",
    "lng": "4.00739"
  },
  {
    "country": "FR",
    "name": "Maubourguet",
    "lat": "43.46824",
    "lng": "0.03578"
  },
  {
    "country": "FR",
    "name": "Maubeuge",
    "lat": "50.27875",
    "lng": "3.97267"
  },
  {
    "country": "FR",
    "name": "Maubec",
    "lat": "45.56749",
    "lng": "5.26434"
  },
  {
    "country": "FR",
    "name": "Maubec",
    "lat": "43.84593",
    "lng": "5.14027"
  },
  {
    "country": "FR",
    "name": "Matzenheim",
    "lat": "48.3945",
    "lng": "7.62185"
  },
  {
    "country": "FR",
    "name": "Matour",
    "lat": "46.30654",
    "lng": "4.48178"
  },
  {
    "country": "FR",
    "name": "Matignon",
    "lat": "48.59627",
    "lng": "-2.29125"
  },
  {
    "country": "FR",
    "name": "Mathieu",
    "lat": "49.25448",
    "lng": "-0.37188"
  },
  {
    "country": "FR",
    "name": "Mathay",
    "lat": "47.43905",
    "lng": "6.78487"
  },
  {
    "country": "FR",
    "name": "Matha",
    "lat": "45.86823",
    "lng": "-0.31849"
  },
  {
    "country": "FR",
    "name": "Massy",
    "lat": "48.72692",
    "lng": "2.28301"
  },
  {
    "country": "FR",
    "name": "Massongy",
    "lat": "46.31601",
    "lng": "6.33503"
  },
  {
    "country": "FR",
    "name": "Massieux",
    "lat": "45.90969",
    "lng": "4.83321"
  },
  {
    "country": "FR",
    "name": "Massiac",
    "lat": "45.25551",
    "lng": "3.19759"
  },
  {
    "country": "FR",
    "name": "Masseube",
    "lat": "43.42984",
    "lng": "0.5781"
  },
  {
    "country": "FR",
    "name": "Massay",
    "lat": "47.15324",
    "lng": "1.99334"
  },
  {
    "country": "FR",
    "name": "Masny",
    "lat": "50.34797",
    "lng": "3.20165"
  },
  {
    "country": "FR",
    "name": "Masnières",
    "lat": "50.11489",
    "lng": "3.20889"
  },
  {
    "country": "FR",
    "name": "Masevaux",
    "lat": "47.77671",
    "lng": "6.99683"
  },
  {
    "country": "FR",
    "name": "Marzy",
    "lat": "46.98125",
    "lng": "3.09352"
  },
  {
    "country": "FR",
    "name": "Marzan",
    "lat": "47.54069",
    "lng": "-2.32466"
  },
  {
    "country": "FR",
    "name": "Mary-sur-Marne",
    "lat": "49.01591",
    "lng": "3.02788"
  },
  {
    "country": "FR",
    "name": "Marvejols",
    "lat": "44.55378",
    "lng": "3.29137"
  },
  {
    "country": "FR",
    "name": "Martres-Tolosane",
    "lat": "43.19929",
    "lng": "1.01056"
  },
  {
    "country": "FR",
    "name": "Les Martres-d'Artière",
    "lat": "45.83333",
    "lng": "3.26667"
  },
  {
    "country": "FR",
    "name": "Martizay",
    "lat": "46.80767",
    "lng": "1.04324"
  },
  {
    "country": "FR",
    "name": "Martinvast",
    "lat": "49.59608",
    "lng": "-1.66434"
  },
  {
    "country": "FR",
    "name": "Martin-Église",
    "lat": "49.90174",
    "lng": "1.1412"
  },
  {
    "country": "FR",
    "name": "Martillac",
    "lat": "44.711",
    "lng": "-0.53747"
  },
  {
    "country": "FR",
    "name": "Martigues",
    "lat": "43.40735",
    "lng": "5.05526"
  },
  {
    "country": "FR",
    "name": "Martigné-Ferchaud",
    "lat": "47.82934",
    "lng": "-1.31911"
  },
  {
    "country": "FR",
    "name": "Martigné-Briand",
    "lat": "47.23358",
    "lng": "-0.42933"
  },
  {
    "country": "FR",
    "name": "Martigné-sur-Mayenne",
    "lat": "48.2",
    "lng": "-0.66667"
  },
  {
    "country": "FR",
    "name": "Martignat",
    "lat": "46.20972",
    "lng": "5.61049"
  },
  {
    "country": "FR",
    "name": "Martignas-sur-Jalle",
    "lat": "44.84528",
    "lng": "-0.7806"
  },
  {
    "country": "FR",
    "name": "Marthod",
    "lat": "45.7284",
    "lng": "6.41298"
  },
  {
    "country": "FR",
    "name": "Martel",
    "lat": "44.93667",
    "lng": "1.60851"
  },
  {
    "country": "FR",
    "name": "Marssac-sur-Tarn",
    "lat": "43.91768",
    "lng": "2.02921"
  },
  {
    "country": "FR",
    "name": "Marsilly",
    "lat": "46.23027",
    "lng": "-1.1384"
  },
  {
    "country": "FR",
    "name": "Marsillargues",
    "lat": "43.66424",
    "lng": "4.17448"
  },
  {
    "country": "FR",
    "name": "Marseille",
    "lat": "43.29695",
    "lng": "5.38107"
  },
  {
    "country": "FR",
    "name": "Marseillan",
    "lat": "43.35618",
    "lng": "3.52795"
  },
  {
    "country": "FR",
    "name": "Marsat",
    "lat": "45.87655",
    "lng": "3.08288"
  },
  {
    "country": "FR",
    "name": "Marsanne",
    "lat": "44.64375",
    "lng": "4.87394"
  },
  {
    "country": "FR",
    "name": "Marsannay-la-Côte",
    "lat": "47.27095",
    "lng": "4.98895"
  },
  {
    "country": "FR",
    "name": "Marsac-sur-Don",
    "lat": "47.59648",
    "lng": "-1.67952"
  },
  {
    "country": "FR",
    "name": "Marsac-en-Livradois",
    "lat": "45.47882",
    "lng": "3.72726"
  },
  {
    "country": "FR",
    "name": "Marquise",
    "lat": "50.81294",
    "lng": "1.70786"
  },
  {
    "country": "FR",
    "name": "Marquion",
    "lat": "50.21126",
    "lng": "3.08719"
  },
  {
    "country": "FR",
    "name": "Marquillies",
    "lat": "50.55577",
    "lng": "2.87067"
  },
  {
    "country": "FR",
    "name": "Marquette-lez-Lille",
    "lat": "50.67628",
    "lng": "3.06613"
  },
  {
    "country": "FR",
    "name": "Marquette-en-Ostrevant",
    "lat": "50.28333",
    "lng": "3.26667"
  },
  {
    "country": "FR",
    "name": "Marquefave",
    "lat": "43.31766",
    "lng": "1.24661"
  },
  {
    "country": "FR",
    "name": "Marpent",
    "lat": "50.29252",
    "lng": "4.07936"
  },
  {
    "country": "FR",
    "name": "Maromme",
    "lat": "49.47925",
    "lng": "1.02375"
  },
  {
    "country": "FR",
    "name": "Marolles-sur-Seine",
    "lat": "48.38662",
    "lng": "3.03562"
  },
  {
    "country": "FR",
    "name": "Marolles-les-Braults",
    "lat": "48.25271",
    "lng": "0.31631"
  },
  {
    "country": "FR",
    "name": "Marolles-en-Hurepoix",
    "lat": "48.56232",
    "lng": "2.29885"
  },
  {
    "country": "FR",
    "name": "Maroilles",
    "lat": "50.13508",
    "lng": "3.76132"
  },
  {
    "country": "FR",
    "name": "Marœuil",
    "lat": "50.32519",
    "lng": "2.70504"
  },
  {
    "country": "FR",
    "name": "Marnes-la-Coquette",
    "lat": "48.82732",
    "lng": "2.17151"
  },
  {
    "country": "FR",
    "name": "Marnaz",
    "lat": "46.06201",
    "lng": "6.52692"
  },
  {
    "country": "FR",
    "name": "Marnay",
    "lat": "47.29088",
    "lng": "5.77277"
  },
  {
    "country": "FR",
    "name": "Marmoutier",
    "lat": "48.69005",
    "lng": "7.38195"
  },
  {
    "country": "FR",
    "name": "Marmande",
    "lat": "44.5",
    "lng": "0.16667"
  },
  {
    "country": "FR",
    "name": "Marmagne",
    "lat": "47.1",
    "lng": "2.28333"
  },
  {
    "country": "FR",
    "name": "Marmagne",
    "lat": "46.83666",
    "lng": "4.35892"
  },
  {
    "country": "FR",
    "name": "Marly",
    "lat": "49.06382",
    "lng": "6.15427"
  },
  {
    "country": "FR",
    "name": "Marly-le-Roi",
    "lat": "48.86667",
    "lng": "2.08333"
  },
  {
    "country": "FR",
    "name": "Marly-la-Ville",
    "lat": "49.08201",
    "lng": "2.50347"
  },
  {
    "country": "FR",
    "name": "Marly",
    "lat": "50.34556",
    "lng": "3.54959"
  },
  {
    "country": "FR",
    "name": "Marlhes",
    "lat": "45.28321",
    "lng": "4.39752"
  },
  {
    "country": "FR",
    "name": "Marles-les-Mines",
    "lat": "50.50478",
    "lng": "2.50882"
  },
  {
    "country": "FR",
    "name": "Marles-en-Brie",
    "lat": "48.72783",
    "lng": "2.88003"
  },
  {
    "country": "FR",
    "name": "Marlenheim",
    "lat": "48.62134",
    "lng": "7.49096"
  },
  {
    "country": "FR",
    "name": "Marle",
    "lat": "49.74006",
    "lng": "3.7706"
  },
  {
    "country": "FR",
    "name": "Maringues",
    "lat": "45.92117",
    "lng": "3.32969"
  },
  {
    "country": "FR",
    "name": "Marines",
    "lat": "49.14485",
    "lng": "1.98226"
  },
  {
    "country": "FR",
    "name": "Marin",
    "lat": "46.37472",
    "lng": "6.53022"
  },
  {
    "country": "FR",
    "name": "Marigny-les-Usages",
    "lat": "47.95799",
    "lng": "2.01462"
  },
  {
    "country": "FR",
    "name": "Marigny-le-Châtel",
    "lat": "48.40291",
    "lng": "3.73588"
  },
  {
    "country": "FR",
    "name": "Marigny-Brizay",
    "lat": "46.74622",
    "lng": "0.37626"
  },
  {
    "country": "FR",
    "name": "Marigny",
    "lat": "49.09952",
    "lng": "-1.24179"
  },
  {
    "country": "FR",
    "name": "Marignier",
    "lat": "46.09014",
    "lng": "6.50004"
  },
  {
    "country": "FR",
    "name": "Marigné-Laillé",
    "lat": "47.81765",
    "lng": "0.3405"
  },
  {
    "country": "FR",
    "name": "Marignane",
    "lat": "43.41604",
    "lng": "5.21453"
  },
  {
    "country": "FR",
    "name": "Marguerittes",
    "lat": "43.8596",
    "lng": "4.44517"
  },
  {
    "country": "FR",
    "name": "Margon",
    "lat": "48.33568",
    "lng": "0.83454"
  },
  {
    "country": "FR",
    "name": "Margny-lès-Compiègne",
    "lat": "49.42559",
    "lng": "2.81806"
  },
  {
    "country": "FR",
    "name": "Margency",
    "lat": "49",
    "lng": "2.3"
  },
  {
    "country": "FR",
    "name": "Margencel",
    "lat": "46.337",
    "lng": "6.43305"
  },
  {
    "country": "FR",
    "name": "Margaux",
    "lat": "45.04012",
    "lng": "-0.67892"
  },
  {
    "country": "FR",
    "name": "Mareuil-sur-Ourcq",
    "lat": "49.13752",
    "lng": "3.07822"
  },
  {
    "country": "FR",
    "name": "Mareuil-sur-Lay-Dissais",
    "lat": "46.53333",
    "lng": "-1.23333"
  },
  {
    "country": "FR",
    "name": "Mareuil-sur-Cher",
    "lat": "47.29314",
    "lng": "1.32897"
  },
  {
    "country": "FR",
    "name": "Mareuil",
    "lat": "45.45",
    "lng": "0.45"
  },
  {
    "country": "FR",
    "name": "Mareuil-sur-Ay",
    "lat": "49.04581",
    "lng": "4.03587"
  },
  {
    "country": "FR",
    "name": "Mareuil-lès-Meaux",
    "lat": "48.92648",
    "lng": "2.86134"
  },
  {
    "country": "FR",
    "name": "Mareuil-le-Port",
    "lat": "49.08179",
    "lng": "3.76011"
  },
  {
    "country": "FR",
    "name": "Maretz",
    "lat": "50.0453",
    "lng": "3.41808"
  },
  {
    "country": "FR",
    "name": "Marennes",
    "lat": "45.8228",
    "lng": "-1.10546"
  },
  {
    "country": "FR",
    "name": "Marennes",
    "lat": "45.62054",
    "lng": "4.91551"
  },
  {
    "country": "FR",
    "name": "Mareil-sur-Mauldre",
    "lat": "48.89521",
    "lng": "1.8687"
  },
  {
    "country": "FR",
    "name": "Mareil-Marly",
    "lat": "48.88213",
    "lng": "2.07351"
  },
  {
    "country": "FR",
    "name": "Mareau-aux-Prés",
    "lat": "47.86667",
    "lng": "1.78333"
  },
  {
    "country": "FR",
    "name": "Mardié",
    "lat": "47.88617",
    "lng": "2.05745"
  },
  {
    "country": "FR",
    "name": "Mardeuil",
    "lat": "49.05393",
    "lng": "3.93"
  },
  {
    "country": "FR",
    "name": "Marcq-en-Barœul",
    "lat": "50.66667",
    "lng": "3.08333"
  },
  {
    "country": "FR",
    "name": "Marcoussis",
    "lat": "48.64026",
    "lng": "2.23858"
  },
  {
    "country": "FR",
    "name": "Marcorignan",
    "lat": "43.22634",
    "lng": "2.92281"
  },
  {
    "country": "FR",
    "name": "Marconnelle",
    "lat": "50.37588",
    "lng": "2.01108"
  },
  {
    "country": "FR",
    "name": "Marconne",
    "lat": "50.37143",
    "lng": "2.04669"
  },
  {
    "country": "FR",
    "name": "Marçon",
    "lat": "47.71059",
    "lng": "0.51101"
  },
  {
    "country": "FR",
    "name": "Marcoing",
    "lat": "50.1211",
    "lng": "3.17321"
  },
  {
    "country": "FR",
    "name": "Marckolsheim",
    "lat": "48.16471",
    "lng": "7.544"
  },
  {
    "country": "FR",
    "name": "Marck",
    "lat": "50.94897",
    "lng": "1.94328"
  },
  {
    "country": "FR",
    "name": "Marcilly-sur-Tille",
    "lat": "47.517",
    "lng": "5.12979"
  },
  {
    "country": "FR",
    "name": "Marcilly-sur-Eure",
    "lat": "48.82568",
    "lng": "1.34741"
  },
  {
    "country": "FR",
    "name": "Marcilly-le-Châtel",
    "lat": "45.7",
    "lng": "4.03333"
  },
  {
    "country": "FR",
    "name": "Marcilly-en-Villette",
    "lat": "47.76505",
    "lng": "2.02266"
  },
  {
    "country": "FR",
    "name": "Marcillac-Vallon",
    "lat": "44.47464",
    "lng": "2.46454"
  },
  {
    "country": "FR",
    "name": "Marcillac",
    "lat": "45.2687",
    "lng": "-0.52379"
  },
  {
    "country": "FR",
    "name": "Marcigny",
    "lat": "46.27627",
    "lng": "4.03957"
  },
  {
    "country": "FR",
    "name": "Marciac",
    "lat": "43.52321",
    "lng": "0.16091"
  },
  {
    "country": "FR",
    "name": "Marchiennes",
    "lat": "50.4",
    "lng": "3.28333"
  },
  {
    "country": "FR",
    "name": "Marcheprime",
    "lat": "44.69146",
    "lng": "-0.85496"
  },
  {
    "country": "FR",
    "name": "Marcey-les-Grèves",
    "lat": "48.69673",
    "lng": "-1.39156"
  },
  {
    "country": "FR",
    "name": "Marcellaz-Albanais",
    "lat": "45.87526",
    "lng": "6.00162"
  },
  {
    "country": "FR",
    "name": "Marcamps",
    "lat": "45.04045",
    "lng": "-0.49275"
  },
  {
    "country": "FR",
    "name": "Marboz",
    "lat": "46.34337",
    "lng": "5.25978"
  },
  {
    "country": "FR",
    "name": "Marboué",
    "lat": "48.11377",
    "lng": "1.3321"
  },
  {
    "country": "FR",
    "name": "Marbache",
    "lat": "48.79572",
    "lng": "6.09752"
  },
  {
    "country": "FR",
    "name": "Maraussan",
    "lat": "43.36895",
    "lng": "3.15643"
  },
  {
    "country": "FR",
    "name": "Marans",
    "lat": "46.30811",
    "lng": "-0.9945"
  },
  {
    "country": "FR",
    "name": "Marange-Silvange",
    "lat": "49.20822",
    "lng": "6.10426"
  },
  {
    "country": "FR",
    "name": "Manziat",
    "lat": "46.3594",
    "lng": "4.90662"
  },
  {
    "country": "FR",
    "name": "Manzat",
    "lat": "45.96105",
    "lng": "2.94205"
  },
  {
    "country": "FR",
    "name": "Manthelan",
    "lat": "47.13632",
    "lng": "0.79319"
  },
  {
    "country": "FR",
    "name": "Mantes-la-Ville",
    "lat": "48.97374",
    "lng": "1.70253"
  },
  {
    "country": "FR",
    "name": "Mantes-la-Jolie",
    "lat": "48.98333",
    "lng": "1.71667"
  },
  {
    "country": "FR",
    "name": "Mansle",
    "lat": "45.87526",
    "lng": "0.17914"
  },
  {
    "country": "FR",
    "name": "Mansigné",
    "lat": "47.74833",
    "lng": "0.13311"
  },
  {
    "country": "FR",
    "name": "Mansac",
    "lat": "45.1687",
    "lng": "1.38341"
  },
  {
    "country": "FR",
    "name": "Manosque",
    "lat": "43.82883",
    "lng": "5.78688"
  },
  {
    "country": "FR",
    "name": "Manom",
    "lat": "49.37092",
    "lng": "6.18345"
  },
  {
    "country": "FR",
    "name": "Manneville-sur-Risle",
    "lat": "49.35173",
    "lng": "0.54526"
  },
  {
    "country": "FR",
    "name": "Manéglise",
    "lat": "49.56578",
    "lng": "0.25572"
  },
  {
    "country": "FR",
    "name": "Mane",
    "lat": "43.93747",
    "lng": "5.76677"
  },
  {
    "country": "FR",
    "name": "Manduel",
    "lat": "43.81855",
    "lng": "4.47247"
  },
  {
    "country": "FR",
    "name": "Mandres-les-Roses",
    "lat": "48.70198",
    "lng": "2.54662"
  },
  {
    "country": "FR",
    "name": "Mandeure",
    "lat": "47.44921",
    "lng": "6.80762"
  },
  {
    "country": "FR",
    "name": "Mandelieu-la-Napoule",
    "lat": "43.55",
    "lng": "6.93333"
  },
  {
    "country": "FR",
    "name": "Mancieulles",
    "lat": "49.28553",
    "lng": "5.8971"
  },
  {
    "country": "FR",
    "name": "Mamirolle",
    "lat": "47.19857",
    "lng": "6.15924"
  },
  {
    "country": "FR",
    "name": "Mametz",
    "lat": "50.63485",
    "lng": "2.32478"
  },
  {
    "country": "FR",
    "name": "Mamers",
    "lat": "48.35",
    "lng": "0.38333"
  },
  {
    "country": "FR",
    "name": "Malzéville",
    "lat": "48.71181",
    "lng": "6.18176"
  },
  {
    "country": "FR",
    "name": "Malville",
    "lat": "47.35905",
    "lng": "-1.86227"
  },
  {
    "country": "FR",
    "name": "Mallemort",
    "lat": "43.73172",
    "lng": "5.17945"
  },
  {
    "country": "FR",
    "name": "Mallemoisson",
    "lat": "44.04813",
    "lng": "6.12459"
  },
  {
    "country": "FR",
    "name": "Malissard",
    "lat": "44.90201",
    "lng": "4.95915"
  },
  {
    "country": "FR",
    "name": "Malintrat",
    "lat": "45.81446",
    "lng": "3.18718"
  },
  {
    "country": "FR",
    "name": "Malijai",
    "lat": "44.04606",
    "lng": "6.03195"
  },
  {
    "country": "FR",
    "name": "Malicorne-sur-Sarthe",
    "lat": "47.81317",
    "lng": "-0.08152"
  },
  {
    "country": "FR",
    "name": "Malguénac",
    "lat": "48.08008",
    "lng": "-3.05248"
  },
  {
    "country": "FR",
    "name": "Malestroit",
    "lat": "47.80934",
    "lng": "-2.38457"
  },
  {
    "country": "FR",
    "name": "Malesherbes",
    "lat": "48.29566",
    "lng": "2.40935"
  },
  {
    "country": "FR",
    "name": "Malemort-sur-Corrèze",
    "lat": "45.17009",
    "lng": "1.56193"
  },
  {
    "country": "FR",
    "name": "Malemort-du-Comtat",
    "lat": "44.0207",
    "lng": "5.15991"
  },
  {
    "country": "FR",
    "name": "Malay-le-Grand",
    "lat": "48.17589",
    "lng": "3.34189"
  },
  {
    "country": "FR",
    "name": "Malaunay",
    "lat": "49.5271",
    "lng": "1.04292"
  },
  {
    "country": "FR",
    "name": "Malaucène",
    "lat": "44.1724",
    "lng": "5.13294"
  },
  {
    "country": "FR",
    "name": "Malataverne",
    "lat": "44.48727",
    "lng": "4.75207"
  },
  {
    "country": "FR",
    "name": "Malansac",
    "lat": "47.67724",
    "lng": "-2.29543"
  },
  {
    "country": "FR",
    "name": "Malakoff",
    "lat": "48.81999",
    "lng": "2.29998"
  },
  {
    "country": "FR",
    "name": "Maizières-lès-Metz",
    "lat": "49.21335",
    "lng": "6.15956"
  },
  {
    "country": "FR",
    "name": "Maizières-la-Grande-Paroisse",
    "lat": "48.51012",
    "lng": "3.78573"
  },
  {
    "country": "FR",
    "name": "Maisse",
    "lat": "48.39525",
    "lng": "2.37902"
  },
  {
    "country": "FR",
    "name": "Maisons-Laffitte",
    "lat": "48.95264",
    "lng": "2.14521"
  },
  {
    "country": "FR",
    "name": "Maisons-Alfort",
    "lat": "48.81171",
    "lng": "2.43945"
  },
  {
    "country": "FR",
    "name": "Maisnil-lès-Ruitz",
    "lat": "50.45342",
    "lng": "2.58992"
  },
  {
    "country": "FR",
    "name": "Maisdon-sur-Sèvre",
    "lat": "47.09714",
    "lng": "-1.38"
  },
  {
    "country": "FR",
    "name": "Mainvilliers",
    "lat": "48.45003",
    "lng": "1.45607"
  },
  {
    "country": "FR",
    "name": "Maintenon",
    "lat": "48.58704",
    "lng": "1.57847"
  },
  {
    "country": "FR",
    "name": "Maing",
    "lat": "50.30791",
    "lng": "3.48447"
  },
  {
    "country": "FR",
    "name": "Maincy",
    "lat": "48.54977",
    "lng": "2.70017"
  },
  {
    "country": "FR",
    "name": "Mailly-le-Camp",
    "lat": "48.66526",
    "lng": "4.21303"
  },
  {
    "country": "FR",
    "name": "Maillot",
    "lat": "48.17557",
    "lng": "3.30784"
  },
  {
    "country": "FR",
    "name": "Maillezais",
    "lat": "46.37267",
    "lng": "-0.73963"
  },
  {
    "country": "FR",
    "name": "Maillane",
    "lat": "43.83114",
    "lng": "4.78152"
  },
  {
    "country": "FR",
    "name": "Maignelay-Montigny",
    "lat": "49.55",
    "lng": "2.51667"
  },
  {
    "country": "FR",
    "name": "Maidières",
    "lat": "48.90029",
    "lng": "6.03988"
  },
  {
    "country": "FR",
    "name": "Maîche",
    "lat": "47.2516",
    "lng": "6.80309"
  },
  {
    "country": "FR",
    "name": "Magny-Vernois",
    "lat": "47.66997",
    "lng": "6.47545"
  },
  {
    "country": "FR",
    "name": "Magny-les-Hameaux",
    "lat": "48.74345",
    "lng": "2.06154"
  },
  {
    "country": "FR",
    "name": "Magny-le-Hongre",
    "lat": "48.86325",
    "lng": "2.81546"
  },
  {
    "country": "FR",
    "name": "Magny-le-Désert",
    "lat": "48.57015",
    "lng": "-0.32732"
  },
  {
    "country": "FR",
    "name": "Magny-en-Vexin",
    "lat": "49.15515",
    "lng": "1.78669"
  },
  {
    "country": "FR",
    "name": "Magny-Cours",
    "lat": "46.88333",
    "lng": "3.15"
  },
  {
    "country": "FR",
    "name": "Magné",
    "lat": "46.31548",
    "lng": "-0.54575"
  },
  {
    "country": "FR",
    "name": "Magnanville",
    "lat": "48.96798",
    "lng": "1.67842"
  },
  {
    "country": "FR",
    "name": "Magnac-sur-Touvre",
    "lat": "45.66667",
    "lng": "0.23333"
  },
  {
    "country": "FR",
    "name": "Magnac-Laval",
    "lat": "46.21514",
    "lng": "1.16724"
  },
  {
    "country": "FR",
    "name": "Magland",
    "lat": "46.01971",
    "lng": "6.62015"
  },
  {
    "country": "FR",
    "name": "Magescq",
    "lat": "43.78205",
    "lng": "-1.21652"
  },
  {
    "country": "FR",
    "name": "Magenta",
    "lat": "49.04899",
    "lng": "3.96882"
  },
  {
    "country": "FR",
    "name": "Magalas",
    "lat": "43.47095",
    "lng": "3.22338"
  },
  {
    "country": "FR",
    "name": "Maffliers",
    "lat": "49.07758",
    "lng": "2.30768"
  },
  {
    "country": "FR",
    "name": "Maël-Carhaix",
    "lat": "48.28444",
    "lng": "-3.42322"
  },
  {
    "country": "FR",
    "name": "Mâcot-la-Plagne",
    "lat": "45.55",
    "lng": "6.66667"
  },
  {
    "country": "FR",
    "name": "Mâcon",
    "lat": "46.31407",
    "lng": "4.82823"
  },
  {
    "country": "FR",
    "name": "Maclas",
    "lat": "45.36529",
    "lng": "4.68912"
  },
  {
    "country": "FR",
    "name": "Macheren",
    "lat": "49.10019",
    "lng": "6.77763"
  },
  {
    "country": "FR",
    "name": "Machecoul",
    "lat": "46.99358",
    "lng": "-1.82352"
  },
  {
    "country": "FR",
    "name": "Maché",
    "lat": "46.75405",
    "lng": "-1.68692"
  },
  {
    "country": "FR",
    "name": "Macau",
    "lat": "45.00679",
    "lng": "-0.61821"
  },
  {
    "country": "FR",
    "name": "Mably",
    "lat": "46.08623",
    "lng": "4.06607"
  },
  {
    "country": "FR",
    "name": "Lys-lez-Lannoy",
    "lat": "50.66667",
    "lng": "3.21667"
  },
  {
    "country": "FR",
    "name": "Lyon",
    "lat": "45.74846",
    "lng": "4.84671"
  },
  {
    "country": "FR",
    "name": "Lyaud",
    "lat": "46.33662",
    "lng": "6.52868"
  },
  {
    "country": "FR",
    "name": "Luzy",
    "lat": "46.79011",
    "lng": "3.97036"
  },
  {
    "country": "FR",
    "name": "Luz-Saint-Sauveur",
    "lat": "42.87191",
    "lng": "-0.00323"
  },
  {
    "country": "FR",
    "name": "Luzinay",
    "lat": "45.58895",
    "lng": "4.95829"
  },
  {
    "country": "FR",
    "name": "Luzech",
    "lat": "44.47818",
    "lng": "1.28704"
  },
  {
    "country": "FR",
    "name": "Luzarches",
    "lat": "49.11319",
    "lng": "2.4223"
  },
  {
    "country": "FR",
    "name": "Luynes",
    "lat": "47.38441",
    "lng": "0.5547"
  },
  {
    "country": "FR",
    "name": "Luxeuil-les-Bains",
    "lat": "47.8171",
    "lng": "6.365"
  },
  {
    "country": "FR",
    "name": "Lutzelhouse",
    "lat": "48.52114",
    "lng": "7.287"
  },
  {
    "country": "FR",
    "name": "Lutterbach",
    "lat": "47.75835",
    "lng": "7.27695"
  },
  {
    "country": "FR",
    "name": "Lussac-les-Châteaux",
    "lat": "46.40327",
    "lng": "0.72524"
  },
  {
    "country": "FR",
    "name": "Lussac",
    "lat": "44.95",
    "lng": "-0.1"
  },
  {
    "country": "FR",
    "name": "Lusigny-sur-Barse",
    "lat": "48.25451",
    "lng": "4.26891"
  },
  {
    "country": "FR",
    "name": "Lusigny",
    "lat": "46.58849",
    "lng": "3.49003"
  },
  {
    "country": "FR",
    "name": "Lusignan",
    "lat": "46.43598",
    "lng": "0.1262"
  },
  {
    "country": "FR",
    "name": "Lusanger",
    "lat": "47.68153",
    "lng": "-1.58857"
  },
  {
    "country": "FR",
    "name": "Lure",
    "lat": "47.68333",
    "lng": "6.5"
  },
  {
    "country": "FR",
    "name": "Lurcy-Lévis",
    "lat": "46.73056",
    "lng": "2.93876"
  },
  {
    "country": "FR",
    "name": "Luray",
    "lat": "48.72035",
    "lng": "1.39889"
  },
  {
    "country": "FR",
    "name": "L'Union",
    "lat": "43.66042",
    "lng": "1.48264"
  },
  {
    "country": "FR",
    "name": "Lunéville",
    "lat": "48.6",
    "lng": "6.5"
  },
  {
    "country": "FR",
    "name": "Lunery",
    "lat": "46.93569",
    "lng": "2.26895"
  },
  {
    "country": "FR",
    "name": "Luneray",
    "lat": "49.82795",
    "lng": "0.91581"
  },
  {
    "country": "FR",
    "name": "Lunel-Viel",
    "lat": "43.6789",
    "lng": "4.0925"
  },
  {
    "country": "FR",
    "name": "Lunel",
    "lat": "43.67778",
    "lng": "4.13611"
  },
  {
    "country": "FR",
    "name": "Lunay",
    "lat": "47.80864",
    "lng": "0.91499"
  },
  {
    "country": "FR",
    "name": "Lumio",
    "lat": "42.5759",
    "lng": "8.8355"
  },
  {
    "country": "FR",
    "name": "Lumigny-Nesles-Ormeaux",
    "lat": "48.73333",
    "lng": "2.95"
  },
  {
    "country": "FR",
    "name": "Lumes",
    "lat": "49.73461",
    "lng": "4.78616"
  },
  {
    "country": "FR",
    "name": "Lumbres",
    "lat": "50.70693",
    "lng": "2.12081"
  },
  {
    "country": "FR",
    "name": "Lumbin",
    "lat": "45.30568",
    "lng": "5.91136"
  },
  {
    "country": "FR",
    "name": "Luitré",
    "lat": "48.28247",
    "lng": "-1.11866"
  },
  {
    "country": "FR",
    "name": "Luisant",
    "lat": "48.4295",
    "lng": "1.47383"
  },
  {
    "country": "FR",
    "name": "Lugrin",
    "lat": "46.40329",
    "lng": "6.66744"
  },
  {
    "country": "FR",
    "name": "Ludres",
    "lat": "48.62181",
    "lng": "6.16183"
  },
  {
    "country": "FR",
    "name": "Ludon-Médoc",
    "lat": "44.98118",
    "lng": "-0.60254"
  },
  {
    "country": "FR",
    "name": "Luc-sur-Mer",
    "lat": "49.31452",
    "lng": "-0.35499"
  },
  {
    "country": "FR",
    "name": "Lucq-de-Béarn",
    "lat": "43.3",
    "lng": "-0.66667"
  },
  {
    "country": "FR",
    "name": "Luçon",
    "lat": "46.45773",
    "lng": "-1.16512"
  },
  {
    "country": "FR",
    "name": "Lucinges",
    "lat": "46.19136",
    "lng": "6.31731"
  },
  {
    "country": "FR",
    "name": "Luché-Pringé",
    "lat": "47.70326",
    "lng": "0.07549"
  },
  {
    "country": "FR",
    "name": "Lucéram",
    "lat": "43.88312",
    "lng": "7.35996"
  },
  {
    "country": "FR",
    "name": "Lucenay-lès-Aix",
    "lat": "46.70274",
    "lng": "3.48308"
  },
  {
    "country": "FR",
    "name": "Lucenay",
    "lat": "45.91263",
    "lng": "4.70276"
  },
  {
    "country": "FR",
    "name": "Luceau",
    "lat": "47.71167",
    "lng": "0.39734"
  },
  {
    "country": "FR",
    "name": "Lucé",
    "lat": "48.43689",
    "lng": "1.46359"
  },
  {
    "country": "FR",
    "name": "Lucciana",
    "lat": "42.54589",
    "lng": "9.41859"
  },
  {
    "country": "FR",
    "name": "Luçay-le-Mâle",
    "lat": "47.12996",
    "lng": "1.44173"
  },
  {
    "country": "FR",
    "name": "Luc-la-Primaube",
    "lat": "44.31439",
    "lng": "2.53552"
  },
  {
    "country": "FR",
    "name": "Lubersac",
    "lat": "45.44394",
    "lng": "1.40418"
  },
  {
    "country": "FR",
    "name": "Luant",
    "lat": "46.733",
    "lng": "1.55793"
  },
  {
    "country": "FR",
    "name": "Lozinghem",
    "lat": "50.51554",
    "lng": "2.50209"
  },
  {
    "country": "FR",
    "name": "Lozanne",
    "lat": "45.85591",
    "lng": "4.68594"
  },
  {
    "country": "FR",
    "name": "Loyettes",
    "lat": "45.7762",
    "lng": "5.20743"
  },
  {
    "country": "FR",
    "name": "Loyat",
    "lat": "47.98933",
    "lng": "-2.38344"
  },
  {
    "country": "FR",
    "name": "Lovagny",
    "lat": "45.9042",
    "lng": "6.03387"
  },
  {
    "country": "FR",
    "name": "Louzy",
    "lat": "47.01201",
    "lng": "-0.18537"
  },
  {
    "country": "FR",
    "name": "Louvroil",
    "lat": "50.26427",
    "lng": "3.96272"
  },
  {
    "country": "FR",
    "name": "Louvres",
    "lat": "49.0446",
    "lng": "2.50479"
  },
  {
    "country": "FR",
    "name": "Louvigny",
    "lat": "49.15715",
    "lng": "-0.39376"
  },
  {
    "country": "FR",
    "name": "Louvigné-du-Désert",
    "lat": "48.48047",
    "lng": "-1.12537"
  },
  {
    "country": "FR",
    "name": "Louvigné-de-Bais",
    "lat": "48.04898",
    "lng": "-1.33091"
  },
  {
    "country": "FR",
    "name": "Louviers",
    "lat": "49.21667",
    "lng": "1.16667"
  },
  {
    "country": "FR",
    "name": "Louvie-Juzon",
    "lat": "43.08646",
    "lng": "-0.41928"
  },
  {
    "country": "FR",
    "name": "Louverné",
    "lat": "48.12178",
    "lng": "-0.71721"
  },
  {
    "country": "FR",
    "name": "Louveciennes",
    "lat": "48.86115",
    "lng": "2.11463"
  },
  {
    "country": "FR",
    "name": "Loury",
    "lat": "47.99944",
    "lng": "2.08474"
  },
  {
    "country": "FR",
    "name": "Lourmarin",
    "lat": "43.76599",
    "lng": "5.36667"
  },
  {
    "country": "FR",
    "name": "Lourdes",
    "lat": "43.1",
    "lng": "-0.05"
  },
  {
    "country": "FR",
    "name": "Lourches",
    "lat": "50.31354",
    "lng": "3.35258"
  },
  {
    "country": "FR",
    "name": "Louplande",
    "lat": "47.95",
    "lng": "-0.05"
  },
  {
    "country": "FR",
    "name": "Loupian",
    "lat": "43.44886",
    "lng": "3.61381"
  },
  {
    "country": "FR",
    "name": "Loupiac",
    "lat": "44.61667",
    "lng": "-0.3"
  },
  {
    "country": "FR",
    "name": "Louhans",
    "lat": "46.63333",
    "lng": "5.21667"
  },
  {
    "country": "FR",
    "name": "Loué",
    "lat": "47.99575",
    "lng": "-0.1545"
  },
  {
    "country": "FR",
    "name": "Loudun",
    "lat": "47.00788",
    "lng": "0.08296"
  },
  {
    "country": "FR",
    "name": "Loudéac",
    "lat": "48.17826",
    "lng": "-2.75433"
  },
  {
    "country": "FR",
    "name": "Loubert",
    "lat": "45.91422",
    "lng": "0.58617"
  },
  {
    "country": "FR",
    "name": "Louargat",
    "lat": "48.56576",
    "lng": "-3.3375"
  },
  {
    "country": "FR",
    "name": "Louannec",
    "lat": "48.79423",
    "lng": "-3.412"
  },
  {
    "country": "FR",
    "name": "Losne",
    "lat": "47.0985",
    "lng": "5.26216"
  },
  {
    "country": "FR",
    "name": "Lorris",
    "lat": "47.8895",
    "lng": "2.51478"
  },
  {
    "country": "FR",
    "name": "Lorrez-le-Bocage-Préaux",
    "lat": "48.23333",
    "lng": "2.9"
  },
  {
    "country": "FR",
    "name": "Lorquin",
    "lat": "48.67102",
    "lng": "6.99915"
  },
  {
    "country": "FR",
    "name": "Lormont",
    "lat": "44.87495",
    "lng": "-0.51782"
  },
  {
    "country": "FR",
    "name": "Lormes",
    "lat": "47.28964",
    "lng": "3.81714"
  },
  {
    "country": "FR",
    "name": "Lormaison",
    "lat": "49.25647",
    "lng": "2.10575"
  },
  {
    "country": "FR",
    "name": "Loriol-sur-Drôme",
    "lat": "44.75214",
    "lng": "4.82547"
  },
  {
    "country": "FR",
    "name": "Loriol-du-Comtat",
    "lat": "44.07626",
    "lng": "4.99922"
  },
  {
    "country": "FR",
    "name": "Lorient",
    "lat": "47.75",
    "lng": "-3.36667"
  },
  {
    "country": "FR",
    "name": "Lorgues",
    "lat": "43.49361",
    "lng": "6.3611"
  },
  {
    "country": "FR",
    "name": "Lorgies",
    "lat": "50.5688",
    "lng": "2.79034"
  },
  {
    "country": "FR",
    "name": "Lorette",
    "lat": "45.50618",
    "lng": "4.57522"
  },
  {
    "country": "FR",
    "name": "Loperhet",
    "lat": "48.37725",
    "lng": "-4.30608"
  },
  {
    "country": "FR",
    "name": "Lopérec",
    "lat": "48.27734",
    "lng": "-4.04756"
  },
  {
    "country": "FR",
    "name": "Loos-en-Gohelle",
    "lat": "50.45786",
    "lng": "2.79215"
  },
  {
    "country": "FR",
    "name": "Loos",
    "lat": "50.60982",
    "lng": "3.01874"
  },
  {
    "country": "FR",
    "name": "Loon-Plage",
    "lat": "50.99647",
    "lng": "2.2177"
  },
  {
    "country": "FR",
    "name": "Looberghe",
    "lat": "50.91694",
    "lng": "2.27439"
  },
  {
    "country": "FR",
    "name": "Lons-le-Saunier",
    "lat": "46.67535",
    "lng": "5.55575"
  },
  {
    "country": "FR",
    "name": "Lons",
    "lat": "43.31667",
    "lng": "-0.4"
  },
  {
    "country": "FR",
    "name": "Longwy",
    "lat": "49.51936",
    "lng": "5.76882"
  },
  {
    "country": "FR",
    "name": "Longvic",
    "lat": "47.28754",
    "lng": "5.06341"
  },
  {
    "country": "FR",
    "name": "Longuyon",
    "lat": "49.44548",
    "lng": "5.60145"
  },
  {
    "country": "FR",
    "name": "Longueville",
    "lat": "48.51503",
    "lng": "3.24677"
  },
  {
    "country": "FR",
    "name": "Longuenesse",
    "lat": "50.73395",
    "lng": "2.2352"
  },
  {
    "country": "FR",
    "name": "Longueil-Sainte-Marie",
    "lat": "49.35723",
    "lng": "2.71844"
  },
  {
    "country": "FR",
    "name": "Longueil-Annel",
    "lat": "49.46908",
    "lng": "2.86464"
  },
  {
    "country": "FR",
    "name": "Longueau",
    "lat": "49.87226",
    "lng": "2.3588"
  },
  {
    "country": "FR",
    "name": "Longpré-les-Corps-Saints",
    "lat": "50.01239",
    "lng": "1.99287"
  },
  {
    "country": "FR",
    "name": "Longpont-sur-Orge",
    "lat": "48.64171",
    "lng": "2.29278"
  },
  {
    "country": "FR",
    "name": "Longperrier",
    "lat": "49.04844",
    "lng": "2.66571"
  },
  {
    "country": "FR",
    "name": "Longny-au-Perche",
    "lat": "48.52984",
    "lng": "0.75239"
  },
  {
    "country": "FR",
    "name": "Longnes",
    "lat": "48.92002",
    "lng": "1.58705"
  },
  {
    "country": "FR",
    "name": "Longlaville",
    "lat": "49.53455",
    "lng": "5.80203"
  },
  {
    "country": "FR",
    "name": "Longjumeau",
    "lat": "48.69503",
    "lng": "2.30735"
  },
  {
    "country": "FR",
    "name": "Longfossé",
    "lat": "50.65217",
    "lng": "1.80693"
  },
  {
    "country": "FR",
    "name": "Longeville-lès-Saint-Avold",
    "lat": "49.11689",
    "lng": "6.64327"
  },
  {
    "country": "FR",
    "name": "Longeville-lès-Metz",
    "lat": "49.11403",
    "lng": "6.13612"
  },
  {
    "country": "FR",
    "name": "Longeville-en-Barrois",
    "lat": "48.74242",
    "lng": "5.20905"
  },
  {
    "country": "FR",
    "name": "Longeville-sur-Mer",
    "lat": "46.41667",
    "lng": "-1.5"
  },
  {
    "country": "FR",
    "name": "Longecourt-en-Plaine",
    "lat": "47.19783",
    "lng": "5.14956"
  },
  {
    "country": "FR",
    "name": "Longchaumois",
    "lat": "46.46228",
    "lng": "5.93052"
  },
  {
    "country": "FR",
    "name": "Longchamp",
    "lat": "47.25973",
    "lng": "5.28694"
  },
  {
    "country": "FR",
    "name": "Longages",
    "lat": "43.35398",
    "lng": "1.23905"
  },
  {
    "country": "FR",
    "name": "Londinières",
    "lat": "49.83187",
    "lng": "1.40232"
  },
  {
    "country": "FR",
    "name": "Lompret",
    "lat": "50.66931",
    "lng": "2.98968"
  },
  {
    "country": "FR",
    "name": "Lomme",
    "lat": "50.64358",
    "lng": "2.98715"
  },
  {
    "country": "FR",
    "name": "Lombron",
    "lat": "48.07879",
    "lng": "0.41869"
  },
  {
    "country": "FR",
    "name": "Lombez",
    "lat": "43.47501",
    "lng": "0.91119"
  },
  {
    "country": "FR",
    "name": "Loivre",
    "lat": "49.34619",
    "lng": "3.97978"
  },
  {
    "country": "FR",
    "name": "Loison-sous-Lens",
    "lat": "50.43796",
    "lng": "2.85322"
  },
  {
    "country": "FR",
    "name": "Loisin",
    "lat": "46.29227",
    "lng": "6.3101"
  },
  {
    "country": "FR",
    "name": "Loiron",
    "lat": "48.06667",
    "lng": "-0.93333"
  },
  {
    "country": "FR",
    "name": "Loire-sur-Rhône",
    "lat": "45.55",
    "lng": "4.8"
  },
  {
    "country": "FR",
    "name": "Logonna-Daoulas",
    "lat": "48.32308",
    "lng": "-4.29675"
  },
  {
    "country": "FR",
    "name": "Lognes",
    "lat": "48.83541",
    "lng": "2.62998"
  },
  {
    "country": "FR",
    "name": "Lodève",
    "lat": "43.71667",
    "lng": "3.31667"
  },
  {
    "country": "FR",
    "name": "Loctudy",
    "lat": "47.83333",
    "lng": "-4.16667"
  },
  {
    "country": "FR",
    "name": "Locquirec",
    "lat": "48.69243",
    "lng": "-3.64554"
  },
  {
    "country": "FR",
    "name": "Locquémeau",
    "lat": "48.72474",
    "lng": "-3.56275"
  },
  {
    "country": "FR",
    "name": "Locon",
    "lat": "50.57029",
    "lng": "2.66629"
  },
  {
    "country": "FR",
    "name": "Locoal-Mendon",
    "lat": "47.7052",
    "lng": "-3.10796"
  },
  {
    "country": "FR",
    "name": "Locmiquélic",
    "lat": "47.72499",
    "lng": "-3.34153"
  },
  {
    "country": "FR",
    "name": "Locminé",
    "lat": "47.88619",
    "lng": "-2.83536"
  },
  {
    "country": "FR",
    "name": "Locmariaquer",
    "lat": "47.56915",
    "lng": "-2.94468"
  },
  {
    "country": "FR",
    "name": "Loches",
    "lat": "47.13333",
    "lng": "1"
  },
  {
    "country": "FR",
    "name": "Llupia",
    "lat": "42.62074",
    "lng": "2.76924"
  },
  {
    "country": "FR",
    "name": "Lizy-sur-Ourcq",
    "lat": "49.02454",
    "lng": "3.02178"
  },
  {
    "country": "FR",
    "name": "Livry-sur-Seine",
    "lat": "48.51771",
    "lng": "2.67879"
  },
  {
    "country": "FR",
    "name": "Livry-Gargan",
    "lat": "48.9193",
    "lng": "2.54305"
  },
  {
    "country": "FR",
    "name": "Livron-sur-Drôme",
    "lat": "44.7731",
    "lng": "4.84705"
  },
  {
    "country": "FR",
    "name": "Livré-sur-Changeon",
    "lat": "48.21937",
    "lng": "-1.34438"
  },
  {
    "country": "FR",
    "name": "Livinhac-le-Haut",
    "lat": "44.59212",
    "lng": "2.23117"
  },
  {
    "country": "FR",
    "name": "Livet-et-Gavet",
    "lat": "45.10782",
    "lng": "5.93333"
  },
  {
    "country": "FR",
    "name": "Liverdy-en-Brie",
    "lat": "48.69987",
    "lng": "2.77606"
  },
  {
    "country": "FR",
    "name": "Liverdun",
    "lat": "48.75084",
    "lng": "6.06424"
  },
  {
    "country": "FR",
    "name": "Livarot",
    "lat": "49.005",
    "lng": "0.1502"
  },
  {
    "country": "FR",
    "name": "Lit-et-Mixe",
    "lat": "44.03308",
    "lng": "-1.2533"
  },
  {
    "country": "FR",
    "name": "Listrac-Médoc",
    "lat": "45.0741",
    "lng": "-0.79132"
  },
  {
    "country": "FR",
    "name": "Lissieu",
    "lat": "45.86426",
    "lng": "4.74703"
  },
  {
    "country": "FR",
    "name": "Lisses",
    "lat": "48.60222",
    "lng": "2.42245"
  },
  {
    "country": "FR",
    "name": "Lisle-sur-Tarn",
    "lat": "43.85249",
    "lng": "1.81099"
  },
  {
    "country": "FR",
    "name": "L’Isle-sur-la-Sorgue",
    "lat": "43.91915",
    "lng": "5.05092"
  },
  {
    "country": "FR",
    "name": "L’Isle-en-Dodon",
    "lat": "43.38428",
    "lng": "0.83513"
  },
  {
    "country": "FR",
    "name": "L’Isle-d’Abeau",
    "lat": "45.61813",
    "lng": "5.23546"
  },
  {
    "country": "FR",
    "name": "L’Isle-Adam",
    "lat": "49.10744",
    "lng": "2.22818"
  },
  {
    "country": "FR",
    "name": "Lisieux",
    "lat": "49.1466",
    "lng": "0.22925"
  },
  {
    "country": "FR",
    "name": "Liré",
    "lat": "47.34322",
    "lng": "-1.16536"
  },
  {
    "country": "FR",
    "name": "Lipsheim",
    "lat": "48.49164",
    "lng": "7.66751"
  },
  {
    "country": "FR",
    "name": "Lion-sur-Mer",
    "lat": "49.30018",
    "lng": "-0.32157"
  },
  {
    "country": "FR",
    "name": "Linxe",
    "lat": "43.91984",
    "lng": "-1.24619"
  },
  {
    "country": "FR",
    "name": "Linselles",
    "lat": "50.73708",
    "lng": "3.07878"
  },
  {
    "country": "FR",
    "name": "Linguizzetta",
    "lat": "42.26024",
    "lng": "9.47333"
  },
  {
    "country": "FR",
    "name": "Lingolsheim",
    "lat": "48.55752",
    "lng": "7.68253"
  },
  {
    "country": "FR",
    "name": "Linas",
    "lat": "48.63041",
    "lng": "2.26266"
  },
  {
    "country": "FR",
    "name": "Linars",
    "lat": "45.65",
    "lng": "0.08333"
  },
  {
    "country": "FR",
    "name": "Linards",
    "lat": "45.70083",
    "lng": "1.53259"
  },
  {
    "country": "FR",
    "name": "Limoux",
    "lat": "43.05487",
    "lng": "2.22173"
  },
  {
    "country": "FR",
    "name": "Limours",
    "lat": "48.64625",
    "lng": "2.07688"
  },
  {
    "country": "FR",
    "name": "Limonest",
    "lat": "45.83744",
    "lng": "4.7718"
  },
  {
    "country": "FR",
    "name": "Limoges",
    "lat": "45.83153",
    "lng": "1.25781"
  },
  {
    "country": "FR",
    "name": "Limetz-Villez",
    "lat": "49.06667",
    "lng": "1.55"
  },
  {
    "country": "FR",
    "name": "Limésy",
    "lat": "49.61271",
    "lng": "0.92483"
  },
  {
    "country": "FR",
    "name": "Limerzel",
    "lat": "47.63619",
    "lng": "-2.35448"
  },
  {
    "country": "FR",
    "name": "Limeil-Brévannes",
    "lat": "48.7448",
    "lng": "2.48705"
  },
  {
    "country": "FR",
    "name": "Limay",
    "lat": "48.99553",
    "lng": "1.74081"
  },
  {
    "country": "FR",
    "name": "Limas",
    "lat": "45.97896",
    "lng": "4.70292"
  },
  {
    "country": "FR",
    "name": "Lillers",
    "lat": "50.56345",
    "lng": "2.48042"
  },
  {
    "country": "FR",
    "name": "Lillebonne",
    "lat": "49.5203",
    "lng": "0.53617"
  },
  {
    "country": "FR",
    "name": "Lille",
    "lat": "50.63297",
    "lng": "3.05858"
  },
  {
    "country": "FR",
    "name": "L'Île-Rousse",
    "lat": "42.63371",
    "lng": "8.93764"
  },
  {
    "country": "FR",
    "name": "L'Île-Bouchard",
    "lat": "47.11667",
    "lng": "0.41667"
  },
  {
    "country": "FR",
    "name": "Ligugé",
    "lat": "46.52035",
    "lng": "0.32617"
  },
  {
    "country": "FR",
    "name": "Ligueil",
    "lat": "47.0421",
    "lng": "0.81893"
  },
  {
    "country": "FR",
    "name": "Ligré",
    "lat": "47.11185",
    "lng": "0.27562"
  },
  {
    "country": "FR",
    "name": "Ligny-le-Ribault",
    "lat": "47.68419",
    "lng": "1.78153"
  },
  {
    "country": "FR",
    "name": "Ligny-le-Châtel",
    "lat": "47.90022",
    "lng": "3.7576"
  },
  {
    "country": "FR",
    "name": "Ligny-en-Cambrésis",
    "lat": "50.10123",
    "lng": "3.37841"
  },
  {
    "country": "FR",
    "name": "Ligny-en-Barrois",
    "lat": "48.68861",
    "lng": "5.32543"
  },
  {
    "country": "FR",
    "name": "Lignières",
    "lat": "46.75152",
    "lng": "2.17381"
  },
  {
    "country": "FR",
    "name": "Ligné",
    "lat": "47.41096",
    "lng": "-1.37726"
  },
  {
    "country": "FR",
    "name": "Lignan-sur-Orb",
    "lat": "43.38462",
    "lng": "3.16891"
  },
  {
    "country": "FR",
    "name": "Liffré",
    "lat": "48.21324",
    "lng": "-1.50838"
  },
  {
    "country": "FR",
    "name": "Liffol-le-Grand",
    "lat": "48.31771",
    "lng": "5.58125"
  },
  {
    "country": "FR",
    "name": "Liévin",
    "lat": "50.4198",
    "lng": "2.78068"
  },
  {
    "country": "FR",
    "name": "Lieu-Saint-Amand",
    "lat": "50.27318",
    "lng": "3.34624"
  },
  {
    "country": "FR",
    "name": "Lieusaint",
    "lat": "48.63476",
    "lng": "2.54806"
  },
  {
    "country": "FR",
    "name": "Lieurey",
    "lat": "49.23019",
    "lng": "0.49879"
  },
  {
    "country": "FR",
    "name": "Lieuran-lès-Béziers",
    "lat": "43.4186",
    "lng": "3.23719"
  },
  {
    "country": "FR",
    "name": "Liesse-Notre-Dame",
    "lat": "49.61667",
    "lng": "3.8"
  },
  {
    "country": "FR",
    "name": "Liergues",
    "lat": "45.97138",
    "lng": "4.66231"
  },
  {
    "country": "FR",
    "name": "Lièpvre",
    "lat": "48.27036",
    "lng": "7.28414"
  },
  {
    "country": "FR",
    "name": "Licques",
    "lat": "50.78416",
    "lng": "1.93844"
  },
  {
    "country": "FR",
    "name": "Libourne",
    "lat": "44.91667",
    "lng": "-0.23333"
  },
  {
    "country": "FR",
    "name": "Libercourt",
    "lat": "50.48322",
    "lng": "3.01584"
  },
  {
    "country": "FR",
    "name": "Liancourt",
    "lat": "49.33034",
    "lng": "2.46595"
  },
  {
    "country": "FR",
    "name": "Hôpital-Camfrout",
    "lat": "48.32789",
    "lng": "-4.24155"
  },
  {
    "country": "FR",
    "name": "Lherm",
    "lat": "43.43127",
    "lng": "1.22239"
  },
  {
    "country": "FR",
    "name": "L'Haÿ-les-Roses",
    "lat": "48.78333",
    "lng": "2.33333"
  },
  {
    "country": "FR",
    "name": "Lezoux",
    "lat": "45.82689",
    "lng": "3.37924"
  },
  {
    "country": "FR",
    "name": "Lézigneux",
    "lat": "45.56705",
    "lng": "4.06524"
  },
  {
    "country": "FR",
    "name": "Lézignan-la-Cèbe",
    "lat": "43.49368",
    "lng": "3.43708"
  },
  {
    "country": "FR",
    "name": "Lézignan-Corbières",
    "lat": "43.19765",
    "lng": "2.76142"
  },
  {
    "country": "FR",
    "name": "Lezennes",
    "lat": "50.61553",
    "lng": "3.11354"
  },
  {
    "country": "FR",
    "name": "Lezay",
    "lat": "46.26437",
    "lng": "-0.00925"
  },
  {
    "country": "FR",
    "name": "Lézat-sur-Lèze",
    "lat": "43.27734",
    "lng": "1.34686"
  },
  {
    "country": "FR",
    "name": "Lézardrieux",
    "lat": "48.7851",
    "lng": "-3.10588"
  },
  {
    "country": "FR",
    "name": "Lézan",
    "lat": "44.01667",
    "lng": "4.05"
  },
  {
    "country": "FR",
    "name": "Leyment",
    "lat": "45.92294",
    "lng": "5.29479"
  },
  {
    "country": "FR",
    "name": "Leymen",
    "lat": "47.49522",
    "lng": "7.48426"
  },
  {
    "country": "FR",
    "name": "Leyme",
    "lat": "44.78622",
    "lng": "1.89897"
  },
  {
    "country": "FR",
    "name": "Lexy",
    "lat": "49.50356",
    "lng": "5.7338"
  },
  {
    "country": "FR",
    "name": "Lewarde",
    "lat": "50.34173",
    "lng": "3.16782"
  },
  {
    "country": "FR",
    "name": "Levroux",
    "lat": "46.9786",
    "lng": "1.61243"
  },
  {
    "country": "FR",
    "name": "Le Vivier-sur-Mer",
    "lat": "48.60169",
    "lng": "-1.77303"
  },
  {
    "country": "FR",
    "name": "Viviers-du-Lac",
    "lat": "45.65",
    "lng": "5.9"
  },
  {
    "country": "FR",
    "name": "Lévis-Saint-Nom",
    "lat": "48.71667",
    "lng": "1.95"
  },
  {
    "country": "FR",
    "name": "Lévignac",
    "lat": "43.66667",
    "lng": "1.2"
  },
  {
    "country": "FR",
    "name": "Le Vigen",
    "lat": "45.75149",
    "lng": "1.28865"
  },
  {
    "country": "FR",
    "name": "Le Vigan",
    "lat": "44.74075",
    "lng": "1.43963"
  },
  {
    "country": "FR",
    "name": "Le Vigan",
    "lat": "43.98333",
    "lng": "3.6"
  },
  {
    "country": "FR",
    "name": "Levier",
    "lat": "46.95302",
    "lng": "6.12059"
  },
  {
    "country": "FR",
    "name": "Le Vieil-Baugé",
    "lat": "47.53193",
    "lng": "-0.11888"
  },
  {
    "country": "FR",
    "name": "Levet",
    "lat": "46.92605",
    "lng": "2.40732"
  },
  {
    "country": "FR",
    "name": "Le Vésinet",
    "lat": "48.89281",
    "lng": "2.13308"
  },
  {
    "country": "FR",
    "name": "Lèves",
    "lat": "48.47065",
    "lng": "1.48194"
  },
  {
    "country": "FR",
    "name": "Le Versoud",
    "lat": "45.21386",
    "lng": "5.85815"
  },
  {
    "country": "FR",
    "name": "Vernet",
    "lat": "43.43333",
    "lng": "1.41667"
  },
  {
    "country": "FR",
    "name": "Le Verdon-sur-Mer",
    "lat": "45.5449",
    "lng": "-1.06225"
  },
  {
    "country": "FR",
    "name": "Levens",
    "lat": "43.86043",
    "lng": "7.22653"
  },
  {
    "country": "FR",
    "name": "Le Vaudreuil",
    "lat": "49.25407",
    "lng": "1.2096"
  },
  {
    "country": "FR",
    "name": "Le Val-Saint-Père",
    "lat": "48.66177",
    "lng": "-1.37653"
  },
  {
    "country": "FR",
    "name": "Le Val-Saint-Germain",
    "lat": "48.56601",
    "lng": "2.06471"
  },
  {
    "country": "FR",
    "name": "Levallois-Perret",
    "lat": "48.89389",
    "lng": "2.28864"
  },
  {
    "country": "FR",
    "name": "Valdahon",
    "lat": "47.15",
    "lng": "6.35"
  },
  {
    "country": "FR",
    "name": "Leval",
    "lat": "50.18106",
    "lng": "3.83093"
  },
  {
    "country": "FR",
    "name": "Le Val",
    "lat": "43.43865",
    "lng": "6.07295"
  },
  {
    "country": "FR",
    "name": "Leuville-sur-Orge",
    "lat": "48.6173",
    "lng": "2.26685"
  },
  {
    "country": "FR",
    "name": "Leudeville",
    "lat": "48.56591",
    "lng": "2.32676"
  },
  {
    "country": "FR",
    "name": "Leucate",
    "lat": "42.91056",
    "lng": "3.02944"
  },
  {
    "country": "FR",
    "name": "Le Trévoux",
    "lat": "47.89478",
    "lng": "-3.6408"
  },
  {
    "country": "FR",
    "name": "Le Tréport",
    "lat": "50.05979",
    "lng": "1.37583"
  },
  {
    "country": "FR",
    "name": "L’Étrat",
    "lat": "45.48578",
    "lng": "4.37734"
  },
  {
    "country": "FR",
    "name": "Le Trait",
    "lat": "49.46895",
    "lng": "0.81634"
  },
  {
    "country": "FR",
    "name": "Le Touvet",
    "lat": "45.35809",
    "lng": "5.94889"
  },
  {
    "country": "FR",
    "name": "Le Touquet-Paris-Plage",
    "lat": "50.52432",
    "lng": "1.58571"
  },
  {
    "country": "FR",
    "name": "Le Tignet",
    "lat": "43.63887",
    "lng": "6.84173"
  },
  {
    "country": "FR",
    "name": "Le Thuit-Signol",
    "lat": "49.26487",
    "lng": "0.9391"
  },
  {
    "country": "FR",
    "name": "Le Thou",
    "lat": "46.08333",
    "lng": "-0.91667"
  },
  {
    "country": "FR",
    "name": "Le Thoronet",
    "lat": "43.45257",
    "lng": "6.30343"
  },
  {
    "country": "FR",
    "name": "Le Thor",
    "lat": "43.92943",
    "lng": "4.99543"
  },
  {
    "country": "FR",
    "name": "Le Tholy",
    "lat": "48.08229",
    "lng": "6.74351"
  },
  {
    "country": "FR",
    "name": "Le Tholonet",
    "lat": "43.52176",
    "lng": "5.51115"
  },
  {
    "country": "FR",
    "name": "Le Thillot",
    "lat": "47.87941",
    "lng": "6.76279"
  },
  {
    "country": "FR",
    "name": "Le Thillay",
    "lat": "49.00659",
    "lng": "2.47218"
  },
  {
    "country": "FR",
    "name": "Le Theil-de-Bretagne",
    "lat": "47.9195",
    "lng": "-1.42975"
  },
  {
    "country": "FR",
    "name": "Le Theil-Bocage",
    "lat": "48.88333",
    "lng": "-0.71667"
  },
  {
    "country": "FR",
    "name": "Le Temple-de-Bretagne",
    "lat": "47.32737",
    "lng": "-1.78904"
  },
  {
    "country": "FR",
    "name": "Le Teilleul",
    "lat": "48.53758",
    "lng": "-0.87304"
  },
  {
    "country": "FR",
    "name": "Le Teil",
    "lat": "44.54679",
    "lng": "4.68165"
  },
  {
    "country": "FR",
    "name": "Le Teich",
    "lat": "44.63177",
    "lng": "-1.02155"
  },
  {
    "country": "FR",
    "name": "Le Tallud",
    "lat": "46.62911",
    "lng": "-0.29979"
  },
  {
    "country": "FR",
    "name": "Le Taillan-Médoc",
    "lat": "44.90521",
    "lng": "-0.6706"
  },
  {
    "country": "FR",
    "name": "Le Syndicat",
    "lat": "48.01733",
    "lng": "6.68436"
  },
  {
    "country": "FR",
    "name": "Les Vans",
    "lat": "44.40619",
    "lng": "4.13471"
  },
  {
    "country": "FR",
    "name": "Lestrem",
    "lat": "50.61987",
    "lng": "2.68646"
  },
  {
    "country": "FR",
    "name": "Les Touches",
    "lat": "47.44249",
    "lng": "-1.43097"
  },
  {
    "country": "FR",
    "name": "Lestelle-Bétharram",
    "lat": "43.13333",
    "lng": "-0.21667"
  },
  {
    "country": "FR",
    "name": "L'Estaque",
    "lat": "43.36385",
    "lng": "5.30854"
  },
  {
    "country": "FR",
    "name": "Les Sorinières",
    "lat": "47.14831",
    "lng": "-1.52932"
  },
  {
    "country": "FR",
    "name": "Lessay",
    "lat": "49.21703",
    "lng": "-1.53089"
  },
  {
    "country": "FR",
    "name": "Les Salles-du-Gardon",
    "lat": "44.2079",
    "lng": "4.03689"
  },
  {
    "country": "FR",
    "name": "Les Sables-d'Olonne",
    "lat": "46.5",
    "lng": "-1.78333"
  },
  {
    "country": "FR",
    "name": "Les Rousses",
    "lat": "46.48412",
    "lng": "6.0633"
  },
  {
    "country": "FR",
    "name": "Les Rosiers-sur-Loire",
    "lat": "47.35",
    "lng": "-0.21667"
  },
  {
    "country": "FR",
    "name": "Les Roches-de-Condrieu",
    "lat": "45.45107",
    "lng": "4.76738"
  },
  {
    "country": "FR",
    "name": "Les Riceys",
    "lat": "47.9939",
    "lng": "4.36986"
  },
  {
    "country": "FR",
    "name": "Lesquin",
    "lat": "50.58232",
    "lng": "3.119"
  },
  {
    "country": "FR",
    "name": "Les Ponts-de-Cé",
    "lat": "47.42315",
    "lng": "-0.52477"
  },
  {
    "country": "FR",
    "name": "Lespinasse",
    "lat": "43.71206",
    "lng": "1.38462"
  },
  {
    "country": "FR",
    "name": "Lespignan",
    "lat": "43.27366",
    "lng": "3.17224"
  },
  {
    "country": "FR",
    "name": "Les Pieux",
    "lat": "49.51286",
    "lng": "-1.80714"
  },
  {
    "country": "FR",
    "name": "Les Pennes-Mirabeau",
    "lat": "43.41028",
    "lng": "5.31306"
  },
  {
    "country": "FR",
    "name": "Les Peintures",
    "lat": "45.06667",
    "lng": "-0.1"
  },
  {
    "country": "FR",
    "name": "Les Pavillons-sous-Bois",
    "lat": "48.90683",
    "lng": "2.50648"
  },
  {
    "country": "FR",
    "name": "Lesparre-Médoc",
    "lat": "45.3",
    "lng": "-0.93333"
  },
  {
    "country": "FR",
    "name": "Le Sourn",
    "lat": "48.04262",
    "lng": "-2.9879"
  },
  {
    "country": "FR",
    "name": "Les Ormes",
    "lat": "46.97478",
    "lng": "0.60484"
  },
  {
    "country": "FR",
    "name": "Les Olives",
    "lat": "43.32393",
    "lng": "5.4584"
  },
  {
    "country": "FR",
    "name": "Le Soler",
    "lat": "42.68101",
    "lng": "2.79335"
  },
  {
    "country": "FR",
    "name": "Les Noës-près-Troyes",
    "lat": "48.30358",
    "lng": "4.04552"
  },
  {
    "country": "FR",
    "name": "Lesneven",
    "lat": "48.57233",
    "lng": "-4.32133"
  },
  {
    "country": "FR",
    "name": "Les Mureaux",
    "lat": "48.99173",
    "lng": "1.90972"
  },
  {
    "country": "FR",
    "name": "Moutiers-les-Mauxfaits",
    "lat": "46.48333",
    "lng": "-1.41667"
  },
  {
    "country": "FR",
    "name": "Les Moutiers-en-Retz",
    "lat": "47.06375",
    "lng": "-1.999"
  },
  {
    "country": "FR",
    "name": "Les Montils",
    "lat": "47.49499",
    "lng": "1.29775"
  },
  {
    "country": "FR",
    "name": "Les Molières",
    "lat": "48.67306",
    "lng": "2.06959"
  },
  {
    "country": "FR",
    "name": "Les Mées",
    "lat": "44.03071",
    "lng": "5.97681"
  },
  {
    "country": "FR",
    "name": "Les Mathes",
    "lat": "45.7139",
    "lng": "-1.15497"
  },
  {
    "country": "FR",
    "name": "Les Matelles",
    "lat": "43.72905",
    "lng": "3.8136"
  },
  {
    "country": "FR",
    "name": "Les Marches",
    "lat": "45.49921",
    "lng": "6.00087"
  },
  {
    "country": "FR",
    "name": "Les Magnils-Reigniers",
    "lat": "46.48333",
    "lng": "-1.21667"
  },
  {
    "country": "FR",
    "name": "Les Mages",
    "lat": "44.22862",
    "lng": "4.16946"
  },
  {
    "country": "FR",
    "name": "Les Lucs-sur-Boulogne",
    "lat": "46.84478",
    "lng": "-1.49445"
  },
  {
    "country": "FR",
    "name": "Les Loges-Marchis",
    "lat": "48.54132",
    "lng": "-1.08754"
  },
  {
    "country": "FR",
    "name": "Les Loges-en-Josas",
    "lat": "48.76377",
    "lng": "2.14002"
  },
  {
    "country": "FR",
    "name": "Les Loges",
    "lat": "49.6986",
    "lng": "0.28403"
  },
  {
    "country": "FR",
    "name": "Les Lilas",
    "lat": "48.87992",
    "lng": "2.42057"
  },
  {
    "country": "FR",
    "name": "Les Landes-Genusson",
    "lat": "46.96667",
    "lng": "-1.11667"
  },
  {
    "country": "FR",
    "name": "Lésigny",
    "lat": "48.74374",
    "lng": "2.61518"
  },
  {
    "country": "FR",
    "name": "Les Houches",
    "lat": "45.89011",
    "lng": "6.79613"
  },
  {
    "country": "FR",
    "name": "Les Herbiers",
    "lat": "46.86667",
    "lng": "-1.01667"
  },
  {
    "country": "FR",
    "name": "Les Hautes-Rivières",
    "lat": "49.88595",
    "lng": "4.84186"
  },
  {
    "country": "FR",
    "name": "Les Grandes-Ventes",
    "lat": "49.78544",
    "lng": "1.22921"
  },
  {
    "country": "FR",
    "name": "Les Gonds",
    "lat": "45.71437",
    "lng": "-0.61408"
  },
  {
    "country": "FR",
    "name": "Les Gets",
    "lat": "46.15522",
    "lng": "6.66492"
  },
  {
    "country": "FR",
    "name": "Les Fourgs",
    "lat": "46.83455",
    "lng": "6.39953"
  },
  {
    "country": "FR",
    "name": "Les Forges",
    "lat": "48.17747",
    "lng": "6.38846"
  },
  {
    "country": "FR",
    "name": "Les Fins",
    "lat": "47.07764",
    "lng": "6.63002"
  },
  {
    "country": "FR",
    "name": "Les Essarts-le-Roi",
    "lat": "48.71673",
    "lng": "1.90089"
  },
  {
    "country": "FR",
    "name": "Les Essarts",
    "lat": "46.7744",
    "lng": "-1.22834"
  },
  {
    "country": "FR",
    "name": "Les Epesses",
    "lat": "46.88333",
    "lng": "-0.9"
  },
  {
    "country": "FR",
    "name": "Les Églisottes-et-Chalaures",
    "lat": "45.1",
    "lng": "-0.05"
  },
  {
    "country": "FR",
    "name": "Les Échelles",
    "lat": "45.43481",
    "lng": "5.75133"
  },
  {
    "country": "FR",
    "name": "Les Contamines-Montjoie",
    "lat": "45.82136",
    "lng": "6.72817"
  },
  {
    "country": "FR",
    "name": "Les Clouzeaux",
    "lat": "46.62881",
    "lng": "-1.50947"
  },
  {
    "country": "FR",
    "name": "Les Clayes-sous-Bois",
    "lat": "48.82206",
    "lng": "1.98677"
  },
  {
    "country": "FR",
    "name": "Les Chères",
    "lat": "45.88975",
    "lng": "4.7467"
  },
  {
    "country": "FR",
    "name": "Les Champs-Géraux",
    "lat": "48.41647",
    "lng": "-1.97087"
  },
  {
    "country": "FR",
    "name": "L’Escarène",
    "lat": "43.8365",
    "lng": "7.35457"
  },
  {
    "country": "FR",
    "name": "Lescar",
    "lat": "43.33333",
    "lng": "-0.41667"
  },
  {
    "country": "FR",
    "name": "Les Camoins",
    "lat": "43.30607",
    "lng": "5.51745"
  },
  {
    "country": "FR",
    "name": "L’Escale",
    "lat": "44.08225",
    "lng": "6.0236"
  },
  {
    "country": "FR",
    "name": "Les Brouzils",
    "lat": "46.88571",
    "lng": "-1.32095"
  },
  {
    "country": "FR",
    "name": "Les Baumettes",
    "lat": "43.22641",
    "lng": "5.41642"
  },
  {
    "country": "FR",
    "name": "Les Aygalades",
    "lat": "43.35711",
    "lng": "5.37116"
  },
  {
    "country": "FR",
    "name": "Les Avenières",
    "lat": "45.63156",
    "lng": "5.57074"
  },
  {
    "country": "FR",
    "name": "Les Authieux-sur-le-Port-Saint-Ouen",
    "lat": "49.341",
    "lng": "1.13465"
  },
  {
    "country": "FR",
    "name": "Les Attaques",
    "lat": "50.90962",
    "lng": "1.92961"
  },
  {
    "country": "FR",
    "name": "Les Artigues-de-Lussac",
    "lat": "44.96667",
    "lng": "-0.15"
  },
  {
    "country": "FR",
    "name": "Les Arcs",
    "lat": "43.45702",
    "lng": "6.47905"
  },
  {
    "country": "FR",
    "name": "Le Sappey-en-Chartreuse",
    "lat": "45.25998",
    "lng": "5.77721"
  },
  {
    "country": "FR",
    "name": "Les Angles",
    "lat": "43.95806",
    "lng": "4.76342"
  },
  {
    "country": "FR",
    "name": "Les Andelys",
    "lat": "49.25",
    "lng": "1.41667"
  },
  {
    "country": "FR",
    "name": "Les Ancizes-Comps",
    "lat": "45.92535",
    "lng": "2.81074"
  },
  {
    "country": "FR",
    "name": "Les Alluets-le-Roi",
    "lat": "48.91379",
    "lng": "1.9181"
  },
  {
    "country": "FR",
    "name": "Les Allues",
    "lat": "45.43255",
    "lng": "6.55558"
  },
  {
    "country": "FR",
    "name": "Les Aix-d’Angillon",
    "lat": "47.19652",
    "lng": "2.56506"
  },
  {
    "country": "FR",
    "name": "Les Ageux",
    "lat": "49.31667",
    "lng": "2.6"
  },
  {
    "country": "FR",
    "name": "Les Abrets",
    "lat": "45.53706",
    "lng": "5.58535"
  },
  {
    "country": "FR",
    "name": "Léry",
    "lat": "49.28585",
    "lng": "1.20768"
  },
  {
    "country": "FR",
    "name": "Le Russey",
    "lat": "47.16055",
    "lng": "6.72912"
  },
  {
    "country": "FR",
    "name": "Le Rove",
    "lat": "43.36987",
    "lng": "5.25112"
  },
  {
    "country": "FR",
    "name": "Lérouville",
    "lat": "48.79261",
    "lng": "5.54063"
  },
  {
    "country": "FR",
    "name": "Le Rouret",
    "lat": "43.67873",
    "lng": "7.01521"
  },
  {
    "country": "FR",
    "name": "Le Rheu",
    "lat": "48.10228",
    "lng": "-1.79733"
  },
  {
    "country": "FR",
    "name": "Le Revest-les-Eaux",
    "lat": "43.17612",
    "lng": "5.92667"
  },
  {
    "country": "FR",
    "name": "Le Relecq-Kerhuon",
    "lat": "48.40691",
    "lng": "-4.39359"
  },
  {
    "country": "FR",
    "name": "Le Redon",
    "lat": "43.24604",
    "lng": "5.42889"
  },
  {
    "country": "FR",
    "name": "Léré",
    "lat": "47.46867",
    "lng": "2.86981"
  },
  {
    "country": "FR",
    "name": "Le Raincy",
    "lat": "48.9",
    "lng": "2.51667"
  },
  {
    "country": "FR",
    "name": "Le Quesnoy",
    "lat": "50.24797",
    "lng": "3.63656"
  },
  {
    "country": "FR",
    "name": "Le Puy-Sainte-Réparade",
    "lat": "43.66319",
    "lng": "5.43434"
  },
  {
    "country": "FR",
    "name": "Le Puy-Notre-Dame",
    "lat": "47.12551",
    "lng": "-0.23572"
  },
  {
    "country": "FR",
    "name": "Le Puy-en-Velay",
    "lat": "45.04366",
    "lng": "3.88523"
  },
  {
    "country": "FR",
    "name": "Lepuix",
    "lat": "47.75997",
    "lng": "6.8165"
  },
  {
    "country": "FR",
    "name": "Le Pré-Saint-Gervais",
    "lat": "48.88549",
    "lng": "2.40422"
  },
  {
    "country": "FR",
    "name": "Le Pradet",
    "lat": "43.10661",
    "lng": "6.01718"
  },
  {
    "country": "FR",
    "name": "Le Pouzin",
    "lat": "44.75173",
    "lng": "4.74798"
  },
  {
    "country": "FR",
    "name": "Le Pouliguen",
    "lat": "47.26973",
    "lng": "-2.4278"
  },
  {
    "country": "FR",
    "name": "Le Poujol-sur-Orb",
    "lat": "43.57919",
    "lng": "3.06156"
  },
  {
    "country": "FR",
    "name": "Le Pouget",
    "lat": "43.59195",
    "lng": "3.52423"
  },
  {
    "country": "FR",
    "name": "Le Port-Marly",
    "lat": "48.89016",
    "lng": "2.11139"
  },
  {
    "country": "FR",
    "name": "Le Portel",
    "lat": "50.70559",
    "lng": "1.57574"
  },
  {
    "country": "FR",
    "name": "Port-des-Barques",
    "lat": "45.94763",
    "lng": "-1.07795"
  },
  {
    "country": "FR",
    "name": "Le Porge",
    "lat": "44.87277",
    "lng": "-1.08889"
  },
  {
    "country": "FR",
    "name": "Le Pontet",
    "lat": "43.96119",
    "lng": "4.86008"
  },
  {
    "country": "FR",
    "name": "Le Pont-de-Claix",
    "lat": "45.12443",
    "lng": "5.7064"
  },
  {
    "country": "FR",
    "name": "Le Pont-de-Beauvoisin",
    "lat": "45.53694",
    "lng": "5.67333"
  },
  {
    "country": "FR",
    "name": "Le Poiré-sur-Vie",
    "lat": "46.76921",
    "lng": "-1.50938"
  },
  {
    "country": "FR",
    "name": "Le Poinçonnet",
    "lat": "46.7641",
    "lng": "1.7179"
  },
  {
    "country": "FR",
    "name": "Le Plessis-Trévise",
    "lat": "48.81074",
    "lng": "2.57363"
  },
  {
    "country": "FR",
    "name": "Le Plessis-Robinson",
    "lat": "48.78889",
    "lng": "2.27078"
  },
  {
    "country": "FR",
    "name": "Le Plessis-Pâté",
    "lat": "48.61078",
    "lng": "2.32318"
  },
  {
    "country": "FR",
    "name": "Le Plessis-Macé",
    "lat": "47.54304",
    "lng": "-0.67436"
  },
  {
    "country": "FR",
    "name": "Le Plessis-Grammoire",
    "lat": "47.49884",
    "lng": "-0.43021"
  },
  {
    "country": "FR",
    "name": "Le Plessis-Brion",
    "lat": "49.46419",
    "lng": "2.89096"
  },
  {
    "country": "FR",
    "name": "Le Plessis-Bouchard",
    "lat": "49",
    "lng": "2.23333"
  },
  {
    "country": "FR",
    "name": "Le Plessis-Belleville",
    "lat": "49.09501",
    "lng": "2.75614"
  },
  {
    "country": "FR",
    "name": "Le Pizou",
    "lat": "45.01667",
    "lng": "0.06667"
  },
  {
    "country": "FR",
    "name": "Le Pin-en-Mauges",
    "lat": "47.25357",
    "lng": "-0.89917"
  },
  {
    "country": "FR",
    "name": "Le Pin",
    "lat": "48.91523",
    "lng": "2.62841"
  },
  {
    "country": "FR",
    "name": "Le Pin",
    "lat": "46.86179",
    "lng": "-0.6544"
  },
  {
    "country": "FR",
    "name": "Le Pin",
    "lat": "45.45582",
    "lng": "5.50497"
  },
  {
    "country": "FR",
    "name": "Le Pian-Médoc",
    "lat": "44.95537",
    "lng": "-0.66227"
  },
  {
    "country": "FR",
    "name": "Le Petit-Quevilly",
    "lat": "49.41338",
    "lng": "1.06155"
  },
  {
    "country": "FR",
    "name": "Petit-Couronne",
    "lat": "49.38333",
    "lng": "1.01667"
  },
  {
    "country": "FR",
    "name": "Le Pertre",
    "lat": "48.03373",
    "lng": "-1.03735"
  },
  {
    "country": "FR",
    "name": "Le Perrier",
    "lat": "46.81932",
    "lng": "-1.99306"
  },
  {
    "country": "FR",
    "name": "Le Perreux-sur-Marne",
    "lat": "48.85",
    "lng": "2.5"
  },
  {
    "country": "FR",
    "name": "Le Perréon",
    "lat": "46.06312",
    "lng": "4.60205"
  },
  {
    "country": "FR",
    "name": "Le Perray-en-Yvelines",
    "lat": "48.69441",
    "lng": "1.85643"
  },
  {
    "country": "FR",
    "name": "Le Pellerin",
    "lat": "47.19915",
    "lng": "-1.75514"
  },
  {
    "country": "FR",
    "name": "Le Pecq",
    "lat": "48.89317",
    "lng": "2.10371"
  },
  {
    "country": "FR",
    "name": "Le Pêchereau",
    "lat": "46.57677",
    "lng": "1.54743"
  },
  {
    "country": "FR",
    "name": "Le Péage-de-Roussillon",
    "lat": "45.37179",
    "lng": "4.79791"
  },
  {
    "country": "FR",
    "name": "Le Passage",
    "lat": "44.20143",
    "lng": "0.60275"
  },
  {
    "country": "FR",
    "name": "Le Pallet",
    "lat": "47.13809",
    "lng": "-1.33476"
  },
  {
    "country": "FR",
    "name": "Le Palais-sur-Vienne",
    "lat": "45.8638",
    "lng": "1.32207"
  },
  {
    "country": "FR",
    "name": "Le Palais",
    "lat": "47.34557",
    "lng": "-3.15411"
  },
  {
    "country": "FR",
    "name": "Léon",
    "lat": "43.87676",
    "lng": "-1.30057"
  },
  {
    "country": "FR",
    "name": "Léognan",
    "lat": "44.73548",
    "lng": "-0.59738"
  },
  {
    "country": "FR",
    "name": "Lentilly",
    "lat": "45.81984",
    "lng": "4.66352"
  },
  {
    "country": "FR",
    "name": "Lentigny",
    "lat": "45.99596",
    "lng": "3.98163"
  },
  {
    "country": "FR",
    "name": "Lent",
    "lat": "46.12032",
    "lng": "5.19369"
  },
  {
    "country": "FR",
    "name": "Lens",
    "lat": "50.43302",
    "lng": "2.82791"
  },
  {
    "country": "FR",
    "name": "Le Nouvion-en-Thiérache",
    "lat": "50.01625",
    "lng": "3.78509"
  },
  {
    "country": "FR",
    "name": "Le Neubourg",
    "lat": "49.15048",
    "lng": "0.9102"
  },
  {
    "country": "FR",
    "name": "Lencloître",
    "lat": "46.81622",
    "lng": "0.32827"
  },
  {
    "country": "FR",
    "name": "Le Muy",
    "lat": "43.47381",
    "lng": "6.56452"
  },
  {
    "country": "FR",
    "name": "Lempdes-sur-Allagnon",
    "lat": "45.38333",
    "lng": "3.28333"
  },
  {
    "country": "FR",
    "name": "Mont-Dore",
    "lat": "45.56667",
    "lng": "2.81667"
  },
  {
    "country": "FR",
    "name": "Le Monêtier-les-Bains",
    "lat": "44.97565",
    "lng": "6.50671"
  },
  {
    "country": "FR",
    "name": "Le Monastier-sur-Gazeille",
    "lat": "44.93333",
    "lng": "4"
  },
  {
    "country": "FR",
    "name": "Le Monastère",
    "lat": "44.34165",
    "lng": "2.57956"
  },
  {
    "country": "FR",
    "name": "Le Molay-Littry",
    "lat": "49.24265",
    "lng": "-0.87238"
  },
  {
    "country": "FR",
    "name": "Le Minihic-sur-Rance",
    "lat": "48.57835",
    "lng": "-2.00876"
  },
  {
    "country": "FR",
    "name": "Le Meux",
    "lat": "49.36718",
    "lng": "2.74374"
  },
  {
    "country": "FR",
    "name": "Le Mesnil-sur-Oger",
    "lat": "48.94708",
    "lng": "4.02263"
  },
  {
    "country": "FR",
    "name": "Le Mesnil-Saint-Denis",
    "lat": "48.74485",
    "lng": "1.95594"
  },
  {
    "country": "FR",
    "name": "Le Mesnil-le-Roi",
    "lat": "48.93825",
    "lng": "2.12554"
  },
  {
    "country": "FR",
    "name": "Le Mesnil-Esnard",
    "lat": "49.41319",
    "lng": "1.14521"
  },
  {
    "country": "FR",
    "name": "Le Mesnil-en-Vallée",
    "lat": "47.36551",
    "lng": "-0.93485"
  },
  {
    "country": "FR",
    "name": "Le Mesnil-en-Thelle",
    "lat": "49.1783",
    "lng": "2.28573"
  },
  {
    "country": "FR",
    "name": "Le Merlan",
    "lat": "43.33875",
    "lng": "5.40773"
  },
  {
    "country": "FR",
    "name": "Le Ménil",
    "lat": "47.90477",
    "lng": "6.78209"
  },
  {
    "country": "FR",
    "name": "Le Mée-sur-Seine",
    "lat": "48.53157",
    "lng": "2.62829"
  },
  {
    "country": "FR",
    "name": "Lembras",
    "lat": "44.88431",
    "lng": "0.52657"
  },
  {
    "country": "FR",
    "name": "Lemberg",
    "lat": "49.00199",
    "lng": "7.37889"
  },
  {
    "country": "FR",
    "name": "Lembach",
    "lat": "49.00362",
    "lng": "7.78986"
  },
  {
    "country": "FR",
    "name": "Le May-sur-Èvre",
    "lat": "47.13714",
    "lng": "-0.89227"
  },
  {
    "country": "FR",
    "name": "Le Mayet-de-Montagne",
    "lat": "46.07251",
    "lng": "3.66651"
  },
  {
    "country": "FR",
    "name": "Le Mas-d’Agenais",
    "lat": "44.41033",
    "lng": "0.21869"
  },
  {
    "country": "FR",
    "name": "Le Mans",
    "lat": "48.00039",
    "lng": "0.20471"
  },
  {
    "country": "FR",
    "name": "Le Manoir",
    "lat": "49.31355",
    "lng": "1.20455"
  },
  {
    "country": "FR",
    "name": "Le Malzieu-Ville",
    "lat": "44.85699",
    "lng": "3.33302"
  },
  {
    "country": "FR",
    "name": "Le Lude",
    "lat": "47.64648",
    "lng": "0.15664"
  },
  {
    "country": "FR",
    "name": "Le Luc",
    "lat": "43.39318",
    "lng": "6.31474"
  },
  {
    "country": "FR",
    "name": "Le Luart",
    "lat": "48.07053",
    "lng": "0.58564"
  },
  {
    "country": "FR",
    "name": "Le Louroux-Béconnais",
    "lat": "47.52211",
    "lng": "-0.88663"
  },
  {
    "country": "FR",
    "name": "Le Loroux-Bottereau",
    "lat": "47.23763",
    "lng": "-1.34952"
  },
  {
    "country": "FR",
    "name": "Le Longeron",
    "lat": "47.01845",
    "lng": "-1.05763"
  },
  {
    "country": "FR",
    "name": "Le Lavandou",
    "lat": "43.137",
    "lng": "6.366"
  },
  {
    "country": "FR",
    "name": "Le Lardin-Saint-Lazare",
    "lat": "45.13333",
    "lng": "1.21667"
  },
  {
    "country": "FR",
    "name": "Le Langon",
    "lat": "46.4385",
    "lng": "-0.94767"
  },
  {
    "country": "FR",
    "name": "Le Landreau",
    "lat": "47.20512",
    "lng": "-1.30452"
  },
  {
    "country": "FR",
    "name": "Le Kremlin-Bicêtre",
    "lat": "48.81471",
    "lng": "2.36073"
  },
  {
    "country": "FR",
    "name": "Le Houlme",
    "lat": "49.50972",
    "lng": "1.03537"
  },
  {
    "country": "FR",
    "name": "Le Houga",
    "lat": "43.77464",
    "lng": "-0.17833"
  },
  {
    "country": "FR",
    "name": "Léhon",
    "lat": "48.44432",
    "lng": "-2.04578"
  },
  {
    "country": "FR",
    "name": "Le Havre",
    "lat": "49.4938",
    "lng": "0.10767"
  },
  {
    "country": "FR",
    "name": "Le Haillan",
    "lat": "44.87225",
    "lng": "-0.67965"
  },
  {
    "country": "FR",
    "name": "Léguevin",
    "lat": "43.60028",
    "lng": "1.23236"
  },
  {
    "country": "FR",
    "name": "Le Gua",
    "lat": "45.72614",
    "lng": "-0.94468"
  },
  {
    "country": "FR",
    "name": "Le Gua",
    "lat": "45.01667",
    "lng": "5.61667"
  },
  {
    "country": "FR",
    "name": "Le Grau-du-Roi",
    "lat": "43.53881",
    "lng": "4.13559"
  },
  {
    "country": "FR",
    "name": "Le Grand-Quevilly",
    "lat": "49.40076",
    "lng": "1.04582"
  },
  {
    "country": "FR",
    "name": "Le Grand-Pressigny",
    "lat": "46.92017",
    "lng": "0.8038"
  },
  {
    "country": "FR",
    "name": "Le Grand-Lucé",
    "lat": "47.86618",
    "lng": "0.46919"
  },
  {
    "country": "FR",
    "name": "Le Grand-Lemps",
    "lat": "45.39789",
    "lng": "5.42215"
  },
  {
    "country": "FR",
    "name": "Le Grand-Bourg",
    "lat": "46.16018",
    "lng": "1.64465"
  },
  {
    "country": "FR",
    "name": "Le Grand-Bornand",
    "lat": "45.94346",
    "lng": "6.44111"
  },
  {
    "country": "FR",
    "name": "Gond-Pontouvre",
    "lat": "45.68333",
    "lng": "0.16667"
  },
  {
    "country": "FR",
    "name": "Legé",
    "lat": "46.88484",
    "lng": "-1.60127"
  },
  {
    "country": "FR",
    "name": "Le Gâvre",
    "lat": "47.52131",
    "lng": "-1.74905"
  },
  {
    "country": "FR",
    "name": "Le Garric",
    "lat": "44.00932",
    "lng": "2.16431"
  },
  {
    "country": "FR",
    "name": "Le Fuilet",
    "lat": "47.28345",
    "lng": "-1.1131"
  },
  {
    "country": "FR",
    "name": "Le Fousseret",
    "lat": "43.28205",
    "lng": "1.06624"
  },
  {
    "country": "FR",
    "name": "Leforest",
    "lat": "50.43866",
    "lng": "3.0648"
  },
  {
    "country": "FR",
    "name": "Le Folgoët",
    "lat": "48.56359",
    "lng": "-4.33641"
  },
  {
    "country": "FR",
    "name": "Le Fœil",
    "lat": "48.43333",
    "lng": "-2.91667"
  },
  {
    "country": "FR",
    "name": "Le Fleix",
    "lat": "44.86667",
    "lng": "0.25"
  },
  {
    "country": "FR",
    "name": "Le Fief-Sauvin",
    "lat": "47.22143",
    "lng": "-1.04214"
  },
  {
    "country": "FR",
    "name": "Leffrinckoucke",
    "lat": "51.03457",
    "lng": "2.46452"
  },
  {
    "country": "FR",
    "name": "Le Fenouiller",
    "lat": "46.71901",
    "lng": "-1.90175"
  },
  {
    "country": "FR",
    "name": "Le Fauga",
    "lat": "43.39619",
    "lng": "1.29571"
  },
  {
    "country": "FR",
    "name": "Le Faouët",
    "lat": "48.03299",
    "lng": "-3.49048"
  },
  {
    "country": "FR",
    "name": "Le Faou",
    "lat": "48.29456",
    "lng": "-4.17927"
  },
  {
    "country": "FR",
    "name": "Leers",
    "lat": "50.68217",
    "lng": "3.24429"
  },
  {
    "country": "FR",
    "name": "Le Drennec",
    "lat": "48.53475",
    "lng": "-4.37008"
  },
  {
    "country": "FR",
    "name": "Le Doulieu",
    "lat": "50.68194",
    "lng": "2.71741"
  },
  {
    "country": "FR",
    "name": "Le Dorat",
    "lat": "46.21514",
    "lng": "1.08153"
  },
  {
    "country": "FR",
    "name": "Le Donjon",
    "lat": "46.35062",
    "lng": "3.79506"
  },
  {
    "country": "FR",
    "name": "Lédignan",
    "lat": "43.9869",
    "lng": "4.10644"
  },
  {
    "country": "FR",
    "name": "Ledeuix",
    "lat": "43.21667",
    "lng": "-0.61667"
  },
  {
    "country": "FR",
    "name": "Lédenon",
    "lat": "43.91349",
    "lng": "4.51444"
  },
  {
    "country": "FR",
    "name": "Lectoure",
    "lat": "43.93464",
    "lng": "0.62107"
  },
  {
    "country": "FR",
    "name": "Le Crotoy",
    "lat": "50.216",
    "lng": "1.625"
  },
  {
    "country": "FR",
    "name": "Le Croisic",
    "lat": "47.29189",
    "lng": "-2.5138"
  },
  {
    "country": "FR",
    "name": "Le Creusot",
    "lat": "46.80714",
    "lng": "4.41632"
  },
  {
    "country": "FR",
    "name": "Le Crest",
    "lat": "45.68687",
    "lng": "3.12844"
  },
  {
    "country": "FR",
    "name": "Le Crès",
    "lat": "43.64807",
    "lng": "3.93976"
  },
  {
    "country": "FR",
    "name": "Lécousse",
    "lat": "48.36458",
    "lng": "-1.21289"
  },
  {
    "country": "FR",
    "name": "Le Coudray-Montceaux",
    "lat": "48.56376",
    "lng": "2.50013"
  },
  {
    "country": "FR",
    "name": "Le Coudray",
    "lat": "48.42115",
    "lng": "1.50057"
  },
  {
    "country": "FR",
    "name": "Le Coteau",
    "lat": "46.02706",
    "lng": "4.0869"
  },
  {
    "country": "FR",
    "name": "Le Conquet",
    "lat": "48.36053",
    "lng": "-4.77086"
  },
  {
    "country": "FR",
    "name": "Lécluse",
    "lat": "50.27671",
    "lng": "3.04045"
  },
  {
    "country": "FR",
    "name": "Le Cheylas",
    "lat": "45.37369",
    "lng": "5.99376"
  },
  {
    "country": "FR",
    "name": "Le Cheylard",
    "lat": "44.90623",
    "lng": "4.42406"
  },
  {
    "country": "FR",
    "name": "Le Chesnay",
    "lat": "48.8222",
    "lng": "2.12213"
  },
  {
    "country": "FR",
    "name": "Le Châtelet-en-Brie",
    "lat": "48.50695",
    "lng": "2.79163"
  },
  {
    "country": "FR",
    "name": "Le Châtelet",
    "lat": "46.64247",
    "lng": "2.28229"
  },
  {
    "country": "FR",
    "name": "Le Champ-Saint-Père",
    "lat": "46.50773",
    "lng": "-1.34726"
  },
  {
    "country": "FR",
    "name": "Le Champ-près-Froges",
    "lat": "45.28105",
    "lng": "5.93966"
  },
  {
    "country": "FR",
    "name": "Le Chambon-sur-Lignon",
    "lat": "45.06079",
    "lng": "4.30314"
  },
  {
    "country": "FR",
    "name": "Le Chambon-Feugerolles",
    "lat": "45.39689",
    "lng": "4.32592"
  },
  {
    "country": "FR",
    "name": "Le Cendre",
    "lat": "45.72118",
    "lng": "3.18839"
  },
  {
    "country": "FR",
    "name": "Le Cellier",
    "lat": "47.31988",
    "lng": "-1.34584"
  },
  {
    "country": "FR",
    "name": "Lecelles",
    "lat": "50.46779",
    "lng": "3.40096"
  },
  {
    "country": "FR",
    "name": "Le Castellet",
    "lat": "43.20285",
    "lng": "5.77642"
  },
  {
    "country": "FR",
    "name": "Le Cap d'Agde",
    "lat": "43.27796",
    "lng": "3.51357"
  },
  {
    "country": "FR",
    "name": "Le Cannet-des-Maures",
    "lat": "43.39272",
    "lng": "6.34165"
  },
  {
    "country": "FR",
    "name": "Le Cannet",
    "lat": "43.57662",
    "lng": "7.01912"
  },
  {
    "country": "FR",
    "name": "Le Canet",
    "lat": "43.32611",
    "lng": "5.3723"
  },
  {
    "country": "FR",
    "name": "Le Cailar",
    "lat": "43.67923",
    "lng": "4.23576"
  },
  {
    "country": "FR",
    "name": "Le Buisson-de-Cadouin",
    "lat": "44.85",
    "lng": "0.91667"
  },
  {
    "country": "FR",
    "name": "Le Bugue",
    "lat": "44.91847",
    "lng": "0.92714"
  },
  {
    "country": "FR",
    "name": "Le Brusquet",
    "lat": "44.16143",
    "lng": "6.31143"
  },
  {
    "country": "FR",
    "name": "Le Broc",
    "lat": "43.80843",
    "lng": "7.16928"
  },
  {
    "country": "FR",
    "name": "Le Breuil-sur-Couze",
    "lat": "45.46886",
    "lng": "3.26344"
  },
  {
    "country": "FR",
    "name": "Le Breuil",
    "lat": "46.80654",
    "lng": "4.46953"
  },
  {
    "country": "FR",
    "name": "Le Breil-sur-Mérize",
    "lat": "48.00755",
    "lng": "0.47808"
  },
  {
    "country": "FR",
    "name": "Le Bousquet-d’Orb",
    "lat": "43.69242",
    "lng": "3.16746"
  },
  {
    "country": "FR",
    "name": "Le Bouscat",
    "lat": "44.866",
    "lng": "-0.59411"
  },
  {
    "country": "FR",
    "name": "Le Bourgneuf-la-Forêt",
    "lat": "48.16325",
    "lng": "-0.96963"
  },
  {
    "country": "FR",
    "name": "Le Bourget-du-Lac",
    "lat": "45.64756",
    "lng": "5.86085"
  },
  {
    "country": "FR",
    "name": "Le Bourget",
    "lat": "48.93405",
    "lng": "2.43584"
  },
  {
    "country": "FR",
    "name": "Le Bourg-d’Oisans",
    "lat": "45.05485",
    "lng": "6.02984"
  },
  {
    "country": "FR",
    "name": "Le Boupère",
    "lat": "46.79595",
    "lng": "-0.92654"
  },
  {
    "country": "FR",
    "name": "el Voló",
    "lat": "42.52424",
    "lng": "2.83336"
  },
  {
    "country": "FR",
    "name": "Le Bosc-Roger-en-Roumois",
    "lat": "49.28333",
    "lng": "0.93333"
  },
  {
    "country": "FR",
    "name": "Le Bono",
    "lat": "47.64129",
    "lng": "-2.94902"
  },
  {
    "country": "FR",
    "name": "Le Bois-Plage-en-Ré",
    "lat": "46.18659",
    "lng": "-1.39267"
  },
  {
    "country": "FR",
    "name": "Le Blanc-Mesnil",
    "lat": "48.93872",
    "lng": "2.46138"
  },
  {
    "country": "FR",
    "name": "Le Blanc",
    "lat": "46.63333",
    "lng": "1.06667"
  },
  {
    "country": "FR",
    "name": "Le Bignon",
    "lat": "47.09722",
    "lng": "-1.49167"
  },
  {
    "country": "FR",
    "name": "Le Beausset",
    "lat": "43.19853",
    "lng": "5.80155"
  },
  {
    "country": "FR",
    "name": "Le Bar-sur-Loup",
    "lat": "43.7",
    "lng": "6.98333"
  },
  {
    "country": "FR",
    "name": "Le Barp",
    "lat": "44.60833",
    "lng": "-0.76948"
  },
  {
    "country": "FR",
    "name": "Le Barcarès",
    "lat": "42.78773",
    "lng": "3.03656"
  },
  {
    "country": "FR",
    "name": "Lay-Saint-Christophe",
    "lat": "48.74867",
    "lng": "6.19776"
  },
  {
    "country": "FR",
    "name": "Layrac",
    "lat": "44.13449",
    "lng": "0.66176"
  },
  {
    "country": "FR",
    "name": "Laxou",
    "lat": "48.68315",
    "lng": "6.14799"
  },
  {
    "country": "FR",
    "name": "La Wantzenau",
    "lat": "48.65786",
    "lng": "7.83068"
  },
  {
    "country": "FR",
    "name": "La Vraie-Croix",
    "lat": "47.68954",
    "lng": "-2.54274"
  },
  {
    "country": "FR",
    "name": "Lavoux",
    "lat": "46.59566",
    "lng": "0.53012"
  },
  {
    "country": "FR",
    "name": "La Voulte-sur-Rhône",
    "lat": "44.80072",
    "lng": "4.7716"
  },
  {
    "country": "FR",
    "name": "Lavit",
    "lat": "43.95674",
    "lng": "0.9201"
  },
  {
    "country": "FR",
    "name": "La Ville-du-Bois",
    "lat": "48.65521",
    "lng": "2.26833"
  },
  {
    "country": "FR",
    "name": "La Villedieu-du-Clain",
    "lat": "46.45559",
    "lng": "0.36917"
  },
  {
    "country": "FR",
    "name": "Lavilledieu",
    "lat": "44.57456",
    "lng": "4.4547"
  },
  {
    "country": "FR",
    "name": "La Ville-aux-Dames",
    "lat": "47.39551",
    "lng": "0.76837"
  },
  {
    "country": "FR",
    "name": "La Ville-aux-Clercs",
    "lat": "47.91835",
    "lng": "1.08521"
  },
  {
    "country": "FR",
    "name": "La Vespière",
    "lat": "49.01975",
    "lng": "0.4125"
  },
  {
    "country": "FR",
    "name": "Lavérune",
    "lat": "43.58639",
    "lng": "3.80611"
  },
  {
    "country": "FR",
    "name": "La Verrière",
    "lat": "48.752",
    "lng": "1.94649"
  },
  {
    "country": "FR",
    "name": "La Verrie",
    "lat": "46.96131",
    "lng": "-0.99596"
  },
  {
    "country": "FR",
    "name": "La Verpillière",
    "lat": "45.63647",
    "lng": "5.14151"
  },
  {
    "country": "FR",
    "name": "Lavernose-Lacasse",
    "lat": "43.397",
    "lng": "1.26205"
  },
  {
    "country": "FR",
    "name": "Laventie",
    "lat": "50.62818",
    "lng": "2.77076"
  },
  {
    "country": "FR",
    "name": "Lavelanet",
    "lat": "42.93127",
    "lng": "1.84656"
  },
  {
    "country": "FR",
    "name": "Lavaur",
    "lat": "43.69847",
    "lng": "1.81858"
  },
  {
    "country": "FR",
    "name": "La Vaupalière",
    "lat": "49.48789",
    "lng": "0.9963"
  },
  {
    "country": "FR",
    "name": "Lavault-Sainte-Anne",
    "lat": "46.31667",
    "lng": "2.6"
  },
  {
    "country": "FR",
    "name": "La Varenne",
    "lat": "47.31107",
    "lng": "-1.31976"
  },
  {
    "country": "FR",
    "name": "Lavardac",
    "lat": "44.17785",
    "lng": "0.29825"
  },
  {
    "country": "FR",
    "name": "Lavans-lès-Saint-Claude",
    "lat": "46.38484",
    "lng": "5.78172"
  },
  {
    "country": "FR",
    "name": "Laval-Pradel",
    "lat": "44.20665",
    "lng": "4.06591"
  },
  {
    "country": "FR",
    "name": "La Valette-du-Var",
    "lat": "43.13741",
    "lng": "5.98314"
  },
  {
    "country": "FR",
    "name": "Lavalette",
    "lat": "43.18428",
    "lng": "2.26825"
  },
  {
    "country": "FR",
    "name": "La Valentine",
    "lat": "43.29757",
    "lng": "5.48432"
  },
  {
    "country": "FR",
    "name": "Laval",
    "lat": "48.0732",
    "lng": "-0.7634"
  },
  {
    "country": "FR",
    "name": "Lauzerte",
    "lat": "44.25535",
    "lng": "1.13817"
  },
  {
    "country": "FR",
    "name": "Lauwin-Planque",
    "lat": "50.39024",
    "lng": "3.0451"
  },
  {
    "country": "FR",
    "name": "Lautrec",
    "lat": "43.70591",
    "lng": "2.13925"
  },
  {
    "country": "FR",
    "name": "Lauterbourg",
    "lat": "48.97515",
    "lng": "8.17846"
  },
  {
    "country": "FR",
    "name": "Lautenbachzell",
    "lat": "47.94124",
    "lng": "7.14643"
  },
  {
    "country": "FR",
    "name": "Lautenbach",
    "lat": "47.94055",
    "lng": "7.15768"
  },
  {
    "country": "FR",
    "name": "Laussonne",
    "lat": "44.96941",
    "lng": "4.05272"
  },
  {
    "country": "FR",
    "name": "Lauris",
    "lat": "43.74799",
    "lng": "5.31518"
  },
  {
    "country": "FR",
    "name": "Laurens",
    "lat": "43.52238",
    "lng": "3.19714"
  },
  {
    "country": "FR",
    "name": "Laure-Minervois",
    "lat": "43.27106",
    "lng": "2.52031"
  },
  {
    "country": "FR",
    "name": "Launaguet",
    "lat": "43.67818",
    "lng": "1.45603"
  },
  {
    "country": "FR",
    "name": "Launac",
    "lat": "43.74357",
    "lng": "1.18172"
  },
  {
    "country": "FR",
    "name": "Laudun-l'Ardoise",
    "lat": "44.1",
    "lng": "4.66667"
  },
  {
    "country": "FR",
    "name": "La Turbie",
    "lat": "43.74514",
    "lng": "7.40101"
  },
  {
    "country": "FR",
    "name": "La Turballe",
    "lat": "47.34686",
    "lng": "-2.50734"
  },
  {
    "country": "FR",
    "name": "Lattes",
    "lat": "43.56752",
    "lng": "3.9046"
  },
  {
    "country": "FR",
    "name": "La Tronche",
    "lat": "45.20429",
    "lng": "5.73645"
  },
  {
    "country": "FR",
    "name": "La Trinité-sur-Mer",
    "lat": "47.5868",
    "lng": "-3.02994"
  },
  {
    "country": "FR",
    "name": "La Trinité",
    "lat": "43.74149",
    "lng": "7.31353"
  },
  {
    "country": "FR",
    "name": "Latresne",
    "lat": "44.78601",
    "lng": "-0.48994"
  },
  {
    "country": "FR",
    "name": "La Tremblade",
    "lat": "45.76806",
    "lng": "-1.14265"
  },
  {
    "country": "FR",
    "name": "La Tranche-sur-Mer",
    "lat": "46.343",
    "lng": "-1.437"
  },
  {
    "country": "FR",
    "name": "La Tour-sur-Orb",
    "lat": "43.65186",
    "lng": "3.15071"
  },
  {
    "country": "FR",
    "name": "La Tourlandry",
    "lat": "47.14375",
    "lng": "-0.69688"
  },
  {
    "country": "FR",
    "name": "La Tour-en-Jarez",
    "lat": "45.48523",
    "lng": "4.38759"
  },
  {
    "country": "FR",
    "name": "La Tour-du-Pin",
    "lat": "45.56667",
    "lng": "5.45"
  },
  {
    "country": "FR",
    "name": "La Tour-du-Crieu",
    "lat": "43.10471",
    "lng": "1.65275"
  },
  {
    "country": "FR",
    "name": "La Tour-de-Salvagny",
    "lat": "45.81233",
    "lng": "4.71626"
  },
  {
    "country": "FR",
    "name": "Latour-Bas-Elne",
    "lat": "42.60646",
    "lng": "3.00201"
  },
  {
    "country": "FR",
    "name": "La Tour",
    "lat": "46.13448",
    "lng": "6.42933"
  },
  {
    "country": "FR",
    "name": "Latillé",
    "lat": "46.61818",
    "lng": "0.0763"
  },
  {
    "country": "FR",
    "name": "Lathus-Saint-Rémy",
    "lat": "46.33333",
    "lng": "0.96667"
  },
  {
    "country": "FR",
    "name": "La Teste-de-Buch",
    "lat": "44.62875",
    "lng": "-1.14059"
  },
  {
    "country": "FR",
    "name": "La Tessoualle",
    "lat": "47.00476",
    "lng": "-0.85119"
  },
  {
    "country": "FR",
    "name": "La Terrasse",
    "lat": "45.32634",
    "lng": "5.93277"
  },
  {
    "country": "FR",
    "name": "La Tardière",
    "lat": "46.66096",
    "lng": "-0.73143"
  },
  {
    "country": "FR",
    "name": "La Talaudière",
    "lat": "45.48094",
    "lng": "4.43173"
  },
  {
    "country": "FR",
    "name": "La Suze-sur-Sarthe",
    "lat": "47.88753",
    "lng": "0.02519"
  },
  {
    "country": "FR",
    "name": "Lassy",
    "lat": "47.97829",
    "lng": "-1.8719"
  },
  {
    "country": "FR",
    "name": "Lassigny",
    "lat": "49.58828",
    "lng": "2.84289"
  },
  {
    "country": "FR",
    "name": "Lasseube",
    "lat": "43.23333",
    "lng": "-0.48333"
  },
  {
    "country": "FR",
    "name": "Lassay-les-Châteaux",
    "lat": "48.43835",
    "lng": "-0.49758"
  },
  {
    "country": "FR",
    "name": "La Souterraine",
    "lat": "46.23714",
    "lng": "1.48701"
  },
  {
    "country": "FR",
    "name": "La Seyne-sur-Mer",
    "lat": "43.09818",
    "lng": "5.88471"
  },
  {
    "country": "FR",
    "name": "La Sentinelle",
    "lat": "50.35115",
    "lng": "3.48425"
  },
  {
    "country": "FR",
    "name": "La Selle-la-Forge",
    "lat": "48.73295",
    "lng": "-0.54103"
  },
  {
    "country": "FR",
    "name": "La Séguinière",
    "lat": "47.06357",
    "lng": "-0.93857"
  },
  {
    "country": "FR",
    "name": "La Séauve-sur-Semène",
    "lat": "45.29702",
    "lng": "4.25318"
  },
  {
    "country": "FR",
    "name": "La Sauve",
    "lat": "44.76667",
    "lng": "-0.31667"
  },
  {
    "country": "FR",
    "name": "La Saussaye",
    "lat": "49.25936",
    "lng": "0.98094"
  },
  {
    "country": "FR",
    "name": "La Salvetat-Peyralès",
    "lat": "44.2194",
    "lng": "2.20297"
  },
  {
    "country": "FR",
    "name": "La Salvetat-sur-Agout",
    "lat": "43.6",
    "lng": "2.71667"
  },
  {
    "country": "FR",
    "name": "La Salvetat-Saint-Gilles",
    "lat": "43.57622",
    "lng": "1.27192"
  },
  {
    "country": "FR",
    "name": "La Salle-et-Chapelle-Aubry",
    "lat": "47.25013",
    "lng": "-0.97512"
  },
  {
    "country": "FR",
    "name": "Lasalle",
    "lat": "44.0453",
    "lng": "3.85477"
  },
  {
    "country": "FR",
    "name": "Laruscade",
    "lat": "45.11667",
    "lng": "-0.33333"
  },
  {
    "country": "FR",
    "name": "Laruns",
    "lat": "42.98826",
    "lng": "-0.42658"
  },
  {
    "country": "FR",
    "name": "Larringes",
    "lat": "46.36737",
    "lng": "6.57318"
  },
  {
    "country": "FR",
    "name": "Larressore",
    "lat": "43.36792",
    "lng": "-1.43976"
  },
  {
    "country": "FR",
    "name": "La Roquette-sur-Siagne",
    "lat": "43.59948",
    "lng": "6.95705"
  },
  {
    "country": "FR",
    "name": "Laroque-Timbaut",
    "lat": "44.28238",
    "lng": "0.76274"
  },
  {
    "country": "FR",
    "name": "Laroque-d’Olmes",
    "lat": "42.96785",
    "lng": "1.86677"
  },
  {
    "country": "FR",
    "name": "la Roca d'Albera",
    "lat": "42.5213",
    "lng": "2.93374"
  },
  {
    "country": "FR",
    "name": "La Roquebrussanne",
    "lat": "43.33989",
    "lng": "5.97618"
  },
  {
    "country": "FR",
    "name": "Laroquebrou",
    "lat": "44.96728",
    "lng": "2.19393"
  },
  {
    "country": "FR",
    "name": "Laroque",
    "lat": "43.9232",
    "lng": "3.72397"
  },
  {
    "country": "FR",
    "name": "La Romagne",
    "lat": "47.06119",
    "lng": "-1.02"
  },
  {
    "country": "FR",
    "name": "La Roche-Vineuse",
    "lat": "46.34524",
    "lng": "4.72023"
  },
  {
    "country": "FR",
    "name": "La Rochette",
    "lat": "48.50882",
    "lng": "2.66357"
  },
  {
    "country": "FR",
    "name": "La Rochette",
    "lat": "45.46025",
    "lng": "6.12065"
  },
  {
    "country": "FR",
    "name": "La Roche-sur-Yon",
    "lat": "46.66667",
    "lng": "-1.43333"
  },
  {
    "country": "FR",
    "name": "La Roche-sur-Foron",
    "lat": "46.0666",
    "lng": "6.31224"
  },
  {
    "country": "FR",
    "name": "Laroche-Saint-Cydroine",
    "lat": "47.96801",
    "lng": "3.48467"
  },
  {
    "country": "FR",
    "name": "La Roche-Posay",
    "lat": "46.78654",
    "lng": "0.81354"
  },
  {
    "country": "FR",
    "name": "La Roche-Maurice",
    "lat": "48.47455",
    "lng": "-4.20211"
  },
  {
    "country": "FR",
    "name": "La Rochelle",
    "lat": "46.16667",
    "lng": "-1.15"
  },
  {
    "country": "FR",
    "name": "La Rochefoucauld",
    "lat": "45.74048",
    "lng": "0.38564"
  },
  {
    "country": "FR",
    "name": "La Roche-des-Arnauds",
    "lat": "44.56134",
    "lng": "5.95519"
  },
  {
    "country": "FR",
    "name": "La Roche-Derrien",
    "lat": "48.74627",
    "lng": "-3.26142"
  },
  {
    "country": "FR",
    "name": "La Roche-de-Glun",
    "lat": "45.01336",
    "lng": "4.84488"
  },
  {
    "country": "FR",
    "name": "La Roche-Chalais",
    "lat": "45.15",
    "lng": "0.01667"
  },
  {
    "country": "FR",
    "name": "La Roche-Blanche",
    "lat": "45.70064",
    "lng": "3.12648"
  },
  {
    "country": "FR",
    "name": "Larmor-Plage",
    "lat": "47.70646",
    "lng": "-3.38339"
  },
  {
    "country": "FR",
    "name": "Larmor-Baden",
    "lat": "47.58341",
    "lng": "-2.8944"
  },
  {
    "country": "FR",
    "name": "La Rivière-Saint-Sauveur",
    "lat": "49.40821",
    "lng": "0.2703"
  },
  {
    "country": "FR",
    "name": "La Rivière-de-Corps",
    "lat": "48.2884",
    "lng": "4.01947"
  },
  {
    "country": "FR",
    "name": "La Riche",
    "lat": "47.38996",
    "lng": "0.67072"
  },
  {
    "country": "FR",
    "name": "La Richardais",
    "lat": "48.60641",
    "lng": "-2.03639"
  },
  {
    "country": "FR",
    "name": "La Ricamarie",
    "lat": "45.41684",
    "lng": "4.31199"
  },
  {
    "country": "FR",
    "name": "Largentière",
    "lat": "44.53333",
    "lng": "4.3"
  },
  {
    "country": "FR",
    "name": "La Réole",
    "lat": "44.58201",
    "lng": "-0.03691"
  },
  {
    "country": "FR",
    "name": "La Remuée",
    "lat": "49.52773",
    "lng": "0.40283"
  },
  {
    "country": "FR",
    "name": "La Remaudière",
    "lat": "47.23762",
    "lng": "-1.24358"
  },
  {
    "country": "FR",
    "name": "La Regrippière",
    "lat": "47.18167",
    "lng": "-1.1762"
  },
  {
    "country": "FR",
    "name": "Lardy",
    "lat": "48.51847",
    "lng": "2.2736"
  },
  {
    "country": "FR",
    "name": "Larche",
    "lat": "45.12291",
    "lng": "1.41419"
  },
  {
    "country": "FR",
    "name": "Larchamp",
    "lat": "48.36131",
    "lng": "-0.999"
  },
  {
    "country": "FR",
    "name": "Larçay",
    "lat": "47.36649",
    "lng": "0.78145"
  },
  {
    "country": "FR",
    "name": "La Ravoire",
    "lat": "45.55978",
    "lng": "5.96871"
  },
  {
    "country": "FR",
    "name": "Larajasse",
    "lat": "45.61252",
    "lng": "4.50028"
  },
  {
    "country": "FR",
    "name": "Laragne-Montéglin",
    "lat": "44.31667",
    "lng": "5.81667"
  },
  {
    "country": "FR",
    "name": "La Queue-les-Yvelines",
    "lat": "48.8",
    "lng": "1.76667"
  },
  {
    "country": "FR",
    "name": "La Queue-en-Brie",
    "lat": "48.7852",
    "lng": "2.58112"
  },
  {
    "country": "FR",
    "name": "Lapugnoy",
    "lat": "50.51635",
    "lng": "2.5346"
  },
  {
    "country": "FR",
    "name": "Lapte",
    "lat": "45.18562",
    "lng": "4.21705"
  },
  {
    "country": "FR",
    "name": "Lapoutroie",
    "lat": "48.15323",
    "lng": "7.16696"
  },
  {
    "country": "FR",
    "name": "La Pouëze",
    "lat": "47.55357",
    "lng": "-0.80928"
  },
  {
    "country": "FR",
    "name": "La Possonnière",
    "lat": "47.37485",
    "lng": "-0.68539"
  },
  {
    "country": "FR",
    "name": "La Pommeraye",
    "lat": "47.35562",
    "lng": "-0.85892"
  },
  {
    "country": "FR",
    "name": "La Pommeraie-sur-Sèvre",
    "lat": "46.83535",
    "lng": "-0.77785"
  },
  {
    "country": "FR",
    "name": "La Pomme",
    "lat": "43.28987",
    "lng": "5.44153"
  },
  {
    "country": "FR",
    "name": "Laplume",
    "lat": "44.11292",
    "lng": "0.52975"
  },
  {
    "country": "FR",
    "name": "La Planche",
    "lat": "47.01619",
    "lng": "-1.43159"
  },
  {
    "country": "FR",
    "name": "La Plaine-sur-Mer",
    "lat": "47.13619",
    "lng": "-2.19182"
  },
  {
    "country": "FR",
    "name": "Lapeyrouse-Fossat",
    "lat": "43.69973",
    "lng": "1.51049"
  },
  {
    "country": "FR",
    "name": "La Peyratte",
    "lat": "46.67453",
    "lng": "-0.14912"
  },
  {
    "country": "FR",
    "name": "La Penne-sur-Huveaune",
    "lat": "43.28208",
    "lng": "5.51642"
  },
  {
    "country": "FR",
    "name": "La Panouse",
    "lat": "43.25576",
    "lng": "5.42963"
  },
  {
    "country": "FR",
    "name": "Lapalud",
    "lat": "44.30446",
    "lng": "4.68953"
  },
  {
    "country": "FR",
    "name": "Lapalisse",
    "lat": "46.24835",
    "lng": "3.63605"
  },
  {
    "country": "FR",
    "name": "La Pacaudière",
    "lat": "46.17545",
    "lng": "3.87196"
  },
  {
    "country": "FR",
    "name": "Laon",
    "lat": "49.5631",
    "lng": "3.62714"
  },
  {
    "country": "FR",
    "name": "Lanvollon",
    "lat": "48.63117",
    "lng": "-2.98641"
  },
  {
    "country": "FR",
    "name": "Lanvéoc",
    "lat": "48.28799",
    "lng": "-4.46277"
  },
  {
    "country": "FR",
    "name": "Lanvénégen",
    "lat": "47.99811",
    "lng": "-3.54134"
  },
  {
    "country": "FR",
    "name": "Lanvallay",
    "lat": "48.45543",
    "lng": "-2.02803"
  },
  {
    "country": "FR",
    "name": "Lantriac",
    "lat": "45.0005",
    "lng": "4.00444"
  },
  {
    "country": "FR",
    "name": "Lantosque",
    "lat": "43.97406",
    "lng": "7.31166"
  },
  {
    "country": "FR",
    "name": "Lanton",
    "lat": "44.70478",
    "lng": "-1.03562"
  },
  {
    "country": "FR",
    "name": "Lantic",
    "lat": "48.60641",
    "lng": "-2.882"
  },
  {
    "country": "FR",
    "name": "Lanta",
    "lat": "43.56667",
    "lng": "1.66667"
  },
  {
    "country": "FR",
    "name": "Lans-en-Vercors",
    "lat": "45.12793",
    "lng": "5.58572"
  },
  {
    "country": "FR",
    "name": "Lansargues",
    "lat": "43.65157",
    "lng": "4.07495"
  },
  {
    "country": "FR",
    "name": "Lanrodec",
    "lat": "48.51622",
    "lng": "-3.03122"
  },
  {
    "country": "FR",
    "name": "Lanrivoaré",
    "lat": "48.4731",
    "lng": "-4.6387"
  },
  {
    "country": "FR",
    "name": "Lanquetot",
    "lat": "49.58527",
    "lng": "0.52637"
  },
  {
    "country": "FR",
    "name": "Lanouée",
    "lat": "48.00225",
    "lng": "-2.58157"
  },
  {
    "country": "FR",
    "name": "Lanouaille",
    "lat": "45.39517",
    "lng": "1.13968"
  },
  {
    "country": "FR",
    "name": "La Norville",
    "lat": "48.58243",
    "lng": "2.2618"
  },
  {
    "country": "FR",
    "name": "Lanobre",
    "lat": "45.43333",
    "lng": "2.53333"
  },
  {
    "country": "FR",
    "name": "Lannoy",
    "lat": "50.66674",
    "lng": "3.21012"
  },
  {
    "country": "FR",
    "name": "Lannion",
    "lat": "48.73333",
    "lng": "-3.46667"
  },
  {
    "country": "FR",
    "name": "Lannilis",
    "lat": "48.57091",
    "lng": "-4.52233"
  },
  {
    "country": "FR",
    "name": "Lannemezan",
    "lat": "43.12517",
    "lng": "0.38401"
  },
  {
    "country": "FR",
    "name": "Lanmeur",
    "lat": "48.64733",
    "lng": "-3.71645"
  },
  {
    "country": "FR",
    "name": "Lanmeur",
    "lat": "47.83333",
    "lng": "-3.71667"
  },
  {
    "country": "FR",
    "name": "Languidic",
    "lat": "47.83266",
    "lng": "-3.15821"
  },
  {
    "country": "FR",
    "name": "Langueux",
    "lat": "48.495",
    "lng": "-2.7185"
  },
  {
    "country": "FR",
    "name": "Langrune-sur-Mer",
    "lat": "49.32346",
    "lng": "-0.37346"
  },
  {
    "country": "FR",
    "name": "Langres",
    "lat": "47.86667",
    "lng": "5.33333"
  },
  {
    "country": "FR",
    "name": "Langonnet",
    "lat": "48.10511",
    "lng": "-3.49356"
  },
  {
    "country": "FR",
    "name": "Langon",
    "lat": "47.72057",
    "lng": "-1.8501"
  },
  {
    "country": "FR",
    "name": "Langon",
    "lat": "44.55",
    "lng": "-0.25"
  },
  {
    "country": "FR",
    "name": "Langoiran",
    "lat": "44.70869",
    "lng": "-0.39368"
  },
  {
    "country": "FR",
    "name": "Langogne",
    "lat": "44.72726",
    "lng": "3.85539"
  },
  {
    "country": "FR",
    "name": "Langoat",
    "lat": "48.75061",
    "lng": "-3.28121"
  },
  {
    "country": "FR",
    "name": "Langlade",
    "lat": "43.80284",
    "lng": "4.25232"
  },
  {
    "country": "FR",
    "name": "Langeais",
    "lat": "47.32587",
    "lng": "0.40136"
  },
  {
    "country": "FR",
    "name": "Langeac",
    "lat": "45.10331",
    "lng": "3.4932"
  },
  {
    "country": "FR",
    "name": "Laneuveville-devant-Nancy",
    "lat": "48.65628",
    "lng": "6.2317"
  },
  {
    "country": "FR",
    "name": "Lanester",
    "lat": "47.76132",
    "lng": "-3.33965"
  },
  {
    "country": "FR",
    "name": "Landunvez",
    "lat": "48.53466",
    "lng": "-4.72545"
  },
  {
    "country": "FR",
    "name": "Landudec",
    "lat": "47.99983",
    "lng": "-4.33641"
  },
  {
    "country": "FR",
    "name": "Landser",
    "lat": "47.68387",
    "lng": "7.394"
  },
  {
    "country": "FR",
    "name": "Landrévarzec",
    "lat": "48.09177",
    "lng": "-4.06044"
  },
  {
    "country": "FR",
    "name": "Landres",
    "lat": "49.32075",
    "lng": "5.80578"
  },
  {
    "country": "FR",
    "name": "Landrecies",
    "lat": "50.12499",
    "lng": "3.69171"
  },
  {
    "country": "FR",
    "name": "Landivy",
    "lat": "48.47868",
    "lng": "-1.0332"
  },
  {
    "country": "FR",
    "name": "Landivisiau",
    "lat": "48.50784",
    "lng": "-4.06833"
  },
  {
    "country": "FR",
    "name": "Landiras",
    "lat": "44.56702",
    "lng": "-0.41536"
  },
  {
    "country": "FR",
    "name": "Landévant",
    "lat": "47.76499",
    "lng": "-3.12221"
  },
  {
    "country": "FR",
    "name": "Landeronde",
    "lat": "46.65722",
    "lng": "-1.56953"
  },
  {
    "country": "FR",
    "name": "Landerneau",
    "lat": "48.45252",
    "lng": "-4.25252"
  },
  {
    "country": "FR",
    "name": "Landemont",
    "lat": "47.26536",
    "lng": "-1.23989"
  },
  {
    "country": "FR",
    "name": "Landeleau",
    "lat": "48.22734",
    "lng": "-3.7285"
  },
  {
    "country": "FR",
    "name": "Landéhen",
    "lat": "48.43022",
    "lng": "-2.53999"
  },
  {
    "country": "FR",
    "name": "Landéda",
    "lat": "48.58733",
    "lng": "-4.571"
  },
  {
    "country": "FR",
    "name": "Landéan",
    "lat": "48.41253",
    "lng": "-1.15245"
  },
  {
    "country": "FR",
    "name": "Landaul",
    "lat": "47.74785",
    "lng": "-3.07694"
  },
  {
    "country": "FR",
    "name": "Landas",
    "lat": "50.47269",
    "lng": "3.30367"
  },
  {
    "country": "FR",
    "name": "Lancrans",
    "lat": "46.12729",
    "lng": "5.83277"
  },
  {
    "country": "FR",
    "name": "Lançon-Provence",
    "lat": "43.59237",
    "lng": "5.13167"
  },
  {
    "country": "FR",
    "name": "Lancieux",
    "lat": "48.60767",
    "lng": "-2.1503"
  },
  {
    "country": "FR",
    "name": "La Murette",
    "lat": "45.38097",
    "lng": "5.54028"
  },
  {
    "country": "FR",
    "name": "Lamure-sur-Azergues",
    "lat": "46.05967",
    "lng": "4.49112"
  },
  {
    "country": "FR",
    "name": "La Mure",
    "lat": "44.90257",
    "lng": "5.78659"
  },
  {
    "country": "FR",
    "name": "La Mulatière",
    "lat": "45.7259",
    "lng": "4.80712"
  },
  {
    "country": "FR",
    "name": "Lampertheim",
    "lat": "48.65149",
    "lng": "7.69876"
  },
  {
    "country": "FR",
    "name": "Lampaul-Plouarzel",
    "lat": "48.44727",
    "lng": "-4.76045"
  },
  {
    "country": "FR",
    "name": "Lampaul-Guimiliau",
    "lat": "48.49156",
    "lng": "-4.04144"
  },
  {
    "country": "FR",
    "name": "La Motte-Servolex",
    "lat": "45.59416",
    "lng": "5.87575"
  },
  {
    "country": "FR",
    "name": "La Motte-Saint-Martin",
    "lat": "44.95131",
    "lng": "5.71814"
  },
  {
    "country": "FR",
    "name": "La Motte-Saint-Jean",
    "lat": "46.49594",
    "lng": "3.96396"
  },
  {
    "country": "FR",
    "name": "La Motte-d’Aveillans",
    "lat": "44.96015",
    "lng": "5.74409"
  },
  {
    "country": "FR",
    "name": "Lamotte-Beuvron",
    "lat": "47.602",
    "lng": "2.02837"
  },
  {
    "country": "FR",
    "name": "La Motte",
    "lat": "48.23381",
    "lng": "-2.73271"
  },
  {
    "country": "FR",
    "name": "La Motte",
    "lat": "43.49142",
    "lng": "6.53689"
  },
  {
    "country": "FR",
    "name": "La Mothe-Saint-Héray",
    "lat": "46.35934",
    "lng": "-0.11236"
  },
  {
    "country": "FR",
    "name": "Lamothe-Montravel",
    "lat": "44.85",
    "lng": "0.03333"
  },
  {
    "country": "FR",
    "name": "La Mothe-Achard",
    "lat": "46.61586",
    "lng": "-1.65938"
  },
  {
    "country": "FR",
    "name": "Lamorlaye",
    "lat": "49.16246",
    "lng": "2.44687"
  },
  {
    "country": "FR",
    "name": "Lamonzie-Saint-Martin",
    "lat": "44.84713",
    "lng": "0.39102"
  },
  {
    "country": "FR",
    "name": "La Montagne",
    "lat": "47.18651",
    "lng": "-1.68272"
  },
  {
    "country": "FR",
    "name": "La Monnerie-le-Montel",
    "lat": "45.86667",
    "lng": "3.6"
  },
  {
    "country": "FR",
    "name": "La Millère",
    "lat": "43.28128",
    "lng": "5.49804"
  },
  {
    "country": "FR",
    "name": "La Milesse",
    "lat": "48.06314",
    "lng": "0.13428"
  },
  {
    "country": "FR",
    "name": "La Mézière",
    "lat": "48.21829",
    "lng": "-1.75514"
  },
  {
    "country": "FR",
    "name": "La Ménitré",
    "lat": "47.4",
    "lng": "-0.26667"
  },
  {
    "country": "FR",
    "name": "La Membrolle-sur-Longuenée",
    "lat": "47.55991",
    "lng": "-0.67236"
  },
  {
    "country": "FR",
    "name": "La Membrolle-sur-Choisille",
    "lat": "47.43719",
    "lng": "0.63163"
  },
  {
    "country": "FR",
    "name": "La Meilleraye-de-Bretagne",
    "lat": "47.55941",
    "lng": "-1.402"
  },
  {
    "country": "FR",
    "name": "La Meilleraie-Tillay",
    "lat": "46.74059",
    "lng": "-0.845"
  },
  {
    "country": "FR",
    "name": "La Meignanne",
    "lat": "47.517",
    "lng": "-0.66861"
  },
  {
    "country": "FR",
    "name": "La Méaugon",
    "lat": "48.49933",
    "lng": "-2.8385"
  },
  {
    "country": "FR",
    "name": "La Meauffe",
    "lat": "49.17643",
    "lng": "-1.11119"
  },
  {
    "country": "FR",
    "name": "Lambres-lez-Douai",
    "lat": "50.35",
    "lng": "3.06667"
  },
  {
    "country": "FR",
    "name": "Lambesc",
    "lat": "43.65311",
    "lng": "5.26282"
  },
  {
    "country": "FR",
    "name": "Lambersart",
    "lat": "50.65",
    "lng": "3.03333"
  },
  {
    "country": "FR",
    "name": "Lamballe",
    "lat": "48.46762",
    "lng": "-2.51436"
  },
  {
    "country": "FR",
    "name": "Lamastre",
    "lat": "44.98672",
    "lng": "4.57975"
  },
  {
    "country": "FR",
    "name": "Lamarque",
    "lat": "45.09536",
    "lng": "-0.71892"
  },
  {
    "country": "FR",
    "name": "Lamarche-sur-Saône",
    "lat": "47.26946",
    "lng": "5.38589"
  },
  {
    "country": "FR",
    "name": "Lamarche",
    "lat": "48.06967",
    "lng": "5.78141"
  },
  {
    "country": "FR",
    "name": "Lamanon",
    "lat": "43.7006",
    "lng": "5.08857"
  },
  {
    "country": "FR",
    "name": "Lamalou-les-Bains",
    "lat": "43.59786",
    "lng": "3.08052"
  },
  {
    "country": "FR",
    "name": "La Mailleraye-sur-Seine",
    "lat": "49.48308",
    "lng": "0.7703"
  },
  {
    "country": "FR",
    "name": "Lamagistère",
    "lat": "44.12488",
    "lng": "0.82486"
  },
  {
    "country": "FR",
    "name": "La Madeleine-de-Nonancourt",
    "lat": "48.77298",
    "lng": "1.20253"
  },
  {
    "country": "FR",
    "name": "La Madeleine",
    "lat": "50.64603",
    "lng": "3.07585"
  },
  {
    "country": "FR",
    "name": "La Machine",
    "lat": "46.89226",
    "lng": "3.46426"
  },
  {
    "country": "FR",
    "name": "La Loupe",
    "lat": "48.4732",
    "lng": "1.01585"
  },
  {
    "country": "FR",
    "name": "La Loubière",
    "lat": "44.37143",
    "lng": "2.66825"
  },
  {
    "country": "FR",
    "name": "Laloubère",
    "lat": "43.2043",
    "lng": "0.07296"
  },
  {
    "country": "FR",
    "name": "La Longueville",
    "lat": "50.28939",
    "lng": "3.85672"
  },
  {
    "country": "FR",
    "name": "La Londe-les-Maures",
    "lat": "43.13714",
    "lng": "6.23499"
  },
  {
    "country": "FR",
    "name": "Lallaing",
    "lat": "50.39012",
    "lng": "3.16949"
  },
  {
    "country": "FR",
    "name": "Lalinde",
    "lat": "44.83621",
    "lng": "0.73075"
  },
  {
    "country": "FR",
    "name": "La Limouzinière",
    "lat": "46.99274",
    "lng": "-1.59722"
  },
  {
    "country": "FR",
    "name": "Lalevade-d’Ardèche",
    "lat": "44.64834",
    "lng": "4.32418"
  },
  {
    "country": "FR",
    "name": "Lalbenque",
    "lat": "44.33929",
    "lng": "1.54501"
  },
  {
    "country": "FR",
    "name": "La Lande-Patry",
    "lat": "48.76202",
    "lng": "-0.59876"
  },
  {
    "country": "FR",
    "name": "La Lande-de-Fronsac",
    "lat": "44.98036",
    "lng": "-0.38048"
  },
  {
    "country": "FR",
    "name": "La Jumellière",
    "lat": "47.27976",
    "lng": "-0.72952"
  },
  {
    "country": "FR",
    "name": "La Jubaudière",
    "lat": "47.17202",
    "lng": "-0.89215"
  },
  {
    "country": "FR",
    "name": "La Jarrie",
    "lat": "46.12879",
    "lng": "-1.00896"
  },
  {
    "country": "FR",
    "name": "La Jarne",
    "lat": "46.12773",
    "lng": "-1.07259"
  },
  {
    "country": "FR",
    "name": "Laiz",
    "lat": "46.24758",
    "lng": "4.89203"
  },
  {
    "country": "FR",
    "name": "Laissac",
    "lat": "44.38085",
    "lng": "2.82154"
  },
  {
    "country": "FR",
    "name": "Lailly-en-Val",
    "lat": "47.76962",
    "lng": "1.68657"
  },
  {
    "country": "FR",
    "name": "Laillé",
    "lat": "47.97848",
    "lng": "-1.71676"
  },
  {
    "country": "FR",
    "name": "Laigneville",
    "lat": "49.29149",
    "lng": "2.44581"
  },
  {
    "country": "FR",
    "name": "Laigné-en-Belin",
    "lat": "47.87706",
    "lng": "0.22795"
  },
  {
    "country": "FR",
    "name": "La Houssaye-en-Brie",
    "lat": "48.75381",
    "lng": "2.86552"
  },
  {
    "country": "FR",
    "name": "Lahonce",
    "lat": "43.48248",
    "lng": "-1.39101"
  },
  {
    "country": "FR",
    "name": "La Haye-Pesnel",
    "lat": "48.79561",
    "lng": "-1.39655"
  },
  {
    "country": "FR",
    "name": "La Haye-Malherbe",
    "lat": "49.22553",
    "lng": "1.06774"
  },
  {
    "country": "FR",
    "name": "La Haye-du-Puits",
    "lat": "49.28973",
    "lng": "-1.54324"
  },
  {
    "country": "FR",
    "name": "Descartes",
    "lat": "46.96667",
    "lng": "0.7"
  },
  {
    "country": "FR",
    "name": "La Haie-Fouassière",
    "lat": "47.15492",
    "lng": "-1.39794"
  },
  {
    "country": "FR",
    "name": "La Guyonnière",
    "lat": "46.96476",
    "lng": "-1.25059"
  },
  {
    "country": "FR",
    "name": "Laguiole",
    "lat": "44.68465",
    "lng": "2.84666"
  },
  {
    "country": "FR",
    "name": "La Guérinière",
    "lat": "46.96667",
    "lng": "-2.23333"
  },
  {
    "country": "FR",
    "name": "La Guerche-de-Bretagne",
    "lat": "47.94112",
    "lng": "-1.22869"
  },
  {
    "country": "FR",
    "name": "Laguenne",
    "lat": "45.24257",
    "lng": "1.78096"
  },
  {
    "country": "FR",
    "name": "La Grigonnais",
    "lat": "47.52724",
    "lng": "-1.66781"
  },
  {
    "country": "FR",
    "name": "Lagrave",
    "lat": "43.89734",
    "lng": "1.99268"
  },
  {
    "country": "FR",
    "name": "La Grande-Paroisse",
    "lat": "48.38682",
    "lng": "2.90157"
  },
  {
    "country": "FR",
    "name": "La Grande-Motte",
    "lat": "43.56667",
    "lng": "4.08333"
  },
  {
    "country": "FR",
    "name": "La Grand-Croix",
    "lat": "45.5",
    "lng": "4.55"
  },
  {
    "country": "FR",
    "name": "La Gouesnière",
    "lat": "48.60467",
    "lng": "-1.894"
  },
  {
    "country": "FR",
    "name": "La Gorgue",
    "lat": "50.6379",
    "lng": "2.71502"
  },
  {
    "country": "FR",
    "name": "Lagord",
    "lat": "46.18822",
    "lng": "-1.15355"
  },
  {
    "country": "FR",
    "name": "Lagorce",
    "lat": "45.06667",
    "lng": "-0.13333"
  },
  {
    "country": "FR",
    "name": "Lagor",
    "lat": "43.38333",
    "lng": "-0.65"
  },
  {
    "country": "FR",
    "name": "Lagny-le-Sec",
    "lat": "49.08744",
    "lng": "2.74502"
  },
  {
    "country": "FR",
    "name": "Lagny-sur-Marne",
    "lat": "48.86667",
    "lng": "2.71667"
  },
  {
    "country": "FR",
    "name": "Lagnieu",
    "lat": "45.90038",
    "lng": "5.3466"
  },
  {
    "country": "FR",
    "name": "Lagnes",
    "lat": "43.89325",
    "lng": "5.11346"
  },
  {
    "country": "FR",
    "name": "La Glacerie",
    "lat": "49.60517",
    "lng": "-1.58185"
  },
  {
    "country": "FR",
    "name": "La Génétouze",
    "lat": "46.73333",
    "lng": "-1.51667"
  },
  {
    "country": "FR",
    "name": "La Gaude",
    "lat": "43.72235",
    "lng": "7.15083"
  },
  {
    "country": "FR",
    "name": "La Gaubretière",
    "lat": "46.94143",
    "lng": "-1.06215"
  },
  {
    "country": "FR",
    "name": "Lagarrigue",
    "lat": "43.57765",
    "lng": "2.27784"
  },
  {
    "country": "FR",
    "name": "La Garnache",
    "lat": "46.89176",
    "lng": "-1.83163"
  },
  {
    "country": "FR",
    "name": "La Garenne-Colombes",
    "lat": "48.90472",
    "lng": "2.2469"
  },
  {
    "country": "FR",
    "name": "Lagardelle-sur-Lèze",
    "lat": "43.41143",
    "lng": "1.3892"
  },
  {
    "country": "FR",
    "name": "La Garde-Freinet",
    "lat": "43.31709",
    "lng": "6.46881"
  },
  {
    "country": "FR",
    "name": "La Garde-Adhémar",
    "lat": "44.39553",
    "lng": "4.75776"
  },
  {
    "country": "FR",
    "name": "La Garde",
    "lat": "43.12277",
    "lng": "6.00745"
  },
  {
    "country": "FR",
    "name": "La Gacilly",
    "lat": "47.76562",
    "lng": "-2.1322"
  },
  {
    "country": "FR",
    "name": "La Frette-sur-Seine",
    "lat": "48.98057",
    "lng": "2.17866"
  },
  {
    "country": "FR",
    "name": "La Fresnais",
    "lat": "48.59478",
    "lng": "-1.84186"
  },
  {
    "country": "FR",
    "name": "La Francheville",
    "lat": "49.72923",
    "lng": "4.71273"
  },
  {
    "country": "FR",
    "name": "Lafrançaise",
    "lat": "44.12791",
    "lng": "1.24141"
  },
  {
    "country": "FR",
    "name": "La Fouillouse",
    "lat": "45.502",
    "lng": "4.31213"
  },
  {
    "country": "FR",
    "name": "La Fouillade",
    "lat": "44.23072",
    "lng": "2.03989"
  },
  {
    "country": "FR",
    "name": "La Forêt-sur-Sèvre",
    "lat": "46.76905",
    "lng": "-0.64964"
  },
  {
    "country": "FR",
    "name": "La Forêt-Fouesnant",
    "lat": "47.9101",
    "lng": "-3.97858"
  },
  {
    "country": "FR",
    "name": "La Forest-Landerneau",
    "lat": "48.42589",
    "lng": "-4.31578"
  },
  {
    "country": "FR",
    "name": "La Force",
    "lat": "44.86902",
    "lng": "0.37541"
  },
  {
    "country": "FR",
    "name": "La Flotte",
    "lat": "46.18771",
    "lng": "-1.32815"
  },
  {
    "country": "FR",
    "name": "La Flocellière",
    "lat": "46.83202",
    "lng": "-0.86215"
  },
  {
    "country": "FR",
    "name": "La Flèche",
    "lat": "47.69815",
    "lng": "-0.07553"
  },
  {
    "country": "FR",
    "name": "La Flamengrie",
    "lat": "50.00175",
    "lng": "3.92081"
  },
  {
    "country": "FR",
    "name": "La Feuillie",
    "lat": "49.46415",
    "lng": "1.51463"
  },
  {
    "country": "FR",
    "name": "La Ferté-sous-Jouarre",
    "lat": "48.9514",
    "lng": "3.12724"
  },
  {
    "country": "FR",
    "name": "La Ferté-Saint-Aubin",
    "lat": "47.71695",
    "lng": "1.93904"
  },
  {
    "country": "FR",
    "name": "La Ferté-Milon",
    "lat": "49.17453",
    "lng": "3.12885"
  },
  {
    "country": "FR",
    "name": "La Ferté-Macé",
    "lat": "48.58999",
    "lng": "-0.358"
  },
  {
    "country": "FR",
    "name": "La Ferté-Imbault",
    "lat": "47.38467",
    "lng": "1.95344"
  },
  {
    "country": "FR",
    "name": "La Ferté-Gaucher",
    "lat": "48.7831",
    "lng": "3.30678"
  },
  {
    "country": "FR",
    "name": "La Ferté-Bernard",
    "lat": "48.18633",
    "lng": "0.65357"
  },
  {
    "country": "FR",
    "name": "La Ferté-Alais",
    "lat": "48.48306",
    "lng": "2.34802"
  },
  {
    "country": "FR",
    "name": "La Ferrière-aux-Étangs",
    "lat": "48.66227",
    "lng": "-0.51955"
  },
  {
    "country": "FR",
    "name": "La Ferrière",
    "lat": "46.71453",
    "lng": "-1.31417"
  },
  {
    "country": "FR",
    "name": "La Fère",
    "lat": "49.66286",
    "lng": "3.36631"
  },
  {
    "country": "FR",
    "name": "La Farlède",
    "lat": "43.1677",
    "lng": "6.04266"
  },
  {
    "country": "FR",
    "name": "La Fare-les-Oliviers",
    "lat": "43.55104",
    "lng": "5.1943"
  },
  {
    "country": "FR",
    "name": "Ladon",
    "lat": "48.00259",
    "lng": "2.53724"
  },
  {
    "country": "FR",
    "name": "La Dominelais",
    "lat": "47.76229",
    "lng": "-1.68819"
  },
  {
    "country": "FR",
    "name": "Ladignac-le-Long",
    "lat": "45.58256",
    "lng": "1.11359"
  },
  {
    "country": "FR",
    "name": "La Destrousse",
    "lat": "43.37505",
    "lng": "5.6056"
  },
  {
    "country": "FR",
    "name": "La Daguenière",
    "lat": "47.41934",
    "lng": "-0.43128"
  },
  {
    "country": "FR",
    "name": "Lacrouzette",
    "lat": "43.6603",
    "lng": "2.34838"
  },
  {
    "country": "FR",
    "name": "La Croix-Valmer",
    "lat": "43.20795",
    "lng": "6.56696"
  },
  {
    "country": "FR",
    "name": "Lacroix-Saint-Ouen",
    "lat": "49.35685",
    "lng": "2.78803"
  },
  {
    "country": "FR",
    "name": "La Croix-Rouge",
    "lat": "43.33329",
    "lng": "5.45403"
  },
  {
    "country": "FR",
    "name": "Lacroix-Falgarde",
    "lat": "43.49968",
    "lng": "1.40985"
  },
  {
    "country": "FR",
    "name": "La Croix-en-Touraine",
    "lat": "47.34031",
    "lng": "0.99024"
  },
  {
    "country": "FR",
    "name": "La Crau",
    "lat": "43.14981",
    "lng": "6.07425"
  },
  {
    "country": "FR",
    "name": "La Couture-Boussey",
    "lat": "48.89581",
    "lng": "1.40491"
  },
  {
    "country": "FR",
    "name": "La Couture",
    "lat": "50.58212",
    "lng": "2.7071"
  },
  {
    "country": "FR",
    "name": "La Courtine",
    "lat": "45.7",
    "lng": "2.26667"
  },
  {
    "country": "FR",
    "name": "La Couronne",
    "lat": "45.61128",
    "lng": "0.09948"
  },
  {
    "country": "FR",
    "name": "La Courneuve",
    "lat": "48.92805",
    "lng": "2.39627"
  },
  {
    "country": "FR",
    "name": "La Couarde-sur-Mer",
    "lat": "46.19411",
    "lng": "-1.42522"
  },
  {
    "country": "FR",
    "name": "La Côte-Saint-André",
    "lat": "45.39357",
    "lng": "5.26055"
  },
  {
    "country": "FR",
    "name": "La Coquille",
    "lat": "45.54201",
    "lng": "0.97675"
  },
  {
    "country": "FR",
    "name": "La Colle-sur-Loup",
    "lat": "43.6875",
    "lng": "7.10268"
  },
  {
    "country": "FR",
    "name": "La Cluse-et-Mijoux",
    "lat": "46.88333",
    "lng": "6.38333"
  },
  {
    "country": "FR",
    "name": "La Clusaz",
    "lat": "45.9052",
    "lng": "6.42376"
  },
  {
    "country": "FR",
    "name": "La Clayette",
    "lat": "46.29002",
    "lng": "4.30422"
  },
  {
    "country": "FR",
    "name": "La Ciotat",
    "lat": "43.17476",
    "lng": "5.60449"
  },
  {
    "country": "FR",
    "name": "La Chevrolière",
    "lat": "47.09124",
    "lng": "-1.60973"
  },
  {
    "country": "FR",
    "name": "La Chaussée-Saint-Victor",
    "lat": "47.61621",
    "lng": "1.36765"
  },
  {
    "country": "FR",
    "name": "La Châtre",
    "lat": "46.58333",
    "lng": "1.98333"
  },
  {
    "country": "FR",
    "name": "La Châtaigneraie",
    "lat": "46.64786",
    "lng": "-0.73916"
  },
  {
    "country": "FR",
    "name": "La Chartre-sur-le-Loir",
    "lat": "47.73117",
    "lng": "0.56852"
  },
  {
    "country": "FR",
    "name": "La Charité-sur-Loire",
    "lat": "47.18333",
    "lng": "3.01667"
  },
  {
    "country": "FR",
    "name": "La Chapelle-Thouarault",
    "lat": "48.12486",
    "lng": "-1.86619"
  },
  {
    "country": "FR",
    "name": "La Chapelle-sur-Loire",
    "lat": "47.25063",
    "lng": "0.21887"
  },
  {
    "country": "FR",
    "name": "La Chapelle-sur-Erdre",
    "lat": "47.29583",
    "lng": "-1.55309"
  },
  {
    "country": "FR",
    "name": "La Chapelle-sur-Crécy",
    "lat": "48.85879",
    "lng": "2.92597"
  },
  {
    "country": "FR",
    "name": "Lachapelle-sous-Aubenas",
    "lat": "44.56417",
    "lng": "4.36392"
  },
  {
    "country": "FR",
    "name": "La Chapelle-Saint-Ursin",
    "lat": "47.06248",
    "lng": "2.32447"
  },
  {
    "country": "FR",
    "name": "La Chapelle-Saint-Mesmin",
    "lat": "47.88648",
    "lng": "1.8345"
  },
  {
    "country": "FR",
    "name": "La Chapelle-Saint-Luc",
    "lat": "48.31734",
    "lng": "4.03988"
  },
  {
    "country": "FR",
    "name": "La Chapelle-Saint-Laurent",
    "lat": "46.74643",
    "lng": "-0.47643"
  },
  {
    "country": "FR",
    "name": "La Chapelle-Saint-Florent",
    "lat": "47.33393",
    "lng": "-1.05631"
  },
  {
    "country": "FR",
    "name": "La Chapelle-Saint-Aubin",
    "lat": "48.03595",
    "lng": "0.15624"
  },
  {
    "country": "FR",
    "name": "La Chapelle-Réanville",
    "lat": "49.09752",
    "lng": "1.38209"
  },
  {
    "country": "FR",
    "name": "La Chapelle-Launay",
    "lat": "47.37226",
    "lng": "-1.97071"
  },
  {
    "country": "FR",
    "name": "La Chapelle-la-Reine",
    "lat": "48.31813",
    "lng": "2.57152"
  },
  {
    "country": "FR",
    "name": "La Chapelle-Janson",
    "lat": "48.34775",
    "lng": "-1.10209"
  },
  {
    "country": "FR",
    "name": "La Chapelle-Heulin",
    "lat": "47.17667",
    "lng": "-1.34"
  },
  {
    "country": "FR",
    "name": "La Chapelle-Gauthier",
    "lat": "48.54947",
    "lng": "2.89776"
  },
  {
    "country": "FR",
    "name": "La Chapelle-en-Serval",
    "lat": "49.12842",
    "lng": "2.53405"
  },
  {
    "country": "FR",
    "name": "La Chapelle-du-Noyer",
    "lat": "48.03191",
    "lng": "1.30953"
  },
  {
    "country": "FR",
    "name": "La Chapelle-du-Genêt",
    "lat": "47.18203",
    "lng": "-1.01857"
  },
  {
    "country": "FR",
    "name": "La Chapelle-des-Marais",
    "lat": "47.44845",
    "lng": "-2.23834"
  },
  {
    "country": "FR",
    "name": "La Chapelle-des-Fougeretz",
    "lat": "48.17705",
    "lng": "-1.73143"
  },
  {
    "country": "FR",
    "name": "La Chapelle-de-la-Tour",
    "lat": "45.58422",
    "lng": "5.46611"
  },
  {
    "country": "FR",
    "name": "La Chapelle-de-Guinchay",
    "lat": "46.20841",
    "lng": "4.76245"
  },
  {
    "country": "FR",
    "name": "La Chapelle-Basse-Mer",
    "lat": "47.27086",
    "lng": "-1.33913"
  },
  {
    "country": "FR",
    "name": "Lachapelle-aux-Pots",
    "lat": "49.44905",
    "lng": "1.90228"
  },
  {
    "country": "FR",
    "name": "La Chapelle-Achard",
    "lat": "46.58862",
    "lng": "-1.64757"
  },
  {
    "country": "FR",
    "name": "La Chambre",
    "lat": "45.35866",
    "lng": "6.30249"
  },
  {
    "country": "FR",
    "name": "La Chaize-le-Vicomte",
    "lat": "46.67166",
    "lng": "-1.29084"
  },
  {
    "country": "FR",
    "name": "La Cerlangue",
    "lat": "49.50592",
    "lng": "0.41332"
  },
  {
    "country": "FR",
    "name": "La Celle-sur-Morin",
    "lat": "48.81146",
    "lng": "2.96921"
  },
  {
    "country": "FR",
    "name": "La Celle-Saint-Cloud",
    "lat": "48.85029",
    "lng": "2.14523"
  },
  {
    "country": "FR",
    "name": "La Celle-Saint-Avant",
    "lat": "47.022",
    "lng": "0.60488"
  },
  {
    "country": "FR",
    "name": "La Celle",
    "lat": "43.39391",
    "lng": "6.03484"
  },
  {
    "country": "FR",
    "name": "La Cavalerie",
    "lat": "44.00961",
    "lng": "3.1584"
  },
  {
    "country": "FR",
    "name": "Lacaune",
    "lat": "43.7066",
    "lng": "2.69293"
  },
  {
    "country": "FR",
    "name": "Lacasse",
    "lat": "43.39873",
    "lng": "1.26951"
  },
  {
    "country": "FR",
    "name": "Lacapelle-Marival",
    "lat": "44.72773",
    "lng": "1.92465"
  },
  {
    "country": "FR",
    "name": "La Capelle-lès-Boulogne",
    "lat": "50.73302",
    "lng": "1.70147"
  },
  {
    "country": "FR",
    "name": "La Capelle",
    "lat": "49.96667",
    "lng": "3.91667"
  },
  {
    "country": "FR",
    "name": "La Canourgue",
    "lat": "44.43133",
    "lng": "3.21584"
  },
  {
    "country": "FR",
    "name": "Lacanau",
    "lat": "44.97779",
    "lng": "-1.07621"
  },
  {
    "country": "FR",
    "name": "La Calmette",
    "lat": "43.92283",
    "lng": "4.26617"
  },
  {
    "country": "FR",
    "name": "La Buisse",
    "lat": "45.3354",
    "lng": "5.62282"
  },
  {
    "country": "FR",
    "name": "Labry",
    "lat": "49.17126",
    "lng": "5.88003"
  },
  {
    "country": "FR",
    "name": "Labruguière",
    "lat": "43.53858",
    "lng": "2.26392"
  },
  {
    "country": "FR",
    "name": "La Bruffière",
    "lat": "47.01492",
    "lng": "-1.1973"
  },
  {
    "country": "FR",
    "name": "La Broque",
    "lat": "48.47298",
    "lng": "7.21639"
  },
  {
    "country": "FR",
    "name": "La Bridoire",
    "lat": "45.52504",
    "lng": "5.74073"
  },
  {
    "country": "FR",
    "name": "La Bresse",
    "lat": "47.99974",
    "lng": "6.86499"
  },
  {
    "country": "FR",
    "name": "La Boussac",
    "lat": "48.5126",
    "lng": "-1.66088"
  },
  {
    "country": "FR",
    "name": "Labourse",
    "lat": "50.49883",
    "lng": "2.68121"
  },
  {
    "country": "FR",
    "name": "La Bourboule",
    "lat": "45.58837",
    "lng": "2.73956"
  },
  {
    "country": "FR",
    "name": "La Bouilladisse",
    "lat": "43.39619",
    "lng": "5.59307"
  },
  {
    "country": "FR",
    "name": "Labouheyre",
    "lat": "44.21297",
    "lng": "-0.92062"
  },
  {
    "country": "FR",
    "name": "La Bouëxière",
    "lat": "48.18333",
    "lng": "-1.43333"
  },
  {
    "country": "FR",
    "name": "La Bonneville-sur-Iton",
    "lat": "49",
    "lng": "1.03333"
  },
  {
    "country": "FR",
    "name": "Laboissière-en-Thelle",
    "lat": "49.29329",
    "lng": "2.1615"
  },
  {
    "country": "FR",
    "name": "La Boissière-des-Landes",
    "lat": "46.56398",
    "lng": "-1.46172"
  },
  {
    "country": "FR",
    "name": "La Boissière-de-Montaigu",
    "lat": "46.95012",
    "lng": "-1.19047"
  },
  {
    "country": "FR",
    "name": "La Boisse",
    "lat": "45.84278",
    "lng": "5.03639"
  },
  {
    "country": "FR",
    "name": "La Bohalle",
    "lat": "47.42095",
    "lng": "-0.39723"
  },
  {
    "country": "FR",
    "name": "Lablachère",
    "lat": "44.46595",
    "lng": "4.2165"
  },
  {
    "country": "FR",
    "name": "La Biolle",
    "lat": "45.75916",
    "lng": "5.9307"
  },
  {
    "country": "FR",
    "name": "Labeuvrière",
    "lat": "50.51915",
    "lng": "2.56268"
  },
  {
    "country": "FR",
    "name": "La Bernerie-en-Retz",
    "lat": "47.0804",
    "lng": "-2.03642"
  },
  {
    "country": "FR",
    "name": "La Bernardière",
    "lat": "47.04952",
    "lng": "-1.26587"
  },
  {
    "country": "FR",
    "name": "Labenne",
    "lat": "43.59464",
    "lng": "-1.42559"
  },
  {
    "country": "FR",
    "name": "La Bégude-de-Mazenc",
    "lat": "44.54573",
    "lng": "4.93608"
  },
  {
    "country": "FR",
    "name": "Labégude",
    "lat": "44.64657",
    "lng": "4.369"
  },
  {
    "country": "FR",
    "name": "Labège",
    "lat": "43.53039",
    "lng": "1.53596"
  },
  {
    "country": "FR",
    "name": "La Bazoge",
    "lat": "48.09689",
    "lng": "0.15534"
  },
  {
    "country": "FR",
    "name": "La Bazoche-Gouet",
    "lat": "48.13985",
    "lng": "0.98163"
  },
  {
    "country": "FR",
    "name": "Labatut",
    "lat": "43.55",
    "lng": "-0.98333"
  },
  {
    "country": "FR",
    "name": "La Bâtie-Neuve",
    "lat": "44.56667",
    "lng": "6.2"
  },
  {
    "country": "FR",
    "name": "La Bâtie-Montgascon",
    "lat": "45.57809",
    "lng": "5.53024"
  },
  {
    "country": "FR",
    "name": "La Bâthie",
    "lat": "45.62813",
    "lng": "6.45106"
  },
  {
    "country": "FR",
    "name": "Labastidette",
    "lat": "43.45952",
    "lng": "1.24525"
  },
  {
    "country": "FR",
    "name": "Labastide-Saint-Sernin",
    "lat": "43.73743",
    "lng": "1.46985"
  },
  {
    "country": "FR",
    "name": "Labastide-Saint-Pierre",
    "lat": "43.91769",
    "lng": "1.36628"
  },
  {
    "country": "FR",
    "name": "Labastide-Saint-Georges",
    "lat": "43.69962",
    "lng": "1.84585"
  },
  {
    "country": "FR",
    "name": "Labastide-Rouairoux",
    "lat": "43.47566",
    "lng": "2.63929"
  },
  {
    "country": "FR",
    "name": "La Bastide-des-Jourdans",
    "lat": "43.78707",
    "lng": "5.63468"
  },
  {
    "country": "FR",
    "name": "Labastide-Beauvoir",
    "lat": "43.48148",
    "lng": "1.66543"
  },
  {
    "country": "FR",
    "name": "La Bassée",
    "lat": "50.53424",
    "lng": "2.8062"
  },
  {
    "country": "FR",
    "name": "Labarthe-sur-Lèze",
    "lat": "43.45206",
    "lng": "1.39968"
  },
  {
    "country": "FR",
    "name": "Labarthe-Rivière",
    "lat": "43.081",
    "lng": "0.67134"
  },
  {
    "country": "FR",
    "name": "La Barthe-de-Neste",
    "lat": "43.08123",
    "lng": "0.38438"
  },
  {
    "country": "FR",
    "name": "La Barre-de-Monts",
    "lat": "46.88059",
    "lng": "-2.12168"
  },
  {
    "country": "FR",
    "name": "Labaroche",
    "lat": "48.11076",
    "lng": "7.19244"
  },
  {
    "country": "FR",
    "name": "La Barasse",
    "lat": "43.28433",
    "lng": "5.48664"
  },
  {
    "country": "FR",
    "name": "La Balme-de-Sillingy",
    "lat": "45.9611",
    "lng": "6.04251"
  },
  {
    "country": "FR",
    "name": "La Baconnière",
    "lat": "48.18012",
    "lng": "-0.89202"
  },
  {
    "country": "FR",
    "name": "Kuntzig",
    "lat": "49.34731",
    "lng": "6.2371"
  },
  {
    "country": "FR",
    "name": "Kunheim",
    "lat": "48.07681",
    "lng": "7.5343"
  },
  {
    "country": "FR",
    "name": "Kruth",
    "lat": "47.93079",
    "lng": "6.96475"
  },
  {
    "country": "FR",
    "name": "Krautergersheim",
    "lat": "48.47634",
    "lng": "7.56718"
  },
  {
    "country": "FR",
    "name": "Kœnigsmacker",
    "lat": "49.4",
    "lng": "6.28333"
  },
  {
    "country": "FR",
    "name": "Knutange",
    "lat": "49.33895",
    "lng": "6.03898"
  },
  {
    "country": "FR",
    "name": "Kintzheim",
    "lat": "48.2548",
    "lng": "7.39491"
  },
  {
    "country": "FR",
    "name": "Kingersheim",
    "lat": "47.79259",
    "lng": "7.33491"
  },
  {
    "country": "FR",
    "name": "Kilstett",
    "lat": "48.676",
    "lng": "7.85471"
  },
  {
    "country": "FR",
    "name": "Killem",
    "lat": "50.95779",
    "lng": "2.56068"
  },
  {
    "country": "FR",
    "name": "Keskastel",
    "lat": "48.97132",
    "lng": "7.04412"
  },
  {
    "country": "FR",
    "name": "Kervignac",
    "lat": "47.76289",
    "lng": "-3.23778"
  },
  {
    "country": "FR",
    "name": "Kertzfeld",
    "lat": "48.3799",
    "lng": "7.56816"
  },
  {
    "country": "FR",
    "name": "Kersaint-Plabennec",
    "lat": "48.47166",
    "lng": "-4.37233"
  },
  {
    "country": "FR",
    "name": "Kernilis",
    "lat": "48.57075",
    "lng": "-4.418"
  },
  {
    "country": "FR",
    "name": "Kerlouan",
    "lat": "48.645",
    "lng": "-4.36556"
  },
  {
    "country": "FR",
    "name": "Kerbach",
    "lat": "49.16682",
    "lng": "6.96549"
  },
  {
    "country": "FR",
    "name": "Kembs",
    "lat": "47.68948",
    "lng": "7.50323"
  },
  {
    "country": "FR",
    "name": "Kédange-sur-Canner",
    "lat": "49.30887",
    "lng": "6.33805"
  },
  {
    "country": "FR",
    "name": "Kaysersberg",
    "lat": "48.13803",
    "lng": "7.26385"
  },
  {
    "country": "FR",
    "name": "Kaltenhouse",
    "lat": "48.7911",
    "lng": "7.83217"
  },
  {
    "country": "FR",
    "name": "Juziers",
    "lat": "48.99137",
    "lng": "1.8476"
  },
  {
    "country": "FR",
    "name": "Juvisy-sur-Orge",
    "lat": "48.68333",
    "lng": "2.38333"
  },
  {
    "country": "FR",
    "name": "Juvigny-sous-Andaine",
    "lat": "48.55194",
    "lng": "-0.50878"
  },
  {
    "country": "FR",
    "name": "Juvigné",
    "lat": "48.22891",
    "lng": "-1.03408"
  },
  {
    "country": "FR",
    "name": "Juvignac",
    "lat": "43.61389",
    "lng": "3.81056"
  },
  {
    "country": "FR",
    "name": "Jussy",
    "lat": "49.71984",
    "lng": "3.2327"
  },
  {
    "country": "FR",
    "name": "Jussey",
    "lat": "47.82536",
    "lng": "5.90193"
  },
  {
    "country": "FR",
    "name": "Jussac",
    "lat": "44.98804",
    "lng": "2.42445"
  },
  {
    "country": "FR",
    "name": "Jurançon",
    "lat": "43.2883",
    "lng": "-0.38694"
  },
  {
    "country": "FR",
    "name": "Jumilhac-le-Grand",
    "lat": "45.49432",
    "lng": "1.06339"
  },
  {
    "country": "FR",
    "name": "Jumièges",
    "lat": "49.43324",
    "lng": "0.81918"
  },
  {
    "country": "FR",
    "name": "Jumelles",
    "lat": "47.43511",
    "lng": "-0.1037"
  },
  {
    "country": "FR",
    "name": "Jullouville",
    "lat": "48.77576",
    "lng": "-1.56366"
  },
  {
    "country": "FR",
    "name": "Jujurieux",
    "lat": "46.03976",
    "lng": "5.41328"
  },
  {
    "country": "FR",
    "name": "Juilly",
    "lat": "49.01375",
    "lng": "2.70563"
  },
  {
    "country": "FR",
    "name": "Juillan",
    "lat": "43.19937",
    "lng": "0.0257"
  },
  {
    "country": "FR",
    "name": "Juillac",
    "lat": "45.31875",
    "lng": "1.32282"
  },
  {
    "country": "FR",
    "name": "Juigné-sur-Sarthe",
    "lat": "47.86499",
    "lng": "-0.28624"
  },
  {
    "country": "FR",
    "name": "Juigné-sur-Loire",
    "lat": "47.40741",
    "lng": "-0.47682"
  },
  {
    "country": "FR",
    "name": "Juigné",
    "lat": "47.71878",
    "lng": "-0.39405"
  },
  {
    "country": "FR",
    "name": "Jugon-les-Lacs",
    "lat": "48.41667",
    "lng": "-2.33333"
  },
  {
    "country": "FR",
    "name": "Joyeuse",
    "lat": "44.47972",
    "lng": "4.23781"
  },
  {
    "country": "FR",
    "name": "Jouy-sur-Morin",
    "lat": "48.795",
    "lng": "3.27238"
  },
  {
    "country": "FR",
    "name": "Jouy-le-Potier",
    "lat": "47.74553",
    "lng": "1.81115"
  },
  {
    "country": "FR",
    "name": "Jouy-le-Moutier",
    "lat": "49.01068",
    "lng": "2.04028"
  },
  {
    "country": "FR",
    "name": "Jouy-le-Châtel",
    "lat": "48.66651",
    "lng": "3.13036"
  },
  {
    "country": "FR",
    "name": "Jouy-en-Josas",
    "lat": "48.75909",
    "lng": "2.16966"
  },
  {
    "country": "FR",
    "name": "Jouy-aux-Arches",
    "lat": "49.06148",
    "lng": "6.07925"
  },
  {
    "country": "FR",
    "name": "Jouy",
    "lat": "48.51005",
    "lng": "1.54501"
  },
  {
    "country": "FR",
    "name": "Joux-la-Ville",
    "lat": "47.62241",
    "lng": "3.86217"
  },
  {
    "country": "FR",
    "name": "Jouques",
    "lat": "43.6375",
    "lng": "5.64006"
  },
  {
    "country": "FR",
    "name": "Jougne",
    "lat": "46.76291",
    "lng": "6.38838"
  },
  {
    "country": "FR",
    "name": "Jouet-sur-l'Aubois",
    "lat": "47.04562",
    "lng": "2.98725"
  },
  {
    "country": "FR",
    "name": "Bourg de Joué-sur-Erdre",
    "lat": "47.49596",
    "lng": "-1.42047"
  },
  {
    "country": "FR",
    "name": "Joué-lès-Tours",
    "lat": "47.35223",
    "lng": "0.66905"
  },
  {
    "country": "FR",
    "name": "Joudreville",
    "lat": "49.2856",
    "lng": "5.77832"
  },
  {
    "country": "FR",
    "name": "Jouars-Pontchartrain",
    "lat": "48.78888",
    "lng": "1.89898"
  },
  {
    "country": "FR",
    "name": "Jouarre",
    "lat": "48.92661",
    "lng": "3.13168"
  },
  {
    "country": "FR",
    "name": "Josselin",
    "lat": "47.9572",
    "lng": "-2.54713"
  },
  {
    "country": "FR",
    "name": "Jonzieux",
    "lat": "45.31582",
    "lng": "4.36041"
  },
  {
    "country": "FR",
    "name": "Jonzac",
    "lat": "45.45",
    "lng": "-0.43333"
  },
  {
    "country": "FR",
    "name": "Jons",
    "lat": "45.80797",
    "lng": "5.08032"
  },
  {
    "country": "FR",
    "name": "Jonquières-Saint-Vincent",
    "lat": "43.82809",
    "lng": "4.56327"
  },
  {
    "country": "FR",
    "name": "Jonquières",
    "lat": "44.11431",
    "lng": "4.90003"
  },
  {
    "country": "FR",
    "name": "Jonquerettes",
    "lat": "43.94655",
    "lng": "4.93286"
  },
  {
    "country": "FR",
    "name": "Jonchery-sur-Vesle",
    "lat": "49.28952",
    "lng": "3.81345"
  },
  {
    "country": "FR",
    "name": "Joncherey",
    "lat": "47.52616",
    "lng": "7.00158"
  },
  {
    "country": "FR",
    "name": "Jonage",
    "lat": "45.7964",
    "lng": "5.0453"
  },
  {
    "country": "FR",
    "name": "Joinville-le-Pont",
    "lat": "48.82538",
    "lng": "2.47458"
  },
  {
    "country": "FR",
    "name": "Joinville",
    "lat": "48.44363",
    "lng": "5.14144"
  },
  {
    "country": "FR",
    "name": "Joigny",
    "lat": "47.98288",
    "lng": "3.40096"
  },
  {
    "country": "FR",
    "name": "Jœuf",
    "lat": "49.23333",
    "lng": "6.01667"
  },
  {
    "country": "FR",
    "name": "Job",
    "lat": "45.61776",
    "lng": "3.74602"
  },
  {
    "country": "FR",
    "name": "Jeumont",
    "lat": "50.29658",
    "lng": "4.10108"
  },
  {
    "country": "FR",
    "name": "Jenlain",
    "lat": "50.31164",
    "lng": "3.62872"
  },
  {
    "country": "FR",
    "name": "Jegun",
    "lat": "43.76667",
    "lng": "0.46667"
  },
  {
    "country": "FR",
    "name": "Jebsheim",
    "lat": "48.12345",
    "lng": "7.47549"
  },
  {
    "country": "FR",
    "name": "Jeanménil",
    "lat": "48.3356",
    "lng": "6.68769"
  },
  {
    "country": "FR",
    "name": "Javené",
    "lat": "48.31933",
    "lng": "-1.2163"
  },
  {
    "country": "FR",
    "name": "Jaux",
    "lat": "49.3912",
    "lng": "2.77809"
  },
  {
    "country": "FR",
    "name": "Jausiers",
    "lat": "44.41705",
    "lng": "6.72947"
  },
  {
    "country": "FR",
    "name": "Jaunay-Clan",
    "lat": "46.68453",
    "lng": "0.37128"
  },
  {
    "country": "FR",
    "name": "Jaujac",
    "lat": "44.6354",
    "lng": "4.2573"
  },
  {
    "country": "FR",
    "name": "Jasseron",
    "lat": "46.21316",
    "lng": "5.32579"
  },
  {
    "country": "FR",
    "name": "Jassans-Riottier",
    "lat": "45.98352",
    "lng": "4.76004"
  },
  {
    "country": "FR",
    "name": "Jarzé",
    "lat": "47.55563",
    "lng": "-0.23183"
  },
  {
    "country": "FR",
    "name": "Jarville-la-Malgrange",
    "lat": "48.66907",
    "lng": "6.20636"
  },
  {
    "country": "FR",
    "name": "Javron-les-Chapelles",
    "lat": "48.41797",
    "lng": "-0.33742"
  },
  {
    "country": "FR",
    "name": "Jarrie",
    "lat": "45.11732",
    "lng": "5.75957"
  },
  {
    "country": "FR",
    "name": "Jarny",
    "lat": "49.15736",
    "lng": "5.87877"
  },
  {
    "country": "FR",
    "name": "Jarnac",
    "lat": "45.6816",
    "lng": "-0.17329"
  },
  {
    "country": "FR",
    "name": "Jargeau",
    "lat": "47.86316",
    "lng": "2.12648"
  },
  {
    "country": "FR",
    "name": "Jard-sur-Mer",
    "lat": "46.41451",
    "lng": "-1.57639"
  },
  {
    "country": "FR",
    "name": "Jardin",
    "lat": "45.49617",
    "lng": "4.90641"
  },
  {
    "country": "FR",
    "name": "Janzé",
    "lat": "47.95915",
    "lng": "-1.49829"
  },
  {
    "country": "FR",
    "name": "Janville-sur-Juine",
    "lat": "48.51352",
    "lng": "2.27064"
  },
  {
    "country": "FR",
    "name": "Janville",
    "lat": "48.20284",
    "lng": "1.8802"
  },
  {
    "country": "FR",
    "name": "Jans",
    "lat": "47.62029",
    "lng": "-1.61438"
  },
  {
    "country": "FR",
    "name": "Janneyrias",
    "lat": "45.75346",
    "lng": "5.11027"
  },
  {
    "country": "FR",
    "name": "Jallais",
    "lat": "47.19691",
    "lng": "-0.86738"
  },
  {
    "country": "FR",
    "name": "Jacou",
    "lat": "43.66139",
    "lng": "3.91222"
  },
  {
    "country": "FR",
    "name": "Jacob-Bellecombette",
    "lat": "45.55275",
    "lng": "5.9116"
  },
  {
    "country": "FR",
    "name": "Izon",
    "lat": "44.92416",
    "lng": "-0.36322"
  },
  {
    "country": "FR",
    "name": "Izernore",
    "lat": "46.21686",
    "lng": "5.55366"
  },
  {
    "country": "FR",
    "name": "Izeaux",
    "lat": "45.33515",
    "lng": "5.42509"
  },
  {
    "country": "FR",
    "name": "Iwuy",
    "lat": "50.233",
    "lng": "3.32058"
  },
  {
    "country": "FR",
    "name": "Ivry-sur-Seine",
    "lat": "48.81568",
    "lng": "2.38487"
  },
  {
    "country": "FR",
    "name": "Ivry-la-Bataille",
    "lat": "48.88333",
    "lng": "1.45948"
  },
  {
    "country": "FR",
    "name": "Itxassou",
    "lat": "43.32893",
    "lng": "-1.40617"
  },
  {
    "country": "FR",
    "name": "Itteville",
    "lat": "48.51536",
    "lng": "2.34377"
  },
  {
    "country": "FR",
    "name": "Ittenheim",
    "lat": "48.60508",
    "lng": "7.59372"
  },
  {
    "country": "FR",
    "name": "Iteuil",
    "lat": "46.48808",
    "lng": "0.31212"
  },
  {
    "country": "FR",
    "name": "Itancourt",
    "lat": "49.80664",
    "lng": "3.34427"
  },
  {
    "country": "FR",
    "name": "Istres",
    "lat": "43.51667",
    "lng": "4.98333"
  },
  {
    "country": "FR",
    "name": "Issy-les-Moulineaux",
    "lat": "48.82104",
    "lng": "2.27718"
  },
  {
    "country": "FR",
    "name": "Is-sur-Tille",
    "lat": "47.5267",
    "lng": "5.10649"
  },
  {
    "country": "FR",
    "name": "Issoudun",
    "lat": "46.95",
    "lng": "2"
  },
  {
    "country": "FR",
    "name": "Issou",
    "lat": "48.98994",
    "lng": "1.79292"
  },
  {
    "country": "FR",
    "name": "Issoire",
    "lat": "45.55",
    "lng": "3.25"
  },
  {
    "country": "FR",
    "name": "Issenheim",
    "lat": "47.90357",
    "lng": "7.25235"
  },
  {
    "country": "FR",
    "name": "Issé",
    "lat": "47.62419",
    "lng": "-1.45152"
  },
  {
    "country": "FR",
    "name": "Isques",
    "lat": "50.67391",
    "lng": "1.65445"
  },
  {
    "country": "FR",
    "name": "Isneauville",
    "lat": "49.49832",
    "lng": "1.15431"
  },
  {
    "country": "FR",
    "name": "Isle",
    "lat": "45.80272",
    "lng": "1.21213"
  },
  {
    "country": "FR",
    "name": "Isigny-sur-Mer",
    "lat": "49.31604",
    "lng": "-1.10384"
  },
  {
    "country": "FR",
    "name": "Isigny-le-Buat",
    "lat": "48.61705",
    "lng": "-1.16993"
  },
  {
    "country": "FR",
    "name": "Isbergues",
    "lat": "50.62328",
    "lng": "2.45902"
  },
  {
    "country": "FR",
    "name": "Irvillac",
    "lat": "48.37011",
    "lng": "-4.21223"
  },
  {
    "country": "FR",
    "name": "Irodouër",
    "lat": "48.24932",
    "lng": "-1.94959"
  },
  {
    "country": "FR",
    "name": "Irmstett",
    "lat": "48.58801",
    "lng": "7.47837"
  },
  {
    "country": "FR",
    "name": "Irigny",
    "lat": "45.67362",
    "lng": "4.81753"
  },
  {
    "country": "FR",
    "name": "Innenheim",
    "lat": "48.49659",
    "lng": "7.57439"
  },
  {
    "country": "FR",
    "name": "Ingwiller",
    "lat": "48.87284",
    "lng": "7.4798"
  },
  {
    "country": "FR",
    "name": "Inguiniel",
    "lat": "47.97658",
    "lng": "-3.28072"
  },
  {
    "country": "FR",
    "name": "Ingré",
    "lat": "47.91995",
    "lng": "1.82778"
  },
  {
    "country": "FR",
    "name": "Ingrandes",
    "lat": "47.405",
    "lng": "-0.92336"
  },
  {
    "country": "FR",
    "name": "Ingersheim",
    "lat": "48.09803",
    "lng": "7.30308"
  },
  {
    "country": "FR",
    "name": "Incheville",
    "lat": "50.01239",
    "lng": "1.49438"
  },
  {
    "country": "FR",
    "name": "Imphy",
    "lat": "46.93619",
    "lng": "3.26037"
  },
  {
    "country": "FR",
    "name": "Illzach",
    "lat": "47.78088",
    "lng": "7.34662"
  },
  {
    "country": "FR",
    "name": "Illkirch-Graffenstaden",
    "lat": "48.52894",
    "lng": "7.71523"
  },
  {
    "country": "FR",
    "name": "Illies",
    "lat": "50.56144",
    "lng": "2.83011"
  },
  {
    "country": "FR",
    "name": "Illfurth",
    "lat": "47.67291",
    "lng": "7.26539"
  },
  {
    "country": "FR",
    "name": "Ille-sur-Têt",
    "lat": "42.67069",
    "lng": "2.62162"
  },
  {
    "country": "FR",
    "name": "Illats",
    "lat": "44.59714",
    "lng": "-0.37238"
  },
  {
    "country": "FR",
    "name": "Illange",
    "lat": "49.32617",
    "lng": "6.17953"
  },
  {
    "country": "FR",
    "name": "Igoville",
    "lat": "49.3199",
    "lng": "1.14832"
  },
  {
    "country": "FR",
    "name": "Igon",
    "lat": "43.16667",
    "lng": "-0.23333"
  },
  {
    "country": "FR",
    "name": "Igny",
    "lat": "48.74437",
    "lng": "2.22428"
  },
  {
    "country": "FR",
    "name": "Igney",
    "lat": "48.27358",
    "lng": "6.39664"
  },
  {
    "country": "FR",
    "name": "Ifs",
    "lat": "49.14",
    "lng": "-0.34899"
  },
  {
    "country": "FR",
    "name": "Iffendic",
    "lat": "48.12981",
    "lng": "-2.03486"
  },
  {
    "country": "FR",
    "name": "Idron",
    "lat": "43.28333",
    "lng": "-0.31667"
  },
  {
    "country": "FR",
    "name": "Ibos",
    "lat": "43.23333",
    "lng": "0"
  },
  {
    "country": "FR",
    "name": "Hyères",
    "lat": "43.12038",
    "lng": "6.12857"
  },
  {
    "country": "FR",
    "name": "Huttenheim",
    "lat": "48.35864",
    "lng": "7.57833"
  },
  {
    "country": "FR",
    "name": "Hussigny-Godbrange",
    "lat": "49.49119",
    "lng": "5.86683"
  },
  {
    "country": "FR",
    "name": "Husseren-Wesserling",
    "lat": "47.88297",
    "lng": "6.99388"
  },
  {
    "country": "FR",
    "name": "Hurigny",
    "lat": "46.34722",
    "lng": "4.79676"
  },
  {
    "country": "FR",
    "name": "Huriel",
    "lat": "46.37368",
    "lng": "2.47793"
  },
  {
    "country": "FR",
    "name": "Huningue",
    "lat": "47.60477",
    "lng": "7.57782"
  },
  {
    "country": "FR",
    "name": "Hundling",
    "lat": "49.1086",
    "lng": "6.97989"
  },
  {
    "country": "FR",
    "name": "Hulluch",
    "lat": "50.48961",
    "lng": "2.81232"
  },
  {
    "country": "FR",
    "name": "Huisseau-sur-Mauves",
    "lat": "47.89319",
    "lng": "1.70274"
  },
  {
    "country": "FR",
    "name": "Huisseau-sur-Cosson",
    "lat": "47.59335",
    "lng": "1.45333"
  },
  {
    "country": "FR",
    "name": "Huismes",
    "lat": "47.23319",
    "lng": "0.25116"
  },
  {
    "country": "FR",
    "name": "Huez",
    "lat": "45.08252",
    "lng": "6.05848"
  },
  {
    "country": "FR",
    "name": "Huelgoat",
    "lat": "48.36111",
    "lng": "-3.74578"
  },
  {
    "country": "FR",
    "name": "Hoymille",
    "lat": "50.97187",
    "lng": "2.44738"
  },
  {
    "country": "FR",
    "name": "Houssen",
    "lat": "48.12581",
    "lng": "7.37841"
  },
  {
    "country": "FR",
    "name": "Hourtin",
    "lat": "45.1857",
    "lng": "-1.05719"
  },
  {
    "country": "FR",
    "name": "Houppeville",
    "lat": "49.51259",
    "lng": "1.07962"
  },
  {
    "country": "FR",
    "name": "Houplines",
    "lat": "50.69499",
    "lng": "2.91518"
  },
  {
    "country": "FR",
    "name": "Houplin-Ancoisne",
    "lat": "50.56284",
    "lng": "3.00251"
  },
  {
    "country": "FR",
    "name": "Houlgate",
    "lat": "49.299",
    "lng": "-0.08153"
  },
  {
    "country": "FR",
    "name": "Houlbec-Cocherel",
    "lat": "49.0735",
    "lng": "1.36563"
  },
  {
    "country": "FR",
    "name": "Houilles",
    "lat": "48.92161",
    "lng": "2.19263"
  },
  {
    "country": "FR",
    "name": "Houdemont",
    "lat": "48.65",
    "lng": "6.18333"
  },
  {
    "country": "FR",
    "name": "Houdan",
    "lat": "48.79044",
    "lng": "1.60007"
  },
  {
    "country": "FR",
    "name": "Houdain",
    "lat": "50.4504",
    "lng": "2.53777"
  },
  {
    "country": "FR",
    "name": "Hornoy-le-Bourg",
    "lat": "49.85",
    "lng": "1.9"
  },
  {
    "country": "FR",
    "name": "Hornaing",
    "lat": "50.36835",
    "lng": "3.33707"
  },
  {
    "country": "FR",
    "name": "Horgues",
    "lat": "43.18865",
    "lng": "0.08733"
  },
  {
    "country": "FR",
    "name": "Hordain",
    "lat": "50.26306",
    "lng": "3.31358"
  },
  {
    "country": "FR",
    "name": "Horbourg-Wihr",
    "lat": "48.08106",
    "lng": "7.3938"
  },
  {
    "country": "FR",
    "name": "Honfleur",
    "lat": "49.41985",
    "lng": "0.23294"
  },
  {
    "country": "FR",
    "name": "Hondschoote",
    "lat": "50.978",
    "lng": "2.58372"
  },
  {
    "country": "FR",
    "name": "Homécourt",
    "lat": "49.22111",
    "lng": "5.98445"
  },
  {
    "country": "FR",
    "name": "Hombourg-Haut",
    "lat": "49.12819",
    "lng": "6.77066"
  },
  {
    "country": "FR",
    "name": "Homblières",
    "lat": "49.85031",
    "lng": "3.36456"
  },
  {
    "country": "FR",
    "name": "Hombleux",
    "lat": "49.73942",
    "lng": "2.98574"
  },
  {
    "country": "FR",
    "name": "Holving",
    "lat": "49.01162",
    "lng": "6.96556"
  },
  {
    "country": "FR",
    "name": "Holtzwihr",
    "lat": "48.11278",
    "lng": "7.42046"
  },
  {
    "country": "FR",
    "name": "Holtzheim",
    "lat": "48.5582",
    "lng": "7.64434"
  },
  {
    "country": "FR",
    "name": "Holnon",
    "lat": "49.86086",
    "lng": "3.21509"
  },
  {
    "country": "FR",
    "name": "Hœrdt",
    "lat": "48.7",
    "lng": "7.78333"
  },
  {
    "country": "FR",
    "name": "Hœnheim",
    "lat": "48.62224",
    "lng": "7.75549"
  },
  {
    "country": "FR",
    "name": "Hochstatt",
    "lat": "47.70343",
    "lng": "7.27583"
  },
  {
    "country": "FR",
    "name": "Hochfelden",
    "lat": "48.75738",
    "lng": "7.56769"
  },
  {
    "country": "FR",
    "name": "Hirtzfelden",
    "lat": "47.91079",
    "lng": "7.44669"
  },
  {
    "country": "FR",
    "name": "Hirtzbach",
    "lat": "47.59618",
    "lng": "7.22043"
  },
  {
    "country": "FR",
    "name": "Hirson",
    "lat": "49.92262",
    "lng": "4.08259"
  },
  {
    "country": "FR",
    "name": "Hirsingue",
    "lat": "47.58655",
    "lng": "7.2513"
  },
  {
    "country": "FR",
    "name": "Hirel",
    "lat": "48.60502",
    "lng": "-1.80224"
  },
  {
    "country": "FR",
    "name": "Hinx",
    "lat": "43.7019",
    "lng": "-0.92591"
  },
  {
    "country": "FR",
    "name": "Hinges",
    "lat": "50.56674",
    "lng": "2.6216"
  },
  {
    "country": "FR",
    "name": "Hindisheim",
    "lat": "48.46837",
    "lng": "7.63859"
  },
  {
    "country": "FR",
    "name": "Hilsenheim",
    "lat": "48.28761",
    "lng": "7.56348"
  },
  {
    "country": "FR",
    "name": "Hillion",
    "lat": "48.51429",
    "lng": "-2.66634"
  },
  {
    "country": "FR",
    "name": "Hiersac",
    "lat": "45.66667",
    "lng": "0"
  },
  {
    "country": "FR",
    "name": "Hières-sur-Amby",
    "lat": "45.79783",
    "lng": "5.29467"
  },
  {
    "country": "FR",
    "name": "Heyrieux",
    "lat": "45.62853",
    "lng": "5.05849"
  },
  {
    "country": "FR",
    "name": "Heuringhem",
    "lat": "50.69638",
    "lng": "2.28333"
  },
  {
    "country": "FR",
    "name": "Heugas",
    "lat": "43.64334",
    "lng": "-1.08143"
  },
  {
    "country": "FR",
    "name": "Heudreville-sur-Eure",
    "lat": "49.14089",
    "lng": "1.18813"
  },
  {
    "country": "FR",
    "name": "Hettange-Grande",
    "lat": "49.4065",
    "lng": "6.15233"
  },
  {
    "country": "FR",
    "name": "Hésingue",
    "lat": "47.57621",
    "lng": "7.52244"
  },
  {
    "country": "FR",
    "name": "Hesdin",
    "lat": "50.37349",
    "lng": "2.0382"
  },
  {
    "country": "FR",
    "name": "Herzeele",
    "lat": "50.88584",
    "lng": "2.5351"
  },
  {
    "country": "FR",
    "name": "Héry",
    "lat": "47.90146",
    "lng": "3.62868"
  },
  {
    "country": "FR",
    "name": "Hersin-Coupigny",
    "lat": "50.44796",
    "lng": "2.6494"
  },
  {
    "country": "FR",
    "name": "Herserange",
    "lat": "49.51758",
    "lng": "5.78163"
  },
  {
    "country": "FR",
    "name": "Herry",
    "lat": "47.21667",
    "lng": "2.95385"
  },
  {
    "country": "FR",
    "name": "Herrlisheim-près-Colmar",
    "lat": "48.01835",
    "lng": "7.32668"
  },
  {
    "country": "FR",
    "name": "Herrlisheim",
    "lat": "48.73049",
    "lng": "7.90535"
  },
  {
    "country": "FR",
    "name": "Hérouvillette",
    "lat": "49.2213",
    "lng": "-0.24348"
  },
  {
    "country": "FR",
    "name": "Hérouville-Saint-Clair",
    "lat": "49.21088",
    "lng": "-0.30653"
  },
  {
    "country": "FR",
    "name": "Hermonville",
    "lat": "49.33655",
    "lng": "3.91011"
  },
  {
    "country": "FR",
    "name": "Hermies",
    "lat": "50.11126",
    "lng": "3.04202"
  },
  {
    "country": "FR",
    "name": "Hermes",
    "lat": "49.36032",
    "lng": "2.24461"
  },
  {
    "country": "FR",
    "name": "Hermanville-sur-Mer",
    "lat": "49.28464",
    "lng": "-0.31544"
  },
  {
    "country": "FR",
    "name": "Herlies",
    "lat": "50.57753",
    "lng": "2.85285"
  },
  {
    "country": "FR",
    "name": "Hérin",
    "lat": "50.35557",
    "lng": "3.45309"
  },
  {
    "country": "FR",
    "name": "Hérimoncourt",
    "lat": "47.44284",
    "lng": "6.88242"
  },
  {
    "country": "FR",
    "name": "Héricy",
    "lat": "48.44848",
    "lng": "2.76445"
  },
  {
    "country": "FR",
    "name": "Héricourt",
    "lat": "47.57305",
    "lng": "6.76139"
  },
  {
    "country": "FR",
    "name": "Héric",
    "lat": "47.41417",
    "lng": "-1.65309"
  },
  {
    "country": "FR",
    "name": "Hergnies",
    "lat": "50.47287",
    "lng": "3.52612"
  },
  {
    "country": "FR",
    "name": "Hérépian",
    "lat": "43.593",
    "lng": "3.11595"
  },
  {
    "country": "FR",
    "name": "Herblay",
    "lat": "48.98994",
    "lng": "2.1699"
  },
  {
    "country": "FR",
    "name": "Herbitzheim",
    "lat": "49.01541",
    "lng": "7.08188"
  },
  {
    "country": "FR",
    "name": "Herbignac",
    "lat": "47.44822",
    "lng": "-2.3181"
  },
  {
    "country": "FR",
    "name": "Herbeys",
    "lat": "45.13735",
    "lng": "5.79592"
  },
  {
    "country": "FR",
    "name": "Herbault",
    "lat": "47.60501",
    "lng": "1.13934"
  },
  {
    "country": "FR",
    "name": "Henvic",
    "lat": "48.63256",
    "lng": "-3.92623"
  },
  {
    "country": "FR",
    "name": "Henrichemont",
    "lat": "47.30333",
    "lng": "2.52458"
  },
  {
    "country": "FR",
    "name": "Hénouville",
    "lat": "49.4789",
    "lng": "0.96367"
  },
  {
    "country": "FR",
    "name": "Hénon",
    "lat": "48.38433",
    "lng": "-2.68334"
  },
  {
    "country": "FR",
    "name": "Hennebont",
    "lat": "47.80512",
    "lng": "-3.27337"
  },
  {
    "country": "FR",
    "name": "Hénin-Beaumont",
    "lat": "50.41359",
    "lng": "2.96485"
  },
  {
    "country": "FR",
    "name": "Hendaye",
    "lat": "43.37172",
    "lng": "-1.77382"
  },
  {
    "country": "FR",
    "name": "Hénanbihen",
    "lat": "48.56072",
    "lng": "-2.37602"
  },
  {
    "country": "FR",
    "name": "Hem",
    "lat": "50.65256",
    "lng": "3.18681"
  },
  {
    "country": "FR",
    "name": "Helfaut",
    "lat": "50.69783",
    "lng": "2.24234"
  },
  {
    "country": "FR",
    "name": "Hélesmes",
    "lat": "50.37036",
    "lng": "3.35918"
  },
  {
    "country": "FR",
    "name": "Heimsbrunn",
    "lat": "47.72647",
    "lng": "7.22638"
  },
  {
    "country": "FR",
    "name": "Heillecourt",
    "lat": "48.65854",
    "lng": "6.20711"
  },
  {
    "country": "FR",
    "name": "Hégenheim",
    "lat": "47.56251",
    "lng": "7.52684"
  },
  {
    "country": "FR",
    "name": "Hédé-Bazouges",
    "lat": "48.3",
    "lng": "-1.8"
  },
  {
    "country": "FR",
    "name": "Hazebrouck",
    "lat": "50.72374",
    "lng": "2.53729"
  },
  {
    "country": "FR",
    "name": "Haybes",
    "lat": "50.00458",
    "lng": "4.70496"
  },
  {
    "country": "FR",
    "name": "Hayange",
    "lat": "49.32881",
    "lng": "6.06278"
  },
  {
    "country": "FR",
    "name": "Haverskerque",
    "lat": "50.64089",
    "lng": "2.54162"
  },
  {
    "country": "FR",
    "name": "Haveluy",
    "lat": "50.35289",
    "lng": "3.40389"
  },
  {
    "country": "FR",
    "name": "Hauville",
    "lat": "49.39645",
    "lng": "0.77232"
  },
  {
    "country": "FR",
    "name": "Hautot-sur-Mer",
    "lat": "49.89789",
    "lng": "1.02884"
  },
  {
    "country": "FR",
    "name": "Hautmont",
    "lat": "50.25077",
    "lng": "3.92143"
  },
  {
    "country": "FR",
    "name": "Yutz",
    "lat": "49.35571",
    "lng": "6.1926"
  },
  {
    "country": "FR",
    "name": "Hauteville-Lompnes",
    "lat": "45.97794",
    "lng": "5.60114"
  },
  {
    "country": "FR",
    "name": "Hauteville-lès-Dijon",
    "lat": "47.36602",
    "lng": "4.99375"
  },
  {
    "country": "FR",
    "name": "Haute-Rivoire",
    "lat": "45.71526",
    "lng": "4.39662"
  },
  {
    "country": "FR",
    "name": "Hauterives",
    "lat": "45.2562",
    "lng": "5.02572"
  },
  {
    "country": "FR",
    "name": "Hauterive",
    "lat": "46.09005",
    "lng": "3.44593"
  },
  {
    "country": "FR",
    "name": "Haute-Goulaine",
    "lat": "47.19905",
    "lng": "-1.42941"
  },
  {
    "country": "FR",
    "name": "Hautefort",
    "lat": "45.25953",
    "lng": "1.14879"
  },
  {
    "country": "FR",
    "name": "Haussy",
    "lat": "50.2183",
    "lng": "3.47683"
  },
  {
    "country": "FR",
    "name": "Haulchin",
    "lat": "50.3172",
    "lng": "3.43599"
  },
  {
    "country": "FR",
    "name": "Haucourt-Moulaine",
    "lat": "49.49022",
    "lng": "5.80283"
  },
  {
    "country": "FR",
    "name": "Haubourdin",
    "lat": "50.60826",
    "lng": "2.99143"
  },
  {
    "country": "FR",
    "name": "Hatten",
    "lat": "48.90123",
    "lng": "7.97968"
  },
  {
    "country": "FR",
    "name": "Haspres",
    "lat": "50.25829",
    "lng": "3.41695"
  },
  {
    "country": "FR",
    "name": "Hasparren",
    "lat": "43.38377",
    "lng": "-1.30499"
  },
  {
    "country": "FR",
    "name": "Hasnon",
    "lat": "50.42472",
    "lng": "3.38657"
  },
  {
    "country": "FR",
    "name": "Harnes",
    "lat": "50.44643",
    "lng": "2.90481"
  },
  {
    "country": "FR",
    "name": "Harly",
    "lat": "49.83766",
    "lng": "3.31001"
  },
  {
    "country": "FR",
    "name": "Hargarten-aux-Mines",
    "lat": "49.22436",
    "lng": "6.61459"
  },
  {
    "country": "FR",
    "name": "Harfleur",
    "lat": "49.5066",
    "lng": "0.19827"
  },
  {
    "country": "FR",
    "name": "Hardricourt",
    "lat": "49.00779",
    "lng": "1.89389"
  },
  {
    "country": "FR",
    "name": "Hardinghen",
    "lat": "50.80414",
    "lng": "1.82122"
  },
  {
    "country": "FR",
    "name": "Harbonnières",
    "lat": "49.84958",
    "lng": "2.66812"
  },
  {
    "country": "FR",
    "name": "Hanvec",
    "lat": "48.32692",
    "lng": "-4.15951"
  },
  {
    "country": "FR",
    "name": "Hangenbieten",
    "lat": "48.55985",
    "lng": "7.61464"
  },
  {
    "country": "FR",
    "name": "Hanches",
    "lat": "48.60115",
    "lng": "1.65137"
  },
  {
    "country": "FR",
    "name": "Ham-sous-Varsberg",
    "lat": "49.18014",
    "lng": "6.64702"
  },
  {
    "country": "FR",
    "name": "Hames-Boucres",
    "lat": "50.88178",
    "lng": "1.84338"
  },
  {
    "country": "FR",
    "name": "Hambye",
    "lat": "48.94798",
    "lng": "-1.26417"
  },
  {
    "country": "FR",
    "name": "Hambach",
    "lat": "49.05942",
    "lng": "7.0353"
  },
  {
    "country": "FR",
    "name": "Ham",
    "lat": "49.74721",
    "lng": "3.07301"
  },
  {
    "country": "FR",
    "name": "Halluin",
    "lat": "50.78628",
    "lng": "3.12611"
  },
  {
    "country": "FR",
    "name": "Hallines",
    "lat": "50.71087",
    "lng": "2.22629"
  },
  {
    "country": "FR",
    "name": "Hallennes-lez-Haubourdin",
    "lat": "50.61667",
    "lng": "2.96667"
  },
  {
    "country": "FR",
    "name": "Hallencourt",
    "lat": "49.99201",
    "lng": "1.87649"
  },
  {
    "country": "FR",
    "name": "Haisnes",
    "lat": "50.50776",
    "lng": "2.79416"
  },
  {
    "country": "FR",
    "name": "Haillicourt",
    "lat": "50.47519",
    "lng": "2.57458"
  },
  {
    "country": "FR",
    "name": "Haguenau",
    "lat": "48.81557",
    "lng": "7.79051"
  },
  {
    "country": "FR",
    "name": "Hagondange",
    "lat": "49.24879",
    "lng": "6.16374"
  },
  {
    "country": "FR",
    "name": "Hagetmau",
    "lat": "43.65893",
    "lng": "-0.59172"
  },
  {
    "country": "FR",
    "name": "Hagenthal-le-Bas",
    "lat": "47.52497",
    "lng": "7.47783"
  },
  {
    "country": "FR",
    "name": "Hadol",
    "lat": "48.08983",
    "lng": "6.47662"
  },
  {
    "country": "FR",
    "name": "Habsheim",
    "lat": "47.73087",
    "lng": "7.41855"
  },
  {
    "country": "FR",
    "name": "Habas",
    "lat": "43.5718",
    "lng": "-0.92976"
  },
  {
    "country": "FR",
    "name": "Gy",
    "lat": "47.40588",
    "lng": "5.81226"
  },
  {
    "country": "FR",
    "name": "Guyancourt",
    "lat": "48.77334",
    "lng": "2.07393"
  },
  {
    "country": "FR",
    "name": "Gurgy",
    "lat": "47.86712",
    "lng": "3.56341"
  },
  {
    "country": "FR",
    "name": "Gundershoffen",
    "lat": "48.90648",
    "lng": "7.66096"
  },
  {
    "country": "FR",
    "name": "Gumbrechtshoffen",
    "lat": "48.9058",
    "lng": "7.62915"
  },
  {
    "country": "FR",
    "name": "Gujan-Mestras",
    "lat": "44.63333",
    "lng": "-1.06667"
  },
  {
    "country": "FR",
    "name": "Guîtres",
    "lat": "45.03333",
    "lng": "-0.18333"
  },
  {
    "country": "FR",
    "name": "Guissény",
    "lat": "48.63292",
    "lng": "-4.40884"
  },
  {
    "country": "FR",
    "name": "Guise",
    "lat": "49.90055",
    "lng": "3.62801"
  },
  {
    "country": "FR",
    "name": "Guiscriff",
    "lat": "48.04944",
    "lng": "-3.64356"
  },
  {
    "country": "FR",
    "name": "Guiscard",
    "lat": "49.6566",
    "lng": "3.05127"
  },
  {
    "country": "FR",
    "name": "Guipry",
    "lat": "47.82637",
    "lng": "-1.84218"
  },
  {
    "country": "FR",
    "name": "Guipel",
    "lat": "48.29937",
    "lng": "-1.71866"
  },
  {
    "country": "FR",
    "name": "Guipavas",
    "lat": "48.43522",
    "lng": "-4.39722"
  },
  {
    "country": "FR",
    "name": "Guingamp",
    "lat": "48.55",
    "lng": "-3.15"
  },
  {
    "country": "FR",
    "name": "Guînes",
    "lat": "50.86708",
    "lng": "1.87025"
  },
  {
    "country": "FR",
    "name": "Guilvinec",
    "lat": "47.79861",
    "lng": "-4.28111"
  },
  {
    "country": "FR",
    "name": "Guilliers",
    "lat": "48.04286",
    "lng": "-2.40562"
  },
  {
    "country": "FR",
    "name": "Guillestre",
    "lat": "44.6595",
    "lng": "6.64948"
  },
  {
    "country": "FR",
    "name": "Guillac",
    "lat": "47.91096",
    "lng": "-2.46571"
  },
  {
    "country": "FR",
    "name": "Guilherand-Granges",
    "lat": "44.93278",
    "lng": "4.87372"
  },
  {
    "country": "FR",
    "name": "Guilers",
    "lat": "48.42545",
    "lng": "-4.55801"
  },
  {
    "country": "FR",
    "name": "Guignicourt",
    "lat": "49.43714",
    "lng": "3.96755"
  },
  {
    "country": "FR",
    "name": "Guignes",
    "lat": "48.63333",
    "lng": "2.8"
  },
  {
    "country": "FR",
    "name": "Guignen",
    "lat": "47.92009",
    "lng": "-1.86161"
  },
  {
    "country": "FR",
    "name": "Guiclan",
    "lat": "48.54967",
    "lng": "-3.96211"
  },
  {
    "country": "FR",
    "name": "Guichen",
    "lat": "47.96762",
    "lng": "-1.79534"
  },
  {
    "country": "FR",
    "name": "Guichainville",
    "lat": "49.00139",
    "lng": "1.19305"
  },
  {
    "country": "FR",
    "name": "Guewenheim",
    "lat": "47.75283",
    "lng": "7.09253"
  },
  {
    "country": "FR",
    "name": "Gueux",
    "lat": "49.25048",
    "lng": "3.91024"
  },
  {
    "country": "FR",
    "name": "Gueugnon",
    "lat": "46.60357",
    "lng": "4.06286"
  },
  {
    "country": "FR",
    "name": "Guéthary",
    "lat": "43.42285",
    "lng": "-1.61073"
  },
  {
    "country": "FR",
    "name": "Guesnain",
    "lat": "50.35",
    "lng": "3.15"
  },
  {
    "country": "FR",
    "name": "Guerville",
    "lat": "48.94388",
    "lng": "1.73429"
  },
  {
    "country": "FR",
    "name": "Guern",
    "lat": "48.02964",
    "lng": "-3.09145"
  },
  {
    "country": "FR",
    "name": "Guermantes",
    "lat": "48.85303",
    "lng": "2.70495"
  },
  {
    "country": "FR",
    "name": "Guerlesquin",
    "lat": "48.51758",
    "lng": "-3.58583"
  },
  {
    "country": "FR",
    "name": "Guérigny",
    "lat": "47.08703",
    "lng": "3.20182"
  },
  {
    "country": "FR",
    "name": "Guéret",
    "lat": "46.17234",
    "lng": "1.87456"
  },
  {
    "country": "FR",
    "name": "Guéreins",
    "lat": "46.10628",
    "lng": "4.77902"
  },
  {
    "country": "FR",
    "name": "Guérard",
    "lat": "48.82086",
    "lng": "2.95969"
  },
  {
    "country": "FR",
    "name": "Guérande",
    "lat": "47.32911",
    "lng": "-2.42829"
  },
  {
    "country": "FR",
    "name": "Guer",
    "lat": "47.90619",
    "lng": "-2.12314"
  },
  {
    "country": "FR",
    "name": "Guenrouet",
    "lat": "47.51881",
    "lng": "-1.95381"
  },
  {
    "country": "FR",
    "name": "Guénin",
    "lat": "47.90757",
    "lng": "-2.97941"
  },
  {
    "country": "FR",
    "name": "Guengat",
    "lat": "48.04193",
    "lng": "-4.2047"
  },
  {
    "country": "FR",
    "name": "Guénange",
    "lat": "49.29945",
    "lng": "6.20535"
  },
  {
    "country": "FR",
    "name": "Guémené-sur-Scorff",
    "lat": "48.06667",
    "lng": "-3.2"
  },
  {
    "country": "FR",
    "name": "Guémené-Penfao",
    "lat": "47.63333",
    "lng": "-1.83333"
  },
  {
    "country": "FR",
    "name": "Guémar",
    "lat": "48.18869",
    "lng": "7.39706"
  },
  {
    "country": "FR",
    "name": "Guégon",
    "lat": "47.93707",
    "lng": "-2.5645"
  },
  {
    "country": "FR",
    "name": "Guécélard",
    "lat": "47.87751",
    "lng": "0.1293"
  },
  {
    "country": "FR",
    "name": "Guebwiller",
    "lat": "47.91667",
    "lng": "7.2"
  },
  {
    "country": "FR",
    "name": "Guarbecque",
    "lat": "50.61162",
    "lng": "2.48895"
  },
  {
    "country": "FR",
    "name": "Gruson",
    "lat": "50.59583",
    "lng": "3.20777"
  },
  {
    "country": "FR",
    "name": "Gruissan",
    "lat": "43.10759",
    "lng": "3.08651"
  },
  {
    "country": "FR",
    "name": "Gruffy",
    "lat": "45.78717",
    "lng": "6.05504"
  },
  {
    "country": "FR",
    "name": "Gruchet-le-Valasse",
    "lat": "49.55466",
    "lng": "0.48684"
  },
  {
    "country": "FR",
    "name": "Grosseto-Prugna",
    "lat": "41.87097",
    "lng": "8.96403"
  },
  {
    "country": "FR",
    "name": "Gros-Réderching",
    "lat": "49.06835",
    "lng": "7.21914"
  },
  {
    "country": "FR",
    "name": "Groslay",
    "lat": "48.98561",
    "lng": "2.34736"
  },
  {
    "country": "FR",
    "name": "Grosbreuil",
    "lat": "46.53946",
    "lng": "-1.61655"
  },
  {
    "country": "FR",
    "name": "Grosbliederstroff",
    "lat": "49.15808",
    "lng": "7.02413"
  },
  {
    "country": "FR",
    "name": "Gron",
    "lat": "48.15967",
    "lng": "3.26345"
  },
  {
    "country": "FR",
    "name": "Groix",
    "lat": "47.63887",
    "lng": "-3.4543"
  },
  {
    "country": "FR",
    "name": "Groisy",
    "lat": "46.01835",
    "lng": "6.17083"
  },
  {
    "country": "FR",
    "name": "Groissiat",
    "lat": "46.22213",
    "lng": "5.60775"
  },
  {
    "country": "FR",
    "name": "Groffliers",
    "lat": "50.38444",
    "lng": "1.61474"
  },
  {
    "country": "FR",
    "name": "Grisy-Suisnes",
    "lat": "48.68538",
    "lng": "2.66781"
  },
  {
    "country": "FR",
    "name": "Grisolles",
    "lat": "43.8292",
    "lng": "1.29673"
  },
  {
    "country": "FR",
    "name": "Grimaud",
    "lat": "43.27049",
    "lng": "6.52491"
  },
  {
    "country": "FR",
    "name": "Grillon",
    "lat": "44.39152",
    "lng": "4.9304"
  },
  {
    "country": "FR",
    "name": "Grigny",
    "lat": "48.65412",
    "lng": "2.39343"
  },
  {
    "country": "FR",
    "name": "Grigny",
    "lat": "45.61128",
    "lng": "4.79589"
  },
  {
    "country": "FR",
    "name": "Grignon",
    "lat": "45.65122",
    "lng": "6.37795"
  },
  {
    "country": "FR",
    "name": "Grignols",
    "lat": "44.38842",
    "lng": "-0.04287"
  },
  {
    "country": "FR",
    "name": "Grignan",
    "lat": "44.41976",
    "lng": "4.90826"
  },
  {
    "country": "FR",
    "name": "Griesheim-sur-Souffel",
    "lat": "48.63591",
    "lng": "7.66923"
  },
  {
    "country": "FR",
    "name": "Griesheim-près-Molsheim",
    "lat": "48.50296",
    "lng": "7.53027"
  },
  {
    "country": "FR",
    "name": "Gries",
    "lat": "48.7537",
    "lng": "7.81403"
  },
  {
    "country": "FR",
    "name": "Grièges",
    "lat": "46.25583",
    "lng": "4.85134"
  },
  {
    "country": "FR",
    "name": "Grez-sur-Loing",
    "lat": "48.31754",
    "lng": "2.68848"
  },
  {
    "country": "FR",
    "name": "Grez-Neuville",
    "lat": "47.60288",
    "lng": "-0.68193"
  },
  {
    "country": "FR",
    "name": "Grézieu-la-Varenne",
    "lat": "45.74833",
    "lng": "4.69016"
  },
  {
    "country": "FR",
    "name": "Gretz-Armainvilliers",
    "lat": "48.7412",
    "lng": "2.73105"
  },
  {
    "country": "FR",
    "name": "Grésy-sur-Isère",
    "lat": "45.60172",
    "lng": "6.25509"
  },
  {
    "country": "FR",
    "name": "Grésy-sur-Aix",
    "lat": "45.72301",
    "lng": "5.93412"
  },
  {
    "country": "FR",
    "name": "Gresswiller",
    "lat": "48.53542",
    "lng": "7.43251"
  },
  {
    "country": "FR",
    "name": "Gréoux-les-Bains",
    "lat": "43.75753",
    "lng": "5.88169"
  },
  {
    "country": "FR",
    "name": "Grenoble",
    "lat": "45.17155",
    "lng": "5.72239"
  },
  {
    "country": "FR",
    "name": "Grendelbruch",
    "lat": "48.49272",
    "lng": "7.32239"
  },
  {
    "country": "FR",
    "name": "Grenay",
    "lat": "50.44962",
    "lng": "2.75168"
  },
  {
    "country": "FR",
    "name": "Grenay",
    "lat": "45.66317",
    "lng": "5.07987"
  },
  {
    "country": "FR",
    "name": "Grenade-sur-l’Adour",
    "lat": "43.77753",
    "lng": "-0.42961"
  },
  {
    "country": "FR",
    "name": "Grenade",
    "lat": "43.76667",
    "lng": "1.28333"
  },
  {
    "country": "FR",
    "name": "Gréasque",
    "lat": "43.4331",
    "lng": "5.54449"
  },
  {
    "country": "FR",
    "name": "Gray-la-Ville",
    "lat": "47.43932",
    "lng": "5.57252"
  },
  {
    "country": "FR",
    "name": "Gray",
    "lat": "47.44575",
    "lng": "5.59215"
  },
  {
    "country": "FR",
    "name": "Gravigny",
    "lat": "49.0531",
    "lng": "1.16962"
  },
  {
    "country": "FR",
    "name": "Graveson",
    "lat": "43.85134",
    "lng": "4.77189"
  },
  {
    "country": "FR",
    "name": "Gravelines",
    "lat": "50.98651",
    "lng": "2.12807"
  },
  {
    "country": "FR",
    "name": "Graulhet",
    "lat": "43.76688",
    "lng": "1.98938"
  },
  {
    "country": "FR",
    "name": "Gratentour",
    "lat": "43.7236",
    "lng": "1.43234"
  },
  {
    "country": "FR",
    "name": "Grasse",
    "lat": "43.66667",
    "lng": "6.91667"
  },
  {
    "country": "FR",
    "name": "Granville",
    "lat": "48.83792",
    "lng": "-1.59714"
  },
  {
    "country": "FR",
    "name": "Grans",
    "lat": "43.60357",
    "lng": "5.06881"
  },
  {
    "country": "FR",
    "name": "Granges-sur-Vologne",
    "lat": "48.14517",
    "lng": "6.79095"
  },
  {
    "country": "FR",
    "name": "Grane",
    "lat": "44.73333",
    "lng": "4.91667"
  },
  {
    "country": "FR",
    "name": "Grandvilliers",
    "lat": "49.66547",
    "lng": "1.94088"
  },
  {
    "country": "FR",
    "name": "Grandvillars",
    "lat": "47.53921",
    "lng": "6.96424"
  },
  {
    "country": "FR",
    "name": "Grandris",
    "lat": "46.03871",
    "lng": "4.47486"
  },
  {
    "country": "FR",
    "name": "Gallargues-le-Montueux",
    "lat": "43.71667",
    "lng": "4.16667"
  },
  {
    "country": "FR",
    "name": "Grandfresnoy",
    "lat": "49.37218",
    "lng": "2.65216"
  },
  {
    "country": "FR",
    "name": "Grand-Fougeray",
    "lat": "47.7239",
    "lng": "-1.7321"
  },
  {
    "country": "FR",
    "name": "Grand-Fort-Philippe",
    "lat": "50.99961",
    "lng": "2.10784"
  },
  {
    "country": "FR",
    "name": "Grandfontaine",
    "lat": "47.19763",
    "lng": "5.90079"
  },
  {
    "country": "FR",
    "name": "Grande-Synthe",
    "lat": "51.0154",
    "lng": "2.29975"
  },
  {
    "country": "FR",
    "name": "Grand-Couronne",
    "lat": "49.35563",
    "lng": "1.00647"
  },
  {
    "country": "FR",
    "name": "Grand-Charmont",
    "lat": "47.52674",
    "lng": "6.82604"
  },
  {
    "country": "FR",
    "name": "Grand-Champ",
    "lat": "47.75804",
    "lng": "-2.84635"
  },
  {
    "country": "FR",
    "name": "Grandcamp-Maisy",
    "lat": "49.38333",
    "lng": "-1.03333"
  },
  {
    "country": "FR",
    "name": "Grambois",
    "lat": "43.76187",
    "lng": "5.58725"
  },
  {
    "country": "FR",
    "name": "Gramat",
    "lat": "44.78075",
    "lng": "1.71957"
  },
  {
    "country": "FR",
    "name": "Grainville-sur-Odon",
    "lat": "49.13936",
    "lng": "-0.53046"
  },
  {
    "country": "FR",
    "name": "Grainville-la-Teinturière",
    "lat": "49.74773",
    "lng": "0.64048"
  },
  {
    "country": "FR",
    "name": "Gragnague",
    "lat": "43.68091",
    "lng": "1.58461"
  },
  {
    "country": "FR",
    "name": "Gradignan",
    "lat": "44.77262",
    "lng": "-0.61393"
  },
  {
    "country": "FR",
    "name": "Grâces",
    "lat": "48.55651",
    "lng": "-3.18533"
  },
  {
    "country": "FR",
    "name": "Graçay",
    "lat": "47.14371",
    "lng": "1.84733"
  },
  {
    "country": "FR",
    "name": "Grabels",
    "lat": "43.64797",
    "lng": "3.79865"
  },
  {
    "country": "FR",
    "name": "Goven",
    "lat": "48.00638",
    "lng": "-1.84629"
  },
  {
    "country": "FR",
    "name": "Gouzon",
    "lat": "46.19286",
    "lng": "2.23876"
  },
  {
    "country": "FR",
    "name": "Gouzeaucourt",
    "lat": "50.05606",
    "lng": "3.12351"
  },
  {
    "country": "FR",
    "name": "Gouy-sous-Bellonne",
    "lat": "50.31139",
    "lng": "3.05657"
  },
  {
    "country": "FR",
    "name": "Gouville-sur-Mer",
    "lat": "49.09611",
    "lng": "-1.57908"
  },
  {
    "country": "FR",
    "name": "Gouvieux",
    "lat": "49.18705",
    "lng": "2.41439"
  },
  {
    "country": "FR",
    "name": "Gouvernes",
    "lat": "48.86007",
    "lng": "2.69074"
  },
  {
    "country": "FR",
    "name": "Goussainville",
    "lat": "49.01367",
    "lng": "2.46595"
  },
  {
    "country": "FR",
    "name": "Gournay-sur-Marne",
    "lat": "48.86223",
    "lng": "2.58452"
  },
  {
    "country": "FR",
    "name": "Gournay-en-Bray",
    "lat": "49.48285",
    "lng": "1.72471"
  },
  {
    "country": "FR",
    "name": "Gourin",
    "lat": "48.13866",
    "lng": "-3.60755"
  },
  {
    "country": "FR",
    "name": "Gourdon",
    "lat": "44.73333",
    "lng": "1.38333"
  },
  {
    "country": "FR",
    "name": "Gourdan-Polignan",
    "lat": "43.07092",
    "lng": "0.57482"
  },
  {
    "country": "FR",
    "name": "Goult",
    "lat": "43.8608",
    "lng": "5.24247"
  },
  {
    "country": "FR",
    "name": "Gouézec",
    "lat": "48.16911",
    "lng": "-3.97277"
  },
  {
    "country": "FR",
    "name": "Gouesnou",
    "lat": "48.45267",
    "lng": "-4.46456"
  },
  {
    "country": "FR",
    "name": "Gouesnach",
    "lat": "47.9104",
    "lng": "-4.1145"
  },
  {
    "country": "FR",
    "name": "Goudelin",
    "lat": "48.60375",
    "lng": "-3.01842"
  },
  {
    "country": "FR",
    "name": "Goudargues",
    "lat": "44.21376",
    "lng": "4.46652"
  },
  {
    "country": "FR",
    "name": "Gouarec",
    "lat": "48.22725",
    "lng": "-3.17994"
  },
  {
    "country": "FR",
    "name": "Gouaix",
    "lat": "48.48539",
    "lng": "3.29336"
  },
  {
    "country": "FR",
    "name": "Gosné",
    "lat": "48.24674",
    "lng": "-1.46558"
  },
  {
    "country": "FR",
    "name": "Gosnay",
    "lat": "50.50622",
    "lng": "2.58904"
  },
  {
    "country": "FR",
    "name": "Gorze",
    "lat": "49.05236",
    "lng": "6.00072"
  },
  {
    "country": "FR",
    "name": "Gorron",
    "lat": "48.41095",
    "lng": "-0.81267"
  },
  {
    "country": "FR",
    "name": "Gorges",
    "lat": "47.09917",
    "lng": "-1.30024"
  },
  {
    "country": "FR",
    "name": "Gordes",
    "lat": "43.91237",
    "lng": "5.20089"
  },
  {
    "country": "FR",
    "name": "Gorcy",
    "lat": "49.53333",
    "lng": "5.7"
  },
  {
    "country": "FR",
    "name": "Gorbio",
    "lat": "43.78681",
    "lng": "7.4426"
  },
  {
    "country": "FR",
    "name": "Gontaud-de-Nogaret",
    "lat": "44.45",
    "lng": "0.3"
  },
  {
    "country": "FR",
    "name": "Gonneville-la-Mallet",
    "lat": "49.6395",
    "lng": "0.22245"
  },
  {
    "country": "FR",
    "name": "Gonnehem",
    "lat": "50.56061",
    "lng": "2.57277"
  },
  {
    "country": "FR",
    "name": "Gonfaron",
    "lat": "43.32067",
    "lng": "6.28806"
  },
  {
    "country": "FR",
    "name": "Gonesse",
    "lat": "48.98693",
    "lng": "2.44892"
  },
  {
    "country": "FR",
    "name": "Gondrin",
    "lat": "43.88466",
    "lng": "0.23737"
  },
  {
    "country": "FR",
    "name": "Gondreville",
    "lat": "48.69436",
    "lng": "5.96551"
  },
  {
    "country": "FR",
    "name": "Gondrecourt-le-Château",
    "lat": "48.51366",
    "lng": "5.51058"
  },
  {
    "country": "FR",
    "name": "Gondecourt",
    "lat": "50.54469",
    "lng": "2.98378"
  },
  {
    "country": "FR",
    "name": "Goncelin",
    "lat": "45.34453",
    "lng": "5.97892"
  },
  {
    "country": "FR",
    "name": "Gommegnies",
    "lat": "50.27155",
    "lng": "3.70625"
  },
  {
    "country": "FR",
    "name": "Gometz-le-Châtel",
    "lat": "48.67837",
    "lng": "2.13792"
  },
  {
    "country": "FR",
    "name": "Gometz-la-Ville",
    "lat": "48.67219",
    "lng": "2.12868"
  },
  {
    "country": "FR",
    "name": "Golbey",
    "lat": "48.19764",
    "lng": "6.43966"
  },
  {
    "country": "FR",
    "name": "Goincourt",
    "lat": "49.42614",
    "lng": "2.03621"
  },
  {
    "country": "FR",
    "name": "Gœulzin",
    "lat": "50.31667",
    "lng": "3.1"
  },
  {
    "country": "FR",
    "name": "Goetzenbruck",
    "lat": "48.97778",
    "lng": "7.3796"
  },
  {
    "country": "FR",
    "name": "Gœrsdorf",
    "lat": "48.95",
    "lng": "7.76667"
  },
  {
    "country": "FR",
    "name": "Godewaersvelde",
    "lat": "50.79399",
    "lng": "2.64456"
  },
  {
    "country": "FR",
    "name": "Goderville",
    "lat": "49.64566",
    "lng": "0.36593"
  },
  {
    "country": "FR",
    "name": "Glomel",
    "lat": "48.223",
    "lng": "-3.39696"
  },
  {
    "country": "FR",
    "name": "Gleizé",
    "lat": "45.99082",
    "lng": "4.70071"
  },
  {
    "country": "FR",
    "name": "Givry",
    "lat": "46.78202",
    "lng": "4.74262"
  },
  {
    "country": "FR",
    "name": "Givrand",
    "lat": "46.67083",
    "lng": "-1.88612"
  },
  {
    "country": "FR",
    "name": "Givors",
    "lat": "45.58415",
    "lng": "4.77256"
  },
  {
    "country": "FR",
    "name": "Givet",
    "lat": "50.13796",
    "lng": "4.82545"
  },
  {
    "country": "FR",
    "name": "Givenchy-en-Gohelle",
    "lat": "50.3908",
    "lng": "2.7732"
  },
  {
    "country": "FR",
    "name": "Gisors",
    "lat": "49.28178",
    "lng": "1.7801"
  },
  {
    "country": "FR",
    "name": "Giroussens",
    "lat": "43.76199",
    "lng": "1.77608"
  },
  {
    "country": "FR",
    "name": "Gironde-sur-Dropt",
    "lat": "44.58333",
    "lng": "-0.08333"
  },
  {
    "country": "FR",
    "name": "Giromagny",
    "lat": "47.74146",
    "lng": "6.82671"
  },
  {
    "country": "FR",
    "name": "Giraumont",
    "lat": "49.17313",
    "lng": "5.91159"
  },
  {
    "country": "FR",
    "name": "Ginestas",
    "lat": "43.26645",
    "lng": "2.87038"
  },
  {
    "country": "FR",
    "name": "Ginasservis",
    "lat": "43.67113",
    "lng": "5.84925"
  },
  {
    "country": "FR",
    "name": "Gimont",
    "lat": "43.62627",
    "lng": "0.87655"
  },
  {
    "country": "FR",
    "name": "Gilly-sur-Isère",
    "lat": "45.65917",
    "lng": "6.35096"
  },
  {
    "country": "FR",
    "name": "Gillonnay",
    "lat": "45.3937",
    "lng": "5.29586"
  },
  {
    "country": "FR",
    "name": "Gilley",
    "lat": "47.0474",
    "lng": "6.48257"
  },
  {
    "country": "FR",
    "name": "Gilette",
    "lat": "43.84788",
    "lng": "7.16349"
  },
  {
    "country": "FR",
    "name": "Gignac-la-Nerthe",
    "lat": "43.39145",
    "lng": "5.23348"
  },
  {
    "country": "FR",
    "name": "Gignac",
    "lat": "43.652",
    "lng": "3.5509"
  },
  {
    "country": "FR",
    "name": "Gigean",
    "lat": "43.50028",
    "lng": "3.71167"
  },
  {
    "country": "FR",
    "name": "Gif-sur-Yvette",
    "lat": "48.68333",
    "lng": "2.13333"
  },
  {
    "country": "FR",
    "name": "Gièvres",
    "lat": "47.27847",
    "lng": "1.66943"
  },
  {
    "country": "FR",
    "name": "Gières",
    "lat": "45.18273",
    "lng": "5.79179"
  },
  {
    "country": "FR",
    "name": "Gien",
    "lat": "47.69332",
    "lng": "2.63094"
  },
  {
    "country": "FR",
    "name": "Gidy",
    "lat": "47.98539",
    "lng": "1.83816"
  },
  {
    "country": "FR",
    "name": "Giberville",
    "lat": "49.18158",
    "lng": "-0.28386"
  },
  {
    "country": "FR",
    "name": "Ghyvelde",
    "lat": "51.05275",
    "lng": "2.52642"
  },
  {
    "country": "FR",
    "name": "Ghisonaccia",
    "lat": "42.01621",
    "lng": "9.40412"
  },
  {
    "country": "FR",
    "name": "Gex",
    "lat": "46.33333",
    "lng": "6.06667"
  },
  {
    "country": "FR",
    "name": "Gevrey-Chambertin",
    "lat": "47.22614",
    "lng": "4.96806"
  },
  {
    "country": "FR",
    "name": "Gévezé",
    "lat": "48.21933",
    "lng": "-1.78952"
  },
  {
    "country": "FR",
    "name": "Geudertheim",
    "lat": "48.72415",
    "lng": "7.75188"
  },
  {
    "country": "FR",
    "name": "Gétigné",
    "lat": "47.0765",
    "lng": "-1.2481"
  },
  {
    "country": "FR",
    "name": "Gestel",
    "lat": "47.80361",
    "lng": "-3.44245"
  },
  {
    "country": "FR",
    "name": "Gesté",
    "lat": "47.18179",
    "lng": "-1.10917"
  },
  {
    "country": "FR",
    "name": "Gespunsart",
    "lat": "49.82143",
    "lng": "4.82926"
  },
  {
    "country": "FR",
    "name": "Gerzat",
    "lat": "45.82432",
    "lng": "3.14404"
  },
  {
    "country": "FR",
    "name": "Gerstheim",
    "lat": "48.38215",
    "lng": "7.70395"
  },
  {
    "country": "FR",
    "name": "Gergy",
    "lat": "46.87557",
    "lng": "4.94527"
  },
  {
    "country": "FR",
    "name": "Gerde",
    "lat": "43.05567",
    "lng": "0.16688"
  },
  {
    "country": "FR",
    "name": "Gerbéviller",
    "lat": "48.49462",
    "lng": "6.51006"
  },
  {
    "country": "FR",
    "name": "Gérardmer",
    "lat": "48.07346",
    "lng": "6.87787"
  },
  {
    "country": "FR",
    "name": "Ger",
    "lat": "43.25",
    "lng": "-0.05"
  },
  {
    "country": "FR",
    "name": "Gentilly",
    "lat": "48.81294",
    "lng": "2.3417"
  },
  {
    "country": "FR",
    "name": "Gensac-la-Pallue",
    "lat": "45.65",
    "lng": "-0.25"
  },
  {
    "country": "FR",
    "name": "Gennevilliers",
    "lat": "48.93333",
    "lng": "2.3"
  },
  {
    "country": "FR",
    "name": "Gennes",
    "lat": "47.3401",
    "lng": "-0.23149"
  },
  {
    "country": "FR",
    "name": "Genlis",
    "lat": "47.24203",
    "lng": "5.22415"
  },
  {
    "country": "FR",
    "name": "Génissieux",
    "lat": "45.08426",
    "lng": "5.08337"
  },
  {
    "country": "FR",
    "name": "Génissac",
    "lat": "44.85",
    "lng": "-0.25"
  },
  {
    "country": "FR",
    "name": "Genillé",
    "lat": "47.18333",
    "lng": "1.1"
  },
  {
    "country": "FR",
    "name": "Générac",
    "lat": "43.7283",
    "lng": "4.35"
  },
  {
    "country": "FR",
    "name": "Génelard",
    "lat": "46.58119",
    "lng": "4.23619"
  },
  {
    "country": "FR",
    "name": "Genech",
    "lat": "50.53122",
    "lng": "3.21651"
  },
  {
    "country": "FR",
    "name": "Genay",
    "lat": "45.89764",
    "lng": "4.83729"
  },
  {
    "country": "FR",
    "name": "Genas",
    "lat": "45.73215",
    "lng": "4.99943"
  },
  {
    "country": "FR",
    "name": "Gémozac",
    "lat": "45.56896",
    "lng": "-0.67574"
  },
  {
    "country": "FR",
    "name": "Gémenos",
    "lat": "43.29751",
    "lng": "5.62843"
  },
  {
    "country": "FR",
    "name": "Gelos",
    "lat": "43.28333",
    "lng": "-0.36667"
  },
  {
    "country": "FR",
    "name": "Gelles",
    "lat": "45.76937",
    "lng": "2.76347"
  },
  {
    "country": "FR",
    "name": "Geispolsheim",
    "lat": "48.51603",
    "lng": "7.64825"
  },
  {
    "country": "FR",
    "name": "Gazeran",
    "lat": "48.63264",
    "lng": "1.77149"
  },
  {
    "country": "FR",
    "name": "Gavray",
    "lat": "48.91108",
    "lng": "-1.35059"
  },
  {
    "country": "FR",
    "name": "Gauriaguet",
    "lat": "45.03904",
    "lng": "-0.39191"
  },
  {
    "country": "FR",
    "name": "Gauchy",
    "lat": "49.82765",
    "lng": "3.27371"
  },
  {
    "country": "FR",
    "name": "Gattières",
    "lat": "43.76037",
    "lng": "7.17799"
  },
  {
    "country": "FR",
    "name": "Gasville-Oisème",
    "lat": "48.46973",
    "lng": "1.53843"
  },
  {
    "country": "FR",
    "name": "Gassin",
    "lat": "43.22874",
    "lng": "6.58481"
  },
  {
    "country": "FR",
    "name": "Gasny",
    "lat": "49.09184",
    "lng": "1.60336"
  },
  {
    "country": "FR",
    "name": "Garons",
    "lat": "43.76861",
    "lng": "4.42753"
  },
  {
    "country": "FR",
    "name": "Garnay",
    "lat": "48.70489",
    "lng": "1.33706"
  },
  {
    "country": "FR",
    "name": "Garlin",
    "lat": "43.55927",
    "lng": "-0.27321"
  },
  {
    "country": "FR",
    "name": "Garidech",
    "lat": "43.71076",
    "lng": "1.56036"
  },
  {
    "country": "FR",
    "name": "Garges-lès-Gonesse",
    "lat": "48.96791",
    "lng": "2.39781"
  },
  {
    "country": "FR",
    "name": "Gargenville",
    "lat": "48.98802",
    "lng": "1.81176"
  },
  {
    "country": "FR",
    "name": "Gargas",
    "lat": "43.90199",
    "lng": "5.35781"
  },
  {
    "country": "FR",
    "name": "Garéoult",
    "lat": "43.32858",
    "lng": "6.04594"
  },
  {
    "country": "FR",
    "name": "Garennes-sur-Eure",
    "lat": "48.91116",
    "lng": "1.43836"
  },
  {
    "country": "FR",
    "name": "Gardouch",
    "lat": "43.39096",
    "lng": "1.68313"
  },
  {
    "country": "FR",
    "name": "Gardonne",
    "lat": "44.83333",
    "lng": "0.35"
  },
  {
    "country": "FR",
    "name": "Gardanne",
    "lat": "43.45491",
    "lng": "5.46913"
  },
  {
    "country": "FR",
    "name": "Garchizy",
    "lat": "47.04786",
    "lng": "3.09625"
  },
  {
    "country": "FR",
    "name": "Garches",
    "lat": "48.84226",
    "lng": "2.18232"
  },
  {
    "country": "FR",
    "name": "Garat",
    "lat": "45.63333",
    "lng": "0.26667"
  },
  {
    "country": "FR",
    "name": "Garancières",
    "lat": "48.82271",
    "lng": "1.75512"
  },
  {
    "country": "FR",
    "name": "Gap",
    "lat": "44.56151",
    "lng": "6.08106"
  },
  {
    "country": "FR",
    "name": "Gannat",
    "lat": "46.10015",
    "lng": "3.19886"
  },
  {
    "country": "FR",
    "name": "Ganges",
    "lat": "43.9338",
    "lng": "3.70784"
  },
  {
    "country": "FR",
    "name": "Gandrange",
    "lat": "49.27133",
    "lng": "6.12536"
  },
  {
    "country": "FR",
    "name": "Gan",
    "lat": "43.23333",
    "lng": "-0.38333"
  },
  {
    "country": "FR",
    "name": "Gambsheim",
    "lat": "48.69209",
    "lng": "7.88286"
  },
  {
    "country": "FR",
    "name": "Gambais",
    "lat": "48.77351",
    "lng": "1.67196"
  },
  {
    "country": "FR",
    "name": "Gamaches",
    "lat": "49.98615",
    "lng": "1.55624"
  },
  {
    "country": "FR",
    "name": "Galluis",
    "lat": "48.79657",
    "lng": "1.79414"
  },
  {
    "country": "FR",
    "name": "Gallardon",
    "lat": "48.52622",
    "lng": "1.69307"
  },
  {
    "country": "FR",
    "name": "Galgon",
    "lat": "44.98333",
    "lng": "-0.26667"
  },
  {
    "country": "FR",
    "name": "Gainneville",
    "lat": "49.51845",
    "lng": "0.26164"
  },
  {
    "country": "FR",
    "name": "Gaillon",
    "lat": "49.16104",
    "lng": "1.34016"
  },
  {
    "country": "FR",
    "name": "Gaillefontaine",
    "lat": "49.65371",
    "lng": "1.61547"
  },
  {
    "country": "FR",
    "name": "Gaillard",
    "lat": "46.1853",
    "lng": "6.20693"
  },
  {
    "country": "FR",
    "name": "Gaillan-en-Médoc",
    "lat": "45.32133",
    "lng": "-0.95794"
  },
  {
    "country": "FR",
    "name": "Gaillac-Toulza",
    "lat": "43.25536",
    "lng": "1.47141"
  },
  {
    "country": "FR",
    "name": "Gaillac",
    "lat": "43.9016",
    "lng": "1.89686"
  },
  {
    "country": "FR",
    "name": "Gagny",
    "lat": "48.88333",
    "lng": "2.53333"
  },
  {
    "country": "FR",
    "name": "Gagnac-sur-Garonne",
    "lat": "43.6999",
    "lng": "1.37535"
  },
  {
    "country": "FR",
    "name": "Gaël",
    "lat": "48.13209",
    "lng": "-2.22267"
  },
  {
    "country": "FR",
    "name": "Gacé",
    "lat": "48.79344",
    "lng": "0.29624"
  },
  {
    "country": "FR",
    "name": "Gabarret",
    "lat": "43.98779",
    "lng": "0.00978"
  },
  {
    "country": "FR",
    "name": "Fuveau",
    "lat": "43.45578",
    "lng": "5.56149"
  },
  {
    "country": "FR",
    "name": "Fussy",
    "lat": "47.14372",
    "lng": "2.42953"
  },
  {
    "country": "FR",
    "name": "Furiani",
    "lat": "42.65814",
    "lng": "9.41469"
  },
  {
    "country": "FR",
    "name": "Furdenheim",
    "lat": "48.61129",
    "lng": "7.561"
  },
  {
    "country": "FR",
    "name": "Fumel",
    "lat": "44.49862",
    "lng": "0.96506"
  },
  {
    "country": "FR",
    "name": "Fumay",
    "lat": "49.99132",
    "lng": "4.70771"
  },
  {
    "country": "FR",
    "name": "Fublaines",
    "lat": "48.93816",
    "lng": "2.93655"
  },
  {
    "country": "FR",
    "name": "Fruges",
    "lat": "50.51501",
    "lng": "2.13292"
  },
  {
    "country": "FR",
    "name": "Frouzins",
    "lat": "43.51482",
    "lng": "1.32523"
  },
  {
    "country": "FR",
    "name": "Frouard",
    "lat": "48.75998",
    "lng": "6.13163"
  },
  {
    "country": "FR",
    "name": "Frotey-lès-Vesoul",
    "lat": "47.62078",
    "lng": "6.18831"
  },
  {
    "country": "FR",
    "name": "Frossay",
    "lat": "47.24451",
    "lng": "-1.93557"
  },
  {
    "country": "FR",
    "name": "Frontonas",
    "lat": "45.64782",
    "lng": "5.18341"
  },
  {
    "country": "FR",
    "name": "Fronton",
    "lat": "43.83931",
    "lng": "1.38931"
  },
  {
    "country": "FR",
    "name": "Frontignan",
    "lat": "43.44848",
    "lng": "3.754"
  },
  {
    "country": "FR",
    "name": "Frontenex",
    "lat": "45.63333",
    "lng": "6.31667"
  },
  {
    "country": "FR",
    "name": "Frontenay-Rohan-Rohan",
    "lat": "46.25276",
    "lng": "-0.53833"
  },
  {
    "country": "FR",
    "name": "Fronsac",
    "lat": "44.91667",
    "lng": "-0.26667"
  },
  {
    "country": "FR",
    "name": "Froncles",
    "lat": "48.29756",
    "lng": "5.14586"
  },
  {
    "country": "FR",
    "name": "Fromelennes",
    "lat": "50.12333",
    "lng": "4.85952"
  },
  {
    "country": "FR",
    "name": "Froidfond",
    "lat": "46.86898",
    "lng": "-1.7574"
  },
  {
    "country": "FR",
    "name": "Froideconche",
    "lat": "47.82121",
    "lng": "6.41523"
  },
  {
    "country": "FR",
    "name": "Froges",
    "lat": "45.27359",
    "lng": "5.92159"
  },
  {
    "country": "FR",
    "name": "Friville-Escarbotin",
    "lat": "50.08602",
    "lng": "1.5456"
  },
  {
    "country": "FR",
    "name": "Frignicourt",
    "lat": "48.69966",
    "lng": "4.59153"
  },
  {
    "country": "FR",
    "name": "Freyming-Merlebach",
    "lat": "49.15",
    "lng": "6.78333"
  },
  {
    "country": "FR",
    "name": "Frévent",
    "lat": "50.27608",
    "lng": "2.28725"
  },
  {
    "country": "FR",
    "name": "Fretin",
    "lat": "50.55745",
    "lng": "3.13668"
  },
  {
    "country": "FR",
    "name": "Fréthun",
    "lat": "50.91729",
    "lng": "1.82505"
  },
  {
    "country": "FR",
    "name": "Fresse-sur-Moselle",
    "lat": "47.87589",
    "lng": "6.78589"
  },
  {
    "country": "FR",
    "name": "Fressenneville",
    "lat": "50.06838",
    "lng": "1.57816"
  },
  {
    "country": "FR",
    "name": "Fresnoy-le-Grand",
    "lat": "49.94757",
    "lng": "3.41841"
  },
  {
    "country": "FR",
    "name": "Fresnes-sur-Escaut",
    "lat": "50.43382",
    "lng": "3.57752"
  },
  {
    "country": "FR",
    "name": "Fresnes",
    "lat": "48.75568",
    "lng": "2.32241"
  },
  {
    "country": "FR",
    "name": "Fresnay-sur-Sarthe",
    "lat": "48.28199",
    "lng": "0.02288"
  },
  {
    "country": "FR",
    "name": "Frépillon",
    "lat": "49.05216",
    "lng": "2.20528"
  },
  {
    "country": "FR",
    "name": "Freneuse",
    "lat": "49.04832",
    "lng": "1.60168"
  },
  {
    "country": "FR",
    "name": "Frelinghien",
    "lat": "50.71667",
    "lng": "2.93333"
  },
  {
    "country": "FR",
    "name": "Fréland",
    "lat": "48.17215",
    "lng": "7.19167"
  },
  {
    "country": "FR",
    "name": "Fréjus",
    "lat": "43.43286",
    "lng": "6.73524"
  },
  {
    "country": "FR",
    "name": "Fréjairolles",
    "lat": "43.88094",
    "lng": "2.23151"
  },
  {
    "country": "FR",
    "name": "Freigné",
    "lat": "47.54858",
    "lng": "-1.12274"
  },
  {
    "country": "FR",
    "name": "Frasne",
    "lat": "46.85641",
    "lng": "6.1594"
  },
  {
    "country": "FR",
    "name": "Frans",
    "lat": "45.99228",
    "lng": "4.77582"
  },
  {
    "country": "FR",
    "name": "Franois",
    "lat": "47.23055",
    "lng": "5.92869"
  },
  {
    "country": "FR",
    "name": "Frangy",
    "lat": "46.0187",
    "lng": "5.93313"
  },
  {
    "country": "FR",
    "name": "Franconville",
    "lat": "48.98333",
    "lng": "2.23333"
  },
  {
    "country": "FR",
    "name": "Francheville",
    "lat": "48.78647",
    "lng": "0.84962"
  },
  {
    "country": "FR",
    "name": "Francheville",
    "lat": "45.73879",
    "lng": "4.77219"
  },
  {
    "country": "FR",
    "name": "Francheleins",
    "lat": "46.0744",
    "lng": "4.8092"
  },
  {
    "country": "FR",
    "name": "Fraize",
    "lat": "48.1866",
    "lng": "6.99787"
  },
  {
    "country": "FR",
    "name": "Fraisses",
    "lat": "45.38333",
    "lng": "4.25"
  },
  {
    "country": "FR",
    "name": "Fraisans",
    "lat": "47.14857",
    "lng": "5.76051"
  },
  {
    "country": "FR",
    "name": "Frahier-et-Chatebier",
    "lat": "47.66667",
    "lng": "6.75"
  },
  {
    "country": "FR",
    "name": "Foussais-Payré",
    "lat": "46.53333",
    "lng": "-0.68333"
  },
  {
    "country": "FR",
    "name": "Fourqueux",
    "lat": "48.88693",
    "lng": "2.06367"
  },
  {
    "country": "FR",
    "name": "Fourques-sur-Garonne",
    "lat": "44.44798",
    "lng": "0.15703"
  },
  {
    "country": "FR",
    "name": "Fourques",
    "lat": "43.6945",
    "lng": "4.60932"
  },
  {
    "country": "FR",
    "name": "Fournes-en-Weppes",
    "lat": "50.58497",
    "lng": "2.88793"
  },
  {
    "country": "FR",
    "name": "Fourmies",
    "lat": "50.01532",
    "lng": "4.04784"
  },
  {
    "country": "FR",
    "name": "Fourchambault",
    "lat": "47.01667",
    "lng": "3.08333"
  },
  {
    "country": "FR",
    "name": "Fouras",
    "lat": "45.98736",
    "lng": "-1.09275"
  },
  {
    "country": "FR",
    "name": "Fouquières-lès-Lens",
    "lat": "50.42842",
    "lng": "2.91321"
  },
  {
    "country": "FR",
    "name": "Fouquières-lès-Béthune",
    "lat": "50.51534",
    "lng": "2.60999"
  },
  {
    "country": "FR",
    "name": "Fouquereuil",
    "lat": "50.51885",
    "lng": "2.60024"
  },
  {
    "country": "FR",
    "name": "Foulayronnes",
    "lat": "44.24029",
    "lng": "0.64516"
  },
  {
    "country": "FR",
    "name": "Fouillard",
    "lat": "48.1582",
    "lng": "-1.57915"
  },
  {
    "country": "FR",
    "name": "Fougerolles-du-Plessis",
    "lat": "48.47424",
    "lng": "-0.97255"
  },
  {
    "country": "FR",
    "name": "Fougerolles",
    "lat": "47.88542",
    "lng": "6.40454"
  },
  {
    "country": "FR",
    "name": "Fougères",
    "lat": "48.35",
    "lng": "-1.2"
  },
  {
    "country": "FR",
    "name": "Foug",
    "lat": "48.68375",
    "lng": "5.78691"
  },
  {
    "country": "FR",
    "name": "Fouesnant",
    "lat": "47.89187",
    "lng": "-4.01484"
  },
  {
    "country": "FR",
    "name": "Foucherans",
    "lat": "47.08094",
    "lng": "5.45503"
  },
  {
    "country": "FR",
    "name": "Foucarmont",
    "lat": "49.84682",
    "lng": "1.56899"
  },
  {
    "country": "FR",
    "name": "Fos-sur-Mer",
    "lat": "43.43774",
    "lng": "4.94457"
  },
  {
    "country": "FR",
    "name": "Fosses",
    "lat": "49.09808",
    "lng": "2.50957"
  },
  {
    "country": "FR",
    "name": "Fortschwihr",
    "lat": "48.08647",
    "lng": "7.45054"
  },
  {
    "country": "FR",
    "name": "Fort-Mardyck",
    "lat": "51.02899",
    "lng": "2.30724"
  },
  {
    "country": "FR",
    "name": "Fort-Mahon-Plage",
    "lat": "50.33955",
    "lng": "1.55984"
  },
  {
    "country": "FR",
    "name": "Fors",
    "lat": "46.2357",
    "lng": "-0.40904"
  },
  {
    "country": "FR",
    "name": "Formerie",
    "lat": "49.64928",
    "lng": "1.73106"
  },
  {
    "country": "FR",
    "name": "Forges-les-Eaux",
    "lat": "49.61391",
    "lng": "1.54449"
  },
  {
    "country": "FR",
    "name": "Forges-les-Bains",
    "lat": "48.62942",
    "lng": "2.10264"
  },
  {
    "country": "FR",
    "name": "Forest-sur-Marque",
    "lat": "50.63341",
    "lng": "3.18939"
  },
  {
    "country": "FR",
    "name": "Forcalquier",
    "lat": "43.96667",
    "lng": "5.78333"
  },
  {
    "country": "FR",
    "name": "Forcalqueiret",
    "lat": "43.33471",
    "lng": "6.08238"
  },
  {
    "country": "FR",
    "name": "Forbach",
    "lat": "49.18333",
    "lng": "6.9"
  },
  {
    "country": "FR",
    "name": "Fontvieille",
    "lat": "43.72806",
    "lng": "4.70953"
  },
  {
    "country": "FR",
    "name": "Font-Romeu-Odeillo-Via",
    "lat": "42.50552",
    "lng": "2.04011"
  },
  {
    "country": "FR",
    "name": "Fontoy",
    "lat": "49.35597",
    "lng": "5.9925"
  },
  {
    "country": "FR",
    "name": "Fontevraud-l'Abbaye",
    "lat": "47.18333",
    "lng": "0.05"
  },
  {
    "country": "FR",
    "name": "Fontenilles",
    "lat": "43.55286",
    "lng": "1.19096"
  },
  {
    "country": "FR",
    "name": "Fontenay-Trésigny",
    "lat": "48.70647",
    "lng": "2.87047"
  },
  {
    "country": "FR",
    "name": "Fontenay-sur-Loing",
    "lat": "48.10365",
    "lng": "2.77542"
  },
  {
    "country": "FR",
    "name": "Fontenay-sous-Bois",
    "lat": "48.85442",
    "lng": "2.48268"
  },
  {
    "country": "FR",
    "name": "Fontenay-lès-Briis",
    "lat": "48.61962",
    "lng": "2.15276"
  },
  {
    "country": "FR",
    "name": "Fontenay-le-Marmion",
    "lat": "49.09346",
    "lng": "-0.35294"
  },
  {
    "country": "FR",
    "name": "Fontenay-le-Fleury",
    "lat": "48.81253",
    "lng": "2.04863"
  },
  {
    "country": "FR",
    "name": "Fontenay-le-Comte",
    "lat": "46.46667",
    "lng": "-0.81667"
  },
  {
    "country": "FR",
    "name": "Fontenay-en-Parisis",
    "lat": "49.05371",
    "lng": "2.45156"
  },
  {
    "country": "FR",
    "name": "Fontenay-aux-Roses",
    "lat": "48.79325",
    "lng": "2.29275"
  },
  {
    "country": "FR",
    "name": "Fontenay",
    "lat": "49.55993",
    "lng": "0.18391"
  },
  {
    "country": "FR",
    "name": "Fontcouverte",
    "lat": "45.76708",
    "lng": "-0.58682"
  },
  {
    "country": "FR",
    "name": "Fontannes",
    "lat": "45.30149",
    "lng": "3.76366"
  },
  {
    "country": "FR",
    "name": "Fontanil-Cornillon",
    "lat": "45.24808",
    "lng": "5.66434"
  },
  {
    "country": "FR",
    "name": "Fontaines-sur-Saône",
    "lat": "45.83377",
    "lng": "4.84834"
  },
  {
    "country": "FR",
    "name": "Fontaines-Saint-Martin",
    "lat": "45.84478",
    "lng": "4.85489"
  },
  {
    "country": "FR",
    "name": "Fontaines",
    "lat": "46.84905",
    "lng": "4.77036"
  },
  {
    "country": "FR",
    "name": "Fontaine-Notre-Dame",
    "lat": "50.16681",
    "lng": "3.15812"
  },
  {
    "country": "FR",
    "name": "Fontaine-lès-Luxeuil",
    "lat": "47.85592",
    "lng": "6.33482"
  },
  {
    "country": "FR",
    "name": "Fontaine-lès-Dijon",
    "lat": "47.34238",
    "lng": "5.02007"
  },
  {
    "country": "FR",
    "name": "Fontaine-le-Dun",
    "lat": "49.81182",
    "lng": "0.85095"
  },
  {
    "country": "FR",
    "name": "Fontaine-le-Comte",
    "lat": "46.53217",
    "lng": "0.26176"
  },
  {
    "country": "FR",
    "name": "Fontaine-le-Bourg",
    "lat": "49.56451",
    "lng": "1.16391"
  },
  {
    "country": "FR",
    "name": "Fontaine-la-Mallet",
    "lat": "49.536",
    "lng": "0.14625"
  },
  {
    "country": "FR",
    "name": "Fontaine-la-Guyon",
    "lat": "48.4727",
    "lng": "1.31417"
  },
  {
    "country": "FR",
    "name": "Fontaine-Étoupefour",
    "lat": "49.146",
    "lng": "-0.45522"
  },
  {
    "country": "FR",
    "name": "Fontainebleau",
    "lat": "48.4",
    "lng": "2.7"
  },
  {
    "country": "FR",
    "name": "Fontaine-au-Pire",
    "lat": "50.1325",
    "lng": "3.37667"
  },
  {
    "country": "FR",
    "name": "Fontaine",
    "lat": "45.19839",
    "lng": "5.68265"
  },
  {
    "country": "FR",
    "name": "Fonsorbes",
    "lat": "43.53524",
    "lng": "1.22937"
  },
  {
    "country": "FR",
    "name": "Fondettes",
    "lat": "47.4035",
    "lng": "0.59686"
  },
  {
    "country": "FR",
    "name": "Fonbeauzard",
    "lat": "43.6783",
    "lng": "1.4344"
  },
  {
    "country": "FR",
    "name": "Folschviller",
    "lat": "49.07732",
    "lng": "6.68358"
  },
  {
    "country": "FR",
    "name": "Follainville-Dennemont",
    "lat": "49.02194",
    "lng": "1.71331"
  },
  {
    "country": "FR",
    "name": "Folkling",
    "lat": "49.14756",
    "lng": "6.89482"
  },
  {
    "country": "FR",
    "name": "Folembray",
    "lat": "49.54334",
    "lng": "3.29119"
  },
  {
    "country": "FR",
    "name": "Foix",
    "lat": "42.96046",
    "lng": "1.60787"
  },
  {
    "country": "FR",
    "name": "Foissiat",
    "lat": "46.37008",
    "lng": "5.17573"
  },
  {
    "country": "FR",
    "name": "Foëcy",
    "lat": "47.17618",
    "lng": "2.16257"
  },
  {
    "country": "FR",
    "name": "Flourens",
    "lat": "43.59273",
    "lng": "1.56259"
  },
  {
    "country": "FR",
    "name": "Florensac",
    "lat": "43.38301",
    "lng": "3.46638"
  },
  {
    "country": "FR",
    "name": "Florange",
    "lat": "49.32373",
    "lng": "6.1212"
  },
  {
    "country": "FR",
    "name": "Florac",
    "lat": "44.31667",
    "lng": "3.6"
  },
  {
    "country": "FR",
    "name": "Floirac",
    "lat": "44.83238",
    "lng": "-0.51411"
  },
  {
    "country": "FR",
    "name": "Floing",
    "lat": "49.72216",
    "lng": "4.92947"
  },
  {
    "country": "FR",
    "name": "Flogny-la-Chapelle",
    "lat": "47.95",
    "lng": "3.86667"
  },
  {
    "country": "FR",
    "name": "Flize",
    "lat": "49.69875",
    "lng": "4.77171"
  },
  {
    "country": "FR",
    "name": "Flixecourt",
    "lat": "50.01465",
    "lng": "2.08095"
  },
  {
    "country": "FR",
    "name": "Flins-sur-Seine",
    "lat": "48.96523",
    "lng": "1.87314"
  },
  {
    "country": "FR",
    "name": "Flines-lez-Raches",
    "lat": "50.41667",
    "lng": "3.18333"
  },
  {
    "country": "FR",
    "name": "Flines-lès-Mortagne",
    "lat": "50.50281",
    "lng": "3.46495"
  },
  {
    "country": "FR",
    "name": "Fléville-devant-Nancy",
    "lat": "48.62493",
    "lng": "6.20499"
  },
  {
    "country": "FR",
    "name": "Fleury-sur-Orne",
    "lat": "49.14851",
    "lng": "-0.37508"
  },
  {
    "country": "FR",
    "name": "Fleury-sur-Andelle",
    "lat": "49.36176",
    "lng": "1.35599"
  },
  {
    "country": "FR",
    "name": "Fleury-Mérogis",
    "lat": "48.6373",
    "lng": "2.36378"
  },
  {
    "country": "FR",
    "name": "Fleury-les-Aubrais",
    "lat": "47.93328",
    "lng": "1.91811"
  },
  {
    "country": "FR",
    "name": "Fleury-la-Vallée",
    "lat": "47.86672",
    "lng": "3.44908"
  },
  {
    "country": "FR",
    "name": "Fleury",
    "lat": "49.04181",
    "lng": "6.19329"
  },
  {
    "country": "FR",
    "name": "Fleury",
    "lat": "43.23095",
    "lng": "3.13745"
  },
  {
    "country": "FR",
    "name": "Fleurines",
    "lat": "49.25901",
    "lng": "2.58385"
  },
  {
    "country": "FR",
    "name": "Fleurieu-sur-Saône",
    "lat": "45.86381",
    "lng": "4.84455"
  },
  {
    "country": "FR",
    "name": "Fleurie",
    "lat": "46.19208",
    "lng": "4.69733"
  },
  {
    "country": "FR",
    "name": "Fleurey-sur-Ouche",
    "lat": "47.31182",
    "lng": "4.85911"
  },
  {
    "country": "FR",
    "name": "Fleurbaix",
    "lat": "50.65061",
    "lng": "2.83305"
  },
  {
    "country": "FR",
    "name": "Fleurance",
    "lat": "43.84824",
    "lng": "0.66302"
  },
  {
    "country": "FR",
    "name": "Flesselles",
    "lat": "50.00202",
    "lng": "2.26119"
  },
  {
    "country": "FR",
    "name": "Flers-en-Escrebieux",
    "lat": "50.3979",
    "lng": "3.06038"
  },
  {
    "country": "FR",
    "name": "Flers",
    "lat": "48.73722",
    "lng": "-0.57466"
  },
  {
    "country": "FR",
    "name": "Fléac",
    "lat": "45.66667",
    "lng": "0.1"
  },
  {
    "country": "FR",
    "name": "Flayosc",
    "lat": "43.53253",
    "lng": "6.39401"
  },
  {
    "country": "FR",
    "name": "Flaxlanden",
    "lat": "47.69493",
    "lng": "7.31343"
  },
  {
    "country": "FR",
    "name": "Flavy-le-Martel",
    "lat": "49.71299",
    "lng": "3.1915"
  },
  {
    "country": "FR",
    "name": "Flavin",
    "lat": "44.2889",
    "lng": "2.60513"
  },
  {
    "country": "FR",
    "name": "Flavigny-sur-Moselle",
    "lat": "48.56412",
    "lng": "6.19113"
  },
  {
    "country": "FR",
    "name": "Flaviac",
    "lat": "44.74777",
    "lng": "4.67434"
  },
  {
    "country": "FR",
    "name": "Flassans-sur-Issole",
    "lat": "43.3702",
    "lng": "6.22363"
  },
  {
    "country": "FR",
    "name": "Flamanville",
    "lat": "49.53274",
    "lng": "-1.8656"
  },
  {
    "country": "FR",
    "name": "Fitz-James",
    "lat": "49.39113",
    "lng": "2.4307"
  },
  {
    "country": "FR",
    "name": "Fitilieu",
    "lat": "45.54744",
    "lng": "5.56194"
  },
  {
    "country": "FR",
    "name": "Fismes",
    "lat": "49.30773",
    "lng": "3.68607"
  },
  {
    "country": "FR",
    "name": "Firminy",
    "lat": "45.38732",
    "lng": "4.29074"
  },
  {
    "country": "FR",
    "name": "Firmi",
    "lat": "44.54106",
    "lng": "2.30764"
  },
  {
    "country": "FR",
    "name": "Finhan",
    "lat": "43.91335",
    "lng": "1.2212"
  },
  {
    "country": "FR",
    "name": "Fillinges",
    "lat": "46.15944",
    "lng": "6.34237"
  },
  {
    "country": "FR",
    "name": "Fillé",
    "lat": "47.90011",
    "lng": "0.12543"
  },
  {
    "country": "FR",
    "name": "Figeac",
    "lat": "44.6",
    "lng": "2.03333"
  },
  {
    "country": "FR",
    "name": "Figanières",
    "lat": "43.57",
    "lng": "6.5"
  },
  {
    "country": "FR",
    "name": "Feyzin",
    "lat": "45.66728",
    "lng": "4.85971"
  },
  {
    "country": "FR",
    "name": "Feytiat",
    "lat": "45.80905",
    "lng": "1.33033"
  },
  {
    "country": "FR",
    "name": "Feurs",
    "lat": "45.73988",
    "lng": "4.22706"
  },
  {
    "country": "FR",
    "name": "Feuquières-en-Vimeu",
    "lat": "50.05982",
    "lng": "1.60465"
  },
  {
    "country": "FR",
    "name": "Feuquières",
    "lat": "49.64677",
    "lng": "1.84784"
  },
  {
    "country": "FR",
    "name": "Feuchy",
    "lat": "50.29439",
    "lng": "2.84335"
  },
  {
    "country": "FR",
    "name": "Feucherolles",
    "lat": "48.87002",
    "lng": "1.97402"
  },
  {
    "country": "FR",
    "name": "Féternes",
    "lat": "46.35259",
    "lng": "6.5639"
  },
  {
    "country": "FR",
    "name": "Festubert",
    "lat": "50.5425",
    "lng": "2.73593"
  },
  {
    "country": "FR",
    "name": "Fessenheim",
    "lat": "47.91744",
    "lng": "7.53698"
  },
  {
    "country": "FR",
    "name": "Fesches-le-Châtel",
    "lat": "47.52415",
    "lng": "6.90535"
  },
  {
    "country": "FR",
    "name": "Ferrières-en-Brie",
    "lat": "48.82352",
    "lng": "2.70664"
  },
  {
    "country": "FR",
    "name": "Ferrière-la-Grande",
    "lat": "50.25521",
    "lng": "3.99288"
  },
  {
    "country": "FR",
    "name": "Ferrette",
    "lat": "47.49196",
    "lng": "7.31937"
  },
  {
    "country": "FR",
    "name": "Ferrals-les-Corbières",
    "lat": "43.15",
    "lng": "2.73333"
  },
  {
    "country": "FR",
    "name": "Ferques",
    "lat": "50.83002",
    "lng": "1.75994"
  },
  {
    "country": "FR",
    "name": "Férolles-Attilly",
    "lat": "48.73184",
    "lng": "2.63088"
  },
  {
    "country": "FR",
    "name": "Férolles",
    "lat": "47.83475",
    "lng": "2.11113"
  },
  {
    "country": "FR",
    "name": "Ferney-Voltaire",
    "lat": "46.25858",
    "lng": "6.11063"
  },
  {
    "country": "FR",
    "name": "Fermanville",
    "lat": "49.68673",
    "lng": "-1.46284"
  },
  {
    "country": "FR",
    "name": "Férin",
    "lat": "50.32732",
    "lng": "3.07415"
  },
  {
    "country": "FR",
    "name": "Férel",
    "lat": "47.48203",
    "lng": "-2.34227"
  },
  {
    "country": "FR",
    "name": "Fère-en-Tardenois",
    "lat": "49.2",
    "lng": "3.51667"
  },
  {
    "country": "FR",
    "name": "Fère-Champenoise",
    "lat": "48.75431",
    "lng": "3.99069"
  },
  {
    "country": "FR",
    "name": "Fenouillet",
    "lat": "43.68041",
    "lng": "1.392"
  },
  {
    "country": "FR",
    "name": "Feneu",
    "lat": "47.57211",
    "lng": "-0.59422"
  },
  {
    "country": "FR",
    "name": "Fénay",
    "lat": "47.23185",
    "lng": "5.06211"
  },
  {
    "country": "FR",
    "name": "Fenain",
    "lat": "50.36667",
    "lng": "3.3"
  },
  {
    "country": "FR",
    "name": "Felletin",
    "lat": "45.88333",
    "lng": "2.17431"
  },
  {
    "country": "FR",
    "name": "Fellering",
    "lat": "47.89659",
    "lng": "6.98552"
  },
  {
    "country": "FR",
    "name": "Félines",
    "lat": "45.31693",
    "lng": "4.73067"
  },
  {
    "country": "FR",
    "name": "Feillens",
    "lat": "46.33515",
    "lng": "4.88863"
  },
  {
    "country": "FR",
    "name": "Feignies",
    "lat": "50.29806",
    "lng": "3.91534"
  },
  {
    "country": "FR",
    "name": "Feigères",
    "lat": "46.11305",
    "lng": "6.08041"
  },
  {
    "country": "FR",
    "name": "Fégréac",
    "lat": "47.58476",
    "lng": "-2.0441"
  },
  {
    "country": "FR",
    "name": "Fegersheim",
    "lat": "48.49016",
    "lng": "7.68107"
  },
  {
    "country": "FR",
    "name": "Féchain",
    "lat": "50.26638",
    "lng": "3.21024"
  },
  {
    "country": "FR",
    "name": "Fécamp",
    "lat": "49.75787",
    "lng": "0.37457"
  },
  {
    "country": "FR",
    "name": "Fayl-Billot",
    "lat": "47.78199",
    "lng": "5.59917"
  },
  {
    "country": "FR",
    "name": "Fayence",
    "lat": "43.6257",
    "lng": "6.69531"
  },
  {
    "country": "FR",
    "name": "Fay-de-Bretagne",
    "lat": "47.41453",
    "lng": "-1.79155"
  },
  {
    "country": "FR",
    "name": "Fay-aux-Loges",
    "lat": "47.92724",
    "lng": "2.14012"
  },
  {
    "country": "FR",
    "name": "Favières",
    "lat": "48.76324",
    "lng": "2.7747"
  },
  {
    "country": "FR",
    "name": "Faverolles-sur-Cher",
    "lat": "47.31732",
    "lng": "1.19045"
  },
  {
    "country": "FR",
    "name": "Faverney",
    "lat": "47.76713",
    "lng": "6.10428"
  },
  {
    "country": "FR",
    "name": "Faverges-de-la-Tour",
    "lat": "45.59096",
    "lng": "5.52265"
  },
  {
    "country": "FR",
    "name": "Faverges",
    "lat": "45.74752",
    "lng": "6.29297"
  },
  {
    "country": "FR",
    "name": "Fauville-en-Caux",
    "lat": "49.65257",
    "lng": "0.59197"
  },
  {
    "country": "FR",
    "name": "Faumont",
    "lat": "50.46017",
    "lng": "3.13713"
  },
  {
    "country": "FR",
    "name": "Faulx",
    "lat": "48.79396",
    "lng": "6.19449"
  },
  {
    "country": "FR",
    "name": "Faulquemont",
    "lat": "49.0491",
    "lng": "6.59732"
  },
  {
    "country": "FR",
    "name": "Farschviller",
    "lat": "49.09406",
    "lng": "6.89517"
  },
  {
    "country": "FR",
    "name": "Farnay",
    "lat": "45.49291",
    "lng": "4.59643"
  },
  {
    "country": "FR",
    "name": "Fargues-Saint-Hilaire",
    "lat": "44.82304",
    "lng": "-0.44676"
  },
  {
    "country": "FR",
    "name": "Faremoutiers",
    "lat": "48.79962",
    "lng": "2.99607"
  },
  {
    "country": "FR",
    "name": "Fareins",
    "lat": "46.01793",
    "lng": "4.75993"
  },
  {
    "country": "FR",
    "name": "Farébersviller",
    "lat": "49.11898",
    "lng": "6.86914"
  },
  {
    "country": "FR",
    "name": "Fampoux",
    "lat": "50.30173",
    "lng": "2.8731"
  },
  {
    "country": "FR",
    "name": "Fameck",
    "lat": "49.29895",
    "lng": "6.10915"
  },
  {
    "country": "FR",
    "name": "Famars",
    "lat": "50.31743",
    "lng": "3.51945"
  },
  {
    "country": "FR",
    "name": "Falleron",
    "lat": "46.8816",
    "lng": "-1.70208"
  },
  {
    "country": "FR",
    "name": "Falicon",
    "lat": "43.74786",
    "lng": "7.27764"
  },
  {
    "country": "FR",
    "name": "Falck",
    "lat": "49.22695",
    "lng": "6.63373"
  },
  {
    "country": "FR",
    "name": "Falaise",
    "lat": "48.89217",
    "lng": "-0.19527"
  },
  {
    "country": "FR",
    "name": "Fains-Véel",
    "lat": "48.78333",
    "lng": "5.13333"
  },
  {
    "country": "FR",
    "name": "Fagnières",
    "lat": "48.96385",
    "lng": "4.31692"
  },
  {
    "country": "FR",
    "name": "Faches-Thumesnil",
    "lat": "50.58333",
    "lng": "3.06667"
  },
  {
    "country": "FR",
    "name": "Fabrezan",
    "lat": "43.13581",
    "lng": "2.69814"
  },
  {
    "country": "FR",
    "name": "Fabrègues",
    "lat": "43.55057",
    "lng": "3.77637"
  },
  {
    "country": "FR",
    "name": "Ézy-sur-Eure",
    "lat": "48.86667",
    "lng": "1.41667"
  },
  {
    "country": "FR",
    "name": "Èze",
    "lat": "43.71667",
    "lng": "7.36667"
  },
  {
    "country": "FR",
    "name": "Ézanville",
    "lat": "49.02794",
    "lng": "2.36787"
  },
  {
    "country": "FR",
    "name": "Eyzin-Pinet",
    "lat": "45.47241",
    "lng": "4.99841"
  },
  {
    "country": "FR",
    "name": "Eyvigues-et-Eybènes",
    "lat": "44.93333",
    "lng": "1.35"
  },
  {
    "country": "FR",
    "name": "Eysines",
    "lat": "44.88352",
    "lng": "-0.64686"
  },
  {
    "country": "FR",
    "name": "Eyragues",
    "lat": "43.84103",
    "lng": "4.84231"
  },
  {
    "country": "FR",
    "name": "Eymoutiers",
    "lat": "45.7379",
    "lng": "1.74189"
  },
  {
    "country": "FR",
    "name": "Eymet",
    "lat": "44.66812",
    "lng": "0.39961"
  },
  {
    "country": "FR",
    "name": "Eyguières",
    "lat": "43.69481",
    "lng": "5.03131"
  },
  {
    "country": "FR",
    "name": "Eygalières",
    "lat": "43.76099",
    "lng": "4.94968"
  },
  {
    "country": "FR",
    "name": "Eybens",
    "lat": "45.14867",
    "lng": "5.74925"
  },
  {
    "country": "FR",
    "name": "Exireuil",
    "lat": "46.43382",
    "lng": "-0.19251"
  },
  {
    "country": "FR",
    "name": "Exincourt",
    "lat": "47.49465",
    "lng": "6.83169"
  },
  {
    "country": "FR",
    "name": "Exideuil",
    "lat": "45.88639",
    "lng": "0.67318"
  },
  {
    "country": "FR",
    "name": "Excideuil",
    "lat": "45.33635",
    "lng": "1.04754"
  },
  {
    "country": "FR",
    "name": "Évry",
    "lat": "48.6328",
    "lng": "2.44049"
  },
  {
    "country": "FR",
    "name": "Évron",
    "lat": "48.15642",
    "lng": "-0.3997"
  },
  {
    "country": "FR",
    "name": "Évreux",
    "lat": "49.02414",
    "lng": "1.15082"
  },
  {
    "country": "FR",
    "name": "Évrecy",
    "lat": "49.09904",
    "lng": "-0.50421"
  },
  {
    "country": "FR",
    "name": "Évran",
    "lat": "48.37987",
    "lng": "-1.98076"
  },
  {
    "country": "FR",
    "name": "Évires",
    "lat": "46.03783",
    "lng": "6.22453"
  },
  {
    "country": "FR",
    "name": "Évin-Malmaison",
    "lat": "50.43923",
    "lng": "3.03139"
  },
  {
    "country": "FR",
    "name": "Évian-les-Bains",
    "lat": "46.40111",
    "lng": "6.58793"
  },
  {
    "country": "FR",
    "name": "Évenos",
    "lat": "43.15863",
    "lng": "5.84786"
  },
  {
    "country": "FR",
    "name": "Évaux-les-Bains",
    "lat": "46.17346",
    "lng": "2.48463"
  },
  {
    "country": "FR",
    "name": "Euville",
    "lat": "48.7503",
    "lng": "5.62603"
  },
  {
    "country": "FR",
    "name": "Eurville-Bienville",
    "lat": "48.58333",
    "lng": "5.03333"
  },
  {
    "country": "FR",
    "name": "Eurre",
    "lat": "44.76088",
    "lng": "4.99099"
  },
  {
    "country": "FR",
    "name": "Eulmont",
    "lat": "48.75174",
    "lng": "6.22593"
  },
  {
    "country": "FR",
    "name": "Eu",
    "lat": "50.04606",
    "lng": "1.42079"
  },
  {
    "country": "FR",
    "name": "Etzling",
    "lat": "49.17943",
    "lng": "6.95864"
  },
  {
    "country": "FR",
    "name": "Étupes",
    "lat": "47.50525",
    "lng": "6.87075"
  },
  {
    "country": "FR",
    "name": "Étriché",
    "lat": "47.65087",
    "lng": "-0.44377"
  },
  {
    "country": "FR",
    "name": "Étreux",
    "lat": "49.98333",
    "lng": "3.65"
  },
  {
    "country": "FR",
    "name": "Étretat",
    "lat": "49.70669",
    "lng": "0.20523"
  },
  {
    "country": "FR",
    "name": "Étrépagny",
    "lat": "49.30623",
    "lng": "1.61139"
  },
  {
    "country": "FR",
    "name": "Étrembières",
    "lat": "46.17865",
    "lng": "6.21774"
  },
  {
    "country": "FR",
    "name": "Étrelles",
    "lat": "48.06031",
    "lng": "-1.19402"
  },
  {
    "country": "FR",
    "name": "Étreillers",
    "lat": "49.83059",
    "lng": "3.16029"
  },
  {
    "country": "FR",
    "name": "Étréchy",
    "lat": "48.49465",
    "lng": "2.19489"
  },
  {
    "country": "FR",
    "name": "Étoile-sur-Rhône",
    "lat": "44.83812",
    "lng": "4.89159"
  },
  {
    "country": "FR",
    "name": "Étival-lès-le-Mans",
    "lat": "47.95",
    "lng": "0.08333"
  },
  {
    "country": "FR",
    "name": "Étival-Clairefontaine",
    "lat": "48.36519",
    "lng": "6.86118"
  },
  {
    "country": "FR",
    "name": "Étiolles",
    "lat": "48.63248",
    "lng": "2.48226"
  },
  {
    "country": "FR",
    "name": "Éterville",
    "lat": "49.14423",
    "lng": "-0.42512"
  },
  {
    "country": "FR",
    "name": "Étel",
    "lat": "47.65614",
    "lng": "-3.20018"
  },
  {
    "country": "FR",
    "name": "Etaux",
    "lat": "46.06667",
    "lng": "6.3"
  },
  {
    "country": "FR",
    "name": "Étauliers",
    "lat": "45.22582",
    "lng": "-0.57243"
  },
  {
    "country": "FR",
    "name": "Étaules",
    "lat": "45.73407",
    "lng": "-1.09918"
  },
  {
    "country": "FR",
    "name": "Étaples",
    "lat": "50.52194",
    "lng": "1.63319"
  },
  {
    "country": "FR",
    "name": "Étang-sur-Arroux",
    "lat": "46.8656",
    "lng": "4.18988"
  },
  {
    "country": "FR",
    "name": "Étampes-sur-Marne",
    "lat": "49.03464",
    "lng": "3.41893"
  },
  {
    "country": "FR",
    "name": "Étampes",
    "lat": "48.43333",
    "lng": "2.15"
  },
  {
    "country": "FR",
    "name": "Étalans",
    "lat": "47.15125",
    "lng": "6.27315"
  },
  {
    "country": "FR",
    "name": "Étainhus",
    "lat": "49.56648",
    "lng": "0.31285"
  },
  {
    "country": "FR",
    "name": "Étain",
    "lat": "49.21259",
    "lng": "5.64022"
  },
  {
    "country": "FR",
    "name": "Étagnac",
    "lat": "45.89506",
    "lng": "0.77897"
  },
  {
    "country": "FR",
    "name": "Étables-sur-Mer",
    "lat": "48.63333",
    "lng": "-2.83333"
  },
  {
    "country": "FR",
    "name": "Esvres",
    "lat": "47.28537",
    "lng": "0.78588"
  },
  {
    "country": "FR",
    "name": "Estrées-Saint-Denis",
    "lat": "49.42602",
    "lng": "2.64293"
  },
  {
    "country": "FR",
    "name": "Estrées",
    "lat": "50.30079",
    "lng": "3.0698"
  },
  {
    "country": "FR",
    "name": "Estrablin",
    "lat": "45.51732",
    "lng": "4.96626"
  },
  {
    "country": "FR",
    "name": "Estivareilles",
    "lat": "46.42533",
    "lng": "2.61829"
  },
  {
    "country": "FR",
    "name": "Estissac",
    "lat": "48.2692",
    "lng": "3.80515"
  },
  {
    "country": "FR",
    "name": "Estillac",
    "lat": "44.15766",
    "lng": "0.56383"
  },
  {
    "country": "FR",
    "name": "Estevelles",
    "lat": "50.47653",
    "lng": "2.90928"
  },
  {
    "country": "FR",
    "name": "Esternay",
    "lat": "48.73232",
    "lng": "3.56159"
  },
  {
    "country": "FR",
    "name": "Estaires",
    "lat": "50.64574",
    "lng": "2.72782"
  },
  {
    "country": "FR",
    "name": "Estagel",
    "lat": "42.77314",
    "lng": "2.69665"
  },
  {
    "country": "FR",
    "name": "Essômes-sur-Marne",
    "lat": "49.02881",
    "lng": "3.37571"
  },
  {
    "country": "FR",
    "name": "Essigny-le-Grand",
    "lat": "49.77865",
    "lng": "3.27774"
  },
  {
    "country": "FR",
    "name": "Essey-lès-Nancy",
    "lat": "48.70179",
    "lng": "6.22425"
  },
  {
    "country": "FR",
    "name": "Essert",
    "lat": "47.63253",
    "lng": "6.81539"
  },
  {
    "country": "FR",
    "name": "Essars",
    "lat": "50.54868",
    "lng": "2.6662"
  },
  {
    "country": "FR",
    "name": "Esquibien",
    "lat": "48.02506",
    "lng": "-4.56139"
  },
  {
    "country": "FR",
    "name": "Esquerdes",
    "lat": "50.70414",
    "lng": "2.18851"
  },
  {
    "country": "FR",
    "name": "Esquelbecq",
    "lat": "50.88694",
    "lng": "2.43215"
  },
  {
    "country": "FR",
    "name": "Esquéhéries",
    "lat": "49.98391",
    "lng": "3.74743"
  },
  {
    "country": "FR",
    "name": "Espéraza",
    "lat": "42.93225",
    "lng": "2.22006"
  },
  {
    "country": "FR",
    "name": "Espelette",
    "lat": "43.34015",
    "lng": "-1.44737"
  },
  {
    "country": "FR",
    "name": "Espaly-Saint-Marcel",
    "lat": "45.0479",
    "lng": "3.86557"
  },
  {
    "country": "FR",
    "name": "Espalion",
    "lat": "44.52237",
    "lng": "2.76265"
  },
  {
    "country": "FR",
    "name": "Esnandes",
    "lat": "46.25033",
    "lng": "-1.11566"
  },
  {
    "country": "FR",
    "name": "Eslettes",
    "lat": "49.5482",
    "lng": "1.05515"
  },
  {
    "country": "FR",
    "name": "Escoutoux",
    "lat": "45.82075",
    "lng": "3.56415"
  },
  {
    "country": "FR",
    "name": "La Baule-Escoublac",
    "lat": "47.29221",
    "lng": "-2.36395"
  },
  {
    "country": "FR",
    "name": "Esches",
    "lat": "49.22086",
    "lng": "2.16595"
  },
  {
    "country": "FR",
    "name": "Eschentzwiller",
    "lat": "47.71253",
    "lng": "7.39806"
  },
  {
    "country": "FR",
    "name": "Eschbach",
    "lat": "48.87465",
    "lng": "7.73609"
  },
  {
    "country": "FR",
    "name": "Eschau",
    "lat": "48.48897",
    "lng": "7.71644"
  },
  {
    "country": "FR",
    "name": "Escautpont",
    "lat": "50.41875",
    "lng": "3.55341"
  },
  {
    "country": "FR",
    "name": "Escaudœuvres",
    "lat": "50.2",
    "lng": "3.26667"
  },
  {
    "country": "FR",
    "name": "Escaudain",
    "lat": "50.33315",
    "lng": "3.3443"
  },
  {
    "country": "FR",
    "name": "Escalquens",
    "lat": "43.51744",
    "lng": "1.55893"
  },
  {
    "country": "FR",
    "name": "Esbly",
    "lat": "48.9052",
    "lng": "2.81235"
  },
  {
    "country": "FR",
    "name": "Ervy-le-Châtel",
    "lat": "48.04116",
    "lng": "3.90988"
  },
  {
    "country": "FR",
    "name": "Erstein",
    "lat": "48.42373",
    "lng": "7.66262"
  },
  {
    "country": "FR",
    "name": "Erre",
    "lat": "50.36252",
    "lng": "3.31561"
  },
  {
    "country": "FR",
    "name": "Erquy",
    "lat": "48.63186",
    "lng": "-2.4628"
  },
  {
    "country": "FR",
    "name": "Erquinghem-Lys",
    "lat": "50.67601",
    "lng": "2.84505"
  },
  {
    "country": "FR",
    "name": "Ernolsheim-Bruche",
    "lat": "48.56531",
    "lng": "7.56503"
  },
  {
    "country": "FR",
    "name": "Ernée",
    "lat": "48.29764",
    "lng": "-0.93143"
  },
  {
    "country": "FR",
    "name": "Ermont",
    "lat": "48.99004",
    "lng": "2.25804"
  },
  {
    "country": "FR",
    "name": "Ergué-Gabéric",
    "lat": "47.99562",
    "lng": "-4.02223"
  },
  {
    "country": "FR",
    "name": "Erdeven",
    "lat": "47.6421",
    "lng": "-3.15706"
  },
  {
    "country": "FR",
    "name": "Ercuis",
    "lat": "49.23465",
    "lng": "2.30407"
  },
  {
    "country": "FR",
    "name": "Ercé-près-Liffré",
    "lat": "48.25454",
    "lng": "-1.5156"
  },
  {
    "country": "FR",
    "name": "Ercé-en-Lamée",
    "lat": "47.83048",
    "lng": "-1.55867"
  },
  {
    "country": "FR",
    "name": "Erbrée",
    "lat": "48.09745",
    "lng": "-1.12479"
  },
  {
    "country": "FR",
    "name": "Erbray",
    "lat": "47.65492",
    "lng": "-1.31783"
  },
  {
    "country": "FR",
    "name": "Éragny",
    "lat": "49.01667",
    "lng": "2.1"
  },
  {
    "country": "FR",
    "name": "Équihen-Plage",
    "lat": "50.67557",
    "lng": "1.57225"
  },
  {
    "country": "FR",
    "name": "Équeurdreville-Hainneville",
    "lat": "49.64868",
    "lng": "-1.65306"
  },
  {
    "country": "FR",
    "name": "Équemauville",
    "lat": "49.39406",
    "lng": "0.2076"
  },
  {
    "country": "FR",
    "name": "Épron",
    "lat": "49.22174",
    "lng": "-0.37085"
  },
  {
    "country": "FR",
    "name": "Eppeville",
    "lat": "49.74069",
    "lng": "3.05114"
  },
  {
    "country": "FR",
    "name": "Épouville",
    "lat": "49.56349",
    "lng": "0.22373"
  },
  {
    "country": "FR",
    "name": "Épône",
    "lat": "48.95476",
    "lng": "1.82233"
  },
  {
    "country": "FR",
    "name": "Épinouze",
    "lat": "45.30907",
    "lng": "4.93376"
  },
  {
    "country": "FR",
    "name": "Epiniac",
    "lat": "48.5",
    "lng": "-1.7"
  },
  {
    "country": "FR",
    "name": "Épinay-sur-Seine",
    "lat": "48.9535",
    "lng": "2.31514"
  },
  {
    "country": "FR",
    "name": "Épinay-sur-Orge",
    "lat": "48.67338",
    "lng": "2.31074"
  },
  {
    "country": "FR",
    "name": "Épinay-sous-Sénart",
    "lat": "48.6897",
    "lng": "2.51186"
  },
  {
    "country": "FR",
    "name": "Épinal",
    "lat": "48.18324",
    "lng": "6.45304"
  },
  {
    "country": "FR",
    "name": "Épinac",
    "lat": "46.98333",
    "lng": "4.51667"
  },
  {
    "country": "FR",
    "name": "Épieds-en-Beauce",
    "lat": "47.95066",
    "lng": "1.61732"
  },
  {
    "country": "FR",
    "name": "Epfig",
    "lat": "48.35933",
    "lng": "7.46427"
  },
  {
    "country": "FR",
    "name": "Épervans",
    "lat": "46.75247",
    "lng": "4.8993"
  },
  {
    "country": "FR",
    "name": "Épernon",
    "lat": "48.61031",
    "lng": "1.67218"
  },
  {
    "country": "FR",
    "name": "Épernay",
    "lat": "49.05",
    "lng": "3.95"
  },
  {
    "country": "FR",
    "name": "Éperlecques",
    "lat": "50.80566",
    "lng": "2.15207"
  },
  {
    "country": "FR",
    "name": "Épehy",
    "lat": "50",
    "lng": "3.13333"
  },
  {
    "country": "FR",
    "name": "Épaignes",
    "lat": "49.27945",
    "lng": "0.4398"
  },
  {
    "country": "FR",
    "name": "Épagny",
    "lat": "45.93805",
    "lng": "6.09095"
  },
  {
    "country": "FR",
    "name": "Éoures",
    "lat": "43.30045",
    "lng": "5.52193"
  },
  {
    "country": "FR",
    "name": "Envermeu",
    "lat": "49.8956",
    "lng": "1.26493"
  },
  {
    "country": "FR",
    "name": "Enval",
    "lat": "45.89883",
    "lng": "3.0497"
  },
  {
    "country": "FR",
    "name": "Entzheim",
    "lat": "48.53424",
    "lng": "7.63772"
  },
  {
    "country": "FR",
    "name": "Entre-deux-Guiers",
    "lat": "45.43181",
    "lng": "5.74911"
  },
  {
    "country": "FR",
    "name": "Entraygues-sur-Truyère",
    "lat": "44.64606",
    "lng": "2.56745"
  },
  {
    "country": "FR",
    "name": "Entrange",
    "lat": "49.413",
    "lng": "6.10501"
  },
  {
    "country": "FR",
    "name": "Entrammes",
    "lat": "47.99759",
    "lng": "-0.71399"
  },
  {
    "country": "FR",
    "name": "Entraigues-sur-la-Sorgue",
    "lat": "44",
    "lng": "4.91667"
  },
  {
    "country": "FR",
    "name": "Ensuès-la-Redonne",
    "lat": "43.35464",
    "lng": "5.20357"
  },
  {
    "country": "FR",
    "name": "Ensisheim",
    "lat": "47.86695",
    "lng": "7.35212"
  },
  {
    "country": "FR",
    "name": "Ennezat",
    "lat": "45.89768",
    "lng": "3.22217"
  },
  {
    "country": "FR",
    "name": "Ennevelin",
    "lat": "50.54121",
    "lng": "3.12972"
  },
  {
    "country": "FR",
    "name": "Ennetières-en-Weppes",
    "lat": "50.6353",
    "lng": "2.94012"
  },
  {
    "country": "FR",
    "name": "Ennery",
    "lat": "49.22619",
    "lng": "6.21778"
  },
  {
    "country": "FR",
    "name": "Ennery",
    "lat": "49.07505",
    "lng": "2.10599"
  },
  {
    "country": "FR",
    "name": "Englefontaine",
    "lat": "50.19091",
    "lng": "3.64401"
  },
  {
    "country": "FR",
    "name": "Enghien-les-Bains",
    "lat": "48.96667",
    "lng": "2.31667"
  },
  {
    "country": "FR",
    "name": "Enchenberg",
    "lat": "49.01354",
    "lng": "7.33868"
  },
  {
    "country": "FR",
    "name": "Emmerin",
    "lat": "50.59475",
    "lng": "3.00124"
  },
  {
    "country": "FR",
    "name": "Émerchicourt",
    "lat": "50.30786",
    "lng": "3.24537"
  },
  {
    "country": "FR",
    "name": "Émerainville",
    "lat": "48.81276",
    "lng": "2.62139"
  },
  {
    "country": "FR",
    "name": "Embrun",
    "lat": "44.56387",
    "lng": "6.49526"
  },
  {
    "country": "FR",
    "name": "Elven",
    "lat": "47.7323",
    "lng": "-2.58956"
  },
  {
    "country": "FR",
    "name": "Éloyes",
    "lat": "48.09793",
    "lng": "6.60653"
  },
  {
    "country": "FR",
    "name": "Elne",
    "lat": "42.60031",
    "lng": "2.97146"
  },
  {
    "country": "FR",
    "name": "Elliant",
    "lat": "47.99417",
    "lng": "-3.88966"
  },
  {
    "country": "FR",
    "name": "Éleu-dit-Leauwette",
    "lat": "50.4234",
    "lng": "2.81135"
  },
  {
    "country": "FR",
    "name": "Elbeuf",
    "lat": "49.28669",
    "lng": "1.00288"
  },
  {
    "country": "FR",
    "name": "Élancourt",
    "lat": "48.78421",
    "lng": "1.9552"
  },
  {
    "country": "FR",
    "name": "Einville-au-Jard",
    "lat": "48.65323",
    "lng": "6.48786"
  },
  {
    "country": "FR",
    "name": "Éguzon-Chantôme",
    "lat": "46.45",
    "lng": "1.58333"
  },
  {
    "country": "FR",
    "name": "Eguisheim",
    "lat": "48.0428",
    "lng": "7.30617"
  },
  {
    "country": "FR",
    "name": "Éguilles",
    "lat": "43.56867",
    "lng": "5.35575"
  },
  {
    "country": "FR",
    "name": "Égriselles-le-Bocage",
    "lat": "48.12103",
    "lng": "3.18233"
  },
  {
    "country": "FR",
    "name": "Égreville",
    "lat": "48.17606",
    "lng": "2.87278"
  },
  {
    "country": "FR",
    "name": "Égly",
    "lat": "48.57828",
    "lng": "2.22417"
  },
  {
    "country": "FR",
    "name": "Égletons",
    "lat": "45.40336",
    "lng": "2.05073"
  },
  {
    "country": "FR",
    "name": "Edern",
    "lat": "48.1",
    "lng": "-3.98333"
  },
  {
    "country": "FR",
    "name": "Écully",
    "lat": "45.77726",
    "lng": "4.77481"
  },
  {
    "country": "FR",
    "name": "Écuisses",
    "lat": "46.75631",
    "lng": "4.53845"
  },
  {
    "country": "FR",
    "name": "Écuelles",
    "lat": "48.35636",
    "lng": "2.82335"
  },
  {
    "country": "FR",
    "name": "Écueillé",
    "lat": "47.08462",
    "lng": "1.34668"
  },
  {
    "country": "FR",
    "name": "Écrouves",
    "lat": "48.67937",
    "lng": "5.84433"
  },
  {
    "country": "FR",
    "name": "Écrainville",
    "lat": "49.64943",
    "lng": "0.32488"
  },
  {
    "country": "FR",
    "name": "Ecquevilly",
    "lat": "48.95192",
    "lng": "1.92338"
  },
  {
    "country": "FR",
    "name": "Ecques",
    "lat": "50.66998",
    "lng": "2.28633"
  },
  {
    "country": "FR",
    "name": "Écoyeux",
    "lat": "45.82231",
    "lng": "-0.50539"
  },
  {
    "country": "FR",
    "name": "Écourt-Saint-Quentin",
    "lat": "50.25226",
    "lng": "3.07331"
  },
  {
    "country": "FR",
    "name": "Écouflant",
    "lat": "47.53101",
    "lng": "-0.5278"
  },
  {
    "country": "FR",
    "name": "Écouen",
    "lat": "49.02062",
    "lng": "2.38309"
  },
  {
    "country": "FR",
    "name": "Écouché",
    "lat": "48.71751",
    "lng": "-0.12409"
  },
  {
    "country": "FR",
    "name": "Écommoy",
    "lat": "47.82565",
    "lng": "0.27422"
  },
  {
    "country": "FR",
    "name": "École-Valentin",
    "lat": "47.26667",
    "lng": "5.98333"
  },
  {
    "country": "FR",
    "name": "Eckwersheim",
    "lat": "48.68167",
    "lng": "7.69687"
  },
  {
    "country": "FR",
    "name": "Eckbolsheim",
    "lat": "48.58075",
    "lng": "7.68768"
  },
  {
    "country": "FR",
    "name": "Échirolles",
    "lat": "45.1439",
    "lng": "5.72883"
  },
  {
    "country": "FR",
    "name": "Échiré",
    "lat": "46.38748",
    "lng": "-0.41511"
  },
  {
    "country": "FR",
    "name": "Échillais",
    "lat": "45.90072",
    "lng": "-0.95211"
  },
  {
    "country": "FR",
    "name": "Échenoz-la-Méline",
    "lat": "47.60086",
    "lng": "6.13544"
  },
  {
    "country": "FR",
    "name": "Échenevex",
    "lat": "46.30963",
    "lng": "6.0393"
  },
  {
    "country": "FR",
    "name": "Échalas",
    "lat": "45.5519",
    "lng": "4.71645"
  },
  {
    "country": "FR",
    "name": "Écaillon",
    "lat": "50.35034",
    "lng": "3.21664"
  },
  {
    "country": "FR",
    "name": "Ébreuil",
    "lat": "46.11629",
    "lng": "3.08771"
  },
  {
    "country": "FR",
    "name": "Ebersheim",
    "lat": "48.30438",
    "lng": "7.49903"
  },
  {
    "country": "FR",
    "name": "Eauze",
    "lat": "43.86055",
    "lng": "0.10199"
  },
  {
    "country": "FR",
    "name": "Eaunes",
    "lat": "43.42079",
    "lng": "1.35397"
  },
  {
    "country": "FR",
    "name": "Eaubonne",
    "lat": "48.99712",
    "lng": "2.28249"
  },
  {
    "country": "FR",
    "name": "Duttlenheim",
    "lat": "48.52553",
    "lng": "7.56572"
  },
  {
    "country": "FR",
    "name": "Dury",
    "lat": "49.84731",
    "lng": "2.2707"
  },
  {
    "country": "FR",
    "name": "Durtol",
    "lat": "45.79622",
    "lng": "3.05264"
  },
  {
    "country": "FR",
    "name": "Durtal",
    "lat": "47.67247",
    "lng": "-0.23393"
  },
  {
    "country": "FR",
    "name": "Durrenbach",
    "lat": "48.89681",
    "lng": "7.76769"
  },
  {
    "country": "FR",
    "name": "Durdat-Larequille",
    "lat": "46.25173",
    "lng": "2.70112"
  },
  {
    "country": "FR",
    "name": "Duras",
    "lat": "44.67618",
    "lng": "0.18247"
  },
  {
    "country": "FR",
    "name": "Duppigheim",
    "lat": "48.52866",
    "lng": "7.59421"
  },
  {
    "country": "FR",
    "name": "Dun-sur-Auron",
    "lat": "46.8849",
    "lng": "2.57345"
  },
  {
    "country": "FR",
    "name": "Dun-le-Palestel",
    "lat": "46.3",
    "lng": "1.66667"
  },
  {
    "country": "FR",
    "name": "Dunkerque",
    "lat": "51.03297",
    "lng": "2.377"
  },
  {
    "country": "FR",
    "name": "Dunières",
    "lat": "45.21598",
    "lng": "4.34579"
  },
  {
    "country": "FR",
    "name": "Duisans",
    "lat": "50.30633",
    "lng": "2.68653"
  },
  {
    "country": "FR",
    "name": "Dugny-sur-Meuse",
    "lat": "49.10953",
    "lng": "5.3855"
  },
  {
    "country": "FR",
    "name": "Dugny",
    "lat": "48.95371",
    "lng": "2.41734"
  },
  {
    "country": "FR",
    "name": "Duclair",
    "lat": "49.48385",
    "lng": "0.87617"
  },
  {
    "country": "FR",
    "name": "Ducey",
    "lat": "48.61843",
    "lng": "-1.29052"
  },
  {
    "country": "FR",
    "name": "Dry",
    "lat": "47.79612",
    "lng": "1.7133"
  },
  {
    "country": "FR",
    "name": "Drusenheim",
    "lat": "48.76207",
    "lng": "7.95326"
  },
  {
    "country": "FR",
    "name": "Drumettaz-Clarafond",
    "lat": "45.66037",
    "lng": "5.92145"
  },
  {
    "country": "FR",
    "name": "Drulingen",
    "lat": "48.86804",
    "lng": "7.18956"
  },
  {
    "country": "FR",
    "name": "Druelle",
    "lat": "44.36006",
    "lng": "2.50505"
  },
  {
    "country": "FR",
    "name": "Droue-sur-Drouette",
    "lat": "48.60053",
    "lng": "1.70113"
  },
  {
    "country": "FR",
    "name": "Droué",
    "lat": "48.04023",
    "lng": "1.07534"
  },
  {
    "country": "FR",
    "name": "Drocourt",
    "lat": "50.39002",
    "lng": "2.92425"
  },
  {
    "country": "FR",
    "name": "Dreux",
    "lat": "48.73333",
    "lng": "1.36667"
  },
  {
    "country": "FR",
    "name": "Dreuil-lès-Amiens",
    "lat": "49.91483",
    "lng": "2.22893"
  },
  {
    "country": "FR",
    "name": "Dreslincourt",
    "lat": "49.52809",
    "lng": "2.92699"
  },
  {
    "country": "FR",
    "name": "Drémil-Lafage",
    "lat": "43.59624",
    "lng": "1.60117"
  },
  {
    "country": "FR",
    "name": "Drefféac",
    "lat": "47.47464",
    "lng": "-2.05774"
  },
  {
    "country": "FR",
    "name": "Draveil",
    "lat": "48.68466",
    "lng": "2.41418"
  },
  {
    "country": "FR",
    "name": "Drap",
    "lat": "43.75614",
    "lng": "7.32059"
  },
  {
    "country": "FR",
    "name": "Drancy",
    "lat": "48.92578",
    "lng": "2.44533"
  },
  {
    "country": "FR",
    "name": "Drain",
    "lat": "47.33655",
    "lng": "-1.20773"
  },
  {
    "country": "FR",
    "name": "Draguignan",
    "lat": "43.53333",
    "lng": "6.46667"
  },
  {
    "country": "FR",
    "name": "Dracy-le-Fort",
    "lat": "46.7975",
    "lng": "4.76215"
  },
  {
    "country": "FR",
    "name": "Dozulé",
    "lat": "49.23132",
    "lng": "-0.04454"
  },
  {
    "country": "FR",
    "name": "Doyet",
    "lat": "46.33476",
    "lng": "2.79707"
  },
  {
    "country": "FR",
    "name": "Douzy",
    "lat": "49.6708",
    "lng": "5.04156"
  },
  {
    "country": "FR",
    "name": "Douvrin",
    "lat": "50.50916",
    "lng": "2.83053"
  },
  {
    "country": "FR",
    "name": "Douvres-la-Délivrande",
    "lat": "49.29472",
    "lng": "-0.38039"
  },
  {
    "country": "FR",
    "name": "Douvaine",
    "lat": "46.30544",
    "lng": "6.30375"
  },
  {
    "country": "FR",
    "name": "Doussard",
    "lat": "45.77556",
    "lng": "6.21941"
  },
  {
    "country": "FR",
    "name": "Dourgne",
    "lat": "43.48381",
    "lng": "2.13989"
  },
  {
    "country": "FR",
    "name": "Dourges",
    "lat": "50.43636",
    "lng": "2.98589"
  },
  {
    "country": "FR",
    "name": "Dourdan",
    "lat": "48.52772",
    "lng": "2.01113"
  },
  {
    "country": "FR",
    "name": "Doullens",
    "lat": "50.15724",
    "lng": "2.34019"
  },
  {
    "country": "FR",
    "name": "Doulaincourt-Saucourt",
    "lat": "48.31667",
    "lng": "5.2"
  },
  {
    "country": "FR",
    "name": "Doué-la-Fontaine",
    "lat": "47.19372",
    "lng": "-0.27492"
  },
  {
    "country": "FR",
    "name": "Doue",
    "lat": "48.86641",
    "lng": "3.16269"
  },
  {
    "country": "FR",
    "name": "Doudeville",
    "lat": "49.72268",
    "lng": "0.78479"
  },
  {
    "country": "FR",
    "name": "Douchy-les-Mines",
    "lat": "50.3008",
    "lng": "3.3927"
  },
  {
    "country": "FR",
    "name": "Douchy",
    "lat": "47.94282",
    "lng": "3.05392"
  },
  {
    "country": "FR",
    "name": "Doubs",
    "lat": "46.92788",
    "lng": "6.35104"
  },
  {
    "country": "FR",
    "name": "Douarnenez",
    "lat": "48.09542",
    "lng": "-4.32904"
  },
  {
    "country": "FR",
    "name": "Douai",
    "lat": "50.36667",
    "lng": "3.06667"
  },
  {
    "country": "FR",
    "name": "Dossenheim-sur-Zinsel",
    "lat": "48.8059",
    "lng": "7.40273"
  },
  {
    "country": "FR",
    "name": "Dortan",
    "lat": "46.31973",
    "lng": "5.66028"
  },
  {
    "country": "FR",
    "name": "Dornes",
    "lat": "46.716",
    "lng": "3.35343"
  },
  {
    "country": "FR",
    "name": "Dormans",
    "lat": "49.07392",
    "lng": "3.63819"
  },
  {
    "country": "FR",
    "name": "Dorlisheim",
    "lat": "48.52485",
    "lng": "7.48624"
  },
  {
    "country": "FR",
    "name": "Dordives",
    "lat": "48.14253",
    "lng": "2.76775"
  },
  {
    "country": "FR",
    "name": "Donzy",
    "lat": "47.37066",
    "lng": "3.12548"
  },
  {
    "country": "FR",
    "name": "Donzère",
    "lat": "44.44089",
    "lng": "4.71179"
  },
  {
    "country": "FR",
    "name": "Donzenac",
    "lat": "45.22795",
    "lng": "1.52375"
  },
  {
    "country": "FR",
    "name": "Donville-les-Bains",
    "lat": "48.84608",
    "lng": "-1.58315"
  },
  {
    "country": "FR",
    "name": "Donnery",
    "lat": "47.91486",
    "lng": "2.10299"
  },
  {
    "country": "FR",
    "name": "Donnemarie-Dontilly",
    "lat": "48.47719",
    "lng": "3.13162"
  },
  {
    "country": "FR",
    "name": "Donges",
    "lat": "47.31824",
    "lng": "-2.07538"
  },
  {
    "country": "FR",
    "name": "Doncourt-lès-Conflans",
    "lat": "49.1436",
    "lng": "5.93382"
  },
  {
    "country": "FR",
    "name": "Donchery",
    "lat": "49.69584",
    "lng": "4.87417"
  },
  {
    "country": "FR",
    "name": "Don",
    "lat": "50.54912",
    "lng": "2.91817"
  },
  {
    "country": "FR",
    "name": "Dompierre-sur-Yon",
    "lat": "46.73857",
    "lng": "-1.38463"
  },
  {
    "country": "FR",
    "name": "Dompierre-sur-Veyle",
    "lat": "46.07179",
    "lng": "5.20573"
  },
  {
    "country": "FR",
    "name": "Dompierre-sur-Mer",
    "lat": "46.18817",
    "lng": "-1.06351"
  },
  {
    "country": "FR",
    "name": "Dompierre-sur-Besbre",
    "lat": "46.51962",
    "lng": "3.69905"
  },
  {
    "country": "FR",
    "name": "Domont",
    "lat": "49.02782",
    "lng": "2.32638"
  },
  {
    "country": "FR",
    "name": "Domme",
    "lat": "44.80218",
    "lng": "1.21459"
  },
  {
    "country": "FR",
    "name": "Dommartin-lès-Toul",
    "lat": "48.66981",
    "lng": "5.90998"
  },
  {
    "country": "FR",
    "name": "Dommartin-lès-Remiremont",
    "lat": "47.99902",
    "lng": "6.64048"
  },
  {
    "country": "FR",
    "name": "Dom-le-Mesnil",
    "lat": "49.69012",
    "lng": "4.80363"
  },
  {
    "country": "FR",
    "name": "Domgermain",
    "lat": "48.64292",
    "lng": "5.82582"
  },
  {
    "country": "FR",
    "name": "Domfront",
    "lat": "48.59208",
    "lng": "-0.64588"
  },
  {
    "country": "FR",
    "name": "Domessin",
    "lat": "45.5343",
    "lng": "5.70077"
  },
  {
    "country": "FR",
    "name": "Domérat",
    "lat": "46.36064",
    "lng": "2.53426"
  },
  {
    "country": "FR",
    "name": "Domène",
    "lat": "45.20345",
    "lng": "5.83905"
  },
  {
    "country": "FR",
    "name": "Dombasle-sur-Meurthe",
    "lat": "48.6252",
    "lng": "6.34967"
  },
  {
    "country": "FR",
    "name": "Domart-en-Ponthieu",
    "lat": "50.07437",
    "lng": "2.12596"
  },
  {
    "country": "FR",
    "name": "Domarin",
    "lat": "45.58555",
    "lng": "5.24308"
  },
  {
    "country": "FR",
    "name": "Domancy",
    "lat": "45.91418",
    "lng": "6.64741"
  },
  {
    "country": "FR",
    "name": "Domalain",
    "lat": "47.99617",
    "lng": "-1.2425"
  },
  {
    "country": "FR",
    "name": "Domagné",
    "lat": "48.07081",
    "lng": "-1.39291"
  },
  {
    "country": "FR",
    "name": "Dolus-d'Oléron",
    "lat": "45.91667",
    "lng": "-1.26667"
  },
  {
    "country": "FR",
    "name": "Dolomieu",
    "lat": "45.61328",
    "lng": "5.50016"
  },
  {
    "country": "FR",
    "name": "Dollon",
    "lat": "48.03879",
    "lng": "0.58686"
  },
  {
    "country": "FR",
    "name": "Dole",
    "lat": "47.1",
    "lng": "5.5"
  },
  {
    "country": "FR",
    "name": "Dol-de-Bretagne",
    "lat": "48.54765",
    "lng": "-1.75018"
  },
  {
    "country": "FR",
    "name": "Doingt",
    "lat": "49.92113",
    "lng": "2.96766"
  },
  {
    "country": "FR",
    "name": "Dogneville",
    "lat": "48.22251",
    "lng": "6.45944"
  },
  {
    "country": "FR",
    "name": "Docelles",
    "lat": "48.14475",
    "lng": "6.61289"
  },
  {
    "country": "FR",
    "name": "Dizy",
    "lat": "49.06667",
    "lng": "3.96667"
  },
  {
    "country": "FR",
    "name": "Divonne-les-Bains",
    "lat": "46.35938",
    "lng": "6.13574"
  },
  {
    "country": "FR",
    "name": "Divion",
    "lat": "50.47169",
    "lng": "2.50546"
  },
  {
    "country": "FR",
    "name": "Dives-sur-Mer",
    "lat": "49.28176",
    "lng": "-0.10125"
  },
  {
    "country": "FR",
    "name": "Distroff",
    "lat": "49.33295",
    "lng": "6.26662"
  },
  {
    "country": "FR",
    "name": "Distré",
    "lat": "47.22281",
    "lng": "-0.11071"
  },
  {
    "country": "FR",
    "name": "Dissay",
    "lat": "46.70007",
    "lng": "0.43311"
  },
  {
    "country": "FR",
    "name": "Dirinon",
    "lat": "48.39775",
    "lng": "-4.27017"
  },
  {
    "country": "FR",
    "name": "Dirac",
    "lat": "45.6",
    "lng": "0.25"
  },
  {
    "country": "FR",
    "name": "Diou",
    "lat": "46.53333",
    "lng": "3.75"
  },
  {
    "country": "FR",
    "name": "Dinsheim-sur-Bruche",
    "lat": "48.54258",
    "lng": "7.42727"
  },
  {
    "country": "FR",
    "name": "Dingy-Saint-Clair",
    "lat": "45.90806",
    "lng": "6.22452"
  },
  {
    "country": "FR",
    "name": "Dingsheim",
    "lat": "48.63053",
    "lng": "7.66932"
  },
  {
    "country": "FR",
    "name": "Dingé",
    "lat": "48.35702",
    "lng": "-1.71489"
  },
  {
    "country": "FR",
    "name": "Dinéault",
    "lat": "48.21922",
    "lng": "-4.16411"
  },
  {
    "country": "FR",
    "name": "Dinard",
    "lat": "48.63143",
    "lng": "-2.06144"
  },
  {
    "country": "FR",
    "name": "Dinan",
    "lat": "48.45",
    "lng": "-2.03333"
  },
  {
    "country": "FR",
    "name": "Dijon",
    "lat": "47.31667",
    "lng": "5.01667"
  },
  {
    "country": "FR",
    "name": "Digosville",
    "lat": "49.63104",
    "lng": "-1.52627"
  },
  {
    "country": "FR",
    "name": "Digoin",
    "lat": "46.48124",
    "lng": "3.97946"
  },
  {
    "country": "FR",
    "name": "Digne-les-Bains",
    "lat": "44.09252",
    "lng": "6.23199"
  },
  {
    "country": "FR",
    "name": "Dignac",
    "lat": "45.55",
    "lng": "0.28333"
  },
  {
    "country": "FR",
    "name": "Diges",
    "lat": "47.72862",
    "lng": "3.39786"
  },
  {
    "country": "FR",
    "name": "Dieuze",
    "lat": "48.81263",
    "lng": "6.7178"
  },
  {
    "country": "FR",
    "name": "Dieulouard",
    "lat": "48.8414",
    "lng": "6.06808"
  },
  {
    "country": "FR",
    "name": "Dieulefit",
    "lat": "44.52341",
    "lng": "5.06425"
  },
  {
    "country": "FR",
    "name": "Dieue-sur-Meuse",
    "lat": "49.072",
    "lng": "5.42248"
  },
  {
    "country": "FR",
    "name": "Dietwiller",
    "lat": "47.69259",
    "lng": "7.40222"
  },
  {
    "country": "FR",
    "name": "Diesen",
    "lat": "49.17818",
    "lng": "6.67798"
  },
  {
    "country": "FR",
    "name": "Dieppe",
    "lat": "49.93333",
    "lng": "1.08333"
  },
  {
    "country": "FR",
    "name": "Diémoz",
    "lat": "45.58651",
    "lng": "5.09397"
  },
  {
    "country": "FR",
    "name": "Diemeringen",
    "lat": "48.94013",
    "lng": "7.18839"
  },
  {
    "country": "FR",
    "name": "Diebling",
    "lat": "49.10966",
    "lng": "6.93974"
  },
  {
    "country": "FR",
    "name": "Die",
    "lat": "44.75",
    "lng": "5.36667"
  },
  {
    "country": "FR",
    "name": "Didenheim",
    "lat": "47.71737",
    "lng": "7.3022"
  },
  {
    "country": "FR",
    "name": "Dhuizon",
    "lat": "47.58723",
    "lng": "1.65809"
  },
  {
    "country": "FR",
    "name": "Deyvillers",
    "lat": "48.20013",
    "lng": "6.51533"
  },
  {
    "country": "FR",
    "name": "Déville-lès-Rouen",
    "lat": "49.46942",
    "lng": "1.05214"
  },
  {
    "country": "FR",
    "name": "Deville",
    "lat": "49.87893",
    "lng": "4.7061"
  },
  {
    "country": "FR",
    "name": "Devecey",
    "lat": "47.32169",
    "lng": "6.019"
  },
  {
    "country": "FR",
    "name": "Deûlémont",
    "lat": "50.73333",
    "lng": "2.95"
  },
  {
    "country": "FR",
    "name": "Deuil-la-Barre",
    "lat": "48.97674",
    "lng": "2.32722"
  },
  {
    "country": "FR",
    "name": "Dettwiller",
    "lat": "48.75415",
    "lng": "7.46633"
  },
  {
    "country": "FR",
    "name": "Desvres",
    "lat": "50.66884",
    "lng": "1.83478"
  },
  {
    "country": "FR",
    "name": "Dessenheim",
    "lat": "47.9763",
    "lng": "7.48886"
  },
  {
    "country": "FR",
    "name": "Désertines",
    "lat": "46.35521",
    "lng": "2.62074"
  },
  {
    "country": "FR",
    "name": "Désaignes",
    "lat": "44.99544",
    "lng": "4.51413"
  },
  {
    "country": "FR",
    "name": "Derval",
    "lat": "47.66724",
    "lng": "-1.6699"
  },
  {
    "country": "FR",
    "name": "Déols",
    "lat": "46.82934",
    "lng": "1.70428"
  },
  {
    "country": "FR",
    "name": "Denicé",
    "lat": "46.00141",
    "lng": "4.64523"
  },
  {
    "country": "FR",
    "name": "Denguin",
    "lat": "43.36667",
    "lng": "-0.5"
  },
  {
    "country": "FR",
    "name": "Denée",
    "lat": "47.37885",
    "lng": "-0.60816"
  },
  {
    "country": "FR",
    "name": "Denain",
    "lat": "50.3293",
    "lng": "3.3943"
  },
  {
    "country": "FR",
    "name": "Démouville",
    "lat": "49.18001",
    "lng": "-0.26947"
  },
  {
    "country": "FR",
    "name": "Demigny",
    "lat": "46.93048",
    "lng": "4.83381"
  },
  {
    "country": "FR",
    "name": "Delle",
    "lat": "47.51048",
    "lng": "6.99963"
  },
  {
    "country": "FR",
    "name": "Decize",
    "lat": "46.82852",
    "lng": "3.46192"
  },
  {
    "country": "FR",
    "name": "Décines-Charpieu",
    "lat": "45.76899",
    "lng": "4.97277"
  },
  {
    "country": "FR",
    "name": "Dechy",
    "lat": "50.35",
    "lng": "3.11667"
  },
  {
    "country": "FR",
    "name": "Decazeville",
    "lat": "44.56045",
    "lng": "2.25091"
  },
  {
    "country": "FR",
    "name": "Deauville",
    "lat": "49.357",
    "lng": "0.06995"
  },
  {
    "country": "FR",
    "name": "Dax",
    "lat": "43.71032",
    "lng": "-1.05366"
  },
  {
    "country": "FR",
    "name": "Davézieux",
    "lat": "45.25732",
    "lng": "4.70875"
  },
  {
    "country": "FR",
    "name": "Daux",
    "lat": "43.69506",
    "lng": "1.26892"
  },
  {
    "country": "FR",
    "name": "Daumeray",
    "lat": "47.7007",
    "lng": "-0.36119"
  },
  {
    "country": "FR",
    "name": "Dauendorf",
    "lat": "48.82987",
    "lng": "7.65532"
  },
  {
    "country": "FR",
    "name": "Dasle",
    "lat": "47.47843",
    "lng": "6.89728"
  },
  {
    "country": "FR",
    "name": "Darvoy",
    "lat": "47.85839",
    "lng": "2.10033"
  },
  {
    "country": "FR",
    "name": "Darnieulles",
    "lat": "48.1995",
    "lng": "6.34929"
  },
  {
    "country": "FR",
    "name": "Darney",
    "lat": "48.0866",
    "lng": "6.04917"
  },
  {
    "country": "FR",
    "name": "Darnétal",
    "lat": "49.44533",
    "lng": "1.15144"
  },
  {
    "country": "FR",
    "name": "Dargnies",
    "lat": "50.04144",
    "lng": "1.52526"
  },
  {
    "country": "FR",
    "name": "Dardilly",
    "lat": "45.80506",
    "lng": "4.75342"
  },
  {
    "country": "FR",
    "name": "Daoulas",
    "lat": "48.36089",
    "lng": "-4.25977"
  },
  {
    "country": "FR",
    "name": "Dannes",
    "lat": "50.58799",
    "lng": "1.61381"
  },
  {
    "country": "FR",
    "name": "Dannemarie-sur-Crête",
    "lat": "47.20488",
    "lng": "5.87018"
  },
  {
    "country": "FR",
    "name": "Dannemarie",
    "lat": "47.63031",
    "lng": "7.12237"
  },
  {
    "country": "FR",
    "name": "Danjoutin",
    "lat": "47.6156",
    "lng": "6.86637"
  },
  {
    "country": "FR",
    "name": "Dangé-Saint-Romain",
    "lat": "46.93333",
    "lng": "0.6"
  },
  {
    "country": "FR",
    "name": "Damville",
    "lat": "48.8693",
    "lng": "1.07458"
  },
  {
    "country": "FR",
    "name": "Damprichard",
    "lat": "47.24413",
    "lng": "6.88121"
  },
  {
    "country": "FR",
    "name": "Dampmart",
    "lat": "48.88854",
    "lng": "2.74095"
  },
  {
    "country": "FR",
    "name": "Dampierre-sur-Salon",
    "lat": "47.55719",
    "lng": "5.6797"
  },
  {
    "country": "FR",
    "name": "Dampierre-les-Bois",
    "lat": "47.50639",
    "lng": "6.91279"
  },
  {
    "country": "FR",
    "name": "Dampierre-en-Burly",
    "lat": "47.76143",
    "lng": "2.51962"
  },
  {
    "country": "FR",
    "name": "Dampierre-en-Yvelines",
    "lat": "48.7",
    "lng": "1.98333"
  },
  {
    "country": "FR",
    "name": "Dampierre",
    "lat": "47.15498",
    "lng": "5.74167"
  },
  {
    "country": "FR",
    "name": "Damparis",
    "lat": "47.07556",
    "lng": "5.41398"
  },
  {
    "country": "FR",
    "name": "Dammartin-en-Goële",
    "lat": "49.05423",
    "lng": "2.67777"
  },
  {
    "country": "FR",
    "name": "Dammarie-les-Lys",
    "lat": "48.51667",
    "lng": "2.65"
  },
  {
    "country": "FR",
    "name": "Dammarie",
    "lat": "48.34314",
    "lng": "1.49444"
  },
  {
    "country": "FR",
    "name": "Damigny",
    "lat": "48.45",
    "lng": "0.06667"
  },
  {
    "country": "FR",
    "name": "Damgan",
    "lat": "47.51799",
    "lng": "-2.57698"
  },
  {
    "country": "FR",
    "name": "Damery",
    "lat": "49.07238",
    "lng": "3.88036"
  },
  {
    "country": "FR",
    "name": "Damelevières",
    "lat": "48.55736",
    "lng": "6.38611"
  },
  {
    "country": "FR",
    "name": "Dambach-la-Ville",
    "lat": "48.32379",
    "lng": "7.42547"
  },
  {
    "country": "FR",
    "name": "Damazan",
    "lat": "44.29068",
    "lng": "0.27694"
  },
  {
    "country": "FR",
    "name": "Dallet",
    "lat": "45.77039",
    "lng": "3.23906"
  },
  {
    "country": "FR",
    "name": "Daix",
    "lat": "47.35081",
    "lng": "5.00052"
  },
  {
    "country": "FR",
    "name": "Dainville",
    "lat": "50.28097",
    "lng": "2.72603"
  },
  {
    "country": "FR",
    "name": "Dagneux",
    "lat": "45.8514",
    "lng": "5.0778"
  },
  {
    "country": "FR",
    "name": "Dadonville",
    "lat": "48.15776",
    "lng": "2.2715"
  },
  {
    "country": "FR",
    "name": "Dachstein",
    "lat": "48.56127",
    "lng": "7.53233"
  },
  {
    "country": "FR",
    "name": "Dabo",
    "lat": "48.65373",
    "lng": "7.23611"
  },
  {
    "country": "FR",
    "name": "Cysoing",
    "lat": "50.56939",
    "lng": "3.21627"
  },
  {
    "country": "FR",
    "name": "Cuzieu",
    "lat": "45.6084",
    "lng": "4.25858"
  },
  {
    "country": "FR",
    "name": "Cuxac-Cabardès",
    "lat": "43.37087",
    "lng": "2.28369"
  },
  {
    "country": "FR",
    "name": "Cuverville",
    "lat": "49.18998",
    "lng": "-0.26474"
  },
  {
    "country": "FR",
    "name": "Cuttoli-Corticchiato",
    "lat": "41.98333",
    "lng": "8.91667"
  },
  {
    "country": "FR",
    "name": "Cusy",
    "lat": "45.76633",
    "lng": "6.02695"
  },
  {
    "country": "FR",
    "name": "Custines",
    "lat": "48.79363",
    "lng": "6.14835"
  },
  {
    "country": "FR",
    "name": "Cusset",
    "lat": "46.13002",
    "lng": "3.45963"
  },
  {
    "country": "FR",
    "name": "Cussac",
    "lat": "45.70666",
    "lng": "0.85124"
  },
  {
    "country": "FR",
    "name": "Cussac-Fort-Médoc",
    "lat": "45.11667",
    "lng": "-0.73333"
  },
  {
    "country": "FR",
    "name": "Cussac-sur-Loire",
    "lat": "44.98807",
    "lng": "3.88416"
  },
  {
    "country": "FR",
    "name": "Curtin",
    "lat": "45.64353",
    "lng": "5.48982"
  },
  {
    "country": "FR",
    "name": "Curgy",
    "lat": "46.98714",
    "lng": "4.38452"
  },
  {
    "country": "FR",
    "name": "Curgies",
    "lat": "50.32975",
    "lng": "3.60299"
  },
  {
    "country": "FR",
    "name": "Cunlhat",
    "lat": "45.63348",
    "lng": "3.5598"
  },
  {
    "country": "FR",
    "name": "Cunac",
    "lat": "43.9301",
    "lng": "2.21878"
  },
  {
    "country": "FR",
    "name": "Culoz",
    "lat": "45.84964",
    "lng": "5.78081"
  },
  {
    "country": "FR",
    "name": "Culhat",
    "lat": "45.86254",
    "lng": "3.33566"
  },
  {
    "country": "FR",
    "name": "Cuisiat",
    "lat": "46.30021",
    "lng": "5.38809"
  },
  {
    "country": "FR",
    "name": "Cuisery",
    "lat": "46.55696",
    "lng": "4.99797"
  },
  {
    "country": "FR",
    "name": "Cuise-la-Motte",
    "lat": "49.38642",
    "lng": "3.00588"
  },
  {
    "country": "FR",
    "name": "Cuiseaux",
    "lat": "46.49473",
    "lng": "5.38931"
  },
  {
    "country": "FR",
    "name": "Cuincy",
    "lat": "50.37933",
    "lng": "3.05301"
  },
  {
    "country": "FR",
    "name": "Cuinchy",
    "lat": "50.5175",
    "lng": "2.7488"
  },
  {
    "country": "FR",
    "name": "Cugnaux",
    "lat": "43.53635",
    "lng": "1.34428"
  },
  {
    "country": "FR",
    "name": "Cuges-les-Pins",
    "lat": "43.27585",
    "lng": "5.69944"
  },
  {
    "country": "FR",
    "name": "Cugand",
    "lat": "47.06318",
    "lng": "-1.2527"
  },
  {
    "country": "FR",
    "name": "Cuffy",
    "lat": "46.96275",
    "lng": "3.05238"
  },
  {
    "country": "FR",
    "name": "Cuffies",
    "lat": "49.40358",
    "lng": "3.32119"
  },
  {
    "country": "FR",
    "name": "Cuers",
    "lat": "43.23731",
    "lng": "6.07107"
  },
  {
    "country": "FR",
    "name": "Cucuron",
    "lat": "43.77321",
    "lng": "5.439"
  },
  {
    "country": "FR",
    "name": "Cucq",
    "lat": "50.47733",
    "lng": "1.62018"
  },
  {
    "country": "FR",
    "name": "Cubzac-les-Ponts",
    "lat": "44.97119",
    "lng": "-0.44976"
  },
  {
    "country": "FR",
    "name": "Cublize",
    "lat": "46.0204",
    "lng": "4.37953"
  },
  {
    "country": "FR",
    "name": "Cublac",
    "lat": "45.14488",
    "lng": "1.30609"
  },
  {
    "country": "FR",
    "name": "Crusnes",
    "lat": "49.43359",
    "lng": "5.91536"
  },
  {
    "country": "FR",
    "name": "Cruseilles",
    "lat": "46.03333",
    "lng": "6.11667"
  },
  {
    "country": "FR",
    "name": "Cruet",
    "lat": "45.5289",
    "lng": "6.0922"
  },
  {
    "country": "FR",
    "name": "Cruas",
    "lat": "44.65544",
    "lng": "4.76144"
  },
  {
    "country": "FR",
    "name": "Crozon",
    "lat": "48.24643",
    "lng": "-4.48993"
  },
  {
    "country": "FR",
    "name": "Crouy-sur-Ourcq",
    "lat": "49.0898",
    "lng": "3.0753"
  },
  {
    "country": "FR",
    "name": "Crouy-en-Thelle",
    "lat": "49.21487",
    "lng": "2.32146"
  },
  {
    "country": "FR",
    "name": "Crouy",
    "lat": "49.40274",
    "lng": "3.35834"
  },
  {
    "country": "FR",
    "name": "Crottet",
    "lat": "46.27778",
    "lng": "4.89249"
  },
  {
    "country": "FR",
    "name": "Croth",
    "lat": "48.84557",
    "lng": "1.37861"
  },
  {
    "country": "FR",
    "name": "Crossac",
    "lat": "47.41119",
    "lng": "-2.16952"
  },
  {
    "country": "FR",
    "name": "Crosne",
    "lat": "48.71921",
    "lng": "2.45728"
  },
  {
    "country": "FR",
    "name": "Crolles",
    "lat": "45.28198",
    "lng": "5.87824"
  },
  {
    "country": "FR",
    "name": "Croix",
    "lat": "50.67846",
    "lng": "3.1493"
  },
  {
    "country": "FR",
    "name": "Croissy-sur-Seine",
    "lat": "48.87925",
    "lng": "2.13836"
  },
  {
    "country": "FR",
    "name": "Croissy-Beaubourg",
    "lat": "48.8283",
    "lng": "2.66964"
  },
  {
    "country": "FR",
    "name": "Croisilles",
    "lat": "50.19978",
    "lng": "2.87935"
  },
  {
    "country": "FR",
    "name": "Crissey",
    "lat": "46.81652",
    "lng": "4.88185"
  },
  {
    "country": "FR",
    "name": "Crisolles",
    "lat": "49.6225",
    "lng": "3.01451"
  },
  {
    "country": "FR",
    "name": "Criquetot-l’Esneval",
    "lat": "49.64555",
    "lng": "0.26571"
  },
  {
    "country": "FR",
    "name": "Criquebeuf-sur-Seine",
    "lat": "49.30563",
    "lng": "1.09964"
  },
  {
    "country": "FR",
    "name": "Criel-sur-Mer",
    "lat": "50.01508",
    "lng": "1.31459"
  },
  {
    "country": "FR",
    "name": "Crézancy",
    "lat": "49.04833",
    "lng": "3.51047"
  },
  {
    "country": "FR",
    "name": "Creysse",
    "lat": "44.85474",
    "lng": "0.56583"
  },
  {
    "country": "FR",
    "name": "Creys-Mépieu",
    "lat": "45.73333",
    "lng": "5.48333"
  },
  {
    "country": "FR",
    "name": "Crevin",
    "lat": "47.93333",
    "lng": "-1.66667"
  },
  {
    "country": "FR",
    "name": "Crèvecœur-le-Grand",
    "lat": "49.6",
    "lng": "2.08333"
  },
  {
    "country": "FR",
    "name": "Creuzier-le-Vieux",
    "lat": "46.16253",
    "lng": "3.43311"
  },
  {
    "country": "FR",
    "name": "Creutzwald",
    "lat": "49.20531",
    "lng": "6.69668"
  },
  {
    "country": "FR",
    "name": "Creully",
    "lat": "49.28478",
    "lng": "-0.53976"
  },
  {
    "country": "FR",
    "name": "Créteil",
    "lat": "48.79266",
    "lng": "2.46569"
  },
  {
    "country": "FR",
    "name": "Crest",
    "lat": "44.72836",
    "lng": "5.02722"
  },
  {
    "country": "FR",
    "name": "Cresserons",
    "lat": "49.28701",
    "lng": "-0.35569"
  },
  {
    "country": "FR",
    "name": "Crespin",
    "lat": "50.4211",
    "lng": "3.66137"
  },
  {
    "country": "FR",
    "name": "Crespières",
    "lat": "48.88317",
    "lng": "1.92151"
  },
  {
    "country": "FR",
    "name": "Crépy-en-Valois",
    "lat": "49.23359",
    "lng": "2.88807"
  },
  {
    "country": "FR",
    "name": "Crépy",
    "lat": "49.6",
    "lng": "3.51667"
  },
  {
    "country": "FR",
    "name": "Créon",
    "lat": "44.77457",
    "lng": "-0.348"
  },
  {
    "country": "FR",
    "name": "Creney-près-Troyes",
    "lat": "48.33333",
    "lng": "4.13333"
  },
  {
    "country": "FR",
    "name": "Crémieu",
    "lat": "45.72899",
    "lng": "5.24839"
  },
  {
    "country": "FR",
    "name": "Creissels",
    "lat": "44.08588",
    "lng": "3.06071"
  },
  {
    "country": "FR",
    "name": "Creissan",
    "lat": "43.37524",
    "lng": "3.01196"
  },
  {
    "country": "FR",
    "name": "Creil",
    "lat": "49.25672",
    "lng": "2.48477"
  },
  {
    "country": "FR",
    "name": "Créhen",
    "lat": "48.54546",
    "lng": "-2.21307"
  },
  {
    "country": "FR",
    "name": "Créhange",
    "lat": "49.05897",
    "lng": "6.58178"
  },
  {
    "country": "FR",
    "name": "Crégy-lès-Meaux",
    "lat": "48.97648",
    "lng": "2.87483"
  },
  {
    "country": "FR",
    "name": "Crédin",
    "lat": "48.03462",
    "lng": "-2.7663"
  },
  {
    "country": "FR",
    "name": "Crécy-sur-Serre",
    "lat": "49.69594",
    "lng": "3.62453"
  },
  {
    "country": "FR",
    "name": "Crécy-en-Ponthieu",
    "lat": "50.25193",
    "lng": "1.88085"
  },
  {
    "country": "FR",
    "name": "Crêches-sur-Saône",
    "lat": "46.24475",
    "lng": "4.78678"
  },
  {
    "country": "FR",
    "name": "Créances",
    "lat": "49.19873",
    "lng": "-1.56938"
  },
  {
    "country": "FR",
    "name": "Cravanche",
    "lat": "47.65644",
    "lng": "6.83647"
  },
  {
    "country": "FR",
    "name": "Craponne-sur-Arzon",
    "lat": "45.33135",
    "lng": "3.84802"
  },
  {
    "country": "FR",
    "name": "Craponne",
    "lat": "45.74684",
    "lng": "4.72661"
  },
  {
    "country": "FR",
    "name": "Craon",
    "lat": "47.84687",
    "lng": "-0.94929"
  },
  {
    "country": "FR",
    "name": "Cranves-Sales",
    "lat": "46.18746",
    "lng": "6.29108"
  },
  {
    "country": "FR",
    "name": "Cransac",
    "lat": "44.52411",
    "lng": "2.2837"
  },
  {
    "country": "FR",
    "name": "Cran-Gevrier",
    "lat": "45.9",
    "lng": "6.1"
  },
  {
    "country": "FR",
    "name": "Crach",
    "lat": "47.617",
    "lng": "-3.0017"
  },
  {
    "country": "FR",
    "name": "Cozes",
    "lat": "45.58375",
    "lng": "-0.83178"
  },
  {
    "country": "FR",
    "name": "Coye-la-Forêt",
    "lat": "49.14233",
    "lng": "2.47038"
  },
  {
    "country": "FR",
    "name": "Couzon-au-Mont-d’Or",
    "lat": "45.84461",
    "lng": "4.82674"
  },
  {
    "country": "FR",
    "name": "Couzeix",
    "lat": "45.87047",
    "lng": "1.23828"
  },
  {
    "country": "FR",
    "name": "Coux",
    "lat": "44.73484",
    "lng": "4.62057"
  },
  {
    "country": "FR",
    "name": "Couvron-et-Aumencourt",
    "lat": "49.64476",
    "lng": "3.51857"
  },
  {
    "country": "FR",
    "name": "Coutras",
    "lat": "45.03333",
    "lng": "-0.13333"
  },
  {
    "country": "FR",
    "name": "Coutouvre",
    "lat": "46.07298",
    "lng": "4.21243"
  },
  {
    "country": "FR",
    "name": "Coutiches",
    "lat": "50.4552",
    "lng": "3.20384"
  },
  {
    "country": "FR",
    "name": "Couternon",
    "lat": "47.33333",
    "lng": "5.15"
  },
  {
    "country": "FR",
    "name": "Couterne",
    "lat": "48.51318",
    "lng": "-0.41538"
  },
  {
    "country": "FR",
    "name": "Coutances",
    "lat": "49.05",
    "lng": "-1.43333"
  },
  {
    "country": "FR",
    "name": "Coussac-Bonneval",
    "lat": "45.51199",
    "lng": "1.32261"
  },
  {
    "country": "FR",
    "name": "Cousolre",
    "lat": "50.24607",
    "lng": "4.14941"
  },
  {
    "country": "FR",
    "name": "Cousance",
    "lat": "46.53324",
    "lng": "5.39214"
  },
  {
    "country": "FR",
    "name": "Courzieu",
    "lat": "45.74309",
    "lng": "4.57034"
  },
  {
    "country": "FR",
    "name": "Courville-sur-Eure",
    "lat": "48.44899",
    "lng": "1.24085"
  },
  {
    "country": "FR",
    "name": "Courtry",
    "lat": "48.91906",
    "lng": "2.60431"
  },
  {
    "country": "FR",
    "name": "Courtisols",
    "lat": "48.9867",
    "lng": "4.517"
  },
  {
    "country": "FR",
    "name": "Courthézon",
    "lat": "44.08731",
    "lng": "4.88382"
  },
  {
    "country": "FR",
    "name": "Courtenay",
    "lat": "48.03901",
    "lng": "3.05851"
  },
  {
    "country": "FR",
    "name": "Courteilles",
    "lat": "48.77495",
    "lng": "-0.19942"
  },
  {
    "country": "FR",
    "name": "Cours-les-Barres",
    "lat": "47.02513",
    "lng": "3.03167"
  },
  {
    "country": "FR",
    "name": "Courseulles-sur-Mer",
    "lat": "49.33027",
    "lng": "-0.45612"
  },
  {
    "country": "FR",
    "name": "Cours-de-Pile",
    "lat": "44.83608",
    "lng": "0.54656"
  },
  {
    "country": "FR",
    "name": "Coursan",
    "lat": "43.2337",
    "lng": "3.05712"
  },
  {
    "country": "FR",
    "name": "Coursac",
    "lat": "45.12881",
    "lng": "0.63919"
  },
  {
    "country": "FR",
    "name": "Cours-la-Ville",
    "lat": "46.1",
    "lng": "4.31667"
  },
  {
    "country": "FR",
    "name": "Courrières",
    "lat": "50.45701",
    "lng": "2.94725"
  },
  {
    "country": "FR",
    "name": "Courpière",
    "lat": "45.75689",
    "lng": "3.54216"
  },
  {
    "country": "FR",
    "name": "Courpalay",
    "lat": "48.64947",
    "lng": "2.96116"
  },
  {
    "country": "FR",
    "name": "Cournonterral",
    "lat": "43.55889",
    "lng": "3.72"
  },
  {
    "country": "FR",
    "name": "Cournonsec",
    "lat": "43.54944",
    "lng": "3.70556"
  },
  {
    "country": "FR",
    "name": "Cournon-d’Auvergne",
    "lat": "45.73543",
    "lng": "3.19608"
  },
  {
    "country": "FR",
    "name": "Courmelles",
    "lat": "49.34595",
    "lng": "3.31215"
  },
  {
    "country": "FR",
    "name": "Courlon-sur-Yonne",
    "lat": "48.33927",
    "lng": "3.1666"
  },
  {
    "country": "FR",
    "name": "Courlay",
    "lat": "46.77941",
    "lng": "-0.56607"
  },
  {
    "country": "FR",
    "name": "Courdimanche",
    "lat": "49.03513",
    "lng": "2.00096"
  },
  {
    "country": "FR",
    "name": "Courcy",
    "lat": "49.32361",
    "lng": "4.00257"
  },
  {
    "country": "FR",
    "name": "Courcouronnes",
    "lat": "48.61429",
    "lng": "2.40762"
  },
  {
    "country": "FR",
    "name": "Courçon",
    "lat": "46.24389",
    "lng": "-0.813"
  },
  {
    "country": "FR",
    "name": "Courcité",
    "lat": "48.30633",
    "lng": "-0.24961"
  },
  {
    "country": "FR",
    "name": "Cour-Cheverny",
    "lat": "47.51033",
    "lng": "1.45583"
  },
  {
    "country": "FR",
    "name": "Courchevel",
    "lat": "45.41538",
    "lng": "6.63643"
  },
  {
    "country": "FR",
    "name": "Courchelettes",
    "lat": "50.34043",
    "lng": "3.05938"
  },
  {
    "country": "FR",
    "name": "Courcelles-sur-Seine",
    "lat": "49.18285",
    "lng": "1.36008"
  },
  {
    "country": "FR",
    "name": "Courcelles-lès-Montbéliard",
    "lat": "47.50113",
    "lng": "6.78461"
  },
  {
    "country": "FR",
    "name": "Courcelles-lès-Lens",
    "lat": "50.41667",
    "lng": "3.01667"
  },
  {
    "country": "FR",
    "name": "Courcelles-Chaussy",
    "lat": "49.1094",
    "lng": "6.40153"
  },
  {
    "country": "FR",
    "name": "Courbevoie",
    "lat": "48.89672",
    "lng": "2.25666"
  },
  {
    "country": "FR",
    "name": "Coupvray",
    "lat": "48.89289",
    "lng": "2.7967"
  },
  {
    "country": "FR",
    "name": "Coulounieix-Chamiers",
    "lat": "45.15289",
    "lng": "0.68852"
  },
  {
    "country": "FR",
    "name": "Coulonges-sur-l’Autize",
    "lat": "46.48333",
    "lng": "-0.59845"
  },
  {
    "country": "FR",
    "name": "Coulon",
    "lat": "46.32328",
    "lng": "-0.58561"
  },
  {
    "country": "FR",
    "name": "Coulommiers",
    "lat": "48.81451",
    "lng": "3.08498"
  },
  {
    "country": "FR",
    "name": "Coulombs",
    "lat": "48.65253",
    "lng": "1.54646"
  },
  {
    "country": "FR",
    "name": "Coulombiers",
    "lat": "46.48324",
    "lng": "0.18494"
  },
  {
    "country": "FR",
    "name": "Coulogne",
    "lat": "50.92463",
    "lng": "1.88137"
  },
  {
    "country": "FR",
    "name": "Coullons",
    "lat": "47.62105",
    "lng": "2.49258"
  },
  {
    "country": "FR",
    "name": "Coulans-sur-Gée",
    "lat": "48.0207",
    "lng": "0.00974"
  },
  {
    "country": "FR",
    "name": "Coulanges-lès-Nevers",
    "lat": "47.00509",
    "lng": "3.18756"
  },
  {
    "country": "FR",
    "name": "Coulaines",
    "lat": "48.02409",
    "lng": "0.20411"
  },
  {
    "country": "FR",
    "name": "Couiza",
    "lat": "42.94198",
    "lng": "2.25453"
  },
  {
    "country": "FR",
    "name": "Couilly-Pont-aux-Dames",
    "lat": "48.88473",
    "lng": "2.85677"
  },
  {
    "country": "FR",
    "name": "Couhé",
    "lat": "46.29911",
    "lng": "0.18174"
  },
  {
    "country": "FR",
    "name": "Coufouleux",
    "lat": "43.81713",
    "lng": "1.73078"
  },
  {
    "country": "FR",
    "name": "Couffé",
    "lat": "47.3912",
    "lng": "-1.29321"
  },
  {
    "country": "FR",
    "name": "Couëron",
    "lat": "47.21508",
    "lng": "-1.72171"
  },
  {
    "country": "FR",
    "name": "Coudun",
    "lat": "49.46146",
    "lng": "2.81248"
  },
  {
    "country": "FR",
    "name": "Coudoux",
    "lat": "43.558",
    "lng": "5.24889"
  },
  {
    "country": "FR",
    "name": "Coudekerque-Branche",
    "lat": "51.02288",
    "lng": "2.39359"
  },
  {
    "country": "FR",
    "name": "Coudekerque-Village",
    "lat": "51",
    "lng": "2.41667"
  },
  {
    "country": "FR",
    "name": "Coucy-le-Château-Auffrique",
    "lat": "49.52083",
    "lng": "3.32381"
  },
  {
    "country": "FR",
    "name": "Couchey",
    "lat": "47.25991",
    "lng": "4.98257"
  },
  {
    "country": "FR",
    "name": "Couches",
    "lat": "46.86667",
    "lng": "4.56667"
  },
  {
    "country": "FR",
    "name": "Coubron",
    "lat": "48.91667",
    "lng": "2.58333"
  },
  {
    "country": "FR",
    "name": "Coubon",
    "lat": "44.99731",
    "lng": "3.91783"
  },
  {
    "country": "FR",
    "name": "Coublevie",
    "lat": "45.35624",
    "lng": "5.61759"
  },
  {
    "country": "FR",
    "name": "Coubert",
    "lat": "48.67186",
    "lng": "2.69733"
  },
  {
    "country": "FR",
    "name": "Cotignac",
    "lat": "43.52841",
    "lng": "6.15"
  },
  {
    "country": "FR",
    "name": "Cossé-le-Vivien",
    "lat": "47.94599",
    "lng": "-0.91185"
  },
  {
    "country": "FR",
    "name": "Cosne-Cours-sur-Loire",
    "lat": "47.41101",
    "lng": "2.92528"
  },
  {
    "country": "FR",
    "name": "Cosnes-et-Romain",
    "lat": "49.51943",
    "lng": "5.71765"
  },
  {
    "country": "FR",
    "name": "Cosnac",
    "lat": "45.13516",
    "lng": "1.58575"
  },
  {
    "country": "FR",
    "name": "Corzé",
    "lat": "47.55956",
    "lng": "-0.39062"
  },
  {
    "country": "FR",
    "name": "Corte",
    "lat": "42.30956",
    "lng": "9.14917"
  },
  {
    "country": "FR",
    "name": "Corseul",
    "lat": "48.4818",
    "lng": "-2.16947"
  },
  {
    "country": "FR",
    "name": "Corsept",
    "lat": "47.27703",
    "lng": "-2.05904"
  },
  {
    "country": "FR",
    "name": "Corrèze",
    "lat": "45.37273",
    "lng": "1.87465"
  },
  {
    "country": "FR",
    "name": "Corquilleroy",
    "lat": "48.04212",
    "lng": "2.70382"
  },
  {
    "country": "FR",
    "name": "Corps-Nuds",
    "lat": "47.97915",
    "lng": "-1.58409"
  },
  {
    "country": "FR",
    "name": "Corpeau",
    "lat": "46.92917",
    "lng": "4.75226"
  },
  {
    "country": "FR",
    "name": "Coron",
    "lat": "47.12726",
    "lng": "-0.64512"
  },
  {
    "country": "FR",
    "name": "Corny-sur-Moselle",
    "lat": "49.03557",
    "lng": "6.06084"
  },
  {
    "country": "FR",
    "name": "Cornimont",
    "lat": "47.95998",
    "lng": "6.83038"
  },
  {
    "country": "FR",
    "name": "Cornillon-Confoux",
    "lat": "43.56667",
    "lng": "5.06667"
  },
  {
    "country": "FR",
    "name": "Cornil",
    "lat": "45.21168",
    "lng": "1.69204"
  },
  {
    "country": "FR",
    "name": "Cornier",
    "lat": "46.09378",
    "lng": "6.29796"
  },
  {
    "country": "FR",
    "name": "Corneville-sur-Risle",
    "lat": "49.34128",
    "lng": "0.58628"
  },
  {
    "country": "FR",
    "name": "Corneilla-la-Rivière",
    "lat": "42.69675",
    "lng": "2.72962"
  },
  {
    "country": "FR",
    "name": "Corneilla-del-Vercol",
    "lat": "42.6239",
    "lng": "2.95216"
  },
  {
    "country": "FR",
    "name": "Corneilhan",
    "lat": "43.39957",
    "lng": "3.19147"
  },
  {
    "country": "FR",
    "name": "Cornebarrieu",
    "lat": "43.64895",
    "lng": "1.32407"
  },
  {
    "country": "FR",
    "name": "Corné",
    "lat": "47.47091",
    "lng": "-0.34992"
  },
  {
    "country": "FR",
    "name": "Cornas",
    "lat": "44.96498",
    "lng": "4.84806"
  },
  {
    "country": "FR",
    "name": "Cormontreuil",
    "lat": "49.21667",
    "lng": "4.05"
  },
  {
    "country": "FR",
    "name": "Cormicy",
    "lat": "49.37071",
    "lng": "3.89595"
  },
  {
    "country": "FR",
    "name": "Cormery",
    "lat": "47.26812",
    "lng": "0.83583"
  },
  {
    "country": "FR",
    "name": "Corme-Royal",
    "lat": "45.74395",
    "lng": "-0.81471"
  },
  {
    "country": "FR",
    "name": "Cormeray",
    "lat": "47.49195",
    "lng": "1.4061"
  },
  {
    "country": "FR",
    "name": "Cormelles-le-Royal",
    "lat": "49.15398",
    "lng": "-0.33062"
  },
  {
    "country": "FR",
    "name": "Cormeilles-en-Parisis",
    "lat": "48.97111",
    "lng": "2.20491"
  },
  {
    "country": "FR",
    "name": "Cormeilles",
    "lat": "49.24803",
    "lng": "0.37654"
  },
  {
    "country": "FR",
    "name": "Corlay",
    "lat": "48.31725",
    "lng": "-3.05733"
  },
  {
    "country": "FR",
    "name": "Corenc",
    "lat": "45.21421",
    "lng": "5.77152"
  },
  {
    "country": "FR",
    "name": "Cordon",
    "lat": "45.92408",
    "lng": "6.61237"
  },
  {
    "country": "FR",
    "name": "Cordes-sur-Ciel",
    "lat": "44.06667",
    "lng": "1.95"
  },
  {
    "country": "FR",
    "name": "Cordemais",
    "lat": "47.29107",
    "lng": "-1.87869"
  },
  {
    "country": "FR",
    "name": "Corcieux",
    "lat": "48.17236",
    "lng": "6.88148"
  },
  {
    "country": "FR",
    "name": "Corbreuse",
    "lat": "48.50065",
    "lng": "1.95913"
  },
  {
    "country": "FR",
    "name": "Corbigny",
    "lat": "47.25678",
    "lng": "3.68285"
  },
  {
    "country": "FR",
    "name": "Corbie",
    "lat": "49.90672",
    "lng": "2.50682"
  },
  {
    "country": "FR",
    "name": "Corbenay",
    "lat": "47.89275",
    "lng": "6.33047"
  },
  {
    "country": "FR",
    "name": "Corbelin",
    "lat": "45.60868",
    "lng": "5.54448"
  },
  {
    "country": "FR",
    "name": "Corbeilles",
    "lat": "48.07201",
    "lng": "2.5503"
  },
  {
    "country": "FR",
    "name": "Corbeil-Essonnes",
    "lat": "48.60603",
    "lng": "2.48757"
  },
  {
    "country": "FR",
    "name": "Corbehem",
    "lat": "50.33141",
    "lng": "3.04995"
  },
  {
    "country": "FR",
    "name": "Corbas",
    "lat": "45.6679",
    "lng": "4.89627"
  },
  {
    "country": "FR",
    "name": "Corbarieu",
    "lat": "43.94415",
    "lng": "1.36881"
  },
  {
    "country": "FR",
    "name": "Coray",
    "lat": "48.05934",
    "lng": "-3.83056"
  },
  {
    "country": "FR",
    "name": "Coquelles",
    "lat": "50.93461",
    "lng": "1.7988"
  },
  {
    "country": "FR",
    "name": "Conty",
    "lat": "49.741",
    "lng": "2.1512"
  },
  {
    "country": "FR",
    "name": "Contrexéville",
    "lat": "48.18424",
    "lng": "5.89572"
  },
  {
    "country": "FR",
    "name": "Contres",
    "lat": "47.41754",
    "lng": "1.42849"
  },
  {
    "country": "FR",
    "name": "Contes",
    "lat": "43.81278",
    "lng": "7.31444"
  },
  {
    "country": "FR",
    "name": "Contamine-sur-Arve",
    "lat": "46.12942",
    "lng": "6.33839"
  },
  {
    "country": "FR",
    "name": "Conques-sur-Orbiel",
    "lat": "43.26667",
    "lng": "2.41667"
  },
  {
    "country": "FR",
    "name": "Conquereuil",
    "lat": "47.62524",
    "lng": "-1.75105"
  },
  {
    "country": "FR",
    "name": "Connerré",
    "lat": "48.05698",
    "lng": "0.49344"
  },
  {
    "country": "FR",
    "name": "Connaux",
    "lat": "44.08919",
    "lng": "4.59387"
  },
  {
    "country": "FR",
    "name": "Connantre",
    "lat": "48.72657",
    "lng": "3.92403"
  },
  {
    "country": "FR",
    "name": "Conlie",
    "lat": "48.12334",
    "lng": "-0.01739"
  },
  {
    "country": "FR",
    "name": "Congrier",
    "lat": "47.80989",
    "lng": "-1.117"
  },
  {
    "country": "FR",
    "name": "Congis-sur-Thérouanne",
    "lat": "49",
    "lng": "2.98333"
  },
  {
    "country": "FR",
    "name": "Congénies",
    "lat": "43.76667",
    "lng": "4.16667"
  },
  {
    "country": "FR",
    "name": "Confolens",
    "lat": "46.01667",
    "lng": "0.66667"
  },
  {
    "country": "FR",
    "name": "Conflans-Sainte-Honorine",
    "lat": "49.00158",
    "lng": "2.09694"
  },
  {
    "country": "FR",
    "name": "Conflans-en-Jarnisy",
    "lat": "49.16768",
    "lng": "5.84863"
  },
  {
    "country": "FR",
    "name": "Condrieu",
    "lat": "45.46344",
    "lng": "4.76848"
  },
  {
    "country": "FR",
    "name": "Condom",
    "lat": "43.95816",
    "lng": "0.37199"
  },
  {
    "country": "FR",
    "name": "Condette",
    "lat": "50.65817",
    "lng": "1.63386"
  },
  {
    "country": "FR",
    "name": "Condé-sur-Vire",
    "lat": "49.05",
    "lng": "-1.03333"
  },
  {
    "country": "FR",
    "name": "Condé-sur-Vesgre",
    "lat": "48.74199",
    "lng": "1.66069"
  },
  {
    "country": "FR",
    "name": "Condé-sur-Sarthe",
    "lat": "48.43197",
    "lng": "0.03398"
  },
  {
    "country": "FR",
    "name": "Condé-sur-Noireau",
    "lat": "48.84881",
    "lng": "-0.55214"
  },
  {
    "country": "FR",
    "name": "Condé-sur-l’Escaut",
    "lat": "50.45436",
    "lng": "3.58884"
  },
  {
    "country": "FR",
    "name": "Condé-sur-Huisne",
    "lat": "48.38103",
    "lng": "0.85093"
  },
  {
    "country": "FR",
    "name": "Condé-Sainte-Libiaire",
    "lat": "48.89695",
    "lng": "2.83904"
  },
  {
    "country": "FR",
    "name": "Condat-sur-Vienne",
    "lat": "45.78648",
    "lng": "1.28454"
  },
  {
    "country": "FR",
    "name": "Condat",
    "lat": "45.34093",
    "lng": "2.75791"
  },
  {
    "country": "FR",
    "name": "Conches-en-Ouche",
    "lat": "48.95768",
    "lng": "0.94052"
  },
  {
    "country": "FR",
    "name": "Conches-sur-Gondoire",
    "lat": "48.85624",
    "lng": "2.71783"
  },
  {
    "country": "FR",
    "name": "Concarneau",
    "lat": "47.87502",
    "lng": "-3.92245"
  },
  {
    "country": "FR",
    "name": "Comps",
    "lat": "43.85304",
    "lng": "4.60567"
  },
  {
    "country": "FR",
    "name": "Compreignac",
    "lat": "45.99162",
    "lng": "1.27561"
  },
  {
    "country": "FR",
    "name": "Compiègne",
    "lat": "49.41794",
    "lng": "2.82606"
  },
  {
    "country": "FR",
    "name": "Compertrix",
    "lat": "48.94179",
    "lng": "4.34631"
  },
  {
    "country": "FR",
    "name": "Communay",
    "lat": "45.60671",
    "lng": "4.83988"
  },
  {
    "country": "FR",
    "name": "Commercy",
    "lat": "48.76128",
    "lng": "5.59067"
  },
  {
    "country": "FR",
    "name": "Commer",
    "lat": "48.23333",
    "lng": "-0.61667"
  },
  {
    "country": "FR",
    "name": "Commequiers",
    "lat": "46.76049",
    "lng": "-1.83901"
  },
  {
    "country": "FR",
    "name": "Commentry",
    "lat": "46.29211",
    "lng": "2.7416"
  },
  {
    "country": "FR",
    "name": "Commelle-Vernay",
    "lat": "45.99439",
    "lng": "4.06635"
  },
  {
    "country": "FR",
    "name": "Comines",
    "lat": "50.7615",
    "lng": "3.01063"
  },
  {
    "country": "FR",
    "name": "Combs-la-Ville",
    "lat": "48.66497",
    "lng": "2.56957"
  },
  {
    "country": "FR",
    "name": "Combronde",
    "lat": "45.98138",
    "lng": "3.08768"
  },
  {
    "country": "FR",
    "name": "Combrit",
    "lat": "47.88734",
    "lng": "-4.15817"
  },
  {
    "country": "FR",
    "name": "Combrée",
    "lat": "47.70446",
    "lng": "-1.03003"
  },
  {
    "country": "FR",
    "name": "Combrand",
    "lat": "46.86405",
    "lng": "-0.68869"
  },
  {
    "country": "FR",
    "name": "Combourg",
    "lat": "48.41267",
    "lng": "-1.74424"
  },
  {
    "country": "FR",
    "name": "Combloux",
    "lat": "45.89669",
    "lng": "6.63444"
  },
  {
    "country": "FR",
    "name": "Pontault-Combault",
    "lat": "48.79813",
    "lng": "2.60676"
  },
  {
    "country": "FR",
    "name": "Combaillaux",
    "lat": "43.67191",
    "lng": "3.76767"
  },
  {
    "country": "FR",
    "name": "Colpo",
    "lat": "47.81778",
    "lng": "-2.81002"
  },
  {
    "country": "FR",
    "name": "Colomiers",
    "lat": "43.61058",
    "lng": "1.33467"
  },
  {
    "country": "FR",
    "name": "Colombiès",
    "lat": "44.34414",
    "lng": "2.33772"
  },
  {
    "country": "FR",
    "name": "Colombiers",
    "lat": "46.77158",
    "lng": "0.42388"
  },
  {
    "country": "FR",
    "name": "Colombiers",
    "lat": "43.31424",
    "lng": "3.13947"
  },
  {
    "country": "FR",
    "name": "Colombier-Fontaine",
    "lat": "47.45224",
    "lng": "6.6901"
  },
  {
    "country": "FR",
    "name": "Colombey-les-Belles",
    "lat": "48.52766",
    "lng": "5.89693"
  },
  {
    "country": "FR",
    "name": "Colombes",
    "lat": "48.91882",
    "lng": "2.25404"
  },
  {
    "country": "FR",
    "name": "Colombelles",
    "lat": "49.2049",
    "lng": "-0.29571"
  },
  {
    "country": "FR",
    "name": "Colombe",
    "lat": "45.39912",
    "lng": "5.45109"
  },
  {
    "country": "FR",
    "name": "Colomars",
    "lat": "43.75406",
    "lng": "7.2198"
  },
  {
    "country": "FR",
    "name": "Colmar",
    "lat": "48.07871",
    "lng": "7.3554"
  },
  {
    "country": "FR",
    "name": "Collonges-sous-Salève",
    "lat": "46.1416",
    "lng": "6.15372"
  },
  {
    "country": "FR",
    "name": "Collonges",
    "lat": "46.13894",
    "lng": "5.90334"
  },
  {
    "country": "FR",
    "name": "Collobrières",
    "lat": "43.23735",
    "lng": "6.30875"
  },
  {
    "country": "FR",
    "name": "Collioure",
    "lat": "42.52462",
    "lng": "3.08235"
  },
  {
    "country": "FR",
    "name": "Colleville-Montgomery",
    "lat": "49.27528",
    "lng": "-0.30052"
  },
  {
    "country": "FR",
    "name": "Colleret",
    "lat": "50.25693",
    "lng": "4.08083"
  },
  {
    "country": "FR",
    "name": "Collégien",
    "lat": "48.83571",
    "lng": "2.67365"
  },
  {
    "country": "FR",
    "name": "Coligny",
    "lat": "46.38252",
    "lng": "5.34554"
  },
  {
    "country": "FR",
    "name": "Colayrac-Saint-Cirq",
    "lat": "44.22095",
    "lng": "0.55061"
  },
  {
    "country": "FR",
    "name": "Coise-Saint-Jean-Pied-Gauthier",
    "lat": "45.52578",
    "lng": "6.14359"
  },
  {
    "country": "FR",
    "name": "Coincy",
    "lat": "49.16036",
    "lng": "3.42202"
  },
  {
    "country": "FR",
    "name": "Coignières",
    "lat": "48.7501",
    "lng": "1.92082"
  },
  {
    "country": "FR",
    "name": "Cogolin",
    "lat": "43.25221",
    "lng": "6.53002"
  },
  {
    "country": "FR",
    "name": "Cogny",
    "lat": "45.98732",
    "lng": "4.62501"
  },
  {
    "country": "FR",
    "name": "Cognin",
    "lat": "45.56377",
    "lng": "5.89435"
  },
  {
    "country": "FR",
    "name": "Cognac-la-Forêt",
    "lat": "45.83333",
    "lng": "1"
  },
  {
    "country": "FR",
    "name": "Cognac",
    "lat": "45.7",
    "lng": "-0.33333"
  },
  {
    "country": "FR",
    "name": "Coëx",
    "lat": "46.69808",
    "lng": "-1.75956"
  },
  {
    "country": "FR",
    "name": "Coëtmieux",
    "lat": "48.49117",
    "lng": "-2.60067"
  },
  {
    "country": "FR",
    "name": "Coësmes",
    "lat": "47.88325",
    "lng": "-1.44074"
  },
  {
    "country": "FR",
    "name": "Codognan",
    "lat": "43.73033",
    "lng": "4.2212"
  },
  {
    "country": "FR",
    "name": "Cocheren",
    "lat": "49.14384",
    "lng": "6.85649"
  },
  {
    "country": "FR",
    "name": "Coarraze",
    "lat": "43.16667",
    "lng": "-0.23333"
  },
  {
    "country": "FR",
    "name": "Cluses",
    "lat": "46.06251",
    "lng": "6.57497"
  },
  {
    "country": "FR",
    "name": "Cluny",
    "lat": "46.43318",
    "lng": "4.65845"
  },
  {
    "country": "FR",
    "name": "Cluis",
    "lat": "46.54486",
    "lng": "1.74933"
  },
  {
    "country": "FR",
    "name": "Cloyes-sur-le-Loir",
    "lat": "47.99726",
    "lng": "1.23711"
  },
  {
    "country": "FR",
    "name": "Clouange",
    "lat": "49.2624",
    "lng": "6.09723"
  },
  {
    "country": "FR",
    "name": "Clonas-sur-Varèze",
    "lat": "45.41326",
    "lng": "4.78996"
  },
  {
    "country": "FR",
    "name": "Clohars-Fouesnant",
    "lat": "47.89657",
    "lng": "-4.06396"
  },
  {
    "country": "FR",
    "name": "Clohars-Carnoët",
    "lat": "47.79606",
    "lng": "-3.58502"
  },
  {
    "country": "FR",
    "name": "Clisson",
    "lat": "47.08714",
    "lng": "-1.28286"
  },
  {
    "country": "FR",
    "name": "Clion",
    "lat": "46.94085",
    "lng": "1.23214"
  },
  {
    "country": "FR",
    "name": "Clinchamps-sur-Orne",
    "lat": "49.07857",
    "lng": "-0.40156"
  },
  {
    "country": "FR",
    "name": "Clichy-sous-Bois",
    "lat": "48.9102",
    "lng": "2.55323"
  },
  {
    "country": "FR",
    "name": "Clichy",
    "lat": "48.90018",
    "lng": "2.30952"
  },
  {
    "country": "FR",
    "name": "Cléry-Saint-André",
    "lat": "47.82218",
    "lng": "1.75091"
  },
  {
    "country": "FR",
    "name": "Clerval",
    "lat": "47.39167",
    "lng": "6.49925"
  },
  {
    "country": "FR",
    "name": "Clermont-Ferrand",
    "lat": "45.77966",
    "lng": "3.08628"
  },
  {
    "country": "FR",
    "name": "Clermont-en-Argonne",
    "lat": "49.10711",
    "lng": "5.07002"
  },
  {
    "country": "FR",
    "name": "Clermont-Créans",
    "lat": "47.71831",
    "lng": "-0.01459"
  },
  {
    "country": "FR",
    "name": "Clermont",
    "lat": "49.38333",
    "lng": "2.4"
  },
  {
    "country": "FR",
    "name": "Clérieux",
    "lat": "45.07722",
    "lng": "4.95937"
  },
  {
    "country": "FR",
    "name": "Clères",
    "lat": "49.6",
    "lng": "1.11667"
  },
  {
    "country": "FR",
    "name": "Cléré-les-Pins",
    "lat": "47.4255",
    "lng": "0.38963"
  },
  {
    "country": "FR",
    "name": "Clérac",
    "lat": "45.18333",
    "lng": "-0.21667"
  },
  {
    "country": "FR",
    "name": "Cléon",
    "lat": "49.31235",
    "lng": "1.0295"
  },
  {
    "country": "FR",
    "name": "Cléguérec",
    "lat": "48.12577",
    "lng": "-3.07162"
  },
  {
    "country": "FR",
    "name": "Cléguer",
    "lat": "47.85407",
    "lng": "-3.38219"
  },
  {
    "country": "FR",
    "name": "Cléder",
    "lat": "48.663",
    "lng": "-4.102"
  },
  {
    "country": "FR",
    "name": "Cléden-Poher",
    "lat": "48.23644",
    "lng": "-3.66911"
  },
  {
    "country": "FR",
    "name": "Clécy",
    "lat": "48.91718",
    "lng": "-0.48041"
  },
  {
    "country": "FR",
    "name": "Claye-Souilly",
    "lat": "48.94492",
    "lng": "2.68566"
  },
  {
    "country": "FR",
    "name": "Claville",
    "lat": "49.04844",
    "lng": "1.01954"
  },
  {
    "country": "FR",
    "name": "Clary",
    "lat": "50.07789",
    "lng": "3.39943"
  },
  {
    "country": "FR",
    "name": "Claret",
    "lat": "43.86244",
    "lng": "3.90522"
  },
  {
    "country": "FR",
    "name": "Clarensac",
    "lat": "43.82536",
    "lng": "4.22047"
  },
  {
    "country": "FR",
    "name": "Clapiers",
    "lat": "43.65833",
    "lng": "3.88917"
  },
  {
    "country": "FR",
    "name": "Clamecy",
    "lat": "47.45",
    "lng": "3.51667"
  },
  {
    "country": "FR",
    "name": "Clamart",
    "lat": "48.80299",
    "lng": "2.26692"
  },
  {
    "country": "FR",
    "name": "Claix",
    "lat": "45.12254",
    "lng": "5.67481"
  },
  {
    "country": "FR",
    "name": "Clairvaux-les-Lacs",
    "lat": "46.57473",
    "lng": "5.74825"
  },
  {
    "country": "FR",
    "name": "Clairoix",
    "lat": "49.44264",
    "lng": "2.84628"
  },
  {
    "country": "FR",
    "name": "Clairac",
    "lat": "44.36011",
    "lng": "0.37893"
  },
  {
    "country": "FR",
    "name": "Claira",
    "lat": "42.76036",
    "lng": "2.95572"
  },
  {
    "country": "FR",
    "name": "Civrieux",
    "lat": "45.92177",
    "lng": "4.88548"
  },
  {
    "country": "FR",
    "name": "Civray-de-Touraine",
    "lat": "47.33253",
    "lng": "1.04952"
  },
  {
    "country": "FR",
    "name": "Civray",
    "lat": "46.1471",
    "lng": "0.29509"
  },
  {
    "country": "FR",
    "name": "Civens",
    "lat": "45.77987",
    "lng": "4.2517"
  },
  {
    "country": "FR",
    "name": "Varennes-Vauzelles",
    "lat": "47.01678",
    "lng": "3.14037"
  },
  {
    "country": "FR",
    "name": "Cissé",
    "lat": "46.64583",
    "lng": "0.2287"
  },
  {
    "country": "FR",
    "name": "Ciry-le-Noble",
    "lat": "46.60607",
    "lng": "4.29869"
  },
  {
    "country": "FR",
    "name": "Cirey-sur-Vezouze",
    "lat": "48.58333",
    "lng": "6.95"
  },
  {
    "country": "FR",
    "name": "Cires-lès-Mello",
    "lat": "49.27242",
    "lng": "2.3584"
  },
  {
    "country": "FR",
    "name": "Ciré-d’Aunis",
    "lat": "46.05544",
    "lng": "-0.93056"
  },
  {
    "country": "FR",
    "name": "Cintré",
    "lat": "48.10504",
    "lng": "-1.87162"
  },
  {
    "country": "FR",
    "name": "Cintegabelle",
    "lat": "43.31316",
    "lng": "1.53333"
  },
  {
    "country": "FR",
    "name": "Cinqueux",
    "lat": "49.31739",
    "lng": "2.52997"
  },
  {
    "country": "FR",
    "name": "Cinq-Mars-la-Pile",
    "lat": "47.34638",
    "lng": "0.45873"
  },
  {
    "country": "FR",
    "name": "Ciboure",
    "lat": "43.38287",
    "lng": "-1.676"
  },
  {
    "country": "FR",
    "name": "Chuzelles",
    "lat": "45.58484",
    "lng": "4.87795"
  },
  {
    "country": "FR",
    "name": "Chouzy-sur-Cisse",
    "lat": "47.52576",
    "lng": "1.24661"
  },
  {
    "country": "FR",
    "name": "Chouzé-sur-Loire",
    "lat": "47.23673",
    "lng": "0.12364"
  },
  {
    "country": "FR",
    "name": "Chorges",
    "lat": "44.5471",
    "lng": "6.27752"
  },
  {
    "country": "FR",
    "name": "Chomérac",
    "lat": "44.70752",
    "lng": "4.66164"
  },
  {
    "country": "FR",
    "name": "Cholet",
    "lat": "47.06667",
    "lng": "-0.88333"
  },
  {
    "country": "FR",
    "name": "Choisy-le-Roi",
    "lat": "48.76846",
    "lng": "2.41874"
  },
  {
    "country": "FR",
    "name": "Choisy-en-Brie",
    "lat": "48.75867",
    "lng": "3.21705"
  },
  {
    "country": "FR",
    "name": "Choisy-au-Bac",
    "lat": "49.43777",
    "lng": "2.87739"
  },
  {
    "country": "FR",
    "name": "Choisy",
    "lat": "45.99305",
    "lng": "6.05535"
  },
  {
    "country": "FR",
    "name": "Choisey",
    "lat": "47.06389",
    "lng": "5.45911"
  },
  {
    "country": "FR",
    "name": "Chocques",
    "lat": "50.54084",
    "lng": "2.57193"
  },
  {
    "country": "FR",
    "name": "Chitenay",
    "lat": "47.49753",
    "lng": "1.37139"
  },
  {
    "country": "FR",
    "name": "Chissay-en-Touraine",
    "lat": "47.33747",
    "lng": "1.13362"
  },
  {
    "country": "FR",
    "name": "Chiry-Ourscamp",
    "lat": "49.54378",
    "lng": "2.94721"
  },
  {
    "country": "FR",
    "name": "Chirens",
    "lat": "45.4128",
    "lng": "5.55707"
  },
  {
    "country": "FR",
    "name": "Chirac",
    "lat": "44.52289",
    "lng": "3.26652"
  },
  {
    "country": "FR",
    "name": "Chinon",
    "lat": "47.16667",
    "lng": "0.25"
  },
  {
    "country": "FR",
    "name": "Chindrieux",
    "lat": "45.82132",
    "lng": "5.85122"
  },
  {
    "country": "FR",
    "name": "Chimilin",
    "lat": "45.57753",
    "lng": "5.59819"
  },
  {
    "country": "FR",
    "name": "Chilly-Mazarin",
    "lat": "48.71489",
    "lng": "2.31638"
  },
  {
    "country": "FR",
    "name": "Chilly",
    "lat": "45.99332",
    "lng": "5.95335"
  },
  {
    "country": "FR",
    "name": "Chilleurs-aux-Bois",
    "lat": "48.0722",
    "lng": "2.1354"
  },
  {
    "country": "FR",
    "name": "Chierry",
    "lat": "49.0394",
    "lng": "3.42976"
  },
  {
    "country": "FR",
    "name": "Chiché",
    "lat": "46.79643",
    "lng": "-0.3556"
  },
  {
    "country": "FR",
    "name": "Chézy-sur-Marne",
    "lat": "48.98881",
    "lng": "3.36786"
  },
  {
    "country": "FR",
    "name": "Chevry-Cossigny",
    "lat": "48.72465",
    "lng": "2.66106"
  },
  {
    "country": "FR",
    "name": "Chevry",
    "lat": "46.27855",
    "lng": "6.04008"
  },
  {
    "country": "FR",
    "name": "Chevrières",
    "lat": "49.34645",
    "lng": "2.68219"
  },
  {
    "country": "FR",
    "name": "Chevreuse",
    "lat": "48.70662",
    "lng": "2.03329"
  },
  {
    "country": "FR",
    "name": "Chèvremont",
    "lat": "47.62824",
    "lng": "6.92164"
  },
  {
    "country": "FR",
    "name": "Chevilly-Larue",
    "lat": "48.76476",
    "lng": "2.3503"
  },
  {
    "country": "FR",
    "name": "Chevilly",
    "lat": "48.02973",
    "lng": "1.87402"
  },
  {
    "country": "FR",
    "name": "Chevillon-sur-Huillard",
    "lat": "47.96197",
    "lng": "2.62601"
  },
  {
    "country": "FR",
    "name": "Chevillon",
    "lat": "48.52869",
    "lng": "5.13086"
  },
  {
    "country": "FR",
    "name": "Chevigny-Saint-Sauveur",
    "lat": "47.29908",
    "lng": "5.13367"
  },
  {
    "country": "FR",
    "name": "Cheverny",
    "lat": "47.50079",
    "lng": "1.45951"
  },
  {
    "country": "FR",
    "name": "Chevannes",
    "lat": "48.53259",
    "lng": "2.44388"
  },
  {
    "country": "FR",
    "name": "Chevanceaux",
    "lat": "45.3",
    "lng": "-0.23333"
  },
  {
    "country": "FR",
    "name": "Cheval-Blanc",
    "lat": "43.80189",
    "lng": "5.06229"
  },
  {
    "country": "FR",
    "name": "Chevaigné",
    "lat": "48.21153",
    "lng": "-1.62933"
  },
  {
    "country": "FR",
    "name": "Cheux",
    "lat": "49.16611",
    "lng": "-0.52544"
  },
  {
    "country": "FR",
    "name": "Chessy",
    "lat": "48.88333",
    "lng": "2.76667"
  },
  {
    "country": "FR",
    "name": "Chessy",
    "lat": "45.88707",
    "lng": "4.62366"
  },
  {
    "country": "FR",
    "name": "Cherveux",
    "lat": "46.41543",
    "lng": "-0.35706"
  },
  {
    "country": "FR",
    "name": "Cherves-Richemont",
    "lat": "45.74345",
    "lng": "-0.35096"
  },
  {
    "country": "FR",
    "name": "Cherrueix",
    "lat": "48.60629",
    "lng": "-1.70405"
  },
  {
    "country": "FR",
    "name": "Cherré",
    "lat": "48.1729",
    "lng": "0.65781"
  },
  {
    "country": "FR",
    "name": "Chéroy",
    "lat": "48.20076",
    "lng": "3.00011"
  },
  {
    "country": "FR",
    "name": "Chermignac",
    "lat": "45.68578",
    "lng": "-0.67349"
  },
  {
    "country": "FR",
    "name": "Cherisy",
    "lat": "48.75",
    "lng": "1.43333"
  },
  {
    "country": "FR",
    "name": "Chéreng",
    "lat": "50.61059",
    "lng": "3.20666"
  },
  {
    "country": "FR",
    "name": "Cherbourg-Octeville",
    "lat": "49.63984",
    "lng": "-1.61636"
  },
  {
    "country": "FR",
    "name": "Chéraute",
    "lat": "43.23096",
    "lng": "-0.86831"
  },
  {
    "country": "FR",
    "name": "Chérac",
    "lat": "45.70456",
    "lng": "-0.43859"
  },
  {
    "country": "FR",
    "name": "Chépy",
    "lat": "50.06361",
    "lng": "1.64694"
  },
  {
    "country": "FR",
    "name": "Cheptainville",
    "lat": "48.5509",
    "lng": "2.27665"
  },
  {
    "country": "FR",
    "name": "Cheny",
    "lat": "47.95166",
    "lng": "3.5334"
  },
  {
    "country": "FR",
    "name": "Chens-sur-Léman",
    "lat": "46.32906",
    "lng": "6.26267"
  },
  {
    "country": "FR",
    "name": "Chenôve",
    "lat": "47.29323",
    "lng": "5.00457"
  },
  {
    "country": "FR",
    "name": "Chenoise",
    "lat": "48.61462",
    "lng": "3.19459"
  },
  {
    "country": "FR",
    "name": "Chennevières-sur-Marne",
    "lat": "48.79702",
    "lng": "2.54046"
  },
  {
    "country": "FR",
    "name": "Cheniménil",
    "lat": "48.1388",
    "lng": "6.60346"
  },
  {
    "country": "FR",
    "name": "Chênehutte-Trèves-Cunault",
    "lat": "47.31084",
    "lng": "-0.16042"
  },
  {
    "country": "FR",
    "name": "Chemillé-Melay",
    "lat": "47.21476",
    "lng": "-0.72488"
  },
  {
    "country": "FR",
    "name": "Chéméré",
    "lat": "47.11667",
    "lng": "-1.91667"
  },
  {
    "country": "FR",
    "name": "Chemazé",
    "lat": "47.7869",
    "lng": "-0.77523"
  },
  {
    "country": "FR",
    "name": "Chemaudin",
    "lat": "47.22392",
    "lng": "5.89419"
  },
  {
    "country": "FR",
    "name": "Chelles",
    "lat": "48.88109",
    "lng": "2.59295"
  },
  {
    "country": "FR",
    "name": "Cheillé",
    "lat": "47.26114",
    "lng": "0.40553"
  },
  {
    "country": "FR",
    "name": "Chef-Boutonne",
    "lat": "46.10859",
    "lng": "-0.07083"
  },
  {
    "country": "FR",
    "name": "Chécy",
    "lat": "47.89402",
    "lng": "2.02304"
  },
  {
    "country": "FR",
    "name": "Chazey-sur-Ain",
    "lat": "45.893",
    "lng": "5.25352"
  },
  {
    "country": "FR",
    "name": "Chazelles-sur-Lyon",
    "lat": "45.63806",
    "lng": "4.3913"
  },
  {
    "country": "FR",
    "name": "Chazelles",
    "lat": "45.64713",
    "lng": "0.36748"
  },
  {
    "country": "FR",
    "name": "Chaville",
    "lat": "48.80565",
    "lng": "2.18864"
  },
  {
    "country": "FR",
    "name": "Chavigny",
    "lat": "48.62887",
    "lng": "6.12599"
  },
  {
    "country": "FR",
    "name": "Chavenay",
    "lat": "48.85437",
    "lng": "1.99163"
  },
  {
    "country": "FR",
    "name": "Chavelot",
    "lat": "48.23459",
    "lng": "6.43809"
  },
  {
    "country": "FR",
    "name": "Chavanoz",
    "lat": "45.77643",
    "lng": "5.17032"
  },
  {
    "country": "FR",
    "name": "Chavanod",
    "lat": "45.88964",
    "lng": "6.04235"
  },
  {
    "country": "FR",
    "name": "Chavanay",
    "lat": "45.41437",
    "lng": "4.73157"
  },
  {
    "country": "FR",
    "name": "Chavagnes-en-Paillers",
    "lat": "46.89167",
    "lng": "-1.25214"
  },
  {
    "country": "FR",
    "name": "Chavagne",
    "lat": "48.05438",
    "lng": "-1.78571"
  },
  {
    "country": "FR",
    "name": "Chauvigny",
    "lat": "46.56747",
    "lng": "0.64928"
  },
  {
    "country": "FR",
    "name": "Chauvé",
    "lat": "47.15174",
    "lng": "-1.98489"
  },
  {
    "country": "FR",
    "name": "Chaussin",
    "lat": "46.96612",
    "lng": "5.40791"
  },
  {
    "country": "FR",
    "name": "Chauriat",
    "lat": "45.75152",
    "lng": "3.27946"
  },
  {
    "country": "FR",
    "name": "Chauray",
    "lat": "46.35997",
    "lng": "-0.37859"
  },
  {
    "country": "FR",
    "name": "Chauny",
    "lat": "49.61514",
    "lng": "3.21857"
  },
  {
    "country": "FR",
    "name": "Chaunay",
    "lat": "46.20759",
    "lng": "0.16084"
  },
  {
    "country": "FR",
    "name": "Chaumont-sur-Tharonne",
    "lat": "47.61039",
    "lng": "1.90514"
  },
  {
    "country": "FR",
    "name": "Chaumont-sur-Loire",
    "lat": "47.48108",
    "lng": "1.18929"
  },
  {
    "country": "FR",
    "name": "Chaumont-en-Vexin",
    "lat": "49.26595",
    "lng": "1.88597"
  },
  {
    "country": "FR",
    "name": "Chaumontel",
    "lat": "49.1247",
    "lng": "2.43237"
  },
  {
    "country": "FR",
    "name": "Chaumont",
    "lat": "48.11121",
    "lng": "5.14134"
  },
  {
    "country": "FR",
    "name": "Chaumes-en-Brie",
    "lat": "48.66853",
    "lng": "2.84015"
  },
  {
    "country": "FR",
    "name": "Chaulnes",
    "lat": "49.81699",
    "lng": "2.80064"
  },
  {
    "country": "FR",
    "name": "Chaulgnes",
    "lat": "47.12889",
    "lng": "3.10348"
  },
  {
    "country": "FR",
    "name": "Chauffailles",
    "lat": "46.20726",
    "lng": "4.33932"
  },
  {
    "country": "FR",
    "name": "Chaudron-en-Mauges",
    "lat": "47.28809",
    "lng": "-0.98547"
  },
  {
    "country": "FR",
    "name": "Chaudon",
    "lat": "48.66276",
    "lng": "1.4967"
  },
  {
    "country": "FR",
    "name": "Chaudes-Aigues",
    "lat": "44.85344",
    "lng": "3.00364"
  },
  {
    "country": "FR",
    "name": "Chauconin-Neufmontiers",
    "lat": "48.96667",
    "lng": "2.85"
  },
  {
    "country": "FR",
    "name": "Chauché",
    "lat": "46.82963",
    "lng": "-1.27178"
  },
  {
    "country": "FR",
    "name": "Chatuzange-le-Goubet",
    "lat": "45.00138",
    "lng": "5.087"
  },
  {
    "country": "FR",
    "name": "Chatte",
    "lat": "45.1431",
    "lng": "5.28441"
  },
  {
    "country": "FR",
    "name": "Châtres-sur-Cher",
    "lat": "47.26505",
    "lng": "1.90591"
  },
  {
    "country": "FR",
    "name": "Chatou",
    "lat": "48.8898",
    "lng": "2.15863"
  },
  {
    "country": "FR",
    "name": "Châtonnay",
    "lat": "45.48699",
    "lng": "5.20368"
  },
  {
    "country": "FR",
    "name": "Châtillon-sur-Thouet",
    "lat": "46.66176",
    "lng": "-0.23489"
  },
  {
    "country": "FR",
    "name": "Châtillon-sur-Seine",
    "lat": "47.85851",
    "lng": "4.57375"
  },
  {
    "country": "FR",
    "name": "Châtillon-sur-Seiche",
    "lat": "48.03448",
    "lng": "-1.67114"
  },
  {
    "country": "FR",
    "name": "Châtillon-sur-Marne",
    "lat": "49.10048",
    "lng": "3.76023"
  },
  {
    "country": "FR",
    "name": "Châtillon-sur-Indre",
    "lat": "46.98735",
    "lng": "1.17218"
  },
  {
    "country": "FR",
    "name": "Châtillon-sur-Cluses",
    "lat": "46.09108",
    "lng": "6.58689"
  },
  {
    "country": "FR",
    "name": "Châtillon-sur-Cher",
    "lat": "47.27571",
    "lng": "1.49424"
  },
  {
    "country": "FR",
    "name": "Châtillon-sur-Chalaronne",
    "lat": "46.12019",
    "lng": "4.95817"
  },
  {
    "country": "FR",
    "name": "Châtillon-le-Duc",
    "lat": "47.30486",
    "lng": "6.00792"
  },
  {
    "country": "FR",
    "name": "Châtillon-la-Palud",
    "lat": "45.97473",
    "lng": "5.24799"
  },
  {
    "country": "FR",
    "name": "Châtillon-en-Vendelais",
    "lat": "48.22409",
    "lng": "-1.17695"
  },
  {
    "country": "FR",
    "name": "Châtillon-en-Bazois",
    "lat": "47.05464",
    "lng": "3.65893"
  },
  {
    "country": "FR",
    "name": "Châtillon-en-Michaille",
    "lat": "46.1432",
    "lng": "5.7995"
  },
  {
    "country": "FR",
    "name": "Châtillon",
    "lat": "45.88333",
    "lng": "4.61667"
  },
  {
    "country": "FR",
    "name": "Châtillon-Coligny",
    "lat": "47.82266",
    "lng": "2.84563"
  },
  {
    "country": "FR",
    "name": "Châtillon",
    "lat": "48.8024",
    "lng": "2.29346"
  },
  {
    "country": "FR",
    "name": "Châtillon",
    "lat": "45.80091",
    "lng": "5.84352"
  },
  {
    "country": "FR",
    "name": "Châtenoy-le-Royal",
    "lat": "46.79797",
    "lng": "4.8119"
  },
  {
    "country": "FR",
    "name": "Châtenois-les-Forges",
    "lat": "47.5598",
    "lng": "6.84894"
  },
  {
    "country": "FR",
    "name": "Châtenois",
    "lat": "48.30286",
    "lng": "5.83125"
  },
  {
    "country": "FR",
    "name": "Châtenois",
    "lat": "48.27201",
    "lng": "7.40109"
  },
  {
    "country": "FR",
    "name": "Châtenay-sur-Seine",
    "lat": "48.41839",
    "lng": "3.09474"
  },
  {
    "country": "FR",
    "name": "Châtenay-Malabry",
    "lat": "48.76507",
    "lng": "2.26655"
  },
  {
    "country": "FR",
    "name": "Châtel-sur-Moselle",
    "lat": "48.3143",
    "lng": "6.39403"
  },
  {
    "country": "FR",
    "name": "Châtel-Saint-Germain",
    "lat": "49.12255",
    "lng": "6.08006"
  },
  {
    "country": "FR",
    "name": "Châtellerault",
    "lat": "46.8",
    "lng": "0.53333"
  },
  {
    "country": "FR",
    "name": "Châtel-Guyon",
    "lat": "45.91667",
    "lng": "3.06667"
  },
  {
    "country": "FR",
    "name": "Châtelaillon-Plage",
    "lat": "46.0719",
    "lng": "-1.08926"
  },
  {
    "country": "FR",
    "name": "Châtel",
    "lat": "46.26658",
    "lng": "6.84229"
  },
  {
    "country": "FR",
    "name": "Châteauvillain",
    "lat": "48.03655",
    "lng": "4.91823"
  },
  {
    "country": "FR",
    "name": "Château-Thierry",
    "lat": "49.05",
    "lng": "3.4"
  },
  {
    "country": "FR",
    "name": "Château-Salins",
    "lat": "48.81885",
    "lng": "6.51455"
  },
  {
    "country": "FR",
    "name": "Châteauroux",
    "lat": "46.81248",
    "lng": "1.69362"
  },
  {
    "country": "FR",
    "name": "Château-Renault",
    "lat": "47.59188",
    "lng": "0.91143"
  },
  {
    "country": "FR",
    "name": "Château-Renard",
    "lat": "47.93333",
    "lng": "2.93333"
  },
  {
    "country": "FR",
    "name": "Châteaurenard",
    "lat": "43.88169",
    "lng": "4.85493"
  },
  {
    "country": "FR",
    "name": "Château-Porcien",
    "lat": "49.5274",
    "lng": "4.24533"
  },
  {
    "country": "FR",
    "name": "Châteauponsac",
    "lat": "46.13536",
    "lng": "1.27623"
  },
  {
    "country": "FR",
    "name": "Châteauneuf-sur-Sarthe",
    "lat": "47.68145",
    "lng": "-0.48652"
  },
  {
    "country": "FR",
    "name": "Châteauneuf-sur-Loire",
    "lat": "47.86575",
    "lng": "2.21903"
  },
  {
    "country": "FR",
    "name": "Châteauneuf-sur-Cher",
    "lat": "46.85778",
    "lng": "2.3171"
  },
  {
    "country": "FR",
    "name": "Châteauneuf-sur-Charente",
    "lat": "45.6",
    "lng": "-0.05"
  },
  {
    "country": "FR",
    "name": "Châteauneuf-les-Martigues",
    "lat": "43.38333",
    "lng": "5.16667"
  },
  {
    "country": "FR",
    "name": "Châteauneuf-le-Rouge",
    "lat": "43.48936",
    "lng": "5.56921"
  },
  {
    "country": "FR",
    "name": "Châteauneuf-la-Forêt",
    "lat": "45.71436",
    "lng": "1.6061"
  },
  {
    "country": "FR",
    "name": "Châteauneuf-en-Thymerais",
    "lat": "48.58112",
    "lng": "1.24085"
  },
  {
    "country": "FR",
    "name": "Châteauneuf-du-Rhône",
    "lat": "44.48779",
    "lng": "4.71759"
  },
  {
    "country": "FR",
    "name": "Châteauneuf-du-Pape",
    "lat": "44.05638",
    "lng": "4.83244"
  },
  {
    "country": "FR",
    "name": "Châteauneuf-du-Faou",
    "lat": "48.18755",
    "lng": "-3.81789"
  },
  {
    "country": "FR",
    "name": "Châteauneuf-sur-Isère",
    "lat": "45.01667",
    "lng": "4.93333"
  },
  {
    "country": "FR",
    "name": "Châteauneuf-d’Ille-et-Vilaine",
    "lat": "48.56083",
    "lng": "-1.92838"
  },
  {
    "country": "FR",
    "name": "Châteauneuf-de-Galaure",
    "lat": "45.23096",
    "lng": "4.9568"
  },
  {
    "country": "FR",
    "name": "Châteauneuf-de-Gadagne",
    "lat": "43.92683",
    "lng": "4.94453"
  },
  {
    "country": "FR",
    "name": "Châteauneuf",
    "lat": "45.52457",
    "lng": "4.64044"
  },
  {
    "country": "FR",
    "name": "Châteauneuf-Grasse",
    "lat": "43.66667",
    "lng": "6.98333"
  },
  {
    "country": "FR",
    "name": "Châteaumeillant",
    "lat": "46.56219",
    "lng": "2.19515"
  },
  {
    "country": "FR",
    "name": "Châteaulin",
    "lat": "48.2",
    "lng": "-4.08333"
  },
  {
    "country": "FR",
    "name": "Château-la-Vallière",
    "lat": "47.54665",
    "lng": "0.32458"
  },
  {
    "country": "FR",
    "name": "Château-Landon",
    "lat": "48.14721",
    "lng": "2.69754"
  },
  {
    "country": "FR",
    "name": "Château-Guibert",
    "lat": "46.5811",
    "lng": "-1.23656"
  },
  {
    "country": "FR",
    "name": "Château-Gontier",
    "lat": "47.83333",
    "lng": "-0.7"
  },
  {
    "country": "FR",
    "name": "Châteaugiron",
    "lat": "48.04629",
    "lng": "-1.50438"
  },
  {
    "country": "FR",
    "name": "Châteaugay",
    "lat": "45.85134",
    "lng": "3.08972"
  },
  {
    "country": "FR",
    "name": "Château-Gaillard",
    "lat": "45.97359",
    "lng": "5.30673"
  },
  {
    "country": "FR",
    "name": "Châteaufort",
    "lat": "48.73584",
    "lng": "2.09054"
  },
  {
    "country": "FR",
    "name": "Châteaudun",
    "lat": "48.08333",
    "lng": "1.33333"
  },
  {
    "country": "FR",
    "name": "Château-du-Loir",
    "lat": "47.69492",
    "lng": "0.41851"
  },
  {
    "country": "FR",
    "name": "Château-d’Olonne",
    "lat": "46.50382",
    "lng": "-1.74097"
  },
  {
    "country": "FR",
    "name": "Château-Chinon(Ville)",
    "lat": "47.06667",
    "lng": "3.93333"
  },
  {
    "country": "FR",
    "name": "Châteaubriant",
    "lat": "47.71667",
    "lng": "-1.38333"
  },
  {
    "country": "FR",
    "name": "Châteaubourg",
    "lat": "48.11119",
    "lng": "-1.40019"
  },
  {
    "country": "FR",
    "name": "Châteaubernard",
    "lat": "45.66667",
    "lng": "-0.33333"
  },
  {
    "country": "FR",
    "name": "Chassors",
    "lat": "45.7",
    "lng": "-0.21667"
  },
  {
    "country": "FR",
    "name": "Chassieu",
    "lat": "45.74584",
    "lng": "4.97088"
  },
  {
    "country": "FR",
    "name": "Chasse-sur-Rhône",
    "lat": "45.58339",
    "lng": "4.79823"
  },
  {
    "country": "FR",
    "name": "Chasseneuil-du-Poitou",
    "lat": "46.65112",
    "lng": "0.37329"
  },
  {
    "country": "FR",
    "name": "Chasseneuil-sur-Bonnieure",
    "lat": "45.81667",
    "lng": "0.45"
  },
  {
    "country": "FR",
    "name": "Chasselay",
    "lat": "45.87524",
    "lng": "4.7734"
  },
  {
    "country": "FR",
    "name": "Chassagny",
    "lat": "45.6067",
    "lng": "4.73214"
  },
  {
    "country": "FR",
    "name": "Chasné-sur-Illet",
    "lat": "48.24247",
    "lng": "-1.56138"
  },
  {
    "country": "FR",
    "name": "Charvieu-Chavagneux",
    "lat": "45.75",
    "lng": "5.15"
  },
  {
    "country": "FR",
    "name": "Chartrettes",
    "lat": "48.48808",
    "lng": "2.70083"
  },
  {
    "country": "FR",
    "name": "Chartres-de-Bretagne",
    "lat": "48.03924",
    "lng": "-1.70533"
  },
  {
    "country": "FR",
    "name": "Chartres",
    "lat": "48.44685",
    "lng": "1.48925"
  },
  {
    "country": "FR",
    "name": "Chars",
    "lat": "49.16032",
    "lng": "1.93669"
  },
  {
    "country": "FR",
    "name": "Charroux",
    "lat": "46.1441",
    "lng": "0.40354"
  },
  {
    "country": "FR",
    "name": "Charron",
    "lat": "46.29433",
    "lng": "-1.10572"
  },
  {
    "country": "FR",
    "name": "Charquemont",
    "lat": "47.21417",
    "lng": "6.8198"
  },
  {
    "country": "FR",
    "name": "Chârost",
    "lat": "46.9939",
    "lng": "2.11639"
  },
  {
    "country": "FR",
    "name": "Charolles",
    "lat": "46.43333",
    "lng": "4.28333"
  },
  {
    "country": "FR",
    "name": "Charny",
    "lat": "48.97098",
    "lng": "2.76121"
  },
  {
    "country": "FR",
    "name": "Charny",
    "lat": "47.88661",
    "lng": "3.09583"
  },
  {
    "country": "FR",
    "name": "Charnècles",
    "lat": "45.34467",
    "lng": "5.52595"
  },
  {
    "country": "FR",
    "name": "Charnay-lès-Mâcon",
    "lat": "46.30751",
    "lng": "4.78479"
  },
  {
    "country": "FR",
    "name": "Charnay",
    "lat": "45.89112",
    "lng": "4.66801"
  },
  {
    "country": "FR",
    "name": "Charmes-sur-Rhône",
    "lat": "44.86393",
    "lng": "4.84039"
  },
  {
    "country": "FR",
    "name": "Charmes",
    "lat": "49.65345",
    "lng": "3.37857"
  },
  {
    "country": "FR",
    "name": "Charmes",
    "lat": "48.3722",
    "lng": "6.29117"
  },
  {
    "country": "FR",
    "name": "Charly-sur-Marne",
    "lat": "48.97749",
    "lng": "3.28464"
  },
  {
    "country": "FR",
    "name": "Charly",
    "lat": "45.65255",
    "lng": "4.7961"
  },
  {
    "country": "FR",
    "name": "Charlieu",
    "lat": "46.16014",
    "lng": "4.17406"
  },
  {
    "country": "FR",
    "name": "Charleville-Mézières",
    "lat": "49.7685",
    "lng": "4.72487"
  },
  {
    "country": "FR",
    "name": "Charleval",
    "lat": "49.3729",
    "lng": "1.38369"
  },
  {
    "country": "FR",
    "name": "Charleval",
    "lat": "43.71864",
    "lng": "5.24546"
  },
  {
    "country": "FR",
    "name": "Chargé",
    "lat": "47.4327",
    "lng": "1.03037"
  },
  {
    "country": "FR",
    "name": "Charenton-le-Pont",
    "lat": "48.82209",
    "lng": "2.41217"
  },
  {
    "country": "FR",
    "name": "Charenton-du-Cher",
    "lat": "46.73007",
    "lng": "2.64438"
  },
  {
    "country": "FR",
    "name": "Charentilly",
    "lat": "47.46981",
    "lng": "0.60903"
  },
  {
    "country": "FR",
    "name": "Charentay",
    "lat": "46.08906",
    "lng": "4.67923"
  },
  {
    "country": "FR",
    "name": "Charbuy",
    "lat": "47.82282",
    "lng": "3.46617"
  },
  {
    "country": "FR",
    "name": "Charbonnières-les-Varennes",
    "lat": "45.9",
    "lng": "3"
  },
  {
    "country": "FR",
    "name": "Charbonnières-les-Bains",
    "lat": "45.7842",
    "lng": "4.7463"
  },
  {
    "country": "FR",
    "name": "Charavines",
    "lat": "45.43043",
    "lng": "5.51602"
  },
  {
    "country": "FR",
    "name": "Charantonnay",
    "lat": "45.53671",
    "lng": "5.11034"
  },
  {
    "country": "FR",
    "name": "Chaptelat",
    "lat": "45.90962",
    "lng": "1.26018"
  },
  {
    "country": "FR",
    "name": "Chappes",
    "lat": "45.86831",
    "lng": "3.22241"
  },
  {
    "country": "FR",
    "name": "Chaponost",
    "lat": "45.70592",
    "lng": "4.74441"
  },
  {
    "country": "FR",
    "name": "Chaponnay",
    "lat": "45.63097",
    "lng": "4.94299"
  },
  {
    "country": "FR",
    "name": "Chapet",
    "lat": "48.96667",
    "lng": "1.93333"
  },
  {
    "country": "FR",
    "name": "Chapdes-Beaufort",
    "lat": "45.89225",
    "lng": "2.86381"
  },
  {
    "country": "FR",
    "name": "Chapareillan",
    "lat": "45.46513",
    "lng": "5.99171"
  },
  {
    "country": "FR",
    "name": "Chaource",
    "lat": "48.05915",
    "lng": "4.13738"
  },
  {
    "country": "FR",
    "name": "Chanu",
    "lat": "48.72914",
    "lng": "-0.67603"
  },
  {
    "country": "FR",
    "name": "Chantraine",
    "lat": "48.17157",
    "lng": "6.43538"
  },
  {
    "country": "FR",
    "name": "Chantonnay",
    "lat": "46.68702",
    "lng": "-1.05024"
  },
  {
    "country": "FR",
    "name": "Chantôme",
    "lat": "46.41067",
    "lng": "1.5559"
  },
  {
    "country": "FR",
    "name": "Chantilly",
    "lat": "49.19461",
    "lng": "2.47124"
  },
  {
    "country": "FR",
    "name": "Chantepie",
    "lat": "48.08885",
    "lng": "-1.61524"
  },
  {
    "country": "FR",
    "name": "Chantenay-Saint-Imbert",
    "lat": "46.73333",
    "lng": "3.18333"
  },
  {
    "country": "FR",
    "name": "Chanteloup-les-Vignes",
    "lat": "48.97614",
    "lng": "2.03261"
  },
  {
    "country": "FR",
    "name": "Chanteloup-en-Brie",
    "lat": "48.85478",
    "lng": "2.73929"
  },
  {
    "country": "FR",
    "name": "Chanteloup",
    "lat": "47.96574",
    "lng": "-1.61517"
  },
  {
    "country": "FR",
    "name": "Chantelle",
    "lat": "46.23592",
    "lng": "3.15207"
  },
  {
    "country": "FR",
    "name": "Chanteheux",
    "lat": "48.59938",
    "lng": "6.5286"
  },
  {
    "country": "FR",
    "name": "Chanteau",
    "lat": "47.96651",
    "lng": "1.97129"
  },
  {
    "country": "FR",
    "name": "Chanos-Curson",
    "lat": "45.06057",
    "lng": "4.92381"
  },
  {
    "country": "FR",
    "name": "Chanonat",
    "lat": "45.69299",
    "lng": "3.09351"
  },
  {
    "country": "FR",
    "name": "Chaniers",
    "lat": "45.71858",
    "lng": "-0.55779"
  },
  {
    "country": "FR",
    "name": "Changy-les-Bois",
    "lat": "47.85793",
    "lng": "2.68543"
  },
  {
    "country": "FR",
    "name": "Changis-sur-Marne",
    "lat": "48.95816",
    "lng": "3.02191"
  },
  {
    "country": "FR",
    "name": "Changé",
    "lat": "48.09918",
    "lng": "-0.79292"
  },
  {
    "country": "FR",
    "name": "Changé",
    "lat": "47.98499",
    "lng": "0.28328"
  },
  {
    "country": "FR",
    "name": "Chandon",
    "lat": "46.1496",
    "lng": "4.21446"
  },
  {
    "country": "FR",
    "name": "Chancenay",
    "lat": "48.67001",
    "lng": "4.98715"
  },
  {
    "country": "FR",
    "name": "Chancelade",
    "lat": "45.20049",
    "lng": "0.67261"
  },
  {
    "country": "FR",
    "name": "Chanceaux-sur-Choisille",
    "lat": "47.47145",
    "lng": "0.70539"
  },
  {
    "country": "FR",
    "name": "Chanas",
    "lat": "45.31881",
    "lng": "4.81849"
  },
  {
    "country": "FR",
    "name": "Chanac",
    "lat": "44.46614",
    "lng": "3.34327"
  },
  {
    "country": "FR",
    "name": "Champvans",
    "lat": "47.10466",
    "lng": "5.4376"
  },
  {
    "country": "FR",
    "name": "Champtocé-sur-Loire",
    "lat": "47.41239",
    "lng": "-0.86452"
  },
  {
    "country": "FR",
    "name": "Champtoceaux",
    "lat": "47.33476",
    "lng": "-1.26131"
  },
  {
    "country": "FR",
    "name": "Champ-sur-Drac",
    "lat": "45.06912",
    "lng": "5.73225"
  },
  {
    "country": "FR",
    "name": "Champs-sur-Tarentaine-Marchal",
    "lat": "45.4",
    "lng": "2.56667"
  },
  {
    "country": "FR",
    "name": "Champs-sur-Marne",
    "lat": "48.85",
    "lng": "2.6"
  },
  {
    "country": "FR",
    "name": "Champsecret",
    "lat": "48.60925",
    "lng": "-0.55058"
  },
  {
    "country": "FR",
    "name": "Champs-sur-Yonne",
    "lat": "47.73333",
    "lng": "3.6"
  },
  {
    "country": "FR",
    "name": "Champniers",
    "lat": "45.71451",
    "lng": "0.20436"
  },
  {
    "country": "FR",
    "name": "Champlitte-la-Ville",
    "lat": "47.61333",
    "lng": "5.53191"
  },
  {
    "country": "FR",
    "name": "Champlitte",
    "lat": "47.61667",
    "lng": "5.51667"
  },
  {
    "country": "FR",
    "name": "Champlan",
    "lat": "48.70823",
    "lng": "2.27975"
  },
  {
    "country": "FR",
    "name": "Champigny",
    "lat": "48.31667",
    "lng": "3.13333"
  },
  {
    "country": "FR",
    "name": "Champigny-sur-Marne",
    "lat": "48.81642",
    "lng": "2.49366"
  },
  {
    "country": "FR",
    "name": "Champigneulles",
    "lat": "48.73419",
    "lng": "6.16417"
  },
  {
    "country": "FR",
    "name": "Champignelles",
    "lat": "47.78009",
    "lng": "3.07457"
  },
  {
    "country": "FR",
    "name": "Champigné",
    "lat": "47.66332",
    "lng": "-0.5716"
  },
  {
    "country": "FR",
    "name": "Champier",
    "lat": "45.45638",
    "lng": "5.29223"
  },
  {
    "country": "FR",
    "name": "Champhol",
    "lat": "48.46813",
    "lng": "1.50281"
  },
  {
    "country": "FR",
    "name": "Champforgeuil",
    "lat": "46.81857",
    "lng": "4.83357"
  },
  {
    "country": "FR",
    "name": "Champfleur",
    "lat": "48.38668",
    "lng": "0.12942"
  },
  {
    "country": "FR",
    "name": "Champenoux",
    "lat": "48.74174",
    "lng": "6.35032"
  },
  {
    "country": "FR",
    "name": "Champeix",
    "lat": "45.5868",
    "lng": "3.12866"
  },
  {
    "country": "FR",
    "name": "Champdieu",
    "lat": "45.64478",
    "lng": "4.04583"
  },
  {
    "country": "FR",
    "name": "Champdeniers-Saint-Denis",
    "lat": "46.48333",
    "lng": "-0.4"
  },
  {
    "country": "FR",
    "name": "Champcueil",
    "lat": "48.51594",
    "lng": "2.44674"
  },
  {
    "country": "FR",
    "name": "Champcevinel",
    "lat": "45.2163",
    "lng": "0.72796"
  },
  {
    "country": "FR",
    "name": "Champagnole",
    "lat": "46.74452",
    "lng": "5.91354"
  },
  {
    "country": "FR",
    "name": "Champagnier",
    "lat": "45.11294",
    "lng": "5.72654"
  },
  {
    "country": "FR",
    "name": "Champagney",
    "lat": "47.70504",
    "lng": "6.68173"
  },
  {
    "country": "FR",
    "name": "Champagne-sur-Seine",
    "lat": "48.39794",
    "lng": "2.79785"
  },
  {
    "country": "FR",
    "name": "Champagne-sur-Oise",
    "lat": "49.14052",
    "lng": "2.24233"
  },
  {
    "country": "FR",
    "name": "Champagne-Mouton",
    "lat": "45.99078",
    "lng": "0.41051"
  },
  {
    "country": "FR",
    "name": "Champagné-les-Marais",
    "lat": "46.38081",
    "lng": "-1.12112"
  },
  {
    "country": "FR",
    "name": "Champagné",
    "lat": "48.02185",
    "lng": "0.33096"
  },
  {
    "country": "FR",
    "name": "Champagnac",
    "lat": "45.35",
    "lng": "2.4"
  },
  {
    "country": "FR",
    "name": "Chamonix-Mont-Blanc",
    "lat": "45.92375",
    "lng": "6.86933"
  },
  {
    "country": "FR",
    "name": "Chamigny",
    "lat": "48.97242",
    "lng": "3.15165"
  },
  {
    "country": "FR",
    "name": "Chameyrat",
    "lat": "45.23481",
    "lng": "1.69803"
  },
  {
    "country": "FR",
    "name": "Chambretaud",
    "lat": "46.92166",
    "lng": "-0.96405"
  },
  {
    "country": "FR",
    "name": "Chambray-lès-Tours",
    "lat": "47.33537",
    "lng": "0.70286"
  },
  {
    "country": "FR",
    "name": "Chambourg-sur-Indre",
    "lat": "47.18159",
    "lng": "0.96863"
  },
  {
    "country": "FR",
    "name": "Chambourcy",
    "lat": "48.90655",
    "lng": "2.041"
  },
  {
    "country": "FR",
    "name": "Chamboulive",
    "lat": "45.4329",
    "lng": "1.70415"
  },
  {
    "country": "FR",
    "name": "Chambon-sur-Voueize",
    "lat": "46.18938",
    "lng": "2.42568"
  },
  {
    "country": "FR",
    "name": "Chambœuf",
    "lat": "45.58333",
    "lng": "4.31667"
  },
  {
    "country": "FR",
    "name": "Chambly",
    "lat": "49.16667",
    "lng": "2.25"
  },
  {
    "country": "FR",
    "name": "Chambéry",
    "lat": "45.56465",
    "lng": "5.92645"
  },
  {
    "country": "FR",
    "name": "Chamberet",
    "lat": "45.58314",
    "lng": "1.72124"
  },
  {
    "country": "FR",
    "name": "Chamarandes-Choignes",
    "lat": "48.08333",
    "lng": "5.15"
  },
  {
    "country": "FR",
    "name": "Chamarande",
    "lat": "48.51715",
    "lng": "2.2171"
  },
  {
    "country": "FR",
    "name": "Chamant",
    "lat": "49.2199",
    "lng": "2.61176"
  },
  {
    "country": "FR",
    "name": "Chamalières",
    "lat": "45.77559",
    "lng": "3.0631"
  },
  {
    "country": "FR",
    "name": "Chamagnieu",
    "lat": "45.68114",
    "lng": "5.16392"
  },
  {
    "country": "FR",
    "name": "Châlus",
    "lat": "45.6544",
    "lng": "0.98011"
  },
  {
    "country": "FR",
    "name": "Chalo-Saint-Mars",
    "lat": "48.42328",
    "lng": "2.06491"
  },
  {
    "country": "FR",
    "name": "Châlonvillars",
    "lat": "47.64055",
    "lng": "6.78407"
  },
  {
    "country": "FR",
    "name": "Chalon-sur-Saône",
    "lat": "46.78333",
    "lng": "4.85"
  },
  {
    "country": "FR",
    "name": "Châlons-en-Champagne",
    "lat": "48.95393",
    "lng": "4.36724"
  },
  {
    "country": "FR",
    "name": "Chalonnes-sur-Loire",
    "lat": "47.3516",
    "lng": "-0.7631"
  },
  {
    "country": "FR",
    "name": "Challuy",
    "lat": "46.94971",
    "lng": "3.14807"
  },
  {
    "country": "FR",
    "name": "Challex",
    "lat": "46.18458",
    "lng": "5.97639"
  },
  {
    "country": "FR",
    "name": "Challes-les-Eaux",
    "lat": "45.55195",
    "lng": "5.98171"
  },
  {
    "country": "FR",
    "name": "Challes",
    "lat": "47.93033",
    "lng": "0.41511"
  },
  {
    "country": "FR",
    "name": "Challans",
    "lat": "46.84363",
    "lng": "-1.87491"
  },
  {
    "country": "FR",
    "name": "Chalindrey",
    "lat": "47.80308",
    "lng": "5.42797"
  },
  {
    "country": "FR",
    "name": "Chaligny",
    "lat": "48.62405",
    "lng": "6.08333"
  },
  {
    "country": "FR",
    "name": "Chalifert",
    "lat": "48.88993",
    "lng": "2.77339"
  },
  {
    "country": "FR",
    "name": "Châlette-sur-Loing",
    "lat": "48.01337",
    "lng": "2.73587"
  },
  {
    "country": "FR",
    "name": "Chaleins",
    "lat": "46.03058",
    "lng": "4.80417"
  },
  {
    "country": "FR",
    "name": "Chalampé",
    "lat": "47.81941",
    "lng": "7.54098"
  },
  {
    "country": "FR",
    "name": "Chalamont",
    "lat": "45.99665",
    "lng": "5.17014"
  },
  {
    "country": "FR",
    "name": "Chalais",
    "lat": "45.27338",
    "lng": "0.0388"
  },
  {
    "country": "FR",
    "name": "Chalabre",
    "lat": "42.98248",
    "lng": "2.00538"
  },
  {
    "country": "FR",
    "name": "Chaingy",
    "lat": "47.88326",
    "lng": "1.77059"
  },
  {
    "country": "FR",
    "name": "Chailly-en-Brie",
    "lat": "48.79006",
    "lng": "3.12453"
  },
  {
    "country": "FR",
    "name": "Chailly-en-Bière",
    "lat": "48.46701",
    "lng": "2.60785"
  },
  {
    "country": "FR",
    "name": "Chaillevette",
    "lat": "45.7303",
    "lng": "-1.0581"
  },
  {
    "country": "FR",
    "name": "Chailles",
    "lat": "47.5416",
    "lng": "1.3122"
  },
  {
    "country": "FR",
    "name": "Chaillé-les-Marais",
    "lat": "46.39628",
    "lng": "-1.02369"
  },
  {
    "country": "FR",
    "name": "Chailland",
    "lat": "48.22516",
    "lng": "-0.87387"
  },
  {
    "country": "FR",
    "name": "Chaillac",
    "lat": "46.43382",
    "lng": "1.29889"
  },
  {
    "country": "FR",
    "name": "Chagny",
    "lat": "46.90953",
    "lng": "4.7519"
  },
  {
    "country": "FR",
    "name": "Chadrac",
    "lat": "45.06181",
    "lng": "3.90261"
  },
  {
    "country": "FR",
    "name": "Chacé",
    "lat": "47.21435",
    "lng": "-0.07179"
  },
  {
    "country": "FR",
    "name": "Chabris",
    "lat": "47.25343",
    "lng": "1.65181"
  },
  {
    "country": "FR",
    "name": "Chabreloche",
    "lat": "45.87967",
    "lng": "3.69519"
  },
  {
    "country": "FR",
    "name": "Châbons",
    "lat": "45.44093",
    "lng": "5.4275"
  },
  {
    "country": "FR",
    "name": "Chablis",
    "lat": "47.81386",
    "lng": "3.79835"
  },
  {
    "country": "FR",
    "name": "Chabeuil",
    "lat": "44.89963",
    "lng": "5.01884"
  },
  {
    "country": "FR",
    "name": "Chabanais",
    "lat": "45.87339",
    "lng": "0.71763"
  },
  {
    "country": "FR",
    "name": "Cézy",
    "lat": "47.99265",
    "lng": "3.34067"
  },
  {
    "country": "FR",
    "name": "Cézac",
    "lat": "45.09019",
    "lng": "-0.41963"
  },
  {
    "country": "FR",
    "name": "Ceyzériat",
    "lat": "46.1801",
    "lng": "5.31972"
  },
  {
    "country": "FR",
    "name": "Ceyreste",
    "lat": "43.2133",
    "lng": "5.63111"
  },
  {
    "country": "FR",
    "name": "Ceyrat",
    "lat": "45.73176",
    "lng": "3.06335"
  },
  {
    "country": "FR",
    "name": "Ceton",
    "lat": "48.22631",
    "lng": "0.74968"
  },
  {
    "country": "FR",
    "name": "Cestas",
    "lat": "44.74345",
    "lng": "-0.67905"
  },
  {
    "country": "FR",
    "name": "Cessy",
    "lat": "46.31662",
    "lng": "6.06915"
  },
  {
    "country": "FR",
    "name": "Cesson-Sévigné",
    "lat": "48.1212",
    "lng": "-1.603"
  },
  {
    "country": "FR",
    "name": "Cesson",
    "lat": "48.56204",
    "lng": "2.60816"
  },
  {
    "country": "FR",
    "name": "Cessieu",
    "lat": "45.56576",
    "lng": "5.37704"
  },
  {
    "country": "FR",
    "name": "Cessenon-sur-Orb",
    "lat": "43.45011",
    "lng": "3.05154"
  },
  {
    "country": "FR",
    "name": "Cervione",
    "lat": "42.33096",
    "lng": "9.49112"
  },
  {
    "country": "FR",
    "name": "Certines",
    "lat": "46.13324",
    "lng": "5.26496"
  },
  {
    "country": "FR",
    "name": "Cers",
    "lat": "43.32352",
    "lng": "3.3045"
  },
  {
    "country": "FR",
    "name": "Cérons",
    "lat": "44.63572",
    "lng": "-0.33351"
  },
  {
    "country": "FR",
    "name": "Cerny",
    "lat": "48.47796",
    "lng": "2.32815"
  },
  {
    "country": "FR",
    "name": "Cernay-lès-Reims",
    "lat": "49.26375",
    "lng": "4.10216"
  },
  {
    "country": "FR",
    "name": "Cernay-la-Ville",
    "lat": "48.67324",
    "lng": "1.97422"
  },
  {
    "country": "FR",
    "name": "Cernay",
    "lat": "47.8097",
    "lng": "7.17699"
  },
  {
    "country": "FR",
    "name": "Cerizay",
    "lat": "46.82154",
    "lng": "-0.66726"
  },
  {
    "country": "FR",
    "name": "Cerisy-la-Salle",
    "lat": "49.02622",
    "lng": "-1.28283"
  },
  {
    "country": "FR",
    "name": "Cérilly",
    "lat": "46.6179",
    "lng": "2.8202"
  },
  {
    "country": "FR",
    "name": "Cergy",
    "lat": "49.03645",
    "lng": "2.07613"
  },
  {
    "country": "FR",
    "name": "Ceret",
    "lat": "42.48533",
    "lng": "2.74804"
  },
  {
    "country": "FR",
    "name": "Céreste",
    "lat": "43.85567",
    "lng": "5.58452"
  },
  {
    "country": "FR",
    "name": "Cérences",
    "lat": "48.91667",
    "lng": "-1.4347"
  },
  {
    "country": "FR",
    "name": "Cerelles",
    "lat": "47.50168",
    "lng": "0.68333"
  },
  {
    "country": "FR",
    "name": "Cerdon",
    "lat": "47.63571",
    "lng": "2.36277"
  },
  {
    "country": "FR",
    "name": "Cercy-la-Tour",
    "lat": "46.86203",
    "lng": "3.64652"
  },
  {
    "country": "FR",
    "name": "Cercoux",
    "lat": "45.13333",
    "lng": "-0.2"
  },
  {
    "country": "FR",
    "name": "Cervera de la Marenda",
    "lat": "42.44094",
    "lng": "3.16518"
  },
  {
    "country": "FR",
    "name": "Cérans-Foulletourte",
    "lat": "47.82651",
    "lng": "0.07724"
  },
  {
    "country": "FR",
    "name": "Cepoy",
    "lat": "48.04795",
    "lng": "2.73782"
  },
  {
    "country": "FR",
    "name": "Cépet",
    "lat": "43.74885",
    "lng": "1.43168"
  },
  {
    "country": "FR",
    "name": "Cenon-sur-Vienne",
    "lat": "46.77426",
    "lng": "0.53698"
  },
  {
    "country": "FR",
    "name": "Cenon",
    "lat": "44.8559",
    "lng": "-0.51839"
  },
  {
    "country": "FR",
    "name": "Cendras",
    "lat": "44.15",
    "lng": "4.06667"
  },
  {
    "country": "FR",
    "name": "Cénac-et-Saint-Julien",
    "lat": "44.79968",
    "lng": "1.20535"
  },
  {
    "country": "FR",
    "name": "Cénac",
    "lat": "44.78003",
    "lng": "-0.45999"
  },
  {
    "country": "FR",
    "name": "Cély",
    "lat": "48.45959",
    "lng": "2.53245"
  },
  {
    "country": "FR",
    "name": "Cellieu",
    "lat": "45.5225",
    "lng": "4.54076"
  },
  {
    "country": "FR",
    "name": "Cellettes",
    "lat": "47.52758",
    "lng": "1.38102"
  },
  {
    "country": "FR",
    "name": "Celles-sur-Durolle",
    "lat": "45.85787",
    "lng": "3.63534"
  },
  {
    "country": "FR",
    "name": "Celles-sur-Belle",
    "lat": "46.26223",
    "lng": "-0.21274"
  },
  {
    "country": "FR",
    "name": "Celle-Lévescault",
    "lat": "46.42406",
    "lng": "0.1881"
  },
  {
    "country": "FR",
    "name": "Cébazat",
    "lat": "45.83405",
    "lng": "3.10048"
  },
  {
    "country": "FR",
    "name": "Ceaucé",
    "lat": "48.49436",
    "lng": "-0.62526"
  },
  {
    "country": "FR",
    "name": "Cazouls-lès-Béziers",
    "lat": "43.39218",
    "lng": "3.101"
  },
  {
    "country": "FR",
    "name": "Cazilhac",
    "lat": "43.92031",
    "lng": "3.70285"
  },
  {
    "country": "FR",
    "name": "Cazilhac",
    "lat": "43.18205",
    "lng": "2.36085"
  },
  {
    "country": "FR",
    "name": "Cazes-Mondenard",
    "lat": "44.22689",
    "lng": "1.20299"
  },
  {
    "country": "FR",
    "name": "Cazères-sur-l’Adour",
    "lat": "43.76154",
    "lng": "-0.31546"
  },
  {
    "country": "FR",
    "name": "Cazères",
    "lat": "43.2071",
    "lng": "1.08633"
  },
  {
    "country": "FR",
    "name": "Cazaubon",
    "lat": "43.93431",
    "lng": "-0.06814"
  },
  {
    "country": "FR",
    "name": "Caylus",
    "lat": "44.23607",
    "lng": "1.77168"
  },
  {
    "country": "FR",
    "name": "Cayeux-sur-Mer",
    "lat": "50.182",
    "lng": "1.494"
  },
  {
    "country": "FR",
    "name": "Cavignac",
    "lat": "45.10083",
    "lng": "-0.38976"
  },
  {
    "country": "FR",
    "name": "Caveirac",
    "lat": "43.82437",
    "lng": "4.26664"
  },
  {
    "country": "FR",
    "name": "Cavan",
    "lat": "48.67242",
    "lng": "-3.34606"
  },
  {
    "country": "FR",
    "name": "Cavalaire-sur-Mer",
    "lat": "43.17403",
    "lng": "6.52715"
  },
  {
    "country": "FR",
    "name": "Cavaillon",
    "lat": "43.83125",
    "lng": "5.03586"
  },
  {
    "country": "FR",
    "name": "Caux",
    "lat": "43.50621",
    "lng": "3.36709"
  },
  {
    "country": "FR",
    "name": "Cauville-sur-Mer",
    "lat": "49.6",
    "lng": "0.13333"
  },
  {
    "country": "FR",
    "name": "Cauvigny",
    "lat": "49.3018",
    "lng": "2.24844"
  },
  {
    "country": "FR",
    "name": "Cauterets",
    "lat": "42.88333",
    "lng": "-0.11667"
  },
  {
    "country": "FR",
    "name": "Caussade",
    "lat": "44.1608",
    "lng": "1.53913"
  },
  {
    "country": "FR",
    "name": "Cauro",
    "lat": "41.9179",
    "lng": "8.91399"
  },
  {
    "country": "FR",
    "name": "Caunes-Minervois",
    "lat": "43.32555",
    "lng": "2.52541"
  },
  {
    "country": "FR",
    "name": "Caumont-sur-Durance",
    "lat": "43.89356",
    "lng": "4.94745"
  },
  {
    "country": "FR",
    "name": "Caumont-l'Éventé",
    "lat": "49.09017",
    "lng": "-0.80501"
  },
  {
    "country": "FR",
    "name": "Caumont",
    "lat": "49.36642",
    "lng": "0.89591"
  },
  {
    "country": "FR",
    "name": "Caulnes",
    "lat": "48.28804",
    "lng": "-2.15518"
  },
  {
    "country": "FR",
    "name": "Cauffry",
    "lat": "49.31978",
    "lng": "2.44581"
  },
  {
    "country": "FR",
    "name": "Caudry",
    "lat": "50.1249",
    "lng": "3.41186"
  },
  {
    "country": "FR",
    "name": "Caudebec-lès-Elbeuf",
    "lat": "49.28082",
    "lng": "1.02195"
  },
  {
    "country": "FR",
    "name": "Caudebec-en-Caux",
    "lat": "49.52577",
    "lng": "0.72561"
  },
  {
    "country": "FR",
    "name": "Caudan",
    "lat": "47.80877",
    "lng": "-3.3425"
  },
  {
    "country": "FR",
    "name": "Cauchy-à-la-Tour",
    "lat": "50.50394",
    "lng": "2.44606"
  },
  {
    "country": "FR",
    "name": "Cattenom",
    "lat": "49.40627",
    "lng": "6.24297"
  },
  {
    "country": "FR",
    "name": "Catenoy",
    "lat": "49.36824",
    "lng": "2.51054"
  },
  {
    "country": "FR",
    "name": "Castries",
    "lat": "43.67972",
    "lng": "3.98222"
  },
  {
    "country": "FR",
    "name": "Castres-Gironde",
    "lat": "44.69464",
    "lng": "-0.44679"
  },
  {
    "country": "FR",
    "name": "Castres",
    "lat": "43.6",
    "lng": "2.25"
  },
  {
    "country": "FR",
    "name": "Castillonnès",
    "lat": "44.65215",
    "lng": "0.59222"
  },
  {
    "country": "FR",
    "name": "Castillon-la-Bataille",
    "lat": "44.85",
    "lng": "-0.03333"
  },
  {
    "country": "FR",
    "name": "Castillon-du-Gard",
    "lat": "43.96457",
    "lng": "4.55337"
  },
  {
    "country": "FR",
    "name": "Castets-en-Dorthe",
    "lat": "44.56146",
    "lng": "-0.15226"
  },
  {
    "country": "FR",
    "name": "Castets",
    "lat": "43.88233",
    "lng": "-1.14572"
  },
  {
    "country": "FR",
    "name": "Castelsarrasin",
    "lat": "44.03333",
    "lng": "1.1"
  },
  {
    "country": "FR",
    "name": "Castelnau-le-Lez",
    "lat": "43.63333",
    "lng": "3.9"
  },
  {
    "country": "FR",
    "name": "Castelnau-d'Estrétefonds",
    "lat": "43.78367",
    "lng": "1.35904"
  },
  {
    "country": "FR",
    "name": "Castelnau-Montratier",
    "lat": "44.26667",
    "lng": "1.36667"
  },
  {
    "country": "FR",
    "name": "Castelnau-de-Médoc",
    "lat": "45.02934",
    "lng": "-0.79828"
  },
  {
    "country": "FR",
    "name": "Castelnau-de-Lévis",
    "lat": "43.93975",
    "lng": "2.08491"
  },
  {
    "country": "FR",
    "name": "Castelnau-de-Guers",
    "lat": "43.43398",
    "lng": "3.43708"
  },
  {
    "country": "FR",
    "name": "Castelnaudary",
    "lat": "43.31829",
    "lng": "1.95449"
  },
  {
    "country": "FR",
    "name": "Castelmoron-sur-Lot",
    "lat": "44.3981",
    "lng": "0.49572"
  },
  {
    "country": "FR",
    "name": "Castellane",
    "lat": "43.85",
    "lng": "6.51667"
  },
  {
    "country": "FR",
    "name": "Casteljaloux",
    "lat": "44.31762",
    "lng": "0.08605"
  },
  {
    "country": "FR",
    "name": "Castelginest",
    "lat": "43.69382",
    "lng": "1.4344"
  },
  {
    "country": "FR",
    "name": "Castelculier",
    "lat": "44.17486",
    "lng": "0.69142"
  },
  {
    "country": "FR",
    "name": "Castanet-Tolosan",
    "lat": "43.51591",
    "lng": "1.49864"
  },
  {
    "country": "FR",
    "name": "Castagniers",
    "lat": "43.79321",
    "lng": "7.23286"
  },
  {
    "country": "FR",
    "name": "Cast",
    "lat": "48.15712",
    "lng": "-4.13889"
  },
  {
    "country": "FR",
    "name": "Casson",
    "lat": "47.38761",
    "lng": "-1.55654"
  },
  {
    "country": "FR",
    "name": "Cassis",
    "lat": "43.21241",
    "lng": "5.5451"
  },
  {
    "country": "FR",
    "name": "Casseneuil",
    "lat": "44.4431",
    "lng": "0.62095"
  },
  {
    "country": "FR",
    "name": "Cassel",
    "lat": "50.80109",
    "lng": "2.48527"
  },
  {
    "country": "FR",
    "name": "Cassagnes-Bégonhès",
    "lat": "44.16893",
    "lng": "2.53084"
  },
  {
    "country": "FR",
    "name": "Carvin",
    "lat": "50.49235",
    "lng": "2.95815"
  },
  {
    "country": "FR",
    "name": "Cartignies",
    "lat": "50.0929",
    "lng": "3.84473"
  },
  {
    "country": "FR",
    "name": "Carspach",
    "lat": "47.61628",
    "lng": "7.2115"
  },
  {
    "country": "FR",
    "name": "Carsac-Aillac",
    "lat": "44.83333",
    "lng": "1.25"
  },
  {
    "country": "FR",
    "name": "Cars",
    "lat": "45.12917",
    "lng": "-0.61952"
  },
  {
    "country": "FR",
    "name": "Carry-le-Rouet",
    "lat": "43.33139",
    "lng": "5.15237"
  },
  {
    "country": "FR",
    "name": "Carros",
    "lat": "43.78941",
    "lng": "7.18395"
  },
  {
    "country": "FR",
    "name": "Carrières-sur-Seine",
    "lat": "48.90687",
    "lng": "2.1792"
  },
  {
    "country": "FR",
    "name": "Carrières-sous-Poissy",
    "lat": "48.94952",
    "lng": "2.04068"
  },
  {
    "country": "FR",
    "name": "Carqueiranne",
    "lat": "43.09531",
    "lng": "6.07297"
  },
  {
    "country": "FR",
    "name": "Carquefou",
    "lat": "47.29821",
    "lng": "-1.49024"
  },
  {
    "country": "FR",
    "name": "Carpiquet",
    "lat": "49.18522",
    "lng": "-0.44623"
  },
  {
    "country": "FR",
    "name": "Carpentras",
    "lat": "44.05",
    "lng": "5.05"
  },
  {
    "country": "FR",
    "name": "Caromb",
    "lat": "44.11076",
    "lng": "5.1058"
  },
  {
    "country": "FR",
    "name": "Caro",
    "lat": "47.86429",
    "lng": "-2.31924"
  },
  {
    "country": "FR",
    "name": "Carnoules",
    "lat": "43.30193",
    "lng": "6.18804"
  },
  {
    "country": "FR",
    "name": "Carnac",
    "lat": "47.58351",
    "lng": "-3.07884"
  },
  {
    "country": "FR",
    "name": "Carmaux",
    "lat": "44.05099",
    "lng": "2.15795"
  },
  {
    "country": "FR",
    "name": "Carling",
    "lat": "49.16635",
    "lng": "6.71563"
  },
  {
    "country": "FR",
    "name": "Carlepont",
    "lat": "49.51438",
    "lng": "3.02327"
  },
  {
    "country": "FR",
    "name": "Carignan",
    "lat": "49.63159",
    "lng": "5.16796"
  },
  {
    "country": "FR",
    "name": "Carignan-de-Bordeaux",
    "lat": "44.8",
    "lng": "-0.48333"
  },
  {
    "country": "FR",
    "name": "Carhaix-Plouguer",
    "lat": "48.27594",
    "lng": "-3.57326"
  },
  {
    "country": "FR",
    "name": "Cargèse",
    "lat": "42.13629",
    "lng": "8.59586"
  },
  {
    "country": "FR",
    "name": "Carentoir",
    "lat": "47.81667",
    "lng": "-2.13333"
  },
  {
    "country": "FR",
    "name": "Carentan",
    "lat": "49.30312",
    "lng": "-1.24806"
  },
  {
    "country": "FR",
    "name": "Carcès",
    "lat": "43.47631",
    "lng": "6.18308"
  },
  {
    "country": "FR",
    "name": "Carcassonne",
    "lat": "43.21351",
    "lng": "2.35162"
  },
  {
    "country": "FR",
    "name": "Carcans",
    "lat": "45.07869",
    "lng": "-1.04429"
  },
  {
    "country": "FR",
    "name": "Carbonne",
    "lat": "43.29857",
    "lng": "1.2252"
  },
  {
    "country": "FR",
    "name": "Carbon-Blanc",
    "lat": "44.89642",
    "lng": "-0.50107"
  },
  {
    "country": "FR",
    "name": "Carantec",
    "lat": "48.66811",
    "lng": "-3.91545"
  },
  {
    "country": "FR",
    "name": "Caraman",
    "lat": "43.53271",
    "lng": "1.76002"
  },
  {
    "country": "FR",
    "name": "Capvern",
    "lat": "43.10357",
    "lng": "0.31604"
  },
  {
    "country": "FR",
    "name": "Captieux",
    "lat": "44.2924",
    "lng": "-0.26196"
  },
  {
    "country": "FR",
    "name": "Cappelle-la-Grande",
    "lat": "50.99979",
    "lng": "2.35848"
  },
  {
    "country": "FR",
    "name": "Cappelle-en-Pévèle",
    "lat": "50.51011",
    "lng": "3.17133"
  },
  {
    "country": "FR",
    "name": "Capinghem",
    "lat": "50.64551",
    "lng": "2.96193"
  },
  {
    "country": "FR",
    "name": "Capestang",
    "lat": "43.32791",
    "lng": "3.04447"
  },
  {
    "country": "FR",
    "name": "Capendu",
    "lat": "43.18596",
    "lng": "2.55677"
  },
  {
    "country": "FR",
    "name": "Capdenac-Gare",
    "lat": "44.57567",
    "lng": "2.08079"
  },
  {
    "country": "FR",
    "name": "Cap-d’Ail",
    "lat": "43.72192",
    "lng": "7.40685"
  },
  {
    "country": "FR",
    "name": "Capbreton",
    "lat": "43.64216",
    "lng": "-1.42816"
  },
  {
    "country": "FR",
    "name": "Cany-Barville",
    "lat": "49.78885",
    "lng": "0.63704"
  },
  {
    "country": "FR",
    "name": "Cantin",
    "lat": "50.30885",
    "lng": "3.12765"
  },
  {
    "country": "FR",
    "name": "Cantenay-Épinard",
    "lat": "47.53503",
    "lng": "-0.56899"
  },
  {
    "country": "FR",
    "name": "Cantenac",
    "lat": "45.02816",
    "lng": "-0.65312"
  },
  {
    "country": "FR",
    "name": "Canteleu",
    "lat": "49.44065",
    "lng": "1.02459"
  },
  {
    "country": "FR",
    "name": "Cantaron",
    "lat": "43.75865",
    "lng": "7.31876"
  },
  {
    "country": "FR",
    "name": "Canon",
    "lat": "49.0738",
    "lng": "-0.09219"
  },
  {
    "country": "FR",
    "name": "Canohès",
    "lat": "42.65461",
    "lng": "2.83633"
  },
  {
    "country": "FR",
    "name": "Cannes-Écluse",
    "lat": "48.36303",
    "lng": "2.98748"
  },
  {
    "country": "FR",
    "name": "Cannes",
    "lat": "43.55135",
    "lng": "7.01275"
  },
  {
    "country": "FR",
    "name": "Cangey",
    "lat": "47.46718",
    "lng": "1.06051"
  },
  {
    "country": "FR",
    "name": "Canet",
    "lat": "43.22744",
    "lng": "2.848"
  },
  {
    "country": "FR",
    "name": "Canet-en-Roussillon",
    "lat": "42.7",
    "lng": "3.01667"
  },
  {
    "country": "FR",
    "name": "Canéjan",
    "lat": "44.76667",
    "lng": "-0.63333"
  },
  {
    "country": "FR",
    "name": "Candillargues",
    "lat": "43.62052",
    "lng": "4.06924"
  },
  {
    "country": "FR",
    "name": "Candé-sur-Beuvron",
    "lat": "47.49499",
    "lng": "1.25937"
  },
  {
    "country": "FR",
    "name": "Candé",
    "lat": "47.56158",
    "lng": "-1.03619"
  },
  {
    "country": "FR",
    "name": "Cancon",
    "lat": "44.53543",
    "lng": "0.6252"
  },
  {
    "country": "FR",
    "name": "Cancale",
    "lat": "48.67601",
    "lng": "-1.85231"
  },
  {
    "country": "FR",
    "name": "Camps-la-Source",
    "lat": "43.38641",
    "lng": "6.08661"
  },
  {
    "country": "FR",
    "name": "Campsas",
    "lat": "43.89591",
    "lng": "1.32677"
  },
  {
    "country": "FR",
    "name": "Camphin-en-Pévèle",
    "lat": "50.59561",
    "lng": "3.26082"
  },
  {
    "country": "FR",
    "name": "Camphin-en-Carembault",
    "lat": "50.51196",
    "lng": "2.9871"
  },
  {
    "country": "FR",
    "name": "Campénéac",
    "lat": "47.95733",
    "lng": "-2.29277"
  },
  {
    "country": "FR",
    "name": "Campbon",
    "lat": "47.4131",
    "lng": "-1.96857"
  },
  {
    "country": "FR",
    "name": "Campan",
    "lat": "43.01587",
    "lng": "0.17846"
  },
  {
    "country": "FR",
    "name": "Campagne-lès-Hesdin",
    "lat": "50.39724",
    "lng": "1.87494"
  },
  {
    "country": "FR",
    "name": "Camors",
    "lat": "47.84739",
    "lng": "-2.99981"
  },
  {
    "country": "FR",
    "name": "Camon",
    "lat": "49.88764",
    "lng": "2.34486"
  },
  {
    "country": "FR",
    "name": "Camiers",
    "lat": "50.57153",
    "lng": "1.61325"
  },
  {
    "country": "FR",
    "name": "Cambronne-lès-Ribécourt",
    "lat": "49.50711",
    "lng": "2.89797"
  },
  {
    "country": "FR",
    "name": "Cambronne-lès-Clermont",
    "lat": "49.33022",
    "lng": "2.39928"
  },
  {
    "country": "FR",
    "name": "Cambremer",
    "lat": "49.15192",
    "lng": "0.0476"
  },
  {
    "country": "FR",
    "name": "Cambrai",
    "lat": "50.16667",
    "lng": "3.23333"
  },
  {
    "country": "FR",
    "name": "Cambo-les-Bains",
    "lat": "43.35851",
    "lng": "-1.40105"
  },
  {
    "country": "FR",
    "name": "Camblanes-et-Meynac",
    "lat": "44.76551",
    "lng": "-0.48653"
  },
  {
    "country": "FR",
    "name": "Camblain-Châtelain",
    "lat": "50.48355",
    "lng": "2.45521"
  },
  {
    "country": "FR",
    "name": "Cambes-en-Plaine",
    "lat": "49.23161",
    "lng": "-0.3854"
  },
  {
    "country": "FR",
    "name": "Cambes",
    "lat": "44.73179",
    "lng": "-0.46261"
  },
  {
    "country": "FR",
    "name": "Camaret-sur-Mer",
    "lat": "48.27497",
    "lng": "-4.59615"
  },
  {
    "country": "FR",
    "name": "Camaret-sur-Aigues",
    "lat": "44.16405",
    "lng": "4.87424"
  },
  {
    "country": "FR",
    "name": "Camarès",
    "lat": "43.82208",
    "lng": "2.88005"
  },
  {
    "country": "FR",
    "name": "Calvisson",
    "lat": "43.78696",
    "lng": "4.19626"
  },
  {
    "country": "FR",
    "name": "Calvi",
    "lat": "42.56604",
    "lng": "8.75713"
  },
  {
    "country": "FR",
    "name": "Caluire-et-Cuire",
    "lat": "45.79041",
    "lng": "4.84112"
  },
  {
    "country": "FR",
    "name": "Calonne-sur-la-Lys",
    "lat": "50.62292",
    "lng": "2.61664"
  },
  {
    "country": "FR",
    "name": "Calonne-Ricouart",
    "lat": "50.48504",
    "lng": "2.47335"
  },
  {
    "country": "FR",
    "name": "Calmont",
    "lat": "44.24883",
    "lng": "2.51201"
  },
  {
    "country": "FR",
    "name": "Calmont",
    "lat": "43.28718",
    "lng": "1.63031"
  },
  {
    "country": "FR",
    "name": "Callian",
    "lat": "43.6231",
    "lng": "6.7519"
  },
  {
    "country": "FR",
    "name": "Callas",
    "lat": "43.59237",
    "lng": "6.53738"
  },
  {
    "country": "FR",
    "name": "Callac",
    "lat": "48.40292",
    "lng": "-3.428"
  },
  {
    "country": "FR",
    "name": "Calenzana",
    "lat": "42.50839",
    "lng": "8.85594"
  },
  {
    "country": "FR",
    "name": "Calais",
    "lat": "50.95194",
    "lng": "1.85635"
  },
  {
    "country": "FR",
    "name": "Cajarc",
    "lat": "44.48546",
    "lng": "1.84261"
  },
  {
    "country": "FR",
    "name": "Caissargues",
    "lat": "43.79509",
    "lng": "4.37955"
  },
  {
    "country": "FR",
    "name": "Cairon",
    "lat": "49.24017",
    "lng": "-0.45046"
  },
  {
    "country": "FR",
    "name": "Cailloux-sur-Fontaines",
    "lat": "45.85147",
    "lng": "4.87585"
  },
  {
    "country": "FR",
    "name": "Cahuzac-sur-Vère",
    "lat": "43.98268",
    "lng": "1.91052"
  },
  {
    "country": "FR",
    "name": "Cahors",
    "lat": "44.4491",
    "lng": "1.43663"
  },
  {
    "country": "FR",
    "name": "Cahagnes",
    "lat": "49.06631",
    "lng": "-0.76869"
  },
  {
    "country": "FR",
    "name": "Cagny",
    "lat": "49.86217",
    "lng": "2.34266"
  },
  {
    "country": "FR",
    "name": "Cagny",
    "lat": "49.1458",
    "lng": "-0.2563"
  },
  {
    "country": "FR",
    "name": "Cagnes-sur-Mer",
    "lat": "43.66459",
    "lng": "7.15339"
  },
  {
    "country": "FR",
    "name": "Cagnac-les-Mines",
    "lat": "43.98445",
    "lng": "2.14227"
  },
  {
    "country": "FR",
    "name": "Caëstre",
    "lat": "50.75838",
    "lng": "2.60274"
  },
  {
    "country": "FR",
    "name": "Caen",
    "lat": "49.18585",
    "lng": "-0.35912"
  },
  {
    "country": "FR",
    "name": "Cadolive",
    "lat": "43.39694",
    "lng": "5.54526"
  },
  {
    "country": "FR",
    "name": "Cadillac",
    "lat": "44.63631",
    "lng": "-0.31702"
  },
  {
    "country": "FR",
    "name": "Caderousse",
    "lat": "44.10252",
    "lng": "4.75679"
  },
  {
    "country": "FR",
    "name": "Cadenet",
    "lat": "43.73445",
    "lng": "5.37499"
  },
  {
    "country": "FR",
    "name": "Caden",
    "lat": "47.63124",
    "lng": "-2.28704"
  },
  {
    "country": "FR",
    "name": "Cadaujac",
    "lat": "44.75437",
    "lng": "-0.53128"
  },
  {
    "country": "FR",
    "name": "Cadalen",
    "lat": "43.84933",
    "lng": "1.98089"
  },
  {
    "country": "FR",
    "name": "Cachan",
    "lat": "48.79632",
    "lng": "2.33661"
  },
  {
    "country": "FR",
    "name": "Cabris",
    "lat": "43.65317",
    "lng": "6.87172"
  },
  {
    "country": "FR",
    "name": "Cabriès",
    "lat": "43.44127",
    "lng": "5.37884"
  },
  {
    "country": "FR",
    "name": "Cabrières",
    "lat": "43.90389",
    "lng": "4.47094"
  },
  {
    "country": "FR",
    "name": "Cabourg",
    "lat": "49.2911",
    "lng": "-0.1133"
  },
  {
    "country": "FR",
    "name": "Cabestany",
    "lat": "42.68132",
    "lng": "2.94122"
  },
  {
    "country": "FR",
    "name": "Cabasse",
    "lat": "43.42823",
    "lng": "6.22091"
  },
  {
    "country": "FR",
    "name": "Cabariot",
    "lat": "45.92645",
    "lng": "-0.85741"
  },
  {
    "country": "FR",
    "name": "Cabannes",
    "lat": "43.86015",
    "lng": "4.95192"
  },
  {
    "country": "FR",
    "name": "Cabanac-et-Villagrains",
    "lat": "44.6",
    "lng": "-0.55"
  },
  {
    "country": "FR",
    "name": "Buzet-sur-Tarn",
    "lat": "43.77977",
    "lng": "1.63301"
  },
  {
    "country": "FR",
    "name": "Buzet-sur-Baïse",
    "lat": "44.25811",
    "lng": "0.29809"
  },
  {
    "country": "FR",
    "name": "Buzançais",
    "lat": "46.88877",
    "lng": "1.4195"
  },
  {
    "country": "FR",
    "name": "Buxy",
    "lat": "46.71369",
    "lng": "4.70427"
  },
  {
    "country": "FR",
    "name": "Buxières-les-Mines",
    "lat": "46.46886",
    "lng": "2.96143"
  },
  {
    "country": "FR",
    "name": "Buxerolles",
    "lat": "46.61667",
    "lng": "0.48333"
  },
  {
    "country": "FR",
    "name": "Butry-sur-Oise",
    "lat": "49.08837",
    "lng": "2.19916"
  },
  {
    "country": "FR",
    "name": "Bussy-Saint-Georges",
    "lat": "48.84099",
    "lng": "2.70165"
  },
  {
    "country": "FR",
    "name": "Bussières",
    "lat": "45.83621",
    "lng": "4.26855"
  },
  {
    "country": "FR",
    "name": "Bussière-Poitevine",
    "lat": "46.23543",
    "lng": "0.9053"
  },
  {
    "country": "FR",
    "name": "Bussière-Galant",
    "lat": "45.62702",
    "lng": "1.0364"
  },
  {
    "country": "FR",
    "name": "Bussière-Dunoise",
    "lat": "46.25898",
    "lng": "1.76216"
  },
  {
    "country": "FR",
    "name": "Bussang",
    "lat": "47.88449",
    "lng": "6.85272"
  },
  {
    "country": "FR",
    "name": "Bussac-sur-Charente",
    "lat": "45.78333",
    "lng": "-0.63333"
  },
  {
    "country": "FR",
    "name": "Busnes",
    "lat": "50.58781",
    "lng": "2.51827"
  },
  {
    "country": "FR",
    "name": "Busigny",
    "lat": "50.03424",
    "lng": "3.46713"
  },
  {
    "country": "FR",
    "name": "Bury",
    "lat": "49.31307",
    "lng": "2.34401"
  },
  {
    "country": "FR",
    "name": "Buros",
    "lat": "43.35",
    "lng": "-0.3"
  },
  {
    "country": "FR",
    "name": "Burnhaupt-le-Haut",
    "lat": "47.72945",
    "lng": "7.1461"
  },
  {
    "country": "FR",
    "name": "Burnhaupt-le-Bas",
    "lat": "47.71721",
    "lng": "7.16149"
  },
  {
    "country": "FR",
    "name": "Burlats",
    "lat": "43.63633",
    "lng": "2.31879"
  },
  {
    "country": "FR",
    "name": "Burie",
    "lat": "45.77273",
    "lng": "-0.42289"
  },
  {
    "country": "FR",
    "name": "Bures-sur-Yvette",
    "lat": "48.69981",
    "lng": "2.17064"
  },
  {
    "country": "FR",
    "name": "Burbure",
    "lat": "50.53663",
    "lng": "2.46897"
  },
  {
    "country": "FR",
    "name": "Bully-les-Mines",
    "lat": "50.4438",
    "lng": "2.72703"
  },
  {
    "country": "FR",
    "name": "Bully",
    "lat": "49.10155",
    "lng": "-0.40825"
  },
  {
    "country": "FR",
    "name": "Bully",
    "lat": "45.85205",
    "lng": "4.58195"
  },
  {
    "country": "FR",
    "name": "Bullion",
    "lat": "48.62285",
    "lng": "1.99024"
  },
  {
    "country": "FR",
    "name": "Bulgnéville",
    "lat": "48.20694",
    "lng": "5.8343"
  },
  {
    "country": "FR",
    "name": "Buis-les-Baronnies",
    "lat": "44.27373",
    "lng": "5.2722"
  },
  {
    "country": "FR",
    "name": "Buironfosse",
    "lat": "49.96659",
    "lng": "3.83587"
  },
  {
    "country": "FR",
    "name": "Buhl",
    "lat": "47.92806",
    "lng": "7.18719"
  },
  {
    "country": "FR",
    "name": "Bugeat",
    "lat": "45.59756",
    "lng": "1.92887"
  },
  {
    "country": "FR",
    "name": "Buellas",
    "lat": "46.2111",
    "lng": "5.1322"
  },
  {
    "country": "FR",
    "name": "Bueil",
    "lat": "48.93189",
    "lng": "1.44257"
  },
  {
    "country": "FR",
    "name": "Bucy-le-Long",
    "lat": "49.39072",
    "lng": "3.39582"
  },
  {
    "country": "FR",
    "name": "Bucquoy",
    "lat": "50.13973",
    "lng": "2.71036"
  },
  {
    "country": "FR",
    "name": "Buchy",
    "lat": "49.58513",
    "lng": "1.35852"
  },
  {
    "country": "FR",
    "name": "Buchères",
    "lat": "48.23508",
    "lng": "4.1131"
  },
  {
    "country": "FR",
    "name": "Buchelay",
    "lat": "48.97926",
    "lng": "1.67026"
  },
  {
    "country": "FR",
    "name": "Buc",
    "lat": "48.77627",
    "lng": "2.12577"
  },
  {
    "country": "FR",
    "name": "Bubry",
    "lat": "47.96336",
    "lng": "-3.17108"
  },
  {
    "country": "FR",
    "name": "Bû",
    "lat": "48.79705",
    "lng": "1.49702"
  },
  {
    "country": "FR",
    "name": "Bry-sur-Marne",
    "lat": "48.83811",
    "lng": "2.52488"
  },
  {
    "country": "FR",
    "name": "Bruz",
    "lat": "48.0242",
    "lng": "-1.74591"
  },
  {
    "country": "FR",
    "name": "Bruyères-sur-Oise",
    "lat": "49.15756",
    "lng": "2.32577"
  },
  {
    "country": "FR",
    "name": "Bruyères-le-Châtel",
    "lat": "48.58868",
    "lng": "2.18991"
  },
  {
    "country": "FR",
    "name": "Bruyères-et-Montbérault",
    "lat": "49.52535",
    "lng": "3.66369"
  },
  {
    "country": "FR",
    "name": "Bruyères",
    "lat": "48.20709",
    "lng": "6.71845"
  },
  {
    "country": "FR",
    "name": "Brunstatt",
    "lat": "47.72004",
    "lng": "7.31784"
  },
  {
    "country": "FR",
    "name": "Brunoy",
    "lat": "48.6942",
    "lng": "2.49223"
  },
  {
    "country": "FR",
    "name": "Brumath",
    "lat": "48.73398",
    "lng": "7.71095"
  },
  {
    "country": "FR",
    "name": "Brûlon",
    "lat": "47.96667",
    "lng": "-0.23333"
  },
  {
    "country": "FR",
    "name": "Bruille-Saint-Amand",
    "lat": "50.46605",
    "lng": "3.50013"
  },
  {
    "country": "FR",
    "name": "Bruille-lez-Marchiennes",
    "lat": "50.36068",
    "lng": "3.24424"
  },
  {
    "country": "FR",
    "name": "Bruguières",
    "lat": "43.7272",
    "lng": "1.40762"
  },
  {
    "country": "FR",
    "name": "Brugheas",
    "lat": "46.07698",
    "lng": "3.36754"
  },
  {
    "country": "FR",
    "name": "Bruges",
    "lat": "44.87981",
    "lng": "-0.61219"
  },
  {
    "country": "FR",
    "name": "Bruay-sur-l’Escaut",
    "lat": "50.39918",
    "lng": "3.54379"
  },
  {
    "country": "FR",
    "name": "Bruay-la-Buissière",
    "lat": "50.48333",
    "lng": "2.55"
  },
  {
    "country": "FR",
    "name": "Broût-Vernet",
    "lat": "46.18756",
    "lng": "3.27324"
  },
  {
    "country": "FR",
    "name": "Brou-sur-Chantereine",
    "lat": "48.88333",
    "lng": "2.63333"
  },
  {
    "country": "FR",
    "name": "Brouckerque",
    "lat": "50.95476",
    "lng": "2.29378"
  },
  {
    "country": "FR",
    "name": "Brou",
    "lat": "48.21719",
    "lng": "1.16539"
  },
  {
    "country": "FR",
    "name": "Broons",
    "lat": "48.31748",
    "lng": "-2.25952"
  },
  {
    "country": "FR",
    "name": "Bron",
    "lat": "45.73333",
    "lng": "4.91667"
  },
  {
    "country": "FR",
    "name": "Broglie",
    "lat": "49.00911",
    "lng": "0.52915"
  },
  {
    "country": "FR",
    "name": "Brix",
    "lat": "49.54512",
    "lng": "-1.58012"
  },
  {
    "country": "FR",
    "name": "Brives-Charensac",
    "lat": "45.0478",
    "lng": "3.92878"
  },
  {
    "country": "FR",
    "name": "Brive-la-Gaillarde",
    "lat": "45.15",
    "lng": "1.53333"
  },
  {
    "country": "FR",
    "name": "Brissac-Quincé",
    "lat": "47.35575",
    "lng": "-0.44924"
  },
  {
    "country": "FR",
    "name": "Brison-Saint-Innocent",
    "lat": "45.72185",
    "lng": "5.89011"
  },
  {
    "country": "FR",
    "name": "Briscous",
    "lat": "43.45958",
    "lng": "-1.33353"
  },
  {
    "country": "FR",
    "name": "Briouze",
    "lat": "48.69848",
    "lng": "-0.36806"
  },
  {
    "country": "FR",
    "name": "Brioux-sur-Boutonne",
    "lat": "46.14171",
    "lng": "-0.22182"
  },
  {
    "country": "FR",
    "name": "Brioude",
    "lat": "45.3",
    "lng": "3.4"
  },
  {
    "country": "FR",
    "name": "Brionne",
    "lat": "49.19553",
    "lng": "0.7151"
  },
  {
    "country": "FR",
    "name": "Brion",
    "lat": "47.44121",
    "lng": "-0.15616"
  },
  {
    "country": "FR",
    "name": "Briollay",
    "lat": "47.56478",
    "lng": "-0.50681"
  },
  {
    "country": "FR",
    "name": "Brinon-sur-Sauldre",
    "lat": "47.566",
    "lng": "2.25647"
  },
  {
    "country": "FR",
    "name": "Brindas",
    "lat": "45.72181",
    "lng": "4.68973"
  },
  {
    "country": "FR",
    "name": "Briis-sous-Forges",
    "lat": "48.62399",
    "lng": "2.12112"
  },
  {
    "country": "FR",
    "name": "Brigueuil",
    "lat": "45.95337",
    "lng": "0.86065"
  },
  {
    "country": "FR",
    "name": "Brignoles",
    "lat": "43.4",
    "lng": "6.06667"
  },
  {
    "country": "FR",
    "name": "Brignais",
    "lat": "45.67358",
    "lng": "4.75484"
  },
  {
    "country": "FR",
    "name": "Briey",
    "lat": "49.25",
    "lng": "5.93333"
  },
  {
    "country": "FR",
    "name": "Brienon-sur-Armançon",
    "lat": "47.99009",
    "lng": "3.61628"
  },
  {
    "country": "FR",
    "name": "Briennon",
    "lat": "46.15024",
    "lng": "4.0872"
  },
  {
    "country": "FR",
    "name": "Brienne-le-Château",
    "lat": "48.39319",
    "lng": "4.52637"
  },
  {
    "country": "FR",
    "name": "Brié-et-Angonnes",
    "lat": "45.12418",
    "lng": "5.78374"
  },
  {
    "country": "FR",
    "name": "Brie-Comte-Robert",
    "lat": "48.69247",
    "lng": "2.6109"
  },
  {
    "country": "FR",
    "name": "Briec",
    "lat": "48.10167",
    "lng": "-3.99833"
  },
  {
    "country": "FR",
    "name": "Brie",
    "lat": "45.73804",
    "lng": "0.24107"
  },
  {
    "country": "FR",
    "name": "Bricy",
    "lat": "47.99847",
    "lng": "1.77937"
  },
  {
    "country": "FR",
    "name": "Bricquebec",
    "lat": "49.47008",
    "lng": "-1.63254"
  },
  {
    "country": "FR",
    "name": "Briatexte",
    "lat": "43.75237",
    "lng": "1.90879"
  },
  {
    "country": "FR",
    "name": "Briare",
    "lat": "47.63343",
    "lng": "2.7438"
  },
  {
    "country": "FR",
    "name": "Briançon",
    "lat": "44.89978",
    "lng": "6.64201"
  },
  {
    "country": "FR",
    "name": "Brezolles",
    "lat": "48.69033",
    "lng": "1.07404"
  },
  {
    "country": "FR",
    "name": "Brézins",
    "lat": "45.35202",
    "lng": "5.30692"
  },
  {
    "country": "FR",
    "name": "Brézé",
    "lat": "47.17357",
    "lng": "-0.06059"
  },
  {
    "country": "FR",
    "name": "Bréviandes",
    "lat": "48.25693",
    "lng": "4.09531"
  },
  {
    "country": "FR",
    "name": "Bréval",
    "lat": "48.94545",
    "lng": "1.53309"
  },
  {
    "country": "FR",
    "name": "Breuschwickersheim",
    "lat": "48.58007",
    "lng": "7.60159"
  },
  {
    "country": "FR",
    "name": "Breuilpont",
    "lat": "48.96398",
    "lng": "1.42919"
  },
  {
    "country": "FR",
    "name": "Breuil-Magné",
    "lat": "45.98478",
    "lng": "-0.96"
  },
  {
    "country": "FR",
    "name": "Breuil-le-Vert",
    "lat": "49.36176",
    "lng": "2.43633"
  },
  {
    "country": "FR",
    "name": "Breuillet",
    "lat": "48.57064",
    "lng": "2.17424"
  },
  {
    "country": "FR",
    "name": "Breuillet",
    "lat": "45.69143",
    "lng": "-1.05175"
  },
  {
    "country": "FR",
    "name": "Breuil-le-Sec",
    "lat": "49.37135",
    "lng": "2.45084"
  },
  {
    "country": "FR",
    "name": "Bretteville-sur-Odon",
    "lat": "49.16627",
    "lng": "-0.41662"
  },
  {
    "country": "FR",
    "name": "Bretteville-sur-Laize",
    "lat": "49.04466",
    "lng": "-0.32639"
  },
  {
    "country": "FR",
    "name": "Bretteville-l’Orgueilleuse",
    "lat": "49.21189",
    "lng": "-0.51428"
  },
  {
    "country": "FR",
    "name": "Bretteville-du-Grand-Caux",
    "lat": "49.66667",
    "lng": "0.4"
  },
  {
    "country": "FR",
    "name": "Bretteville",
    "lat": "49.6544",
    "lng": "-1.52884"
  },
  {
    "country": "FR",
    "name": "Brette-les-Pins",
    "lat": "47.91062",
    "lng": "0.33649"
  },
  {
    "country": "FR",
    "name": "Bretoncelles",
    "lat": "48.43122",
    "lng": "0.88775"
  },
  {
    "country": "FR",
    "name": "Brétigny-sur-Orge",
    "lat": "48.61135",
    "lng": "2.30593"
  },
  {
    "country": "FR",
    "name": "Bretignolles-sur-Mer",
    "lat": "46.63333",
    "lng": "-1.86667"
  },
  {
    "country": "FR",
    "name": "Breteuil",
    "lat": "48.83333",
    "lng": "0.91667"
  },
  {
    "country": "FR",
    "name": "Breteuil",
    "lat": "49.63357",
    "lng": "2.29509"
  },
  {
    "country": "FR",
    "name": "Bretenoux",
    "lat": "44.91468",
    "lng": "1.84007"
  },
  {
    "country": "FR",
    "name": "Breteil",
    "lat": "48.14534",
    "lng": "-1.89886"
  },
  {
    "country": "FR",
    "name": "Brest",
    "lat": "48.39029",
    "lng": "-4.48628"
  },
  {
    "country": "FR",
    "name": "Bressuire",
    "lat": "46.85",
    "lng": "-0.48333"
  },
  {
    "country": "FR",
    "name": "Bressols",
    "lat": "43.96796",
    "lng": "1.33839"
  },
  {
    "country": "FR",
    "name": "Bresles",
    "lat": "49.41044",
    "lng": "2.25024"
  },
  {
    "country": "FR",
    "name": "Brens",
    "lat": "43.88725",
    "lng": "1.90716"
  },
  {
    "country": "FR",
    "name": "Brenouille",
    "lat": "49.30551",
    "lng": "2.54437"
  },
  {
    "country": "FR",
    "name": "Brêmes",
    "lat": "50.85483",
    "lng": "1.97687"
  },
  {
    "country": "FR",
    "name": "La Crèche",
    "lat": "46.36667",
    "lng": "-0.3"
  },
  {
    "country": "FR",
    "name": "Breil-sur-Roya",
    "lat": "43.94341",
    "lng": "7.51474"
  },
  {
    "country": "FR",
    "name": "Bréhand",
    "lat": "48.40333",
    "lng": "-2.57412"
  },
  {
    "country": "FR",
    "name": "Bréhal",
    "lat": "48.89915",
    "lng": "-1.51225"
  },
  {
    "country": "FR",
    "name": "Brech",
    "lat": "47.72134",
    "lng": "-2.99862"
  },
  {
    "country": "FR",
    "name": "Brécey",
    "lat": "48.72413",
    "lng": "-1.16647"
  },
  {
    "country": "FR",
    "name": "Brécé",
    "lat": "48.10839",
    "lng": "-1.48086"
  },
  {
    "country": "FR",
    "name": "Brebières",
    "lat": "50.33333",
    "lng": "3.01667"
  },
  {
    "country": "FR",
    "name": "Bréauté",
    "lat": "49.62805",
    "lng": "0.40005"
  },
  {
    "country": "FR",
    "name": "Bréal-sous-Montfort",
    "lat": "48.04876",
    "lng": "-1.86438"
  },
  {
    "country": "FR",
    "name": "Brazey-en-Plaine",
    "lat": "47.13784",
    "lng": "5.21538"
  },
  {
    "country": "FR",
    "name": "Bray-sur-Somme",
    "lat": "49.94085",
    "lng": "2.71847"
  },
  {
    "country": "FR",
    "name": "Bray-sur-Seine",
    "lat": "48.41371",
    "lng": "3.23852"
  },
  {
    "country": "FR",
    "name": "Bray-en-Val",
    "lat": "47.82856",
    "lng": "2.36644"
  },
  {
    "country": "FR",
    "name": "Bray-Dunes",
    "lat": "51.07786",
    "lng": "2.51673"
  },
  {
    "country": "FR",
    "name": "Brax",
    "lat": "44.20277",
    "lng": "0.55163"
  },
  {
    "country": "FR",
    "name": "Brax",
    "lat": "43.61793",
    "lng": "1.23957"
  },
  {
    "country": "FR",
    "name": "Braud-et-Saint-Louis",
    "lat": "45.24703",
    "lng": "-0.62438"
  },
  {
    "country": "FR",
    "name": "Brassac-les-Mines",
    "lat": "45.41105",
    "lng": "3.32915"
  },
  {
    "country": "FR",
    "name": "Brassac",
    "lat": "43.62959",
    "lng": "2.49763"
  },
  {
    "country": "FR",
    "name": "Brasparts",
    "lat": "48.30167",
    "lng": "-3.95516"
  },
  {
    "country": "FR",
    "name": "Brasles",
    "lat": "49.0481",
    "lng": "3.43"
  },
  {
    "country": "FR",
    "name": "Bras",
    "lat": "43.47183",
    "lng": "5.95672"
  },
  {
    "country": "FR",
    "name": "Brantôme",
    "lat": "45.36091",
    "lng": "0.65398"
  },
  {
    "country": "FR",
    "name": "Branoux-les-Taillades",
    "lat": "44.21941",
    "lng": "3.99647"
  },
  {
    "country": "FR",
    "name": "Branne",
    "lat": "44.83333",
    "lng": "-0.18333"
  },
  {
    "country": "FR",
    "name": "Branges",
    "lat": "46.64441",
    "lng": "5.18465"
  },
  {
    "country": "FR",
    "name": "Brando",
    "lat": "42.76667",
    "lng": "9.45"
  },
  {
    "country": "FR",
    "name": "Brandérion",
    "lat": "47.79412",
    "lng": "-3.19474"
  },
  {
    "country": "FR",
    "name": "Bram",
    "lat": "43.24376",
    "lng": "2.11341"
  },
  {
    "country": "FR",
    "name": "Brain-sur-Allonnes",
    "lat": "47.30325",
    "lng": "0.06514"
  },
  {
    "country": "FR",
    "name": "Brains",
    "lat": "47.1685",
    "lng": "-1.7229"
  },
  {
    "country": "FR",
    "name": "Braine",
    "lat": "49.34261",
    "lng": "3.53262"
  },
  {
    "country": "FR",
    "name": "Bracieux",
    "lat": "47.54895",
    "lng": "1.5412"
  },
  {
    "country": "FR",
    "name": "Bozouls",
    "lat": "44.4705",
    "lng": "2.72432"
  },
  {
    "country": "FR",
    "name": "Bozel",
    "lat": "45.44288",
    "lng": "6.64896"
  },
  {
    "country": "FR",
    "name": "Boynes",
    "lat": "48.11822",
    "lng": "2.36006"
  },
  {
    "country": "FR",
    "name": "Boyard-Ville",
    "lat": "45.96717",
    "lng": "-1.24289"
  },
  {
    "country": "FR",
    "name": "Boves",
    "lat": "49.84645",
    "lng": "2.39605"
  },
  {
    "country": "FR",
    "name": "Bouzy-la-Forêt",
    "lat": "47.8512",
    "lng": "2.37773"
  },
  {
    "country": "FR",
    "name": "Bouzonville",
    "lat": "49.29188",
    "lng": "6.53386"
  },
  {
    "country": "FR",
    "name": "Bouzillé",
    "lat": "47.3375",
    "lng": "-1.11143"
  },
  {
    "country": "FR",
    "name": "Bouzigues",
    "lat": "43.4481",
    "lng": "3.65781"
  },
  {
    "country": "FR",
    "name": "Bouxwiller",
    "lat": "48.82495",
    "lng": "7.48117"
  },
  {
    "country": "FR",
    "name": "Bouxières-aux-Dames",
    "lat": "48.75194",
    "lng": "6.16918"
  },
  {
    "country": "FR",
    "name": "Bouxières-aux-Chênes",
    "lat": "48.77115",
    "lng": "6.2603"
  },
  {
    "country": "FR",
    "name": "Bouvron",
    "lat": "47.41726",
    "lng": "-1.84679"
  },
  {
    "country": "FR",
    "name": "Bouville",
    "lat": "49.56193",
    "lng": "0.89514"
  },
  {
    "country": "FR",
    "name": "Bouvigny-Boyeffles",
    "lat": "50.42146",
    "lng": "2.67209"
  },
  {
    "country": "FR",
    "name": "Bouvignies",
    "lat": "50.43627",
    "lng": "3.24361"
  },
  {
    "country": "FR",
    "name": "Bouvesse-Quirieu",
    "lat": "45.79503",
    "lng": "5.41574"
  },
  {
    "country": "FR",
    "name": "Bouttencourt",
    "lat": "49.93725",
    "lng": "1.63431"
  },
  {
    "country": "FR",
    "name": "Boutigny-sur-Essonne",
    "lat": "48.43333",
    "lng": "2.38333"
  },
  {
    "country": "FR",
    "name": "Boutiers-Saint-Trojan",
    "lat": "45.71667",
    "lng": "-0.3"
  },
  {
    "country": "FR",
    "name": "Bout-du-Pont-de-Larn",
    "lat": "43.49738",
    "lng": "2.41642"
  },
  {
    "country": "FR",
    "name": "Boussy-Saint-Antoine",
    "lat": "48.69101",
    "lng": "2.5306"
  },
  {
    "country": "FR",
    "name": "Boussois",
    "lat": "50.28907",
    "lng": "4.04117"
  },
  {
    "country": "FR",
    "name": "Boussières",
    "lat": "47.15866",
    "lng": "5.90314"
  },
  {
    "country": "FR",
    "name": "Bousse",
    "lat": "49.27786",
    "lng": "6.19672"
  },
  {
    "country": "FR",
    "name": "Boussay",
    "lat": "47.04476",
    "lng": "-1.18476"
  },
  {
    "country": "FR",
    "name": "Boussac",
    "lat": "46.34941",
    "lng": "2.21474"
  },
  {
    "country": "FR",
    "name": "Bousies",
    "lat": "50.15097",
    "lng": "3.61752"
  },
  {
    "country": "FR",
    "name": "Bousbecque",
    "lat": "50.77123",
    "lng": "3.08459"
  },
  {
    "country": "FR",
    "name": "Bourth",
    "lat": "48.76846",
    "lng": "0.80911"
  },
  {
    "country": "FR",
    "name": "Bourron-Marlotte",
    "lat": "48.34051",
    "lng": "2.70041"
  },
  {
    "country": "FR",
    "name": "Bourogne",
    "lat": "47.56287",
    "lng": "6.91613"
  },
  {
    "country": "FR",
    "name": "Bournoncle-Saint-Pierre",
    "lat": "45.34301",
    "lng": "3.31837"
  },
  {
    "country": "FR",
    "name": "Bournezeau",
    "lat": "46.63714",
    "lng": "-1.17107"
  },
  {
    "country": "FR",
    "name": "Bourlon",
    "lat": "50.17692",
    "lng": "3.11425"
  },
  {
    "country": "FR",
    "name": "Bourgueil",
    "lat": "47.28333",
    "lng": "0.16612"
  },
  {
    "country": "FR",
    "name": "Bourguébus",
    "lat": "49.12187",
    "lng": "-0.29786"
  },
  {
    "country": "FR",
    "name": "Bourgtheroulde-Infreville",
    "lat": "49.3",
    "lng": "0.88333"
  },
  {
    "country": "FR",
    "name": "Bourg",
    "lat": "45.04062",
    "lng": "-0.55893"
  },
  {
    "country": "FR",
    "name": "Bourg-Saint-Maurice",
    "lat": "45.61716",
    "lng": "6.76902"
  },
  {
    "country": "FR",
    "name": "Bourg-Saint-Andéol",
    "lat": "44.37566",
    "lng": "4.64273"
  },
  {
    "country": "FR",
    "name": "Bourgoin",
    "lat": "45.58333",
    "lng": "5.28333"
  },
  {
    "country": "FR",
    "name": "Bourgogne",
    "lat": "49.34962",
    "lng": "4.07111"
  },
  {
    "country": "FR",
    "name": "Bourgneuf-en-Retz",
    "lat": "47.04122",
    "lng": "-1.95019"
  },
  {
    "country": "FR",
    "name": "Bourgneuf",
    "lat": "46.16766",
    "lng": "-1.02141"
  },
  {
    "country": "FR",
    "name": "la Guingueta d'Ix",
    "lat": "42.43416",
    "lng": "1.94391"
  },
  {
    "country": "FR",
    "name": "Bourg-lès-Valence",
    "lat": "44.95601",
    "lng": "4.91023"
  },
  {
    "country": "FR",
    "name": "Bourg-la-Reine",
    "lat": "48.77888",
    "lng": "2.31781"
  },
  {
    "country": "FR",
    "name": "Bourghelles",
    "lat": "50.56501",
    "lng": "3.24447"
  },
  {
    "country": "FR",
    "name": "Bourges",
    "lat": "47.08333",
    "lng": "2.4"
  },
  {
    "country": "FR",
    "name": "Bourg-en-Bresse",
    "lat": "46.20574",
    "lng": "5.2258"
  },
  {
    "country": "FR",
    "name": "Bourg-de-Thizy",
    "lat": "46.03371",
    "lng": "4.29904"
  },
  {
    "country": "FR",
    "name": "Bourg-des-Comptes",
    "lat": "47.92934",
    "lng": "-1.74534"
  },
  {
    "country": "FR",
    "name": "Bourg-de-Péage",
    "lat": "45.02825",
    "lng": "5.07162"
  },
  {
    "country": "FR",
    "name": "Bourg-Blanc",
    "lat": "48.49867",
    "lng": "-4.50406"
  },
  {
    "country": "FR",
    "name": "Bourgbarré",
    "lat": "47.99515",
    "lng": "-1.61419"
  },
  {
    "country": "FR",
    "name": "Bourg-Argental",
    "lat": "45.2959",
    "lng": "4.56037"
  },
  {
    "country": "FR",
    "name": "Bourganeuf",
    "lat": "45.95268",
    "lng": "1.7552"
  },
  {
    "country": "FR",
    "name": "Bourg-Achard",
    "lat": "49.35322",
    "lng": "0.81623"
  },
  {
    "country": "FR",
    "name": "Bourcefranc-le-Chapus",
    "lat": "45.85",
    "lng": "-1.15"
  },
  {
    "country": "FR",
    "name": "Bourbriac",
    "lat": "48.47384",
    "lng": "-3.18758"
  },
  {
    "country": "FR",
    "name": "Bourbourg",
    "lat": "50.94783",
    "lng": "2.19576"
  },
  {
    "country": "FR",
    "name": "Bourbonne-les-Bains",
    "lat": "47.95305",
    "lng": "5.74801"
  },
  {
    "country": "FR",
    "name": "Bourbon-l’Archambault",
    "lat": "46.58666",
    "lng": "3.05876"
  },
  {
    "country": "FR",
    "name": "Bourbon-Lancy",
    "lat": "46.62214",
    "lng": "3.76953"
  },
  {
    "country": "FR",
    "name": "Bouray-sur-Juine",
    "lat": "48.51981",
    "lng": "2.30001"
  },
  {
    "country": "FR",
    "name": "Boult-sur-Suippe",
    "lat": "49.37149",
    "lng": "4.14632"
  },
  {
    "country": "FR",
    "name": "Bouloire",
    "lat": "47.97385",
    "lng": "0.55009"
  },
  {
    "country": "FR",
    "name": "Boulogne-sur-Mer",
    "lat": "50.71667",
    "lng": "1.61667"
  },
  {
    "country": "FR",
    "name": "Boulogne-sur-Gesse",
    "lat": "43.3",
    "lng": "0.65"
  },
  {
    "country": "FR",
    "name": "Boulogne-Billancourt",
    "lat": "48.83333",
    "lng": "2.25"
  },
  {
    "country": "FR",
    "name": "Bouloc",
    "lat": "43.78163",
    "lng": "1.40522"
  },
  {
    "country": "FR",
    "name": "Boulleret",
    "lat": "47.42419",
    "lng": "2.87343"
  },
  {
    "country": "FR",
    "name": "Bouligny",
    "lat": "49.29189",
    "lng": "5.74248"
  },
  {
    "country": "FR",
    "name": "Boulieu-lès-Annonay",
    "lat": "45.27084",
    "lng": "4.66718"
  },
  {
    "country": "FR",
    "name": "Bouliac",
    "lat": "44.81724",
    "lng": "-0.50248"
  },
  {
    "country": "FR",
    "name": "Bouleurs",
    "lat": "48.88181",
    "lng": "2.90728"
  },
  {
    "country": "FR",
    "name": "Boulbon",
    "lat": "43.86232",
    "lng": "4.69391"
  },
  {
    "country": "FR",
    "name": "Boulazac",
    "lat": "45.11667",
    "lng": "0.75"
  },
  {
    "country": "FR",
    "name": "Boulay-Moselle",
    "lat": "49.18333",
    "lng": "6.5"
  },
  {
    "country": "FR",
    "name": "Boulange",
    "lat": "49.38229",
    "lng": "5.95"
  },
  {
    "country": "FR",
    "name": "Boujan-sur-Libron",
    "lat": "43.36996",
    "lng": "3.24759"
  },
  {
    "country": "FR",
    "name": "Bouin",
    "lat": "46.97314",
    "lng": "-1.9983"
  },
  {
    "country": "FR",
    "name": "Bouilly",
    "lat": "48.19674",
    "lng": "4.00011"
  },
  {
    "country": "FR",
    "name": "Bouillé-Loretz",
    "lat": "47.07911",
    "lng": "-0.27178"
  },
  {
    "country": "FR",
    "name": "Bouillargues",
    "lat": "43.79733",
    "lng": "4.42853"
  },
  {
    "country": "FR",
    "name": "Bouguenais",
    "lat": "47.17762",
    "lng": "-1.62143"
  },
  {
    "country": "FR",
    "name": "Bougival",
    "lat": "48.86223",
    "lng": "2.14148"
  },
  {
    "country": "FR",
    "name": "Boufféré",
    "lat": "46.96179",
    "lng": "-1.33965"
  },
  {
    "country": "FR",
    "name": "Bouffémont",
    "lat": "49.04377",
    "lng": "2.29796"
  },
  {
    "country": "FR",
    "name": "Boué",
    "lat": "50.01141",
    "lng": "3.69608"
  },
  {
    "country": "FR",
    "name": "Bouchemaine",
    "lat": "47.42234",
    "lng": "-0.60888"
  },
  {
    "country": "FR",
    "name": "Bouchain",
    "lat": "50.28519",
    "lng": "3.31491"
  },
  {
    "country": "FR",
    "name": "Bouc-Bel-Air",
    "lat": "43.45217",
    "lng": "5.413"
  },
  {
    "country": "FR",
    "name": "Boucau",
    "lat": "43.5277",
    "lng": "-1.46556"
  },
  {
    "country": "FR",
    "name": "Bouaye",
    "lat": "47.14263",
    "lng": "-1.69306"
  },
  {
    "country": "FR",
    "name": "Bouafle",
    "lat": "48.96463",
    "lng": "1.9012"
  },
  {
    "country": "FR",
    "name": "Bosmie-l'Aiguille",
    "lat": "45.75",
    "lng": "1.2"
  },
  {
    "country": "FR",
    "name": "Bosdarros",
    "lat": "43.21667",
    "lng": "-0.36667"
  },
  {
    "country": "FR",
    "name": "Bosc-le-Hard",
    "lat": "49.62734",
    "lng": "1.17483"
  },
  {
    "country": "FR",
    "name": "Bort-les-Orgues",
    "lat": "45.40065",
    "lng": "2.4965"
  },
  {
    "country": "FR",
    "name": "Bornel",
    "lat": "49.1982",
    "lng": "2.20912"
  },
  {
    "country": "FR",
    "name": "Bormes-les-Mimosas",
    "lat": "43.14073",
    "lng": "6.33863"
  },
  {
    "country": "FR",
    "name": "Borgo",
    "lat": "42.55488",
    "lng": "9.42636"
  },
  {
    "country": "FR",
    "name": "Bords",
    "lat": "45.89722",
    "lng": "-0.79528"
  },
  {
    "country": "FR",
    "name": "Bordes",
    "lat": "43.23333",
    "lng": "-0.28333"
  },
  {
    "country": "FR",
    "name": "Bordeaux",
    "lat": "44.84044",
    "lng": "-0.5805"
  },
  {
    "country": "FR",
    "name": "Boran-sur-Oise",
    "lat": "49.16715",
    "lng": "2.35803"
  },
  {
    "country": "FR",
    "name": "Boos",
    "lat": "49.38849",
    "lng": "1.20348"
  },
  {
    "country": "FR",
    "name": "Boofzheim",
    "lat": "48.33186",
    "lng": "7.68071"
  },
  {
    "country": "FR",
    "name": "Bonson",
    "lat": "45.52455",
    "lng": "4.21659"
  },
  {
    "country": "FR",
    "name": "Bons-en-Chablais",
    "lat": "46.26667",
    "lng": "6.38333"
  },
  {
    "country": "FR",
    "name": "Bonny-sur-Loire",
    "lat": "47.56172",
    "lng": "2.83933"
  },
  {
    "country": "FR",
    "name": "Bonnieux",
    "lat": "43.82452",
    "lng": "5.30739"
  },
  {
    "country": "FR",
    "name": "Bonnières-sur-Seine",
    "lat": "49.03525",
    "lng": "1.5783"
  },
  {
    "country": "FR",
    "name": "Bonneville",
    "lat": "46.0802",
    "lng": "6.40726"
  },
  {
    "country": "FR",
    "name": "Bonneveine",
    "lat": "43.25",
    "lng": "5.38333"
  },
  {
    "country": "FR",
    "name": "Bonneval",
    "lat": "48.18312",
    "lng": "1.38524"
  },
  {
    "country": "FR",
    "name": "Bonneuil-sur-Marne",
    "lat": "48.7695",
    "lng": "2.4793"
  },
  {
    "country": "FR",
    "name": "Bonneuil-Matours",
    "lat": "46.68155",
    "lng": "0.57063"
  },
  {
    "country": "FR",
    "name": "Bonnétable",
    "lat": "48.17908",
    "lng": "0.4257"
  },
  {
    "country": "FR",
    "name": "Bonne-sur-Ménoge",
    "lat": "46.166",
    "lng": "6.32277"
  },
  {
    "country": "FR",
    "name": "Bonnes",
    "lat": "46.60386",
    "lng": "0.59791"
  },
  {
    "country": "FR",
    "name": "Bonnemain",
    "lat": "48.46652",
    "lng": "-1.76774"
  },
  {
    "country": "FR",
    "name": "Bonnelles",
    "lat": "48.61816",
    "lng": "2.02922"
  },
  {
    "country": "FR",
    "name": "Bonnefamille",
    "lat": "45.59589",
    "lng": "5.13035"
  },
  {
    "country": "FR",
    "name": "Bonnat",
    "lat": "46.33333",
    "lng": "1.9"
  },
  {
    "country": "FR",
    "name": "Bonnac-la-Côte",
    "lat": "45.94212",
    "lng": "1.28417"
  },
  {
    "country": "FR",
    "name": "Bonifacio",
    "lat": "41.3874",
    "lng": "9.15941"
  },
  {
    "country": "FR",
    "name": "Bon-Encontre",
    "lat": "44.18518",
    "lng": "0.66759"
  },
  {
    "country": "FR",
    "name": "Bondy",
    "lat": "48.9018",
    "lng": "2.48931"
  },
  {
    "country": "FR",
    "name": "Bondues",
    "lat": "50.70196",
    "lng": "3.09497"
  },
  {
    "country": "FR",
    "name": "Bondoufle",
    "lat": "48.61294",
    "lng": "2.37775"
  },
  {
    "country": "FR",
    "name": "Bonchamp-lès-Laval",
    "lat": "48.07357",
    "lng": "-0.7"
  },
  {
    "country": "FR",
    "name": "Bompas",
    "lat": "42.73333",
    "lng": "2.93333"
  },
  {
    "country": "FR",
    "name": "Bologne",
    "lat": "48.20005",
    "lng": "5.14209"
  },
  {
    "country": "FR",
    "name": "Bollwiller",
    "lat": "47.85832",
    "lng": "7.26179"
  },
  {
    "country": "FR",
    "name": "Bollezeele",
    "lat": "50.86687",
    "lng": "2.34751"
  },
  {
    "country": "FR",
    "name": "Bollène",
    "lat": "44.28476",
    "lng": "4.75303"
  },
  {
    "country": "FR",
    "name": "Bolbec",
    "lat": "49.57321",
    "lng": "0.47339"
  },
  {
    "country": "FR",
    "name": "Boissy-sous-Saint-Yon",
    "lat": "48.55379",
    "lng": "2.21212"
  },
  {
    "country": "FR",
    "name": "Boissy-Saint-Léger",
    "lat": "48.75149",
    "lng": "2.51163"
  },
  {
    "country": "FR",
    "name": "Boissy-le-Cutté",
    "lat": "48.4702",
    "lng": "2.28326"
  },
  {
    "country": "FR",
    "name": "Boissy-le-Châtel",
    "lat": "48.82073",
    "lng": "3.13651"
  },
  {
    "country": "FR",
    "name": "Boissise-le-Roi",
    "lat": "48.52479",
    "lng": "2.56971"
  },
  {
    "country": "FR",
    "name": "Boisseuil",
    "lat": "45.76977",
    "lng": "1.33333"
  },
  {
    "country": "FR",
    "name": "Boisset-et-Gaujac",
    "lat": "44.04749",
    "lng": "4.00861"
  },
  {
    "country": "FR",
    "name": "Boisseron",
    "lat": "43.75795",
    "lng": "4.0797"
  },
  {
    "country": "FR",
    "name": "Boismé",
    "lat": "46.77393",
    "lng": "-0.43476"
  },
  {
    "country": "FR",
    "name": "Bois-le-Roi",
    "lat": "48.47348",
    "lng": "2.70464"
  },
  {
    "country": "FR",
    "name": "Bois-Guillaume",
    "lat": "49.4602",
    "lng": "1.12219"
  },
  {
    "country": "FR",
    "name": "Bois-Grenier",
    "lat": "50.64985",
    "lng": "2.87409"
  },
  {
    "country": "FR",
    "name": "Boisgervilly",
    "lat": "48.16692",
    "lng": "-2.06426"
  },
  {
    "country": "FR",
    "name": "Bois-de-Cené",
    "lat": "46.93689",
    "lng": "-1.88656"
  },
  {
    "country": "FR",
    "name": "Bois-d’Arcy",
    "lat": "48.79966",
    "lng": "2.02325"
  },
  {
    "country": "FR",
    "name": "Bois-d’Amont",
    "lat": "46.5328",
    "lng": "6.1375"
  },
  {
    "country": "FR",
    "name": "Boiscommun",
    "lat": "48.03576",
    "lng": "2.38333"
  },
  {
    "country": "FR",
    "name": "Bois-Colombes",
    "lat": "48.91936",
    "lng": "2.27485"
  },
  {
    "country": "FR",
    "name": "Boigny-sur-Bionne",
    "lat": "47.93333",
    "lng": "2.01667"
  },
  {
    "country": "FR",
    "name": "Bohars",
    "lat": "48.42983",
    "lng": "-4.51292"
  },
  {
    "country": "FR",
    "name": "Bohain-en-Vermandois",
    "lat": "49.9873",
    "lng": "3.453"
  },
  {
    "country": "FR",
    "name": "Boeschepe",
    "lat": "50.8",
    "lng": "2.7"
  },
  {
    "country": "FR",
    "name": "Bœrsch",
    "lat": "48.47656",
    "lng": "7.43998"
  },
  {
    "country": "FR",
    "name": "Boën-sur-Lignon",
    "lat": "45.74618",
    "lng": "4.00959"
  },
  {
    "country": "FR",
    "name": "Boeil-Bezing",
    "lat": "43.21667",
    "lng": "-0.26667"
  },
  {
    "country": "FR",
    "name": "Boëge",
    "lat": "46.20954",
    "lng": "6.40383"
  },
  {
    "country": "FR",
    "name": "Boé",
    "lat": "44.16007",
    "lng": "0.62905"
  },
  {
    "country": "FR",
    "name": "Bodilis",
    "lat": "48.52978",
    "lng": "-4.11567"
  },
  {
    "country": "FR",
    "name": "Bobigny",
    "lat": "48.90982",
    "lng": "2.45012"
  },
  {
    "country": "FR",
    "name": "Blotzheim",
    "lat": "47.60205",
    "lng": "7.4963"
  },
  {
    "country": "FR",
    "name": "Blonville-sur-Mer",
    "lat": "49.33709",
    "lng": "0.02709"
  },
  {
    "country": "FR",
    "name": "Blois",
    "lat": "47.59432",
    "lng": "1.32912"
  },
  {
    "country": "FR",
    "name": "Blodelsheim",
    "lat": "47.88411",
    "lng": "7.53679"
  },
  {
    "country": "FR",
    "name": "Bligny-lès-Beaune",
    "lat": "46.98631",
    "lng": "4.8262"
  },
  {
    "country": "FR",
    "name": "Bliesbruck",
    "lat": "49.11543",
    "lng": "7.18112"
  },
  {
    "country": "FR",
    "name": "Bletterans",
    "lat": "46.74673",
    "lng": "5.45444"
  },
  {
    "country": "FR",
    "name": "Bléré",
    "lat": "47.32738",
    "lng": "0.99186"
  },
  {
    "country": "FR",
    "name": "Blérancourt",
    "lat": "49.51667",
    "lng": "3.15"
  },
  {
    "country": "FR",
    "name": "Blénod-lès-Toul",
    "lat": "48.59814",
    "lng": "5.83956"
  },
  {
    "country": "FR",
    "name": "Blénod-lès-Pont-à-Mousson",
    "lat": "48.88487",
    "lng": "6.04844"
  },
  {
    "country": "FR",
    "name": "Bléneau",
    "lat": "47.7",
    "lng": "2.95"
  },
  {
    "country": "FR",
    "name": "Blendecques",
    "lat": "50.71843",
    "lng": "2.28601"
  },
  {
    "country": "FR",
    "name": "Blaye-les-Mines",
    "lat": "44.03073",
    "lng": "2.13166"
  },
  {
    "country": "FR",
    "name": "Blavozy",
    "lat": "45.0572",
    "lng": "3.97993"
  },
  {
    "country": "FR",
    "name": "Blauzac",
    "lat": "43.96151",
    "lng": "4.3693"
  },
  {
    "country": "FR",
    "name": "Blausasc",
    "lat": "43.80572",
    "lng": "7.36477"
  },
  {
    "country": "FR",
    "name": "Blaringhem",
    "lat": "50.6911",
    "lng": "2.40321"
  },
  {
    "country": "FR",
    "name": "Blanzy",
    "lat": "46.70012",
    "lng": "4.38833"
  },
  {
    "country": "FR",
    "name": "Blanzat",
    "lat": "45.83137",
    "lng": "3.08111"
  },
  {
    "country": "FR",
    "name": "Blanquefort",
    "lat": "44.91248",
    "lng": "-0.63663"
  },
  {
    "country": "FR",
    "name": "Blangy-sur-Bresle",
    "lat": "49.93211",
    "lng": "1.62514"
  },
  {
    "country": "FR",
    "name": "Blancafort",
    "lat": "47.53219",
    "lng": "2.52981"
  },
  {
    "country": "FR",
    "name": "Blamont",
    "lat": "47.38513",
    "lng": "6.848"
  },
  {
    "country": "FR",
    "name": "Blaison-Gohier",
    "lat": "47.39951",
    "lng": "-0.37723"
  },
  {
    "country": "FR",
    "name": "Blainville-sur-Orne",
    "lat": "49.22913",
    "lng": "-0.30061"
  },
  {
    "country": "FR",
    "name": "Blainville-sur-Mer",
    "lat": "49.06599",
    "lng": "-1.5834"
  },
  {
    "country": "FR",
    "name": "Blainville-Crevon",
    "lat": "49.50395",
    "lng": "1.29952"
  },
  {
    "country": "FR",
    "name": "Blaincourt-lès-Précy",
    "lat": "49.23333",
    "lng": "2.35"
  },
  {
    "country": "FR",
    "name": "Blain",
    "lat": "47.47655",
    "lng": "-1.76285"
  },
  {
    "country": "FR",
    "name": "Blagny",
    "lat": "49.62167",
    "lng": "5.19194"
  },
  {
    "country": "FR",
    "name": "Blagnac",
    "lat": "43.63276",
    "lng": "1.39399"
  },
  {
    "country": "FR",
    "name": "Blaesheim",
    "lat": "48.50648",
    "lng": "7.60923"
  },
  {
    "country": "FR",
    "name": "Blacé",
    "lat": "46.03185",
    "lng": "4.64499"
  },
  {
    "country": "FR",
    "name": "Bize-Minervois",
    "lat": "43.31656",
    "lng": "2.87134"
  },
  {
    "country": "FR",
    "name": "Bizanos",
    "lat": "43.28333",
    "lng": "-0.35"
  },
  {
    "country": "FR",
    "name": "Bizanet",
    "lat": "43.16419",
    "lng": "2.87034"
  },
  {
    "country": "FR",
    "name": "Biviers",
    "lat": "45.23333",
    "lng": "5.8"
  },
  {
    "country": "FR",
    "name": "Bitschwiller-lès-Thann",
    "lat": "47.82863",
    "lng": "7.08066"
  },
  {
    "country": "FR",
    "name": "Bitche",
    "lat": "49.05232",
    "lng": "7.42992"
  },
  {
    "country": "FR",
    "name": "Bischwiller",
    "lat": "48.76826",
    "lng": "7.85406"
  },
  {
    "country": "FR",
    "name": "Bischoffsheim",
    "lat": "48.48703",
    "lng": "7.48967"
  },
  {
    "country": "FR",
    "name": "Bischheim",
    "lat": "48.61612",
    "lng": "7.75343"
  },
  {
    "country": "FR",
    "name": "Biscarrosse",
    "lat": "44.39454",
    "lng": "-1.16721"
  },
  {
    "country": "FR",
    "name": "Biot",
    "lat": "43.62723",
    "lng": "7.09645"
  },
  {
    "country": "FR",
    "name": "Bining",
    "lat": "49.03729",
    "lng": "7.25273"
  },
  {
    "country": "FR",
    "name": "Binic",
    "lat": "48.60074",
    "lng": "-2.82602"
  },
  {
    "country": "FR",
    "name": "Billy-sur-Aisne",
    "lat": "49.35632",
    "lng": "3.38357"
  },
  {
    "country": "FR",
    "name": "Billy-Montigny",
    "lat": "50.41711",
    "lng": "2.90286"
  },
  {
    "country": "FR",
    "name": "Billy-Berclau",
    "lat": "50.51783",
    "lng": "2.86613"
  },
  {
    "country": "FR",
    "name": "Billom",
    "lat": "45.72303",
    "lng": "3.34243"
  },
  {
    "country": "FR",
    "name": "Billère",
    "lat": "43.3",
    "lng": "-0.4"
  },
  {
    "country": "FR",
    "name": "Bilieu",
    "lat": "45.44452",
    "lng": "5.54624"
  },
  {
    "country": "FR",
    "name": "Bihorel",
    "lat": "49.45468",
    "lng": "1.1223"
  },
  {
    "country": "FR",
    "name": "Biguglia",
    "lat": "42.62589",
    "lng": "9.43324"
  },
  {
    "country": "FR",
    "name": "Bignoux",
    "lat": "46.60008",
    "lng": "0.46932"
  },
  {
    "country": "FR",
    "name": "Bignan",
    "lat": "47.87935",
    "lng": "-2.77153"
  },
  {
    "country": "FR",
    "name": "Biganos",
    "lat": "44.64504",
    "lng": "-0.97367"
  },
  {
    "country": "FR",
    "name": "Bièvres",
    "lat": "48.75772",
    "lng": "2.21881"
  },
  {
    "country": "FR",
    "name": "Biéville-Beuville",
    "lat": "49.24293",
    "lng": "-0.32762"
  },
  {
    "country": "FR",
    "name": "Biesles",
    "lat": "48.08597",
    "lng": "5.29409"
  },
  {
    "country": "FR",
    "name": "Biesheim",
    "lat": "48.04118",
    "lng": "7.54474"
  },
  {
    "country": "FR",
    "name": "Bierne",
    "lat": "50.96232",
    "lng": "2.40963"
  },
  {
    "country": "FR",
    "name": "Bienville",
    "lat": "48.57582",
    "lng": "5.04579"
  },
  {
    "country": "FR",
    "name": "Bidart",
    "lat": "43.4376",
    "lng": "-1.59127"
  },
  {
    "country": "FR",
    "name": "Bidache",
    "lat": "43.48299",
    "lng": "-1.14121"
  },
  {
    "country": "FR",
    "name": "Bias",
    "lat": "44.41655",
    "lng": "0.66977"
  },
  {
    "country": "FR",
    "name": "Biars-sur-Cère",
    "lat": "44.92629",
    "lng": "1.85403"
  },
  {
    "country": "FR",
    "name": "Biarritz",
    "lat": "43.48012",
    "lng": "-1.55558"
  },
  {
    "country": "FR",
    "name": "Biard",
    "lat": "46.57889",
    "lng": "0.30812"
  },
  {
    "country": "FR",
    "name": "Biache-Saint-Vaast",
    "lat": "50.30869",
    "lng": "2.94777"
  },
  {
    "country": "FR",
    "name": "Bézu-Saint-Éloi",
    "lat": "49.29524",
    "lng": "1.70404"
  },
  {
    "country": "FR",
    "name": "Bezouce",
    "lat": "43.88229",
    "lng": "4.49072"
  },
  {
    "country": "FR",
    "name": "Bezons",
    "lat": "48.92426",
    "lng": "2.2128"
  },
  {
    "country": "FR",
    "name": "Béziers",
    "lat": "43.34122",
    "lng": "3.21402"
  },
  {
    "country": "FR",
    "name": "Bezannes",
    "lat": "49.22339",
    "lng": "3.98892"
  },
  {
    "country": "FR",
    "name": "Beynost",
    "lat": "45.83809",
    "lng": "5.00608"
  },
  {
    "country": "FR",
    "name": "Beynes",
    "lat": "48.85626",
    "lng": "1.87261"
  },
  {
    "country": "FR",
    "name": "Beynat",
    "lat": "45.12419",
    "lng": "1.72392"
  },
  {
    "country": "FR",
    "name": "Beychac-et-Caillau",
    "lat": "44.87781",
    "lng": "-0.40219"
  },
  {
    "country": "FR",
    "name": "Béville-le-Comte",
    "lat": "48.43558",
    "lng": "1.71305"
  },
  {
    "country": "FR",
    "name": "Beuzeville-la-Grenier",
    "lat": "49.59157",
    "lng": "0.42684"
  },
  {
    "country": "FR",
    "name": "Beuzeville",
    "lat": "49.34483",
    "lng": "0.34254"
  },
  {
    "country": "FR",
    "name": "Beuzec-Cap-Sizun",
    "lat": "48.07567",
    "lng": "-4.512"
  },
  {
    "country": "FR",
    "name": "Beuvry",
    "lat": "50.51674",
    "lng": "2.68541"
  },
  {
    "country": "FR",
    "name": "Beuvrages",
    "lat": "50.38414",
    "lng": "3.4942"
  },
  {
    "country": "FR",
    "name": "Beuvillers",
    "lat": "49.12961",
    "lng": "0.25492"
  },
  {
    "country": "FR",
    "name": "Beuville",
    "lat": "49.24364",
    "lng": "-0.32585"
  },
  {
    "country": "FR",
    "name": "Beure",
    "lat": "47.2069",
    "lng": "6.00548"
  },
  {
    "country": "FR",
    "name": "Betz",
    "lat": "49.15558",
    "lng": "2.95584"
  },
  {
    "country": "FR",
    "name": "Betton",
    "lat": "48.18048",
    "lng": "-1.63829"
  },
  {
    "country": "FR",
    "name": "Bettancourt-la-Ferrée",
    "lat": "48.64898",
    "lng": "4.96971"
  },
  {
    "country": "FR",
    "name": "Béthune",
    "lat": "50.53333",
    "lng": "2.63333"
  },
  {
    "country": "FR",
    "name": "Bethoncourt",
    "lat": "47.53512",
    "lng": "6.80504"
  },
  {
    "country": "FR",
    "name": "Béthisy-Saint-Pierre",
    "lat": "49.30482",
    "lng": "2.79636"
  },
  {
    "country": "FR",
    "name": "Béthisy-Saint-Martin",
    "lat": "49.2948",
    "lng": "2.81743"
  },
  {
    "country": "FR",
    "name": "Bétheny",
    "lat": "49.28498",
    "lng": "4.05495"
  },
  {
    "country": "FR",
    "name": "Béthencourt-sur-Mer",
    "lat": "50.07756",
    "lng": "1.50348"
  },
  {
    "country": "FR",
    "name": "Bessines-sur-Gartempe",
    "lat": "46.10799",
    "lng": "1.36865"
  },
  {
    "country": "FR",
    "name": "Bessines",
    "lat": "46.30207",
    "lng": "-0.51294"
  },
  {
    "country": "FR",
    "name": "Bessières",
    "lat": "43.79861",
    "lng": "1.60624"
  },
  {
    "country": "FR",
    "name": "Besse-sur-Issole",
    "lat": "43.34957",
    "lng": "6.17759"
  },
  {
    "country": "FR",
    "name": "Bessé-sur-Braye",
    "lat": "47.83333",
    "lng": "0.75"
  },
  {
    "country": "FR",
    "name": "Bessenay",
    "lat": "45.77721",
    "lng": "4.55376"
  },
  {
    "country": "FR",
    "name": "Bessèges",
    "lat": "44.2923",
    "lng": "4.09661"
  },
  {
    "country": "FR",
    "name": "Besse-et-Saint-Anastaise",
    "lat": "45.51667",
    "lng": "2.93333"
  },
  {
    "country": "FR",
    "name": "Bessay-sur-Allier",
    "lat": "46.44352",
    "lng": "3.36248"
  },
  {
    "country": "FR",
    "name": "Bessancourt",
    "lat": "49.03765",
    "lng": "2.20936"
  },
  {
    "country": "FR",
    "name": "Bessan",
    "lat": "43.36196",
    "lng": "3.42288"
  },
  {
    "country": "FR",
    "name": "Besné",
    "lat": "47.4",
    "lng": "-2.08976"
  },
  {
    "country": "FR",
    "name": "Besançon",
    "lat": "47.24878",
    "lng": "6.01815"
  },
  {
    "country": "FR",
    "name": "Béruges",
    "lat": "46.56738",
    "lng": "0.20741"
  },
  {
    "country": "FR",
    "name": "Bertry",
    "lat": "50.08718",
    "lng": "3.44298"
  },
  {
    "country": "FR",
    "name": "Bertrange",
    "lat": "49.31368",
    "lng": "6.19208"
  },
  {
    "country": "FR",
    "name": "Berthecourt",
    "lat": "49.35097",
    "lng": "2.22471"
  },
  {
    "country": "FR",
    "name": "Berteaucourt-les-Dames",
    "lat": "50.04697",
    "lng": "2.1575"
  },
  {
    "country": "FR",
    "name": "Berstett",
    "lat": "48.679",
    "lng": "7.65721"
  },
  {
    "country": "FR",
    "name": "Berson",
    "lat": "45.10679",
    "lng": "-0.58774"
  },
  {
    "country": "FR",
    "name": "Bersée",
    "lat": "50.47978",
    "lng": "3.14765"
  },
  {
    "country": "FR",
    "name": "Berrwiller",
    "lat": "47.84911",
    "lng": "7.21978"
  },
  {
    "country": "FR",
    "name": "Berrien",
    "lat": "48.40278",
    "lng": "-3.75266"
  },
  {
    "country": "FR",
    "name": "Berric",
    "lat": "47.63326",
    "lng": "-2.5225"
  },
  {
    "country": "FR",
    "name": "Berre-l'Étang",
    "lat": "43.47809",
    "lng": "5.17044"
  },
  {
    "country": "FR",
    "name": "Berre-les-Alpes",
    "lat": "43.83333",
    "lng": "7.33333"
  },
  {
    "country": "FR",
    "name": "Bernis",
    "lat": "43.76913",
    "lng": "4.28713"
  },
  {
    "country": "FR",
    "name": "Bernin",
    "lat": "45.2714",
    "lng": "5.86516"
  },
  {
    "country": "FR",
    "name": "Bernières-sur-Mer",
    "lat": "49.33057",
    "lng": "-0.42299"
  },
  {
    "country": "FR",
    "name": "Berneval-le-Grand",
    "lat": "49.95328",
    "lng": "1.18755"
  },
  {
    "country": "FR",
    "name": "Bernes-sur-Oise",
    "lat": "49.16128",
    "lng": "2.3"
  },
  {
    "country": "FR",
    "name": "Berné",
    "lat": "47.9947",
    "lng": "-3.39421"
  },
  {
    "country": "FR",
    "name": "Bernay",
    "lat": "49.08888",
    "lng": "0.59858"
  },
  {
    "country": "FR",
    "name": "Bernaville",
    "lat": "50.13232",
    "lng": "2.163"
  },
  {
    "country": "FR",
    "name": "Bernardswiller",
    "lat": "48.45035",
    "lng": "7.46238"
  },
  {
    "country": "FR",
    "name": "Berlaimont",
    "lat": "50.20155",
    "lng": "3.81343"
  },
  {
    "country": "FR",
    "name": "Bergues",
    "lat": "50.96882",
    "lng": "2.43242"
  },
  {
    "country": "FR",
    "name": "Bergholtz",
    "lat": "47.91595",
    "lng": "7.24612"
  },
  {
    "country": "FR",
    "name": "Bergheim",
    "lat": "48.2054",
    "lng": "7.36299"
  },
  {
    "country": "FR",
    "name": "Bergerac",
    "lat": "44.85",
    "lng": "0.48333"
  },
  {
    "country": "FR",
    "name": "Berck",
    "lat": "50.4",
    "lng": "1.6"
  },
  {
    "country": "FR",
    "name": "Berck-Plage",
    "lat": "50.40704",
    "lng": "1.56446"
  },
  {
    "country": "FR",
    "name": "Bérat",
    "lat": "43.37857",
    "lng": "1.17572"
  },
  {
    "country": "FR",
    "name": "Benquet",
    "lat": "43.82992",
    "lng": "-0.50102"
  },
  {
    "country": "FR",
    "name": "Bénouville",
    "lat": "49.24151",
    "lng": "-0.28246"
  },
  {
    "country": "FR",
    "name": "Bénodet",
    "lat": "47.87531",
    "lng": "-4.1058"
  },
  {
    "country": "FR",
    "name": "Bennwihr",
    "lat": "48.14456",
    "lng": "7.32445"
  },
  {
    "country": "FR",
    "name": "Bennecourt",
    "lat": "49.04148",
    "lng": "1.55469"
  },
  {
    "country": "FR",
    "name": "Béning-lès-Saint-Avold",
    "lat": "49.13504",
    "lng": "6.83902"
  },
  {
    "country": "FR",
    "name": "Benfeld",
    "lat": "48.37062",
    "lng": "7.5937"
  },
  {
    "country": "FR",
    "name": "Benet",
    "lat": "46.36972",
    "lng": "-0.59333"
  },
  {
    "country": "FR",
    "name": "Bénesse-Maremne",
    "lat": "43.63678",
    "lng": "-1.35773"
  },
  {
    "country": "FR",
    "name": "Bénéjacq",
    "lat": "43.2",
    "lng": "-0.21667"
  },
  {
    "country": "FR",
    "name": "Belz",
    "lat": "47.67506",
    "lng": "-3.168"
  },
  {
    "country": "FR",
    "name": "Belvès",
    "lat": "44.77632",
    "lng": "1.00588"
  },
  {
    "country": "FR",
    "name": "Belpech",
    "lat": "43.19957",
    "lng": "1.75157"
  },
  {
    "country": "FR",
    "name": "Belmont-sur-Rance",
    "lat": "43.81981",
    "lng": "2.75524"
  },
  {
    "country": "FR",
    "name": "Belmont-de-la-Loire",
    "lat": "46.1664",
    "lng": "4.34732"
  },
  {
    "country": "FR",
    "name": "Belloy-en-France",
    "lat": "49.08837",
    "lng": "2.37159"
  },
  {
    "country": "FR",
    "name": "Belligné",
    "lat": "47.46774",
    "lng": "-1.0278"
  },
  {
    "country": "FR",
    "name": "Bellignat",
    "lat": "46.24237",
    "lng": "5.62843"
  },
  {
    "country": "FR",
    "name": "Belley",
    "lat": "45.76667",
    "lng": "5.68333"
  },
  {
    "country": "FR",
    "name": "Belleville-sur-Vie",
    "lat": "46.78369",
    "lng": "-1.42905"
  },
  {
    "country": "FR",
    "name": "Belleville",
    "lat": "46.1",
    "lng": "4.75"
  },
  {
    "country": "FR",
    "name": "Belleville-sur-Meuse",
    "lat": "49.17863",
    "lng": "5.3719"
  },
  {
    "country": "FR",
    "name": "Belleville",
    "lat": "48.81902",
    "lng": "6.10108"
  },
  {
    "country": "FR",
    "name": "Belleville-sur-Loire",
    "lat": "47.5",
    "lng": "2.85"
  },
  {
    "country": "FR",
    "name": "Bellevaux",
    "lat": "46.2598",
    "lng": "6.53474"
  },
  {
    "country": "FR",
    "name": "Belleu",
    "lat": "49.35917",
    "lng": "3.33556"
  },
  {
    "country": "FR",
    "name": "Bellerive-sur-Allier",
    "lat": "46.11633",
    "lng": "3.40338"
  },
  {
    "country": "FR",
    "name": "Bellengreville",
    "lat": "49.12425",
    "lng": "-0.20961"
  },
  {
    "country": "FR",
    "name": "Belleneuve",
    "lat": "47.36224",
    "lng": "5.26393"
  },
  {
    "country": "FR",
    "name": "Bellenaves",
    "lat": "46.19979",
    "lng": "3.08215"
  },
  {
    "country": "FR",
    "name": "Bellême",
    "lat": "48.37329",
    "lng": "0.57005"
  },
  {
    "country": "FR",
    "name": "Belle-Isle-en-Terre",
    "lat": "48.54478",
    "lng": "-3.395"
  },
  {
    "country": "FR",
    "name": "Bellegarde-sur-Valserine",
    "lat": "46.10787",
    "lng": "5.82421"
  },
  {
    "country": "FR",
    "name": "Bellegarde-en-Forez",
    "lat": "45.64662",
    "lng": "4.29908"
  },
  {
    "country": "FR",
    "name": "Bellegarde",
    "lat": "47.98333",
    "lng": "2.43333"
  },
  {
    "country": "FR",
    "name": "Bellegarde",
    "lat": "43.75329",
    "lng": "4.51654"
  },
  {
    "country": "FR",
    "name": "Bellaing",
    "lat": "50.36811",
    "lng": "3.42515"
  },
  {
    "country": "FR",
    "name": "Bellac",
    "lat": "46.11667",
    "lng": "1.05"
  },
  {
    "country": "FR",
    "name": "Belin-Béliet",
    "lat": "44.5",
    "lng": "-0.78333"
  },
  {
    "country": "FR",
    "name": "Béligneux",
    "lat": "45.86822",
    "lng": "5.12683"
  },
  {
    "country": "FR",
    "name": "Belgentier",
    "lat": "43.24594",
    "lng": "6.00095"
  },
  {
    "country": "FR",
    "name": "Belfort",
    "lat": "47.63883",
    "lng": "6.85419"
  },
  {
    "country": "FR",
    "name": "Bélesta",
    "lat": "42.90228",
    "lng": "1.93325"
  },
  {
    "country": "FR",
    "name": "Belcodène",
    "lat": "43.42612",
    "lng": "5.58878"
  },
  {
    "country": "FR",
    "name": "Belbeuf",
    "lat": "49.38766",
    "lng": "1.14245"
  },
  {
    "country": "FR",
    "name": "Belberaud",
    "lat": "43.50557",
    "lng": "1.56725"
  },
  {
    "country": "FR",
    "name": "Bélâbre",
    "lat": "46.55121",
    "lng": "1.15791"
  },
  {
    "country": "FR",
    "name": "Beignon",
    "lat": "47.972",
    "lng": "-2.16933"
  },
  {
    "country": "FR",
    "name": "Behren-lès-Forbach",
    "lat": "49.16949",
    "lng": "6.93933"
  },
  {
    "country": "FR",
    "name": "Bégrolles-en-Mauges",
    "lat": "47.14048",
    "lng": "-0.94"
  },
  {
    "country": "FR",
    "name": "Bègles",
    "lat": "44.80845",
    "lng": "-0.54809"
  },
  {
    "country": "FR",
    "name": "Bégard",
    "lat": "48.62754",
    "lng": "-3.30067"
  },
  {
    "country": "FR",
    "name": "Béganne",
    "lat": "47.5967",
    "lng": "-2.24162"
  },
  {
    "country": "FR",
    "name": "Bégaar",
    "lat": "43.82363",
    "lng": "-0.84904"
  },
  {
    "country": "FR",
    "name": "Bédoin",
    "lat": "44.12432",
    "lng": "5.1804"
  },
  {
    "country": "FR",
    "name": "Bédée",
    "lat": "48.17953",
    "lng": "-1.94477"
  },
  {
    "country": "FR",
    "name": "Bédarrides",
    "lat": "44.04022",
    "lng": "4.89819"
  },
  {
    "country": "FR",
    "name": "Bédarieux",
    "lat": "43.61553",
    "lng": "3.15714"
  },
  {
    "country": "FR",
    "name": "Bécon-les-Granits",
    "lat": "47.50134",
    "lng": "-0.8"
  },
  {
    "country": "FR",
    "name": "Beauzelle",
    "lat": "43.66713",
    "lng": "1.37518"
  },
  {
    "country": "FR",
    "name": "Beauzac",
    "lat": "45.26001",
    "lng": "4.09879"
  },
  {
    "country": "FR",
    "name": "Beauvoisin",
    "lat": "43.71835",
    "lng": "4.32339"
  },
  {
    "country": "FR",
    "name": "Beauvois-en-Cambrésis",
    "lat": "50.13735",
    "lng": "3.3787"
  },
  {
    "country": "FR",
    "name": "Beauvoir-sur-Niort",
    "lat": "46.18017",
    "lng": "-0.47178"
  },
  {
    "country": "FR",
    "name": "Beauvoir-sur-Mer",
    "lat": "46.91274",
    "lng": "-2.04156"
  },
  {
    "country": "FR",
    "name": "Beauvoir-de-Marc",
    "lat": "45.51132",
    "lng": "5.08249"
  },
  {
    "country": "FR",
    "name": "Beauvallon",
    "lat": "44.85662",
    "lng": "4.91155"
  },
  {
    "country": "FR",
    "name": "Beauval",
    "lat": "50.10789",
    "lng": "2.33269"
  },
  {
    "country": "FR",
    "name": "Beauvais",
    "lat": "49.43333",
    "lng": "2.08333"
  },
  {
    "country": "FR",
    "name": "Beautor",
    "lat": "49.65214",
    "lng": "3.34475"
  },
  {
    "country": "FR",
    "name": "Beautiran",
    "lat": "44.70393",
    "lng": "-0.45202"
  },
  {
    "country": "FR",
    "name": "Beausoleil",
    "lat": "43.74904",
    "lng": "7.41702"
  },
  {
    "country": "FR",
    "name": "Beausemblant",
    "lat": "45.21784",
    "lng": "4.82847"
  },
  {
    "country": "FR",
    "name": "Beaurevoir",
    "lat": "49.99714",
    "lng": "3.30855"
  },
  {
    "country": "FR",
    "name": "Beaurepaire",
    "lat": "46.90977",
    "lng": "-1.08928"
  },
  {
    "country": "FR",
    "name": "Beaurepaire",
    "lat": "45.33675",
    "lng": "5.05525"
  },
  {
    "country": "FR",
    "name": "Beaurainville",
    "lat": "50.42432",
    "lng": "1.89938"
  },
  {
    "country": "FR",
    "name": "Beaurains",
    "lat": "50.26599",
    "lng": "2.79467"
  },
  {
    "country": "FR",
    "name": "Beauquesne",
    "lat": "50.08526",
    "lng": "2.39276"
  },
  {
    "country": "FR",
    "name": "Beaupuy",
    "lat": "44.53549",
    "lng": "0.149"
  },
  {
    "country": "FR",
    "name": "Beaupuy",
    "lat": "43.64713",
    "lng": "1.55517"
  },
  {
    "country": "FR",
    "name": "Beaupréau",
    "lat": "47.20464",
    "lng": "-0.98703"
  },
  {
    "country": "FR",
    "name": "Beaune-la-Rolande",
    "lat": "48.07124",
    "lng": "2.4314"
  },
  {
    "country": "FR",
    "name": "Beaune",
    "lat": "47.03333",
    "lng": "4.83333"
  },
  {
    "country": "FR",
    "name": "Beaumont-sur-Sarthe",
    "lat": "48.22772",
    "lng": "0.13186"
  },
  {
    "country": "FR",
    "name": "Beaumont-sur-Oise",
    "lat": "49.14232",
    "lng": "2.28705"
  },
  {
    "country": "FR",
    "name": "Beaumont-sur-Lèze",
    "lat": "43.38095",
    "lng": "1.35826"
  },
  {
    "country": "FR",
    "name": "Beaumont-Monteux",
    "lat": "45.01942",
    "lng": "4.92248"
  },
  {
    "country": "FR",
    "name": "Beaumont-lès-Valence",
    "lat": "44.86328",
    "lng": "4.9457"
  },
  {
    "country": "FR",
    "name": "Beaumont-le-Roger",
    "lat": "49.07839",
    "lng": "0.78081"
  },
  {
    "country": "FR",
    "name": "Beaumont-la-Ronce",
    "lat": "47.56948",
    "lng": "0.67017"
  },
  {
    "country": "FR",
    "name": "Beaumont-Hague",
    "lat": "49.66387",
    "lng": "-1.83822"
  },
  {
    "country": "FR",
    "name": "Beaumont-en-Véron",
    "lat": "47.19397",
    "lng": "0.18436"
  },
  {
    "country": "FR",
    "name": "Beaumont-du-Gâtinais",
    "lat": "48.1386",
    "lng": "2.47913"
  },
  {
    "country": "FR",
    "name": "Beaumont-du-Périgord",
    "lat": "44.76662",
    "lng": "0.76916"
  },
  {
    "country": "FR",
    "name": "Beaumont-de-Pertuis",
    "lat": "43.73788",
    "lng": "5.68618"
  },
  {
    "country": "FR",
    "name": "Beaumont-de-Lomagne",
    "lat": "43.88285",
    "lng": "0.98762"
  },
  {
    "country": "FR",
    "name": "Beaumont",
    "lat": "46.73773",
    "lng": "0.42961"
  },
  {
    "country": "FR",
    "name": "Beaumont",
    "lat": "46.10156",
    "lng": "6.11732"
  },
  {
    "country": "FR",
    "name": "Beaumont",
    "lat": "45.75123",
    "lng": "3.08355"
  },
  {
    "country": "FR",
    "name": "Beaumetz-lès-Loges",
    "lat": "50.23897",
    "lng": "2.65818"
  },
  {
    "country": "FR",
    "name": "Beaumes-de-Venise",
    "lat": "44.11934",
    "lng": "5.02426"
  },
  {
    "country": "FR",
    "name": "Beaulon",
    "lat": "46.60178",
    "lng": "3.67262"
  },
  {
    "country": "FR",
    "name": "Beaulieu-sur-Mer",
    "lat": "43.70758",
    "lng": "7.33289"
  },
  {
    "country": "FR",
    "name": "Beaulieu-sur-Layon",
    "lat": "47.31095",
    "lng": "-0.58988"
  },
  {
    "country": "FR",
    "name": "Beaulieu-sur-Dordogne",
    "lat": "44.97826",
    "lng": "1.83835"
  },
  {
    "country": "FR",
    "name": "Beaulieu-sous-la-Roche",
    "lat": "46.67647",
    "lng": "-1.61129"
  },
  {
    "country": "FR",
    "name": "Beaulieu-lès-Loches",
    "lat": "47.12526",
    "lng": "1.01585"
  },
  {
    "country": "FR",
    "name": "Beaulieu",
    "lat": "43.72861",
    "lng": "4.02194"
  },
  {
    "country": "FR",
    "name": "Beaujeu",
    "lat": "46.15176",
    "lng": "4.59243"
  },
  {
    "country": "FR",
    "name": "Beaugency",
    "lat": "47.78019",
    "lng": "1.62705"
  },
  {
    "country": "FR",
    "name": "Beaufort-en-Vallée",
    "lat": "47.43965",
    "lng": "-0.2189"
  },
  {
    "country": "FR",
    "name": "Beaufort",
    "lat": "45.71776",
    "lng": "6.57391"
  },
  {
    "country": "FR",
    "name": "Beaufay",
    "lat": "48.14664",
    "lng": "0.36224"
  },
  {
    "country": "FR",
    "name": "Beaucroissant",
    "lat": "45.34229",
    "lng": "5.46942"
  },
  {
    "country": "FR",
    "name": "Beaucouzé",
    "lat": "47.47444",
    "lng": "-0.63016"
  },
  {
    "country": "FR",
    "name": "Beaucourt",
    "lat": "47.4899",
    "lng": "6.92407"
  },
  {
    "country": "FR",
    "name": "Beauchastel",
    "lat": "44.82759",
    "lng": "4.79696"
  },
  {
    "country": "FR",
    "name": "Beauchamps",
    "lat": "50.01202",
    "lng": "1.51764"
  },
  {
    "country": "FR",
    "name": "Beauchamp",
    "lat": "49.01667",
    "lng": "2.2"
  },
  {
    "country": "FR",
    "name": "Beaucé",
    "lat": "48.3389",
    "lng": "-1.15804"
  },
  {
    "country": "FR",
    "name": "Beaucamps-le-Vieux",
    "lat": "49.84642",
    "lng": "1.78272"
  },
  {
    "country": "FR",
    "name": "Beaucaire",
    "lat": "43.80806",
    "lng": "4.64417"
  },
  {
    "country": "FR",
    "name": "Bazouges-sur-le-Loir",
    "lat": "47.68928",
    "lng": "-0.16883"
  },
  {
    "country": "FR",
    "name": "Bazouges-la-Pérouse",
    "lat": "48.42606",
    "lng": "-1.57431"
  },
  {
    "country": "FR",
    "name": "Bazoges-en-Pareds",
    "lat": "46.65702",
    "lng": "-0.91654"
  },
  {
    "country": "FR",
    "name": "Bazoches-les-Gallerandes",
    "lat": "48.1654",
    "lng": "2.04319"
  },
  {
    "country": "FR",
    "name": "Baziège",
    "lat": "43.45454",
    "lng": "1.61399"
  },
  {
    "country": "FR",
    "name": "Bazet",
    "lat": "43.29145",
    "lng": "0.06728"
  },
  {
    "country": "FR",
    "name": "Bazemont",
    "lat": "48.92726",
    "lng": "1.86651"
  },
  {
    "country": "FR",
    "name": "Bazeilles",
    "lat": "49.6765",
    "lng": "4.97752"
  },
  {
    "country": "FR",
    "name": "Bazas",
    "lat": "44.43202",
    "lng": "-0.21327"
  },
  {
    "country": "FR",
    "name": "Bazancourt",
    "lat": "49.36562",
    "lng": "4.17051"
  },
  {
    "country": "FR",
    "name": "Bazainville",
    "lat": "48.80435",
    "lng": "1.66732"
  },
  {
    "country": "FR",
    "name": "Bayonne",
    "lat": "43.48333",
    "lng": "-1.48333"
  },
  {
    "country": "FR",
    "name": "Bayon",
    "lat": "48.47366",
    "lng": "6.31583"
  },
  {
    "country": "FR",
    "name": "Bayeux",
    "lat": "49.27732",
    "lng": "-0.7039"
  },
  {
    "country": "FR",
    "name": "Bavilliers",
    "lat": "47.62255",
    "lng": "6.8311"
  },
  {
    "country": "FR",
    "name": "Bavent",
    "lat": "49.22996",
    "lng": "-0.18675"
  },
  {
    "country": "FR",
    "name": "Bavay",
    "lat": "50.29828",
    "lng": "3.79372"
  },
  {
    "country": "FR",
    "name": "Bavans",
    "lat": "47.48528",
    "lng": "6.73324"
  },
  {
    "country": "FR",
    "name": "Bauvin",
    "lat": "50.51714",
    "lng": "2.89404"
  },
  {
    "country": "FR",
    "name": "Bauné",
    "lat": "47.49954",
    "lng": "-0.31906"
  },
  {
    "country": "FR",
    "name": "Baume-les-Dames",
    "lat": "47.35295",
    "lng": "6.36117"
  },
  {
    "country": "FR",
    "name": "Baulon",
    "lat": "47.9859",
    "lng": "-1.93114"
  },
  {
    "country": "FR",
    "name": "Baulne",
    "lat": "48.49303",
    "lng": "2.3623"
  },
  {
    "country": "FR",
    "name": "Baule",
    "lat": "47.81084",
    "lng": "1.67259"
  },
  {
    "country": "FR",
    "name": "Baugy",
    "lat": "47.08181",
    "lng": "2.72848"
  },
  {
    "country": "FR",
    "name": "Baugé-en-Anjou",
    "lat": "47.54447",
    "lng": "-0.10653"
  },
  {
    "country": "FR",
    "name": "Baud",
    "lat": "47.87474",
    "lng": "-3.0176"
  },
  {
    "country": "FR",
    "name": "Batz-sur-Mer",
    "lat": "47.2775",
    "lng": "-2.48027"
  },
  {
    "country": "FR",
    "name": "Battenheim",
    "lat": "47.82007",
    "lng": "7.38303"
  },
  {
    "country": "FR",
    "name": "Batilly",
    "lat": "49.17372",
    "lng": "5.96889"
  },
  {
    "country": "FR",
    "name": "Bastia",
    "lat": "42.70278",
    "lng": "9.45"
  },
  {
    "country": "FR",
    "name": "Bassussarry",
    "lat": "43.44272",
    "lng": "-1.51647"
  },
  {
    "country": "FR",
    "name": "Bassillac",
    "lat": "45.19305",
    "lng": "0.81528"
  },
  {
    "country": "FR",
    "name": "Bassens",
    "lat": "45.58503",
    "lng": "5.94349"
  },
  {
    "country": "FR",
    "name": "Bassens",
    "lat": "44.90226",
    "lng": "-0.51631"
  },
  {
    "country": "FR",
    "name": "Indre",
    "lat": "47.2",
    "lng": "-1.66667"
  },
  {
    "country": "FR",
    "name": "Basse-Ham",
    "lat": "49.38626",
    "lng": "6.2418"
  },
  {
    "country": "FR",
    "name": "Basse-Goulaine",
    "lat": "47.21167",
    "lng": "-1.46748"
  },
  {
    "country": "FR",
    "name": "Bassan",
    "lat": "43.4106",
    "lng": "3.25396"
  },
  {
    "country": "FR",
    "name": "Bas-en-Basset",
    "lat": "45.30654",
    "lng": "4.10899"
  },
  {
    "country": "FR",
    "name": "Bartenheim",
    "lat": "47.63354",
    "lng": "7.47712"
  },
  {
    "country": "FR",
    "name": "Bart",
    "lat": "47.48861",
    "lng": "6.7709"
  },
  {
    "country": "FR",
    "name": "Bar-sur-Seine",
    "lat": "48.11295",
    "lng": "4.37656"
  },
  {
    "country": "FR",
    "name": "Bar-sur-Aube",
    "lat": "48.23333",
    "lng": "4.71667"
  },
  {
    "country": "FR",
    "name": "Barsac",
    "lat": "44.60745",
    "lng": "-0.31527"
  },
  {
    "country": "FR",
    "name": "Barraux",
    "lat": "45.43503",
    "lng": "5.9789"
  },
  {
    "country": "FR",
    "name": "Barr",
    "lat": "48.40755",
    "lng": "7.44873"
  },
  {
    "country": "FR",
    "name": "Barneville-Carteret",
    "lat": "49.38333",
    "lng": "-1.75"
  },
  {
    "country": "FR",
    "name": "Barneville-Plage",
    "lat": "49.36786",
    "lng": "-1.76512"
  },
  {
    "country": "FR",
    "name": "Barlin",
    "lat": "50.45238",
    "lng": "2.61955"
  },
  {
    "country": "FR",
    "name": "Bar-le-Duc",
    "lat": "48.77275",
    "lng": "5.16108"
  },
  {
    "country": "FR",
    "name": "Barjouville",
    "lat": "48.41002",
    "lng": "1.47639"
  },
  {
    "country": "FR",
    "name": "Barjols",
    "lat": "43.55783",
    "lng": "6.00783"
  },
  {
    "country": "FR",
    "name": "Barjac",
    "lat": "44.30743",
    "lng": "4.35146"
  },
  {
    "country": "FR",
    "name": "Bargemon",
    "lat": "43.61899",
    "lng": "6.54957"
  },
  {
    "country": "FR",
    "name": "Barenton",
    "lat": "48.60027",
    "lng": "-0.83258"
  },
  {
    "country": "FR",
    "name": "Barentin",
    "lat": "49.54533",
    "lng": "0.95515"
  },
  {
    "country": "FR",
    "name": "Bardos",
    "lat": "43.47392",
    "lng": "-1.20347"
  },
  {
    "country": "FR",
    "name": "Barcelonnette",
    "lat": "44.38691",
    "lng": "6.65179"
  },
  {
    "country": "FR",
    "name": "Barcelonne-du-Gers",
    "lat": "43.7036",
    "lng": "-0.23619"
  },
  {
    "country": "FR",
    "name": "Barby",
    "lat": "45.57083",
    "lng": "5.98273"
  },
  {
    "country": "FR",
    "name": "Barbizon",
    "lat": "48.44346",
    "lng": "2.60313"
  },
  {
    "country": "FR",
    "name": "Barbezieux-Saint-Hilaire",
    "lat": "45.47265",
    "lng": "-0.15218"
  },
  {
    "country": "FR",
    "name": "Barberaz",
    "lat": "45.55",
    "lng": "5.93333"
  },
  {
    "country": "FR",
    "name": "Barbentane",
    "lat": "43.89967",
    "lng": "4.74921"
  },
  {
    "country": "FR",
    "name": "Barbechat",
    "lat": "47.2775",
    "lng": "-1.28524"
  },
  {
    "country": "FR",
    "name": "Barbazan-Debat",
    "lat": "43.1958",
    "lng": "0.1206"
  },
  {
    "country": "FR",
    "name": "Barbâtre",
    "lat": "46.94116",
    "lng": "-2.17752"
  },
  {
    "country": "FR",
    "name": "Barbaste",
    "lat": "44.16905",
    "lng": "0.28659"
  },
  {
    "country": "FR",
    "name": "Baraqueville",
    "lat": "44.27655",
    "lng": "2.43184"
  },
  {
    "country": "FR",
    "name": "Bapaume",
    "lat": "50.10379",
    "lng": "2.84966"
  },
  {
    "country": "FR",
    "name": "Banyuls de la Marenda",
    "lat": "42.48375",
    "lng": "3.12897"
  },
  {
    "country": "FR",
    "name": "Banyuls-dels-Aspres",
    "lat": "42.56567",
    "lng": "2.86667"
  },
  {
    "country": "FR",
    "name": "Bantzenheim",
    "lat": "47.82561",
    "lng": "7.51498"
  },
  {
    "country": "FR",
    "name": "Bannalec",
    "lat": "47.93229",
    "lng": "-3.69759"
  },
  {
    "country": "FR",
    "name": "Bandol",
    "lat": "43.13709",
    "lng": "5.7316"
  },
  {
    "country": "FR",
    "name": "Ban-de-Laveline",
    "lat": "48.24498",
    "lng": "7.06593"
  },
  {
    "country": "FR",
    "name": "Balzac",
    "lat": "45.7",
    "lng": "0.11667"
  },
  {
    "country": "FR",
    "name": "Balma",
    "lat": "43.61111",
    "lng": "1.49944"
  },
  {
    "country": "FR",
    "name": "Ballots",
    "lat": "47.89617",
    "lng": "-1.04759"
  },
  {
    "country": "FR",
    "name": "Ballon",
    "lat": "48.17317",
    "lng": "0.23814"
  },
  {
    "country": "FR",
    "name": "Ballan-Miré",
    "lat": "47.34057",
    "lng": "0.61466"
  },
  {
    "country": "FR",
    "name": "Ballancourt-sur-Essonne",
    "lat": "48.52525",
    "lng": "2.38604"
  },
  {
    "country": "FR",
    "name": "Ballaison",
    "lat": "46.29943",
    "lng": "6.33191"
  },
  {
    "country": "FR",
    "name": "Ballainvilliers",
    "lat": "48.67481",
    "lng": "2.30057"
  },
  {
    "country": "FR",
    "name": "Baldersheim",
    "lat": "47.80158",
    "lng": "7.38021"
  },
  {
    "country": "FR",
    "name": "Balbigny",
    "lat": "45.81928",
    "lng": "4.18756"
  },
  {
    "country": "FR",
    "name": "Balazé",
    "lat": "48.16797",
    "lng": "-1.19157"
  },
  {
    "country": "FR",
    "name": "Balaruc-le-Vieux",
    "lat": "43.4614",
    "lng": "3.6853"
  },
  {
    "country": "FR",
    "name": "Balaruc-les-Bains",
    "lat": "43.4417",
    "lng": "3.6778"
  },
  {
    "country": "FR",
    "name": "Balan",
    "lat": "49.68881",
    "lng": "4.96478"
  },
  {
    "country": "FR",
    "name": "Balan",
    "lat": "45.8343",
    "lng": "5.09834"
  },
  {
    "country": "FR",
    "name": "Balagny-sur-Thérain",
    "lat": "49.29605",
    "lng": "2.33645"
  },
  {
    "country": "FR",
    "name": "Baixas",
    "lat": "42.74969",
    "lng": "2.81002"
  },
  {
    "country": "FR",
    "name": "Baisieux",
    "lat": "50.60841",
    "lng": "3.25251"
  },
  {
    "country": "FR",
    "name": "Bais",
    "lat": "48.2528",
    "lng": "-0.36493"
  },
  {
    "country": "FR",
    "name": "Bais",
    "lat": "48.00959",
    "lng": "-1.28983"
  },
  {
    "country": "FR",
    "name": "Bainville-sur-Madon",
    "lat": "48.58807",
    "lng": "6.09582"
  },
  {
    "country": "FR",
    "name": "Bains-sur-Oust",
    "lat": "47.70362",
    "lng": "-2.07047"
  },
  {
    "country": "FR",
    "name": "Bains-les-Bains",
    "lat": "48.00113",
    "lng": "6.26492"
  },
  {
    "country": "FR",
    "name": "Bains",
    "lat": "45.00963",
    "lng": "3.77465"
  },
  {
    "country": "FR",
    "name": "Bain-de-Bretagne",
    "lat": "47.84418",
    "lng": "-1.68486"
  },
  {
    "country": "FR",
    "name": "Baincthun",
    "lat": "50.70994",
    "lng": "1.68075"
  },
  {
    "country": "FR",
    "name": "Bailly-Romainvilliers",
    "lat": "48.84729",
    "lng": "2.82352"
  },
  {
    "country": "FR",
    "name": "Bailly-Carrois",
    "lat": "48.58029",
    "lng": "2.99047"
  },
  {
    "country": "FR",
    "name": "Bailly",
    "lat": "48.84168",
    "lng": "2.07673"
  },
  {
    "country": "FR",
    "name": "Bailleval",
    "lat": "49.34605",
    "lng": "2.45695"
  },
  {
    "country": "FR",
    "name": "Bailleul-sur-Thérain",
    "lat": "49.38526",
    "lng": "2.22279"
  },
  {
    "country": "FR",
    "name": "Bailleul-Sir-Berthoult",
    "lat": "50.33752",
    "lng": "2.85129"
  },
  {
    "country": "FR",
    "name": "Bailleul",
    "lat": "50.73592",
    "lng": "2.73594"
  },
  {
    "country": "FR",
    "name": "Baillet-en-France",
    "lat": "49.06187",
    "lng": "2.2988"
  },
  {
    "country": "FR",
    "name": "Bailleau-l’Évêque",
    "lat": "48.4896",
    "lng": "1.39665"
  },
  {
    "country": "FR",
    "name": "Bailleau-le-Pin",
    "lat": "48.36698",
    "lng": "1.32948"
  },
  {
    "country": "FR",
    "name": "Baillargues",
    "lat": "43.66267",
    "lng": "4.01681"
  },
  {
    "country": "FR",
    "name": "Baignes-Sainte-Radegonde",
    "lat": "45.38333",
    "lng": "-0.23333"
  },
  {
    "country": "FR",
    "name": "Baho",
    "lat": "42.7",
    "lng": "2.82204"
  },
  {
    "country": "FR",
    "name": "Baguer-Pican",
    "lat": "48.55253",
    "lng": "-1.69837"
  },
  {
    "country": "FR",
    "name": "Baguer-Morvan",
    "lat": "48.52531",
    "lng": "-1.77332"
  },
  {
    "country": "FR",
    "name": "Bagnols-sur-Cèze",
    "lat": "44.1599",
    "lng": "4.61776"
  },
  {
    "country": "FR",
    "name": "Bagnols-en-Forêt",
    "lat": "43.53666",
    "lng": "6.7019"
  },
  {
    "country": "FR",
    "name": "Bagnolet",
    "lat": "48.86667",
    "lng": "2.41667"
  },
  {
    "country": "FR",
    "name": "Bagnoles-de-l'Orne",
    "lat": "48.5572",
    "lng": "-0.41383"
  },
  {
    "country": "FR",
    "name": "Bagneux",
    "lat": "48.79565",
    "lng": "2.30796"
  },
  {
    "country": "FR",
    "name": "Bagnères-de-Luchon",
    "lat": "42.79079",
    "lng": "0.59315"
  },
  {
    "country": "FR",
    "name": "Bagnères-de-Bigorre",
    "lat": "43.06667",
    "lng": "0.15"
  },
  {
    "country": "FR",
    "name": "Bagneaux-sur-Loing",
    "lat": "48.2331",
    "lng": "2.70675"
  },
  {
    "country": "FR",
    "name": "Bagnac-sur-Célé",
    "lat": "44.66667",
    "lng": "2.16667"
  },
  {
    "country": "FR",
    "name": "Bages",
    "lat": "42.60588",
    "lng": "2.8935"
  },
  {
    "country": "FR",
    "name": "Bâgé-la-Ville",
    "lat": "46.31654",
    "lng": "4.94666"
  },
  {
    "country": "FR",
    "name": "Bagard",
    "lat": "44.07126",
    "lng": "4.05225"
  },
  {
    "country": "FR",
    "name": "Badonviller",
    "lat": "48.50164",
    "lng": "6.89148"
  },
  {
    "country": "FR",
    "name": "Baden",
    "lat": "47.61734",
    "lng": "-2.91987"
  },
  {
    "country": "FR",
    "name": "Bacqueville-en-Caux",
    "lat": "49.78761",
    "lng": "0.99927"
  },
  {
    "country": "FR",
    "name": "Bachy",
    "lat": "50.55079",
    "lng": "3.25976"
  },
  {
    "country": "FR",
    "name": "Bachant",
    "lat": "50.2154",
    "lng": "3.86835"
  },
  {
    "country": "FR",
    "name": "Baccarat",
    "lat": "48.45086",
    "lng": "6.73935"
  },
  {
    "country": "FR",
    "name": "Azille",
    "lat": "43.27691",
    "lng": "2.65981"
  },
  {
    "country": "FR",
    "name": "Azé",
    "lat": "47.85141",
    "lng": "0.99829"
  },
  {
    "country": "FR",
    "name": "Azé",
    "lat": "47.8222",
    "lng": "-0.68333"
  },
  {
    "country": "FR",
    "name": "Azay-sur-Cher",
    "lat": "47.34966",
    "lng": "0.84562"
  },
  {
    "country": "FR",
    "name": "Azay-le-Rideau",
    "lat": "47.26405",
    "lng": "0.47132"
  },
  {
    "country": "FR",
    "name": "Azay-le-Ferron",
    "lat": "46.85097",
    "lng": "1.07084"
  },
  {
    "country": "FR",
    "name": "Azay-le-Brûlé",
    "lat": "46.40011",
    "lng": "-0.24914"
  },
  {
    "country": "FR",
    "name": "Aytré",
    "lat": "46.1357",
    "lng": "-1.11452"
  },
  {
    "country": "FR",
    "name": "Ay-sur-Moselle",
    "lat": "49.24326",
    "lng": "6.20627"
  },
  {
    "country": "FR",
    "name": "Ayse",
    "lat": "46.08333",
    "lng": "6.43333"
  },
  {
    "country": "FR",
    "name": "Ayron",
    "lat": "46.66026",
    "lng": "0.07545"
  },
  {
    "country": "FR",
    "name": "Ayguesvives",
    "lat": "43.43636",
    "lng": "1.59505"
  },
  {
    "country": "FR",
    "name": "Ayguemorte-les-Graves",
    "lat": "44.70988",
    "lng": "-0.4806"
  },
  {
    "country": "FR",
    "name": "Aydoilles",
    "lat": "48.21026",
    "lng": "6.57389"
  },
  {
    "country": "FR",
    "name": "Aydat",
    "lat": "45.66136",
    "lng": "2.97391"
  },
  {
    "country": "FR",
    "name": "Ay",
    "lat": "49.05457",
    "lng": "4.00343"
  },
  {
    "country": "FR",
    "name": "Ax-les-Thermes",
    "lat": "42.71968",
    "lng": "1.83845"
  },
  {
    "country": "FR",
    "name": "Avrillé",
    "lat": "47.5",
    "lng": "-0.58333"
  },
  {
    "country": "FR",
    "name": "Avrillé",
    "lat": "46.4684",
    "lng": "-1.48049"
  },
  {
    "country": "FR",
    "name": "Avrechy",
    "lat": "49.44796",
    "lng": "2.4271"
  },
  {
    "country": "FR",
    "name": "Avranches",
    "lat": "48.68333",
    "lng": "-1.36667"
  },
  {
    "country": "FR",
    "name": "Avord",
    "lat": "47.03514",
    "lng": "2.65295"
  },
  {
    "country": "FR",
    "name": "Avon",
    "lat": "48.40219",
    "lng": "2.72022"
  },
  {
    "country": "FR",
    "name": "Avoine",
    "lat": "47.20533",
    "lng": "0.18253"
  },
  {
    "country": "FR",
    "name": "Avize",
    "lat": "48.97352",
    "lng": "4.01438"
  },
  {
    "country": "FR",
    "name": "Aviron",
    "lat": "49.05",
    "lng": "1.11667"
  },
  {
    "country": "FR",
    "name": "Avion",
    "lat": "50.41038",
    "lng": "2.83053"
  },
  {
    "country": "FR",
    "name": "Avilly-Saint-Léonard",
    "lat": "49.19449",
    "lng": "2.54148"
  },
  {
    "country": "FR",
    "name": "Avignonet-Lauragais",
    "lat": "43.36667",
    "lng": "1.8"
  },
  {
    "country": "FR",
    "name": "Avignon",
    "lat": "43.94834",
    "lng": "4.80892"
  },
  {
    "country": "FR",
    "name": "Avèze",
    "lat": "43.97116",
    "lng": "3.60097"
  },
  {
    "country": "FR",
    "name": "Avessac",
    "lat": "47.65324",
    "lng": "-1.98961"
  },
  {
    "country": "FR",
    "name": "Avesnes-sur-Helpe",
    "lat": "50.11667",
    "lng": "3.93333"
  },
  {
    "country": "FR",
    "name": "Avesnes-le-Sec",
    "lat": "50.251",
    "lng": "3.37768"
  },
  {
    "country": "FR",
    "name": "Avesnes-les-Aubert",
    "lat": "50.2",
    "lng": "3.38333"
  },
  {
    "country": "FR",
    "name": "Avesnes-le-Comte",
    "lat": "50.27767",
    "lng": "2.52957"
  },
  {
    "country": "FR",
    "name": "Avesnelles",
    "lat": "50.11782",
    "lng": "3.94674"
  },
  {
    "country": "FR",
    "name": "Avermes",
    "lat": "46.58666",
    "lng": "3.30619"
  },
  {
    "country": "FR",
    "name": "Avensan",
    "lat": "45.03444",
    "lng": "-0.75568"
  },
  {
    "country": "FR",
    "name": "Avelin",
    "lat": "50.53968",
    "lng": "3.08222"
  },
  {
    "country": "FR",
    "name": "Aveizieux",
    "lat": "45.5675",
    "lng": "4.37136"
  },
  {
    "country": "FR",
    "name": "Aveize",
    "lat": "45.68139",
    "lng": "4.47646"
  },
  {
    "country": "FR",
    "name": "Avanton",
    "lat": "46.66369",
    "lng": "0.30862"
  },
  {
    "country": "FR",
    "name": "Avanne-Aveney",
    "lat": "47.2",
    "lng": "5.96667"
  },
  {
    "country": "FR",
    "name": "Avallon",
    "lat": "47.48333",
    "lng": "3.9"
  },
  {
    "country": "FR",
    "name": "Availles-Limouzine",
    "lat": "46.12104",
    "lng": "0.65558"
  },
  {
    "country": "FR",
    "name": "Auzouer-en-Touraine",
    "lat": "47.5423",
    "lng": "0.92067"
  },
  {
    "country": "FR",
    "name": "Auzielle",
    "lat": "43.54165",
    "lng": "1.56574"
  },
  {
    "country": "FR",
    "name": "Auzeville-Tolosane",
    "lat": "43.52777",
    "lng": "1.4824"
  },
  {
    "country": "FR",
    "name": "Auzebosc",
    "lat": "49.59565",
    "lng": "0.7285"
  },
  {
    "country": "FR",
    "name": "Auzat-la-Combelle",
    "lat": "45.45",
    "lng": "3.31667"
  },
  {
    "country": "FR",
    "name": "Auzances",
    "lat": "46.02849",
    "lng": "2.50042"
  },
  {
    "country": "FR",
    "name": "Auxy",
    "lat": "46.9494",
    "lng": "4.4044"
  },
  {
    "country": "FR",
    "name": "Auxonne",
    "lat": "47.19255",
    "lng": "5.38726"
  },
  {
    "country": "FR",
    "name": "Auxon-Dessous",
    "lat": "47.3",
    "lng": "5.95"
  },
  {
    "country": "FR",
    "name": "Auxi-le-Château",
    "lat": "50.23101",
    "lng": "2.11593"
  },
  {
    "country": "FR",
    "name": "Auxerre",
    "lat": "47.7996",
    "lng": "3.57033"
  },
  {
    "country": "FR",
    "name": "Auvillar",
    "lat": "44.06863",
    "lng": "0.90192"
  },
  {
    "country": "FR",
    "name": "Auvers-sur-Oise",
    "lat": "49.07158",
    "lng": "2.16978"
  },
  {
    "country": "FR",
    "name": "Auvers-Saint-Georges",
    "lat": "48.49276",
    "lng": "2.22045"
  },
  {
    "country": "FR",
    "name": "Auvers-le-Hamon",
    "lat": "47.90246",
    "lng": "-0.3517"
  },
  {
    "country": "FR",
    "name": "Autun",
    "lat": "46.95",
    "lng": "4.3"
  },
  {
    "country": "FR",
    "name": "Autry-le-Châtel",
    "lat": "47.59886",
    "lng": "2.602"
  },
  {
    "country": "FR",
    "name": "Autrans",
    "lat": "45.17703",
    "lng": "5.54424"
  },
  {
    "country": "FR",
    "name": "Authon-du-Perche",
    "lat": "48.19615",
    "lng": "0.89189"
  },
  {
    "country": "FR",
    "name": "Authie",
    "lat": "49.20615",
    "lng": "-0.43191"
  },
  {
    "country": "FR",
    "name": "Auterive",
    "lat": "43.35103",
    "lng": "1.47797"
  },
  {
    "country": "FR",
    "name": "Aussonne",
    "lat": "43.68162",
    "lng": "1.31886"
  },
  {
    "country": "FR",
    "name": "Aussillon",
    "lat": "43.50293",
    "lng": "2.36791"
  },
  {
    "country": "FR",
    "name": "Auriol",
    "lat": "43.37161",
    "lng": "5.6341"
  },
  {
    "country": "FR",
    "name": "Aurillac",
    "lat": "44.9214",
    "lng": "2.43732"
  },
  {
    "country": "FR",
    "name": "Aurignac",
    "lat": "43.21695",
    "lng": "0.88176"
  },
  {
    "country": "FR",
    "name": "Auribeau-sur-Siagne",
    "lat": "43.60441",
    "lng": "6.90779"
  },
  {
    "country": "FR",
    "name": "Auriac-sur-Vendinelle",
    "lat": "43.52416",
    "lng": "1.8264"
  },
  {
    "country": "FR",
    "name": "Aureille",
    "lat": "43.70821",
    "lng": "4.94728"
  },
  {
    "country": "FR",
    "name": "Aureilhan",
    "lat": "43.24337",
    "lng": "0.09581"
  },
  {
    "country": "FR",
    "name": "Aurec-sur-Loire",
    "lat": "45.36907",
    "lng": "4.2049"
  },
  {
    "country": "FR",
    "name": "Auray",
    "lat": "47.67025",
    "lng": "-2.99183"
  },
  {
    "country": "FR",
    "name": "Aups",
    "lat": "43.62904",
    "lng": "6.22553"
  },
  {
    "country": "FR",
    "name": "Auneuil",
    "lat": "49.37026",
    "lng": "1.99712"
  },
  {
    "country": "FR",
    "name": "Auneau",
    "lat": "48.46361",
    "lng": "1.77263"
  },
  {
    "country": "FR",
    "name": "Aunay-sur-Odon",
    "lat": "49.02012",
    "lng": "-0.63238"
  },
  {
    "country": "FR",
    "name": "Aunay-sous-Auneau",
    "lat": "48.4414",
    "lng": "1.81094"
  },
  {
    "country": "FR",
    "name": "Aumont-Aubrac",
    "lat": "44.72205",
    "lng": "3.28466"
  },
  {
    "country": "FR",
    "name": "Aumetz",
    "lat": "49.41787",
    "lng": "5.94418"
  },
  {
    "country": "FR",
    "name": "Aumale",
    "lat": "49.76985",
    "lng": "1.75587"
  },
  {
    "country": "FR",
    "name": "Ault",
    "lat": "50.10404",
    "lng": "1.45"
  },
  {
    "country": "FR",
    "name": "Aulnoye-Aymeries",
    "lat": "50.20141",
    "lng": "3.83844"
  },
  {
    "country": "FR",
    "name": "Aulnoy-lez-Valenciennes",
    "lat": "50.33333",
    "lng": "3.53333"
  },
  {
    "country": "FR",
    "name": "Aulnois-sous-Laon",
    "lat": "49.61429",
    "lng": "3.60547"
  },
  {
    "country": "FR",
    "name": "Aulnay-sur-Mauldre",
    "lat": "48.9295",
    "lng": "1.84113"
  },
  {
    "country": "FR",
    "name": "Aulnay-sous-Bois",
    "lat": "48.93814",
    "lng": "2.49402"
  },
  {
    "country": "FR",
    "name": "Aulnay",
    "lat": "46.02082",
    "lng": "-0.34778"
  },
  {
    "country": "FR",
    "name": "Aulnat",
    "lat": "45.79604",
    "lng": "3.16498"
  },
  {
    "country": "FR",
    "name": "Augy",
    "lat": "47.7664",
    "lng": "3.61051"
  },
  {
    "country": "FR",
    "name": "Augny",
    "lat": "49.0611",
    "lng": "6.1182"
  },
  {
    "country": "FR",
    "name": "Augan",
    "lat": "47.91943",
    "lng": "-2.27905"
  },
  {
    "country": "FR",
    "name": "Auffay",
    "lat": "49.71881",
    "lng": "1.09911"
  },
  {
    "country": "FR",
    "name": "Auffargis",
    "lat": "48.70049",
    "lng": "1.88696"
  },
  {
    "country": "FR",
    "name": "Audun-le-Tiche",
    "lat": "49.47217",
    "lng": "5.9555"
  },
  {
    "country": "FR",
    "name": "Audun-le-Roman",
    "lat": "49.36878",
    "lng": "5.89564"
  },
  {
    "country": "FR",
    "name": "Audruicq",
    "lat": "50.87795",
    "lng": "2.07975"
  },
  {
    "country": "FR",
    "name": "Audincourt",
    "lat": "47.48327",
    "lng": "6.85341"
  },
  {
    "country": "FR",
    "name": "Audierne",
    "lat": "48.0164",
    "lng": "-4.53838"
  },
  {
    "country": "FR",
    "name": "Audenge",
    "lat": "44.68686",
    "lng": "-1.01345"
  },
  {
    "country": "FR",
    "name": "Auchy-les-Mines",
    "lat": "50.51349",
    "lng": "2.78283"
  },
  {
    "country": "FR",
    "name": "Auchy-lès-Hesdin",
    "lat": "50.40114",
    "lng": "2.10145"
  },
  {
    "country": "FR",
    "name": "Auchel",
    "lat": "50.50345",
    "lng": "2.47346"
  },
  {
    "country": "FR",
    "name": "Auch",
    "lat": "43.6454",
    "lng": "0.58793"
  },
  {
    "country": "FR",
    "name": "Aucamville",
    "lat": "43.6702",
    "lng": "1.42808"
  },
  {
    "country": "FR",
    "name": "Auby",
    "lat": "50.41457",
    "lng": "3.05396"
  },
  {
    "country": "FR",
    "name": "Aubusson",
    "lat": "45.95",
    "lng": "2.16667"
  },
  {
    "country": "FR",
    "name": "Aubry-du-Hainaut",
    "lat": "50.36667",
    "lng": "3.46667"
  },
  {
    "country": "FR",
    "name": "Auboué",
    "lat": "49.21309",
    "lng": "5.978"
  },
  {
    "country": "FR",
    "name": "Aubord",
    "lat": "43.75827",
    "lng": "4.31105"
  },
  {
    "country": "FR",
    "name": "Aubin",
    "lat": "44.52809",
    "lng": "2.24439"
  },
  {
    "country": "FR",
    "name": "Aubigny-sur-Nère",
    "lat": "47.48819",
    "lng": "2.43895"
  },
  {
    "country": "FR",
    "name": "Aubigny-au-Bac",
    "lat": "50.2637",
    "lng": "3.16448"
  },
  {
    "country": "FR",
    "name": "Aubigny-en-Artois",
    "lat": "50.35",
    "lng": "2.58333"
  },
  {
    "country": "FR",
    "name": "Aubigny",
    "lat": "46.59653",
    "lng": "-1.45364"
  },
  {
    "country": "FR",
    "name": "Aubigné-Racan",
    "lat": "47.69091",
    "lng": "0.2687"
  },
  {
    "country": "FR",
    "name": "Aubignan",
    "lat": "44.09941",
    "lng": "5.02409"
  },
  {
    "country": "FR",
    "name": "Aubiet",
    "lat": "43.64631",
    "lng": "0.78441"
  },
  {
    "country": "FR",
    "name": "Aubière",
    "lat": "45.75157",
    "lng": "3.11251"
  },
  {
    "country": "FR",
    "name": "Aubie-et-Espessas",
    "lat": "45.01869",
    "lng": "-0.40297"
  },
  {
    "country": "FR",
    "name": "Aubevoye",
    "lat": "49.17097",
    "lng": "1.33537"
  },
  {
    "country": "FR",
    "name": "Aube-sur-Rîle",
    "lat": "48.7392",
    "lng": "0.55161"
  },
  {
    "country": "FR",
    "name": "Aubervilliers",
    "lat": "48.91667",
    "lng": "2.38333"
  },
  {
    "country": "FR",
    "name": "Aubers",
    "lat": "50.59543",
    "lng": "2.82666"
  },
  {
    "country": "FR",
    "name": "Auberives-sur-Varèze",
    "lat": "45.43333",
    "lng": "4.83333"
  },
  {
    "country": "FR",
    "name": "Aubergenville",
    "lat": "48.95996",
    "lng": "1.85467"
  },
  {
    "country": "FR",
    "name": "Auberchicourt",
    "lat": "50.33333",
    "lng": "3.23333"
  },
  {
    "country": "FR",
    "name": "Aubenas",
    "lat": "44.62006",
    "lng": "4.38994"
  },
  {
    "country": "FR",
    "name": "Aubais",
    "lat": "43.75402",
    "lng": "4.14567"
  },
  {
    "country": "FR",
    "name": "Aubagne",
    "lat": "43.29276",
    "lng": "5.57067"
  },
  {
    "country": "FR",
    "name": "Atur",
    "lat": "45.14086",
    "lng": "0.74701"
  },
  {
    "country": "FR",
    "name": "Attigny",
    "lat": "49.47846",
    "lng": "4.57803"
  },
  {
    "country": "FR",
    "name": "Attignat",
    "lat": "46.28815",
    "lng": "5.16126"
  },
  {
    "country": "FR",
    "name": "Attichy",
    "lat": "49.41121",
    "lng": "3.04949"
  },
  {
    "country": "FR",
    "name": "Attiches",
    "lat": "50.5222",
    "lng": "3.06222"
  },
  {
    "country": "FR",
    "name": "Attainville",
    "lat": "49.05779",
    "lng": "2.34497"
  },
  {
    "country": "FR",
    "name": "Athis-Mons",
    "lat": "48.70522",
    "lng": "2.39147"
  },
  {
    "country": "FR",
    "name": "Athis-de-l'Orne",
    "lat": "48.81667",
    "lng": "-0.5"
  },
  {
    "country": "FR",
    "name": "Athies-sous-Laon",
    "lat": "49.57369",
    "lng": "3.68417"
  },
  {
    "country": "FR",
    "name": "Athée-sur-Cher",
    "lat": "47.32023",
    "lng": "0.91659"
  },
  {
    "country": "FR",
    "name": "Astaffort",
    "lat": "44.06426",
    "lng": "0.65141"
  },
  {
    "country": "FR",
    "name": "Asson",
    "lat": "43.15",
    "lng": "-0.25"
  },
  {
    "country": "FR",
    "name": "Assérac",
    "lat": "47.42881",
    "lng": "-2.38916"
  },
  {
    "country": "FR",
    "name": "Assat",
    "lat": "43.25",
    "lng": "-0.3"
  },
  {
    "country": "FR",
    "name": "Assas",
    "lat": "43.70278",
    "lng": "3.9"
  },
  {
    "country": "FR",
    "name": "Aspremont",
    "lat": "43.78539",
    "lng": "7.24458"
  },
  {
    "country": "FR",
    "name": "Aspiran",
    "lat": "43.56586",
    "lng": "3.45031"
  },
  {
    "country": "FR",
    "name": "Aspet",
    "lat": "43.01457",
    "lng": "0.80294"
  },
  {
    "country": "FR",
    "name": "Aspach-le-Haut",
    "lat": "47.77653",
    "lng": "7.13145"
  },
  {
    "country": "FR",
    "name": "Aspach-le-Bas",
    "lat": "47.76115",
    "lng": "7.1509"
  },
  {
    "country": "FR",
    "name": "Aspach",
    "lat": "47.64173",
    "lng": "7.23324"
  },
  {
    "country": "FR",
    "name": "Asnières-sur-Oise",
    "lat": "49.13369",
    "lng": "2.35551"
  },
  {
    "country": "FR",
    "name": "Asnières-sur-Nouère",
    "lat": "45.71667",
    "lng": "0.05"
  },
  {
    "country": "FR",
    "name": "Asnières-sur-Seine",
    "lat": "48.91667",
    "lng": "2.28333"
  },
  {
    "country": "FR",
    "name": "Aschères-le-Marché",
    "lat": "48.11008",
    "lng": "2.00725"
  },
  {
    "country": "FR",
    "name": "Ascain",
    "lat": "43.34521",
    "lng": "-1.62073"
  },
  {
    "country": "FR",
    "name": "Arzon",
    "lat": "47.54852",
    "lng": "-2.88989"
  },
  {
    "country": "FR",
    "name": "Arzens",
    "lat": "43.19838",
    "lng": "2.20954"
  },
  {
    "country": "FR",
    "name": "Arzano",
    "lat": "47.90136",
    "lng": "-3.44032"
  },
  {
    "country": "FR",
    "name": "Arveyres",
    "lat": "44.88333",
    "lng": "-0.28333"
  },
  {
    "country": "FR",
    "name": "Arvert",
    "lat": "45.74486",
    "lng": "-1.12573"
  },
  {
    "country": "FR",
    "name": "Arudy",
    "lat": "43.1064",
    "lng": "-0.43333"
  },
  {
    "country": "FR",
    "name": "Art-sur-Meurthe",
    "lat": "48.65589",
    "lng": "6.26612"
  },
  {
    "country": "FR",
    "name": "Artres",
    "lat": "50.29482",
    "lng": "3.54013"
  },
  {
    "country": "FR",
    "name": "Artix",
    "lat": "43.4",
    "lng": "-0.55"
  },
  {
    "country": "FR",
    "name": "Artigues-près-Bordeaux",
    "lat": "44.85",
    "lng": "-0.51667"
  },
  {
    "country": "FR",
    "name": "Artiguelouve",
    "lat": "43.31667",
    "lng": "-0.46667"
  },
  {
    "country": "FR",
    "name": "Arthon-en-Retz",
    "lat": "47.11586",
    "lng": "-1.9426"
  },
  {
    "country": "FR",
    "name": "Arthon",
    "lat": "46.69361",
    "lng": "1.69857"
  },
  {
    "country": "FR",
    "name": "Arthez-de-Béarn",
    "lat": "43.46667",
    "lng": "-0.6"
  },
  {
    "country": "FR",
    "name": "Arthès",
    "lat": "43.95745",
    "lng": "2.2113"
  },
  {
    "country": "FR",
    "name": "Arthaz-Pont-Notre-Dame",
    "lat": "46.15941",
    "lng": "6.26598"
  },
  {
    "country": "FR",
    "name": "Artenay",
    "lat": "48.08246",
    "lng": "1.88098"
  },
  {
    "country": "FR",
    "name": "Artemare",
    "lat": "45.87441",
    "lng": "5.69366"
  },
  {
    "country": "FR",
    "name": "Artas",
    "lat": "45.53555",
    "lng": "5.16505"
  },
  {
    "country": "FR",
    "name": "Artannes-sur-Indre",
    "lat": "47.27451",
    "lng": "0.60036"
  },
  {
    "country": "FR",
    "name": "Ars-sur-Moselle",
    "lat": "49.07791",
    "lng": "6.0742"
  },
  {
    "country": "FR",
    "name": "Ars-sur-Formans",
    "lat": "45.99418",
    "lng": "4.82313"
  },
  {
    "country": "FR",
    "name": "Ars-en-Ré",
    "lat": "46.20555",
    "lng": "-1.5272"
  },
  {
    "country": "FR",
    "name": "Arsac",
    "lat": "44.99688",
    "lng": "-0.68976"
  },
  {
    "country": "FR",
    "name": "Arrou",
    "lat": "48.09768",
    "lng": "1.12851"
  },
  {
    "country": "FR",
    "name": "Arras",
    "lat": "50.29301",
    "lng": "2.78186"
  },
  {
    "country": "FR",
    "name": "Arradon",
    "lat": "47.62709",
    "lng": "-2.8215"
  },
  {
    "country": "FR",
    "name": "Arques-la-Bataille",
    "lat": "49.88122",
    "lng": "1.12875"
  },
  {
    "country": "FR",
    "name": "Arques",
    "lat": "50.73375",
    "lng": "2.30237"
  },
  {
    "country": "FR",
    "name": "Arpajon-sur-Cère",
    "lat": "44.90262",
    "lng": "2.45809"
  },
  {
    "country": "FR",
    "name": "Arpajon",
    "lat": "48.58875",
    "lng": "2.24672"
  },
  {
    "country": "FR",
    "name": "Aron",
    "lat": "48.298",
    "lng": "-0.5598"
  },
  {
    "country": "FR",
    "name": "Arnouville",
    "lat": "48.98333",
    "lng": "2.41667"
  },
  {
    "country": "FR",
    "name": "Arnières-sur-Iton",
    "lat": "48.99678",
    "lng": "1.10384"
  },
  {
    "country": "FR",
    "name": "Arnèke",
    "lat": "50.83219",
    "lng": "2.40943"
  },
  {
    "country": "FR",
    "name": "Arnay-le-Duc",
    "lat": "47.13202",
    "lng": "4.48595"
  },
  {
    "country": "FR",
    "name": "Arnas",
    "lat": "46.0239",
    "lng": "4.70638"
  },
  {
    "country": "FR",
    "name": "Arnage",
    "lat": "47.92616",
    "lng": "0.18782"
  },
  {
    "country": "FR",
    "name": "Arnac-Pompadour",
    "lat": "45.40975",
    "lng": "1.36993"
  },
  {
    "country": "FR",
    "name": "Arnac-la-Poste",
    "lat": "46.26597",
    "lng": "1.37375"
  },
  {
    "country": "FR",
    "name": "Armoy",
    "lat": "46.34893",
    "lng": "6.52001"
  },
  {
    "country": "FR",
    "name": "Armissan",
    "lat": "43.18778",
    "lng": "3.0966"
  },
  {
    "country": "FR",
    "name": "Armentières-en-Brie",
    "lat": "48.97775",
    "lng": "3.02073"
  },
  {
    "country": "FR",
    "name": "Armentières",
    "lat": "50.68568",
    "lng": "2.88214"
  },
  {
    "country": "FR",
    "name": "Armenonville-les-Gâtineaux",
    "lat": "48.54365",
    "lng": "1.6475"
  },
  {
    "country": "FR",
    "name": "Armbouts-Cappel",
    "lat": "50.97682",
    "lng": "2.35352"
  },
  {
    "country": "FR",
    "name": "Arleux",
    "lat": "50.28037",
    "lng": "3.10448"
  },
  {
    "country": "FR",
    "name": "Arles",
    "lat": "42.45654",
    "lng": "2.63457"
  },
  {
    "country": "FR",
    "name": "Arles",
    "lat": "43.67681",
    "lng": "4.63031"
  },
  {
    "country": "FR",
    "name": "Arlanc",
    "lat": "45.41389",
    "lng": "3.72528"
  },
  {
    "country": "FR",
    "name": "Arinthod",
    "lat": "46.39339",
    "lng": "5.56616"
  },
  {
    "country": "FR",
    "name": "Argent-sur-Sauldre",
    "lat": "47.55847",
    "lng": "2.4441"
  },
  {
    "country": "FR",
    "name": "Argentré-du-Plessis",
    "lat": "48.05697",
    "lng": "-1.14601"
  },
  {
    "country": "FR",
    "name": "Argentré",
    "lat": "48.08362",
    "lng": "-0.6415"
  },
  {
    "country": "FR",
    "name": "Argenton-sur-Creuse",
    "lat": "46.58997",
    "lng": "1.51981"
  },
  {
    "country": "FR",
    "name": "Argenton-les-Vallées",
    "lat": "46.98333",
    "lng": "-0.45"
  },
  {
    "country": "FR",
    "name": "Argenteuil",
    "lat": "48.95",
    "lng": "2.25"
  },
  {
    "country": "FR",
    "name": "Argentat",
    "lat": "45.09634",
    "lng": "1.93987"
  },
  {
    "country": "FR",
    "name": "Argentan",
    "lat": "48.75",
    "lng": "-0.01667"
  },
  {
    "country": "FR",
    "name": "Argences",
    "lat": "49.12635",
    "lng": "-0.16644"
  },
  {
    "country": "FR",
    "name": "Argeliers",
    "lat": "43.31217",
    "lng": "2.91046"
  },
  {
    "country": "FR",
    "name": "Argelers",
    "lat": "42.54714",
    "lng": "3.02253"
  },
  {
    "country": "FR",
    "name": "Argelès-Gazost",
    "lat": "43.01667",
    "lng": "-0.1"
  },
  {
    "country": "FR",
    "name": "Argancy",
    "lat": "49.19543",
    "lng": "6.20157"
  },
  {
    "country": "FR",
    "name": "Arette",
    "lat": "43.1",
    "lng": "-0.71667"
  },
  {
    "country": "FR",
    "name": "Arès",
    "lat": "44.76667",
    "lng": "-1.13333"
  },
  {
    "country": "FR",
    "name": "Arenthon",
    "lat": "46.10466",
    "lng": "6.33149"
  },
  {
    "country": "FR",
    "name": "Arenc",
    "lat": "43.31583",
    "lng": "5.36698"
  },
  {
    "country": "FR",
    "name": "Ardres",
    "lat": "50.85786",
    "lng": "1.98168"
  },
  {
    "country": "FR",
    "name": "Ardin",
    "lat": "46.47512",
    "lng": "-0.55416"
  },
  {
    "country": "FR",
    "name": "Ardentes",
    "lat": "46.74191",
    "lng": "1.83428"
  },
  {
    "country": "FR",
    "name": "Arcueil",
    "lat": "48.79993",
    "lng": "2.33256"
  },
  {
    "country": "FR",
    "name": "Arc-sur-Tille",
    "lat": "47.34349",
    "lng": "5.18666"
  },
  {
    "country": "FR",
    "name": "Arçonnay",
    "lat": "48.39678",
    "lng": "0.0862"
  },
  {
    "country": "FR",
    "name": "Arcis-sur-Aube",
    "lat": "48.53387",
    "lng": "4.14085"
  },
  {
    "country": "FR",
    "name": "Archigny",
    "lat": "46.67411",
    "lng": "0.65372"
  },
  {
    "country": "FR",
    "name": "Archettes",
    "lat": "48.1232",
    "lng": "6.53723"
  },
  {
    "country": "FR",
    "name": "Arches",
    "lat": "48.11856",
    "lng": "6.52806"
  },
  {
    "country": "FR",
    "name": "Archamps",
    "lat": "46.13651",
    "lng": "6.13287"
  },
  {
    "country": "FR",
    "name": "Arcey",
    "lat": "47.52258",
    "lng": "6.66222"
  },
  {
    "country": "FR",
    "name": "Arc-et-Senans",
    "lat": "47.03127",
    "lng": "5.77027"
  },
  {
    "country": "FR",
    "name": "Arcangues",
    "lat": "43.43124",
    "lng": "-1.52237"
  },
  {
    "country": "FR",
    "name": "Arcachon",
    "lat": "44.65",
    "lng": "-1.16667"
  },
  {
    "country": "FR",
    "name": "Arc-lès-Gray",
    "lat": "47.45701",
    "lng": "5.58547"
  },
  {
    "country": "FR",
    "name": "Arbus",
    "lat": "43.33333",
    "lng": "-0.5"
  },
  {
    "country": "FR",
    "name": "Arbouans",
    "lat": "47.49944",
    "lng": "6.79505"
  },
  {
    "country": "FR",
    "name": "Arbonne-la-Forêt",
    "lat": "48.41405",
    "lng": "2.56677"
  },
  {
    "country": "FR",
    "name": "Arbonne",
    "lat": "43.43248",
    "lng": "-1.55118"
  },
  {
    "country": "FR",
    "name": "Arbois",
    "lat": "46.90311",
    "lng": "5.77454"
  },
  {
    "country": "FR",
    "name": "Arbent",
    "lat": "46.29221",
    "lng": "5.6789"
  },
  {
    "country": "FR",
    "name": "Aramon",
    "lat": "43.89174",
    "lng": "4.68096"
  },
  {
    "country": "FR",
    "name": "Arâches-la-Frasse",
    "lat": "46.04297",
    "lng": "6.63145"
  },
  {
    "country": "FR",
    "name": "Apt",
    "lat": "43.88333",
    "lng": "5.4"
  },
  {
    "country": "FR",
    "name": "Apremont",
    "lat": "46.7485",
    "lng": "-1.74075"
  },
  {
    "country": "FR",
    "name": "Apprieu",
    "lat": "45.39922",
    "lng": "5.49628"
  },
  {
    "country": "FR",
    "name": "Appoigny",
    "lat": "47.87467",
    "lng": "3.52524"
  },
  {
    "country": "FR",
    "name": "Appietto",
    "lat": "42.01454",
    "lng": "8.76789"
  },
  {
    "country": "FR",
    "name": "Aouste-sur-Sye",
    "lat": "44.71699",
    "lng": "5.05516"
  },
  {
    "country": "FR",
    "name": "Aoste",
    "lat": "45.58679",
    "lng": "5.61014"
  },
  {
    "country": "FR",
    "name": "Anzin-Saint-Aubin",
    "lat": "50.31313",
    "lng": "2.74732"
  },
  {
    "country": "FR",
    "name": "Anzin",
    "lat": "50.37201",
    "lng": "3.50387"
  },
  {
    "country": "FR",
    "name": "Antran",
    "lat": "46.8535",
    "lng": "0.54317"
  },
  {
    "country": "FR",
    "name": "Antrain",
    "lat": "48.46031",
    "lng": "-1.48354"
  },
  {
    "country": "FR",
    "name": "Antony",
    "lat": "48.75",
    "lng": "2.3"
  },
  {
    "country": "FR",
    "name": "Antonne-et-Trigonant",
    "lat": "45.21271",
    "lng": "0.83006"
  },
  {
    "country": "FR",
    "name": "Antigny",
    "lat": "46.62095",
    "lng": "-0.76988"
  },
  {
    "country": "FR",
    "name": "Antibes",
    "lat": "43.56241",
    "lng": "7.12777"
  },
  {
    "country": "FR",
    "name": "Anthy-sur-Léman",
    "lat": "46.35534",
    "lng": "6.42735"
  },
  {
    "country": "FR",
    "name": "Anstaing",
    "lat": "50.60473",
    "lng": "3.19079"
  },
  {
    "country": "FR",
    "name": "Ansouis",
    "lat": "43.73775",
    "lng": "5.46401"
  },
  {
    "country": "FR",
    "name": "Anse",
    "lat": "45.93023",
    "lng": "4.71576"
  },
  {
    "country": "FR",
    "name": "Ansauvillers",
    "lat": "49.56523",
    "lng": "2.38742"
  },
  {
    "country": "FR",
    "name": "Anould",
    "lat": "48.18526",
    "lng": "6.94597"
  },
  {
    "country": "FR",
    "name": "Anor",
    "lat": "49.98999",
    "lng": "4.10049"
  },
  {
    "country": "FR",
    "name": "Annot",
    "lat": "43.96566",
    "lng": "6.66441"
  },
  {
    "country": "FR",
    "name": "Annonay",
    "lat": "45.23969",
    "lng": "4.67075"
  },
  {
    "country": "FR",
    "name": "Annoeullin",
    "lat": "50.52925",
    "lng": "2.9318"
  },
  {
    "country": "FR",
    "name": "Annezin",
    "lat": "50.53192",
    "lng": "2.61785"
  },
  {
    "country": "FR",
    "name": "Anneyron",
    "lat": "45.27265",
    "lng": "4.88786"
  },
  {
    "country": "FR",
    "name": "Annet-sur-Marne",
    "lat": "48.92669",
    "lng": "2.71959"
  },
  {
    "country": "FR",
    "name": "Annesse-et-Beaulieu",
    "lat": "45.16416",
    "lng": "0.57193"
  },
  {
    "country": "FR",
    "name": "Annequin",
    "lat": "50.50525",
    "lng": "2.72019"
  },
  {
    "country": "FR",
    "name": "Annemasse",
    "lat": "46.19439",
    "lng": "6.23775"
  },
  {
    "country": "FR",
    "name": "Annecy-le-Vieux",
    "lat": "45.91971",
    "lng": "6.14393"
  },
  {
    "country": "FR",
    "name": "Annecy",
    "lat": "45.90621",
    "lng": "6.1267"
  },
  {
    "country": "FR",
    "name": "Annay",
    "lat": "50.46303",
    "lng": "2.88122"
  },
  {
    "country": "FR",
    "name": "Anizy-le-Château",
    "lat": "49.50678",
    "lng": "3.45119"
  },
  {
    "country": "FR",
    "name": "Aniche",
    "lat": "50.32995",
    "lng": "3.25346"
  },
  {
    "country": "FR",
    "name": "Aniane",
    "lat": "43.68448",
    "lng": "3.58747"
  },
  {
    "country": "FR",
    "name": "Anhiers",
    "lat": "50.40737",
    "lng": "3.15512"
  },
  {
    "country": "FR",
    "name": "Angy",
    "lat": "49.32975",
    "lng": "2.32854"
  },
  {
    "country": "FR",
    "name": "Angresse",
    "lat": "43.65809",
    "lng": "-1.37191"
  },
  {
    "country": "FR",
    "name": "Angres",
    "lat": "50.40572",
    "lng": "2.76054"
  },
  {
    "country": "FR",
    "name": "Angoulins",
    "lat": "46.10526",
    "lng": "-1.10713"
  },
  {
    "country": "FR",
    "name": "Angoulême",
    "lat": "45.65",
    "lng": "0.15"
  },
  {
    "country": "FR",
    "name": "Anglet",
    "lat": "43.47664",
    "lng": "-1.51346"
  },
  {
    "country": "FR",
    "name": "Angles",
    "lat": "46.40839",
    "lng": "-1.40389"
  },
  {
    "country": "FR",
    "name": "Angicourt",
    "lat": "49.31175",
    "lng": "2.50419"
  },
  {
    "country": "FR",
    "name": "Angevillers",
    "lat": "49.38815",
    "lng": "6.0443"
  },
  {
    "country": "FR",
    "name": "Angervilliers",
    "lat": "48.59263",
    "lng": "2.06541"
  },
  {
    "country": "FR",
    "name": "Angerville-l’Orcher",
    "lat": "49.58833",
    "lng": "0.28191"
  },
  {
    "country": "FR",
    "name": "Angerville",
    "lat": "48.31354",
    "lng": "1.99935"
  },
  {
    "country": "FR",
    "name": "Angers",
    "lat": "47.47381",
    "lng": "-0.54774"
  },
  {
    "country": "FR",
    "name": "Anetz",
    "lat": "47.38059",
    "lng": "-1.10583"
  },
  {
    "country": "FR",
    "name": "Anet",
    "lat": "48.85642",
    "lng": "1.43981"
  },
  {
    "country": "FR",
    "name": "Anduze",
    "lat": "44.05409",
    "lng": "3.98545"
  },
  {
    "country": "FR",
    "name": "Andrézieux-Bouthéon",
    "lat": "45.52625",
    "lng": "4.26021"
  },
  {
    "country": "FR",
    "name": "Andrezé",
    "lat": "47.17155",
    "lng": "-0.95239"
  },
  {
    "country": "FR",
    "name": "Andrésy",
    "lat": "48.98235",
    "lng": "2.05687"
  },
  {
    "country": "FR",
    "name": "Andrest",
    "lat": "43.31998",
    "lng": "0.06405"
  },
  {
    "country": "FR",
    "name": "Andres",
    "lat": "50.86556",
    "lng": "1.92094"
  },
  {
    "country": "FR",
    "name": "Andouillé",
    "lat": "48.17685",
    "lng": "-0.78364"
  },
  {
    "country": "FR",
    "name": "Andolsheim",
    "lat": "48.06179",
    "lng": "7.41637"
  },
  {
    "country": "FR",
    "name": "Andlau",
    "lat": "48.38607",
    "lng": "7.41697"
  },
  {
    "country": "FR",
    "name": "Andilly",
    "lat": "49.00935",
    "lng": "2.3024"
  },
  {
    "country": "FR",
    "name": "Andilly",
    "lat": "46.25425",
    "lng": "-1.02672"
  },
  {
    "country": "FR",
    "name": "Andeville",
    "lat": "49.26078",
    "lng": "2.16427"
  },
  {
    "country": "FR",
    "name": "Andernos-les-Bains",
    "lat": "44.74572",
    "lng": "-1.10355"
  },
  {
    "country": "FR",
    "name": "Andelnans",
    "lat": "47.60223",
    "lng": "6.8672"
  },
  {
    "country": "FR",
    "name": "Andé",
    "lat": "49.23163",
    "lng": "1.24088"
  },
  {
    "country": "FR",
    "name": "Andard",
    "lat": "47.45659",
    "lng": "-0.39752"
  },
  {
    "country": "FR",
    "name": "Andancette",
    "lat": "45.24242",
    "lng": "4.80606"
  },
  {
    "country": "FR",
    "name": "Andance",
    "lat": "45.24046",
    "lng": "4.79798"
  },
  {
    "country": "FR",
    "name": "Ancy-sur-Moselle",
    "lat": "49.05689",
    "lng": "6.05775"
  },
  {
    "country": "FR",
    "name": "Ancy-le-Franc",
    "lat": "47.77586",
    "lng": "4.16361"
  },
  {
    "country": "FR",
    "name": "Ancône",
    "lat": "44.5816",
    "lng": "4.72711"
  },
  {
    "country": "FR",
    "name": "Ancerville",
    "lat": "48.63574",
    "lng": "5.02091"
  },
  {
    "country": "FR",
    "name": "Ancenis",
    "lat": "47.36667",
    "lng": "-1.16667"
  },
  {
    "country": "FR",
    "name": "Ampuis",
    "lat": "45.48906",
    "lng": "4.80879"
  },
  {
    "country": "FR",
    "name": "Amplepuis",
    "lat": "45.97259",
    "lng": "4.3316"
  },
  {
    "country": "FR",
    "name": "Amou",
    "lat": "43.59257",
    "lng": "-0.74676"
  },
  {
    "country": "FR",
    "name": "Amnéville",
    "lat": "49.25671",
    "lng": "6.13414"
  },
  {
    "country": "FR",
    "name": "Ammerschwihr",
    "lat": "48.12548",
    "lng": "7.28282"
  },
  {
    "country": "FR",
    "name": "Amilly",
    "lat": "48.44333",
    "lng": "1.39349"
  },
  {
    "country": "FR",
    "name": "Amilly",
    "lat": "47.97281",
    "lng": "2.77186"
  },
  {
    "country": "FR",
    "name": "Amiens",
    "lat": "49.9",
    "lng": "2.3"
  },
  {
    "country": "FR",
    "name": "Amfreville-la-Mi-Voie",
    "lat": "49.40755",
    "lng": "1.13871"
  },
  {
    "country": "FR",
    "name": "Amfreville",
    "lat": "49.25",
    "lng": "-0.23333"
  },
  {
    "country": "FR",
    "name": "els Banys d'Arles",
    "lat": "42.47289",
    "lng": "2.66916"
  },
  {
    "country": "FR",
    "name": "Ambronay",
    "lat": "46.0046",
    "lng": "5.36107"
  },
  {
    "country": "FR",
    "name": "Ambrières-les-Vallées",
    "lat": "48.4",
    "lng": "-0.63333"
  },
  {
    "country": "FR",
    "name": "Ambon",
    "lat": "47.55367",
    "lng": "-2.55512"
  },
  {
    "country": "FR",
    "name": "Amboise",
    "lat": "47.41249",
    "lng": "0.98266"
  },
  {
    "country": "FR",
    "name": "Ambleteuse",
    "lat": "50.80729",
    "lng": "1.60388"
  },
  {
    "country": "FR",
    "name": "Ambleny",
    "lat": "49.38079",
    "lng": "3.18447"
  },
  {
    "country": "FR",
    "name": "Amblainville",
    "lat": "49.20443",
    "lng": "2.12242"
  },
  {
    "country": "FR",
    "name": "Ambillou",
    "lat": "47.451",
    "lng": "0.4473"
  },
  {
    "country": "FR",
    "name": "Ambierle",
    "lat": "46.10411",
    "lng": "3.89386"
  },
  {
    "country": "FR",
    "name": "Ambès",
    "lat": "45.01127",
    "lng": "-0.53219"
  },
  {
    "country": "FR",
    "name": "Ambert",
    "lat": "45.55",
    "lng": "3.75"
  },
  {
    "country": "FR",
    "name": "Ambérieux-en-Dombes",
    "lat": "45.99432",
    "lng": "4.90512"
  },
  {
    "country": "FR",
    "name": "Ambérieu-en-Bugey",
    "lat": "45.95885",
    "lng": "5.3432"
  },
  {
    "country": "FR",
    "name": "Ambazac",
    "lat": "45.95983",
    "lng": "1.40063"
  },
  {
    "country": "FR",
    "name": "Ambarès-et-Lagrave",
    "lat": "44.91667",
    "lng": "-0.48333"
  },
  {
    "country": "FR",
    "name": "Amanvillers",
    "lat": "49.16784",
    "lng": "6.04367"
  },
  {
    "country": "FR",
    "name": "Amanlis",
    "lat": "48.00752",
    "lng": "-1.47677"
  },
  {
    "country": "FR",
    "name": "Amancy",
    "lat": "46.07449",
    "lng": "6.32973"
  },
  {
    "country": "FR",
    "name": "Alzonne",
    "lat": "43.25338",
    "lng": "2.17808"
  },
  {
    "country": "FR",
    "name": "Altorf",
    "lat": "48.52166",
    "lng": "7.52787"
  },
  {
    "country": "FR",
    "name": "Altkirch",
    "lat": "47.61667",
    "lng": "7.25"
  },
  {
    "country": "FR",
    "name": "Althen-des-Paluds",
    "lat": "44.00405",
    "lng": "4.95861"
  },
  {
    "country": "FR",
    "name": "Alsting",
    "lat": "49.18175",
    "lng": "6.99255"
  },
  {
    "country": "FR",
    "name": "Allouagne",
    "lat": "50.53167",
    "lng": "2.51194"
  },
  {
    "country": "FR",
    "name": "Allonzier-la-Caille",
    "lat": "46.00352",
    "lng": "6.11776"
  },
  {
    "country": "FR",
    "name": "Allonnes",
    "lat": "47.9674",
    "lng": "0.15807"
  },
  {
    "country": "FR",
    "name": "Allonnes",
    "lat": "47.29338",
    "lng": "0.02458"
  },
  {
    "country": "FR",
    "name": "Allonne",
    "lat": "49.40863",
    "lng": "2.11427"
  },
  {
    "country": "FR",
    "name": "Allinges",
    "lat": "46.33658",
    "lng": "6.46363"
  },
  {
    "country": "FR",
    "name": "Allières-et-Risset",
    "lat": "45.09934",
    "lng": "5.67924"
  },
  {
    "country": "FR",
    "name": "Allex",
    "lat": "44.76454",
    "lng": "4.91757"
  },
  {
    "country": "FR",
    "name": "Allevard",
    "lat": "45.39449",
    "lng": "6.07519"
  },
  {
    "country": "FR",
    "name": "Allennes-les-Marais",
    "lat": "50.53754",
    "lng": "2.95361"
  },
  {
    "country": "FR",
    "name": "Alleins",
    "lat": "43.70387",
    "lng": "5.16203"
  },
  {
    "country": "FR",
    "name": "Allègre",
    "lat": "45.20052",
    "lng": "3.71276"
  },
  {
    "country": "FR",
    "name": "Allauch",
    "lat": "43.33573",
    "lng": "5.48201"
  },
  {
    "country": "FR",
    "name": "Allassac",
    "lat": "45.25816",
    "lng": "1.47532"
  },
  {
    "country": "FR",
    "name": "Allanche",
    "lat": "45.22798",
    "lng": "2.93456"
  },
  {
    "country": "FR",
    "name": "Allan",
    "lat": "44.49865",
    "lng": "4.78751"
  },
  {
    "country": "FR",
    "name": "Allaire",
    "lat": "47.63752",
    "lng": "-2.16324"
  },
  {
    "country": "FR",
    "name": "Alizay",
    "lat": "49.32158",
    "lng": "1.17854"
  },
  {
    "country": "FR",
    "name": "Alixan",
    "lat": "44.97476",
    "lng": "5.02641"
  },
  {
    "country": "FR",
    "name": "Alissas",
    "lat": "44.71253",
    "lng": "4.62936"
  },
  {
    "country": "FR",
    "name": "Alignan-du-Vent",
    "lat": "43.46945",
    "lng": "3.34165"
  },
  {
    "country": "FR",
    "name": "Algrange",
    "lat": "49.36276",
    "lng": "6.05094"
  },
  {
    "country": "FR",
    "name": "Algolsheim",
    "lat": "48.00629",
    "lng": "7.55945"
  },
  {
    "country": "FR",
    "name": "Alfortville",
    "lat": "48.80575",
    "lng": "2.4204"
  },
  {
    "country": "FR",
    "name": "Alès",
    "lat": "44.12489",
    "lng": "4.08082"
  },
  {
    "country": "FR",
    "name": "Aléria",
    "lat": "42.1024",
    "lng": "9.51575"
  },
  {
    "country": "FR",
    "name": "Alénya",
    "lat": "42.63875",
    "lng": "2.98148"
  },
  {
    "country": "FR",
    "name": "Alençon",
    "lat": "48.43476",
    "lng": "0.09311"
  },
  {
    "country": "FR",
    "name": "Alby-sur-Chéran",
    "lat": "45.81667",
    "lng": "6.01667"
  },
  {
    "country": "FR",
    "name": "Albitreccia",
    "lat": "41.86248",
    "lng": "8.94182"
  },
  {
    "country": "FR",
    "name": "Albigny-sur-Saône",
    "lat": "45.86667",
    "lng": "4.83333"
  },
  {
    "country": "FR",
    "name": "Albias",
    "lat": "44.09049",
    "lng": "1.44821"
  },
  {
    "country": "FR",
    "name": "Albi",
    "lat": "43.9298",
    "lng": "2.148"
  },
  {
    "country": "FR",
    "name": "Albertville",
    "lat": "45.67452",
    "lng": "6.39061"
  },
  {
    "country": "FR",
    "name": "Albert",
    "lat": "50.00091",
    "lng": "2.65096"
  },
  {
    "country": "FR",
    "name": "Albens",
    "lat": "45.78463",
    "lng": "5.94875"
  },
  {
    "country": "FR",
    "name": "Alba-la-Romaine",
    "lat": "44.55537",
    "lng": "4.59846"
  },
  {
    "country": "FR",
    "name": "Alata",
    "lat": "41.97749",
    "lng": "8.74232"
  },
  {
    "country": "FR",
    "name": "Ajain",
    "lat": "46.20635",
    "lng": "1.9985"
  },
  {
    "country": "FR",
    "name": "Ajaccio",
    "lat": "41.91886",
    "lng": "8.73812"
  },
  {
    "country": "FR",
    "name": "Aizenay",
    "lat": "46.74004",
    "lng": "-1.60834"
  },
  {
    "country": "FR",
    "name": "Aix-Noulette",
    "lat": "50.42568",
    "lng": "2.70554"
  },
  {
    "country": "FR",
    "name": "Aix-les-Bains",
    "lat": "45.69173",
    "lng": "5.90863"
  },
  {
    "country": "FR",
    "name": "Aixe-sur-Vienne",
    "lat": "45.79862",
    "lng": "1.13884"
  },
  {
    "country": "FR",
    "name": "Aix-en-Provence",
    "lat": "43.5283",
    "lng": "5.44973"
  },
  {
    "country": "FR",
    "name": "Aix-en-Othe",
    "lat": "48.22391",
    "lng": "3.73425"
  },
  {
    "country": "FR",
    "name": "Aiton",
    "lat": "45.56048",
    "lng": "6.26053"
  },
  {
    "country": "FR",
    "name": "Aiserey",
    "lat": "47.17229",
    "lng": "5.1626"
  },
  {
    "country": "FR",
    "name": "Airvault",
    "lat": "46.82533",
    "lng": "-0.13634"
  },
  {
    "country": "FR",
    "name": "Aire-sur-la-Lys",
    "lat": "50.63871",
    "lng": "2.39876"
  },
  {
    "country": "FR",
    "name": "Airaines",
    "lat": "49.96826",
    "lng": "1.94266"
  },
  {
    "country": "FR",
    "name": "Ainay-le-Château",
    "lat": "46.71142",
    "lng": "2.69245"
  },
  {
    "country": "FR",
    "name": "Aime",
    "lat": "45.55559",
    "lng": "6.65042"
  },
  {
    "country": "FR",
    "name": "Aimargues",
    "lat": "43.68448",
    "lng": "4.20999"
  },
  {
    "country": "FR",
    "name": "Ailly-sur-Somme",
    "lat": "49.92886",
    "lng": "2.19615"
  },
  {
    "country": "FR",
    "name": "Ailly-sur-Noye",
    "lat": "49.75707",
    "lng": "2.36367"
  },
  {
    "country": "FR",
    "name": "Aillevillers-et-Lyaumont",
    "lat": "47.92033",
    "lng": "6.33775"
  },
  {
    "country": "FR",
    "name": "Aillant-sur-Tholon",
    "lat": "47.87426",
    "lng": "3.35049"
  },
  {
    "country": "FR",
    "name": "Aigurande",
    "lat": "46.43397",
    "lng": "1.83026"
  },
  {
    "country": "FR",
    "name": "Aiguillon",
    "lat": "44.29893",
    "lng": "0.3402"
  },
  {
    "country": "FR",
    "name": "Aigues-Vives",
    "lat": "43.7379",
    "lng": "4.18066"
  },
  {
    "country": "FR",
    "name": "Aigues-Mortes",
    "lat": "43.56683",
    "lng": "4.19068"
  },
  {
    "country": "FR",
    "name": "Aigueperse",
    "lat": "46.02284",
    "lng": "3.20231"
  },
  {
    "country": "FR",
    "name": "Aiguefonde",
    "lat": "43.49394",
    "lng": "2.31686"
  },
  {
    "country": "FR",
    "name": "Aigueblanche",
    "lat": "45.50313",
    "lng": "6.50806"
  },
  {
    "country": "FR",
    "name": "Aigrefeuille-sur-Maine",
    "lat": "47.07888",
    "lng": "-1.40254"
  },
  {
    "country": "FR",
    "name": "Aigre",
    "lat": "45.89377",
    "lng": "0.00963"
  },
  {
    "country": "FR",
    "name": "Aigné",
    "lat": "48.06471",
    "lng": "0.11908"
  },
  {
    "country": "FR",
    "name": "Aiglemont",
    "lat": "49.78031",
    "lng": "4.76483"
  },
  {
    "country": "FR",
    "name": "Aiffres",
    "lat": "46.29449",
    "lng": "-0.42101"
  },
  {
    "country": "FR",
    "name": "Ahuy",
    "lat": "47.36944",
    "lng": "5.02089"
  },
  {
    "country": "FR",
    "name": "Ahun",
    "lat": "46.08594",
    "lng": "2.04479"
  },
  {
    "country": "FR",
    "name": "Ahuillé",
    "lat": "48.02086",
    "lng": "-0.86906"
  },
  {
    "country": "FR",
    "name": "Ahetze",
    "lat": "43.40432",
    "lng": "-1.57191"
  },
  {
    "country": "FR",
    "name": "Agon-Coutainville",
    "lat": "49.04167",
    "lng": "-1.575"
  },
  {
    "country": "FR",
    "name": "Agonac",
    "lat": "45.29248",
    "lng": "0.75025"
  },
  {
    "country": "FR",
    "name": "Agny",
    "lat": "50.25914",
    "lng": "2.76002"
  },
  {
    "country": "FR",
    "name": "Agnetz",
    "lat": "49.38118",
    "lng": "2.38621"
  },
  {
    "country": "FR",
    "name": "Agneaux",
    "lat": "49.11905",
    "lng": "-1.1061"
  },
  {
    "country": "FR",
    "name": "Agen",
    "lat": "44.19991",
    "lng": "0.62664"
  },
  {
    "country": "FR",
    "name": "Agde",
    "lat": "43.31083",
    "lng": "3.47583"
  },
  {
    "country": "FR",
    "name": "Afa",
    "lat": "41.98362",
    "lng": "8.79469"
  },
  {
    "country": "FR",
    "name": "Acquigny",
    "lat": "49.1735",
    "lng": "1.1765"
  },
  {
    "country": "FR",
    "name": "Acigné",
    "lat": "48.13333",
    "lng": "-1.53704"
  },
  {
    "country": "FR",
    "name": "Achiet-le-Grand",
    "lat": "50.13067",
    "lng": "2.78119"
  },
  {
    "country": "FR",
    "name": "Achicourt",
    "lat": "50.27429",
    "lng": "2.75779"
  },
  {
    "country": "FR",
    "name": "Achères-la-Forêt",
    "lat": "48.35458",
    "lng": "2.57035"
  },
  {
    "country": "FR",
    "name": "Achères",
    "lat": "48.96115",
    "lng": "2.06882"
  },
  {
    "country": "FR",
    "name": "Achenheim",
    "lat": "48.5807",
    "lng": "7.62803"
  },
  {
    "country": "FR",
    "name": "Abzac",
    "lat": "45.01667",
    "lng": "-0.13333"
  },
  {
    "country": "FR",
    "name": "Abscon",
    "lat": "50.33333",
    "lng": "3.3"
  },
  {
    "country": "FR",
    "name": "Abrest",
    "lat": "46.09907",
    "lng": "3.448"
  },
  {
    "country": "FR",
    "name": "Abreschviller",
    "lat": "48.63698",
    "lng": "7.09607"
  },
  {
    "country": "FR",
    "name": "Abondant",
    "lat": "48.7859",
    "lng": "1.44006"
  },
  {
    "country": "FR",
    "name": "Abondance",
    "lat": "46.28031",
    "lng": "6.72026"
  },
  {
    "country": "FR",
    "name": "Ablon-sur-Seine",
    "lat": "48.72732",
    "lng": "2.42686"
  },
  {
    "country": "FR",
    "name": "Ablon",
    "lat": "49.39214",
    "lng": "0.29584"
  },
  {
    "country": "FR",
    "name": "Ablis",
    "lat": "48.5172",
    "lng": "1.83624"
  },
  {
    "country": "FR",
    "name": "Ableiges",
    "lat": "49.08932",
    "lng": "1.98154"
  },
  {
    "country": "FR",
    "name": "Ablain-Saint-Nazaire",
    "lat": "50.3932",
    "lng": "2.7088"
  },
  {
    "country": "FR",
    "name": "Abilly",
    "lat": "46.93333",
    "lng": "0.73333"
  },
  {
    "country": "FR",
    "name": "Abeilhan",
    "lat": "43.44925",
    "lng": "3.29529"
  },
  {
    "country": "FR",
    "name": "Abbeville",
    "lat": "50.1",
    "lng": "1.83333"
  },
  {
    "country": "FR",
    "name": "Abbaretz",
    "lat": "47.55314",
    "lng": "-1.532"
  },
  {
    "country": "FR",
    "name": "Lugon-et-l'Île-du-Carnay",
    "lat": "44.95556",
    "lng": "-0.33611"
  },
  {
    "country": "FR",
    "name": "Guidel-Plage",
    "lat": "47.76768",
    "lng": "-3.5218"
  },
  {
    "country": "FR",
    "name": "Les Deux Alpes",
    "lat": "45.0116",
    "lng": "6.12548"
  },
  {
    "country": "FR",
    "name": "Villeneuve-d'Ascq",
    "lat": "50.61669",
    "lng": "3.16664"
  },
  {
    "country": "FR",
    "name": "Val Thorens",
    "lat": "45.29777",
    "lng": "6.58377"
  },
  {
    "country": "FR",
    "name": "La Palme",
    "lat": "42.97518",
    "lng": "2.99243"
  },
  {
    "country": "FR",
    "name": "Pont-d'Ouilly",
    "lat": "48.8759",
    "lng": "-0.40221"
  },
  {
    "country": "FR",
    "name": "Castelmaurou",
    "lat": "43.67778",
    "lng": "1.53222"
  },
  {
    "country": "FR",
    "name": "Geneston",
    "lat": "47.05639",
    "lng": "-1.51139"
  },
  {
    "country": "FR",
    "name": "Le Ban Saint-Martin",
    "lat": "49.1225",
    "lng": "6.15111"
  },
  {
    "country": "FR",
    "name": "Le Sequestre",
    "lat": "43.91076",
    "lng": "2.11804"
  },
  {
    "country": "FR",
    "name": "Les Ulis",
    "lat": "48.68167",
    "lng": "2.16944"
  },
  {
    "country": "FR",
    "name": "Carnoux-en-Provence",
    "lat": "43.25639",
    "lng": "5.56444"
  },
  {
    "country": "FR",
    "name": "Saint-Manvieu-Norrey",
    "lat": "49.18139",
    "lng": "-0.5"
  },
  {
    "country": "FR",
    "name": "Bourgoin-Jallieu",
    "lat": "45.58611",
    "lng": "5.27361"
  },
  {
    "country": "FR",
    "name": "Le Bois-d'Oingt",
    "lat": "45.91718",
    "lng": "4.58259"
  },
  {
    "country": "FR",
    "name": "Les Côtes-d'Arey",
    "lat": "45.4564",
    "lng": "4.8666"
  },
  {
    "country": "FR",
    "name": "Mercurey",
    "lat": "46.84035",
    "lng": "4.71743"
  },
  {
    "country": "FR",
    "name": "Val-de-Reuil",
    "lat": "49.27385",
    "lng": "1.21021"
  },
  {
    "country": "FR",
    "name": "Biol",
    "lat": "45.4914",
    "lng": "5.3855"
  },
  {
    "country": "FR",
    "name": "Bayard-sur-Marne",
    "lat": "48.5541",
    "lng": "5.0768"
  },
  {
    "country": "FR",
    "name": "Belle-Plagne",
    "lat": "45.50932",
    "lng": "6.70685"
  },
  {
    "country": "FR",
    "name": "Marseille 01",
    "lat": "43.29814",
    "lng": "5.38407"
  },
  {
    "country": "FR",
    "name": "Marseille 02",
    "lat": "43.29664",
    "lng": "5.37034"
  },
  {
    "country": "FR",
    "name": "Marseille 03",
    "lat": "43.30257",
    "lng": "5.37583"
  },
  {
    "country": "FR",
    "name": "Marseille 04",
    "lat": "43.30213",
    "lng": "5.40141"
  },
  {
    "country": "FR",
    "name": "Marseille 05",
    "lat": "43.29551",
    "lng": "5.40055"
  },
  {
    "country": "FR",
    "name": "Marseille 06",
    "lat": "43.28764",
    "lng": "5.37918"
  },
  {
    "country": "FR",
    "name": "Marseille 07",
    "lat": "43.28289",
    "lng": "5.36021"
  },
  {
    "country": "FR",
    "name": "Marseille 08",
    "lat": "43.27083",
    "lng": "5.3821"
  },
  {
    "country": "FR",
    "name": "Marseille 10",
    "lat": "43.27889",
    "lng": "5.41523"
  },
  {
    "country": "FR",
    "name": "Marseille 09",
    "lat": "43.25433",
    "lng": "5.4057"
  },
  {
    "country": "FR",
    "name": "Marseille 11",
    "lat": "43.2907",
    "lng": "5.4384"
  },
  {
    "country": "FR",
    "name": "Marseille 12",
    "lat": "43.29614",
    "lng": "5.43617"
  },
  {
    "country": "FR",
    "name": "Marseille 13",
    "lat": "43.31856",
    "lng": "5.40836"
  },
  {
    "country": "FR",
    "name": "Marseille 14",
    "lat": "43.34447",
    "lng": "5.38004"
  },
  {
    "country": "FR",
    "name": "Marseille 15",
    "lat": "43.37224",
    "lng": "5.35386"
  },
  {
    "country": "FR",
    "name": "Marseille 16",
    "lat": "43.35982",
    "lng": "5.33421"
  },
  {
    "country": "FR",
    "name": "Saint-Mitre",
    "lat": "43.3464",
    "lng": "5.42274"
  },
  {
    "country": "FR",
    "name": "La Defense",
    "lat": "48.89198",
    "lng": "2.23881"
  },
  {
    "country": "FR",
    "name": "Saint-Quentin-en-Yvelines",
    "lat": "48.77186",
    "lng": "2.01891"
  },
  {
    "country": "FR",
    "name": "Cergy-Pontoise",
    "lat": "49.03894",
    "lng": "2.07805"
  },
  {
    "country": "FR",
    "name": "Saint-Giniez",
    "lat": "43.26946",
    "lng": "5.38566"
  },
  {
    "country": "FR",
    "name": "La Page",
    "lat": "43.26627",
    "lng": "5.37377"
  },
  {
    "country": "FR",
    "name": "Rouet",
    "lat": "43.27808",
    "lng": "5.39158"
  },
  {
    "country": "FR",
    "name": "Marseille Endoume",
    "lat": "43.2832",
    "lng": "5.35159"
  },
  {
    "country": "FR",
    "name": "Marseille Saint-Victor",
    "lat": "43.28955",
    "lng": "5.36845"
  },
  {
    "country": "FR",
    "name": "Marseille Bompard",
    "lat": "43.2812",
    "lng": "5.36081"
  },
  {
    "country": "FR",
    "name": "Marseille Roucas-Blanc",
    "lat": "43.27652",
    "lng": "5.36519"
  },
  {
    "country": "FR",
    "name": "Marseille Vauban",
    "lat": "43.28408",
    "lng": "5.3754"
  },
  {
    "country": "FR",
    "name": "Marseille Prefecture",
    "lat": "43.29092",
    "lng": "5.37901"
  },
  {
    "country": "FR",
    "name": "Rd pt des Chataigniers, Rte de Milizac, Guilers, Finistère, France",
    "lat": "48.43387",
    "lng": "-4.56809"
  },
  {
    "country": "FR",
    "name": "Belsunce",
    "lat": "43.29834",
    "lng": "5.3766"
  },
  {
    "country": "FR",
    "name": "Le Chapitre",
    "lat": "43.30053",
    "lng": "5.38433"
  },
  {
    "country": "FR",
    "name": "Thiers",
    "lat": "43.29748",
    "lng": "5.38198"
  },
  {
    "country": "FR",
    "name": "Saint-Charles",
    "lat": "43.30199",
    "lng": "5.38405"
  },
  {
    "country": "FR",
    "name": "Opéra",
    "lat": "43.29682",
    "lng": "5.38045"
  },
  {
    "country": "FR",
    "name": "Noailles",
    "lat": "43.29604",
    "lng": "5.37959"
  },
  {
    "country": "FR",
    "name": "Les Grands Carmes",
    "lat": "43.30038",
    "lng": "5.37275"
  },
  {
    "country": "FR",
    "name": "La Joliette",
    "lat": "43.30485",
    "lng": "5.36654"
  },
  {
    "country": "FR",
    "name": "Saint-Lazare",
    "lat": "43.30545",
    "lng": "5.37443"
  },
  {
    "country": "FR",
    "name": "Saint-Mauront",
    "lat": "43.31552",
    "lng": "5.37538"
  },
  {
    "country": "FR",
    "name": "La Villette",
    "lat": "43.31181",
    "lng": "5.37391"
  },
  {
    "country": "FR",
    "name": "Belle de Mai",
    "lat": "43.31184",
    "lng": "5.38541"
  },
  {
    "country": "FR",
    "name": "Les Chartreux",
    "lat": "43.31112",
    "lng": "5.4048"
  },
  {
    "country": "FR",
    "name": "Chutes-Lavie",
    "lat": "43.31017",
    "lng": "5.39464"
  },
  {
    "country": "FR",
    "name": "Cinq Avenues",
    "lat": "43.30375",
    "lng": "5.39761"
  },
  {
    "country": "FR",
    "name": "La Blancarde",
    "lat": "43.30047",
    "lng": "5.40563"
  },
  {
    "country": "FR",
    "name": "Le Camas",
    "lat": "43.29469",
    "lng": "5.39415"
  },
  {
    "country": "FR",
    "name": "La Conception",
    "lat": "43.29174",
    "lng": "5.39391"
  },
  {
    "country": "FR",
    "name": "Baille",
    "lat": "43.2877",
    "lng": "5.39804"
  },
  {
    "country": "FR",
    "name": "Castellane",
    "lat": "43.28587",
    "lng": "5.38277"
  },
  {
    "country": "FR",
    "name": "Lodi",
    "lat": "43.28663",
    "lng": "5.38882"
  },
  {
    "country": "FR",
    "name": "Notre-Dame du Mont",
    "lat": "43.29293",
    "lng": "5.38203"
  },
  {
    "country": "FR",
    "name": "Palais de Justice",
    "lat": "43.28657",
    "lng": "5.37603"
  },
  {
    "country": "FR",
    "name": "Le Pharo",
    "lat": "43.2914",
    "lng": "5.35829"
  },
  {
    "country": "FR",
    "name": "Saint-Lambert",
    "lat": "43.28606",
    "lng": "5.36"
  },
  {
    "country": "FR",
    "name": "La Pointe Rouge",
    "lat": "43.23853",
    "lng": "5.37679"
  },
  {
    "country": "FR",
    "name": "Périer",
    "lat": "43.27755",
    "lng": "5.37925"
  },
  {
    "country": "FR",
    "name": "Le Cabot",
    "lat": "43.25884",
    "lng": "5.41729"
  },
  {
    "country": "FR",
    "name": "La Timone",
    "lat": "43.28847",
    "lng": "5.41447"
  },
  {
    "country": "FR",
    "name": "La Capelette",
    "lat": "43.28086",
    "lng": "5.406"
  },
  {
    "country": "FR",
    "name": "Menpenti",
    "lat": "43.28198",
    "lng": "5.39607"
  },
  {
    "country": "FR",
    "name": "Saint-Tronc",
    "lat": "43.27093",
    "lng": "5.42285"
  },
  {
    "country": "FR",
    "name": "La Valbarelle",
    "lat": "43.28494",
    "lng": "5.45387"
  },
  {
    "country": "FR",
    "name": "Les Accates",
    "lat": "43.29989",
    "lng": "5.49726"
  },
  {
    "country": "FR",
    "name": "Montolivet",
    "lat": "43.31715",
    "lng": "5.4235"
  },
  {
    "country": "FR",
    "name": "Saint-Jean du Désert",
    "lat": "43.29331",
    "lng": "5.42134"
  },
  {
    "country": "FR",
    "name": "Les Caillols",
    "lat": "43.30221",
    "lng": "5.44811"
  },
  {
    "country": "FR",
    "name": "Les Trois-Lucs",
    "lat": "43.31371",
    "lng": "5.46248"
  },
  {
    "country": "FR",
    "name": "La Fourragère",
    "lat": "43.30382",
    "lng": "5.43138"
  },
  {
    "country": "FR",
    "name": "Les Médecins",
    "lat": "43.35417",
    "lng": "5.45483"
  },
  {
    "country": "FR",
    "name": "La Rose",
    "lat": "43.32889",
    "lng": "5.42859"
  },
  {
    "country": "FR",
    "name": "Malpassé",
    "lat": "43.3217",
    "lng": "5.41551"
  },
  {
    "country": "FR",
    "name": "Palama",
    "lat": "43.36566",
    "lng": "5.44427"
  },
  {
    "country": "FR",
    "name": "Saint-Barthélémy",
    "lat": "43.33105",
    "lng": "5.40241"
  },
  {
    "country": "FR",
    "name": "Saint-Joseph",
    "lat": "43.34617",
    "lng": "5.37976"
  },
  {
    "country": "FR",
    "name": "Bon-Secours",
    "lat": "43.31923",
    "lng": "5.38426"
  },
  {
    "country": "FR",
    "name": "Les Arnavaux",
    "lat": "43.33506",
    "lng": "5.37969"
  },
  {
    "country": "FR",
    "name": "Les Crottes",
    "lat": "43.32302",
    "lng": "5.36809"
  },
  {
    "country": "FR",
    "name": "La Delorme",
    "lat": "43.34405",
    "lng": "5.37251"
  },
  {
    "country": "FR",
    "name": "La Viste",
    "lat": "43.35936",
    "lng": "5.35649"
  },
  {
    "country": "FR",
    "name": "Notre-Dame Limite",
    "lat": "43.38165",
    "lng": "5.36269"
  },
  {
    "country": "FR",
    "name": "Verduron",
    "lat": "43.37063",
    "lng": "5.34513"
  },
  {
    "country": "FR",
    "name": "La Cabucelle",
    "lat": "43.33189",
    "lng": "5.36111"
  },
  {
    "country": "FR",
    "name": "Borel",
    "lat": "43.36486",
    "lng": "5.36681"
  },
  {
    "country": "FR",
    "name": "La Calade",
    "lat": "43.33895",
    "lng": "5.35111"
  },
  {
    "country": "FR",
    "name": "Saint-Pierre",
    "lat": "43.29282",
    "lng": "5.40682"
  },
  {
    "country": "GA",
    "name": "Tchibanga",
    "lat": "-2.93323",
    "lng": "10.98178"
  },
  {
    "country": "GA",
    "name": "Port-Gentil",
    "lat": "-0.71933",
    "lng": "8.78151"
  },
  {
    "country": "GA",
    "name": "Oyem",
    "lat": "1.5995",
    "lng": "11.57933"
  },
  {
    "country": "GA",
    "name": "Omboué",
    "lat": "-1.57464",
    "lng": "9.26184"
  },
  {
    "country": "GA",
    "name": "Okondja",
    "lat": "-0.65487",
    "lng": "13.67533"
  },
  {
    "country": "GA",
    "name": "Ntoum",
    "lat": "0.39051",
    "lng": "9.76096"
  },
  {
    "country": "GA",
    "name": "Ndendé",
    "lat": "-2.40077",
    "lng": "11.35813"
  },
  {
    "country": "GA",
    "name": "Ndjolé",
    "lat": "-0.17827",
    "lng": "10.76488"
  },
  {
    "country": "GA",
    "name": "Mounana",
    "lat": "-1.4085",
    "lng": "13.15857"
  },
  {
    "country": "GA",
    "name": "Mouila",
    "lat": "-1.86846",
    "lng": "11.05594"
  },
  {
    "country": "GA",
    "name": "Moanda",
    "lat": "-1.56652",
    "lng": "13.1987"
  },
  {
    "country": "GA",
    "name": "Mitzic",
    "lat": "0.78205",
    "lng": "11.54904"
  },
  {
    "country": "GA",
    "name": "Mimongo",
    "lat": "-1.61952",
    "lng": "11.60675"
  },
  {
    "country": "GA",
    "name": "Mbigou",
    "lat": "-1.90046",
    "lng": "11.906"
  },
  {
    "country": "GA",
    "name": "Mayumba",
    "lat": "-3.43198",
    "lng": "10.6554"
  },
  {
    "country": "GA",
    "name": "Makokou",
    "lat": "0.57381",
    "lng": "12.86419"
  },
  {
    "country": "GA",
    "name": "Libreville",
    "lat": "0.39241",
    "lng": "9.45356"
  },
  {
    "country": "GA",
    "name": "Lékoni",
    "lat": "-1.58431",
    "lng": "14.25905"
  },
  {
    "country": "GA",
    "name": "Lastoursville",
    "lat": "-0.81742",
    "lng": "12.70818"
  },
  {
    "country": "GA",
    "name": "Lambaréné",
    "lat": "-0.7001",
    "lng": "10.24055"
  },
  {
    "country": "GA",
    "name": "Koulamoutou",
    "lat": "-1.13667",
    "lng": "12.46399"
  },
  {
    "country": "GA",
    "name": "Gamba",
    "lat": "-2.65",
    "lng": "10"
  },
  {
    "country": "GA",
    "name": "Franceville",
    "lat": "-1.63333",
    "lng": "13.58357"
  },
  {
    "country": "GA",
    "name": "Fougamou",
    "lat": "-1.21544",
    "lng": "10.58378"
  },
  {
    "country": "GA",
    "name": "Cocobeach",
    "lat": "1.00019",
    "lng": "9.58229"
  },
  {
    "country": "GA",
    "name": "Booué",
    "lat": "-0.09207",
    "lng": "11.93846"
  },
  {
    "country": "GA",
    "name": "Bitam",
    "lat": "2.07597",
    "lng": "11.50065"
  },
  {
    "country": "GB",
    "name": "Ystrad Mynach",
    "lat": "51.64276",
    "lng": "-3.2362"
  },
  {
    "country": "GB",
    "name": "Ystradgynlais",
    "lat": "51.76667",
    "lng": "-3.76667"
  },
  {
    "country": "GB",
    "name": "Ystalyfera",
    "lat": "51.76716",
    "lng": "-3.78082"
  },
  {
    "country": "GB",
    "name": "Yoxall",
    "lat": "52.76659",
    "lng": "-1.79068"
  },
  {
    "country": "GB",
    "name": "Youlgreave",
    "lat": "53.17399",
    "lng": "-1.69044"
  },
  {
    "country": "GB",
    "name": "York",
    "lat": "53.95763",
    "lng": "-1.08271"
  },
  {
    "country": "GB",
    "name": "Yetminster",
    "lat": "50.89579",
    "lng": "-2.57959"
  },
  {
    "country": "GB",
    "name": "Yeovil",
    "lat": "50.94159",
    "lng": "-2.63211"
  },
  {
    "country": "GB",
    "name": "Yelverton",
    "lat": "50.4929",
    "lng": "-4.08382"
  },
  {
    "country": "GB",
    "name": "Yealmpton",
    "lat": "50.34856",
    "lng": "-3.99877"
  },
  {
    "country": "GB",
    "name": "Yeadon",
    "lat": "53.86437",
    "lng": "-1.68743"
  },
  {
    "country": "GB",
    "name": "Yazor",
    "lat": "52.11667",
    "lng": "-2.86667"
  },
  {
    "country": "GB",
    "name": "Yaxley",
    "lat": "52.51768",
    "lng": "-0.25852"
  },
  {
    "country": "GB",
    "name": "Yatton",
    "lat": "51.96667",
    "lng": "-2.53333"
  },
  {
    "country": "GB",
    "name": "Yatton",
    "lat": "51.38839",
    "lng": "-2.82353"
  },
  {
    "country": "GB",
    "name": "Yate",
    "lat": "51.54074",
    "lng": "-2.41839"
  },
  {
    "country": "GB",
    "name": "Yarnton",
    "lat": "51.80448",
    "lng": "-1.31149"
  },
  {
    "country": "GB",
    "name": "Yarmouth",
    "lat": "50.70529",
    "lng": "-1.49929"
  },
  {
    "country": "GB",
    "name": "Yarm",
    "lat": "54.50364",
    "lng": "-1.35793"
  },
  {
    "country": "GB",
    "name": "Yapton",
    "lat": "50.8209",
    "lng": "-0.613"
  },
  {
    "country": "GB",
    "name": "Yalding",
    "lat": "51.22387",
    "lng": "0.4292"
  },
  {
    "country": "GB",
    "name": "Wymondham",
    "lat": "52.75978",
    "lng": "-0.74055"
  },
  {
    "country": "GB",
    "name": "Wymeswold",
    "lat": "52.80536",
    "lng": "-1.11288"
  },
  {
    "country": "GB",
    "name": "Wylam",
    "lat": "54.97654",
    "lng": "-1.82187"
  },
  {
    "country": "GB",
    "name": "Wye",
    "lat": "51.18249",
    "lng": "0.93678"
  },
  {
    "country": "GB",
    "name": "Wroxall",
    "lat": "52.33791",
    "lng": "-1.66898"
  },
  {
    "country": "GB",
    "name": "Wroxall",
    "lat": "50.61625",
    "lng": "-1.22292"
  },
  {
    "country": "GB",
    "name": "Wroughton",
    "lat": "51.52411",
    "lng": "-1.79559"
  },
  {
    "country": "GB",
    "name": "Wrotham",
    "lat": "51.30856",
    "lng": "0.30899"
  },
  {
    "country": "GB",
    "name": "Writtle",
    "lat": "51.72906",
    "lng": "0.42938"
  },
  {
    "country": "GB",
    "name": "Wrington",
    "lat": "51.36173",
    "lng": "-2.76319"
  },
  {
    "country": "GB",
    "name": "Wrexham",
    "lat": "53.04664",
    "lng": "-2.99132"
  },
  {
    "country": "GB",
    "name": "Wrea Green",
    "lat": "53.77651",
    "lng": "-2.91573"
  },
  {
    "country": "GB",
    "name": "Wrawby",
    "lat": "53.56672",
    "lng": "-0.46194"
  },
  {
    "country": "GB",
    "name": "Wragby",
    "lat": "53.28333",
    "lng": "-0.3"
  },
  {
    "country": "GB",
    "name": "Wouldham",
    "lat": "51.34986",
    "lng": "0.45816"
  },
  {
    "country": "GB",
    "name": "Wotton-under-Edge",
    "lat": "51.63242",
    "lng": "-2.34512"
  },
  {
    "country": "GB",
    "name": "Worton",
    "lat": "51.31611",
    "lng": "-2.04111"
  },
  {
    "country": "GB",
    "name": "Wortley",
    "lat": "53.48333",
    "lng": "-1.53333"
  },
  {
    "country": "GB",
    "name": "Worthing",
    "lat": "50.81795",
    "lng": "-0.37538"
  },
  {
    "country": "GB",
    "name": "Worlaby",
    "lat": "53.6113",
    "lng": "-0.46685"
  },
  {
    "country": "GB",
    "name": "Worksop",
    "lat": "53.30182",
    "lng": "-1.12404"
  },
  {
    "country": "GB",
    "name": "Workington",
    "lat": "54.6425",
    "lng": "-3.54413"
  },
  {
    "country": "GB",
    "name": "Worcester",
    "lat": "52.18935",
    "lng": "-2.22001"
  },
  {
    "country": "GB",
    "name": "Royal Wootton Bassett",
    "lat": "51.5419",
    "lng": "-1.9045"
  },
  {
    "country": "GB",
    "name": "Wootton",
    "lat": "53.63021",
    "lng": "-0.35328"
  },
  {
    "country": "GB",
    "name": "Wootton",
    "lat": "52.09525",
    "lng": "-0.53494"
  },
  {
    "country": "GB",
    "name": "Wootton",
    "lat": "51.1738",
    "lng": "1.1794"
  },
  {
    "country": "GB",
    "name": "Wootton",
    "lat": "50.72847",
    "lng": "-1.23536"
  },
  {
    "country": "GB",
    "name": "Woolwich",
    "lat": "51.491",
    "lng": "0.0648"
  },
  {
    "country": "GB",
    "name": "Woolpit",
    "lat": "52.22454",
    "lng": "0.88826"
  },
  {
    "country": "GB",
    "name": "Woolley",
    "lat": "53.61339",
    "lng": "-1.51457"
  },
  {
    "country": "GB",
    "name": "Wooler",
    "lat": "55.54755",
    "lng": "-2.01186"
  },
  {
    "country": "GB",
    "name": "Wool",
    "lat": "50.67966",
    "lng": "-2.2189"
  },
  {
    "country": "GB",
    "name": "Woodstock",
    "lat": "51.8485",
    "lng": "-1.35132"
  },
  {
    "country": "GB",
    "name": "Woodsetts",
    "lat": "53.34804",
    "lng": "-1.17204"
  },
  {
    "country": "GB",
    "name": "Woodley",
    "lat": "51.45",
    "lng": "-0.88333"
  },
  {
    "country": "GB",
    "name": "Woodhall Spa",
    "lat": "53.15215",
    "lng": "-0.21453"
  },
  {
    "country": "GB",
    "name": "Wood Green",
    "lat": "51.6",
    "lng": "-0.11667"
  },
  {
    "country": "GB",
    "name": "Woodford Green",
    "lat": "51.60938",
    "lng": "0.02329"
  },
  {
    "country": "GB",
    "name": "Woodford",
    "lat": "52.38231",
    "lng": "-0.58099"
  },
  {
    "country": "GB",
    "name": "Woodford",
    "lat": "51.11667",
    "lng": "-1.83333"
  },
  {
    "country": "GB",
    "name": "Woodcote",
    "lat": "52.73333",
    "lng": "-2.33333"
  },
  {
    "country": "GB",
    "name": "Woodchurch",
    "lat": "51.07605",
    "lng": "0.77346"
  },
  {
    "country": "GB",
    "name": "Woodbridge",
    "lat": "52.09332",
    "lng": "1.32042"
  },
  {
    "country": "GB",
    "name": "Woodborough",
    "lat": "51.33852",
    "lng": "-1.83976"
  },
  {
    "country": "GB",
    "name": "Wombwell",
    "lat": "53.52189",
    "lng": "-1.39698"
  },
  {
    "country": "GB",
    "name": "Wombourn",
    "lat": "52.53333",
    "lng": "-2.18333"
  },
  {
    "country": "GB",
    "name": "Wolverhampton",
    "lat": "52.58547",
    "lng": "-2.12296"
  },
  {
    "country": "GB",
    "name": "Wolston",
    "lat": "52.37717",
    "lng": "-1.39544"
  },
  {
    "country": "GB",
    "name": "Wolsingham",
    "lat": "54.73085",
    "lng": "-1.88319"
  },
  {
    "country": "GB",
    "name": "Wollaston",
    "lat": "52.25794",
    "lng": "-0.67038"
  },
  {
    "country": "GB",
    "name": "Wold Newton",
    "lat": "54.1428",
    "lng": "-0.39993"
  },
  {
    "country": "GB",
    "name": "Wold Newton",
    "lat": "53.45",
    "lng": "-0.13333"
  },
  {
    "country": "GB",
    "name": "Woldingham",
    "lat": "51.28527",
    "lng": "-0.03372"
  },
  {
    "country": "GB",
    "name": "Wokingham",
    "lat": "51.4112",
    "lng": "-0.83565"
  },
  {
    "country": "GB",
    "name": "Woking",
    "lat": "51.31903",
    "lng": "-0.55893"
  },
  {
    "country": "GB",
    "name": "Woburn Sands",
    "lat": "52.01579",
    "lng": "-0.64982"
  },
  {
    "country": "GB",
    "name": "Woburn",
    "lat": "51.98865",
    "lng": "-0.61903"
  },
  {
    "country": "GB",
    "name": "Wivenhoe",
    "lat": "51.85553",
    "lng": "0.95796"
  },
  {
    "country": "GB",
    "name": "Wivelsfield Green",
    "lat": "50.96313",
    "lng": "-0.07133"
  },
  {
    "country": "GB",
    "name": "Wiveliscombe",
    "lat": "51.04139",
    "lng": "-3.31278"
  },
  {
    "country": "GB",
    "name": "Witton Gilbert",
    "lat": "54.80572",
    "lng": "-1.63686"
  },
  {
    "country": "GB",
    "name": "Wittering",
    "lat": "52.60698",
    "lng": "-0.44048"
  },
  {
    "country": "GB",
    "name": "Witney",
    "lat": "51.7836",
    "lng": "-1.4854"
  },
  {
    "country": "GB",
    "name": "Witley",
    "lat": "51.14993",
    "lng": "-0.64768"
  },
  {
    "country": "GB",
    "name": "Withington",
    "lat": "52.71667",
    "lng": "-2.6"
  },
  {
    "country": "GB",
    "name": "Withington",
    "lat": "52.1",
    "lng": "-2.63333"
  },
  {
    "country": "GB",
    "name": "Withernsea",
    "lat": "53.7311",
    "lng": "0.03347"
  },
  {
    "country": "GB",
    "name": "Witheridge",
    "lat": "50.91743",
    "lng": "-3.70351"
  },
  {
    "country": "GB",
    "name": "Witham",
    "lat": "51.80007",
    "lng": "0.64038"
  },
  {
    "country": "GB",
    "name": "Witchford",
    "lat": "52.38699",
    "lng": "0.20602"
  },
  {
    "country": "GB",
    "name": "Wiston",
    "lat": "51.82583",
    "lng": "-4.87"
  },
  {
    "country": "GB",
    "name": "Wishaw",
    "lat": "55.76667",
    "lng": "-3.91667"
  },
  {
    "country": "GB",
    "name": "Wisbech",
    "lat": "52.66622",
    "lng": "0.15938"
  },
  {
    "country": "GB",
    "name": "Wirksworth",
    "lat": "53.08232",
    "lng": "-1.57391"
  },
  {
    "country": "GB",
    "name": "Winwick",
    "lat": "53.43333",
    "lng": "-2.6"
  },
  {
    "country": "GB",
    "name": "Winterton",
    "lat": "53.65497",
    "lng": "-0.59885"
  },
  {
    "country": "GB",
    "name": "Winterbourne Stoke",
    "lat": "51.16729",
    "lng": "-1.89806"
  },
  {
    "country": "GB",
    "name": "Winterbourne",
    "lat": "51.44609",
    "lng": "-1.3466"
  },
  {
    "country": "GB",
    "name": "Winston",
    "lat": "54.54519",
    "lng": "-1.78854"
  },
  {
    "country": "GB",
    "name": "Winslow",
    "lat": "51.94284",
    "lng": "-0.88131"
  },
  {
    "country": "GB",
    "name": "Winsford",
    "lat": "53.19146",
    "lng": "-2.52398"
  },
  {
    "country": "GB",
    "name": "Winnersh",
    "lat": "51.42747",
    "lng": "-0.87994"
  },
  {
    "country": "GB",
    "name": "Winkleigh",
    "lat": "50.85581",
    "lng": "-3.943"
  },
  {
    "country": "GB",
    "name": "Wingrave",
    "lat": "51.86494",
    "lng": "-0.74244"
  },
  {
    "country": "GB",
    "name": "Wingham",
    "lat": "51.27168",
    "lng": "1.21463"
  },
  {
    "country": "GB",
    "name": "Wingfield",
    "lat": "51.31345",
    "lng": "-2.26038"
  },
  {
    "country": "GB",
    "name": "Wingerworth",
    "lat": "53.202",
    "lng": "-1.43359"
  },
  {
    "country": "GB",
    "name": "Wingate",
    "lat": "54.73242",
    "lng": "-1.37896"
  },
  {
    "country": "GB",
    "name": "Wing",
    "lat": "52.61775",
    "lng": "-0.6827"
  },
  {
    "country": "GB",
    "name": "Wing",
    "lat": "51.89524",
    "lng": "-0.71956"
  },
  {
    "country": "GB",
    "name": "Winford",
    "lat": "51.38333",
    "lng": "-2.66111"
  },
  {
    "country": "GB",
    "name": "Windsor",
    "lat": "51.48333",
    "lng": "-0.6"
  },
  {
    "country": "GB",
    "name": "Windlesham",
    "lat": "51.36509",
    "lng": "-0.65476"
  },
  {
    "country": "GB",
    "name": "Windermere",
    "lat": "54.38086",
    "lng": "-2.90709"
  },
  {
    "country": "GB",
    "name": "Winchester",
    "lat": "51.06513",
    "lng": "-1.3187"
  },
  {
    "country": "GB",
    "name": "Winchcombe",
    "lat": "51.95363",
    "lng": "-1.96398"
  },
  {
    "country": "GB",
    "name": "Wincanton",
    "lat": "51.05676",
    "lng": "-2.40574"
  },
  {
    "country": "GB",
    "name": "Wimborne Minster",
    "lat": "50.78333",
    "lng": "-1.98333"
  },
  {
    "country": "GB",
    "name": "Wimblington",
    "lat": "52.50925",
    "lng": "0.08416"
  },
  {
    "country": "GB",
    "name": "Wilton",
    "lat": "51.07926",
    "lng": "-1.8621"
  },
  {
    "country": "GB",
    "name": "Wilstead",
    "lat": "52.08088",
    "lng": "-0.44889"
  },
  {
    "country": "GB",
    "name": "Wilsford",
    "lat": "51.3",
    "lng": "-1.85"
  },
  {
    "country": "GB",
    "name": "Wilsden",
    "lat": "53.82084",
    "lng": "-1.85959"
  },
  {
    "country": "GB",
    "name": "Wilmslow",
    "lat": "53.32803",
    "lng": "-2.23148"
  },
  {
    "country": "GB",
    "name": "Wilmcote",
    "lat": "52.22081",
    "lng": "-1.76528"
  },
  {
    "country": "GB",
    "name": "Williton",
    "lat": "51.16236",
    "lng": "-3.32208"
  },
  {
    "country": "GB",
    "name": "Willington",
    "lat": "54.71667",
    "lng": "-1.7"
  },
  {
    "country": "GB",
    "name": "Willington",
    "lat": "52.13409",
    "lng": "-0.37235"
  },
  {
    "country": "GB",
    "name": "Willingham",
    "lat": "53.35",
    "lng": "-0.68333"
  },
  {
    "country": "GB",
    "name": "Willingham",
    "lat": "52.31404",
    "lng": "0.05776"
  },
  {
    "country": "GB",
    "name": "Willerby",
    "lat": "53.76099",
    "lng": "-0.44186"
  },
  {
    "country": "GB",
    "name": "Willenhall",
    "lat": "52.58514",
    "lng": "-2.05934"
  },
  {
    "country": "GB",
    "name": "Willaston",
    "lat": "53.2955",
    "lng": "-2.99732"
  },
  {
    "country": "GB",
    "name": "Willaston",
    "lat": "53.06667",
    "lng": "-2.48333"
  },
  {
    "country": "GB",
    "name": "Willand",
    "lat": "50.88333",
    "lng": "-3.36667"
  },
  {
    "country": "GB",
    "name": "Wilden",
    "lat": "52.18272",
    "lng": "-0.39645"
  },
  {
    "country": "GB",
    "name": "Wilburton",
    "lat": "52.35191",
    "lng": "0.17673"
  },
  {
    "country": "GB",
    "name": "Wilberfoss",
    "lat": "53.94854",
    "lng": "-0.88945"
  },
  {
    "country": "GB",
    "name": "Wigton",
    "lat": "54.82482",
    "lng": "-3.16114"
  },
  {
    "country": "GB",
    "name": "Wigston Magna",
    "lat": "52.58128",
    "lng": "-1.09248"
  },
  {
    "country": "GB",
    "name": "Wigmore",
    "lat": "52.31474",
    "lng": "-2.85802"
  },
  {
    "country": "GB",
    "name": "Wigginton",
    "lat": "54.01717",
    "lng": "-1.0831"
  },
  {
    "country": "GB",
    "name": "Wigan",
    "lat": "53.54296",
    "lng": "-2.63706"
  },
  {
    "country": "GB",
    "name": "Widnes",
    "lat": "53.3618",
    "lng": "-2.73406"
  },
  {
    "country": "GB",
    "name": "Wickwar",
    "lat": "51.59404",
    "lng": "-2.39968"
  },
  {
    "country": "GB",
    "name": "Wickham Market",
    "lat": "52.15298",
    "lng": "1.36299"
  },
  {
    "country": "GB",
    "name": "Wickham Bishops",
    "lat": "51.7783",
    "lng": "0.66823"
  },
  {
    "country": "GB",
    "name": "Wickham",
    "lat": "51.44342",
    "lng": "-1.432"
  },
  {
    "country": "GB",
    "name": "Wickham",
    "lat": "50.89924",
    "lng": "-1.18815"
  },
  {
    "country": "GB",
    "name": "Wickford",
    "lat": "51.61101",
    "lng": "0.52331"
  },
  {
    "country": "GB",
    "name": "Wick",
    "lat": "58.43906",
    "lng": "-3.09424"
  },
  {
    "country": "GB",
    "name": "Wick",
    "lat": "51.45306",
    "lng": "-2.42361"
  },
  {
    "country": "GB",
    "name": "Wick",
    "lat": "51.43944",
    "lng": "-3.54944"
  },
  {
    "country": "GB",
    "name": "Whyteleafe",
    "lat": "51.30808",
    "lng": "-0.08429"
  },
  {
    "country": "GB",
    "name": "Whitworth",
    "lat": "53.65601",
    "lng": "-2.1771"
  },
  {
    "country": "GB",
    "name": "Whitwell",
    "lat": "53.28333",
    "lng": "-1.21667"
  },
  {
    "country": "GB",
    "name": "Whitton",
    "lat": "53.7",
    "lng": "-0.63333"
  },
  {
    "country": "GB",
    "name": "Whitton",
    "lat": "52.3",
    "lng": "-3.06667"
  },
  {
    "country": "GB",
    "name": "Whittlesford",
    "lat": "52.11345",
    "lng": "0.14969"
  },
  {
    "country": "GB",
    "name": "Whittlesey",
    "lat": "52.55804",
    "lng": "-0.13016"
  },
  {
    "country": "GB",
    "name": "Whittington",
    "lat": "52.8732",
    "lng": "-3.00304"
  },
  {
    "country": "GB",
    "name": "Whittington",
    "lat": "52.67372",
    "lng": "-1.76091"
  },
  {
    "country": "GB",
    "name": "Whittingham",
    "lat": "55.40115",
    "lng": "-1.8934"
  },
  {
    "country": "GB",
    "name": "Whitstable",
    "lat": "51.3607",
    "lng": "1.0257"
  },
  {
    "country": "GB",
    "name": "Whitley Bay",
    "lat": "55.03973",
    "lng": "-1.44713"
  },
  {
    "country": "GB",
    "name": "Whitland",
    "lat": "51.81889",
    "lng": "-4.61528"
  },
  {
    "country": "GB",
    "name": "Whitford",
    "lat": "53.28333",
    "lng": "-3.28333"
  },
  {
    "country": "GB",
    "name": "White Waltham",
    "lat": "51.49225",
    "lng": "-0.77239"
  },
  {
    "country": "GB",
    "name": "Whiteparish",
    "lat": "51.01041",
    "lng": "-1.64855"
  },
  {
    "country": "GB",
    "name": "Whitehills",
    "lat": "57.6773",
    "lng": "-2.57863"
  },
  {
    "country": "GB",
    "name": "Whitehead",
    "lat": "54.75371",
    "lng": "-5.70933"
  },
  {
    "country": "GB",
    "name": "Whitehaven",
    "lat": "54.54897",
    "lng": "-3.58412"
  },
  {
    "country": "GB",
    "name": "Whitefield",
    "lat": "53.55",
    "lng": "-2.3"
  },
  {
    "country": "GB",
    "name": "Whitchurch",
    "lat": "52.96667",
    "lng": "-2.68333"
  },
  {
    "country": "GB",
    "name": "Whitchurch",
    "lat": "51.85",
    "lng": "-2.65"
  },
  {
    "country": "GB",
    "name": "Whitchurch",
    "lat": "51.40606",
    "lng": "-2.56265"
  },
  {
    "country": "GB",
    "name": "Whitby",
    "lat": "54.48774",
    "lng": "-0.61498"
  },
  {
    "country": "GB",
    "name": "Whitburn",
    "lat": "55.86667",
    "lng": "-3.68333"
  },
  {
    "country": "GB",
    "name": "Whitburn",
    "lat": "54.95333",
    "lng": "-1.36861"
  },
  {
    "country": "GB",
    "name": "Whiston",
    "lat": "53.40851",
    "lng": "-1.3151"
  },
  {
    "country": "GB",
    "name": "Whimple",
    "lat": "50.76649",
    "lng": "-3.35655"
  },
  {
    "country": "GB",
    "name": "Whickham",
    "lat": "54.94561",
    "lng": "-1.67635"
  },
  {
    "country": "GB",
    "name": "Wheldrake",
    "lat": "53.89624",
    "lng": "-0.96303"
  },
  {
    "country": "GB",
    "name": "Wheaton Aston",
    "lat": "52.71145",
    "lng": "-2.22064"
  },
  {
    "country": "GB",
    "name": "Wheatley",
    "lat": "51.74731",
    "lng": "-1.13936"
  },
  {
    "country": "GB",
    "name": "Wheathampstead",
    "lat": "51.81148",
    "lng": "-0.29371"
  },
  {
    "country": "GB",
    "name": "Whaplode",
    "lat": "52.79934",
    "lng": "-0.03639"
  },
  {
    "country": "GB",
    "name": "Whalley",
    "lat": "53.82209",
    "lng": "-2.40712"
  },
  {
    "country": "GB",
    "name": "Whaley Bridge",
    "lat": "53.33031",
    "lng": "-1.9826"
  },
  {
    "country": "GB",
    "name": "Weymouth",
    "lat": "50.61448",
    "lng": "-2.45991"
  },
  {
    "country": "GB",
    "name": "Weybridge",
    "lat": "51.37178",
    "lng": "-0.45975"
  },
  {
    "country": "GB",
    "name": "Wetwang",
    "lat": "54.0175",
    "lng": "-0.57738"
  },
  {
    "country": "GB",
    "name": "Wetherby",
    "lat": "53.92836",
    "lng": "-1.38672"
  },
  {
    "country": "GB",
    "name": "Wetheral",
    "lat": "54.88401",
    "lng": "-2.83327"
  },
  {
    "country": "GB",
    "name": "Westwood",
    "lat": "51.33462",
    "lng": "-2.27975"
  },
  {
    "country": "GB",
    "name": "West Wickham",
    "lat": "51.36667",
    "lng": "-0.01667"
  },
  {
    "country": "GB",
    "name": "West Wellow",
    "lat": "50.97273",
    "lng": "-1.58293"
  },
  {
    "country": "GB",
    "name": "West Walton",
    "lat": "52.69782",
    "lng": "0.17406"
  },
  {
    "country": "GB",
    "name": "West Thurrock",
    "lat": "51.47828",
    "lng": "0.27672"
  },
  {
    "country": "GB",
    "name": "West Rainton",
    "lat": "54.81667",
    "lng": "-1.5"
  },
  {
    "country": "GB",
    "name": "Westonzoyland",
    "lat": "51.10854",
    "lng": "-2.92843"
  },
  {
    "country": "GB",
    "name": "Weston Underwood",
    "lat": "52.14574",
    "lng": "-0.73862"
  },
  {
    "country": "GB",
    "name": "Weston Turville",
    "lat": "51.79168",
    "lng": "-0.75767"
  },
  {
    "country": "GB",
    "name": "Weston-super-Mare",
    "lat": "51.34603",
    "lng": "-2.97665"
  },
  {
    "country": "GB",
    "name": "Westoning",
    "lat": "51.9814",
    "lng": "-0.49698"
  },
  {
    "country": "GB",
    "name": "Weston",
    "lat": "53.06667",
    "lng": "-2.4"
  },
  {
    "country": "GB",
    "name": "West Molesey",
    "lat": "51.39985",
    "lng": "-0.37997"
  },
  {
    "country": "GB",
    "name": "City of Westminster",
    "lat": "51.5",
    "lng": "-0.11667"
  },
  {
    "country": "GB",
    "name": "West Mersea",
    "lat": "51.77798",
    "lng": "0.91873"
  },
  {
    "country": "GB",
    "name": "West Malling",
    "lat": "51.29273",
    "lng": "0.40907"
  },
  {
    "country": "GB",
    "name": "West Linton",
    "lat": "55.74972",
    "lng": "-3.35607"
  },
  {
    "country": "GB",
    "name": "West Kirby",
    "lat": "53.37302",
    "lng": "-3.18417"
  },
  {
    "country": "GB",
    "name": "West Kilbride",
    "lat": "55.69004",
    "lng": "-4.85771"
  },
  {
    "country": "GB",
    "name": "Westhoughton",
    "lat": "53.54899",
    "lng": "-2.52464"
  },
  {
    "country": "GB",
    "name": "West Horsley",
    "lat": "51.26033",
    "lng": "-0.45563"
  },
  {
    "country": "GB",
    "name": "West Hallam",
    "lat": "52.97093",
    "lng": "-1.35846"
  },
  {
    "country": "GB",
    "name": "West Haddon",
    "lat": "52.34168",
    "lng": "-1.07804"
  },
  {
    "country": "GB",
    "name": "Westgate on Sea",
    "lat": "51.38239",
    "lng": "1.33673"
  },
  {
    "country": "GB",
    "name": "Westfield",
    "lat": "51.88333",
    "lng": "-1.86667"
  },
  {
    "country": "GB",
    "name": "Westerham",
    "lat": "51.26632",
    "lng": "0.06892"
  },
  {
    "country": "GB",
    "name": "West End",
    "lat": "50.92741",
    "lng": "-1.33282"
  },
  {
    "country": "GB",
    "name": "West Drayton",
    "lat": "51.5",
    "lng": "-0.46667"
  },
  {
    "country": "GB",
    "name": "Westcott",
    "lat": "51.22438",
    "lng": "-0.37195"
  },
  {
    "country": "GB",
    "name": "West Cornforth",
    "lat": "54.70286",
    "lng": "-1.51938"
  },
  {
    "country": "GB",
    "name": "West Coker",
    "lat": "50.91912",
    "lng": "-2.68707"
  },
  {
    "country": "GB",
    "name": "West Clandon",
    "lat": "51.26063",
    "lng": "-0.50323"
  },
  {
    "country": "GB",
    "name": "West Calder",
    "lat": "55.85188",
    "lng": "-3.56981"
  },
  {
    "country": "GB",
    "name": "West Byfleet",
    "lat": "51.33764",
    "lng": "-0.50649"
  },
  {
    "country": "GB",
    "name": "Westbury",
    "lat": "52.67856",
    "lng": "-2.95433"
  },
  {
    "country": "GB",
    "name": "Westbury",
    "lat": "51.26",
    "lng": "-2.1875"
  },
  {
    "country": "GB",
    "name": "West Bromwich",
    "lat": "52.51868",
    "lng": "-1.9945"
  },
  {
    "country": "GB",
    "name": "West Bridgford",
    "lat": "52.92979",
    "lng": "-1.12537"
  },
  {
    "country": "GB",
    "name": "West Bergholt",
    "lat": "51.91221",
    "lng": "0.84986"
  },
  {
    "country": "GB",
    "name": "Werrington",
    "lat": "50.66667",
    "lng": "-4.36667"
  },
  {
    "country": "GB",
    "name": "Weobley",
    "lat": "52.1596",
    "lng": "-2.875"
  },
  {
    "country": "GB",
    "name": "Wenvoe",
    "lat": "51.44776",
    "lng": "-3.26369"
  },
  {
    "country": "GB",
    "name": "Wentworth",
    "lat": "53.47816",
    "lng": "-1.415"
  },
  {
    "country": "GB",
    "name": "Wendron",
    "lat": "50.13333",
    "lng": "-5.25"
  },
  {
    "country": "GB",
    "name": "Wendover",
    "lat": "51.76194",
    "lng": "-0.73986"
  },
  {
    "country": "GB",
    "name": "Wemyss Bay",
    "lat": "55.87614",
    "lng": "-4.8895"
  },
  {
    "country": "GB",
    "name": "Wembury",
    "lat": "50.32272",
    "lng": "-4.07529"
  },
  {
    "country": "GB",
    "name": "Wembley",
    "lat": "51.55242",
    "lng": "-0.29686"
  },
  {
    "country": "GB",
    "name": "Wem",
    "lat": "52.85835",
    "lng": "-2.71826"
  },
  {
    "country": "GB",
    "name": "Welwyn Garden City",
    "lat": "51.80174",
    "lng": "-0.20691"
  },
  {
    "country": "GB",
    "name": "Welwyn",
    "lat": "51.8331",
    "lng": "-0.21359"
  },
  {
    "country": "GB",
    "name": "Welton",
    "lat": "53.73211",
    "lng": "-0.55232"
  },
  {
    "country": "GB",
    "name": "Welshpool",
    "lat": "52.65973",
    "lng": "-3.1471"
  },
  {
    "country": "GB",
    "name": "Wells-next-the-Sea",
    "lat": "52.95164",
    "lng": "0.8511"
  },
  {
    "country": "GB",
    "name": "Wells",
    "lat": "51.20794",
    "lng": "-2.64896"
  },
  {
    "country": "GB",
    "name": "Wellow",
    "lat": "51.32444",
    "lng": "-2.37417"
  },
  {
    "country": "GB",
    "name": "Wellington",
    "lat": "52.7",
    "lng": "-2.51667"
  },
  {
    "country": "GB",
    "name": "Wellington",
    "lat": "52.12934",
    "lng": "-2.74214"
  },
  {
    "country": "GB",
    "name": "Wellingborough",
    "lat": "52.30273",
    "lng": "-0.69446"
  },
  {
    "country": "GB",
    "name": "Welling",
    "lat": "51.46246",
    "lng": "0.10759"
  },
  {
    "country": "GB",
    "name": "Wellesbourne Mountford",
    "lat": "52.19246",
    "lng": "-1.60967"
  },
  {
    "country": "GB",
    "name": "Wellesbourne",
    "lat": "52.19709",
    "lng": "-1.59053"
  },
  {
    "country": "GB",
    "name": "Welford",
    "lat": "52.41706",
    "lng": "-1.05871"
  },
  {
    "country": "GB",
    "name": "Welford",
    "lat": "51.45727",
    "lng": "-1.41131"
  },
  {
    "country": "GB",
    "name": "Weeting",
    "lat": "52.4644",
    "lng": "0.61485"
  },
  {
    "country": "GB",
    "name": "Weedon Beck",
    "lat": "52.22955",
    "lng": "-1.08371"
  },
  {
    "country": "GB",
    "name": "Wednesfield",
    "lat": "52.5963",
    "lng": "-2.08508"
  },
  {
    "country": "GB",
    "name": "Wednesbury",
    "lat": "52.5514",
    "lng": "-2.02355"
  },
  {
    "country": "GB",
    "name": "Wedmore",
    "lat": "51.22727",
    "lng": "-2.81152"
  },
  {
    "country": "GB",
    "name": "Weaverham",
    "lat": "53.26018",
    "lng": "-2.57291"
  },
  {
    "country": "GB",
    "name": "Waverton",
    "lat": "53.16667",
    "lng": "-2.8"
  },
  {
    "country": "GB",
    "name": "Wavendon",
    "lat": "52.02541",
    "lng": "-0.67411"
  },
  {
    "country": "GB",
    "name": "Watton at Stone",
    "lat": "51.85842",
    "lng": "-0.11381"
  },
  {
    "country": "GB",
    "name": "Watton",
    "lat": "53.93333",
    "lng": "-0.45"
  },
  {
    "country": "GB",
    "name": "Watton",
    "lat": "52.56667",
    "lng": "0.83333"
  },
  {
    "country": "GB",
    "name": "Wattisham",
    "lat": "52.12543",
    "lng": "0.93864"
  },
  {
    "country": "GB",
    "name": "Watlington",
    "lat": "51.64327",
    "lng": "-1.00448"
  },
  {
    "country": "GB",
    "name": "Wath upon Dearne",
    "lat": "53.50291",
    "lng": "-1.3458"
  },
  {
    "country": "GB",
    "name": "Watford",
    "lat": "51.65531",
    "lng": "-0.39602"
  },
  {
    "country": "GB",
    "name": "Water Orton",
    "lat": "52.51575",
    "lng": "-1.74005"
  },
  {
    "country": "GB",
    "name": "Waterlooville",
    "lat": "50.88067",
    "lng": "-1.0304"
  },
  {
    "country": "GB",
    "name": "Wateringbury",
    "lat": "51.25543",
    "lng": "0.42317"
  },
  {
    "country": "GB",
    "name": "Waterbeach",
    "lat": "52.26553",
    "lng": "0.19123"
  },
  {
    "country": "GB",
    "name": "Watchet",
    "lat": "51.18189",
    "lng": "-3.33079"
  },
  {
    "country": "GB",
    "name": "Washington",
    "lat": "54.9",
    "lng": "-1.51667"
  },
  {
    "country": "GB",
    "name": "Washington",
    "lat": "50.90487",
    "lng": "-0.40649"
  },
  {
    "country": "GB",
    "name": "Washingborough",
    "lat": "53.22425",
    "lng": "-0.47485"
  },
  {
    "country": "GB",
    "name": "Warwick",
    "lat": "52.28333",
    "lng": "-1.58333"
  },
  {
    "country": "GB",
    "name": "Warton",
    "lat": "54.14715",
    "lng": "-2.76435"
  },
  {
    "country": "GB",
    "name": "Warton",
    "lat": "53.74988",
    "lng": "-2.89335"
  },
  {
    "country": "GB",
    "name": "Warsop",
    "lat": "53.21402",
    "lng": "-1.15091"
  },
  {
    "country": "GB",
    "name": "Warrington",
    "lat": "53.39254",
    "lng": "-2.58024"
  },
  {
    "country": "GB",
    "name": "Warrington",
    "lat": "52.18446",
    "lng": "-0.68759"
  },
  {
    "country": "GB",
    "name": "Warrenpoint",
    "lat": "54.10148",
    "lng": "-6.25731"
  },
  {
    "country": "GB",
    "name": "Warnham",
    "lat": "51.09107",
    "lng": "-0.34847"
  },
  {
    "country": "GB",
    "name": "Warminster",
    "lat": "51.20434",
    "lng": "-2.17873"
  },
  {
    "country": "GB",
    "name": "Warlingham",
    "lat": "51.30953",
    "lng": "-0.05794"
  },
  {
    "country": "GB",
    "name": "Warkworth",
    "lat": "55.35",
    "lng": "-1.61667"
  },
  {
    "country": "GB",
    "name": "Waringstown",
    "lat": "54.43431",
    "lng": "-6.29929"
  },
  {
    "country": "GB",
    "name": "Wargrave",
    "lat": "51.50068",
    "lng": "-0.86577"
  },
  {
    "country": "GB",
    "name": "Warfield",
    "lat": "51.44213",
    "lng": "-0.72802"
  },
  {
    "country": "GB",
    "name": "Wareham",
    "lat": "50.68792",
    "lng": "-2.11058"
  },
  {
    "country": "GB",
    "name": "Ware",
    "lat": "51.81058",
    "lng": "-0.02875"
  },
  {
    "country": "GB",
    "name": "Wardle",
    "lat": "53.65",
    "lng": "-2.13333"
  },
  {
    "country": "GB",
    "name": "Warden",
    "lat": "54.98333",
    "lng": "-2.13333"
  },
  {
    "country": "GB",
    "name": "Warboys",
    "lat": "52.40352",
    "lng": "-0.07931"
  },
  {
    "country": "GB",
    "name": "Wantage",
    "lat": "51.58846",
    "lng": "-1.42565"
  },
  {
    "country": "GB",
    "name": "Wansford",
    "lat": "52.57851",
    "lng": "-0.42001"
  },
  {
    "country": "GB",
    "name": "Wandsworth",
    "lat": "51.4577",
    "lng": "-0.20784"
  },
  {
    "country": "GB",
    "name": "Wanborough",
    "lat": "51.54263",
    "lng": "-1.69837"
  },
  {
    "country": "GB",
    "name": "Walworth",
    "lat": "54.56667",
    "lng": "-1.65"
  },
  {
    "country": "GB",
    "name": "Walton-on-Thames",
    "lat": "51.38678",
    "lng": "-0.41319"
  },
  {
    "country": "GB",
    "name": "Walton-on-the-Naze",
    "lat": "51.84819",
    "lng": "1.26738"
  },
  {
    "country": "GB",
    "name": "Walthamstow",
    "lat": "51.59067",
    "lng": "-0.02077"
  },
  {
    "country": "GB",
    "name": "Waltham Cross",
    "lat": "51.68602",
    "lng": "-0.03575"
  },
  {
    "country": "GB",
    "name": "Waltham Abbey",
    "lat": "51.687",
    "lng": "-0.00421"
  },
  {
    "country": "GB",
    "name": "Waltham",
    "lat": "53.51667",
    "lng": "-0.1"
  },
  {
    "country": "GB",
    "name": "Walsden",
    "lat": "53.69361",
    "lng": "-2.10001"
  },
  {
    "country": "GB",
    "name": "Walsall",
    "lat": "52.58528",
    "lng": "-1.98396"
  },
  {
    "country": "GB",
    "name": "Wallsend",
    "lat": "54.99111",
    "lng": "-1.53397"
  },
  {
    "country": "GB",
    "name": "Wallingford",
    "lat": "51.59982",
    "lng": "-1.1248"
  },
  {
    "country": "GB",
    "name": "Wallasey",
    "lat": "53.42324",
    "lng": "-3.06497"
  },
  {
    "country": "GB",
    "name": "Wall",
    "lat": "55",
    "lng": "-2.13333"
  },
  {
    "country": "GB",
    "name": "Walkington",
    "lat": "53.8195",
    "lng": "-0.48958"
  },
  {
    "country": "GB",
    "name": "Walkern",
    "lat": "51.91888",
    "lng": "-0.12758"
  },
  {
    "country": "GB",
    "name": "Walkden",
    "lat": "53.51667",
    "lng": "-2.4"
  },
  {
    "country": "GB",
    "name": "Walford",
    "lat": "51.88333",
    "lng": "-2.6"
  },
  {
    "country": "GB",
    "name": "Wales",
    "lat": "53.34061",
    "lng": "-1.28162"
  },
  {
    "country": "GB",
    "name": "Walberton",
    "lat": "50.84475",
    "lng": "-0.62013"
  },
  {
    "country": "GB",
    "name": "Wakefield",
    "lat": "53.68331",
    "lng": "-1.49768"
  },
  {
    "country": "GB",
    "name": "Wainfleet All Saints",
    "lat": "53.1057",
    "lng": "0.23583"
  },
  {
    "country": "GB",
    "name": "Wadworth",
    "lat": "53.46726",
    "lng": "-1.14261"
  },
  {
    "country": "GB",
    "name": "Wadhurst",
    "lat": "51.0623",
    "lng": "0.33929"
  },
  {
    "country": "GB",
    "name": "Wadebridge",
    "lat": "50.51734",
    "lng": "-4.83633"
  },
  {
    "country": "GB",
    "name": "Waddington",
    "lat": "53.88977",
    "lng": "-2.41459"
  },
  {
    "country": "GB",
    "name": "Waddington",
    "lat": "53.16667",
    "lng": "-0.53333"
  },
  {
    "country": "GB",
    "name": "Waddesdon",
    "lat": "51.84675",
    "lng": "-0.92105"
  },
  {
    "country": "GB",
    "name": "Wacton",
    "lat": "52.21667",
    "lng": "-2.56667"
  },
  {
    "country": "GB",
    "name": "Victoria",
    "lat": "51.75",
    "lng": "-3.2"
  },
  {
    "country": "GB",
    "name": "Verwood",
    "lat": "50.87575",
    "lng": "-1.87023"
  },
  {
    "country": "GB",
    "name": "Ventnor",
    "lat": "50.59449",
    "lng": "-1.20672"
  },
  {
    "country": "GB",
    "name": "Valley",
    "lat": "53.2849",
    "lng": "-4.56644"
  },
  {
    "country": "GB",
    "name": "Uxbridge",
    "lat": "51.5489",
    "lng": "-0.48211"
  },
  {
    "country": "GB",
    "name": "Uttoxeter",
    "lat": "52.89838",
    "lng": "-1.86488"
  },
  {
    "country": "GB",
    "name": "Usk",
    "lat": "51.70347",
    "lng": "-2.90332"
  },
  {
    "country": "GB",
    "name": "Ushaw Moor",
    "lat": "54.77803",
    "lng": "-1.6472"
  },
  {
    "country": "GB",
    "name": "Urmston",
    "lat": "53.44852",
    "lng": "-2.35419"
  },
  {
    "country": "GB",
    "name": "Upwell",
    "lat": "52.60249",
    "lng": "0.2219"
  },
  {
    "country": "GB",
    "name": "Upton upon Severn",
    "lat": "52.06258",
    "lng": "-2.21802"
  },
  {
    "country": "GB",
    "name": "Upton Scudamore",
    "lat": "51.23",
    "lng": "-2.19333"
  },
  {
    "country": "GB",
    "name": "Upton",
    "lat": "53.61466",
    "lng": "-1.28677"
  },
  {
    "country": "GB",
    "name": "Upton",
    "lat": "52.59061",
    "lng": "-0.36935"
  },
  {
    "country": "GB",
    "name": "Uppingham",
    "lat": "52.58803",
    "lng": "-0.72272"
  },
  {
    "country": "GB",
    "name": "Upper Poppleton",
    "lat": "53.97907",
    "lng": "-1.15204"
  },
  {
    "country": "GB",
    "name": "Upper Langwith",
    "lat": "53.22919",
    "lng": "-1.20695"
  },
  {
    "country": "GB",
    "name": "Upminster",
    "lat": "51.55594",
    "lng": "0.2556"
  },
  {
    "country": "GB",
    "name": "Upchurch",
    "lat": "51.3762",
    "lng": "0.64789"
  },
  {
    "country": "GB",
    "name": "Uny Lelant",
    "lat": "50.18298",
    "lng": "-5.44047"
  },
  {
    "country": "GB",
    "name": "Undy",
    "lat": "51.57526",
    "lng": "-2.81453"
  },
  {
    "country": "GB",
    "name": "Ulverston",
    "lat": "54.19594",
    "lng": "-3.09626"
  },
  {
    "country": "GB",
    "name": "Ulrome",
    "lat": "53.99198",
    "lng": "-0.22968"
  },
  {
    "country": "GB",
    "name": "Ulley",
    "lat": "53.382",
    "lng": "-1.30222"
  },
  {
    "country": "GB",
    "name": "Ullapool",
    "lat": "57.89872",
    "lng": "-5.16039"
  },
  {
    "country": "GB",
    "name": "Ulceby",
    "lat": "53.61667",
    "lng": "-0.33333"
  },
  {
    "country": "GB",
    "name": "Ufford",
    "lat": "52.62379",
    "lng": "-0.38435"
  },
  {
    "country": "GB",
    "name": "Uffculme",
    "lat": "50.90604",
    "lng": "-3.32746"
  },
  {
    "country": "GB",
    "name": "Uddingston",
    "lat": "55.81971",
    "lng": "-4.08362"
  },
  {
    "country": "GB",
    "name": "Uckfield",
    "lat": "50.96948",
    "lng": "0.09589"
  },
  {
    "country": "GB",
    "name": "Tytherington",
    "lat": "51.5925",
    "lng": "-2.47972"
  },
  {
    "country": "GB",
    "name": "Tynemouth",
    "lat": "55.01788",
    "lng": "-1.42559"
  },
  {
    "country": "GB",
    "name": "Tyldesley",
    "lat": "53.51393",
    "lng": "-2.46754"
  },
  {
    "country": "GB",
    "name": "Tycroes",
    "lat": "51.77806",
    "lng": "-4.02"
  },
  {
    "country": "GB",
    "name": "Tyberton",
    "lat": "52.0455",
    "lng": "-2.90414"
  },
  {
    "country": "GB",
    "name": "Twyford",
    "lat": "51.47518",
    "lng": "-0.86037"
  },
  {
    "country": "GB",
    "name": "Twickenham",
    "lat": "51.44489",
    "lng": "-0.3377"
  },
  {
    "country": "GB",
    "name": "Tuxford",
    "lat": "53.23004",
    "lng": "-0.89325"
  },
  {
    "country": "GB",
    "name": "Turriff",
    "lat": "57.5384",
    "lng": "-2.45932"
  },
  {
    "country": "GB",
    "name": "Turnastone",
    "lat": "52.02398",
    "lng": "-2.94833"
  },
  {
    "country": "GB",
    "name": "Truro",
    "lat": "50.26526",
    "lng": "-5.05436"
  },
  {
    "country": "GB",
    "name": "Trowbridge",
    "lat": "51.31889",
    "lng": "-2.20861"
  },
  {
    "country": "GB",
    "name": "Troon",
    "lat": "55.54359",
    "lng": "-4.66335"
  },
  {
    "country": "GB",
    "name": "Tring",
    "lat": "51.79471",
    "lng": "-0.65824"
  },
  {
    "country": "GB",
    "name": "Trimdon Grange",
    "lat": "54.71414",
    "lng": "-1.42611"
  },
  {
    "country": "GB",
    "name": "Trimdon",
    "lat": "54.69878",
    "lng": "-1.42881"
  },
  {
    "country": "GB",
    "name": "Trewen",
    "lat": "50.61667",
    "lng": "-4.46667"
  },
  {
    "country": "GB",
    "name": "Treuddyn",
    "lat": "53.1148",
    "lng": "-3.12003"
  },
  {
    "country": "GB",
    "name": "Treorchy",
    "lat": "51.65958",
    "lng": "-3.50587"
  },
  {
    "country": "GB",
    "name": "Trelech",
    "lat": "51.94444",
    "lng": "-4.5"
  },
  {
    "country": "GB",
    "name": "Treherbert",
    "lat": "51.67139",
    "lng": "-3.52972"
  },
  {
    "country": "GB",
    "name": "Treharris",
    "lat": "51.66457",
    "lng": "-3.30725"
  },
  {
    "country": "GB",
    "name": "Tregoney",
    "lat": "50.2674",
    "lng": "-4.91647"
  },
  {
    "country": "GB",
    "name": "Tregarth",
    "lat": "53.19012",
    "lng": "-4.0878"
  },
  {
    "country": "GB",
    "name": "Tregaron",
    "lat": "52.2195",
    "lng": "-3.93295"
  },
  {
    "country": "GB",
    "name": "Trefnant",
    "lat": "53.22526",
    "lng": "-3.4203"
  },
  {
    "country": "GB",
    "name": "Treeton",
    "lat": "53.38564",
    "lng": "-1.35189"
  },
  {
    "country": "GB",
    "name": "Tredegar",
    "lat": "51.77251",
    "lng": "-3.24679"
  },
  {
    "country": "GB",
    "name": "Trawsfynydd",
    "lat": "52.90212",
    "lng": "-3.92289"
  },
  {
    "country": "GB",
    "name": "Tranent",
    "lat": "55.94439",
    "lng": "-2.95412"
  },
  {
    "country": "GB",
    "name": "Trafford Park",
    "lat": "53.46879",
    "lng": "-2.31194"
  },
  {
    "country": "GB",
    "name": "Townhill",
    "lat": "56.0891",
    "lng": "-3.43889"
  },
  {
    "country": "GB",
    "name": "Tow Law",
    "lat": "54.74456",
    "lng": "-1.81434"
  },
  {
    "country": "GB",
    "name": "Towcester",
    "lat": "52.13359",
    "lng": "-0.99057"
  },
  {
    "country": "GB",
    "name": "Totton",
    "lat": "50.91877",
    "lng": "-1.49037"
  },
  {
    "country": "GB",
    "name": "Tottington",
    "lat": "53.61326",
    "lng": "-2.34071"
  },
  {
    "country": "GB",
    "name": "Totternhoe",
    "lat": "51.88555",
    "lng": "-0.57343"
  },
  {
    "country": "GB",
    "name": "Totnes",
    "lat": "50.43107",
    "lng": "-3.6843"
  },
  {
    "country": "GB",
    "name": "Totland",
    "lat": "50.68466",
    "lng": "-1.53688"
  },
  {
    "country": "GB",
    "name": "Torquay",
    "lat": "50.46198",
    "lng": "-3.52522"
  },
  {
    "country": "GB",
    "name": "Torpoint",
    "lat": "50.37505",
    "lng": "-4.19566"
  },
  {
    "country": "GB",
    "name": "Torphins",
    "lat": "57.10561",
    "lng": "-2.62398"
  },
  {
    "country": "GB",
    "name": "Topsham",
    "lat": "50.68596",
    "lng": "-3.46696"
  },
  {
    "country": "GB",
    "name": "Tonyrefail",
    "lat": "51.58402",
    "lng": "-3.43041"
  },
  {
    "country": "GB",
    "name": "Tong",
    "lat": "52.66667",
    "lng": "-2.3"
  },
  {
    "country": "GB",
    "name": "Tonbridge",
    "lat": "51.19532",
    "lng": "0.27363"
  },
  {
    "country": "GB",
    "name": "Tolleshunt Knights",
    "lat": "51.79869",
    "lng": "0.77651"
  },
  {
    "country": "GB",
    "name": "Tollesbury",
    "lat": "51.75913",
    "lng": "0.83462"
  },
  {
    "country": "GB",
    "name": "Todwick",
    "lat": "53.35373",
    "lng": "-1.25673"
  },
  {
    "country": "GB",
    "name": "Todmorden",
    "lat": "53.71434",
    "lng": "-2.09701"
  },
  {
    "country": "GB",
    "name": "Toddington",
    "lat": "51.94922",
    "lng": "-0.53277"
  },
  {
    "country": "GB",
    "name": "Tobermory",
    "lat": "56.62198",
    "lng": "-6.07231"
  },
  {
    "country": "GB",
    "name": "Tiverton",
    "lat": "53.13333",
    "lng": "-2.66667"
  },
  {
    "country": "GB",
    "name": "Tiverton",
    "lat": "50.90241",
    "lng": "-3.49232"
  },
  {
    "country": "GB",
    "name": "Tisbury",
    "lat": "51.06283",
    "lng": "-2.08058"
  },
  {
    "country": "GB",
    "name": "Tiptree",
    "lat": "51.8123",
    "lng": "0.7454"
  },
  {
    "country": "GB",
    "name": "Tipton",
    "lat": "52.52956",
    "lng": "-2.06773"
  },
  {
    "country": "GB",
    "name": "Tinwell",
    "lat": "52.64629",
    "lng": "-0.51498"
  },
  {
    "country": "GB",
    "name": "Tingewick",
    "lat": "51.99031",
    "lng": "-1.04804"
  },
  {
    "country": "GB",
    "name": "Timsbury",
    "lat": "51.32444",
    "lng": "-2.47917"
  },
  {
    "country": "GB",
    "name": "Timperley",
    "lat": "53.4",
    "lng": "-2.33333"
  },
  {
    "country": "GB",
    "name": "Tillicoultry",
    "lat": "56.15251",
    "lng": "-3.74015"
  },
  {
    "country": "GB",
    "name": "Tilehurst",
    "lat": "51.45647",
    "lng": "-1.0437"
  },
  {
    "country": "GB",
    "name": "Tilbury",
    "lat": "51.46248",
    "lng": "0.35856"
  },
  {
    "country": "GB",
    "name": "Tideswell",
    "lat": "53.27807",
    "lng": "-1.77292"
  },
  {
    "country": "GB",
    "name": "Tickton",
    "lat": "53.86233",
    "lng": "-0.3833"
  },
  {
    "country": "GB",
    "name": "Tickhill",
    "lat": "53.43194",
    "lng": "-1.10859"
  },
  {
    "country": "GB",
    "name": "Tickencote",
    "lat": "52.67503",
    "lng": "-0.53696"
  },
  {
    "country": "GB",
    "name": "Ticehurst",
    "lat": "51.04652",
    "lng": "0.4086"
  },
  {
    "country": "GB",
    "name": "Tibshelf",
    "lat": "53.14436",
    "lng": "-1.34056"
  },
  {
    "country": "GB",
    "name": "Thwing",
    "lat": "54.11547",
    "lng": "-0.3895"
  },
  {
    "country": "GB",
    "name": "Thurston",
    "lat": "52.25244",
    "lng": "0.80749"
  },
  {
    "country": "GB",
    "name": "Thurso",
    "lat": "58.59271",
    "lng": "-3.52594"
  },
  {
    "country": "GB",
    "name": "Thurlton",
    "lat": "52.52881",
    "lng": "1.55617"
  },
  {
    "country": "GB",
    "name": "Thurlby",
    "lat": "52.73879",
    "lng": "-0.37868"
  },
  {
    "country": "GB",
    "name": "Thruxton",
    "lat": "52",
    "lng": "-2.81667"
  },
  {
    "country": "GB",
    "name": "Three Legged Cross",
    "lat": "50.85",
    "lng": "-1.88333"
  },
  {
    "country": "GB",
    "name": "Thrapston",
    "lat": "52.39675",
    "lng": "-0.5392"
  },
  {
    "country": "GB",
    "name": "Thorpe le Soken",
    "lat": "51.85603",
    "lng": "1.1658"
  },
  {
    "country": "GB",
    "name": "Thorp Arch",
    "lat": "53.91584",
    "lng": "-1.3198"
  },
  {
    "country": "GB",
    "name": "Thornton Heath",
    "lat": "51.39884",
    "lng": "-0.09872"
  },
  {
    "country": "GB",
    "name": "Thornton Dale",
    "lat": "54.23528",
    "lng": "-0.72016"
  },
  {
    "country": "GB",
    "name": "Thornton",
    "lat": "56.16667",
    "lng": "-3.15"
  },
  {
    "country": "GB",
    "name": "Thornton",
    "lat": "53.9",
    "lng": "-0.85"
  },
  {
    "country": "GB",
    "name": "Thornton",
    "lat": "53.5",
    "lng": "-3"
  },
  {
    "country": "GB",
    "name": "Thornley",
    "lat": "54.75",
    "lng": "-1.43333"
  },
  {
    "country": "GB",
    "name": "Thornhill",
    "lat": "55.23333",
    "lng": "-3.76667"
  },
  {
    "country": "GB",
    "name": "Thornhaugh",
    "lat": "52.59252",
    "lng": "-0.42418"
  },
  {
    "country": "GB",
    "name": "Thorngumbald",
    "lat": "53.721",
    "lng": "-0.17175"
  },
  {
    "country": "GB",
    "name": "Thorney",
    "lat": "52.62147",
    "lng": "-0.10815"
  },
  {
    "country": "GB",
    "name": "Thorner",
    "lat": "53.86093",
    "lng": "-1.42676"
  },
  {
    "country": "GB",
    "name": "Thorne",
    "lat": "53.61122",
    "lng": "-0.96308"
  },
  {
    "country": "GB",
    "name": "Thornbury",
    "lat": "52.23333",
    "lng": "-2.55"
  },
  {
    "country": "GB",
    "name": "Thornbury",
    "lat": "51.60889",
    "lng": "-2.52028"
  },
  {
    "country": "GB",
    "name": "Thornaby-on-Tees",
    "lat": "54.53333",
    "lng": "-1.3"
  },
  {
    "country": "GB",
    "name": "Thirsk",
    "lat": "54.23298",
    "lng": "-1.34411"
  },
  {
    "country": "GB",
    "name": "Theydon Bois",
    "lat": "51.67426",
    "lng": "0.09781"
  },
  {
    "country": "GB",
    "name": "Thetford",
    "lat": "52.41667",
    "lng": "0.75"
  },
  {
    "country": "GB",
    "name": "Theale",
    "lat": "51.43694",
    "lng": "-1.077"
  },
  {
    "country": "GB",
    "name": "Thaxted",
    "lat": "51.95326",
    "lng": "0.34478"
  },
  {
    "country": "GB",
    "name": "Thatcham",
    "lat": "51.40366",
    "lng": "-1.26049"
  },
  {
    "country": "GB",
    "name": "Thames Ditton",
    "lat": "51.38964",
    "lng": "-0.33928"
  },
  {
    "country": "GB",
    "name": "Thame",
    "lat": "51.7484",
    "lng": "-0.97624"
  },
  {
    "country": "GB",
    "name": "Teynham",
    "lat": "51.33045",
    "lng": "0.80526"
  },
  {
    "country": "GB",
    "name": "Tewkesbury",
    "lat": "51.99244",
    "lng": "-2.1601"
  },
  {
    "country": "GB",
    "name": "Tetney",
    "lat": "53.49239",
    "lng": "-0.02106"
  },
  {
    "country": "GB",
    "name": "Tetbury",
    "lat": "51.63944",
    "lng": "-2.16222"
  },
  {
    "country": "GB",
    "name": "Terrington Saint John",
    "lat": "52.70546",
    "lng": "0.27389"
  },
  {
    "country": "GB",
    "name": "Terrington St Clement",
    "lat": "52.75813",
    "lng": "0.29732"
  },
  {
    "country": "GB",
    "name": "Tenterden",
    "lat": "51.06845",
    "lng": "0.68776"
  },
  {
    "country": "GB",
    "name": "Tenby",
    "lat": "51.67279",
    "lng": "-4.70447"
  },
  {
    "country": "GB",
    "name": "Tenbury Wells",
    "lat": "52.31077",
    "lng": "-2.59621"
  },
  {
    "country": "GB",
    "name": "Tempsford",
    "lat": "52.17051",
    "lng": "-0.29586"
  },
  {
    "country": "GB",
    "name": "Templeton",
    "lat": "51.77194",
    "lng": "-4.73778"
  },
  {
    "country": "GB",
    "name": "Templepatrick",
    "lat": "54.68333",
    "lng": "-6.08333"
  },
  {
    "country": "GB",
    "name": "Templecombe",
    "lat": "50.99908",
    "lng": "-2.41578"
  },
  {
    "country": "GB",
    "name": "Teignmouth",
    "lat": "50.54768",
    "lng": "-3.49637"
  },
  {
    "country": "GB",
    "name": "Teddington",
    "lat": "51.42233",
    "lng": "-0.33053"
  },
  {
    "country": "GB",
    "name": "Tayport",
    "lat": "56.44699",
    "lng": "-2.87966"
  },
  {
    "country": "GB",
    "name": "Tavistock",
    "lat": "50.54944",
    "lng": "-4.14418"
  },
  {
    "country": "GB",
    "name": "Taunton",
    "lat": "51.01494",
    "lng": "-3.10293"
  },
  {
    "country": "GB",
    "name": "Tattenhall",
    "lat": "53.12188",
    "lng": "-2.76746"
  },
  {
    "country": "GB",
    "name": "Tarvin",
    "lat": "53.19737",
    "lng": "-2.76548"
  },
  {
    "country": "GB",
    "name": "Tarporley",
    "lat": "53.15918",
    "lng": "-2.66867"
  },
  {
    "country": "GB",
    "name": "Tarleton",
    "lat": "53.68005",
    "lng": "-2.82968"
  },
  {
    "country": "GB",
    "name": "Tarbolton",
    "lat": "55.51292",
    "lng": "-4.48648"
  },
  {
    "country": "GB",
    "name": "Tarbert",
    "lat": "55.86277",
    "lng": "-5.41622"
  },
  {
    "country": "GB",
    "name": "Tansley",
    "lat": "53.13197",
    "lng": "-1.51882"
  },
  {
    "country": "GB",
    "name": "Tangmere",
    "lat": "50.85131",
    "lng": "-0.71633"
  },
  {
    "country": "GB",
    "name": "Tanfield",
    "lat": "54.89288",
    "lng": "-1.71316"
  },
  {
    "country": "GB",
    "name": "Tandragee",
    "lat": "54.35486",
    "lng": "-6.41396"
  },
  {
    "country": "GB",
    "name": "Tamworth",
    "lat": "52.63399",
    "lng": "-1.69587"
  },
  {
    "country": "GB",
    "name": "Talgarth",
    "lat": "51.99588",
    "lng": "-3.23205"
  },
  {
    "country": "GB",
    "name": "Takeley",
    "lat": "51.87089",
    "lng": "0.26583"
  },
  {
    "country": "GB",
    "name": "Tain",
    "lat": "57.80903",
    "lng": "-4.05991"
  },
  {
    "country": "GB",
    "name": "Taibach",
    "lat": "51.58333",
    "lng": "-3.76667"
  },
  {
    "country": "GB",
    "name": "Tadworth",
    "lat": "51.29169",
    "lng": "-0.23582"
  },
  {
    "country": "GB",
    "name": "Tadley",
    "lat": "51.35045",
    "lng": "-1.1285"
  },
  {
    "country": "GB",
    "name": "Tadcaster",
    "lat": "53.88322",
    "lng": "-1.26344"
  },
  {
    "country": "GB",
    "name": "Sywell",
    "lat": "52.29856",
    "lng": "-0.79728"
  },
  {
    "country": "GB",
    "name": "Syston",
    "lat": "52.68333",
    "lng": "-1.06667"
  },
  {
    "country": "GB",
    "name": "Symington",
    "lat": "55.55176",
    "lng": "-4.55835"
  },
  {
    "country": "GB",
    "name": "Swinton",
    "lat": "53.5",
    "lng": "-2.35"
  },
  {
    "country": "GB",
    "name": "Swineshead",
    "lat": "52.94543",
    "lng": "-0.15947"
  },
  {
    "country": "GB",
    "name": "Swineshead",
    "lat": "52.28029",
    "lng": "-0.4501"
  },
  {
    "country": "GB",
    "name": "Swindon",
    "lat": "51.55797",
    "lng": "-1.78116"
  },
  {
    "country": "GB",
    "name": "Swillington",
    "lat": "53.76846",
    "lng": "-1.4175"
  },
  {
    "country": "GB",
    "name": "Sway",
    "lat": "50.78685",
    "lng": "-1.60294"
  },
  {
    "country": "GB",
    "name": "Swavesey",
    "lat": "52.30155",
    "lng": "-0.00476"
  },
  {
    "country": "GB",
    "name": "Swansea",
    "lat": "51.62079",
    "lng": "-3.94323"
  },
  {
    "country": "GB",
    "name": "Swanscombe",
    "lat": "51.44713",
    "lng": "0.31028"
  },
  {
    "country": "GB",
    "name": "Swanmore",
    "lat": "50.94404",
    "lng": "-1.18021"
  },
  {
    "country": "GB",
    "name": "Swanley",
    "lat": "51.39717",
    "lng": "0.17321"
  },
  {
    "country": "GB",
    "name": "Swanage",
    "lat": "50.60923",
    "lng": "-1.9626"
  },
  {
    "country": "GB",
    "name": "Swallowfield",
    "lat": "51.37875",
    "lng": "-0.95804"
  },
  {
    "country": "GB",
    "name": "Swaffham",
    "lat": "52.6477",
    "lng": "0.6857"
  },
  {
    "country": "GB",
    "name": "Swadlincote",
    "lat": "52.774",
    "lng": "-1.55744"
  },
  {
    "country": "GB",
    "name": "Sutton upon Derwent",
    "lat": "53.91314",
    "lng": "-0.92465"
  },
  {
    "country": "GB",
    "name": "Sutton on Trent",
    "lat": "53.18437",
    "lng": "-0.81091"
  },
  {
    "country": "GB",
    "name": "Sutton in Ashfield",
    "lat": "53.12542",
    "lng": "-1.26135"
  },
  {
    "country": "GB",
    "name": "Sutton Courtenay",
    "lat": "51.6413",
    "lng": "-1.27682"
  },
  {
    "country": "GB",
    "name": "Sutton Coldfield",
    "lat": "52.56667",
    "lng": "-1.81667"
  },
  {
    "country": "GB",
    "name": "Sutton Bridge",
    "lat": "52.76995",
    "lng": "0.1855"
  },
  {
    "country": "GB",
    "name": "Sutton Bonington",
    "lat": "52.82144",
    "lng": "-1.24969"
  },
  {
    "country": "GB",
    "name": "Sutton Benger",
    "lat": "51.50685",
    "lng": "-2.08015"
  },
  {
    "country": "GB",
    "name": "Sutton",
    "lat": "52.38804",
    "lng": "0.11866"
  },
  {
    "country": "GB",
    "name": "Sutton",
    "lat": "52.1",
    "lng": "-2.68333"
  },
  {
    "country": "GB",
    "name": "Sutton",
    "lat": "52.11078",
    "lng": "-0.2138"
  },
  {
    "country": "GB",
    "name": "Sutton",
    "lat": "51.35",
    "lng": "-0.2"
  },
  {
    "country": "GB",
    "name": "Sutterton",
    "lat": "52.90269",
    "lng": "-0.09235"
  },
  {
    "country": "GB",
    "name": "Sunningdale",
    "lat": "51.39878",
    "lng": "-0.62944"
  },
  {
    "country": "GB",
    "name": "Sunk Island",
    "lat": "53.65168",
    "lng": "-0.08407"
  },
  {
    "country": "GB",
    "name": "Sundridge",
    "lat": "51.27797",
    "lng": "0.12231"
  },
  {
    "country": "GB",
    "name": "Sunderland",
    "lat": "54.90465",
    "lng": "-1.38222"
  },
  {
    "country": "GB",
    "name": "Sunbury-on-Thames",
    "lat": "51.40424",
    "lng": "-0.41817"
  },
  {
    "country": "GB",
    "name": "Sudbury",
    "lat": "52.0389",
    "lng": "0.73117"
  },
  {
    "country": "GB",
    "name": "Sudbrooke",
    "lat": "53.26667",
    "lng": "-0.45"
  },
  {
    "country": "GB",
    "name": "Sturry",
    "lat": "51.30132",
    "lng": "1.12155"
  },
  {
    "country": "GB",
    "name": "Sturminster Newton",
    "lat": "50.92681",
    "lng": "-2.30515"
  },
  {
    "country": "GB",
    "name": "Sturminster Marshall",
    "lat": "50.79968",
    "lng": "-2.07615"
  },
  {
    "country": "GB",
    "name": "Studley",
    "lat": "52.27026",
    "lng": "-1.89188"
  },
  {
    "country": "GB",
    "name": "Stroud",
    "lat": "51.75",
    "lng": "-2.2"
  },
  {
    "country": "GB",
    "name": "Strood",
    "lat": "51.39323",
    "lng": "0.47713"
  },
  {
    "country": "GB",
    "name": "Stromness",
    "lat": "58.96498",
    "lng": "-3.29601"
  },
  {
    "country": "GB",
    "name": "Stretton",
    "lat": "53.33333",
    "lng": "-2.56667"
  },
  {
    "country": "GB",
    "name": "Stretham",
    "lat": "52.34709",
    "lng": "0.21852"
  },
  {
    "country": "GB",
    "name": "Stretford",
    "lat": "53.45",
    "lng": "-2.31667"
  },
  {
    "country": "GB",
    "name": "Strensall",
    "lat": "54.03999",
    "lng": "-1.03512"
  },
  {
    "country": "GB",
    "name": "Streetly",
    "lat": "52.58333",
    "lng": "-1.88333"
  },
  {
    "country": "GB",
    "name": "Street",
    "lat": "51.12472",
    "lng": "-2.74"
  },
  {
    "country": "GB",
    "name": "Streatley",
    "lat": "51.94628",
    "lng": "-0.44374"
  },
  {
    "country": "GB",
    "name": "Strathpeffer",
    "lat": "57.58522",
    "lng": "-4.54195"
  },
  {
    "country": "GB",
    "name": "Strathblane",
    "lat": "55.98596",
    "lng": "-4.30658"
  },
  {
    "country": "GB",
    "name": "Strathaven",
    "lat": "55.6771",
    "lng": "-4.0668"
  },
  {
    "country": "GB",
    "name": "Stratford-upon-Avon",
    "lat": "52.19166",
    "lng": "-1.70734"
  },
  {
    "country": "GB",
    "name": "Stratfield Mortimer",
    "lat": "51.37339",
    "lng": "-1.03495"
  },
  {
    "country": "GB",
    "name": "Stranraer",
    "lat": "54.90234",
    "lng": "-5.02731"
  },
  {
    "country": "GB",
    "name": "Stradbroke",
    "lat": "52.31819",
    "lng": "1.27278"
  },
  {
    "country": "GB",
    "name": "Strabane",
    "lat": "54.82373",
    "lng": "-7.46916"
  },
  {
    "country": "GB",
    "name": "Stow on the Wold",
    "lat": "51.93008",
    "lng": "-1.72382"
  },
  {
    "country": "GB",
    "name": "Stowmarket",
    "lat": "52.18893",
    "lng": "0.99774"
  },
  {
    "country": "GB",
    "name": "Stourport-on-Severn",
    "lat": "52.33976",
    "lng": "-2.28034"
  },
  {
    "country": "GB",
    "name": "Stourbridge",
    "lat": "52.45608",
    "lng": "-2.14317"
  },
  {
    "country": "GB",
    "name": "Stotfold",
    "lat": "52.01632",
    "lng": "-0.23209"
  },
  {
    "country": "GB",
    "name": "Storrington",
    "lat": "50.91765",
    "lng": "-0.45473"
  },
  {
    "country": "GB",
    "name": "Stornoway",
    "lat": "58.20925",
    "lng": "-6.38649"
  },
  {
    "country": "GB",
    "name": "Stony Stratford",
    "lat": "52.05682",
    "lng": "-0.85281"
  },
  {
    "country": "GB",
    "name": "Stoney Stanton",
    "lat": "52.54839",
    "lng": "-1.2793"
  },
  {
    "country": "GB",
    "name": "Stone",
    "lat": "51.45032",
    "lng": "0.2647"
  },
  {
    "country": "GB",
    "name": "Stonesfield",
    "lat": "51.85142",
    "lng": "-1.4296"
  },
  {
    "country": "GB",
    "name": "Stonehouse",
    "lat": "55.69435",
    "lng": "-3.9878"
  },
  {
    "country": "GB",
    "name": "Stonehouse",
    "lat": "51.75",
    "lng": "-2.28333"
  },
  {
    "country": "GB",
    "name": "Stonehaven",
    "lat": "56.96365",
    "lng": "-2.21177"
  },
  {
    "country": "GB",
    "name": "Stone",
    "lat": "52.9059",
    "lng": "-2.15409"
  },
  {
    "country": "GB",
    "name": "Stone",
    "lat": "51.80246",
    "lng": "-0.87032"
  },
  {
    "country": "GB",
    "name": "Stone",
    "lat": "51",
    "lng": "0.76667"
  },
  {
    "country": "GB",
    "name": "Stondon",
    "lat": "52.0015",
    "lng": "-0.31933"
  },
  {
    "country": "GB",
    "name": "Stoke upon Tern",
    "lat": "52.85",
    "lng": "-2.53333"
  },
  {
    "country": "GB",
    "name": "Stokesley",
    "lat": "54.46998",
    "lng": "-1.1933"
  },
  {
    "country": "GB",
    "name": "Stoke Prior",
    "lat": "52.29978",
    "lng": "-2.08034"
  },
  {
    "country": "GB",
    "name": "Stoke Poges",
    "lat": "51.54441",
    "lng": "-0.5888"
  },
  {
    "country": "GB",
    "name": "Stoke-on-Trent",
    "lat": "53.00415",
    "lng": "-2.18538"
  },
  {
    "country": "GB",
    "name": "Stokenchurch",
    "lat": "51.65831",
    "lng": "-0.8974"
  },
  {
    "country": "GB",
    "name": "Stoke Goldington",
    "lat": "52.13133",
    "lng": "-0.77814"
  },
  {
    "country": "GB",
    "name": "Stoke Golding",
    "lat": "52.5706",
    "lng": "-1.41124"
  },
  {
    "country": "GB",
    "name": "Stoke Gifford",
    "lat": "51.51686",
    "lng": "-2.54053"
  },
  {
    "country": "GB",
    "name": "Stoke Gabriel",
    "lat": "50.40328",
    "lng": "-3.62111"
  },
  {
    "country": "GB",
    "name": "Stoke Ferry",
    "lat": "52.57051",
    "lng": "0.5132"
  },
  {
    "country": "GB",
    "name": "Stoke",
    "lat": "53.25",
    "lng": "-2.86667"
  },
  {
    "country": "GB",
    "name": "Upper Stoke",
    "lat": "51.44679",
    "lng": "0.61824"
  },
  {
    "country": "GB",
    "name": "Stockton-on-Tees",
    "lat": "54.56848",
    "lng": "-1.3187"
  },
  {
    "country": "GB",
    "name": "Stockton",
    "lat": "52.27181",
    "lng": "-1.36055"
  },
  {
    "country": "GB",
    "name": "Stocksfield",
    "lat": "54.94026",
    "lng": "-1.90398"
  },
  {
    "country": "GB",
    "name": "Stocksbridge",
    "lat": "53.48249",
    "lng": "-1.59373"
  },
  {
    "country": "GB",
    "name": "Stockport",
    "lat": "53.40979",
    "lng": "-2.15761"
  },
  {
    "country": "GB",
    "name": "Stock",
    "lat": "51.66351",
    "lng": "0.44263"
  },
  {
    "country": "GB",
    "name": "Stithians",
    "lat": "50.1887",
    "lng": "-5.17807"
  },
  {
    "country": "GB",
    "name": "Stirling",
    "lat": "56.11903",
    "lng": "-3.93682"
  },
  {
    "country": "GB",
    "name": "Stilton",
    "lat": "52.48788",
    "lng": "-0.28894"
  },
  {
    "country": "GB",
    "name": "Stillington",
    "lat": "54.60529",
    "lng": "-1.42191"
  },
  {
    "country": "GB",
    "name": "Stickney",
    "lat": "53.08949",
    "lng": "0.00545"
  },
  {
    "country": "GB",
    "name": "Steyning",
    "lat": "50.88744",
    "lng": "-0.32787"
  },
  {
    "country": "GB",
    "name": "Stewkley",
    "lat": "51.92744",
    "lng": "-0.76381"
  },
  {
    "country": "GB",
    "name": "Stewarton",
    "lat": "55.67986",
    "lng": "-4.51435"
  },
  {
    "country": "GB",
    "name": "Stevington",
    "lat": "52.16848",
    "lng": "-0.55515"
  },
  {
    "country": "GB",
    "name": "Steventon",
    "lat": "51.62473",
    "lng": "-1.32145"
  },
  {
    "country": "GB",
    "name": "Stevenston",
    "lat": "55.6397",
    "lng": "-4.75339"
  },
  {
    "country": "GB",
    "name": "Stevenage",
    "lat": "51.90224",
    "lng": "-0.20256"
  },
  {
    "country": "GB",
    "name": "Stepps",
    "lat": "55.88899",
    "lng": "-4.1521"
  },
  {
    "country": "GB",
    "name": "Steppingley",
    "lat": "52.00758",
    "lng": "-0.52855"
  },
  {
    "country": "GB",
    "name": "Steeton",
    "lat": "53.88333",
    "lng": "-1.95"
  },
  {
    "country": "GB",
    "name": "Steeple Claydon",
    "lat": "51.93643",
    "lng": "-0.98328"
  },
  {
    "country": "GB",
    "name": "Steeple Bumpstead",
    "lat": "52.04346",
    "lng": "0.44808"
  },
  {
    "country": "GB",
    "name": "Staveley",
    "lat": "54.37661",
    "lng": "-2.81791"
  },
  {
    "country": "GB",
    "name": "Staveley",
    "lat": "53.26667",
    "lng": "-1.35"
  },
  {
    "country": "GB",
    "name": "Startforth",
    "lat": "54.53851",
    "lng": "-1.93016"
  },
  {
    "country": "GB",
    "name": "Starcross",
    "lat": "50.62734",
    "lng": "-3.44797"
  },
  {
    "country": "GB",
    "name": "Staplehurst",
    "lat": "51.1611",
    "lng": "0.55249"
  },
  {
    "country": "GB",
    "name": "Stapleford",
    "lat": "51.11667",
    "lng": "-1.9"
  },
  {
    "country": "GB",
    "name": "Stanwick",
    "lat": "52.33198",
    "lng": "-0.56348"
  },
  {
    "country": "GB",
    "name": "Stansted Mountfitchet",
    "lat": "51.9",
    "lng": "0.2"
  },
  {
    "country": "GB",
    "name": "Stannington",
    "lat": "55.10862",
    "lng": "-1.66855"
  },
  {
    "country": "GB",
    "name": "Stanmore",
    "lat": "51.61667",
    "lng": "-0.31667"
  },
  {
    "country": "GB",
    "name": "Stanley",
    "lat": "56.4854",
    "lng": "-3.45184"
  },
  {
    "country": "GB",
    "name": "Stanhope",
    "lat": "54.75",
    "lng": "-2.01667"
  },
  {
    "country": "GB",
    "name": "Stanford-le-Hope",
    "lat": "51.52274",
    "lng": "0.43422"
  },
  {
    "country": "GB",
    "name": "Stanford in the Vale",
    "lat": "51.63969",
    "lng": "-1.50652"
  },
  {
    "country": "GB",
    "name": "Standon",
    "lat": "52.91667",
    "lng": "-2.28333"
  },
  {
    "country": "GB",
    "name": "Standlake",
    "lat": "51.7269",
    "lng": "-1.42436"
  },
  {
    "country": "GB",
    "name": "Stanbridge",
    "lat": "51.90864",
    "lng": "-0.59815"
  },
  {
    "country": "GB",
    "name": "Stamford Bridge",
    "lat": "53.9885",
    "lng": "-0.91547"
  },
  {
    "country": "GB",
    "name": "Stamford",
    "lat": "52.65",
    "lng": "-0.48333"
  },
  {
    "country": "GB",
    "name": "Stalybridge",
    "lat": "53.48414",
    "lng": "-2.05908"
  },
  {
    "country": "GB",
    "name": "Stallingborough",
    "lat": "53.58675",
    "lng": "-0.18489"
  },
  {
    "country": "GB",
    "name": "Stalham",
    "lat": "52.77079",
    "lng": "1.51783"
  },
  {
    "country": "GB",
    "name": "Stalbridge",
    "lat": "50.95807",
    "lng": "-2.37548"
  },
  {
    "country": "GB",
    "name": "Stainton",
    "lat": "53.43333",
    "lng": "-1.16667"
  },
  {
    "country": "GB",
    "name": "Stainforth",
    "lat": "53.6",
    "lng": "-1.03333"
  },
  {
    "country": "GB",
    "name": "Staines",
    "lat": "51.43092",
    "lng": "-0.50606"
  },
  {
    "country": "GB",
    "name": "Staindrop",
    "lat": "54.58102",
    "lng": "-1.80708"
  },
  {
    "country": "GB",
    "name": "Stainburn",
    "lat": "53.93333",
    "lng": "-1.61667"
  },
  {
    "country": "GB",
    "name": "Stainborough",
    "lat": "53.52623",
    "lng": "-1.518"
  },
  {
    "country": "GB",
    "name": "Stagsden",
    "lat": "52.13046",
    "lng": "-0.56678"
  },
  {
    "country": "GB",
    "name": "Stafford",
    "lat": "52.80521",
    "lng": "-2.11636"
  },
  {
    "country": "GB",
    "name": "Sproatley",
    "lat": "53.79379",
    "lng": "-0.1913"
  },
  {
    "country": "GB",
    "name": "Springside",
    "lat": "55.61514",
    "lng": "-4.59062"
  },
  {
    "country": "GB",
    "name": "Spratton",
    "lat": "52.32447",
    "lng": "-0.95386"
  },
  {
    "country": "GB",
    "name": "Spofforth",
    "lat": "53.95427",
    "lng": "-1.44848"
  },
  {
    "country": "GB",
    "name": "Spixworth",
    "lat": "52.68529",
    "lng": "1.32027"
  },
  {
    "country": "GB",
    "name": "Spittal",
    "lat": "51.86889",
    "lng": "-4.9425"
  },
  {
    "country": "GB",
    "name": "Spilsby",
    "lat": "53.17363",
    "lng": "0.09373"
  },
  {
    "country": "GB",
    "name": "Spennymoor",
    "lat": "54.6988",
    "lng": "-1.60229"
  },
  {
    "country": "GB",
    "name": "Speldhurst",
    "lat": "51.15076",
    "lng": "0.21947"
  },
  {
    "country": "GB",
    "name": "Spalding",
    "lat": "52.78709",
    "lng": "-0.15141"
  },
  {
    "country": "GB",
    "name": "Sowerby Bridge",
    "lat": "53.70903",
    "lng": "-1.90929"
  },
  {
    "country": "GB",
    "name": "Southwold",
    "lat": "52.32721",
    "lng": "1.68017"
  },
  {
    "country": "GB",
    "name": "South Witham",
    "lat": "52.76476",
    "lng": "-0.62811"
  },
  {
    "country": "GB",
    "name": "South Wingfield",
    "lat": "53.09593",
    "lng": "-1.43998"
  },
  {
    "country": "GB",
    "name": "Southwick",
    "lat": "51.29694",
    "lng": "-2.2325"
  },
  {
    "country": "GB",
    "name": "Southwell",
    "lat": "53.07804",
    "lng": "-0.95538"
  },
  {
    "country": "GB",
    "name": "Southwater",
    "lat": "51.02369",
    "lng": "-0.35173"
  },
  {
    "country": "GB",
    "name": "Tidworth",
    "lat": "51.23142",
    "lng": "-1.66324"
  },
  {
    "country": "GB",
    "name": "South Shields",
    "lat": "54.99859",
    "lng": "-1.4323"
  },
  {
    "country": "GB",
    "name": "Southsea",
    "lat": "50.79205",
    "lng": "-1.08593"
  },
  {
    "country": "GB",
    "name": "Southport",
    "lat": "53.64581",
    "lng": "-3.01008"
  },
  {
    "country": "GB",
    "name": "South Petherton",
    "lat": "50.94829",
    "lng": "-2.80708"
  },
  {
    "country": "GB",
    "name": "Southowram",
    "lat": "53.70988",
    "lng": "-1.83181"
  },
  {
    "country": "GB",
    "name": "Southorpe",
    "lat": "52.61055",
    "lng": "-0.40512"
  },
  {
    "country": "GB",
    "name": "South Ockendon",
    "lat": "51.50799",
    "lng": "0.28333"
  },
  {
    "country": "GB",
    "name": "South Nutfield",
    "lat": "51.01667",
    "lng": "-0.13333"
  },
  {
    "country": "GB",
    "name": "South Molton",
    "lat": "51.01667",
    "lng": "-3.83333"
  },
  {
    "country": "GB",
    "name": "Southminster",
    "lat": "51.66228",
    "lng": "0.82968"
  },
  {
    "country": "GB",
    "name": "South Milford",
    "lat": "53.77672",
    "lng": "-1.24609"
  },
  {
    "country": "GB",
    "name": "South Luffenham",
    "lat": "52.60857",
    "lng": "-0.61232"
  },
  {
    "country": "GB",
    "name": "South Littleton",
    "lat": "52.11416",
    "lng": "-1.89014"
  },
  {
    "country": "GB",
    "name": "Southill",
    "lat": "52.06431",
    "lng": "-0.32358"
  },
  {
    "country": "GB",
    "name": "South Hill",
    "lat": "50.53333",
    "lng": "-4.35"
  },
  {
    "country": "GB",
    "name": "South Hetton",
    "lat": "54.79906",
    "lng": "-1.40671"
  },
  {
    "country": "GB",
    "name": "South Hayling",
    "lat": "50.78773",
    "lng": "-0.97697"
  },
  {
    "country": "GB",
    "name": "South Harting",
    "lat": "50.96924",
    "lng": "-0.88388"
  },
  {
    "country": "GB",
    "name": "Southery",
    "lat": "52.52714",
    "lng": "0.38783"
  },
  {
    "country": "GB",
    "name": "Southend-on-Sea",
    "lat": "51.53782",
    "lng": "0.71433"
  },
  {
    "country": "GB",
    "name": "South Elmsall",
    "lat": "53.59709",
    "lng": "-1.28034"
  },
  {
    "country": "GB",
    "name": "South Collingham",
    "lat": "53.13333",
    "lng": "-0.76667"
  },
  {
    "country": "GB",
    "name": "South Cerney",
    "lat": "51.67319",
    "lng": "-1.93097"
  },
  {
    "country": "GB",
    "name": "South Cave",
    "lat": "53.76987",
    "lng": "-0.60107"
  },
  {
    "country": "GB",
    "name": "South Brent",
    "lat": "50.42654",
    "lng": "-3.83426"
  },
  {
    "country": "GB",
    "name": "South Benfleet",
    "lat": "51.55295",
    "lng": "0.55962"
  },
  {
    "country": "GB",
    "name": "South Bank",
    "lat": "54.56667",
    "lng": "-1.15"
  },
  {
    "country": "GB",
    "name": "Southampton",
    "lat": "50.90395",
    "lng": "-1.40428"
  },
  {
    "country": "GB",
    "name": "Southam",
    "lat": "52.25266",
    "lng": "-1.3884"
  },
  {
    "country": "GB",
    "name": "Southall",
    "lat": "51.50896",
    "lng": "-0.3713"
  },
  {
    "country": "GB",
    "name": "Sonning",
    "lat": "51.47411",
    "lng": "-0.91212"
  },
  {
    "country": "GB",
    "name": "Somerton",
    "lat": "51.95421",
    "lng": "-1.27613"
  },
  {
    "country": "GB",
    "name": "Somersham",
    "lat": "52.38333",
    "lng": "0"
  },
  {
    "country": "GB",
    "name": "Solihull",
    "lat": "52.41426",
    "lng": "-1.78094"
  },
  {
    "country": "GB",
    "name": "Soham",
    "lat": "52.33543",
    "lng": "0.33654"
  },
  {
    "country": "GB",
    "name": "Snodland",
    "lat": "51.32971",
    "lng": "0.44305"
  },
  {
    "country": "GB",
    "name": "Snettisham",
    "lat": "52.87882",
    "lng": "0.50099"
  },
  {
    "country": "GB",
    "name": "Snaith",
    "lat": "53.69112",
    "lng": "-1.02859"
  },
  {
    "country": "GB",
    "name": "Smethwick",
    "lat": "52.49268",
    "lng": "-1.96745"
  },
  {
    "country": "GB",
    "name": "Slough",
    "lat": "51.50949",
    "lng": "-0.59541"
  },
  {
    "country": "GB",
    "name": "Slinfold",
    "lat": "51.07209",
    "lng": "-0.40658"
  },
  {
    "country": "GB",
    "name": "Sleights",
    "lat": "54.45506",
    "lng": "-0.66484"
  },
  {
    "country": "GB",
    "name": "Sleaford",
    "lat": "52.99826",
    "lng": "-0.40941"
  },
  {
    "country": "GB",
    "name": "Slamannan",
    "lat": "55.93729",
    "lng": "-3.83311"
  },
  {
    "country": "GB",
    "name": "Slaley",
    "lat": "54.91368",
    "lng": "-2.03711"
  },
  {
    "country": "GB",
    "name": "Skipton",
    "lat": "53.96144",
    "lng": "-2.01676"
  },
  {
    "country": "GB",
    "name": "Skipsea",
    "lat": "53.97674",
    "lng": "-0.22084"
  },
  {
    "country": "GB",
    "name": "Skinningrove",
    "lat": "54.56908",
    "lng": "-0.89869"
  },
  {
    "country": "GB",
    "name": "Skidby",
    "lat": "53.78921",
    "lng": "-0.46131"
  },
  {
    "country": "GB",
    "name": "Skelton",
    "lat": "54.56062",
    "lng": "-0.98825"
  },
  {
    "country": "GB",
    "name": "Skelton",
    "lat": "54",
    "lng": "-1.13333"
  },
  {
    "country": "GB",
    "name": "Skelton",
    "lat": "53.72521",
    "lng": "-0.84187"
  },
  {
    "country": "GB",
    "name": "Skelmorlie",
    "lat": "55.8695",
    "lng": "-4.88475"
  },
  {
    "country": "GB",
    "name": "Skelmersdale",
    "lat": "53.55024",
    "lng": "-2.77348"
  },
  {
    "country": "GB",
    "name": "Skellingthorpe",
    "lat": "53.23531",
    "lng": "-0.61905"
  },
  {
    "country": "GB",
    "name": "Skegness",
    "lat": "53.14362",
    "lng": "0.3363"
  },
  {
    "country": "GB",
    "name": "Sittingbourne",
    "lat": "51.34128",
    "lng": "0.73282"
  },
  {
    "country": "GB",
    "name": "Siston",
    "lat": "51.47444",
    "lng": "-2.45"
  },
  {
    "country": "GB",
    "name": "Sissinghurst",
    "lat": "51.10905",
    "lng": "0.56"
  },
  {
    "country": "GB",
    "name": "Sion Mills",
    "lat": "54.78752",
    "lng": "-7.47276"
  },
  {
    "country": "GB",
    "name": "Simpson",
    "lat": "52.01667",
    "lng": "-0.7"
  },
  {
    "country": "GB",
    "name": "Silverton",
    "lat": "50.81667",
    "lng": "-3.48333"
  },
  {
    "country": "GB",
    "name": "Silverstone",
    "lat": "52.09216",
    "lng": "-1.02602"
  },
  {
    "country": "GB",
    "name": "Silverdale",
    "lat": "54.16667",
    "lng": "-2.81667"
  },
  {
    "country": "GB",
    "name": "Silsoe",
    "lat": "52.00854",
    "lng": "-0.42484"
  },
  {
    "country": "GB",
    "name": "Silsden",
    "lat": "53.91443",
    "lng": "-1.93802"
  },
  {
    "country": "GB",
    "name": "Silloth",
    "lat": "54.8687",
    "lng": "-3.38448"
  },
  {
    "country": "GB",
    "name": "Silkstone",
    "lat": "53.54808",
    "lng": "-1.56381"
  },
  {
    "country": "GB",
    "name": "Sileby",
    "lat": "52.73286",
    "lng": "-1.10773"
  },
  {
    "country": "GB",
    "name": "Sidmouth",
    "lat": "50.69094",
    "lng": "-3.2397"
  },
  {
    "country": "GB",
    "name": "Siddington",
    "lat": "53.23333",
    "lng": "-2.23333"
  },
  {
    "country": "GB",
    "name": "Sidcup",
    "lat": "51.42619",
    "lng": "0.1036"
  },
  {
    "country": "GB",
    "name": "Sibsey",
    "lat": "53.03858",
    "lng": "0.01579"
  },
  {
    "country": "GB",
    "name": "Sible Hedingham",
    "lat": "51.97772",
    "lng": "0.59262"
  },
  {
    "country": "GB",
    "name": "Shurdington",
    "lat": "51.86264",
    "lng": "-2.1206"
  },
  {
    "country": "GB",
    "name": "Shrivenham",
    "lat": "51.59853",
    "lng": "-1.65461"
  },
  {
    "country": "GB",
    "name": "Shrewton",
    "lat": "51.19194",
    "lng": "-1.90264"
  },
  {
    "country": "GB",
    "name": "Shrewsbury",
    "lat": "52.71009",
    "lng": "-2.75208"
  },
  {
    "country": "GB",
    "name": "Shotwick",
    "lat": "53.23938",
    "lng": "-2.99056"
  },
  {
    "country": "GB",
    "name": "Shotton",
    "lat": "54.78333",
    "lng": "-1.36667"
  },
  {
    "country": "GB",
    "name": "Shotley Gate",
    "lat": "51.95791",
    "lng": "1.26871"
  },
  {
    "country": "GB",
    "name": "Shoreham-by-Sea",
    "lat": "50.83413",
    "lng": "-0.27431"
  },
  {
    "country": "GB",
    "name": "Shirland",
    "lat": "53.12155",
    "lng": "-1.40464"
  },
  {
    "country": "GB",
    "name": "Shirebrook",
    "lat": "53.20333",
    "lng": "-1.21336"
  },
  {
    "country": "GB",
    "name": "Shipton under Wychwood",
    "lat": "51.86035",
    "lng": "-1.59847"
  },
  {
    "country": "GB",
    "name": "Shipston on Stour",
    "lat": "52.06057",
    "lng": "-1.62778"
  },
  {
    "country": "GB",
    "name": "Shipley",
    "lat": "53.83333",
    "lng": "-1.76667"
  },
  {
    "country": "GB",
    "name": "Shipham",
    "lat": "51.31428",
    "lng": "-2.8001"
  },
  {
    "country": "GB",
    "name": "Shipdham",
    "lat": "52.62923",
    "lng": "0.88577"
  },
  {
    "country": "GB",
    "name": "Shinfield",
    "lat": "51.40542",
    "lng": "-0.94534"
  },
  {
    "country": "GB",
    "name": "Shillington",
    "lat": "51.99344",
    "lng": "-0.36006"
  },
  {
    "country": "GB",
    "name": "Shillingstone",
    "lat": "50.89567",
    "lng": "-2.24495"
  },
  {
    "country": "GB",
    "name": "Shildon",
    "lat": "54.62997",
    "lng": "-1.64295"
  },
  {
    "country": "GB",
    "name": "Shilbottle",
    "lat": "55.37099",
    "lng": "-1.6882"
  },
  {
    "country": "GB",
    "name": "Shifnal",
    "lat": "52.67043",
    "lng": "-2.37248"
  },
  {
    "country": "GB",
    "name": "Shevington",
    "lat": "53.57236",
    "lng": "-2.69316"
  },
  {
    "country": "GB",
    "name": "Sherston",
    "lat": "51.57205",
    "lng": "-2.21278"
  },
  {
    "country": "GB",
    "name": "Sherington",
    "lat": "52.11172",
    "lng": "-0.69973"
  },
  {
    "country": "GB",
    "name": "Sheringham",
    "lat": "52.94078",
    "lng": "1.20931"
  },
  {
    "country": "GB",
    "name": "Sheriff Hutton",
    "lat": "54.08904",
    "lng": "-1.00639"
  },
  {
    "country": "GB",
    "name": "Sherburn in Elmet",
    "lat": "53.79519",
    "lng": "-1.2466"
  },
  {
    "country": "GB",
    "name": "Sherburn Hill",
    "lat": "54.7727",
    "lng": "-1.47985"
  },
  {
    "country": "GB",
    "name": "Sherburn",
    "lat": "54.77606",
    "lng": "-1.50474"
  },
  {
    "country": "GB",
    "name": "Sherborne St John",
    "lat": "51.29705",
    "lng": "-1.11387"
  },
  {
    "country": "GB",
    "name": "Sherborne",
    "lat": "50.94599",
    "lng": "-2.51776"
  },
  {
    "country": "GB",
    "name": "Shepton Mallet",
    "lat": "51.18972",
    "lng": "-2.54722"
  },
  {
    "country": "GB",
    "name": "Shepshed",
    "lat": "52.7657",
    "lng": "-1.29021"
  },
  {
    "country": "GB",
    "name": "Shepperton",
    "lat": "51.39546",
    "lng": "-0.44889"
  },
  {
    "country": "GB",
    "name": "Shepley",
    "lat": "53.58333",
    "lng": "-1.71667"
  },
  {
    "country": "GB",
    "name": "Shepherdswell",
    "lat": "51.18713",
    "lng": "1.23049"
  },
  {
    "country": "GB",
    "name": "Shenstone",
    "lat": "52.63802",
    "lng": "-1.84147"
  },
  {
    "country": "GB",
    "name": "Shenley Church End",
    "lat": "52.02522",
    "lng": "-0.78994"
  },
  {
    "country": "GB",
    "name": "Shenley",
    "lat": "51.69054",
    "lng": "-0.28067"
  },
  {
    "country": "GB",
    "name": "Shelley",
    "lat": "53.6",
    "lng": "-1.68333"
  },
  {
    "country": "GB",
    "name": "Shefford",
    "lat": "52.0387",
    "lng": "-0.33399"
  },
  {
    "country": "GB",
    "name": "Sheffield",
    "lat": "53.38297",
    "lng": "-1.4659"
  },
  {
    "country": "GB",
    "name": "Sheerness",
    "lat": "51.44042",
    "lng": "0.76252"
  },
  {
    "country": "GB",
    "name": "Shawbury",
    "lat": "52.79098",
    "lng": "-2.66183"
  },
  {
    "country": "GB",
    "name": "Shaw",
    "lat": "53.56667",
    "lng": "-2.08333"
  },
  {
    "country": "GB",
    "name": "Sharpness",
    "lat": "51.71972",
    "lng": "-2.4775"
  },
  {
    "country": "GB",
    "name": "Sharnbrook",
    "lat": "52.22606",
    "lng": "-0.54425"
  },
  {
    "country": "GB",
    "name": "Shap",
    "lat": "54.53149",
    "lng": "-2.67551"
  },
  {
    "country": "GB",
    "name": "Shanklin",
    "lat": "50.62613",
    "lng": "-1.1785"
  },
  {
    "country": "GB",
    "name": "Shalfleet",
    "lat": "50.70113",
    "lng": "-1.42007"
  },
  {
    "country": "GB",
    "name": "Shalbourne",
    "lat": "51.36358",
    "lng": "-1.55053"
  },
  {
    "country": "GB",
    "name": "Shafton",
    "lat": "53.59286",
    "lng": "-1.40925"
  },
  {
    "country": "GB",
    "name": "Shaftesbury",
    "lat": "51.00528",
    "lng": "-2.19333"
  },
  {
    "country": "GB",
    "name": "Shadoxhurst",
    "lat": "51.10797",
    "lng": "0.81917"
  },
  {
    "country": "GB",
    "name": "Seven Sisters",
    "lat": "51.76667",
    "lng": "-3.71667"
  },
  {
    "country": "GB",
    "name": "Sevenoaks",
    "lat": "51.27266",
    "lng": "0.18883"
  },
  {
    "country": "GB",
    "name": "Settle",
    "lat": "54.06865",
    "lng": "-2.2772"
  },
  {
    "country": "GB",
    "name": "Sennen",
    "lat": "50.07777",
    "lng": "-5.70117"
  },
  {
    "country": "GB",
    "name": "Send",
    "lat": "51.28875",
    "lng": "-0.52666"
  },
  {
    "country": "GB",
    "name": "Selsey",
    "lat": "50.73501",
    "lng": "-0.78979"
  },
  {
    "country": "GB",
    "name": "Sellack",
    "lat": "51.95",
    "lng": "-2.63333"
  },
  {
    "country": "GB",
    "name": "Selkirk",
    "lat": "55.54738",
    "lng": "-2.83911"
  },
  {
    "country": "GB",
    "name": "Selby",
    "lat": "53.78333",
    "lng": "-1.06667"
  },
  {
    "country": "GB",
    "name": "Seghill",
    "lat": "55.06225",
    "lng": "-1.55027"
  },
  {
    "country": "GB",
    "name": "Seend",
    "lat": "51.34806",
    "lng": "-2.08472"
  },
  {
    "country": "GB",
    "name": "Sedgefield",
    "lat": "54.65329",
    "lng": "-1.44952"
  },
  {
    "country": "GB",
    "name": "Sedbergh",
    "lat": "54.32123",
    "lng": "-2.52514"
  },
  {
    "country": "GB",
    "name": "Seaview",
    "lat": "50.71956",
    "lng": "-1.11164"
  },
  {
    "country": "GB",
    "name": "Seaton Delaval",
    "lat": "55.07196",
    "lng": "-1.52609"
  },
  {
    "country": "GB",
    "name": "Seaton",
    "lat": "52.57489",
    "lng": "-0.66759"
  },
  {
    "country": "GB",
    "name": "Seascale",
    "lat": "54.39831",
    "lng": "-3.47961"
  },
  {
    "country": "GB",
    "name": "Seahouses",
    "lat": "55.58063",
    "lng": "-1.65497"
  },
  {
    "country": "GB",
    "name": "Seaham",
    "lat": "54.83903",
    "lng": "-1.34575"
  },
  {
    "country": "GB",
    "name": "Seaford",
    "lat": "50.77141",
    "lng": "0.10268"
  },
  {
    "country": "GB",
    "name": "Scunthorpe",
    "lat": "53.57905",
    "lng": "-0.65437"
  },
  {
    "country": "GB",
    "name": "Scotter",
    "lat": "53.49652",
    "lng": "-0.67429"
  },
  {
    "country": "GB",
    "name": "Scotby",
    "lat": "54.89004",
    "lng": "-2.87464"
  },
  {
    "country": "GB",
    "name": "Scorton",
    "lat": "54.39785",
    "lng": "-1.61276"
  },
  {
    "country": "GB",
    "name": "Scole",
    "lat": "52.36706",
    "lng": "1.15674"
  },
  {
    "country": "GB",
    "name": "Scholes",
    "lat": "53.82346",
    "lng": "-1.42805"
  },
  {
    "country": "GB",
    "name": "Scawby",
    "lat": "53.53787",
    "lng": "-0.54085"
  },
  {
    "country": "GB",
    "name": "Scarcroft",
    "lat": "53.86667",
    "lng": "-1.45"
  },
  {
    "country": "GB",
    "name": "Scarborough",
    "lat": "54.27966",
    "lng": "-0.40443"
  },
  {
    "country": "GB",
    "name": "Scalloway",
    "lat": "60.13832",
    "lng": "-1.2769"
  },
  {
    "country": "GB",
    "name": "Scalby",
    "lat": "53.76667",
    "lng": "-0.71667"
  },
  {
    "country": "GB",
    "name": "Saxmundham",
    "lat": "52.21497",
    "lng": "1.48805"
  },
  {
    "country": "GB",
    "name": "Saxilby",
    "lat": "53.26746",
    "lng": "-0.66253"
  },
  {
    "country": "GB",
    "name": "Sawtry",
    "lat": "52.43984",
    "lng": "-0.28422"
  },
  {
    "country": "GB",
    "name": "Sawston",
    "lat": "52.12089",
    "lng": "0.16943"
  },
  {
    "country": "GB",
    "name": "Sawbridgeworth",
    "lat": "51.81667",
    "lng": "0.15"
  },
  {
    "country": "GB",
    "name": "Saundersfoot",
    "lat": "51.70945",
    "lng": "-4.70215"
  },
  {
    "country": "GB",
    "name": "Saughall",
    "lat": "53.22618",
    "lng": "-2.95649"
  },
  {
    "country": "GB",
    "name": "Sapcote",
    "lat": "52.53707",
    "lng": "-1.279"
  },
  {
    "country": "GB",
    "name": "Sanquhar",
    "lat": "55.36527",
    "lng": "-3.9216"
  },
  {
    "country": "GB",
    "name": "Sandy",
    "lat": "52.12927",
    "lng": "-0.28925"
  },
  {
    "country": "GB",
    "name": "Sandwick",
    "lat": "60",
    "lng": "-1.25"
  },
  {
    "country": "GB",
    "name": "Sandwich",
    "lat": "51.27223",
    "lng": "1.33776"
  },
  {
    "country": "GB",
    "name": "Sandown",
    "lat": "50.65158",
    "lng": "-1.16103"
  },
  {
    "country": "GB",
    "name": "Sandhurst",
    "lat": "51.34675",
    "lng": "-0.78655"
  },
  {
    "country": "GB",
    "name": "Sandford",
    "lat": "51.33228",
    "lng": "-2.83122"
  },
  {
    "country": "GB",
    "name": "Sandbank",
    "lat": "55.98203",
    "lng": "-4.94973"
  },
  {
    "country": "GB",
    "name": "Sandbach",
    "lat": "53.14515",
    "lng": "-2.36251"
  },
  {
    "country": "GB",
    "name": "Sampford Peverell",
    "lat": "50.91945",
    "lng": "-3.38081"
  },
  {
    "country": "GB",
    "name": "Saltford",
    "lat": "51.40139",
    "lng": "-2.45944"
  },
  {
    "country": "GB",
    "name": "Saltcoats",
    "lat": "55.63616",
    "lng": "-4.78588"
  },
  {
    "country": "GB",
    "name": "Saltburn-by-the-Sea",
    "lat": "54.58237",
    "lng": "-0.97367"
  },
  {
    "country": "GB",
    "name": "Saltash",
    "lat": "50.40959",
    "lng": "-4.22514"
  },
  {
    "country": "GB",
    "name": "Salisbury",
    "lat": "51.06931",
    "lng": "-1.79569"
  },
  {
    "country": "GB",
    "name": "Saline",
    "lat": "56.11399",
    "lng": "-3.57034"
  },
  {
    "country": "GB",
    "name": "Salfords",
    "lat": "51.2043",
    "lng": "-0.16947"
  },
  {
    "country": "GB",
    "name": "Salford",
    "lat": "53.48771",
    "lng": "-2.29042"
  },
  {
    "country": "GB",
    "name": "Sale",
    "lat": "53.42519",
    "lng": "-2.32443"
  },
  {
    "country": "GB",
    "name": "Salcombe",
    "lat": "50.23743",
    "lng": "-3.76874"
  },
  {
    "country": "GB",
    "name": "Saint Stephen",
    "lat": "50.34469",
    "lng": "-4.89973"
  },
  {
    "country": "GB",
    "name": "Saint Peters",
    "lat": "51.36667",
    "lng": "1.41667"
  },
  {
    "country": "GB",
    "name": "Saint Osyth",
    "lat": "51.8",
    "lng": "1.08333"
  },
  {
    "country": "GB",
    "name": "Saint Neots",
    "lat": "52.21667",
    "lng": "-0.26667"
  },
  {
    "country": "GB",
    "name": "Saint Monans",
    "lat": "56.20651",
    "lng": "-2.76821"
  },
  {
    "country": "GB",
    "name": "Saint Leonards-on-Sea",
    "lat": "50.85565",
    "lng": "0.5452"
  },
  {
    "country": "GB",
    "name": "St Leonards",
    "lat": "50.83077",
    "lng": "-1.84377"
  },
  {
    "country": "GB",
    "name": "St Ives",
    "lat": "50.20861",
    "lng": "-5.4875"
  },
  {
    "country": "GB",
    "name": "St Helens",
    "lat": "53.45",
    "lng": "-2.73333"
  },
  {
    "country": "GB",
    "name": "St. Helens",
    "lat": "50.69688",
    "lng": "-1.11159"
  },
  {
    "country": "GB",
    "name": "Saintfield",
    "lat": "54.46046",
    "lng": "-5.83065"
  },
  {
    "country": "GB",
    "name": "Saint Dennis",
    "lat": "50.38333",
    "lng": "-4.88333"
  },
  {
    "country": "GB",
    "name": "St. Day",
    "lat": "50.23958",
    "lng": "-5.18572"
  },
  {
    "country": "GB",
    "name": "Saint Davids",
    "lat": "51.88094",
    "lng": "-5.26554"
  },
  {
    "country": "GB",
    "name": "Saint Cyrus",
    "lat": "56.77504",
    "lng": "-2.41553"
  },
  {
    "country": "GB",
    "name": "Saint Columb Major",
    "lat": "50.43163",
    "lng": "-4.94336"
  },
  {
    "country": "GB",
    "name": "Saint Clears",
    "lat": "51.81989",
    "lng": "-4.49783"
  },
  {
    "country": "GB",
    "name": "Saint Boswells",
    "lat": "55.57301",
    "lng": "-2.6441"
  },
  {
    "country": "GB",
    "name": "Saint Bees",
    "lat": "54.49183",
    "lng": "-3.58987"
  },
  {
    "country": "GB",
    "name": "St Austell",
    "lat": "50.3425",
    "lng": "-4.77442"
  },
  {
    "country": "GB",
    "name": "Saint Asaph",
    "lat": "53.25815",
    "lng": "-3.44524"
  },
  {
    "country": "GB",
    "name": "Saint Andrews",
    "lat": "56.33871",
    "lng": "-2.79902"
  },
  {
    "country": "GB",
    "name": "St Albans",
    "lat": "51.75",
    "lng": "-0.33333"
  },
  {
    "country": "GB",
    "name": "Saint Agnes",
    "lat": "50.31278",
    "lng": "-5.20456"
  },
  {
    "country": "GB",
    "name": "Saffron Walden",
    "lat": "52.02337",
    "lng": "0.24234"
  },
  {
    "country": "GB",
    "name": "Sacriston",
    "lat": "54.81769",
    "lng": "-1.6241"
  },
  {
    "country": "GB",
    "name": "Sabden",
    "lat": "53.83355",
    "lng": "-2.33728"
  },
  {
    "country": "GB",
    "name": "Ryton on Dunsmore",
    "lat": "52.36667",
    "lng": "-1.43333"
  },
  {
    "country": "GB",
    "name": "Ryton",
    "lat": "52.61667",
    "lng": "-2.35"
  },
  {
    "country": "GB",
    "name": "Ryhope",
    "lat": "54.87139",
    "lng": "-1.37"
  },
  {
    "country": "GB",
    "name": "Ryhill",
    "lat": "53.62204",
    "lng": "-1.41071"
  },
  {
    "country": "GB",
    "name": "Ryhall",
    "lat": "52.68585",
    "lng": "-0.46846"
  },
  {
    "country": "GB",
    "name": "Rye",
    "lat": "50.95114",
    "lng": "0.7337"
  },
  {
    "country": "GB",
    "name": "Ryde",
    "lat": "50.72999",
    "lng": "-1.1621"
  },
  {
    "country": "GB",
    "name": "Ruyton-XI-Towns",
    "lat": "52.79555",
    "lng": "-2.90318"
  },
  {
    "country": "GB",
    "name": "Ruthin",
    "lat": "53.11368",
    "lng": "-3.31782"
  },
  {
    "country": "GB",
    "name": "Rutherglen",
    "lat": "55.82885",
    "lng": "-4.21376"
  },
  {
    "country": "GB",
    "name": "Rustington",
    "lat": "50.81027",
    "lng": "-0.50674"
  },
  {
    "country": "GB",
    "name": "Ruskington",
    "lat": "53.04544",
    "lng": "-0.38692"
  },
  {
    "country": "GB",
    "name": "Rushden",
    "lat": "52.28927",
    "lng": "-0.60184"
  },
  {
    "country": "GB",
    "name": "Rushall",
    "lat": "51.28333",
    "lng": "-1.81667"
  },
  {
    "country": "GB",
    "name": "Runcorn",
    "lat": "53.34174",
    "lng": "-2.73124"
  },
  {
    "country": "GB",
    "name": "Ruislip",
    "lat": "51.57344",
    "lng": "-0.42341"
  },
  {
    "country": "GB",
    "name": "Rugeley",
    "lat": "52.7593",
    "lng": "-1.93694"
  },
  {
    "country": "GB",
    "name": "Rugby",
    "lat": "52.37092",
    "lng": "-1.26417"
  },
  {
    "country": "GB",
    "name": "Rufford",
    "lat": "53.63375",
    "lng": "-2.81662"
  },
  {
    "country": "GB",
    "name": "Rudgwick",
    "lat": "51.08735",
    "lng": "-0.45164"
  },
  {
    "country": "GB",
    "name": "Ruddington",
    "lat": "52.89254",
    "lng": "-1.14953"
  },
  {
    "country": "GB",
    "name": "Ruabon",
    "lat": "52.9878",
    "lng": "-3.03883"
  },
  {
    "country": "GB",
    "name": "Royton",
    "lat": "53.56507",
    "lng": "-2.12267"
  },
  {
    "country": "GB",
    "name": "Royston",
    "lat": "53.6",
    "lng": "-1.45"
  },
  {
    "country": "GB",
    "name": "Royston",
    "lat": "52.04832",
    "lng": "-0.02438"
  },
  {
    "country": "GB",
    "name": "Roydon",
    "lat": "51.7718",
    "lng": "0.0403"
  },
  {
    "country": "GB",
    "name": "Royal Tunbridge Wells",
    "lat": "51.13321",
    "lng": "0.26256"
  },
  {
    "country": "GB",
    "name": "Roxton",
    "lat": "52.17756",
    "lng": "-0.31594"
  },
  {
    "country": "GB",
    "name": "Rowlstone",
    "lat": "51.93333",
    "lng": "-2.91667"
  },
  {
    "country": "GB",
    "name": "Rowley Regis",
    "lat": "52.48292",
    "lng": "-2.04376"
  },
  {
    "country": "GB",
    "name": "Rowlands Gill",
    "lat": "54.91922",
    "lng": "-1.74489"
  },
  {
    "country": "GB",
    "name": "Rowhedge",
    "lat": "51.85738",
    "lng": "0.94534"
  },
  {
    "country": "GB",
    "name": "Rowde",
    "lat": "51.36325",
    "lng": "-2.03098"
  },
  {
    "country": "GB",
    "name": "Rottingdean",
    "lat": "50.80984",
    "lng": "-0.05939"
  },
  {
    "country": "GB",
    "name": "Rothwell",
    "lat": "52.41667",
    "lng": "-0.8"
  },
  {
    "country": "GB",
    "name": "Rothley",
    "lat": "55.18333",
    "lng": "-1.91667"
  },
  {
    "country": "GB",
    "name": "Rothley",
    "lat": "52.70916",
    "lng": "-1.13739"
  },
  {
    "country": "GB",
    "name": "Rothienorman",
    "lat": "57.41145",
    "lng": "-2.46455"
  },
  {
    "country": "GB",
    "name": "Rothesay",
    "lat": "55.83648",
    "lng": "-5.05508"
  },
  {
    "country": "GB",
    "name": "Rothes",
    "lat": "57.52624",
    "lng": "-3.20663"
  },
  {
    "country": "GB",
    "name": "Rotherham",
    "lat": "53.43012",
    "lng": "-1.35678"
  },
  {
    "country": "GB",
    "name": "Rotherfield Peppard",
    "lat": "51.53064",
    "lng": "-0.97847"
  },
  {
    "country": "GB",
    "name": "Rothbury",
    "lat": "55.31059",
    "lng": "-1.90845"
  },
  {
    "country": "GB",
    "name": "Rosyth",
    "lat": "56.03689",
    "lng": "-3.438"
  },
  {
    "country": "GB",
    "name": "Rostrevor",
    "lat": "54.1",
    "lng": "-6.2"
  },
  {
    "country": "GB",
    "name": "Ross on Wye",
    "lat": "51.91667",
    "lng": "-2.56667"
  },
  {
    "country": "GB",
    "name": "Rossington",
    "lat": "53.47931",
    "lng": "-1.0619"
  },
  {
    "country": "GB",
    "name": "Rossett",
    "lat": "53.10921",
    "lng": "-2.94478"
  },
  {
    "country": "GB",
    "name": "Rosneath",
    "lat": "56.00985",
    "lng": "-4.80151"
  },
  {
    "country": "GB",
    "name": "Rosehearty",
    "lat": "57.697",
    "lng": "-2.11322"
  },
  {
    "country": "GB",
    "name": "Roos",
    "lat": "53.75292",
    "lng": "-0.04463"
  },
  {
    "country": "GB",
    "name": "Romsley",
    "lat": "52.45",
    "lng": "-2.31667"
  },
  {
    "country": "GB",
    "name": "Romsley",
    "lat": "52.41996",
    "lng": "-2.05695"
  },
  {
    "country": "GB",
    "name": "Romsey",
    "lat": "50.98906",
    "lng": "-1.49989"
  },
  {
    "country": "GB",
    "name": "Romford",
    "lat": "51.57515",
    "lng": "0.18582"
  },
  {
    "country": "GB",
    "name": "Romaldkirk",
    "lat": "54.5944",
    "lng": "-2.01058"
  },
  {
    "country": "GB",
    "name": "Rokeby",
    "lat": "54.51667",
    "lng": "-1.86667"
  },
  {
    "country": "GB",
    "name": "Rode Heath",
    "lat": "53.11387",
    "lng": "-2.29186"
  },
  {
    "country": "GB",
    "name": "Rode",
    "lat": "51.2839",
    "lng": "-2.28141"
  },
  {
    "country": "GB",
    "name": "Rochford",
    "lat": "51.58198",
    "lng": "0.70673"
  },
  {
    "country": "GB",
    "name": "Rochester",
    "lat": "55.2752",
    "lng": "-2.2649"
  },
  {
    "country": "GB",
    "name": "Rochester",
    "lat": "51.38764",
    "lng": "0.50546"
  },
  {
    "country": "GB",
    "name": "Roche",
    "lat": "50.40808",
    "lng": "-4.83373"
  },
  {
    "country": "GB",
    "name": "Rochdale",
    "lat": "53.61766",
    "lng": "-2.1552"
  },
  {
    "country": "GB",
    "name": "Robertsbridge",
    "lat": "50.98569",
    "lng": "0.47253"
  },
  {
    "country": "GB",
    "name": "Roade",
    "lat": "52.15824",
    "lng": "-0.89745"
  },
  {
    "country": "GB",
    "name": "Rishton",
    "lat": "53.76806",
    "lng": "-2.41444"
  },
  {
    "country": "GB",
    "name": "Riseley",
    "lat": "52.25213",
    "lng": "-0.47928"
  },
  {
    "country": "GB",
    "name": "Risca",
    "lat": "51.60799",
    "lng": "-3.10081"
  },
  {
    "country": "GB",
    "name": "Ripponden",
    "lat": "53.67449",
    "lng": "-1.94183"
  },
  {
    "country": "GB",
    "name": "Ripon",
    "lat": "54.13579",
    "lng": "-1.52826"
  },
  {
    "country": "GB",
    "name": "Ripley",
    "lat": "53.03333",
    "lng": "-1.4"
  },
  {
    "country": "GB",
    "name": "Ripley",
    "lat": "51.29907",
    "lng": "-0.49164"
  },
  {
    "country": "GB",
    "name": "Ringwood",
    "lat": "50.84541",
    "lng": "-1.78871"
  },
  {
    "country": "GB",
    "name": "Ringway",
    "lat": "53.35",
    "lng": "-2.28333"
  },
  {
    "country": "GB",
    "name": "Ringstead",
    "lat": "52.36528",
    "lng": "-0.5549"
  },
  {
    "country": "GB",
    "name": "Ringmer",
    "lat": "50.89264",
    "lng": "0.05472"
  },
  {
    "country": "GB",
    "name": "Rimswell",
    "lat": "53.74079",
    "lng": "-0.01742"
  },
  {
    "country": "GB",
    "name": "Rillington",
    "lat": "54.15779",
    "lng": "-0.69494"
  },
  {
    "country": "GB",
    "name": "Ridlington",
    "lat": "52.61337",
    "lng": "-0.756"
  },
  {
    "country": "GB",
    "name": "Ridgmont",
    "lat": "52.01532",
    "lng": "-0.57871"
  },
  {
    "country": "GB",
    "name": "Rickmansworth",
    "lat": "51.63898",
    "lng": "-0.47718"
  },
  {
    "country": "GB",
    "name": "Rickinghall",
    "lat": "52.33649",
    "lng": "0.99272"
  },
  {
    "country": "GB",
    "name": "Richmond",
    "lat": "54.4036",
    "lng": "-1.73434"
  },
  {
    "country": "GB",
    "name": "Richmond",
    "lat": "51.46171",
    "lng": "-0.30633"
  },
  {
    "country": "GB",
    "name": "Riccall",
    "lat": "53.83331",
    "lng": "-1.0573"
  },
  {
    "country": "GB",
    "name": "Rhymney",
    "lat": "51.75998",
    "lng": "-3.28553"
  },
  {
    "country": "GB",
    "name": "Rhyl",
    "lat": "53.31929",
    "lng": "-3.49228"
  },
  {
    "country": "GB",
    "name": "Rhuddlan",
    "lat": "53.29203",
    "lng": "-3.46996"
  },
  {
    "country": "GB",
    "name": "Rhu",
    "lat": "56.01667",
    "lng": "-4.76667"
  },
  {
    "country": "GB",
    "name": "Rhosneigr",
    "lat": "53.23186",
    "lng": "-4.5148"
  },
  {
    "country": "GB",
    "name": "Rhosllanerchrugog",
    "lat": "53.00974",
    "lng": "-3.05814"
  },
  {
    "country": "GB",
    "name": "Rhoose",
    "lat": "51.38818",
    "lng": "-3.3543"
  },
  {
    "country": "GB",
    "name": "Rhondda",
    "lat": "51.65896",
    "lng": "-3.44885"
  },
  {
    "country": "GB",
    "name": "Rhayader",
    "lat": "52.30154",
    "lng": "-3.51146"
  },
  {
    "country": "GB",
    "name": "Resolven",
    "lat": "51.71193",
    "lng": "-3.69745"
  },
  {
    "country": "GB",
    "name": "Repton",
    "lat": "52.83983",
    "lng": "-1.55061"
  },
  {
    "country": "GB",
    "name": "Renton",
    "lat": "55.972",
    "lng": "-4.58399"
  },
  {
    "country": "GB",
    "name": "Renfrew",
    "lat": "55.87197",
    "lng": "-4.39253"
  },
  {
    "country": "GB",
    "name": "Rendlesham",
    "lat": "52.12665",
    "lng": "1.41536"
  },
  {
    "country": "GB",
    "name": "Remenham",
    "lat": "51.55189",
    "lng": "-0.89084"
  },
  {
    "country": "GB",
    "name": "Reigate",
    "lat": "51.23736",
    "lng": "-0.20582"
  },
  {
    "country": "GB",
    "name": "Reepham",
    "lat": "53.23333",
    "lng": "-0.43333"
  },
  {
    "country": "GB",
    "name": "Reepham",
    "lat": "52.7632",
    "lng": "1.11099"
  },
  {
    "country": "GB",
    "name": "Reedham",
    "lat": "52.56054",
    "lng": "1.57122"
  },
  {
    "country": "GB",
    "name": "Redwick",
    "lat": "51.55278",
    "lng": "-2.85"
  },
  {
    "country": "GB",
    "name": "Redruth",
    "lat": "50.23315",
    "lng": "-5.22434"
  },
  {
    "country": "GB",
    "name": "Redlynch",
    "lat": "51.09861",
    "lng": "-2.42667"
  },
  {
    "country": "GB",
    "name": "Redhill",
    "lat": "51.24048",
    "lng": "-0.17044"
  },
  {
    "country": "GB",
    "name": "Redditch",
    "lat": "52.3065",
    "lng": "-1.94569"
  },
  {
    "country": "GB",
    "name": "Redcar",
    "lat": "54.61657",
    "lng": "-1.05999"
  },
  {
    "country": "GB",
    "name": "Redbourne",
    "lat": "53.48728",
    "lng": "-0.53567"
  },
  {
    "country": "GB",
    "name": "Redbourn",
    "lat": "51.79896",
    "lng": "-0.39594"
  },
  {
    "country": "GB",
    "name": "Reading",
    "lat": "51.45625",
    "lng": "-0.97113"
  },
  {
    "country": "GB",
    "name": "Rayne",
    "lat": "51.86667",
    "lng": "0.58333"
  },
  {
    "country": "GB",
    "name": "Rayleigh",
    "lat": "51.58571",
    "lng": "0.60459"
  },
  {
    "country": "GB",
    "name": "Rawtenstall",
    "lat": "53.70076",
    "lng": "-2.28442"
  },
  {
    "country": "GB",
    "name": "Rawmarsh",
    "lat": "53.46062",
    "lng": "-1.34437"
  },
  {
    "country": "GB",
    "name": "Rawcliffe",
    "lat": "53.69777",
    "lng": "-0.96319"
  },
  {
    "country": "GB",
    "name": "Ravenstone",
    "lat": "52.72111",
    "lng": "-1.40582"
  },
  {
    "country": "GB",
    "name": "Ravenstone",
    "lat": "52.14934",
    "lng": "-0.75874"
  },
  {
    "country": "GB",
    "name": "Raunds",
    "lat": "52.34428",
    "lng": "-0.53657"
  },
  {
    "country": "GB",
    "name": "Ratho",
    "lat": "55.92164",
    "lng": "-3.38028"
  },
  {
    "country": "GB",
    "name": "Rathfriland",
    "lat": "54.25",
    "lng": "-6.16667"
  },
  {
    "country": "GB",
    "name": "Ranskill",
    "lat": "53.38281",
    "lng": "-1.01402"
  },
  {
    "country": "GB",
    "name": "Randalstown",
    "lat": "54.75",
    "lng": "-6.3"
  },
  {
    "country": "GB",
    "name": "Ramsgate",
    "lat": "51.33568",
    "lng": "1.41797"
  },
  {
    "country": "GB",
    "name": "Ramsey",
    "lat": "52.45058",
    "lng": "-0.10932"
  },
  {
    "country": "GB",
    "name": "Ramsbury",
    "lat": "51.44373",
    "lng": "-1.60257"
  },
  {
    "country": "GB",
    "name": "Ramsbottom",
    "lat": "53.64789",
    "lng": "-2.31683"
  },
  {
    "country": "GB",
    "name": "Rainworth",
    "lat": "53.11883",
    "lng": "-1.11852"
  },
  {
    "country": "GB",
    "name": "Rainham",
    "lat": "51.36323",
    "lng": "0.60893"
  },
  {
    "country": "GB",
    "name": "Rainford",
    "lat": "53.50223",
    "lng": "-2.78839"
  },
  {
    "country": "GB",
    "name": "Raglan",
    "lat": "51.765",
    "lng": "-2.85331"
  },
  {
    "country": "GB",
    "name": "Radyr",
    "lat": "51.51864",
    "lng": "-3.25829"
  },
  {
    "country": "GB",
    "name": "Radstock",
    "lat": "51.28862",
    "lng": "-2.46003"
  },
  {
    "country": "GB",
    "name": "Radley",
    "lat": "51.68746",
    "lng": "-1.24025"
  },
  {
    "country": "GB",
    "name": "Radlett",
    "lat": "51.68593",
    "lng": "-0.31868"
  },
  {
    "country": "GB",
    "name": "Radcliffe on Trent",
    "lat": "52.94802",
    "lng": "-1.03855"
  },
  {
    "country": "GB",
    "name": "Rackheath",
    "lat": "52.66254",
    "lng": "1.38032"
  },
  {
    "country": "GB",
    "name": "Quorndon",
    "lat": "52.74461",
    "lng": "-1.17348"
  },
  {
    "country": "GB",
    "name": "Queniborough",
    "lat": "52.70591",
    "lng": "-1.04749"
  },
  {
    "country": "GB",
    "name": "Queensferry",
    "lat": "55.99089",
    "lng": "-3.39847"
  },
  {
    "country": "GB",
    "name": "Queensferry",
    "lat": "53.2",
    "lng": "-3.03333"
  },
  {
    "country": "GB",
    "name": "Queensbury",
    "lat": "53.76667",
    "lng": "-1.91667"
  },
  {
    "country": "GB",
    "name": "Queenborough",
    "lat": "51.4176",
    "lng": "0.74441"
  },
  {
    "country": "GB",
    "name": "Pyle",
    "lat": "51.51667",
    "lng": "-3.7"
  },
  {
    "country": "GB",
    "name": "Pwllheli",
    "lat": "52.8899",
    "lng": "-4.41451"
  },
  {
    "country": "GB",
    "name": "Purton",
    "lat": "51.58889",
    "lng": "-1.87419"
  },
  {
    "country": "GB",
    "name": "Purley",
    "lat": "51.33678",
    "lng": "-0.11201"
  },
  {
    "country": "GB",
    "name": "Puriton",
    "lat": "51.16933",
    "lng": "-2.97198"
  },
  {
    "country": "GB",
    "name": "Purfleet",
    "lat": "51.4839",
    "lng": "0.24247"
  },
  {
    "country": "GB",
    "name": "Pulloxhill",
    "lat": "51.99487",
    "lng": "-0.45316"
  },
  {
    "country": "GB",
    "name": "Pulborough",
    "lat": "50.95753",
    "lng": "-0.5128"
  },
  {
    "country": "GB",
    "name": "Pudsey",
    "lat": "53.79538",
    "lng": "-1.66134"
  },
  {
    "country": "GB",
    "name": "Puddletown",
    "lat": "50.75",
    "lng": "-2.35"
  },
  {
    "country": "GB",
    "name": "Puckeridge",
    "lat": "51.89013",
    "lng": "0.01309"
  },
  {
    "country": "GB",
    "name": "Publow",
    "lat": "51.37877",
    "lng": "-2.54351"
  },
  {
    "country": "GB",
    "name": "Prudhoe",
    "lat": "54.96154",
    "lng": "-1.85168"
  },
  {
    "country": "GB",
    "name": "Probus",
    "lat": "50.29267",
    "lng": "-4.95401"
  },
  {
    "country": "GB",
    "name": "Priston",
    "lat": "51.34306",
    "lng": "-2.43917"
  },
  {
    "country": "GB",
    "name": "Princetown",
    "lat": "50.54393",
    "lng": "-3.98855"
  },
  {
    "country": "GB",
    "name": "Princes Risborough",
    "lat": "51.72549",
    "lng": "-0.83144"
  },
  {
    "country": "GB",
    "name": "Prestwick",
    "lat": "55.48333",
    "lng": "-4.61667"
  },
  {
    "country": "GB",
    "name": "Prestwich",
    "lat": "53.53333",
    "lng": "-2.28333"
  },
  {
    "country": "GB",
    "name": "Prestonpans",
    "lat": "55.95939",
    "lng": "-2.98038"
  },
  {
    "country": "GB",
    "name": "Preston",
    "lat": "53.76282",
    "lng": "-2.70452"
  },
  {
    "country": "GB",
    "name": "Preston",
    "lat": "53.75663",
    "lng": "-0.19775"
  },
  {
    "country": "GB",
    "name": "Preston",
    "lat": "52.61264",
    "lng": "-0.71437"
  },
  {
    "country": "GB",
    "name": "Presteigne",
    "lat": "52.27183",
    "lng": "-3.00579"
  },
  {
    "country": "GB",
    "name": "Prestbury",
    "lat": "53.28333",
    "lng": "-2.15"
  },
  {
    "country": "GB",
    "name": "Prestatyn",
    "lat": "53.33748",
    "lng": "-3.40776"
  },
  {
    "country": "GB",
    "name": "Prescot",
    "lat": "53.42948",
    "lng": "-2.80031"
  },
  {
    "country": "GB",
    "name": "Preesall",
    "lat": "53.9182",
    "lng": "-2.96633"
  },
  {
    "country": "GB",
    "name": "Prees",
    "lat": "52.89689",
    "lng": "-2.66401"
  },
  {
    "country": "GB",
    "name": "Poynton",
    "lat": "53.35",
    "lng": "-2.11667"
  },
  {
    "country": "GB",
    "name": "Poundstock",
    "lat": "50.76667",
    "lng": "-4.55"
  },
  {
    "country": "GB",
    "name": "Poulton-le-Fylde",
    "lat": "53.83333",
    "lng": "-2.98333"
  },
  {
    "country": "GB",
    "name": "Pott Shrigley",
    "lat": "53.30957",
    "lng": "-2.08405"
  },
  {
    "country": "GB",
    "name": "Potton",
    "lat": "52.12911",
    "lng": "-0.21561"
  },
  {
    "country": "GB",
    "name": "Potterspury",
    "lat": "52.08288",
    "lng": "-0.89676"
  },
  {
    "country": "GB",
    "name": "Potters Bar",
    "lat": "51.69353",
    "lng": "-0.17835"
  },
  {
    "country": "GB",
    "name": "Potterne",
    "lat": "51.32917",
    "lng": "-2.00519"
  },
  {
    "country": "GB",
    "name": "Potsgrove",
    "lat": "51.95939",
    "lng": "-0.61755"
  },
  {
    "country": "GB",
    "name": "Port Talbot",
    "lat": "51.59241",
    "lng": "-3.78019"
  },
  {
    "country": "GB",
    "name": "Portstewart",
    "lat": "55.18132",
    "lng": "-6.71402"
  },
  {
    "country": "GB",
    "name": "Portsoy",
    "lat": "57.68144",
    "lng": "-2.68956"
  },
  {
    "country": "GB",
    "name": "Portsmouth",
    "lat": "50.79899",
    "lng": "-1.09125"
  },
  {
    "country": "GB",
    "name": "Portslade",
    "lat": "50.84286",
    "lng": "-0.21608"
  },
  {
    "country": "GB",
    "name": "Portrush",
    "lat": "55.19592",
    "lng": "-6.6493"
  },
  {
    "country": "GB",
    "name": "Portree",
    "lat": "57.41288",
    "lng": "-6.19418"
  },
  {
    "country": "GB",
    "name": "Portlethen",
    "lat": "57.06942",
    "lng": "-2.13246"
  },
  {
    "country": "GB",
    "name": "Portknockie",
    "lat": "57.70248",
    "lng": "-2.85989"
  },
  {
    "country": "GB",
    "name": "Portishead",
    "lat": "51.48199",
    "lng": "-2.76973"
  },
  {
    "country": "GB",
    "name": "Portscatho",
    "lat": "50.17271",
    "lng": "-4.97356"
  },
  {
    "country": "GB",
    "name": "Porthmadog",
    "lat": "52.92924",
    "lng": "-4.13137"
  },
  {
    "country": "GB",
    "name": "Porthleven",
    "lat": "50.08618",
    "lng": "-5.31501"
  },
  {
    "country": "GB",
    "name": "Porthcawl",
    "lat": "51.47903",
    "lng": "-3.70362"
  },
  {
    "country": "GB",
    "name": "Porth",
    "lat": "51.61306",
    "lng": "-3.40361"
  },
  {
    "country": "GB",
    "name": "Portglenone",
    "lat": "54.87147",
    "lng": "-6.47146"
  },
  {
    "country": "GB",
    "name": "Port Glasgow",
    "lat": "55.93464",
    "lng": "-4.6895"
  },
  {
    "country": "GB",
    "name": "Port Erroll",
    "lat": "57.41427",
    "lng": "-1.84596"
  },
  {
    "country": "GB",
    "name": "Port Bannatyne",
    "lat": "55.8566",
    "lng": "-5.06503"
  },
  {
    "country": "GB",
    "name": "Portavogie",
    "lat": "54.45916",
    "lng": "-5.44304"
  },
  {
    "country": "GB",
    "name": "Portaferry",
    "lat": "54.38086",
    "lng": "-5.54569"
  },
  {
    "country": "GB",
    "name": "Portadown",
    "lat": "54.42302",
    "lng": "-6.44434"
  },
  {
    "country": "GB",
    "name": "Porlock",
    "lat": "51.20889",
    "lng": "-3.59556"
  },
  {
    "country": "GB",
    "name": "Poringland",
    "lat": "52.56756",
    "lng": "1.34961"
  },
  {
    "country": "GB",
    "name": "Poplar",
    "lat": "51.51113",
    "lng": "-0.01565"
  },
  {
    "country": "GB",
    "name": "Poole",
    "lat": "50.71429",
    "lng": "-1.98458"
  },
  {
    "country": "GB",
    "name": "Pool",
    "lat": "53.9",
    "lng": "-1.61667"
  },
  {
    "country": "GB",
    "name": "Pontypridd",
    "lat": "51.6021",
    "lng": "-3.34211"
  },
  {
    "country": "GB",
    "name": "Pontypool",
    "lat": "51.70111",
    "lng": "-3.04444"
  },
  {
    "country": "GB",
    "name": "Pontycymer",
    "lat": "51.61118",
    "lng": "-3.58421"
  },
  {
    "country": "GB",
    "name": "Pontyberem",
    "lat": "51.77826",
    "lng": "-4.1689"
  },
  {
    "country": "GB",
    "name": "Pontyates",
    "lat": "51.75182",
    "lng": "-4.21718"
  },
  {
    "country": "GB",
    "name": "Ponthir",
    "lat": "51.63222",
    "lng": "-2.97611"
  },
  {
    "country": "GB",
    "name": "Pontesbury",
    "lat": "52.64826",
    "lng": "-2.89035"
  },
  {
    "country": "GB",
    "name": "Ponteland",
    "lat": "55.05024",
    "lng": "-1.74532"
  },
  {
    "country": "GB",
    "name": "Pontefract",
    "lat": "53.69107",
    "lng": "-1.31269"
  },
  {
    "country": "GB",
    "name": "Pontarddulais",
    "lat": "51.71423",
    "lng": "-4.03859"
  },
  {
    "country": "GB",
    "name": "Polperro",
    "lat": "50.3313",
    "lng": "-4.5222"
  },
  {
    "country": "GB",
    "name": "Polmont",
    "lat": "55.9905",
    "lng": "-3.70737"
  },
  {
    "country": "GB",
    "name": "Pollington",
    "lat": "53.67093",
    "lng": "-1.07237"
  },
  {
    "country": "GB",
    "name": "Polesworth",
    "lat": "52.61962",
    "lng": "-1.61036"
  },
  {
    "country": "GB",
    "name": "Podington",
    "lat": "52.25424",
    "lng": "-0.62463"
  },
  {
    "country": "GB",
    "name": "Pocklington",
    "lat": "53.93335",
    "lng": "-0.78106"
  },
  {
    "country": "GB",
    "name": "Plymstock",
    "lat": "50.35999",
    "lng": "-4.09049"
  },
  {
    "country": "GB",
    "name": "Plympton",
    "lat": "50.39074",
    "lng": "-4.06022"
  },
  {
    "country": "GB",
    "name": "Plymouth",
    "lat": "50.37153",
    "lng": "-4.14305"
  },
  {
    "country": "GB",
    "name": "Plumpton Green",
    "lat": "50.9342",
    "lng": "-0.0612"
  },
  {
    "country": "GB",
    "name": "Plean",
    "lat": "56.06516",
    "lng": "-3.87596"
  },
  {
    "country": "GB",
    "name": "Pittington",
    "lat": "54.8",
    "lng": "-1.48333"
  },
  {
    "country": "GB",
    "name": "Pittenweem",
    "lat": "56.21406",
    "lng": "-2.72839"
  },
  {
    "country": "GB",
    "name": "Pitstone",
    "lat": "51.8283",
    "lng": "-0.63987"
  },
  {
    "country": "GB",
    "name": "Pitsea",
    "lat": "51.56387",
    "lng": "0.50859"
  },
  {
    "country": "GB",
    "name": "Pitmedden",
    "lat": "57.33691",
    "lng": "-2.18022"
  },
  {
    "country": "GB",
    "name": "Pitlochry",
    "lat": "56.70514",
    "lng": "-3.73432"
  },
  {
    "country": "GB",
    "name": "Pirton",
    "lat": "51.9712",
    "lng": "-0.33394"
  },
  {
    "country": "GB",
    "name": "Pinxton",
    "lat": "53.09062",
    "lng": "-1.31767"
  },
  {
    "country": "GB",
    "name": "Pinner",
    "lat": "51.59384",
    "lng": "-0.38216"
  },
  {
    "country": "GB",
    "name": "Pinchbeck",
    "lat": "52.81303",
    "lng": "-0.16256"
  },
  {
    "country": "GB",
    "name": "Pimperne",
    "lat": "50.88374",
    "lng": "-2.1362"
  },
  {
    "country": "GB",
    "name": "Pilsley",
    "lat": "53.15",
    "lng": "-1.36667"
  },
  {
    "country": "GB",
    "name": "Pilning",
    "lat": "51.56337",
    "lng": "-2.64264"
  },
  {
    "country": "GB",
    "name": "Pillaton",
    "lat": "50.45",
    "lng": "-4.3"
  },
  {
    "country": "GB",
    "name": "Pickworth",
    "lat": "52.71311",
    "lng": "-0.53318"
  },
  {
    "country": "GB",
    "name": "Pickering",
    "lat": "54.25",
    "lng": "-0.76667"
  },
  {
    "country": "GB",
    "name": "Pewsey",
    "lat": "51.33855",
    "lng": "-1.76545"
  },
  {
    "country": "GB",
    "name": "Pevensey",
    "lat": "50.81966",
    "lng": "0.33963"
  },
  {
    "country": "GB",
    "name": "Petworth",
    "lat": "50.98669",
    "lng": "-0.61"
  },
  {
    "country": "GB",
    "name": "Petton",
    "lat": "52.83333",
    "lng": "-2.83333"
  },
  {
    "country": "GB",
    "name": "Petersfield",
    "lat": "51.00495",
    "lng": "-0.93375"
  },
  {
    "country": "GB",
    "name": "Peterlee",
    "lat": "54.76032",
    "lng": "-1.33649"
  },
  {
    "country": "GB",
    "name": "Peterhead",
    "lat": "57.50584",
    "lng": "-1.79806"
  },
  {
    "country": "GB",
    "name": "Peterculter",
    "lat": "57.09929",
    "lng": "-2.26588"
  },
  {
    "country": "GB",
    "name": "Peterborough",
    "lat": "52.57364",
    "lng": "-0.24777"
  },
  {
    "country": "GB",
    "name": "Perth",
    "lat": "56.39522",
    "lng": "-3.43139"
  },
  {
    "country": "GB",
    "name": "Pertenhall",
    "lat": "52.27934",
    "lng": "-0.41448"
  },
  {
    "country": "GB",
    "name": "Pershore",
    "lat": "52.11163",
    "lng": "-2.07586"
  },
  {
    "country": "GB",
    "name": "Perranwell",
    "lat": "50.21333",
    "lng": "-5.12053"
  },
  {
    "country": "GB",
    "name": "Perranporth",
    "lat": "50.34377",
    "lng": "-5.15558"
  },
  {
    "country": "GB",
    "name": "Peover Superior",
    "lat": "53.25",
    "lng": "-2.35"
  },
  {
    "country": "GB",
    "name": "Penzance",
    "lat": "50.11861",
    "lng": "-5.53715"
  },
  {
    "country": "GB",
    "name": "Penygroes",
    "lat": "53.05502",
    "lng": "-4.28535"
  },
  {
    "country": "GB",
    "name": "Penybont",
    "lat": "52.26667",
    "lng": "-3.3"
  },
  {
    "country": "GB",
    "name": "Pentyrch",
    "lat": "51.52889",
    "lng": "-3.295"
  },
  {
    "country": "GB",
    "name": "Penryn",
    "lat": "50.16812",
    "lng": "-5.10416"
  },
  {
    "country": "GB",
    "name": "Penrith",
    "lat": "54.66579",
    "lng": "-2.75757"
  },
  {
    "country": "GB",
    "name": "Penrhyndeudraeth",
    "lat": "52.93333",
    "lng": "-4.06667"
  },
  {
    "country": "GB",
    "name": "Penmaenmawr",
    "lat": "53.26667",
    "lng": "-3.93333"
  },
  {
    "country": "GB",
    "name": "Penllyn",
    "lat": "51.47444",
    "lng": "-3.47889"
  },
  {
    "country": "GB",
    "name": "Penkridge",
    "lat": "52.72556",
    "lng": "-2.1156"
  },
  {
    "country": "GB",
    "name": "Penistone",
    "lat": "53.52572",
    "lng": "-1.63027"
  },
  {
    "country": "GB",
    "name": "Penicuik",
    "lat": "55.83116",
    "lng": "-3.22608"
  },
  {
    "country": "GB",
    "name": "Pengam",
    "lat": "51.66528",
    "lng": "-3.22694"
  },
  {
    "country": "GB",
    "name": "Pencoyd",
    "lat": "51.93333",
    "lng": "-2.7"
  },
  {
    "country": "GB",
    "name": "Pencoed",
    "lat": "51.52371",
    "lng": "-3.50016"
  },
  {
    "country": "GB",
    "name": "Pen-clawdd",
    "lat": "51.64028",
    "lng": "-4.09917"
  },
  {
    "country": "GB",
    "name": "Pencaitland",
    "lat": "55.90727",
    "lng": "-2.8949"
  },
  {
    "country": "GB",
    "name": "Pencader",
    "lat": "52.0008",
    "lng": "-4.26575"
  },
  {
    "country": "GB",
    "name": "Penarth",
    "lat": "51.4386",
    "lng": "-3.17342"
  },
  {
    "country": "GB",
    "name": "Penally",
    "lat": "51.65986",
    "lng": "-4.72399"
  },
  {
    "country": "GB",
    "name": "Pembury",
    "lat": "51.14296",
    "lng": "0.32187"
  },
  {
    "country": "GB",
    "name": "Pembroke Dock",
    "lat": "51.69161",
    "lng": "-4.94036"
  },
  {
    "country": "GB",
    "name": "Pembroke",
    "lat": "51.67464",
    "lng": "-4.91286"
  },
  {
    "country": "GB",
    "name": "Pelton",
    "lat": "54.87305",
    "lng": "-1.6095"
  },
  {
    "country": "GB",
    "name": "Pelsall",
    "lat": "52.6291",
    "lng": "-1.96738"
  },
  {
    "country": "GB",
    "name": "Pegswood",
    "lat": "55.1793",
    "lng": "-1.64525"
  },
  {
    "country": "GB",
    "name": "Peebles",
    "lat": "55.6519",
    "lng": "-3.1888"
  },
  {
    "country": "GB",
    "name": "Peakirk",
    "lat": "52.64567",
    "lng": "-0.27294"
  },
  {
    "country": "GB",
    "name": "Paulton",
    "lat": "51.30472",
    "lng": "-2.50028"
  },
  {
    "country": "GB",
    "name": "Paull",
    "lat": "53.72008",
    "lng": "-0.23303"
  },
  {
    "country": "GB",
    "name": "Pattingham",
    "lat": "52.5891",
    "lng": "-2.26538"
  },
  {
    "country": "GB",
    "name": "Patrington",
    "lat": "53.68395",
    "lng": "-0.0133"
  },
  {
    "country": "GB",
    "name": "Patna",
    "lat": "55.36406",
    "lng": "-4.50594"
  },
  {
    "country": "GB",
    "name": "Pateley Bridge",
    "lat": "54.08616",
    "lng": "-1.75981"
  },
  {
    "country": "GB",
    "name": "Partridge Green",
    "lat": "50.9594",
    "lng": "-0.30796"
  },
  {
    "country": "GB",
    "name": "Partington",
    "lat": "53.41884",
    "lng": "-2.42815"
  },
  {
    "country": "GB",
    "name": "Parkstone",
    "lat": "50.72994",
    "lng": "-1.94492"
  },
  {
    "country": "GB",
    "name": "Parbold",
    "lat": "53.59145",
    "lng": "-2.77028"
  },
  {
    "country": "GB",
    "name": "Par",
    "lat": "50.35107",
    "lng": "-4.70288"
  },
  {
    "country": "GB",
    "name": "Papworth Everard",
    "lat": "52.24893",
    "lng": "-0.11827"
  },
  {
    "country": "GB",
    "name": "Pant",
    "lat": "52.79005",
    "lng": "-3.08031"
  },
  {
    "country": "GB",
    "name": "Pannal",
    "lat": "53.96031",
    "lng": "-1.53573"
  },
  {
    "country": "GB",
    "name": "Pangbourne",
    "lat": "51.4837",
    "lng": "-1.08519"
  },
  {
    "country": "GB",
    "name": "Paisley",
    "lat": "55.83173",
    "lng": "-4.43254"
  },
  {
    "country": "GB",
    "name": "Painswick",
    "lat": "51.78568",
    "lng": "-2.19555"
  },
  {
    "country": "GB",
    "name": "Paignton",
    "lat": "50.43565",
    "lng": "-3.56789"
  },
  {
    "country": "GB",
    "name": "Padstow",
    "lat": "50.53885",
    "lng": "-4.93664"
  },
  {
    "country": "GB",
    "name": "Padiham",
    "lat": "53.80187",
    "lng": "-2.31511"
  },
  {
    "country": "GB",
    "name": "Paddock Wood",
    "lat": "51.18187",
    "lng": "0.38229"
  },
  {
    "country": "GB",
    "name": "Oxted",
    "lat": "51.25687",
    "lng": "-0.00601"
  },
  {
    "country": "GB",
    "name": "Oxford",
    "lat": "51.75222",
    "lng": "-1.25596"
  },
  {
    "country": "GB",
    "name": "Oxenhope",
    "lat": "53.81233",
    "lng": "-1.95196"
  },
  {
    "country": "GB",
    "name": "Owston Ferry",
    "lat": "53.49407",
    "lng": "-0.78045"
  },
  {
    "country": "GB",
    "name": "Overtown",
    "lat": "55.75719",
    "lng": "-3.91645"
  },
  {
    "country": "GB",
    "name": "Overton",
    "lat": "54.01528",
    "lng": "-2.86065"
  },
  {
    "country": "GB",
    "name": "Overton",
    "lat": "52.96667",
    "lng": "-2.93333"
  },
  {
    "country": "GB",
    "name": "Overton",
    "lat": "51.24389",
    "lng": "-1.26154"
  },
  {
    "country": "GB",
    "name": "Overstrand",
    "lat": "52.91623",
    "lng": "1.339"
  },
  {
    "country": "GB",
    "name": "Over",
    "lat": "53.18333",
    "lng": "-2.55"
  },
  {
    "country": "GB",
    "name": "Over",
    "lat": "52.31667",
    "lng": "0.01667"
  },
  {
    "country": "GB",
    "name": "Outwell",
    "lat": "52.60946",
    "lng": "0.23333"
  },
  {
    "country": "GB",
    "name": "Oundle",
    "lat": "52.48093",
    "lng": "-0.46732"
  },
  {
    "country": "GB",
    "name": "Oughtibridge",
    "lat": "53.43612",
    "lng": "-1.53902"
  },
  {
    "country": "GB",
    "name": "Ottringham",
    "lat": "53.70092",
    "lng": "-0.07909"
  },
  {
    "country": "GB",
    "name": "Ottery St Mary",
    "lat": "50.75",
    "lng": "-3.26667"
  },
  {
    "country": "GB",
    "name": "Ottershaw",
    "lat": "51.36262",
    "lng": "-0.52752"
  },
  {
    "country": "GB",
    "name": "Otterburn",
    "lat": "55.2334",
    "lng": "-2.18059"
  },
  {
    "country": "GB",
    "name": "Otley",
    "lat": "53.90553",
    "lng": "-1.69383"
  },
  {
    "country": "GB",
    "name": "Otford",
    "lat": "51.31283",
    "lng": "0.19046"
  },
  {
    "country": "GB",
    "name": "Oswestry",
    "lat": "52.86195",
    "lng": "-3.05497"
  },
  {
    "country": "GB",
    "name": "Ossett",
    "lat": "53.67978",
    "lng": "-1.58006"
  },
  {
    "country": "GB",
    "name": "Orwell",
    "lat": "52.1356",
    "lng": "-0.01099"
  },
  {
    "country": "GB",
    "name": "Orsett",
    "lat": "51.51232",
    "lng": "0.36753"
  },
  {
    "country": "GB",
    "name": "Orpington",
    "lat": "51.37457",
    "lng": "0.09785"
  },
  {
    "country": "GB",
    "name": "Ormskirk",
    "lat": "53.56685",
    "lng": "-2.88178"
  },
  {
    "country": "GB",
    "name": "Ormiston",
    "lat": "55.91302",
    "lng": "-2.93985"
  },
  {
    "country": "GB",
    "name": "Ormesby St Margaret",
    "lat": "52.67506",
    "lng": "1.6885"
  },
  {
    "country": "GB",
    "name": "Orleton",
    "lat": "52.3",
    "lng": "-2.75"
  },
  {
    "country": "GB",
    "name": "Orgreave",
    "lat": "53.38333",
    "lng": "-1.36667"
  },
  {
    "country": "GB",
    "name": "Omagh",
    "lat": "54.6",
    "lng": "-7.3"
  },
  {
    "country": "GB",
    "name": "Olveston",
    "lat": "51.58032",
    "lng": "-2.5775"
  },
  {
    "country": "GB",
    "name": "Olney",
    "lat": "52.15345",
    "lng": "-0.70201"
  },
  {
    "country": "GB",
    "name": "Old Windsor",
    "lat": "51.45807",
    "lng": "-0.58674"
  },
  {
    "country": "GB",
    "name": "Oldmeldrum",
    "lat": "57.33492",
    "lng": "-2.3199"
  },
  {
    "country": "GB",
    "name": "Old Leake",
    "lat": "53.03108",
    "lng": "0.09873"
  },
  {
    "country": "GB",
    "name": "Old Kilpatrick",
    "lat": "55.92241",
    "lng": "-4.45567"
  },
  {
    "country": "GB",
    "name": "Oldham",
    "lat": "53.54051",
    "lng": "-2.1183"
  },
  {
    "country": "GB",
    "name": "Oldbury",
    "lat": "52.5",
    "lng": "-2.01667"
  },
  {
    "country": "GB",
    "name": "Okehampton",
    "lat": "50.73841",
    "lng": "-4.0016"
  },
  {
    "country": "GB",
    "name": "Odiham",
    "lat": "51.25407",
    "lng": "-0.93933"
  },
  {
    "country": "GB",
    "name": "Odell",
    "lat": "52.20937",
    "lng": "-0.5888"
  },
  {
    "country": "GB",
    "name": "Ocle Pychard",
    "lat": "52.11667",
    "lng": "-2.6"
  },
  {
    "country": "GB",
    "name": "Ochiltree",
    "lat": "55.45981",
    "lng": "-4.36782"
  },
  {
    "country": "GB",
    "name": "Oban",
    "lat": "56.41535",
    "lng": "-5.47184"
  },
  {
    "country": "GB",
    "name": "Oakley",
    "lat": "56.08421",
    "lng": "-3.56311"
  },
  {
    "country": "GB",
    "name": "Oakley",
    "lat": "52.16862",
    "lng": "-0.52649"
  },
  {
    "country": "GB",
    "name": "Oakley",
    "lat": "51.80406",
    "lng": "-1.07261"
  },
  {
    "country": "GB",
    "name": "Oakington",
    "lat": "52.26044",
    "lng": "0.06849"
  },
  {
    "country": "GB",
    "name": "Oakham",
    "lat": "52.66667",
    "lng": "-0.73333"
  },
  {
    "country": "GB",
    "name": "Oakengates",
    "lat": "52.69501",
    "lng": "-2.45036"
  },
  {
    "country": "GB",
    "name": "Oadby",
    "lat": "52.60621",
    "lng": "-1.08354"
  },
  {
    "country": "GB",
    "name": "Nunthorpe",
    "lat": "54.5288",
    "lng": "-1.18438"
  },
  {
    "country": "GB",
    "name": "Nuneaton",
    "lat": "52.52323",
    "lng": "-1.46523"
  },
  {
    "country": "GB",
    "name": "Notton",
    "lat": "53.61267",
    "lng": "-1.47234"
  },
  {
    "country": "GB",
    "name": "Nottingham",
    "lat": "52.9536",
    "lng": "-1.15047"
  },
  {
    "country": "GB",
    "name": "Norwich",
    "lat": "52.62783",
    "lng": "1.29834"
  },
  {
    "country": "GB",
    "name": "Norton Canes",
    "lat": "52.67142",
    "lng": "-1.96262"
  },
  {
    "country": "GB",
    "name": "Norton",
    "lat": "54.13303",
    "lng": "-0.78501"
  },
  {
    "country": "GB",
    "name": "Norton",
    "lat": "53.63333",
    "lng": "-1.18333"
  },
  {
    "country": "GB",
    "name": "Norton",
    "lat": "51.55944",
    "lng": "-2.165"
  },
  {
    "country": "GB",
    "name": "North Wraxall",
    "lat": "51.4734",
    "lng": "-2.263"
  },
  {
    "country": "GB",
    "name": "Northwood",
    "lat": "50.74102",
    "lng": "-1.31192"
  },
  {
    "country": "GB",
    "name": "Northwich",
    "lat": "53.25882",
    "lng": "-2.52025"
  },
  {
    "country": "GB",
    "name": "North Walsham",
    "lat": "52.82121",
    "lng": "1.38746"
  },
  {
    "country": "GB",
    "name": "North Thoresby",
    "lat": "53.46651",
    "lng": "-0.05575"
  },
  {
    "country": "GB",
    "name": "North Tawton",
    "lat": "50.79968",
    "lng": "-3.89759"
  },
  {
    "country": "GB",
    "name": "North Sunderland",
    "lat": "55.57688",
    "lng": "-1.66436"
  },
  {
    "country": "GB",
    "name": "North Somercotes",
    "lat": "53.44573",
    "lng": "0.14103"
  },
  {
    "country": "GB",
    "name": "North Shields",
    "lat": "55.01646",
    "lng": "-1.44925"
  },
  {
    "country": "GB",
    "name": "North Queensferry",
    "lat": "56.00899",
    "lng": "-3.39134"
  },
  {
    "country": "GB",
    "name": "North Petherton",
    "lat": "51.09243",
    "lng": "-3.01549"
  },
  {
    "country": "GB",
    "name": "Northorpe",
    "lat": "53.46307",
    "lng": "-0.65347"
  },
  {
    "country": "GB",
    "name": "Northop",
    "lat": "53.20692",
    "lng": "-3.13277"
  },
  {
    "country": "GB",
    "name": "Northolt",
    "lat": "51.54855",
    "lng": "-0.36778"
  },
  {
    "country": "GB",
    "name": "North Newbald",
    "lat": "53.81667",
    "lng": "-0.61667"
  },
  {
    "country": "GB",
    "name": "North Luffenham",
    "lat": "52.62108",
    "lng": "-0.61987"
  },
  {
    "country": "GB",
    "name": "North Leigh",
    "lat": "51.81432",
    "lng": "-1.44144"
  },
  {
    "country": "GB",
    "name": "Northleach",
    "lat": "51.82994",
    "lng": "-1.83712"
  },
  {
    "country": "GB",
    "name": "Lancing",
    "lat": "50.82882",
    "lng": "-0.32247"
  },
  {
    "country": "GB",
    "name": "Northiam",
    "lat": "50.99439",
    "lng": "0.60026"
  },
  {
    "country": "GB",
    "name": "North Hill",
    "lat": "50.55",
    "lng": "-4.43333"
  },
  {
    "country": "GB",
    "name": "North Ferriby",
    "lat": "53.72124",
    "lng": "-0.5052"
  },
  {
    "country": "GB",
    "name": "North Elmsall",
    "lat": "53.60885",
    "lng": "-1.28214"
  },
  {
    "country": "GB",
    "name": "North Elmham",
    "lat": "52.7464",
    "lng": "0.94611"
  },
  {
    "country": "GB",
    "name": "North Collingham",
    "lat": "53.15",
    "lng": "-0.75"
  },
  {
    "country": "GB",
    "name": "North Cave",
    "lat": "53.78012",
    "lng": "-0.64965"
  },
  {
    "country": "GB",
    "name": "North Bradley",
    "lat": "51.295",
    "lng": "-2.20472"
  },
  {
    "country": "GB",
    "name": "Northborough",
    "lat": "52.65868",
    "lng": "-0.29818"
  },
  {
    "country": "GB",
    "name": "North Berwick",
    "lat": "56.05825",
    "lng": "-2.7229"
  },
  {
    "country": "GB",
    "name": "Northampton",
    "lat": "52.25",
    "lng": "-0.88333"
  },
  {
    "country": "GB",
    "name": "Northam",
    "lat": "51.03333",
    "lng": "-4.21667"
  },
  {
    "country": "GB",
    "name": "Northallerton",
    "lat": "54.33901",
    "lng": "-1.43243"
  },
  {
    "country": "GB",
    "name": "Normanton",
    "lat": "53.7",
    "lng": "-1.41667"
  },
  {
    "country": "GB",
    "name": "Normandy",
    "lat": "51.25751",
    "lng": "-0.67472"
  },
  {
    "country": "GB",
    "name": "Norbury",
    "lat": "52.53333",
    "lng": "-2.95"
  },
  {
    "country": "GB",
    "name": "Niton",
    "lat": "50.58702",
    "lng": "-1.28489"
  },
  {
    "country": "GB",
    "name": "Ninfield",
    "lat": "50.88641",
    "lng": "0.42529"
  },
  {
    "country": "GB",
    "name": "Neyland",
    "lat": "51.71014",
    "lng": "-4.95155"
  },
  {
    "country": "GB",
    "name": "New Tredegar",
    "lat": "51.72051",
    "lng": "-3.2413"
  },
  {
    "country": "GB",
    "name": "Newtownstewart",
    "lat": "54.71778",
    "lng": "-7.37886"
  },
  {
    "country": "GB",
    "name": "Newtown St Boswells",
    "lat": "55.57887",
    "lng": "-2.66874"
  },
  {
    "country": "GB",
    "name": "Newtownards",
    "lat": "54.59236",
    "lng": "-5.69092"
  },
  {
    "country": "GB",
    "name": "Newtownabbey",
    "lat": "54.65983",
    "lng": "-5.90858"
  },
  {
    "country": "GB",
    "name": "Newtown",
    "lat": "52.51667",
    "lng": "-3.3"
  },
  {
    "country": "GB",
    "name": "Newton Stewart",
    "lat": "54.95784",
    "lng": "-4.48315"
  },
  {
    "country": "GB",
    "name": "Newton Poppleford",
    "lat": "50.7",
    "lng": "-3.29586"
  },
  {
    "country": "GB",
    "name": "Newtonmore",
    "lat": "57.06567",
    "lng": "-4.12097"
  },
  {
    "country": "GB",
    "name": "Newton Mearns",
    "lat": "55.77334",
    "lng": "-4.33339"
  },
  {
    "country": "GB",
    "name": "Newton Longville",
    "lat": "51.976",
    "lng": "-0.76595"
  },
  {
    "country": "GB",
    "name": "Newton-le-Willows",
    "lat": "53.45",
    "lng": "-2.6"
  },
  {
    "country": "GB",
    "name": "Newtonhill",
    "lat": "57.03333",
    "lng": "-2.15"
  },
  {
    "country": "GB",
    "name": "Newton Ferrers",
    "lat": "50.31467",
    "lng": "-4.0392"
  },
  {
    "country": "GB",
    "name": "Newton Aycliffe",
    "lat": "54.61842",
    "lng": "-1.5719"
  },
  {
    "country": "GB",
    "name": "Newton Abbot",
    "lat": "50.52858",
    "lng": "-3.61186"
  },
  {
    "country": "GB",
    "name": "Scone",
    "lat": "56.41942",
    "lng": "-3.40507"
  },
  {
    "country": "GB",
    "name": "Newry",
    "lat": "54.17841",
    "lng": "-6.33739"
  },
  {
    "country": "GB",
    "name": "New Romney",
    "lat": "50.98599",
    "lng": "0.94122"
  },
  {
    "country": "GB",
    "name": "New Quay",
    "lat": "52.21515",
    "lng": "-4.35887"
  },
  {
    "country": "GB",
    "name": "Newquay",
    "lat": "50.41557",
    "lng": "-5.07319"
  },
  {
    "country": "GB",
    "name": "Newport Pagnell",
    "lat": "52.08731",
    "lng": "-0.72218"
  },
  {
    "country": "GB",
    "name": "Newport-On-Tay",
    "lat": "56.43911",
    "lng": "-2.9367"
  },
  {
    "country": "GB",
    "name": "Newport",
    "lat": "53.76333",
    "lng": "-0.69986"
  },
  {
    "country": "GB",
    "name": "Newport",
    "lat": "52.76684",
    "lng": "-2.37734"
  },
  {
    "country": "GB",
    "name": "Newport",
    "lat": "52.01667",
    "lng": "-4.83333"
  },
  {
    "country": "GB",
    "name": "Newport",
    "lat": "51.58774",
    "lng": "-2.99835"
  },
  {
    "country": "GB",
    "name": "Newport",
    "lat": "50.70146",
    "lng": "-1.29124"
  },
  {
    "country": "GB",
    "name": "New Pitsligo",
    "lat": "57.59019",
    "lng": "-2.19535"
  },
  {
    "country": "GB",
    "name": "New Milton",
    "lat": "50.75601",
    "lng": "-1.6658"
  },
  {
    "country": "GB",
    "name": "Newmilns",
    "lat": "55.60751",
    "lng": "-4.32416"
  },
  {
    "country": "GB",
    "name": "New Mills",
    "lat": "53.36592",
    "lng": "-1.99986"
  },
  {
    "country": "GB",
    "name": "Newmarket",
    "lat": "52.24467",
    "lng": "0.40418"
  },
  {
    "country": "GB",
    "name": "New Malden",
    "lat": "51.40065",
    "lng": "-0.2617"
  },
  {
    "country": "GB",
    "name": "Newmains",
    "lat": "55.78514",
    "lng": "-3.87465"
  },
  {
    "country": "GB",
    "name": "Newmacher",
    "lat": "57.26667",
    "lng": "-2.18333"
  },
  {
    "country": "GB",
    "name": "Newington",
    "lat": "51.35217",
    "lng": "0.66768"
  },
  {
    "country": "GB",
    "name": "Newick",
    "lat": "50.97518",
    "lng": "0.01579"
  },
  {
    "country": "GB",
    "name": "Newhaven",
    "lat": "50.79693",
    "lng": "0.05545"
  },
  {
    "country": "GB",
    "name": "New Ferry",
    "lat": "53.36046",
    "lng": "-2.99377"
  },
  {
    "country": "GB",
    "name": "Newent",
    "lat": "51.93365",
    "lng": "-2.40815"
  },
  {
    "country": "GB",
    "name": "New Cumnock",
    "lat": "55.39563",
    "lng": "-4.18458"
  },
  {
    "country": "GB",
    "name": "Newchurch",
    "lat": "50.66744",
    "lng": "-1.20828"
  },
  {
    "country": "GB",
    "name": "Newcastle upon Tyne",
    "lat": "54.97328",
    "lng": "-1.61396"
  },
  {
    "country": "GB",
    "name": "Newcastle under Lyme",
    "lat": "53",
    "lng": "-2.23333"
  },
  {
    "country": "GB",
    "name": "Newcastle Emlyn",
    "lat": "52.04056",
    "lng": "-4.4667"
  },
  {
    "country": "GB",
    "name": "Newbury",
    "lat": "51.40148",
    "lng": "-1.32471"
  },
  {
    "country": "GB",
    "name": "Newburn",
    "lat": "54.9876",
    "lng": "-1.74415"
  },
  {
    "country": "GB",
    "name": "Newburgh",
    "lat": "57.31711",
    "lng": "-2.00449"
  },
  {
    "country": "GB",
    "name": "Newburgh",
    "lat": "56.35079",
    "lng": "-3.2365"
  },
  {
    "country": "GB",
    "name": "Newbridge",
    "lat": "55.93333",
    "lng": "-3.4"
  },
  {
    "country": "GB",
    "name": "Newbridge",
    "lat": "51.66667",
    "lng": "-3.13333"
  },
  {
    "country": "GB",
    "name": "Newborough",
    "lat": "52.6389",
    "lng": "-0.22333"
  },
  {
    "country": "GB",
    "name": "Newbold Verdon",
    "lat": "52.62959",
    "lng": "-1.3422"
  },
  {
    "country": "GB",
    "name": "Newbiggin-by-the-Sea",
    "lat": "55.18532",
    "lng": "-1.51469"
  },
  {
    "country": "GB",
    "name": "Newbiggin",
    "lat": "54.64171",
    "lng": "-2.13555"
  },
  {
    "country": "GB",
    "name": "Newarthill",
    "lat": "55.8151",
    "lng": "-3.93733"
  },
  {
    "country": "GB",
    "name": "Newark on Trent",
    "lat": "53.06667",
    "lng": "-0.81667"
  },
  {
    "country": "GB",
    "name": "New Alresford",
    "lat": "51.08624",
    "lng": "-1.17011"
  },
  {
    "country": "GB",
    "name": "Nefyn",
    "lat": "52.93538",
    "lng": "-4.5225"
  },
  {
    "country": "GB",
    "name": "Nevern",
    "lat": "52.02387",
    "lng": "-4.80068"
  },
  {
    "country": "GB",
    "name": "Nettleton",
    "lat": "51.50222",
    "lng": "-2.2625"
  },
  {
    "country": "GB",
    "name": "Nettleham",
    "lat": "53.26603",
    "lng": "-0.48866"
  },
  {
    "country": "GB",
    "name": "Netley",
    "lat": "50.87634",
    "lng": "-1.35398"
  },
  {
    "country": "GB",
    "name": "Netherton",
    "lat": "52.48333",
    "lng": "-2.08333"
  },
  {
    "country": "GB",
    "name": "Nether Stowey",
    "lat": "51.15101",
    "lng": "-3.15676"
  },
  {
    "country": "GB",
    "name": "Nether Poppleton",
    "lat": "53.98793",
    "lng": "-1.15062"
  },
  {
    "country": "GB",
    "name": "Netheravon",
    "lat": "51.23613",
    "lng": "-1.79083"
  },
  {
    "country": "GB",
    "name": "Neston",
    "lat": "53.28333",
    "lng": "-3.05"
  },
  {
    "country": "GB",
    "name": "Nelson",
    "lat": "53.83333",
    "lng": "-2.2"
  },
  {
    "country": "GB",
    "name": "Nelson",
    "lat": "51.65333",
    "lng": "-3.28444"
  },
  {
    "country": "GB",
    "name": "Neilston",
    "lat": "55.78574",
    "lng": "-4.42637"
  },
  {
    "country": "GB",
    "name": "Needingworth",
    "lat": "52.33051",
    "lng": "-0.03116"
  },
  {
    "country": "GB",
    "name": "Needham Market",
    "lat": "52.1555",
    "lng": "1.0516"
  },
  {
    "country": "GB",
    "name": "Necton",
    "lat": "52.64994",
    "lng": "0.77539"
  },
  {
    "country": "GB",
    "name": "Neath",
    "lat": "51.66317",
    "lng": "-3.80443"
  },
  {
    "country": "GB",
    "name": "Navenby",
    "lat": "53.1068",
    "lng": "-0.52494"
  },
  {
    "country": "GB",
    "name": "Nash",
    "lat": "51.54889",
    "lng": "-2.94611"
  },
  {
    "country": "GB",
    "name": "Narborough",
    "lat": "52.68333",
    "lng": "0.58333"
  },
  {
    "country": "GB",
    "name": "Narborough",
    "lat": "52.56667",
    "lng": "-1.2"
  },
  {
    "country": "GB",
    "name": "Narberth",
    "lat": "51.79784",
    "lng": "-4.74275"
  },
  {
    "country": "GB",
    "name": "Nantwich",
    "lat": "53.06878",
    "lng": "-2.52051"
  },
  {
    "country": "GB",
    "name": "Nairn",
    "lat": "57.58094",
    "lng": "-3.87973"
  },
  {
    "country": "GB",
    "name": "Nailsworth",
    "lat": "51.69382",
    "lng": "-2.2199"
  },
  {
    "country": "GB",
    "name": "Nailsea",
    "lat": "51.43239",
    "lng": "-2.75847"
  },
  {
    "country": "GB",
    "name": "Nafferton",
    "lat": "54.01965",
    "lng": "-0.3919"
  },
  {
    "country": "GB",
    "name": "Mytholmroyd",
    "lat": "53.73065",
    "lng": "-1.98258"
  },
  {
    "country": "GB",
    "name": "Mylor Bridge",
    "lat": "50.18506",
    "lng": "-5.07963"
  },
  {
    "country": "GB",
    "name": "Musselburgh",
    "lat": "55.9417",
    "lng": "-3.04991"
  },
  {
    "country": "GB",
    "name": "Murton",
    "lat": "54.81812",
    "lng": "-1.39036"
  },
  {
    "country": "GB",
    "name": "Mundford",
    "lat": "52.5093",
    "lng": "0.64991"
  },
  {
    "country": "GB",
    "name": "Mundesley",
    "lat": "52.87842",
    "lng": "1.4297"
  },
  {
    "country": "GB",
    "name": "Mullion",
    "lat": "50.02706",
    "lng": "-5.24248"
  },
  {
    "country": "GB",
    "name": "Mulbarton",
    "lat": "52.55913",
    "lng": "1.23327"
  },
  {
    "country": "GB",
    "name": "Muir of Ord",
    "lat": "57.51976",
    "lng": "-4.45939"
  },
  {
    "country": "GB",
    "name": "Muirkirk",
    "lat": "55.52272",
    "lng": "-4.06551"
  },
  {
    "country": "GB",
    "name": "Muirhead",
    "lat": "56.5",
    "lng": "-3.06667"
  },
  {
    "country": "GB",
    "name": "Muggleswick",
    "lat": "54.83333",
    "lng": "-1.93333"
  },
  {
    "country": "GB",
    "name": "Much Wenlock",
    "lat": "52.59582",
    "lng": "-2.55749"
  },
  {
    "country": "GB",
    "name": "Much Hadham",
    "lat": "51.85407",
    "lng": "0.07188"
  },
  {
    "country": "GB",
    "name": "Much Birch",
    "lat": "51.97108",
    "lng": "-2.72349"
  },
  {
    "country": "GB",
    "name": "Moy",
    "lat": "54.45",
    "lng": "-6.66667"
  },
  {
    "country": "GB",
    "name": "Mountsorrel",
    "lat": "52.71667",
    "lng": "-1.15"
  },
  {
    "country": "GB",
    "name": "Mountain Ash",
    "lat": "51.68361",
    "lng": "-3.38008"
  },
  {
    "country": "GB",
    "name": "Moulton Chapel",
    "lat": "52.74668",
    "lng": "-0.08274"
  },
  {
    "country": "GB",
    "name": "Moulsoe",
    "lat": "52.0688",
    "lng": "-0.67326"
  },
  {
    "country": "GB",
    "name": "Mouldsworth",
    "lat": "53.23333",
    "lng": "-2.73333"
  },
  {
    "country": "GB",
    "name": "Motherwell",
    "lat": "55.78924",
    "lng": "-3.99187"
  },
  {
    "country": "GB",
    "name": "Motcombe",
    "lat": "51.02929",
    "lng": "-2.21627"
  },
  {
    "country": "GB",
    "name": "Mostyn",
    "lat": "53.31271",
    "lng": "-3.26765"
  },
  {
    "country": "GB",
    "name": "Mossley",
    "lat": "53.51454",
    "lng": "-2.03462"
  },
  {
    "country": "GB",
    "name": "Moss",
    "lat": "53.61667",
    "lng": "-1.1"
  },
  {
    "country": "GB",
    "name": "Morriston",
    "lat": "51.66995",
    "lng": "-3.92941"
  },
  {
    "country": "GB",
    "name": "Morpeth",
    "lat": "55.16882",
    "lng": "-1.68893"
  },
  {
    "country": "GB",
    "name": "Morley",
    "lat": "53.74013",
    "lng": "-1.59877"
  },
  {
    "country": "GB",
    "name": "Moreton in Marsh",
    "lat": "51.98964",
    "lng": "-1.70297"
  },
  {
    "country": "GB",
    "name": "Moretonhampstead",
    "lat": "50.66077",
    "lng": "-3.76495"
  },
  {
    "country": "GB",
    "name": "Moreton",
    "lat": "53.4",
    "lng": "-3.11667"
  },
  {
    "country": "GB",
    "name": "Morecambe",
    "lat": "54.06835",
    "lng": "-2.86108"
  },
  {
    "country": "GB",
    "name": "Morden",
    "lat": "51.39822",
    "lng": "-0.19837"
  },
  {
    "country": "GB",
    "name": "Morcott",
    "lat": "52.59669",
    "lng": "-0.63704"
  },
  {
    "country": "GB",
    "name": "Morchard Bishop",
    "lat": "50.85416",
    "lng": "-3.74894"
  },
  {
    "country": "GB",
    "name": "Montrose",
    "lat": "56.71683",
    "lng": "-2.46695"
  },
  {
    "country": "GB",
    "name": "Monmouth",
    "lat": "51.81265",
    "lng": "-2.71363"
  },
  {
    "country": "GB",
    "name": "Monk Fryston",
    "lat": "53.7616",
    "lng": "-1.23751"
  },
  {
    "country": "GB",
    "name": "Monifieth",
    "lat": "56.48227",
    "lng": "-2.81732"
  },
  {
    "country": "GB",
    "name": "Moneymore",
    "lat": "54.69229",
    "lng": "-6.66956"
  },
  {
    "country": "GB",
    "name": "Mollington",
    "lat": "53.22934",
    "lng": "-2.92159"
  },
  {
    "country": "GB",
    "name": "Mold",
    "lat": "53.16674",
    "lng": "-3.14143"
  },
  {
    "country": "GB",
    "name": "Moira",
    "lat": "54.48021",
    "lng": "-6.22822"
  },
  {
    "country": "GB",
    "name": "Moira",
    "lat": "52.73698",
    "lng": "-1.53496"
  },
  {
    "country": "GB",
    "name": "Moffat",
    "lat": "55.33527",
    "lng": "-3.44142"
  },
  {
    "country": "GB",
    "name": "Moelfre",
    "lat": "53.35228",
    "lng": "-4.23734"
  },
  {
    "country": "GB",
    "name": "Modbury",
    "lat": "50.34957",
    "lng": "-3.88684"
  },
  {
    "country": "GB",
    "name": "Mochdre",
    "lat": "53.28333",
    "lng": "-3.75"
  },
  {
    "country": "GB",
    "name": "Mochdre",
    "lat": "52.48333",
    "lng": "-3.36667"
  },
  {
    "country": "GB",
    "name": "Mobberley",
    "lat": "53.31667",
    "lng": "-2.31667"
  },
  {
    "country": "GB",
    "name": "Mitchel Troy",
    "lat": "51.78728",
    "lng": "-2.73731"
  },
  {
    "country": "GB",
    "name": "Mitcheldean",
    "lat": "51.8644",
    "lng": "-2.4895"
  },
  {
    "country": "GB",
    "name": "Mitcham",
    "lat": "51.40322",
    "lng": "-0.16831"
  },
  {
    "country": "GB",
    "name": "Mistley",
    "lat": "51.94331",
    "lng": "1.08254"
  },
  {
    "country": "GB",
    "name": "Misterton",
    "lat": "53.44492",
    "lng": "-0.85032"
  },
  {
    "country": "GB",
    "name": "Mirfield",
    "lat": "53.67343",
    "lng": "-1.69636"
  },
  {
    "country": "GB",
    "name": "Mintlaw",
    "lat": "57.52414",
    "lng": "-2.00099"
  },
  {
    "country": "GB",
    "name": "Minster Lovell",
    "lat": "51.79274",
    "lng": "-1.5483"
  },
  {
    "country": "GB",
    "name": "Minsterley",
    "lat": "52.63989",
    "lng": "-2.92807"
  },
  {
    "country": "GB",
    "name": "Minety",
    "lat": "51.61667",
    "lng": "-1.95"
  },
  {
    "country": "GB",
    "name": "Minehead",
    "lat": "51.20452",
    "lng": "-3.48284"
  },
  {
    "country": "GB",
    "name": "Minchinhampton",
    "lat": "51.70675",
    "lng": "-2.18502"
  },
  {
    "country": "GB",
    "name": "Milverton",
    "lat": "51.02333",
    "lng": "-3.25222"
  },
  {
    "country": "GB",
    "name": "Milton Keynes",
    "lat": "52.04172",
    "lng": "-0.75583"
  },
  {
    "country": "GB",
    "name": "Milton Bryan",
    "lat": "51.95",
    "lng": "-0.58333"
  },
  {
    "country": "GB",
    "name": "Milston",
    "lat": "51.20621",
    "lng": "-1.76901"
  },
  {
    "country": "GB",
    "name": "Milnthorpe",
    "lat": "54.22785",
    "lng": "-2.76939"
  },
  {
    "country": "GB",
    "name": "Milnrow",
    "lat": "53.61115",
    "lng": "-2.11266"
  },
  {
    "country": "GB",
    "name": "Milngavie",
    "lat": "55.94071",
    "lng": "-4.32311"
  },
  {
    "country": "GB",
    "name": "Milnathort",
    "lat": "56.22688",
    "lng": "-3.4193"
  },
  {
    "country": "GB",
    "name": "Milltimber",
    "lat": "57.10424",
    "lng": "-2.24099"
  },
  {
    "country": "GB",
    "name": "Millport",
    "lat": "55.75348",
    "lng": "-4.92559"
  },
  {
    "country": "GB",
    "name": "Millom",
    "lat": "54.21072",
    "lng": "-3.272"
  },
  {
    "country": "GB",
    "name": "Millisle",
    "lat": "54.60638",
    "lng": "-5.52973"
  },
  {
    "country": "GB",
    "name": "Millington",
    "lat": "53.95",
    "lng": "-0.73333"
  },
  {
    "country": "GB",
    "name": "Millbrook",
    "lat": "52.03882",
    "lng": "-0.52438"
  },
  {
    "country": "GB",
    "name": "Millbrook",
    "lat": "50.34925",
    "lng": "-4.21506"
  },
  {
    "country": "GB",
    "name": "Milford on Sea",
    "lat": "50.72561",
    "lng": "-1.59004"
  },
  {
    "country": "GB",
    "name": "Milford Haven",
    "lat": "51.71278",
    "lng": "-5.0341"
  },
  {
    "country": "GB",
    "name": "Milford",
    "lat": "51.17272",
    "lng": "-0.65042"
  },
  {
    "country": "GB",
    "name": "Mildenhall",
    "lat": "52.34446",
    "lng": "0.51086"
  },
  {
    "country": "GB",
    "name": "Mildenhall",
    "lat": "51.4256",
    "lng": "-1.69988"
  },
  {
    "country": "GB",
    "name": "Milborne St Andrew",
    "lat": "50.77829",
    "lng": "-2.28114"
  },
  {
    "country": "GB",
    "name": "Milborne Port",
    "lat": "50.96605",
    "lng": "-2.46248"
  },
  {
    "country": "GB",
    "name": "Midsomer Norton",
    "lat": "51.28567",
    "lng": "-2.48591"
  },
  {
    "country": "GB",
    "name": "Midhurst",
    "lat": "50.98559",
    "lng": "-0.74003"
  },
  {
    "country": "GB",
    "name": "Middle Winterslow",
    "lat": "51.09346",
    "lng": "-1.65453"
  },
  {
    "country": "GB",
    "name": "Middlewich",
    "lat": "53.19296",
    "lng": "-2.44402"
  },
  {
    "country": "GB",
    "name": "Middleton",
    "lat": "53.55",
    "lng": "-2.2"
  },
  {
    "country": "GB",
    "name": "Middlestown",
    "lat": "53.65079",
    "lng": "-1.59762"
  },
  {
    "country": "GB",
    "name": "Middlesbrough",
    "lat": "54.57623",
    "lng": "-1.23483"
  },
  {
    "country": "GB",
    "name": "Middle Rasen",
    "lat": "53.38722",
    "lng": "-0.36202"
  },
  {
    "country": "GB",
    "name": "Mid Calder",
    "lat": "55.89261",
    "lng": "-3.48002"
  },
  {
    "country": "GB",
    "name": "Mickle Trafford",
    "lat": "53.22146",
    "lng": "-2.83225"
  },
  {
    "country": "GB",
    "name": "Mickleton",
    "lat": "54.60807",
    "lng": "-2.04998"
  },
  {
    "country": "GB",
    "name": "Mickleton",
    "lat": "52.09152",
    "lng": "-1.76623"
  },
  {
    "country": "GB",
    "name": "Mexborough",
    "lat": "53.49389",
    "lng": "-1.29243"
  },
  {
    "country": "GB",
    "name": "Mevagissey",
    "lat": "50.27324",
    "lng": "-4.79166"
  },
  {
    "country": "GB",
    "name": "Methven",
    "lat": "56.41737",
    "lng": "-3.57832"
  },
  {
    "country": "GB",
    "name": "Methley",
    "lat": "53.72887",
    "lng": "-1.40318"
  },
  {
    "country": "GB",
    "name": "Methil",
    "lat": "56.18543",
    "lng": "-3.02157"
  },
  {
    "country": "GB",
    "name": "Metheringham",
    "lat": "53.14015",
    "lng": "-0.40368"
  },
  {
    "country": "GB",
    "name": "Messingham",
    "lat": "53.52828",
    "lng": "-0.65385"
  },
  {
    "country": "GB",
    "name": "Merthyr Tydfil",
    "lat": "51.74794",
    "lng": "-3.37779"
  },
  {
    "country": "GB",
    "name": "Meriden",
    "lat": "52.4377",
    "lng": "-1.64366"
  },
  {
    "country": "GB",
    "name": "Mere",
    "lat": "53.3321",
    "lng": "-2.40935"
  },
  {
    "country": "GB",
    "name": "Mere",
    "lat": "51.08889",
    "lng": "-2.26694"
  },
  {
    "country": "GB",
    "name": "Meppershall",
    "lat": "52.01713",
    "lng": "-0.33991"
  },
  {
    "country": "GB",
    "name": "Meopham",
    "lat": "51.36844",
    "lng": "0.36007"
  },
  {
    "country": "GB",
    "name": "Menston",
    "lat": "53.89041",
    "lng": "-1.74395"
  },
  {
    "country": "GB",
    "name": "Menai Bridge",
    "lat": "53.22775",
    "lng": "-4.16926"
  },
  {
    "country": "GB",
    "name": "Melton Mowbray",
    "lat": "52.76588",
    "lng": "-0.88693"
  },
  {
    "country": "GB",
    "name": "Meltham",
    "lat": "53.59305",
    "lng": "-1.84861"
  },
  {
    "country": "GB",
    "name": "Melrose",
    "lat": "55.59969",
    "lng": "-2.7277"
  },
  {
    "country": "GB",
    "name": "Melling",
    "lat": "53.48333",
    "lng": "-2.91667"
  },
  {
    "country": "GB",
    "name": "Melksham",
    "lat": "51.37281",
    "lng": "-2.14002"
  },
  {
    "country": "GB",
    "name": "Meldreth",
    "lat": "52.09396",
    "lng": "0.00807"
  },
  {
    "country": "GB",
    "name": "Meldon",
    "lat": "55.13333",
    "lng": "-1.8"
  },
  {
    "country": "GB",
    "name": "Melbourne",
    "lat": "53.88755",
    "lng": "-0.85925"
  },
  {
    "country": "GB",
    "name": "Melbourne",
    "lat": "52.8219",
    "lng": "-1.42522"
  },
  {
    "country": "GB",
    "name": "Melbourn",
    "lat": "52.08128",
    "lng": "0.01514"
  },
  {
    "country": "GB",
    "name": "Measham",
    "lat": "52.70644",
    "lng": "-1.50637"
  },
  {
    "country": "GB",
    "name": "Mayland",
    "lat": "51.68033",
    "lng": "0.76715"
  },
  {
    "country": "GB",
    "name": "Mayfield",
    "lat": "53",
    "lng": "-1.76667"
  },
  {
    "country": "GB",
    "name": "Maybole",
    "lat": "55.35503",
    "lng": "-4.68026"
  },
  {
    "country": "GB",
    "name": "Maulden",
    "lat": "52.03063",
    "lng": "-0.46975"
  },
  {
    "country": "GB",
    "name": "Mauchline",
    "lat": "55.51604",
    "lng": "-4.37928"
  },
  {
    "country": "GB",
    "name": "Mattishall",
    "lat": "52.65905",
    "lng": "1.0325"
  },
  {
    "country": "GB",
    "name": "Matlock",
    "lat": "53.13838",
    "lng": "-1.5556"
  },
  {
    "country": "GB",
    "name": "Mathry",
    "lat": "51.94639",
    "lng": "-5.08667"
  },
  {
    "country": "GB",
    "name": "Masham",
    "lat": "54.2227",
    "lng": "-1.65718"
  },
  {
    "country": "GB",
    "name": "Maryport",
    "lat": "54.71434",
    "lng": "-3.49509"
  },
  {
    "country": "GB",
    "name": "Martock",
    "lat": "50.97361",
    "lng": "-2.76684"
  },
  {
    "country": "GB",
    "name": "Martham",
    "lat": "52.70464",
    "lng": "1.63636"
  },
  {
    "country": "GB",
    "name": "Marstow",
    "lat": "51.86667",
    "lng": "-2.65"
  },
  {
    "country": "GB",
    "name": "Marston Moretaine",
    "lat": "52.0641",
    "lng": "-0.54932"
  },
  {
    "country": "GB",
    "name": "Marston",
    "lat": "53.26667",
    "lng": "-2.5"
  },
  {
    "country": "GB",
    "name": "Marske-by-the-Sea",
    "lat": "54.59147",
    "lng": "-1.01959"
  },
  {
    "country": "GB",
    "name": "Marshfield",
    "lat": "51.53389",
    "lng": "-3.07306"
  },
  {
    "country": "GB",
    "name": "Marshfield",
    "lat": "51.46194",
    "lng": "-2.32"
  },
  {
    "country": "GB",
    "name": "Marsden",
    "lat": "53.6",
    "lng": "-1.91667"
  },
  {
    "country": "GB",
    "name": "Marr",
    "lat": "53.54296",
    "lng": "-1.22051"
  },
  {
    "country": "GB",
    "name": "Marple",
    "lat": "53.39452",
    "lng": "-2.06292"
  },
  {
    "country": "GB",
    "name": "Marnhull",
    "lat": "50.97045",
    "lng": "-2.31327"
  },
  {
    "country": "GB",
    "name": "Marlow",
    "lat": "51.56933",
    "lng": "-0.77415"
  },
  {
    "country": "GB",
    "name": "Marldon",
    "lat": "50.45512",
    "lng": "-3.59678"
  },
  {
    "country": "GB",
    "name": "Marlborough",
    "lat": "51.42027",
    "lng": "-1.72949"
  },
  {
    "country": "GB",
    "name": "Markyate",
    "lat": "51.83846",
    "lng": "-0.46345"
  },
  {
    "country": "GB",
    "name": "Marks Tey",
    "lat": "51.87628",
    "lng": "0.76424"
  },
  {
    "country": "GB",
    "name": "Markinch",
    "lat": "56.20214",
    "lng": "-3.13517"
  },
  {
    "country": "GB",
    "name": "Markfield",
    "lat": "52.68747",
    "lng": "-1.27476"
  },
  {
    "country": "GB",
    "name": "Market Weighton",
    "lat": "53.8631",
    "lng": "-0.66505"
  },
  {
    "country": "GB",
    "name": "Market Warsop",
    "lat": "53.20516",
    "lng": "-1.15257"
  },
  {
    "country": "GB",
    "name": "Market Rasen",
    "lat": "53.38764",
    "lng": "-0.33781"
  },
  {
    "country": "GB",
    "name": "Market Overton",
    "lat": "52.73806",
    "lng": "-0.6863"
  },
  {
    "country": "GB",
    "name": "Market Lavington",
    "lat": "51.28756",
    "lng": "-1.97729"
  },
  {
    "country": "GB",
    "name": "Market Harborough",
    "lat": "52.4776",
    "lng": "-0.92053"
  },
  {
    "country": "GB",
    "name": "Market Drayton",
    "lat": "52.90538",
    "lng": "-2.49012"
  },
  {
    "country": "GB",
    "name": "Market Deeping",
    "lat": "52.67654",
    "lng": "-0.31629"
  },
  {
    "country": "GB",
    "name": "Market Bosworth",
    "lat": "52.62428",
    "lng": "-1.40174"
  },
  {
    "country": "GB",
    "name": "Marholm",
    "lat": "52.60469",
    "lng": "-0.30824"
  },
  {
    "country": "GB",
    "name": "Margate",
    "lat": "51.38132",
    "lng": "1.38617"
  },
  {
    "country": "GB",
    "name": "Marden",
    "lat": "51.17482",
    "lng": "0.48855"
  },
  {
    "country": "GB",
    "name": "Marchwood",
    "lat": "50.88966",
    "lng": "-1.4544"
  },
  {
    "country": "GB",
    "name": "Marchwiel",
    "lat": "53.0239",
    "lng": "-2.96106"
  },
  {
    "country": "GB",
    "name": "Marcham",
    "lat": "51.66755",
    "lng": "-1.34295"
  },
  {
    "country": "GB",
    "name": "March",
    "lat": "52.55131",
    "lng": "0.08828"
  },
  {
    "country": "GB",
    "name": "Marazion",
    "lat": "50.12556",
    "lng": "-5.47505"
  },
  {
    "country": "GB",
    "name": "Mappleton",
    "lat": "53.87687",
    "lng": "-0.13664"
  },
  {
    "country": "GB",
    "name": "Manton",
    "lat": "53.5136",
    "lng": "-0.59438"
  },
  {
    "country": "GB",
    "name": "Manton",
    "lat": "52.63223",
    "lng": "-0.70038"
  },
  {
    "country": "GB",
    "name": "Manston",
    "lat": "50.95",
    "lng": "-2.26667"
  },
  {
    "country": "GB",
    "name": "Mansfield Woodhouse",
    "lat": "53.16495",
    "lng": "-1.19384"
  },
  {
    "country": "GB",
    "name": "Mansfield",
    "lat": "53.13333",
    "lng": "-1.2"
  },
  {
    "country": "GB",
    "name": "Manorbier",
    "lat": "51.64614",
    "lng": "-4.79901"
  },
  {
    "country": "GB",
    "name": "Manningtree",
    "lat": "51.94538",
    "lng": "1.06112"
  },
  {
    "country": "GB",
    "name": "Mangotsfield",
    "lat": "51.4878",
    "lng": "-2.50403"
  },
  {
    "country": "GB",
    "name": "Manea",
    "lat": "52.48487",
    "lng": "0.1793"
  },
  {
    "country": "GB",
    "name": "Manchester",
    "lat": "53.48095",
    "lng": "-2.23743"
  },
  {
    "country": "GB",
    "name": "Manby",
    "lat": "53.36291",
    "lng": "0.09653"
  },
  {
    "country": "GB",
    "name": "Malton",
    "lat": "54.13695",
    "lng": "-0.7996"
  },
  {
    "country": "GB",
    "name": "Maltby",
    "lat": "53.41667",
    "lng": "-1.2"
  },
  {
    "country": "GB",
    "name": "Malpas",
    "lat": "53.01667",
    "lng": "-2.76667"
  },
  {
    "country": "GB",
    "name": "Malmesbury",
    "lat": "51.58175",
    "lng": "-2.09708"
  },
  {
    "country": "GB",
    "name": "Maldon",
    "lat": "51.7311",
    "lng": "0.67463"
  },
  {
    "country": "GB",
    "name": "Mainstone",
    "lat": "52.48333",
    "lng": "-3.08333"
  },
  {
    "country": "GB",
    "name": "Maidstone",
    "lat": "51.26667",
    "lng": "0.51667"
  },
  {
    "country": "GB",
    "name": "Maiden Newton",
    "lat": "50.77909",
    "lng": "-2.57226"
  },
  {
    "country": "GB",
    "name": "Maidenhead",
    "lat": "51.52279",
    "lng": "-0.71986"
  },
  {
    "country": "GB",
    "name": "Magor",
    "lat": "51.57944",
    "lng": "-2.83139"
  },
  {
    "country": "GB",
    "name": "Maghull",
    "lat": "53.51619",
    "lng": "-2.94117"
  },
  {
    "country": "GB",
    "name": "Magheralin",
    "lat": "54.46695",
    "lng": "-6.2598"
  },
  {
    "country": "GB",
    "name": "Magherafelt",
    "lat": "54.75356",
    "lng": "-6.60656"
  },
  {
    "country": "GB",
    "name": "Maghera",
    "lat": "54.8439",
    "lng": "-6.67145"
  },
  {
    "country": "GB",
    "name": "Maesycwmmer",
    "lat": "51.63528",
    "lng": "-3.23222"
  },
  {
    "country": "GB",
    "name": "Maesteg",
    "lat": "51.60926",
    "lng": "-3.65823"
  },
  {
    "country": "GB",
    "name": "Maerdy",
    "lat": "51.67528",
    "lng": "-3.48667"
  },
  {
    "country": "GB",
    "name": "Maentwrog",
    "lat": "52.946",
    "lng": "-3.98787"
  },
  {
    "country": "GB",
    "name": "Madeley",
    "lat": "53",
    "lng": "-2.33333"
  },
  {
    "country": "GB",
    "name": "Madeley",
    "lat": "52.63333",
    "lng": "-2.43333"
  },
  {
    "country": "GB",
    "name": "Macmerry",
    "lat": "55.94045",
    "lng": "-2.90503"
  },
  {
    "country": "GB",
    "name": "Machynlleth",
    "lat": "52.59097",
    "lng": "-3.85051"
  },
  {
    "country": "GB",
    "name": "Machen",
    "lat": "51.59599",
    "lng": "-3.1419"
  },
  {
    "country": "GB",
    "name": "Macduff",
    "lat": "57.67012",
    "lng": "-2.49686"
  },
  {
    "country": "GB",
    "name": "Macclesfield",
    "lat": "53.26023",
    "lng": "-2.12564"
  },
  {
    "country": "GB",
    "name": "Mablethorpe",
    "lat": "53.3409",
    "lng": "0.26102"
  },
  {
    "country": "GB",
    "name": "Lytchett Matravers",
    "lat": "50.75826",
    "lng": "-2.07806"
  },
  {
    "country": "GB",
    "name": "Lynton",
    "lat": "51.22968",
    "lng": "-3.84131"
  },
  {
    "country": "GB",
    "name": "Lyneham",
    "lat": "51.51667",
    "lng": "-1.96667"
  },
  {
    "country": "GB",
    "name": "Lyndhurst",
    "lat": "50.87259",
    "lng": "-1.57662"
  },
  {
    "country": "GB",
    "name": "Lympstone",
    "lat": "50.64751",
    "lng": "-3.43162"
  },
  {
    "country": "GB",
    "name": "Lympne",
    "lat": "51.07773",
    "lng": "1.02808"
  },
  {
    "country": "GB",
    "name": "Lymm",
    "lat": "53.38105",
    "lng": "-2.47763"
  },
  {
    "country": "GB",
    "name": "Lymington",
    "lat": "50.75767",
    "lng": "-1.5443"
  },
  {
    "country": "GB",
    "name": "Lyminge",
    "lat": "51.12951",
    "lng": "1.08896"
  },
  {
    "country": "GB",
    "name": "Lyme Regis",
    "lat": "50.72654",
    "lng": "-2.93477"
  },
  {
    "country": "GB",
    "name": "Lydney",
    "lat": "51.72598",
    "lng": "-2.52605"
  },
  {
    "country": "GB",
    "name": "Lydiard Tregoze",
    "lat": "51.55",
    "lng": "-1.85"
  },
  {
    "country": "GB",
    "name": "Lydiard Millicent",
    "lat": "51.57117",
    "lng": "-1.86346"
  },
  {
    "country": "GB",
    "name": "Lydham",
    "lat": "52.51476",
    "lng": "-2.9797"
  },
  {
    "country": "GB",
    "name": "Lydd",
    "lat": "50.95132",
    "lng": "0.90654"
  },
  {
    "country": "GB",
    "name": "Lydbrook",
    "lat": "51.83763",
    "lng": "-2.57818"
  },
  {
    "country": "GB",
    "name": "Lutterworth",
    "lat": "52.45634",
    "lng": "-1.20218"
  },
  {
    "country": "GB",
    "name": "Luton",
    "lat": "51.87967",
    "lng": "-0.41748"
  },
  {
    "country": "GB",
    "name": "Lundin Links",
    "lat": "56.2124",
    "lng": "-2.95296"
  },
  {
    "country": "GB",
    "name": "Lund",
    "lat": "53.9192",
    "lng": "-0.52211"
  },
  {
    "country": "GB",
    "name": "Luncarty",
    "lat": "56.45308",
    "lng": "-3.47007"
  },
  {
    "country": "GB",
    "name": "Lugwardine",
    "lat": "52.06583",
    "lng": "-2.6578"
  },
  {
    "country": "GB",
    "name": "Ludlow",
    "lat": "52.37431",
    "lng": "-2.71311"
  },
  {
    "country": "GB",
    "name": "Ludgershall",
    "lat": "51.25558",
    "lng": "-1.6222"
  },
  {
    "country": "GB",
    "name": "Luddenden Foot",
    "lat": "53.71873",
    "lng": "-1.94582"
  },
  {
    "country": "GB",
    "name": "Luckington",
    "lat": "51.55444",
    "lng": "-2.24222"
  },
  {
    "country": "GB",
    "name": "Lowick",
    "lat": "55.65044",
    "lng": "-1.97809"
  },
  {
    "country": "GB",
    "name": "Low Etherley",
    "lat": "54.65349",
    "lng": "-1.74315"
  },
  {
    "country": "GB",
    "name": "Lowestoft",
    "lat": "52.47523",
    "lng": "1.75167"
  },
  {
    "country": "GB",
    "name": "Lower Kingswood",
    "lat": "51.26968",
    "lng": "-0.2123"
  },
  {
    "country": "GB",
    "name": "Lower Halstow",
    "lat": "51.37395",
    "lng": "0.66819"
  },
  {
    "country": "GB",
    "name": "Lower Bullingham",
    "lat": "52.03333",
    "lng": "-2.7"
  },
  {
    "country": "GB",
    "name": "Lower Brailes",
    "lat": "52.05034",
    "lng": "-1.54176"
  },
  {
    "country": "GB",
    "name": "Lowdham",
    "lat": "53.01205",
    "lng": "-1.00483"
  },
  {
    "country": "GB",
    "name": "Low Bradley",
    "lat": "53.93217",
    "lng": "-1.99646"
  },
  {
    "country": "GB",
    "name": "Low Ackworth",
    "lat": "53.65023",
    "lng": "-1.32334"
  },
  {
    "country": "GB",
    "name": "Louth",
    "lat": "53.36664",
    "lng": "-0.00438"
  },
  {
    "country": "GB",
    "name": "Loughton",
    "lat": "52.03037",
    "lng": "-0.78642"
  },
  {
    "country": "GB",
    "name": "Loughborough",
    "lat": "52.76667",
    "lng": "-1.2"
  },
  {
    "country": "GB",
    "name": "Lostwithiel",
    "lat": "50.40784",
    "lng": "-4.67023"
  },
  {
    "country": "GB",
    "name": "Lossiemouth",
    "lat": "57.72136",
    "lng": "-3.28341"
  },
  {
    "country": "GB",
    "name": "Longwick",
    "lat": "51.73607",
    "lng": "-0.85676"
  },
  {
    "country": "GB",
    "name": "Long Whatton",
    "lat": "52.80577",
    "lng": "-1.28506"
  },
  {
    "country": "GB",
    "name": "Longtown",
    "lat": "55.00925",
    "lng": "-2.96722"
  },
  {
    "country": "GB",
    "name": "Longtown",
    "lat": "51.95",
    "lng": "-2.98333"
  },
  {
    "country": "GB",
    "name": "Longton",
    "lat": "52.98333",
    "lng": "-2.13333"
  },
  {
    "country": "GB",
    "name": "Long Sutton",
    "lat": "51.21978",
    "lng": "-0.94293"
  },
  {
    "country": "GB",
    "name": "Long Stratton",
    "lat": "52.48803",
    "lng": "1.23478"
  },
  {
    "country": "GB",
    "name": "Longstanton",
    "lat": "52.28076",
    "lng": "0.04558"
  },
  {
    "country": "GB",
    "name": "Longridge",
    "lat": "53.83212",
    "lng": "-2.59964"
  },
  {
    "country": "GB",
    "name": "Longnor",
    "lat": "52.6",
    "lng": "-2.75"
  },
  {
    "country": "GB",
    "name": "Longniddry",
    "lat": "55.97543",
    "lng": "-2.89593"
  },
  {
    "country": "GB",
    "name": "Long Melford",
    "lat": "52.07481",
    "lng": "0.71639"
  },
  {
    "country": "GB",
    "name": "Long Lawford",
    "lat": "52.38176",
    "lng": "-1.30716"
  },
  {
    "country": "GB",
    "name": "Long Itchington",
    "lat": "52.28396",
    "lng": "-1.39243"
  },
  {
    "country": "GB",
    "name": "Longhoughton",
    "lat": "55.43131",
    "lng": "-1.61691"
  },
  {
    "country": "GB",
    "name": "Longhorsley",
    "lat": "55.24586",
    "lng": "-1.76914"
  },
  {
    "country": "GB",
    "name": "Longhope",
    "lat": "51.86667",
    "lng": "-2.45"
  },
  {
    "country": "GB",
    "name": "Longforgan",
    "lat": "56.45732",
    "lng": "-3.11437"
  },
  {
    "country": "GB",
    "name": "Longfield",
    "lat": "51.3969",
    "lng": "0.30212"
  },
  {
    "country": "GB",
    "name": "Long Eaton",
    "lat": "52.89855",
    "lng": "-1.27136"
  },
  {
    "country": "GB",
    "name": "Longdendale",
    "lat": "53.46667",
    "lng": "-2"
  },
  {
    "country": "GB",
    "name": "Long Crendon",
    "lat": "51.77294",
    "lng": "-0.99684"
  },
  {
    "country": "GB",
    "name": "Long Clawson",
    "lat": "52.83725",
    "lng": "-0.9288"
  },
  {
    "country": "GB",
    "name": "Long Buckby",
    "lat": "52.3026",
    "lng": "-1.08113"
  },
  {
    "country": "GB",
    "name": "Long Bennington",
    "lat": "52.99314",
    "lng": "-0.75803"
  },
  {
    "country": "GB",
    "name": "Long Ashton",
    "lat": "51.42997",
    "lng": "-2.66098"
  },
  {
    "country": "GB",
    "name": "Londonderry County Borough",
    "lat": "54.99721",
    "lng": "-7.30917"
  },
  {
    "country": "GB",
    "name": "Derry",
    "lat": "54.9981",
    "lng": "-7.30934"
  },
  {
    "country": "GB",
    "name": "City of London",
    "lat": "51.51279",
    "lng": "-0.09184"
  },
  {
    "country": "GB",
    "name": "London",
    "lat": "51.50853",
    "lng": "-0.12574"
  },
  {
    "country": "GB",
    "name": "Londesborough",
    "lat": "53.88333",
    "lng": "-0.68333"
  },
  {
    "country": "GB",
    "name": "Loftus",
    "lat": "54.55543",
    "lng": "-0.89459"
  },
  {
    "country": "GB",
    "name": "Lofthouse",
    "lat": "53.72947",
    "lng": "-1.49697"
  },
  {
    "country": "GB",
    "name": "Loddon",
    "lat": "52.5327",
    "lng": "1.48183"
  },
  {
    "country": "GB",
    "name": "Lockington",
    "lat": "53.91415",
    "lng": "-0.48572"
  },
  {
    "country": "GB",
    "name": "Locking",
    "lat": "51.33327",
    "lng": "-2.91387"
  },
  {
    "country": "GB",
    "name": "Lockerbie",
    "lat": "55.12302",
    "lng": "-3.35635"
  },
  {
    "country": "GB",
    "name": "Lochwinnoch",
    "lat": "55.79521",
    "lng": "-4.63034"
  },
  {
    "country": "GB",
    "name": "Lochmaben",
    "lat": "55.13011",
    "lng": "-3.44286"
  },
  {
    "country": "GB",
    "name": "Lochgilphead",
    "lat": "56.03796",
    "lng": "-5.43206"
  },
  {
    "country": "GB",
    "name": "Lochgelly",
    "lat": "56.12826",
    "lng": "-3.30964"
  },
  {
    "country": "GB",
    "name": "Locharbriggs",
    "lat": "55.10337",
    "lng": "-3.58438"
  },
  {
    "country": "GB",
    "name": "Loanhead",
    "lat": "55.87945",
    "lng": "-3.15874"
  },
  {
    "country": "GB",
    "name": "Llysfaen",
    "lat": "53.28333",
    "lng": "-3.66667"
  },
  {
    "country": "GB",
    "name": "Llwynypia",
    "lat": "51.63333",
    "lng": "-3.45"
  },
  {
    "country": "GB",
    "name": "Lledrod",
    "lat": "52.3",
    "lng": "-3.98333"
  },
  {
    "country": "GB",
    "name": "Llanwnda",
    "lat": "53.10139",
    "lng": "-4.27849"
  },
  {
    "country": "GB",
    "name": "Llanwinio",
    "lat": "51.90861",
    "lng": "-4.53056"
  },
  {
    "country": "GB",
    "name": "Llanwern",
    "lat": "51.58889",
    "lng": "-2.91361"
  },
  {
    "country": "GB",
    "name": "Llanveynoe",
    "lat": "51.96667",
    "lng": "-3"
  },
  {
    "country": "GB",
    "name": "Llanvaches",
    "lat": "51.62111",
    "lng": "-2.81833"
  },
  {
    "country": "GB",
    "name": "Llantwit Major",
    "lat": "51.4107",
    "lng": "-3.48632"
  },
  {
    "country": "GB",
    "name": "Llantwit Fardre",
    "lat": "51.5546",
    "lng": "-3.33241"
  },
  {
    "country": "GB",
    "name": "Llantrisant",
    "lat": "51.54028",
    "lng": "-3.37389"
  },
  {
    "country": "GB",
    "name": "Llansteffan",
    "lat": "51.77222",
    "lng": "-4.39139"
  },
  {
    "country": "GB",
    "name": "Llansawel",
    "lat": "52",
    "lng": "-4.01667"
  },
  {
    "country": "GB",
    "name": "Llansantffraid Glan Conwy",
    "lat": "53.26667",
    "lng": "-3.8"
  },
  {
    "country": "GB",
    "name": "Llansadwrn",
    "lat": "51.95",
    "lng": "-3.9"
  },
  {
    "country": "GB",
    "name": "Llanrwst",
    "lat": "53.14021",
    "lng": "-3.79527"
  },
  {
    "country": "GB",
    "name": "Llanrug",
    "lat": "53.14788",
    "lng": "-4.19596"
  },
  {
    "country": "GB",
    "name": "Llanrothal",
    "lat": "51.86667",
    "lng": "-2.76667"
  },
  {
    "country": "GB",
    "name": "Llanrhian",
    "lat": "51.9375",
    "lng": "-5.17389"
  },
  {
    "country": "GB",
    "name": "Llanllwchaiarn",
    "lat": "52.18333",
    "lng": "-4.36667"
  },
  {
    "country": "GB",
    "name": "Llanilar",
    "lat": "52.35657",
    "lng": "-4.02574"
  },
  {
    "country": "GB",
    "name": "Llanidloes",
    "lat": "52.44977",
    "lng": "-3.53997"
  },
  {
    "country": "GB",
    "name": "Llanharry",
    "lat": "51.51422",
    "lng": "-3.4324"
  },
  {
    "country": "GB",
    "name": "Llanharan",
    "lat": "51.53805",
    "lng": "-3.43906"
  },
  {
    "country": "GB",
    "name": "Llangynog",
    "lat": "52.83333",
    "lng": "-3.4"
  },
  {
    "country": "GB",
    "name": "Llangynidr",
    "lat": "51.8673",
    "lng": "-3.22762"
  },
  {
    "country": "GB",
    "name": "Llangybi",
    "lat": "52.15",
    "lng": "-4.05"
  },
  {
    "country": "GB",
    "name": "Llangwm",
    "lat": "51.69611",
    "lng": "-2.83"
  },
  {
    "country": "GB",
    "name": "Llangwm",
    "lat": "52.98333",
    "lng": "-3.53333"
  },
  {
    "country": "GB",
    "name": "Llangollen",
    "lat": "52.96829",
    "lng": "-3.17127"
  },
  {
    "country": "GB",
    "name": "Llangoed",
    "lat": "53.2942",
    "lng": "-4.08772"
  },
  {
    "country": "GB",
    "name": "Llangybi",
    "lat": "51.66583",
    "lng": "-2.90806"
  },
  {
    "country": "GB",
    "name": "Llangefni",
    "lat": "53.25561",
    "lng": "-4.31063"
  },
  {
    "country": "GB",
    "name": "Llangathen",
    "lat": "51.87972",
    "lng": "-4.05611"
  },
  {
    "country": "GB",
    "name": "Llangan",
    "lat": "51.48694",
    "lng": "-3.50056"
  },
  {
    "country": "GB",
    "name": "Llangain",
    "lat": "51.81833",
    "lng": "-4.3475"
  },
  {
    "country": "GB",
    "name": "Llanfynydd",
    "lat": "51.92806",
    "lng": "-4.09889"
  },
  {
    "country": "GB",
    "name": "Llanfyllin",
    "lat": "52.7657",
    "lng": "-3.27187"
  },
  {
    "country": "GB",
    "name": "Llanfechain",
    "lat": "52.77463",
    "lng": "-3.20273"
  },
  {
    "country": "GB",
    "name": "Llanfairpwllgwyngyll",
    "lat": "53.22141",
    "lng": "-4.20329"
  },
  {
    "country": "GB",
    "name": "Llanfairfechan",
    "lat": "53.25779",
    "lng": "-3.97423"
  },
  {
    "country": "GB",
    "name": "Llanfair Caereinion",
    "lat": "52.6479",
    "lng": "-3.32668"
  },
  {
    "country": "GB",
    "name": "Llanfair",
    "lat": "52.84415",
    "lng": "-4.11541"
  },
  {
    "country": "GB",
    "name": "Llanfaethlu",
    "lat": "53.3524",
    "lng": "-4.53418"
  },
  {
    "country": "GB",
    "name": "Llanfachraeth",
    "lat": "53.31244",
    "lng": "-4.53336"
  },
  {
    "country": "GB",
    "name": "Llanerchymedd",
    "lat": "53.33055",
    "lng": "-4.377"
  },
  {
    "country": "GB",
    "name": "Llanelli",
    "lat": "51.68195",
    "lng": "-4.16191"
  },
  {
    "country": "GB",
    "name": "Llandysul",
    "lat": "52.04166",
    "lng": "-4.30909"
  },
  {
    "country": "GB",
    "name": "Llandybie",
    "lat": "51.82044",
    "lng": "-4.0071"
  },
  {
    "country": "GB",
    "name": "Llandudno",
    "lat": "53.32498",
    "lng": "-3.83148"
  },
  {
    "country": "GB",
    "name": "Llandrindod Wells",
    "lat": "52.24164",
    "lng": "-3.37868"
  },
  {
    "country": "GB",
    "name": "Llandrillo",
    "lat": "52.92277",
    "lng": "-3.4376"
  },
  {
    "country": "GB",
    "name": "Llanddowror",
    "lat": "51.80167",
    "lng": "-4.53139"
  },
  {
    "country": "GB",
    "name": "Llandovery",
    "lat": "51.99415",
    "lng": "-3.79637"
  },
  {
    "country": "GB",
    "name": "Llandeilo",
    "lat": "51.88459",
    "lng": "-3.99154"
  },
  {
    "country": "GB",
    "name": "Llandegla",
    "lat": "53.05901",
    "lng": "-3.19882"
  },
  {
    "country": "GB",
    "name": "Llanddeusant",
    "lat": "51.9",
    "lng": "-3.78333"
  },
  {
    "country": "GB",
    "name": "Llanddarog",
    "lat": "51.82722",
    "lng": "-4.17444"
  },
  {
    "country": "GB",
    "name": "Llancillo",
    "lat": "51.91667",
    "lng": "-2.93333"
  },
  {
    "country": "GB",
    "name": "Llanbradach",
    "lat": "51.60639",
    "lng": "-3.23028"
  },
  {
    "country": "GB",
    "name": "Llanboidy",
    "lat": "51.87889",
    "lng": "-4.59278"
  },
  {
    "country": "GB",
    "name": "Llanberis",
    "lat": "53.11809",
    "lng": "-4.12923"
  },
  {
    "country": "GB",
    "name": "Llanbedr",
    "lat": "52.81667",
    "lng": "-4.1"
  },
  {
    "country": "GB",
    "name": "Llanbadoc",
    "lat": "51.695",
    "lng": "-2.90361"
  },
  {
    "country": "GB",
    "name": "Llanarth",
    "lat": "52.19424",
    "lng": "-4.30811"
  },
  {
    "country": "GB",
    "name": "Llanarth",
    "lat": "51.78333",
    "lng": "-2.9"
  },
  {
    "country": "GB",
    "name": "Livingston",
    "lat": "55.90288",
    "lng": "-3.52261"
  },
  {
    "country": "GB",
    "name": "Liversedge",
    "lat": "53.70514",
    "lng": "-1.69327"
  },
  {
    "country": "GB",
    "name": "Liverpool",
    "lat": "53.41058",
    "lng": "-2.97794"
  },
  {
    "country": "GB",
    "name": "Little Weighton",
    "lat": "53.79021",
    "lng": "-0.50679"
  },
  {
    "country": "GB",
    "name": "Littleport",
    "lat": "52.45784",
    "lng": "0.30603"
  },
  {
    "country": "GB",
    "name": "Little Paxton",
    "lat": "52.25045",
    "lng": "-0.25801"
  },
  {
    "country": "GB",
    "name": "Little Lever",
    "lat": "53.56346",
    "lng": "-2.37803"
  },
  {
    "country": "GB",
    "name": "Little Hulton",
    "lat": "53.53333",
    "lng": "-2.41667"
  },
  {
    "country": "GB",
    "name": "Little Houghton",
    "lat": "53.54576",
    "lng": "-1.35999"
  },
  {
    "country": "GB",
    "name": "Littlehampton",
    "lat": "50.81137",
    "lng": "-0.54078"
  },
  {
    "country": "GB",
    "name": "Little Eaton",
    "lat": "52.97028",
    "lng": "-1.4595"
  },
  {
    "country": "GB",
    "name": "Little Dunmow",
    "lat": "51.86096",
    "lng": "0.41478"
  },
  {
    "country": "GB",
    "name": "Little Clacton",
    "lat": "51.82557",
    "lng": "1.14215"
  },
  {
    "country": "GB",
    "name": "Littlebourne",
    "lat": "51.27445",
    "lng": "1.16687"
  },
  {
    "country": "GB",
    "name": "Littleborough",
    "lat": "53.64413",
    "lng": "-2.09581"
  },
  {
    "country": "GB",
    "name": "Little Barford",
    "lat": "52.19898",
    "lng": "-0.2729"
  },
  {
    "country": "GB",
    "name": "Little Amwell",
    "lat": "51.78333",
    "lng": "-0.03333"
  },
  {
    "country": "GB",
    "name": "Litherland",
    "lat": "53.46993",
    "lng": "-2.99809"
  },
  {
    "country": "GB",
    "name": "Liss",
    "lat": "51.04277",
    "lng": "-0.89238"
  },
  {
    "country": "GB",
    "name": "Lisnaskea",
    "lat": "54.25",
    "lng": "-7.45"
  },
  {
    "country": "GB",
    "name": "Liskeard",
    "lat": "50.4545",
    "lng": "-4.46517"
  },
  {
    "country": "GB",
    "name": "Lisburn",
    "lat": "54.52337",
    "lng": "-6.03527"
  },
  {
    "country": "GB",
    "name": "Liphook",
    "lat": "51.07673",
    "lng": "-0.8032"
  },
  {
    "country": "GB",
    "name": "Linton upon Ouse",
    "lat": "54.04639",
    "lng": "-1.2492"
  },
  {
    "country": "GB",
    "name": "Linton",
    "lat": "52.09783",
    "lng": "0.27672"
  },
  {
    "country": "GB",
    "name": "Linton",
    "lat": "51.92529",
    "lng": "-2.49669"
  },
  {
    "country": "GB",
    "name": "Linthwaite",
    "lat": "53.62418",
    "lng": "-1.85017"
  },
  {
    "country": "GB",
    "name": "Linlithgow",
    "lat": "55.97639",
    "lng": "-3.60364"
  },
  {
    "country": "GB",
    "name": "Lingwood",
    "lat": "52.62104",
    "lng": "1.48616"
  },
  {
    "country": "GB",
    "name": "Lingfield",
    "lat": "51.17719",
    "lng": "-0.01558"
  },
  {
    "country": "GB",
    "name": "Lingen",
    "lat": "52.3",
    "lng": "-2.93333"
  },
  {
    "country": "GB",
    "name": "Lingdale",
    "lat": "54.53787",
    "lng": "-0.95864"
  },
  {
    "country": "GB",
    "name": "Lincoln",
    "lat": "53.22683",
    "lng": "-0.53792"
  },
  {
    "country": "GB",
    "name": "Limpley Stoke",
    "lat": "51.34487",
    "lng": "-2.31409"
  },
  {
    "country": "GB",
    "name": "Limekilns",
    "lat": "56.03336",
    "lng": "-3.47713"
  },
  {
    "country": "GB",
    "name": "Limavady",
    "lat": "55.05045",
    "lng": "-6.95074"
  },
  {
    "country": "GB",
    "name": "Lifton",
    "lat": "50.64356",
    "lng": "-4.28216"
  },
  {
    "country": "GB",
    "name": "Lidlington",
    "lat": "52.04154",
    "lng": "-0.55914"
  },
  {
    "country": "GB",
    "name": "Lichfield",
    "lat": "52.68154",
    "lng": "-1.82549"
  },
  {
    "country": "GB",
    "name": "Lhanbryde",
    "lat": "57.63529",
    "lng": "-3.21839"
  },
  {
    "country": "GB",
    "name": "Leysdown-on-Sea",
    "lat": "51.3973",
    "lng": "0.92156"
  },
  {
    "country": "GB",
    "name": "Leyland",
    "lat": "53.69786",
    "lng": "-2.68758"
  },
  {
    "country": "GB",
    "name": "Leyburn",
    "lat": "54.31004",
    "lng": "-1.83041"
  },
  {
    "country": "GB",
    "name": "Lewes",
    "lat": "50.87398",
    "lng": "0.0088"
  },
  {
    "country": "GB",
    "name": "Leven",
    "lat": "56.2",
    "lng": "-3"
  },
  {
    "country": "GB",
    "name": "Leven",
    "lat": "53.89028",
    "lng": "-0.31783"
  },
  {
    "country": "GB",
    "name": "Leuchars",
    "lat": "56.38174",
    "lng": "-2.88253"
  },
  {
    "country": "GB",
    "name": "Letterston",
    "lat": "51.92757",
    "lng": "-4.99141"
  },
  {
    "country": "GB",
    "name": "Letham",
    "lat": "56.62683",
    "lng": "-2.7706"
  },
  {
    "country": "GB",
    "name": "Letchworth",
    "lat": "51.97944",
    "lng": "-0.2284"
  },
  {
    "country": "GB",
    "name": "Lesmahagow",
    "lat": "55.63668",
    "lng": "-3.88736"
  },
  {
    "country": "GB",
    "name": "Leslie",
    "lat": "56.2",
    "lng": "-3.21667"
  },
  {
    "country": "GB",
    "name": "Lesbury",
    "lat": "55.39832",
    "lng": "-1.6283"
  },
  {
    "country": "GB",
    "name": "Lerwick",
    "lat": "60.15339",
    "lng": "-1.14427"
  },
  {
    "country": "GB",
    "name": "Leominster",
    "lat": "52.22583",
    "lng": "-2.74491"
  },
  {
    "country": "GB",
    "name": "Lennoxtown",
    "lat": "55.97263",
    "lng": "-4.20001"
  },
  {
    "country": "GB",
    "name": "Lenham",
    "lat": "51.23705",
    "lng": "0.71892"
  },
  {
    "country": "GB",
    "name": "Leiston",
    "lat": "52.20611",
    "lng": "1.57757"
  },
  {
    "country": "GB",
    "name": "Leighton Buzzard",
    "lat": "51.91722",
    "lng": "-0.65802"
  },
  {
    "country": "GB",
    "name": "Leigh-on-Sea",
    "lat": "51.54297",
    "lng": "0.64905"
  },
  {
    "country": "GB",
    "name": "Leigh",
    "lat": "53.49642",
    "lng": "-2.51973"
  },
  {
    "country": "GB",
    "name": "Leigh",
    "lat": "51.61667",
    "lng": "-1.9"
  },
  {
    "country": "GB",
    "name": "Leicester",
    "lat": "52.6386",
    "lng": "-1.13169"
  },
  {
    "country": "GB",
    "name": "Leeswood",
    "lat": "53.13347",
    "lng": "-3.09466"
  },
  {
    "country": "GB",
    "name": "Lee-on-the-Solent",
    "lat": "50.80169",
    "lng": "-1.20174"
  },
  {
    "country": "GB",
    "name": "Leek Wootton",
    "lat": "52.31782",
    "lng": "-1.57933"
  },
  {
    "country": "GB",
    "name": "Leek",
    "lat": "53.10434",
    "lng": "-2.02207"
  },
  {
    "country": "GB",
    "name": "Leeds",
    "lat": "53.79648",
    "lng": "-1.54785"
  },
  {
    "country": "GB",
    "name": "Ledston",
    "lat": "53.75254",
    "lng": "-1.34355"
  },
  {
    "country": "GB",
    "name": "Ledsham",
    "lat": "53.76322",
    "lng": "-1.30857"
  },
  {
    "country": "GB",
    "name": "Ledsham",
    "lat": "53.26667",
    "lng": "-2.96667"
  },
  {
    "country": "GB",
    "name": "Ledbury",
    "lat": "52.03639",
    "lng": "-2.42635"
  },
  {
    "country": "GB",
    "name": "Leconfield",
    "lat": "53.8773",
    "lng": "-0.45729"
  },
  {
    "country": "GB",
    "name": "Lechlade",
    "lat": "51.69403",
    "lng": "-1.69128"
  },
  {
    "country": "GB",
    "name": "Leatherhead",
    "lat": "51.29652",
    "lng": "-0.3338"
  },
  {
    "country": "GB",
    "name": "Leasingham",
    "lat": "53.02573",
    "lng": "-0.42606"
  },
  {
    "country": "GB",
    "name": "Royal Leamington Spa",
    "lat": "52.2852",
    "lng": "-1.52"
  },
  {
    "country": "GB",
    "name": "Lea",
    "lat": "51.9",
    "lng": "-2.5"
  },
  {
    "country": "GB",
    "name": "Layer de la Haye",
    "lat": "51.84593",
    "lng": "0.85745"
  },
  {
    "country": "GB",
    "name": "Laxton",
    "lat": "53.72005",
    "lng": "-0.80329"
  },
  {
    "country": "GB",
    "name": "Law",
    "lat": "55.75",
    "lng": "-3.88333"
  },
  {
    "country": "GB",
    "name": "Lavenham",
    "lat": "52.10861",
    "lng": "0.79617"
  },
  {
    "country": "GB",
    "name": "Lavendon",
    "lat": "52.17279",
    "lng": "-0.66109"
  },
  {
    "country": "GB",
    "name": "Laurencekirk",
    "lat": "56.83338",
    "lng": "-2.4654"
  },
  {
    "country": "GB",
    "name": "Launceston",
    "lat": "50.63699",
    "lng": "-4.36006"
  },
  {
    "country": "GB",
    "name": "Lauder",
    "lat": "55.71908",
    "lng": "-2.74755"
  },
  {
    "country": "GB",
    "name": "Lathbury",
    "lat": "52.09881",
    "lng": "-0.72132"
  },
  {
    "country": "GB",
    "name": "Latchingdon and Snoreham",
    "lat": "51.6716",
    "lng": "0.72578"
  },
  {
    "country": "GB",
    "name": "Lartington",
    "lat": "54.55415",
    "lng": "-1.97239"
  },
  {
    "country": "GB",
    "name": "Larne",
    "lat": "54.85",
    "lng": "-5.81667"
  },
  {
    "country": "GB",
    "name": "Lark Hill",
    "lat": "51.2",
    "lng": "-1.81667"
  },
  {
    "country": "GB",
    "name": "Larkhall",
    "lat": "55.73333",
    "lng": "-3.96667"
  },
  {
    "country": "GB",
    "name": "Largs",
    "lat": "55.79629",
    "lng": "-4.86337"
  },
  {
    "country": "GB",
    "name": "Larbert",
    "lat": "56.02246",
    "lng": "-3.82872"
  },
  {
    "country": "GB",
    "name": "Llangwm",
    "lat": "51.74833",
    "lng": "-4.91361"
  },
  {
    "country": "GB",
    "name": "Langtoft",
    "lat": "52.69834",
    "lng": "-0.3404"
  },
  {
    "country": "GB",
    "name": "Langport",
    "lat": "51.03778",
    "lng": "-2.82806"
  },
  {
    "country": "GB",
    "name": "Langley Park",
    "lat": "54.79979",
    "lng": "-1.67005"
  },
  {
    "country": "GB",
    "name": "Langholm",
    "lat": "55.15101",
    "lng": "-2.99889"
  },
  {
    "country": "GB",
    "name": "Langho",
    "lat": "53.80217",
    "lng": "-2.45076"
  },
  {
    "country": "GB",
    "name": "Langham",
    "lat": "52.69152",
    "lng": "-0.75385"
  },
  {
    "country": "GB",
    "name": "Langford",
    "lat": "52.0546",
    "lng": "-0.27165"
  },
  {
    "country": "GB",
    "name": "Landrake",
    "lat": "50.42265",
    "lng": "-4.29023"
  },
  {
    "country": "GB",
    "name": "Landore",
    "lat": "51.64396",
    "lng": "-3.94143"
  },
  {
    "country": "GB",
    "name": "Landewednack",
    "lat": "49.96969",
    "lng": "-5.19718"
  },
  {
    "country": "GB",
    "name": "Lanchester",
    "lat": "54.82108",
    "lng": "-1.74256"
  },
  {
    "country": "GB",
    "name": "Lancaster",
    "lat": "54.04649",
    "lng": "-2.79988"
  },
  {
    "country": "GB",
    "name": "Lanark",
    "lat": "55.67371",
    "lng": "-3.7817"
  },
  {
    "country": "GB",
    "name": "Lampeter",
    "lat": "52.11285",
    "lng": "-4.08039"
  },
  {
    "country": "GB",
    "name": "Lamlash",
    "lat": "55.53358",
    "lng": "-5.12956"
  },
  {
    "country": "GB",
    "name": "Lambourn",
    "lat": "51.50805",
    "lng": "-1.53105"
  },
  {
    "country": "GB",
    "name": "Lamberhurst",
    "lat": "51.1005",
    "lng": "0.38967"
  },
  {
    "country": "GB",
    "name": "Lakenheath",
    "lat": "52.41755",
    "lng": "0.52211"
  },
  {
    "country": "GB",
    "name": "Ladybank",
    "lat": "56.27421",
    "lng": "-3.1239"
  },
  {
    "country": "GB",
    "name": "Lacock",
    "lat": "51.41528",
    "lng": "-2.12194"
  },
  {
    "country": "GB",
    "name": "Laceby",
    "lat": "53.54092",
    "lng": "-0.1683"
  },
  {
    "country": "GB",
    "name": "Knutsford",
    "lat": "53.30289",
    "lng": "-2.37482"
  },
  {
    "country": "GB",
    "name": "Knowsley",
    "lat": "53.45401",
    "lng": "-2.85396"
  },
  {
    "country": "GB",
    "name": "Knowle",
    "lat": "52.38333",
    "lng": "-1.73333"
  },
  {
    "country": "GB",
    "name": "Knottingley",
    "lat": "53.70778",
    "lng": "-1.25639"
  },
  {
    "country": "GB",
    "name": "Knighton",
    "lat": "52.34251",
    "lng": "-3.04708"
  },
  {
    "country": "GB",
    "name": "Knebworth",
    "lat": "51.86674",
    "lng": "-0.18394"
  },
  {
    "country": "GB",
    "name": "Knaresborough",
    "lat": "54.0091",
    "lng": "-1.46851"
  },
  {
    "country": "GB",
    "name": "Kiveton Park",
    "lat": "53.3412",
    "lng": "-1.25498"
  },
  {
    "country": "GB",
    "name": "Kislingbury",
    "lat": "52.22976",
    "lng": "-0.97914"
  },
  {
    "country": "GB",
    "name": "Kirton in Lindsey",
    "lat": "53.47548",
    "lng": "-0.59566"
  },
  {
    "country": "GB",
    "name": "Kirton",
    "lat": "52.92774",
    "lng": "-0.06008"
  },
  {
    "country": "GB",
    "name": "Kirriemuir",
    "lat": "56.67398",
    "lng": "-3.00343"
  },
  {
    "country": "GB",
    "name": "Kirkwall",
    "lat": "58.98479",
    "lng": "-2.95873"
  },
  {
    "country": "GB",
    "name": "Kirk Sandall",
    "lat": "53.56211",
    "lng": "-1.06876"
  },
  {
    "country": "GB",
    "name": "Kirknewton",
    "lat": "55.88754",
    "lng": "-3.41898"
  },
  {
    "country": "GB",
    "name": "Kirknewton",
    "lat": "55.55",
    "lng": "-2.13333"
  },
  {
    "country": "GB",
    "name": "Kirkliston",
    "lat": "55.95364",
    "lng": "-3.40288"
  },
  {
    "country": "GB",
    "name": "Kirkintilloch",
    "lat": "55.93933",
    "lng": "-4.15262"
  },
  {
    "country": "GB",
    "name": "Kirkham",
    "lat": "53.78244",
    "lng": "-2.87189"
  },
  {
    "country": "GB",
    "name": "Kirk Ella",
    "lat": "53.75399",
    "lng": "-0.4549"
  },
  {
    "country": "GB",
    "name": "Kirkcudbright",
    "lat": "54.8383",
    "lng": "-4.04908"
  },
  {
    "country": "GB",
    "name": "Kirkconnel",
    "lat": "55.38561",
    "lng": "-3.99836"
  },
  {
    "country": "GB",
    "name": "Kirkcaldy",
    "lat": "56.11683",
    "lng": "-3.15999"
  },
  {
    "country": "GB",
    "name": "Kirkby Stephen",
    "lat": "54.47229",
    "lng": "-2.34865"
  },
  {
    "country": "GB",
    "name": "Kirkbymoorside",
    "lat": "54.27014",
    "lng": "-0.93218"
  },
  {
    "country": "GB",
    "name": "Kirkby Lonsdale",
    "lat": "54.20259",
    "lng": "-2.59827"
  },
  {
    "country": "GB",
    "name": "Kirkby in Ashfield",
    "lat": "53.09982",
    "lng": "-1.24379"
  },
  {
    "country": "GB",
    "name": "Kirkby",
    "lat": "53.48138",
    "lng": "-2.89215"
  },
  {
    "country": "GB",
    "name": "Kirkburton",
    "lat": "53.61047",
    "lng": "-1.70292"
  },
  {
    "country": "GB",
    "name": "Kircubbin",
    "lat": "54.48739",
    "lng": "-5.53385"
  },
  {
    "country": "GB",
    "name": "Kirby Underdale",
    "lat": "54.01715",
    "lng": "-0.77102"
  },
  {
    "country": "GB",
    "name": "Kirby Muxloe",
    "lat": "52.63025",
    "lng": "-1.22755"
  },
  {
    "country": "GB",
    "name": "Kippen",
    "lat": "56.12673",
    "lng": "-4.17083"
  },
  {
    "country": "GB",
    "name": "Kippax",
    "lat": "53.76687",
    "lng": "-1.37099"
  },
  {
    "country": "GB",
    "name": "Kinvere",
    "lat": "52.45",
    "lng": "-2.23333"
  },
  {
    "country": "GB",
    "name": "Kintore",
    "lat": "57.23721",
    "lng": "-2.3454"
  },
  {
    "country": "GB",
    "name": "Kintbury",
    "lat": "51.39958",
    "lng": "-1.44865"
  },
  {
    "country": "GB",
    "name": "Kinsham",
    "lat": "52.28333",
    "lng": "-2.93333"
  },
  {
    "country": "GB",
    "name": "Kinross",
    "lat": "56.20466",
    "lng": "-3.42138"
  },
  {
    "country": "GB",
    "name": "Kinnersley",
    "lat": "52.13333",
    "lng": "-2.95"
  },
  {
    "country": "GB",
    "name": "Kinloss",
    "lat": "57.63494",
    "lng": "-3.57012"
  },
  {
    "country": "GB",
    "name": "Kingussie",
    "lat": "57.07996",
    "lng": "-4.05231"
  },
  {
    "country": "GB",
    "name": "Kington",
    "lat": "52.20408",
    "lng": "-3.02553"
  },
  {
    "country": "GB",
    "name": "Kington",
    "lat": "52.2",
    "lng": "-2.01667"
  },
  {
    "country": "GB",
    "name": "Kings Worthy",
    "lat": "51.08862",
    "lng": "-1.2978"
  },
  {
    "country": "GB",
    "name": "Kingswood",
    "lat": "51.62583",
    "lng": "-2.36722"
  },
  {
    "country": "GB",
    "name": "Kingswood",
    "lat": "51.45278",
    "lng": "-2.50833"
  },
  {
    "country": "GB",
    "name": "Kingswinford",
    "lat": "52.49755",
    "lng": "-2.16889"
  },
  {
    "country": "GB",
    "name": "Kingston upon Hull",
    "lat": "53.7446",
    "lng": "-0.33525"
  },
  {
    "country": "GB",
    "name": "Kingston Seymour",
    "lat": "51.39833",
    "lng": "-2.86111"
  },
  {
    "country": "GB",
    "name": "Kingstone",
    "lat": "52.01667",
    "lng": "-2.83333"
  },
  {
    "country": "GB",
    "name": "Kingston Bagpuize",
    "lat": "51.6815",
    "lng": "-1.42041"
  },
  {
    "country": "GB",
    "name": "Kingsteignton",
    "lat": "50.55",
    "lng": "-3.58333"
  },
  {
    "country": "GB",
    "name": "Kings Sutton",
    "lat": "52.02313",
    "lng": "-1.27613"
  },
  {
    "country": "GB",
    "name": "King's Lynn",
    "lat": "52.75172",
    "lng": "0.39516"
  },
  {
    "country": "GB",
    "name": "Kingsley",
    "lat": "53.26667",
    "lng": "-2.66667"
  },
  {
    "country": "GB",
    "name": "Kings Langley",
    "lat": "51.71395",
    "lng": "-0.45044"
  },
  {
    "country": "GB",
    "name": "Kingsland",
    "lat": "52.24911",
    "lng": "-2.81542"
  },
  {
    "country": "GB",
    "name": "Kingskettle",
    "lat": "56.26215",
    "lng": "-3.11693"
  },
  {
    "country": "GB",
    "name": "Kingskerswell",
    "lat": "50.49915",
    "lng": "-3.58195"
  },
  {
    "country": "GB",
    "name": "Kingsclere",
    "lat": "51.32487",
    "lng": "-1.24339"
  },
  {
    "country": "GB",
    "name": "Kingsbury",
    "lat": "52.56106",
    "lng": "-1.67936"
  },
  {
    "country": "GB",
    "name": "Kingsbridge",
    "lat": "50.28451",
    "lng": "-3.77638"
  },
  {
    "country": "GB",
    "name": "Kinglassie",
    "lat": "56.17371",
    "lng": "-3.24241"
  },
  {
    "country": "GB",
    "name": "Kinghorn",
    "lat": "56.06896",
    "lng": "-3.17607"
  },
  {
    "country": "GB",
    "name": "Kineton",
    "lat": "52.15645",
    "lng": "-1.51148"
  },
  {
    "country": "GB",
    "name": "Kincardine",
    "lat": "56.06945",
    "lng": "-3.71964"
  },
  {
    "country": "GB",
    "name": "Kimpton",
    "lat": "51.85089",
    "lng": "-0.2998"
  },
  {
    "country": "GB",
    "name": "Kimbolton",
    "lat": "52.29704",
    "lng": "-0.38916"
  },
  {
    "country": "GB",
    "name": "Kimbolton",
    "lat": "52.25",
    "lng": "-2.7"
  },
  {
    "country": "GB",
    "name": "Kimberley",
    "lat": "52.98333",
    "lng": "-1.26667"
  },
  {
    "country": "GB",
    "name": "Kilwinning",
    "lat": "55.65333",
    "lng": "-4.70666"
  },
  {
    "country": "GB",
    "name": "Kilsyth",
    "lat": "55.97596",
    "lng": "-4.05916"
  },
  {
    "country": "GB",
    "name": "Kilsby",
    "lat": "52.33375",
    "lng": "-1.17505"
  },
  {
    "country": "GB",
    "name": "Kilrea",
    "lat": "54.95091",
    "lng": "-6.55695"
  },
  {
    "country": "GB",
    "name": "Kilpin",
    "lat": "53.7328",
    "lng": "-0.83397"
  },
  {
    "country": "GB",
    "name": "Kilmington",
    "lat": "51.12694",
    "lng": "-2.32694"
  },
  {
    "country": "GB",
    "name": "Kilmaurs",
    "lat": "55.63801",
    "lng": "-4.5273"
  },
  {
    "country": "GB",
    "name": "Kilmarnock",
    "lat": "55.61171",
    "lng": "-4.49581"
  },
  {
    "country": "GB",
    "name": "Kilmacolm",
    "lat": "55.8947",
    "lng": "-4.62643"
  },
  {
    "country": "GB",
    "name": "Killyleagh",
    "lat": "54.40135",
    "lng": "-5.648"
  },
  {
    "country": "GB",
    "name": "Killearn",
    "lat": "56.04239",
    "lng": "-4.3684"
  },
  {
    "country": "GB",
    "name": "Killamarsh",
    "lat": "53.32395",
    "lng": "-1.31688"
  },
  {
    "country": "GB",
    "name": "Kilkeel",
    "lat": "54.06196",
    "lng": "-6.00308"
  },
  {
    "country": "GB",
    "name": "Kilham",
    "lat": "54.06413",
    "lng": "-0.38057"
  },
  {
    "country": "GB",
    "name": "Kilgetty",
    "lat": "51.73203",
    "lng": "-4.71983"
  },
  {
    "country": "GB",
    "name": "Kilcreggan",
    "lat": "55.9846",
    "lng": "-4.821"
  },
  {
    "country": "GB",
    "name": "Kilburn",
    "lat": "53.0058",
    "lng": "-1.43869"
  },
  {
    "country": "GB",
    "name": "Kilbirnie",
    "lat": "55.75082",
    "lng": "-4.68791"
  },
  {
    "country": "GB",
    "name": "Kilbarchan",
    "lat": "55.8362",
    "lng": "-4.55356"
  },
  {
    "country": "GB",
    "name": "Kidwelly",
    "lat": "51.73639",
    "lng": "-4.30333"
  },
  {
    "country": "GB",
    "name": "Kidsgrove",
    "lat": "53.08691",
    "lng": "-2.23777"
  },
  {
    "country": "GB",
    "name": "Kidlington",
    "lat": "51.82166",
    "lng": "-1.2886"
  },
  {
    "country": "GB",
    "name": "Kidderminster",
    "lat": "52.38819",
    "lng": "-2.25"
  },
  {
    "country": "GB",
    "name": "Kibworth Harcourt",
    "lat": "52.54439",
    "lng": "-0.99491"
  },
  {
    "country": "GB",
    "name": "Keynsham",
    "lat": "51.41387",
    "lng": "-2.4978"
  },
  {
    "country": "GB",
    "name": "Keyingham",
    "lat": "53.70961",
    "lng": "-0.11325"
  },
  {
    "country": "GB",
    "name": "Ketton",
    "lat": "52.62804",
    "lng": "-0.55459"
  },
  {
    "country": "GB",
    "name": "Kettering",
    "lat": "52.39836",
    "lng": "-0.72571"
  },
  {
    "country": "GB",
    "name": "Keswick",
    "lat": "54.59947",
    "lng": "-3.13256"
  },
  {
    "country": "GB",
    "name": "Kessingland",
    "lat": "52.41987",
    "lng": "1.70878"
  },
  {
    "country": "GB",
    "name": "Keresley",
    "lat": "52.45156",
    "lng": "-1.53319"
  },
  {
    "country": "GB",
    "name": "Kenton",
    "lat": "50.63978",
    "lng": "-3.47151"
  },
  {
    "country": "GB",
    "name": "Kensworth",
    "lat": "51.85173",
    "lng": "-0.50386"
  },
  {
    "country": "GB",
    "name": "Kensington",
    "lat": "51.50094",
    "lng": "-0.19175"
  },
  {
    "country": "GB",
    "name": "Kennoway",
    "lat": "56.21081",
    "lng": "-3.04917"
  },
  {
    "country": "GB",
    "name": "Kennington",
    "lat": "51.1674",
    "lng": "0.88491"
  },
  {
    "country": "GB",
    "name": "Kenn",
    "lat": "51.41667",
    "lng": "-2.85"
  },
  {
    "country": "GB",
    "name": "Kenley",
    "lat": "52.6",
    "lng": "-2.63333"
  },
  {
    "country": "GB",
    "name": "Kenilworth",
    "lat": "52.34958",
    "lng": "-1.58276"
  },
  {
    "country": "GB",
    "name": "Kendal",
    "lat": "54.32681",
    "lng": "-2.74757"
  },
  {
    "country": "GB",
    "name": "Kemsing",
    "lat": "51.30604",
    "lng": "0.22917"
  },
  {
    "country": "GB",
    "name": "Kempston",
    "lat": "52.11599",
    "lng": "-0.50044"
  },
  {
    "country": "GB",
    "name": "Kempsey",
    "lat": "52.13936",
    "lng": "-2.21751"
  },
  {
    "country": "GB",
    "name": "Kemnay",
    "lat": "57.23573",
    "lng": "-2.44395"
  },
  {
    "country": "GB",
    "name": "Kelvedon Hatch",
    "lat": "51.66739",
    "lng": "0.26814"
  },
  {
    "country": "GB",
    "name": "Kelvedon",
    "lat": "51.84007",
    "lng": "0.7057"
  },
  {
    "country": "GB",
    "name": "Kelty",
    "lat": "56.13362",
    "lng": "-3.3869"
  },
  {
    "country": "GB",
    "name": "Kelso",
    "lat": "55.59814",
    "lng": "-2.43382"
  },
  {
    "country": "GB",
    "name": "Kelsall",
    "lat": "53.20775",
    "lng": "-2.71242"
  },
  {
    "country": "GB",
    "name": "Keith",
    "lat": "57.53633",
    "lng": "-2.94811"
  },
  {
    "country": "GB",
    "name": "Keighley",
    "lat": "53.86791",
    "lng": "-1.90664"
  },
  {
    "country": "GB",
    "name": "Kegworth",
    "lat": "52.83482",
    "lng": "-1.28042"
  },
  {
    "country": "GB",
    "name": "Keele",
    "lat": "53.00382",
    "lng": "-2.28741"
  },
  {
    "country": "GB",
    "name": "Keelby",
    "lat": "53.5758",
    "lng": "-0.24701"
  },
  {
    "country": "GB",
    "name": "Kedington",
    "lat": "52.09282",
    "lng": "0.48675"
  },
  {
    "country": "GB",
    "name": "Kearsley",
    "lat": "53.53333",
    "lng": "-2.38333"
  },
  {
    "country": "GB",
    "name": "Keady",
    "lat": "54.25",
    "lng": "-6.7"
  },
  {
    "country": "GB",
    "name": "Keadby",
    "lat": "53.59308",
    "lng": "-0.74021"
  },
  {
    "country": "GB",
    "name": "Jordanstown",
    "lat": "54.68333",
    "lng": "-5.9"
  },
  {
    "country": "GB",
    "name": "Johnstone",
    "lat": "55.82906",
    "lng": "-4.51605"
  },
  {
    "country": "GB",
    "name": "Johnston",
    "lat": "51.75556",
    "lng": "-4.99667"
  },
  {
    "country": "GB",
    "name": "Jeffreyston",
    "lat": "51.725",
    "lng": "-4.7675"
  },
  {
    "country": "GB",
    "name": "Jedburgh",
    "lat": "55.47997",
    "lng": "-2.552"
  },
  {
    "country": "GB",
    "name": "Jarrow",
    "lat": "54.98036",
    "lng": "-1.48423"
  },
  {
    "country": "GB",
    "name": "Jacobstow",
    "lat": "50.73333",
    "lng": "-4.55"
  },
  {
    "country": "GB",
    "name": "Ixworth",
    "lat": "52.29893",
    "lng": "0.8341"
  },
  {
    "country": "GB",
    "name": "Iwade",
    "lat": "51.37754",
    "lng": "0.72935"
  },
  {
    "country": "GB",
    "name": "Ivybridge",
    "lat": "50.39039",
    "lng": "-3.91914"
  },
  {
    "country": "GB",
    "name": "Ivinghoe",
    "lat": "51.83602",
    "lng": "-0.62983"
  },
  {
    "country": "GB",
    "name": "Iver",
    "lat": "51.5",
    "lng": "-0.5"
  },
  {
    "country": "GB",
    "name": "Islington",
    "lat": "51.53622",
    "lng": "-0.10304"
  },
  {
    "country": "GB",
    "name": "Isleworth",
    "lat": "51.47518",
    "lng": "-0.34246"
  },
  {
    "country": "GB",
    "name": "Isleham",
    "lat": "52.34289",
    "lng": "0.41212"
  },
  {
    "country": "GB",
    "name": "Irvinestown",
    "lat": "54.46667",
    "lng": "-7.63333"
  },
  {
    "country": "GB",
    "name": "Irvine",
    "lat": "55.6194",
    "lng": "-4.65508"
  },
  {
    "country": "GB",
    "name": "Irthlingborough",
    "lat": "52.32674",
    "lng": "-0.61129"
  },
  {
    "country": "GB",
    "name": "Ironbridge",
    "lat": "52.62795",
    "lng": "-2.48465"
  },
  {
    "country": "GB",
    "name": "Irlam",
    "lat": "53.44253",
    "lng": "-2.42323"
  },
  {
    "country": "GB",
    "name": "Irchester",
    "lat": "52.28108",
    "lng": "-0.6451"
  },
  {
    "country": "GB",
    "name": "Ipswich",
    "lat": "52.05917",
    "lng": "1.15545"
  },
  {
    "country": "GB",
    "name": "Ipplepen",
    "lat": "50.48919",
    "lng": "-3.639"
  },
  {
    "country": "GB",
    "name": "Inverurie",
    "lat": "57.28446",
    "lng": "-2.37736"
  },
  {
    "country": "GB",
    "name": "Inverness",
    "lat": "57.47908",
    "lng": "-4.22398"
  },
  {
    "country": "GB",
    "name": "Inverkip",
    "lat": "55.90831",
    "lng": "-4.87051"
  },
  {
    "country": "GB",
    "name": "Inverkeithing",
    "lat": "56.03297",
    "lng": "-3.39555"
  },
  {
    "country": "GB",
    "name": "Invergowrie",
    "lat": "56.46111",
    "lng": "-3.06158"
  },
  {
    "country": "GB",
    "name": "Invergordon",
    "lat": "57.6886",
    "lng": "-4.16745"
  },
  {
    "country": "GB",
    "name": "Inverbervie",
    "lat": "56.84463",
    "lng": "-2.27997"
  },
  {
    "country": "GB",
    "name": "Insch",
    "lat": "57.34273",
    "lng": "-2.61321"
  },
  {
    "country": "GB",
    "name": "Innerleithen",
    "lat": "55.61927",
    "lng": "-3.06301"
  },
  {
    "country": "GB",
    "name": "Inkberrow",
    "lat": "52.21284",
    "lng": "-1.98093"
  },
  {
    "country": "GB",
    "name": "Ingrave",
    "lat": "51.60416",
    "lng": "0.34058"
  },
  {
    "country": "GB",
    "name": "Ingoldmells",
    "lat": "53.19414",
    "lng": "0.33358"
  },
  {
    "country": "GB",
    "name": "Ingleton",
    "lat": "54.57952",
    "lng": "-1.73532"
  },
  {
    "country": "GB",
    "name": "Ingleby Greenhow",
    "lat": "54.44983",
    "lng": "-1.10687"
  },
  {
    "country": "GB",
    "name": "Ingatestone",
    "lat": "51.67027",
    "lng": "0.38359"
  },
  {
    "country": "GB",
    "name": "Inchture",
    "lat": "56.44551",
    "lng": "-3.16956"
  },
  {
    "country": "GB",
    "name": "Inchinnan",
    "lat": "55.88995",
    "lng": "-4.43842"
  },
  {
    "country": "GB",
    "name": "Ince-in-Makerfield",
    "lat": "53.53333",
    "lng": "-2.61667"
  },
  {
    "country": "GB",
    "name": "Ince Blundell",
    "lat": "53.52429",
    "lng": "-3.02733"
  },
  {
    "country": "GB",
    "name": "Ince",
    "lat": "53.28333",
    "lng": "-2.83333"
  },
  {
    "country": "GB",
    "name": "Immingham",
    "lat": "53.61239",
    "lng": "-0.22219"
  },
  {
    "country": "GB",
    "name": "Ilminster",
    "lat": "50.92684",
    "lng": "-2.91009"
  },
  {
    "country": "GB",
    "name": "Ilkley",
    "lat": "53.92449",
    "lng": "-1.82326"
  },
  {
    "country": "GB",
    "name": "Ilkeston",
    "lat": "52.97055",
    "lng": "-1.30951"
  },
  {
    "country": "GB",
    "name": "Ilfracombe",
    "lat": "51.2093",
    "lng": "-4.11344"
  },
  {
    "country": "GB",
    "name": "Ilford",
    "lat": "51.55765",
    "lng": "0.07278"
  },
  {
    "country": "GB",
    "name": "Ilchester",
    "lat": "51.00587",
    "lng": "-2.67981"
  },
  {
    "country": "GB",
    "name": "Ibstock",
    "lat": "52.68554",
    "lng": "-1.39965"
  },
  {
    "country": "GB",
    "name": "Hythe",
    "lat": "51.0715",
    "lng": "1.08421"
  },
  {
    "country": "GB",
    "name": "Hythe",
    "lat": "50.86004",
    "lng": "-1.40162"
  },
  {
    "country": "GB",
    "name": "Hyde",
    "lat": "53.45131",
    "lng": "-2.07943"
  },
  {
    "country": "GB",
    "name": "Huyton",
    "lat": "53.4115",
    "lng": "-2.83935"
  },
  {
    "country": "GB",
    "name": "Hutton Magna",
    "lat": "54.50992",
    "lng": "-1.80622"
  },
  {
    "country": "GB",
    "name": "Hutton",
    "lat": "51.32417",
    "lng": "-2.93028"
  },
  {
    "country": "GB",
    "name": "Husbands Bosworth",
    "lat": "52.45232",
    "lng": "-1.05557"
  },
  {
    "country": "GB",
    "name": "Hurworth",
    "lat": "54.49008",
    "lng": "-1.53294"
  },
  {
    "country": "GB",
    "name": "Hurstpierpoint",
    "lat": "50.93388",
    "lng": "-0.18007"
  },
  {
    "country": "GB",
    "name": "Hurst",
    "lat": "51.45791",
    "lng": "-0.85196"
  },
  {
    "country": "GB",
    "name": "Hurley",
    "lat": "51.54644",
    "lng": "-0.80921"
  },
  {
    "country": "GB",
    "name": "Hunwick",
    "lat": "54.68791",
    "lng": "-1.70539"
  },
  {
    "country": "GB",
    "name": "Huntspill",
    "lat": "51.20562",
    "lng": "-2.98735"
  },
  {
    "country": "GB",
    "name": "Huntly",
    "lat": "57.44741",
    "lng": "-2.78608"
  },
  {
    "country": "GB",
    "name": "Huntley",
    "lat": "51.87172",
    "lng": "-2.40137"
  },
  {
    "country": "GB",
    "name": "Huntington",
    "lat": "54",
    "lng": "-1.05"
  },
  {
    "country": "GB",
    "name": "Huntingdon",
    "lat": "52.33049",
    "lng": "-0.18651"
  },
  {
    "country": "GB",
    "name": "Hunstanton",
    "lat": "52.95",
    "lng": "0.5"
  },
  {
    "country": "GB",
    "name": "Hunmanby",
    "lat": "54.17957",
    "lng": "-0.32007"
  },
  {
    "country": "GB",
    "name": "Hungerford",
    "lat": "51.41513",
    "lng": "-1.51556"
  },
  {
    "country": "GB",
    "name": "Humbleton",
    "lat": "53.78333",
    "lng": "-0.15"
  },
  {
    "country": "GB",
    "name": "Humberston",
    "lat": "53.53036",
    "lng": "-0.02465"
  },
  {
    "country": "GB",
    "name": "Humber",
    "lat": "52.2",
    "lng": "-2.66667"
  },
  {
    "country": "GB",
    "name": "Huish",
    "lat": "51.37114",
    "lng": "-1.79266"
  },
  {
    "country": "GB",
    "name": "Hugh Town",
    "lat": "49.91447",
    "lng": "-6.31145"
  },
  {
    "country": "GB",
    "name": "Huddersfield",
    "lat": "53.64904",
    "lng": "-1.78416"
  },
  {
    "country": "GB",
    "name": "Hucknall",
    "lat": "53.03333",
    "lng": "-1.2"
  },
  {
    "country": "GB",
    "name": "Hoyland Nether",
    "lat": "53.5",
    "lng": "-1.45"
  },
  {
    "country": "GB",
    "name": "Hoylake",
    "lat": "53.39046",
    "lng": "-3.18066"
  },
  {
    "country": "GB",
    "name": "Howwood",
    "lat": "55.8106",
    "lng": "-4.55733"
  },
  {
    "country": "GB",
    "name": "Howden",
    "lat": "53.7463",
    "lng": "-0.86994"
  },
  {
    "country": "GB",
    "name": "Hove",
    "lat": "50.83088",
    "lng": "-0.1672"
  },
  {
    "country": "GB",
    "name": "Houston",
    "lat": "55.86859",
    "lng": "-4.55201"
  },
  {
    "country": "GB",
    "name": "Hounslow",
    "lat": "51.46839",
    "lng": "-0.36092"
  },
  {
    "country": "GB",
    "name": "Houghton Regis",
    "lat": "51.90441",
    "lng": "-0.52125"
  },
  {
    "country": "GB",
    "name": "Houghton on the Hill",
    "lat": "52.62663",
    "lng": "-0.99546"
  },
  {
    "country": "GB",
    "name": "Houghton-Le-Spring",
    "lat": "54.84034",
    "lng": "-1.46427"
  },
  {
    "country": "GB",
    "name": "Houghton Conquest",
    "lat": "52.06178",
    "lng": "-0.47756"
  },
  {
    "country": "GB",
    "name": "Hotham",
    "lat": "53.79583",
    "lng": "-0.64253"
  },
  {
    "country": "GB",
    "name": "Horwich",
    "lat": "53.60126",
    "lng": "-2.54975"
  },
  {
    "country": "GB",
    "name": "Horton Kirby",
    "lat": "51.39481",
    "lng": "0.24483"
  },
  {
    "country": "GB",
    "name": "Horton",
    "lat": "51.55833",
    "lng": "-2.3525"
  },
  {
    "country": "GB",
    "name": "Horton",
    "lat": "51.47315",
    "lng": "-0.54245"
  },
  {
    "country": "GB",
    "name": "Horsted Keynes",
    "lat": "51.03659",
    "lng": "-0.02798"
  },
  {
    "country": "GB",
    "name": "Horsmonden",
    "lat": "51.13908",
    "lng": "0.42881"
  },
  {
    "country": "GB",
    "name": "Horsley",
    "lat": "54.98333",
    "lng": "-1.85"
  },
  {
    "country": "GB",
    "name": "Horsham",
    "lat": "51.06314",
    "lng": "-0.32757"
  },
  {
    "country": "GB",
    "name": "Horsforth",
    "lat": "53.8426",
    "lng": "-1.63754"
  },
  {
    "country": "GB",
    "name": "Horsford",
    "lat": "52.70153",
    "lng": "1.24015"
  },
  {
    "country": "GB",
    "name": "Horrabridge",
    "lat": "50.50843",
    "lng": "-4.10042"
  },
  {
    "country": "GB",
    "name": "Hornsea",
    "lat": "53.91041",
    "lng": "-0.16806"
  },
  {
    "country": "GB",
    "name": "Horning",
    "lat": "52.7046",
    "lng": "1.46294"
  },
  {
    "country": "GB",
    "name": "Horndon on the Hill",
    "lat": "51.52358",
    "lng": "0.40491"
  },
  {
    "country": "GB",
    "name": "Horncastle",
    "lat": "53.20775",
    "lng": "-0.1172"
  },
  {
    "country": "GB",
    "name": "Horley",
    "lat": "51.17423",
    "lng": "-0.15919"
  },
  {
    "country": "GB",
    "name": "Horbury",
    "lat": "53.66051",
    "lng": "-1.56014"
  },
  {
    "country": "GB",
    "name": "Horam",
    "lat": "50.93523",
    "lng": "0.24436"
  },
  {
    "country": "GB",
    "name": "Hopton on Sea",
    "lat": "52.53333",
    "lng": "1.73333"
  },
  {
    "country": "GB",
    "name": "Hope under Dinmore",
    "lat": "52.18333",
    "lng": "-2.71667"
  },
  {
    "country": "GB",
    "name": "Hopeman",
    "lat": "57.70681",
    "lng": "-3.42911"
  },
  {
    "country": "GB",
    "name": "Hope",
    "lat": "53.11667",
    "lng": "-3.03333"
  },
  {
    "country": "GB",
    "name": "Hook Norton",
    "lat": "51.99564",
    "lng": "-1.48277"
  },
  {
    "country": "GB",
    "name": "Hook",
    "lat": "53.72132",
    "lng": "-0.84891"
  },
  {
    "country": "GB",
    "name": "Hook",
    "lat": "51.36803",
    "lng": "-0.3065"
  },
  {
    "country": "GB",
    "name": "Hook",
    "lat": "51.28425",
    "lng": "-0.95967"
  },
  {
    "country": "GB",
    "name": "Hoo",
    "lat": "51.4205",
    "lng": "0.563"
  },
  {
    "country": "GB",
    "name": "Honiton",
    "lat": "50.7996",
    "lng": "-3.18899"
  },
  {
    "country": "GB",
    "name": "Holywood",
    "lat": "54.63863",
    "lng": "-5.82473"
  },
  {
    "country": "GB",
    "name": "Holywell",
    "lat": "53.27466",
    "lng": "-3.22895"
  },
  {
    "country": "GB",
    "name": "Holytown",
    "lat": "55.82011",
    "lng": "-3.9727"
  },
  {
    "country": "GB",
    "name": "Holyhead",
    "lat": "53.30621",
    "lng": "-4.63211"
  },
  {
    "country": "GB",
    "name": "Holwick",
    "lat": "54.6358",
    "lng": "-2.14371"
  },
  {
    "country": "GB",
    "name": "Holton le Clay",
    "lat": "53.5052",
    "lng": "-0.063"
  },
  {
    "country": "GB",
    "name": "Holtby",
    "lat": "53.97876",
    "lng": "-0.97255"
  },
  {
    "country": "GB",
    "name": "Holt",
    "lat": "53.06667",
    "lng": "-2.88333"
  },
  {
    "country": "GB",
    "name": "Holt",
    "lat": "51.35556",
    "lng": "-2.19722"
  },
  {
    "country": "GB",
    "name": "Holsworthy",
    "lat": "50.81196",
    "lng": "-4.35383"
  },
  {
    "country": "GB",
    "name": "Holmwood",
    "lat": "51.18049",
    "lng": "-0.32176"
  },
  {
    "country": "GB",
    "name": "Holmpton",
    "lat": "53.68771",
    "lng": "0.06583"
  },
  {
    "country": "GB",
    "name": "Holmfirth",
    "lat": "53.56968",
    "lng": "-1.78777"
  },
  {
    "country": "GB",
    "name": "Holmes Chapel",
    "lat": "53.2014",
    "lng": "-2.35742"
  },
  {
    "country": "GB",
    "name": "Hollym",
    "lat": "53.70402",
    "lng": "0.04008"
  },
  {
    "country": "GB",
    "name": "Holbrook",
    "lat": "51.9834",
    "lng": "1.15854"
  },
  {
    "country": "GB",
    "name": "Holbeach",
    "lat": "52.80401",
    "lng": "0.01442"
  },
  {
    "country": "GB",
    "name": "Hoddesdon",
    "lat": "51.76148",
    "lng": "-0.01144"
  },
  {
    "country": "GB",
    "name": "Hockwold cum Wilton",
    "lat": "52.4638",
    "lng": "0.54614"
  },
  {
    "country": "GB",
    "name": "Hockliffe",
    "lat": "51.93109",
    "lng": "-0.58652"
  },
  {
    "country": "GB",
    "name": "Hockley",
    "lat": "52.5",
    "lng": "-1.91667"
  },
  {
    "country": "GB",
    "name": "Hitchin",
    "lat": "51.94924",
    "lng": "-0.28496"
  },
  {
    "country": "GB",
    "name": "Histon",
    "lat": "52.25166",
    "lng": "0.10643"
  },
  {
    "country": "GB",
    "name": "Hirwaun",
    "lat": "51.73917",
    "lng": "-3.51028"
  },
  {
    "country": "GB",
    "name": "Hinton Charterhouse",
    "lat": "51.32377",
    "lng": "-2.32841"
  },
  {
    "country": "GB",
    "name": "Hinton",
    "lat": "51.48972",
    "lng": "-2.38472"
  },
  {
    "country": "GB",
    "name": "Hingham",
    "lat": "52.57969",
    "lng": "0.98422"
  },
  {
    "country": "GB",
    "name": "Hindon",
    "lat": "51.09222",
    "lng": "-2.12583"
  },
  {
    "country": "GB",
    "name": "Hindley",
    "lat": "53.53333",
    "lng": "-2.58333"
  },
  {
    "country": "GB",
    "name": "Hindhead",
    "lat": "51.11381",
    "lng": "-0.73351"
  },
  {
    "country": "GB",
    "name": "Hinckley",
    "lat": "52.5389",
    "lng": "-1.37613"
  },
  {
    "country": "GB",
    "name": "Hilton",
    "lat": "52.27908",
    "lng": "-0.11222"
  },
  {
    "country": "GB",
    "name": "Hillside",
    "lat": "56.74483",
    "lng": "-2.474"
  },
  {
    "country": "GB",
    "name": "Hillsborough",
    "lat": "54.46345",
    "lng": "-6.07664"
  },
  {
    "country": "GB",
    "name": "Hill",
    "lat": "51.65139",
    "lng": "-2.51556"
  },
  {
    "country": "GB",
    "name": "High Wycombe",
    "lat": "51.62907",
    "lng": "-0.74934"
  },
  {
    "country": "GB",
    "name": "Highworth",
    "lat": "51.63051",
    "lng": "-1.711"
  },
  {
    "country": "GB",
    "name": "High Valleyfield",
    "lat": "56.06357",
    "lng": "-3.59913"
  },
  {
    "country": "GB",
    "name": "Hightown",
    "lat": "53.52452",
    "lng": "-3.06192"
  },
  {
    "country": "GB",
    "name": "High Ongar",
    "lat": "51.70953",
    "lng": "0.26221"
  },
  {
    "country": "GB",
    "name": "Highley",
    "lat": "52.44866",
    "lng": "-2.38251"
  },
  {
    "country": "GB",
    "name": "High Legh",
    "lat": "53.35139",
    "lng": "-2.4538"
  },
  {
    "country": "GB",
    "name": "High Halstow",
    "lat": "51.44775",
    "lng": "0.55558"
  },
  {
    "country": "GB",
    "name": "High Halden",
    "lat": "51.10331",
    "lng": "0.71394"
  },
  {
    "country": "GB",
    "name": "High Etherley",
    "lat": "54.65391",
    "lng": "-1.74363"
  },
  {
    "country": "GB",
    "name": "High Coniscliffe",
    "lat": "54.53333",
    "lng": "-1.65"
  },
  {
    "country": "GB",
    "name": "Highclere",
    "lat": "51.3386",
    "lng": "-1.37569"
  },
  {
    "country": "GB",
    "name": "Highbridge",
    "lat": "51.21667",
    "lng": "-2.98333"
  },
  {
    "country": "GB",
    "name": "High Blantyre",
    "lat": "55.78438",
    "lng": "-4.10007"
  },
  {
    "country": "GB",
    "name": "High Bentham",
    "lat": "54.11823",
    "lng": "-2.51199"
  },
  {
    "country": "GB",
    "name": "Higham Ferrers",
    "lat": "52.30596",
    "lng": "-0.59342"
  },
  {
    "country": "GB",
    "name": "Hibaldstow",
    "lat": "53.51133",
    "lng": "-0.52082"
  },
  {
    "country": "GB",
    "name": "Hexham",
    "lat": "54.96986",
    "lng": "-2.104"
  },
  {
    "country": "GB",
    "name": "Hetton-Le-Hole",
    "lat": "54.81667",
    "lng": "-1.45"
  },
  {
    "country": "GB",
    "name": "Hethersett",
    "lat": "52.59761",
    "lng": "1.17359"
  },
  {
    "country": "GB",
    "name": "Heswall",
    "lat": "53.32733",
    "lng": "-3.09648"
  },
  {
    "country": "GB",
    "name": "Hessle",
    "lat": "53.72454",
    "lng": "-0.43842"
  },
  {
    "country": "GB",
    "name": "Heslington",
    "lat": "53.94636",
    "lng": "-1.04919"
  },
  {
    "country": "GB",
    "name": "Hertford",
    "lat": "51.79588",
    "lng": "-0.07854"
  },
  {
    "country": "GB",
    "name": "Herstmonceux",
    "lat": "50.88958",
    "lng": "0.3229"
  },
  {
    "country": "GB",
    "name": "Herne Bay",
    "lat": "51.373",
    "lng": "1.12857"
  },
  {
    "country": "GB",
    "name": "Hermitage",
    "lat": "51.4554",
    "lng": "-1.26823"
  },
  {
    "country": "GB",
    "name": "Hereford",
    "lat": "52.05684",
    "lng": "-2.71482"
  },
  {
    "country": "GB",
    "name": "Herbrandston",
    "lat": "51.72639",
    "lng": "-5.08667"
  },
  {
    "country": "GB",
    "name": "Henstridge",
    "lat": "50.97717",
    "lng": "-2.395"
  },
  {
    "country": "GB",
    "name": "Henlow",
    "lat": "52.03021",
    "lng": "-0.28599"
  },
  {
    "country": "GB",
    "name": "Henllan",
    "lat": "53.2",
    "lng": "-3.46667"
  },
  {
    "country": "GB",
    "name": "Henley on Thames",
    "lat": "51.53333",
    "lng": "-0.9"
  },
  {
    "country": "GB",
    "name": "Henley in Arden",
    "lat": "52.29032",
    "lng": "-1.77807"
  },
  {
    "country": "GB",
    "name": "Hengoed",
    "lat": "51.65083",
    "lng": "-3.23167"
  },
  {
    "country": "GB",
    "name": "Henfield",
    "lat": "50.92995",
    "lng": "-0.27071"
  },
  {
    "country": "GB",
    "name": "Hendon",
    "lat": "51.6",
    "lng": "-0.21667"
  },
  {
    "country": "GB",
    "name": "Hemyock",
    "lat": "50.91234",
    "lng": "-3.22807"
  },
  {
    "country": "GB",
    "name": "Hemsworth",
    "lat": "53.61267",
    "lng": "-1.35424"
  },
  {
    "country": "GB",
    "name": "Hemsby",
    "lat": "52.69714",
    "lng": "1.69181"
  },
  {
    "country": "GB",
    "name": "Hemingford Grey",
    "lat": "52.31756",
    "lng": "-0.10029"
  },
  {
    "country": "GB",
    "name": "Hemingbrough",
    "lat": "53.76863",
    "lng": "-0.97673"
  },
  {
    "country": "GB",
    "name": "Hemel Hempstead",
    "lat": "51.75368",
    "lng": "-0.44975"
  },
  {
    "country": "GB",
    "name": "Helston",
    "lat": "50.10319",
    "lng": "-5.27045"
  },
  {
    "country": "GB",
    "name": "Helsby",
    "lat": "53.27396",
    "lng": "-2.76905"
  },
  {
    "country": "GB",
    "name": "Helpston",
    "lat": "52.63233",
    "lng": "-0.34676"
  },
  {
    "country": "GB",
    "name": "Helmsley",
    "lat": "54.24577",
    "lng": "-1.05683"
  },
  {
    "country": "GB",
    "name": "Hellifield",
    "lat": "54.00486",
    "lng": "-2.22302"
  },
  {
    "country": "GB",
    "name": "Helland",
    "lat": "50.5",
    "lng": "-4.71667"
  },
  {
    "country": "GB",
    "name": "Helensburgh",
    "lat": "56.00614",
    "lng": "-4.72648"
  },
  {
    "country": "GB",
    "name": "Heighington",
    "lat": "54.59594",
    "lng": "-1.61791"
  },
  {
    "country": "GB",
    "name": "Heighington",
    "lat": "53.21241",
    "lng": "-0.45902"
  },
  {
    "country": "GB",
    "name": "Hedon",
    "lat": "53.73962",
    "lng": "-0.19655"
  },
  {
    "country": "GB",
    "name": "Heddon on the Wall",
    "lat": "54.99692",
    "lng": "-1.79386"
  },
  {
    "country": "GB",
    "name": "Heckmondwike",
    "lat": "53.70646",
    "lng": "-1.67747"
  },
  {
    "country": "GB",
    "name": "Heckington",
    "lat": "52.98183",
    "lng": "-0.29903"
  },
  {
    "country": "GB",
    "name": "Hebron",
    "lat": "55.18333",
    "lng": "-1.68333"
  },
  {
    "country": "GB",
    "name": "Hebden Bridge",
    "lat": "53.74093",
    "lng": "-2.01337"
  },
  {
    "country": "GB",
    "name": "Hebburn",
    "lat": "54.97302",
    "lng": "-1.51546"
  },
  {
    "country": "GB",
    "name": "Heathfield",
    "lat": "50.96718",
    "lng": "0.25612"
  },
  {
    "country": "GB",
    "name": "Heath and Reach",
    "lat": "51.94517",
    "lng": "-0.65697"
  },
  {
    "country": "GB",
    "name": "Heanor",
    "lat": "53.01372",
    "lng": "-1.35383"
  },
  {
    "country": "GB",
    "name": "Healing",
    "lat": "53.58101",
    "lng": "-0.16202"
  },
  {
    "country": "GB",
    "name": "Healey",
    "lat": "54.91667",
    "lng": "-1.96667"
  },
  {
    "country": "GB",
    "name": "Heage",
    "lat": "53.0505",
    "lng": "-1.44688"
  },
  {
    "country": "GB",
    "name": "Headcorn",
    "lat": "51.16966",
    "lng": "0.62433"
  },
  {
    "country": "GB",
    "name": "Heacham",
    "lat": "52.90782",
    "lng": "0.49387"
  },
  {
    "country": "GB",
    "name": "Hazel Grove",
    "lat": "53.38333",
    "lng": "-2.11667"
  },
  {
    "country": "GB",
    "name": "Haywards Heath",
    "lat": "50.99769",
    "lng": "-0.10313"
  },
  {
    "country": "GB",
    "name": "Hayton",
    "lat": "53.9",
    "lng": "-0.75"
  },
  {
    "country": "GB",
    "name": "Haynes",
    "lat": "52.06646",
    "lng": "-0.39946"
  },
  {
    "country": "GB",
    "name": "Hayle",
    "lat": "50.18392",
    "lng": "-5.42137"
  },
  {
    "country": "GB",
    "name": "Hayfield",
    "lat": "53.37893",
    "lng": "-1.94544"
  },
  {
    "country": "GB",
    "name": "Hayes",
    "lat": "51.51579",
    "lng": "-0.4234"
  },
  {
    "country": "GB",
    "name": "Haydon Bridge",
    "lat": "54.97486",
    "lng": "-2.2468"
  },
  {
    "country": "GB",
    "name": "Haydock",
    "lat": "53.46723",
    "lng": "-2.68166"
  },
  {
    "country": "GB",
    "name": "Hay",
    "lat": "52.07049",
    "lng": "-3.12741"
  },
  {
    "country": "GB",
    "name": "Haxey",
    "lat": "53.48937",
    "lng": "-0.8402"
  },
  {
    "country": "GB",
    "name": "Haxby",
    "lat": "54.01422",
    "lng": "-1.07121"
  },
  {
    "country": "GB",
    "name": "Hawthorn",
    "lat": "54.8",
    "lng": "-1.35"
  },
  {
    "country": "GB",
    "name": "Haworth",
    "lat": "53.82905",
    "lng": "-1.94827"
  },
  {
    "country": "GB",
    "name": "Hawkinge",
    "lat": "51.11276",
    "lng": "1.16176"
  },
  {
    "country": "GB",
    "name": "Hawkhurst",
    "lat": "51.0479",
    "lng": "0.51095"
  },
  {
    "country": "GB",
    "name": "Hawick",
    "lat": "55.42273",
    "lng": "-2.78666"
  },
  {
    "country": "GB",
    "name": "Hawarden",
    "lat": "53.18478",
    "lng": "-3.02578"
  },
  {
    "country": "GB",
    "name": "Haverigg",
    "lat": "54.19973",
    "lng": "-3.29263"
  },
  {
    "country": "GB",
    "name": "Haverhill",
    "lat": "52.08226",
    "lng": "0.43891"
  },
  {
    "country": "GB",
    "name": "Haverfordwest",
    "lat": "51.80169",
    "lng": "-4.96914"
  },
  {
    "country": "GB",
    "name": "Havant",
    "lat": "50.8567",
    "lng": "-0.98559"
  },
  {
    "country": "GB",
    "name": "Haughley",
    "lat": "52.21907",
    "lng": "0.968"
  },
  {
    "country": "GB",
    "name": "Hatton",
    "lat": "52.30007",
    "lng": "-1.6326"
  },
  {
    "country": "GB",
    "name": "Hathersage",
    "lat": "53.3303",
    "lng": "-1.65398"
  },
  {
    "country": "GB",
    "name": "Hathern",
    "lat": "52.79548",
    "lng": "-1.25644"
  },
  {
    "country": "GB",
    "name": "Hatherleigh",
    "lat": "50.82144",
    "lng": "-4.07228"
  },
  {
    "country": "GB",
    "name": "Hatfield Peverel",
    "lat": "51.77591",
    "lng": "0.59489"
  },
  {
    "country": "GB",
    "name": "Hatfield Heath",
    "lat": "51.81233",
    "lng": "0.21243"
  },
  {
    "country": "GB",
    "name": "Hatfield",
    "lat": "53.57788",
    "lng": "-0.99924"
  },
  {
    "country": "GB",
    "name": "Hatfield",
    "lat": "51.76338",
    "lng": "-0.22419"
  },
  {
    "country": "GB",
    "name": "Haswell",
    "lat": "54.78333",
    "lng": "-1.41667"
  },
  {
    "country": "GB",
    "name": "Hastings",
    "lat": "50.85519",
    "lng": "0.57292"
  },
  {
    "country": "GB",
    "name": "Hassocks",
    "lat": "50.92814",
    "lng": "-0.16617"
  },
  {
    "country": "GB",
    "name": "Haslingfield",
    "lat": "52.15016",
    "lng": "0.05579"
  },
  {
    "country": "GB",
    "name": "Haslingden",
    "lat": "53.70326",
    "lng": "-2.32382"
  },
  {
    "country": "GB",
    "name": "Haslemere",
    "lat": "51.09015",
    "lng": "-0.70785"
  },
  {
    "country": "GB",
    "name": "Harwich",
    "lat": "51.94194",
    "lng": "1.28437"
  },
  {
    "country": "GB",
    "name": "Harwell",
    "lat": "51.59947",
    "lng": "-1.29175"
  },
  {
    "country": "GB",
    "name": "Harvington",
    "lat": "52.14095",
    "lng": "-1.92313"
  },
  {
    "country": "GB",
    "name": "Hartwell",
    "lat": "52.14616",
    "lng": "-0.85376"
  },
  {
    "country": "GB",
    "name": "Hartshill",
    "lat": "52.54831",
    "lng": "-1.52221"
  },
  {
    "country": "GB",
    "name": "Hartley Wintney",
    "lat": "51.30379",
    "lng": "-0.90019"
  },
  {
    "country": "GB",
    "name": "Hartley",
    "lat": "51.38673",
    "lng": "0.30367"
  },
  {
    "country": "GB",
    "name": "Hartlepool",
    "lat": "54.68554",
    "lng": "-1.21028"
  },
  {
    "country": "GB",
    "name": "Hartlebury",
    "lat": "52.33333",
    "lng": "-2.23333"
  },
  {
    "country": "GB",
    "name": "Harthill",
    "lat": "55.86067",
    "lng": "-3.75166"
  },
  {
    "country": "GB",
    "name": "Harthill",
    "lat": "53.31667",
    "lng": "-1.26667"
  },
  {
    "country": "GB",
    "name": "Harthill",
    "lat": "53.08333",
    "lng": "-2.75"
  },
  {
    "country": "GB",
    "name": "Hartford",
    "lat": "53.24508",
    "lng": "-2.55119"
  },
  {
    "country": "GB",
    "name": "Hartburn",
    "lat": "55.16667",
    "lng": "-1.85"
  },
  {
    "country": "GB",
    "name": "Harston",
    "lat": "52.13691",
    "lng": "0.07999"
  },
  {
    "country": "GB",
    "name": "Harrow on the Hill",
    "lat": "51.57142",
    "lng": "-0.33371"
  },
  {
    "country": "GB",
    "name": "Harrow",
    "lat": "51.57835",
    "lng": "-0.33208"
  },
  {
    "country": "GB",
    "name": "Harrold",
    "lat": "52.20127",
    "lng": "-0.61038"
  },
  {
    "country": "GB",
    "name": "Harrogate",
    "lat": "53.99078",
    "lng": "-1.5373"
  },
  {
    "country": "GB",
    "name": "Harrietsham",
    "lat": "51.24252",
    "lng": "0.6706"
  },
  {
    "country": "GB",
    "name": "Harpole",
    "lat": "52.24246",
    "lng": "-0.98937"
  },
  {
    "country": "GB",
    "name": "Harpenden",
    "lat": "51.81684",
    "lng": "-0.35706"
  },
  {
    "country": "GB",
    "name": "Harlow",
    "lat": "51.77655",
    "lng": "0.11158"
  },
  {
    "country": "GB",
    "name": "Harlington",
    "lat": "51.96288",
    "lng": "-0.49241"
  },
  {
    "country": "GB",
    "name": "Harley",
    "lat": "52.6",
    "lng": "-2.6"
  },
  {
    "country": "GB",
    "name": "Harleston",
    "lat": "52.40302",
    "lng": "1.29664"
  },
  {
    "country": "GB",
    "name": "Harlech",
    "lat": "52.85941",
    "lng": "-4.10831"
  },
  {
    "country": "GB",
    "name": "Harefield",
    "lat": "51.60333",
    "lng": "-0.48546"
  },
  {
    "country": "GB",
    "name": "Hardingstone",
    "lat": "52.21358",
    "lng": "-0.88582"
  },
  {
    "country": "GB",
    "name": "Harbury",
    "lat": "52.23537",
    "lng": "-1.45706"
  },
  {
    "country": "GB",
    "name": "Hapton",
    "lat": "53.78333",
    "lng": "-2.31667"
  },
  {
    "country": "GB",
    "name": "Hanslope",
    "lat": "52.11425",
    "lng": "-0.82672"
  },
  {
    "country": "GB",
    "name": "Hannington",
    "lat": "51.63333",
    "lng": "-1.75"
  },
  {
    "country": "GB",
    "name": "Hankerton",
    "lat": "51.61444",
    "lng": "-2.045"
  },
  {
    "country": "GB",
    "name": "Handcross",
    "lat": "51.05383",
    "lng": "-0.20076"
  },
  {
    "country": "GB",
    "name": "Hamsterley",
    "lat": "54.68333",
    "lng": "-1.81667"
  },
  {
    "country": "GB",
    "name": "Hampton in Arden",
    "lat": "52.4254",
    "lng": "-1.70271"
  },
  {
    "country": "GB",
    "name": "Hampton",
    "lat": "51.41334",
    "lng": "-0.36701"
  },
  {
    "country": "GB",
    "name": "Hammersmith",
    "lat": "51.49384",
    "lng": "-0.22882"
  },
  {
    "country": "GB",
    "name": "Hamilton",
    "lat": "55.76667",
    "lng": "-4.03333"
  },
  {
    "country": "GB",
    "name": "Hambleton",
    "lat": "53.76667",
    "lng": "-1.16667"
  },
  {
    "country": "GB",
    "name": "Hamble-le-Rice",
    "lat": "50.85966",
    "lng": "-1.32432"
  },
  {
    "country": "GB",
    "name": "Haltwhistle",
    "lat": "54.97101",
    "lng": "-2.45682"
  },
  {
    "country": "GB",
    "name": "Halton",
    "lat": "54.07887",
    "lng": "-2.758"
  },
  {
    "country": "GB",
    "name": "Halton",
    "lat": "53.31667",
    "lng": "-2.7"
  },
  {
    "country": "GB",
    "name": "Halstead",
    "lat": "51.94506",
    "lng": "0.63927"
  },
  {
    "country": "GB",
    "name": "Halsham",
    "lat": "53.72985",
    "lng": "-0.0745"
  },
  {
    "country": "GB",
    "name": "Hallow",
    "lat": "52.22344",
    "lng": "-2.25468"
  },
  {
    "country": "GB",
    "name": "Halling",
    "lat": "51.35142",
    "lng": "0.4452"
  },
  {
    "country": "GB",
    "name": "Halkyn",
    "lat": "53.22556",
    "lng": "-3.19016"
  },
  {
    "country": "GB",
    "name": "Halkirk",
    "lat": "58.51227",
    "lng": "-3.49155"
  },
  {
    "country": "GB",
    "name": "Halifax",
    "lat": "53.71667",
    "lng": "-1.85"
  },
  {
    "country": "GB",
    "name": "Halesworth",
    "lat": "52.3464",
    "lng": "1.5029"
  },
  {
    "country": "GB",
    "name": "Halesowen",
    "lat": "52.44859",
    "lng": "-2.04938"
  },
  {
    "country": "GB",
    "name": "Hale",
    "lat": "53.33333",
    "lng": "-2.8"
  },
  {
    "country": "GB",
    "name": "Hale",
    "lat": "51.22946",
    "lng": "-0.78908"
  },
  {
    "country": "GB",
    "name": "Hailsham",
    "lat": "50.8622",
    "lng": "0.25775"
  },
  {
    "country": "GB",
    "name": "Haigh",
    "lat": "53.6",
    "lng": "-2.58333"
  },
  {
    "country": "GB",
    "name": "Hagley",
    "lat": "52.4262",
    "lng": "-2.12819"
  },
  {
    "country": "GB",
    "name": "Hadlow",
    "lat": "51.22417",
    "lng": "0.33914"
  },
  {
    "country": "GB",
    "name": "Hadley",
    "lat": "52.7",
    "lng": "-2.48333"
  },
  {
    "country": "GB",
    "name": "Hadleigh",
    "lat": "52.04499",
    "lng": "0.95298"
  },
  {
    "country": "GB",
    "name": "Hadleigh",
    "lat": "51.55269",
    "lng": "0.60983"
  },
  {
    "country": "GB",
    "name": "Haddington",
    "lat": "55.95612",
    "lng": "-2.78332"
  },
  {
    "country": "GB",
    "name": "Haddenham",
    "lat": "52.35789",
    "lng": "0.14827"
  },
  {
    "country": "GB",
    "name": "Haddenham",
    "lat": "51.77326",
    "lng": "-0.92628"
  },
  {
    "country": "GB",
    "name": "Hackney",
    "lat": "51.55",
    "lng": "-0.05"
  },
  {
    "country": "GB",
    "name": "Hackleton",
    "lat": "52.18798",
    "lng": "-0.82312"
  },
  {
    "country": "GB",
    "name": "Gurnard",
    "lat": "50.76057",
    "lng": "-1.32411"
  },
  {
    "country": "GB",
    "name": "Gunnislake",
    "lat": "50.52441",
    "lng": "-4.21333"
  },
  {
    "country": "GB",
    "name": "Gunness",
    "lat": "53.5908",
    "lng": "-0.72834"
  },
  {
    "country": "GB",
    "name": "Gullane",
    "lat": "56.03652",
    "lng": "-2.82829"
  },
  {
    "country": "GB",
    "name": "Guiseley",
    "lat": "53.87561",
    "lng": "-1.71232"
  },
  {
    "country": "GB",
    "name": "Guisborough",
    "lat": "54.53478",
    "lng": "-1.05606"
  },
  {
    "country": "GB",
    "name": "Guilsfield",
    "lat": "52.69634",
    "lng": "-3.15712"
  },
  {
    "country": "GB",
    "name": "Guildford",
    "lat": "51.23536",
    "lng": "-0.57427"
  },
  {
    "country": "GB",
    "name": "Grundisburgh",
    "lat": "52.11222",
    "lng": "1.24618"
  },
  {
    "country": "GB",
    "name": "Grove",
    "lat": "51.60954",
    "lng": "-1.42187"
  },
  {
    "country": "GB",
    "name": "Grosmont",
    "lat": "51.91667",
    "lng": "-2.86667"
  },
  {
    "country": "GB",
    "name": "Groombridge",
    "lat": "51.11543",
    "lng": "0.18295"
  },
  {
    "country": "GB",
    "name": "Griston",
    "lat": "52.5572",
    "lng": "0.86436"
  },
  {
    "country": "GB",
    "name": "Grindon",
    "lat": "54.61667",
    "lng": "-1.38333"
  },
  {
    "country": "GB",
    "name": "Grindale",
    "lat": "54.12453",
    "lng": "-0.27363"
  },
  {
    "country": "GB",
    "name": "Grimston",
    "lat": "52.79011",
    "lng": "-0.98656"
  },
  {
    "country": "GB",
    "name": "Grimston",
    "lat": "52.77312",
    "lng": "0.54846"
  },
  {
    "country": "GB",
    "name": "Grimsby",
    "lat": "53.56539",
    "lng": "-0.07553"
  },
  {
    "country": "GB",
    "name": "Greyabbey",
    "lat": "54.53483",
    "lng": "-5.56028"
  },
  {
    "country": "GB",
    "name": "Gretna",
    "lat": "54.9938",
    "lng": "-3.06594"
  },
  {
    "country": "GB",
    "name": "Gresford",
    "lat": "53.08539",
    "lng": "-2.97062"
  },
  {
    "country": "GB",
    "name": "Greetham",
    "lat": "52.72059",
    "lng": "-0.63068"
  },
  {
    "country": "GB",
    "name": "Greenock",
    "lat": "55.94838",
    "lng": "-4.76121"
  },
  {
    "country": "GB",
    "name": "Greenisland",
    "lat": "54.70081",
    "lng": "-5.87479"
  },
  {
    "country": "GB",
    "name": "Greenhithe",
    "lat": "51.45026",
    "lng": "0.28539"
  },
  {
    "country": "GB",
    "name": "Greenhead",
    "lat": "54.96667",
    "lng": "-2.51667"
  },
  {
    "country": "GB",
    "name": "Greenford",
    "lat": "51.52866",
    "lng": "-0.35508"
  },
  {
    "country": "GB",
    "name": "Greenfield",
    "lat": "53.28333",
    "lng": "-3.21667"
  },
  {
    "country": "GB",
    "name": "Great Yeldham",
    "lat": "52.01347",
    "lng": "0.5654"
  },
  {
    "country": "GB",
    "name": "Great Yarmouth",
    "lat": "52.60831",
    "lng": "1.73052"
  },
  {
    "country": "GB",
    "name": "Great Wyrley",
    "lat": "52.66277",
    "lng": "-2.01111"
  },
  {
    "country": "GB",
    "name": "Great Waldingfield",
    "lat": "52.05545",
    "lng": "0.77436"
  },
  {
    "country": "GB",
    "name": "Great Wakering",
    "lat": "51.55242",
    "lng": "0.8038"
  },
  {
    "country": "GB",
    "name": "Great Torrington",
    "lat": "50.95309",
    "lng": "-4.14401"
  },
  {
    "country": "GB",
    "name": "Great Sankey",
    "lat": "53.39234",
    "lng": "-2.63994"
  },
  {
    "country": "GB",
    "name": "Great Paxton",
    "lat": "52.26057",
    "lng": "-0.22818"
  },
  {
    "country": "GB",
    "name": "Great Ness",
    "lat": "52.76385",
    "lng": "-2.89151"
  },
  {
    "country": "GB",
    "name": "Great Missenden",
    "lat": "51.70419",
    "lng": "-0.70797"
  },
  {
    "country": "GB",
    "name": "Great Malvern",
    "lat": "52.11161",
    "lng": "-2.32515"
  },
  {
    "country": "GB",
    "name": "Great Leighs",
    "lat": "51.82761",
    "lng": "0.5064"
  },
  {
    "country": "GB",
    "name": "Great Houghton",
    "lat": "53.55352",
    "lng": "-1.34952"
  },
  {
    "country": "GB",
    "name": "Great Horwood",
    "lat": "51.97351",
    "lng": "-0.88088"
  },
  {
    "country": "GB",
    "name": "Great Horkesley",
    "lat": "51.93821",
    "lng": "0.87551"
  },
  {
    "country": "GB",
    "name": "Great Harwood",
    "lat": "53.78512",
    "lng": "-2.40865"
  },
  {
    "country": "GB",
    "name": "Great Hanwood",
    "lat": "52.68333",
    "lng": "-2.81667"
  },
  {
    "country": "GB",
    "name": "Greatham",
    "lat": "54.64183",
    "lng": "-1.23806"
  },
  {
    "country": "GB",
    "name": "Great Gransden",
    "lat": "52.18546",
    "lng": "-0.14574"
  },
  {
    "country": "GB",
    "name": "Great Gonerby",
    "lat": "52.93507",
    "lng": "-0.66685"
  },
  {
    "country": "GB",
    "name": "Great Glen",
    "lat": "52.57548",
    "lng": "-1.0349"
  },
  {
    "country": "GB",
    "name": "Great Eccleston",
    "lat": "53.85315",
    "lng": "-2.87026"
  },
  {
    "country": "GB",
    "name": "Great Dunmow",
    "lat": "51.8723",
    "lng": "0.36255"
  },
  {
    "country": "GB",
    "name": "Driffield",
    "lat": "54.00613",
    "lng": "-0.44495"
  },
  {
    "country": "GB",
    "name": "Great Coates",
    "lat": "53.5707",
    "lng": "-0.13905"
  },
  {
    "country": "GB",
    "name": "Great Chesterford",
    "lat": "52.06431",
    "lng": "0.1972"
  },
  {
    "country": "GB",
    "name": "Great Bookham",
    "lat": "51.27916",
    "lng": "-0.37423"
  },
  {
    "country": "GB",
    "name": "Great Bentley",
    "lat": "51.85333",
    "lng": "1.06379"
  },
  {
    "country": "GB",
    "name": "Great Bedwyn",
    "lat": "51.3795",
    "lng": "-1.60151"
  },
  {
    "country": "GB",
    "name": "Great Barton",
    "lat": "52.27257",
    "lng": "0.76679"
  },
  {
    "country": "GB",
    "name": "Great Barford",
    "lat": "52.15791",
    "lng": "-0.35235"
  },
  {
    "country": "GB",
    "name": "Great Bardfield",
    "lat": "51.94813",
    "lng": "0.43645"
  },
  {
    "country": "GB",
    "name": "Great Ayton",
    "lat": "54.49148",
    "lng": "-1.13623"
  },
  {
    "country": "GB",
    "name": "Great Amwell",
    "lat": "51.79014",
    "lng": "-0.01669"
  },
  {
    "country": "GB",
    "name": "Grays",
    "lat": "51.47566",
    "lng": "0.32521"
  },
  {
    "country": "GB",
    "name": "Gravesend",
    "lat": "51.44206",
    "lng": "0.37106"
  },
  {
    "country": "GB",
    "name": "Gravenhurst",
    "lat": "52.00854",
    "lng": "-0.36982"
  },
  {
    "country": "GB",
    "name": "Grassington",
    "lat": "54.0714",
    "lng": "-1.99822"
  },
  {
    "country": "GB",
    "name": "Grantown on Spey",
    "lat": "57.33051",
    "lng": "-3.60867"
  },
  {
    "country": "GB",
    "name": "Grantham",
    "lat": "52.91149",
    "lng": "-0.64184"
  },
  {
    "country": "GB",
    "name": "Grangemouth",
    "lat": "56.01141",
    "lng": "-3.72183"
  },
  {
    "country": "GB",
    "name": "Grain",
    "lat": "51.45591",
    "lng": "0.71126"
  },
  {
    "country": "GB",
    "name": "Goxhill",
    "lat": "53.67635",
    "lng": "-0.33759"
  },
  {
    "country": "GB",
    "name": "Govilon",
    "lat": "51.81928",
    "lng": "-3.06295"
  },
  {
    "country": "GB",
    "name": "Gourock",
    "lat": "55.96157",
    "lng": "-4.81789"
  },
  {
    "country": "GB",
    "name": "Goudhurst",
    "lat": "51.11314",
    "lng": "0.45615"
  },
  {
    "country": "GB",
    "name": "Gotham",
    "lat": "52.86799",
    "lng": "-1.20558"
  },
  {
    "country": "GB",
    "name": "Gosport",
    "lat": "50.79509",
    "lng": "-1.12902"
  },
  {
    "country": "GB",
    "name": "Gosforth",
    "lat": "55",
    "lng": "-1.61667"
  },
  {
    "country": "GB",
    "name": "Gosfield",
    "lat": "51.93657",
    "lng": "0.59197"
  },
  {
    "country": "GB",
    "name": "Gosberton",
    "lat": "52.86913",
    "lng": "-0.16102"
  },
  {
    "country": "GB",
    "name": "Gorseinon",
    "lat": "51.66931",
    "lng": "-4.04163"
  },
  {
    "country": "GB",
    "name": "Gorleston-on-Sea",
    "lat": "52.57301",
    "lng": "1.73069"
  },
  {
    "country": "GB",
    "name": "Goring-by-Sea",
    "lat": "50.81239",
    "lng": "-0.42194"
  },
  {
    "country": "GB",
    "name": "Goring",
    "lat": "51.52322",
    "lng": "-1.13342"
  },
  {
    "country": "GB",
    "name": "Gorebridge",
    "lat": "55.84594",
    "lng": "-3.04563"
  },
  {
    "country": "GB",
    "name": "Goostrey",
    "lat": "53.22731",
    "lng": "-2.33919"
  },
  {
    "country": "GB",
    "name": "Goosnargh",
    "lat": "53.822",
    "lng": "-2.67017"
  },
  {
    "country": "GB",
    "name": "Goole",
    "lat": "53.70324",
    "lng": "-0.87732"
  },
  {
    "country": "GB",
    "name": "Goodwick",
    "lat": "52.00491",
    "lng": "-4.99511"
  },
  {
    "country": "GB",
    "name": "Golspie",
    "lat": "57.97266",
    "lng": "-3.97798"
  },
  {
    "country": "GB",
    "name": "Goldcliff",
    "lat": "51.54222",
    "lng": "-2.91778"
  },
  {
    "country": "GB",
    "name": "Golborne",
    "lat": "53.47693",
    "lng": "-2.59651"
  },
  {
    "country": "GB",
    "name": "Godstone",
    "lat": "51.24779",
    "lng": "-0.06914"
  },
  {
    "country": "GB",
    "name": "Godshill",
    "lat": "50.63308",
    "lng": "-1.25476"
  },
  {
    "country": "GB",
    "name": "Godmanchester",
    "lat": "52.31939",
    "lng": "-0.17509"
  },
  {
    "country": "GB",
    "name": "Godalming",
    "lat": "51.1858",
    "lng": "-0.61489"
  },
  {
    "country": "GB",
    "name": "Gobowen",
    "lat": "52.89615",
    "lng": "-3.03686"
  },
  {
    "country": "GB",
    "name": "Gnosall",
    "lat": "52.78558",
    "lng": "-2.25483"
  },
  {
    "country": "GB",
    "name": "Glyn-neath",
    "lat": "51.7475",
    "lng": "-3.61833"
  },
  {
    "country": "GB",
    "name": "Glyncorrwg",
    "lat": "51.67944",
    "lng": "-3.62806"
  },
  {
    "country": "GB",
    "name": "Glusburn",
    "lat": "53.9",
    "lng": "-2"
  },
  {
    "country": "GB",
    "name": "Gloucester",
    "lat": "51.86568",
    "lng": "-2.2431"
  },
  {
    "country": "GB",
    "name": "Glossop",
    "lat": "53.44325",
    "lng": "-1.949"
  },
  {
    "country": "GB",
    "name": "Glinton",
    "lat": "52.63921",
    "lng": "-0.29629"
  },
  {
    "country": "GB",
    "name": "Glenrothes",
    "lat": "56.19514",
    "lng": "-3.17316"
  },
  {
    "country": "GB",
    "name": "Glenfield",
    "lat": "52.6466",
    "lng": "-1.19493"
  },
  {
    "country": "GB",
    "name": "Glenboig",
    "lat": "55.89422",
    "lng": "-4.04619"
  },
  {
    "country": "GB",
    "name": "Glenavy",
    "lat": "54.59231",
    "lng": "-6.21371"
  },
  {
    "country": "GB",
    "name": "Glenariff",
    "lat": "55.05",
    "lng": "-6.06667"
  },
  {
    "country": "GB",
    "name": "Glemsford",
    "lat": "52.10351",
    "lng": "0.66912"
  },
  {
    "country": "GB",
    "name": "Glazebury",
    "lat": "53.47078",
    "lng": "-2.49823"
  },
  {
    "country": "GB",
    "name": "Glastonbury",
    "lat": "51.14745",
    "lng": "-2.72075"
  },
  {
    "country": "GB",
    "name": "Glasgow",
    "lat": "55.86515",
    "lng": "-4.25763"
  },
  {
    "country": "GB",
    "name": "Glanamman",
    "lat": "51.8",
    "lng": "-3.93333"
  },
  {
    "country": "GB",
    "name": "Girvan",
    "lat": "55.24255",
    "lng": "-4.85551"
  },
  {
    "country": "GB",
    "name": "Girton",
    "lat": "52.23333",
    "lng": "0.08333"
  },
  {
    "country": "GB",
    "name": "Gilwern",
    "lat": "51.82475",
    "lng": "-3.09355"
  },
  {
    "country": "GB",
    "name": "Gillingham",
    "lat": "51.38914",
    "lng": "0.54863"
  },
  {
    "country": "GB",
    "name": "Gillingham",
    "lat": "51.03833",
    "lng": "-2.27611"
  },
  {
    "country": "GB",
    "name": "Gilford",
    "lat": "54.37256",
    "lng": "-6.36126"
  },
  {
    "country": "GB",
    "name": "Gilfach Goch",
    "lat": "51.59213",
    "lng": "-3.47296"
  },
  {
    "country": "GB",
    "name": "Gildersome",
    "lat": "53.7614",
    "lng": "-1.63147"
  },
  {
    "country": "GB",
    "name": "Gilberdyke",
    "lat": "53.75297",
    "lng": "-0.73892"
  },
  {
    "country": "GB",
    "name": "Giffnock",
    "lat": "55.80373",
    "lng": "-4.29488"
  },
  {
    "country": "GB",
    "name": "Germoe",
    "lat": "50.11539",
    "lng": "-5.37881"
  },
  {
    "country": "GB",
    "name": "Gelligaer",
    "lat": "51.66444",
    "lng": "-3.25611"
  },
  {
    "country": "GB",
    "name": "Gedney Hill",
    "lat": "52.68434",
    "lng": "-0.02008"
  },
  {
    "country": "GB",
    "name": "Geddington",
    "lat": "52.43757",
    "lng": "-0.68965"
  },
  {
    "country": "GB",
    "name": "Gayhurst",
    "lat": "52.11362",
    "lng": "-0.76278"
  },
  {
    "country": "GB",
    "name": "Gateshead",
    "lat": "54.96209",
    "lng": "-1.60168"
  },
  {
    "country": "GB",
    "name": "Garvagh",
    "lat": "54.98333",
    "lng": "-6.66667"
  },
  {
    "country": "GB",
    "name": "Garstang",
    "lat": "53.90081",
    "lng": "-2.77417"
  },
  {
    "country": "GB",
    "name": "Garsington",
    "lat": "51.71623",
    "lng": "-1.16129"
  },
  {
    "country": "GB",
    "name": "Gargrave",
    "lat": "53.98353",
    "lng": "-2.10459"
  },
  {
    "country": "GB",
    "name": "Garforth",
    "lat": "53.79173",
    "lng": "-1.38067"
  },
  {
    "country": "GB",
    "name": "Garelochhead",
    "lat": "56.08203",
    "lng": "-4.82909"
  },
  {
    "country": "GB",
    "name": "Gamlingay",
    "lat": "52.15561",
    "lng": "-0.19303"
  },
  {
    "country": "GB",
    "name": "Galston",
    "lat": "55.60093",
    "lng": "-4.38172"
  },
  {
    "country": "GB",
    "name": "Galgate",
    "lat": "53.99362",
    "lng": "-2.79201"
  },
  {
    "country": "GB",
    "name": "Galashiels",
    "lat": "55.61458",
    "lng": "-2.80695"
  },
  {
    "country": "GB",
    "name": "Gainsborough",
    "lat": "53.38333",
    "lng": "-0.76667"
  },
  {
    "country": "GB",
    "name": "Gainford",
    "lat": "54.54718",
    "lng": "-1.73601"
  },
  {
    "country": "GB",
    "name": "Gaerwen",
    "lat": "53.22112",
    "lng": "-4.27362"
  },
  {
    "country": "GB",
    "name": "Fylde",
    "lat": "53.83333",
    "lng": "-2.91667"
  },
  {
    "country": "GB",
    "name": "Fyfield",
    "lat": "51.41667",
    "lng": "-1.78333"
  },
  {
    "country": "GB",
    "name": "Full Sutton",
    "lat": "53.98869",
    "lng": "-0.86758"
  },
  {
    "country": "GB",
    "name": "Fulford",
    "lat": "53.93333",
    "lng": "-1.06667"
  },
  {
    "country": "GB",
    "name": "Fulbourn",
    "lat": "52.18283",
    "lng": "0.22046"
  },
  {
    "country": "GB",
    "name": "Frome",
    "lat": "51.22834",
    "lng": "-2.32211"
  },
  {
    "country": "GB",
    "name": "Frodsham",
    "lat": "53.29485",
    "lng": "-2.72745"
  },
  {
    "country": "GB",
    "name": "Frizington",
    "lat": "54.54185",
    "lng": "-3.4946"
  },
  {
    "country": "GB",
    "name": "Friston",
    "lat": "50.76402",
    "lng": "0.1993"
  },
  {
    "country": "GB",
    "name": "Friockheim",
    "lat": "56.63688",
    "lng": "-2.66806"
  },
  {
    "country": "GB",
    "name": "Frinton-on-Sea",
    "lat": "51.83061",
    "lng": "1.24424"
  },
  {
    "country": "GB",
    "name": "Frimley",
    "lat": "51.31667",
    "lng": "-0.74544"
  },
  {
    "country": "GB",
    "name": "Freystrop",
    "lat": "51.76333",
    "lng": "-4.96028"
  },
  {
    "country": "GB",
    "name": "Freuchie",
    "lat": "56.24688",
    "lng": "-3.15861"
  },
  {
    "country": "GB",
    "name": "Freshwater",
    "lat": "50.68365",
    "lng": "-1.52616"
  },
  {
    "country": "GB",
    "name": "Freshford",
    "lat": "51.33917",
    "lng": "-2.30306"
  },
  {
    "country": "GB",
    "name": "Fremington",
    "lat": "51.06955",
    "lng": "-4.1366"
  },
  {
    "country": "GB",
    "name": "Freckleton",
    "lat": "53.75433",
    "lng": "-2.86489"
  },
  {
    "country": "GB",
    "name": "Fraserburgh",
    "lat": "57.68744",
    "lng": "-2.01844"
  },
  {
    "country": "GB",
    "name": "Frampton on Severn",
    "lat": "51.77054",
    "lng": "-2.36382"
  },
  {
    "country": "GB",
    "name": "Framlingham",
    "lat": "52.22117",
    "lng": "1.34205"
  },
  {
    "country": "GB",
    "name": "Fowlmere",
    "lat": "52.09343",
    "lng": "0.07433"
  },
  {
    "country": "GB",
    "name": "Fowey",
    "lat": "50.33634",
    "lng": "-4.6386"
  },
  {
    "country": "GB",
    "name": "Four Marks",
    "lat": "51.10735",
    "lng": "-1.04945"
  },
  {
    "country": "GB",
    "name": "Four Crosses",
    "lat": "52.75941",
    "lng": "-3.08106"
  },
  {
    "country": "GB",
    "name": "Foulsham",
    "lat": "52.78182",
    "lng": "1.01049"
  },
  {
    "country": "GB",
    "name": "Foulridge",
    "lat": "53.87579",
    "lng": "-2.16864"
  },
  {
    "country": "GB",
    "name": "Fort William",
    "lat": "56.81648",
    "lng": "-5.11208"
  },
  {
    "country": "GB",
    "name": "Fortuneswell",
    "lat": "50.5603",
    "lng": "-2.44243"
  },
  {
    "country": "GB",
    "name": "Fortrose",
    "lat": "57.58087",
    "lng": "-4.13263"
  },
  {
    "country": "GB",
    "name": "Forth",
    "lat": "55.76502",
    "lng": "-3.68874"
  },
  {
    "country": "GB",
    "name": "Forres",
    "lat": "57.60997",
    "lng": "-3.62115"
  },
  {
    "country": "GB",
    "name": "Formby",
    "lat": "53.55838",
    "lng": "-3.06999"
  },
  {
    "country": "GB",
    "name": "Forfar",
    "lat": "56.64382",
    "lng": "-2.89001"
  },
  {
    "country": "GB",
    "name": "Forest Row",
    "lat": "51.09641",
    "lng": "0.03262"
  },
  {
    "country": "GB",
    "name": "Fordingbridge",
    "lat": "50.92747",
    "lng": "-1.79029"
  },
  {
    "country": "GB",
    "name": "Fordham",
    "lat": "52.31129",
    "lng": "0.39057"
  },
  {
    "country": "GB",
    "name": "Ford",
    "lat": "55.63333",
    "lng": "-2.08333"
  },
  {
    "country": "GB",
    "name": "Ford",
    "lat": "52.71693",
    "lng": "-2.86881"
  },
  {
    "country": "GB",
    "name": "Folkestone",
    "lat": "51.08169",
    "lng": "1.16734"
  },
  {
    "country": "GB",
    "name": "Fochriw",
    "lat": "51.74003",
    "lng": "-3.29861"
  },
  {
    "country": "GB",
    "name": "Fochabers",
    "lat": "57.61445",
    "lng": "-3.09947"
  },
  {
    "country": "GB",
    "name": "Flore",
    "lat": "52.23647",
    "lng": "-1.05726"
  },
  {
    "country": "GB",
    "name": "Flookburgh",
    "lat": "54.17415",
    "lng": "-2.97214"
  },
  {
    "country": "GB",
    "name": "Flockton",
    "lat": "53.63034",
    "lng": "-1.63945"
  },
  {
    "country": "GB",
    "name": "Flitwick",
    "lat": "52.00338",
    "lng": "-0.49472"
  },
  {
    "country": "GB",
    "name": "Flint",
    "lat": "53.24488",
    "lng": "-3.13231"
  },
  {
    "country": "GB",
    "name": "Flimby",
    "lat": "54.68956",
    "lng": "-3.52092"
  },
  {
    "country": "GB",
    "name": "Fleetwood",
    "lat": "53.92527",
    "lng": "-3.01085"
  },
  {
    "country": "GB",
    "name": "Fleet",
    "lat": "52.79321",
    "lng": "0.05854"
  },
  {
    "country": "GB",
    "name": "Fleet",
    "lat": "51.28333",
    "lng": "-0.83333"
  },
  {
    "country": "GB",
    "name": "Flamborough",
    "lat": "54.11487",
    "lng": "-0.12274"
  },
  {
    "country": "GB",
    "name": "Fivemiletown",
    "lat": "54.38333",
    "lng": "-7.3"
  },
  {
    "country": "GB",
    "name": "Fitzwilliam",
    "lat": "53.63288",
    "lng": "-1.3769"
  },
  {
    "country": "GB",
    "name": "Fishtoft",
    "lat": "52.96095",
    "lng": "0.02702"
  },
  {
    "country": "GB",
    "name": "Fishguard",
    "lat": "51.99376",
    "lng": "-4.97631"
  },
  {
    "country": "GB",
    "name": "Fishburn",
    "lat": "54.68296",
    "lng": "-1.43631"
  },
  {
    "country": "GB",
    "name": "Fintona",
    "lat": "54.5",
    "lng": "-7.31667"
  },
  {
    "country": "GB",
    "name": "Finningley",
    "lat": "53.48696",
    "lng": "-0.99083"
  },
  {
    "country": "GB",
    "name": "Finedon",
    "lat": "52.33917",
    "lng": "-0.65008"
  },
  {
    "country": "GB",
    "name": "Findon",
    "lat": "50.86816",
    "lng": "-0.40735"
  },
  {
    "country": "GB",
    "name": "Findochty",
    "lat": "57.69735",
    "lng": "-2.90104"
  },
  {
    "country": "GB",
    "name": "Findern",
    "lat": "52.87037",
    "lng": "-1.54409"
  },
  {
    "country": "GB",
    "name": "Finchampstead",
    "lat": "51.36149",
    "lng": "-0.85728"
  },
  {
    "country": "GB",
    "name": "Fimber",
    "lat": "54.03495",
    "lng": "-0.63133"
  },
  {
    "country": "GB",
    "name": "Filey",
    "lat": "54.21",
    "lng": "-0.28917"
  },
  {
    "country": "GB",
    "name": "Ffestiniog",
    "lat": "52.95996",
    "lng": "-3.93242"
  },
  {
    "country": "GB",
    "name": "Ferryhill",
    "lat": "54.68333",
    "lng": "-1.55"
  },
  {
    "country": "GB",
    "name": "Ferrybridge",
    "lat": "53.71058",
    "lng": "-1.27948"
  },
  {
    "country": "GB",
    "name": "Fernhurst",
    "lat": "51.04873",
    "lng": "-0.71789"
  },
  {
    "country": "GB",
    "name": "Fernhill Heath",
    "lat": "52.23002",
    "lng": "-2.19659"
  },
  {
    "country": "GB",
    "name": "Ferndale",
    "lat": "51.66056",
    "lng": "-3.4475"
  },
  {
    "country": "GB",
    "name": "Fenwick",
    "lat": "55.65823",
    "lng": "-4.44342"
  },
  {
    "country": "GB",
    "name": "Fenwick",
    "lat": "53.63868",
    "lng": "-1.0976"
  },
  {
    "country": "GB",
    "name": "Fenstanton",
    "lat": "52.29903",
    "lng": "-0.06712"
  },
  {
    "country": "GB",
    "name": "Feltwell",
    "lat": "52.48581",
    "lng": "0.51945"
  },
  {
    "country": "GB",
    "name": "Felton",
    "lat": "55.29768",
    "lng": "-1.71143"
  },
  {
    "country": "GB",
    "name": "Feltham",
    "lat": "51.4462",
    "lng": "-0.41388"
  },
  {
    "country": "GB",
    "name": "Felling",
    "lat": "54.95297",
    "lng": "-1.57152"
  },
  {
    "country": "GB",
    "name": "Felixstowe",
    "lat": "51.96375",
    "lng": "1.3511"
  },
  {
    "country": "GB",
    "name": "Felbridge",
    "lat": "51.13913",
    "lng": "-0.04116"
  },
  {
    "country": "GB",
    "name": "Featherstone",
    "lat": "53.67688",
    "lng": "-1.35647"
  },
  {
    "country": "GB",
    "name": "Fazeley",
    "lat": "52.61443",
    "lng": "-1.6985"
  },
  {
    "country": "GB",
    "name": "Faversham",
    "lat": "51.3148",
    "lng": "0.88856"
  },
  {
    "country": "GB",
    "name": "Fauldhouse",
    "lat": "55.82749",
    "lng": "-3.70741"
  },
  {
    "country": "GB",
    "name": "Farnworth",
    "lat": "53.55",
    "lng": "-2.4"
  },
  {
    "country": "GB",
    "name": "Farnsfield",
    "lat": "53.10223",
    "lng": "-1.0332"
  },
  {
    "country": "GB",
    "name": "Farnham Royal",
    "lat": "51.54208",
    "lng": "-0.61584"
  },
  {
    "country": "GB",
    "name": "Farnham",
    "lat": "51.21444",
    "lng": "-0.80054"
  },
  {
    "country": "GB",
    "name": "Farndon",
    "lat": "53.08361",
    "lng": "-2.87464"
  },
  {
    "country": "GB",
    "name": "Farndon",
    "lat": "53.05",
    "lng": "-0.85"
  },
  {
    "country": "GB",
    "name": "Farnborough",
    "lat": "52.14289",
    "lng": "-1.36926"
  },
  {
    "country": "GB",
    "name": "Farnborough",
    "lat": "51.53333",
    "lng": "-1.36667"
  },
  {
    "country": "GB",
    "name": "Farnborough",
    "lat": "51.35948",
    "lng": "0.06905"
  },
  {
    "country": "GB",
    "name": "Farnborough",
    "lat": "51.29424",
    "lng": "-0.75565"
  },
  {
    "country": "GB",
    "name": "Faringdon",
    "lat": "51.65644",
    "lng": "-1.58676"
  },
  {
    "country": "GB",
    "name": "Fareham",
    "lat": "50.85162",
    "lng": "-1.17929"
  },
  {
    "country": "GB",
    "name": "Falmouth",
    "lat": "50.15441",
    "lng": "-5.07113"
  },
  {
    "country": "GB",
    "name": "Falkland",
    "lat": "56.25255",
    "lng": "-3.20389"
  },
  {
    "country": "GB",
    "name": "Falkirk",
    "lat": "56.0021",
    "lng": "-3.78535"
  },
  {
    "country": "GB",
    "name": "Falfield",
    "lat": "51.63694",
    "lng": "-2.46056"
  },
  {
    "country": "GB",
    "name": "Fakenham",
    "lat": "52.82996",
    "lng": "0.8477"
  },
  {
    "country": "GB",
    "name": "Fairlight",
    "lat": "50.87802",
    "lng": "0.65669"
  },
  {
    "country": "GB",
    "name": "Fairlie",
    "lat": "55.75602",
    "lng": "-4.85564"
  },
  {
    "country": "GB",
    "name": "Fairford",
    "lat": "51.70816",
    "lng": "-1.78128"
  },
  {
    "country": "GB",
    "name": "Eyton upon the Weald Moors",
    "lat": "52.73333",
    "lng": "-2.51667"
  },
  {
    "country": "GB",
    "name": "Eyton",
    "lat": "52.25",
    "lng": "-2.75"
  },
  {
    "country": "GB",
    "name": "Eythorne",
    "lat": "51.1971",
    "lng": "1.2662"
  },
  {
    "country": "GB",
    "name": "Eynsham",
    "lat": "51.78077",
    "lng": "-1.37454"
  },
  {
    "country": "GB",
    "name": "Eynsford",
    "lat": "51.36765",
    "lng": "0.21132"
  },
  {
    "country": "GB",
    "name": "Eyemouth",
    "lat": "55.8713",
    "lng": "-2.0901"
  },
  {
    "country": "GB",
    "name": "Eye",
    "lat": "52.608",
    "lng": "-0.19209"
  },
  {
    "country": "GB",
    "name": "Exton",
    "lat": "52.69106",
    "lng": "-0.63463"
  },
  {
    "country": "GB",
    "name": "Exning",
    "lat": "52.26642",
    "lng": "0.37439"
  },
  {
    "country": "GB",
    "name": "Exmouth",
    "lat": "50.61723",
    "lng": "-3.40233"
  },
  {
    "country": "GB",
    "name": "Exminster",
    "lat": "50.68075",
    "lng": "-3.49706"
  },
  {
    "country": "GB",
    "name": "Exhall",
    "lat": "52.46464",
    "lng": "-1.48144"
  },
  {
    "country": "GB",
    "name": "Exeter",
    "lat": "50.7236",
    "lng": "-3.52751"
  },
  {
    "country": "GB",
    "name": "Ewyas Harold",
    "lat": "51.95358",
    "lng": "-2.89325"
  },
  {
    "country": "GB",
    "name": "Ewhurst",
    "lat": "51.15448",
    "lng": "-0.44344"
  },
  {
    "country": "GB",
    "name": "Evesham",
    "lat": "52.09237",
    "lng": "-1.94887"
  },
  {
    "country": "GB",
    "name": "Evesbatch",
    "lat": "52.13333",
    "lng": "-2.45"
  },
  {
    "country": "GB",
    "name": "Everton",
    "lat": "52.14581",
    "lng": "-0.24616"
  },
  {
    "country": "GB",
    "name": "Eversholt",
    "lat": "51.98702",
    "lng": "-0.55983"
  },
  {
    "country": "GB",
    "name": "Evercreech",
    "lat": "51.14806",
    "lng": "-2.50556"
  },
  {
    "country": "GB",
    "name": "Evenwood",
    "lat": "54.62213",
    "lng": "-1.76133"
  },
  {
    "country": "GB",
    "name": "Evanton",
    "lat": "57.66385",
    "lng": "-4.34004"
  },
  {
    "country": "GB",
    "name": "Euxton",
    "lat": "53.6699",
    "lng": "-2.67615"
  },
  {
    "country": "GB",
    "name": "Etwall",
    "lat": "52.88353",
    "lng": "-1.60023"
  },
  {
    "country": "GB",
    "name": "Etton",
    "lat": "53.87848",
    "lng": "-0.51314"
  },
  {
    "country": "GB",
    "name": "Eton",
    "lat": "51.48833",
    "lng": "-0.60905"
  },
  {
    "country": "GB",
    "name": "Essendine",
    "lat": "52.70187",
    "lng": "-0.4525"
  },
  {
    "country": "GB",
    "name": "Esher",
    "lat": "51.36969",
    "lng": "-0.36693"
  },
  {
    "country": "GB",
    "name": "Errol",
    "lat": "56.39234",
    "lng": "-3.21275"
  },
  {
    "country": "GB",
    "name": "Erlestoke",
    "lat": "51.28472",
    "lng": "-2.05444"
  },
  {
    "country": "GB",
    "name": "Erith",
    "lat": "51.48315",
    "lng": "0.17484"
  },
  {
    "country": "GB",
    "name": "Epworth",
    "lat": "53.52602",
    "lng": "-0.82399"
  },
  {
    "country": "GB",
    "name": "Epsom",
    "lat": "51.3305",
    "lng": "-0.27011"
  },
  {
    "country": "GB",
    "name": "Epping",
    "lat": "51.69815",
    "lng": "0.11055"
  },
  {
    "country": "GB",
    "name": "Enniskillen",
    "lat": "54.34615",
    "lng": "-7.64133"
  },
  {
    "country": "GB",
    "name": "Enfield Town",
    "lat": "51.65147",
    "lng": "-0.08497"
  },
  {
    "country": "GB",
    "name": "Enderby",
    "lat": "52.58778",
    "lng": "-1.20619"
  },
  {
    "country": "GB",
    "name": "Emsworth",
    "lat": "50.84779",
    "lng": "-0.93697"
  },
  {
    "country": "GB",
    "name": "Empingham",
    "lat": "52.66722",
    "lng": "-0.59601"
  },
  {
    "country": "GB",
    "name": "Emneth",
    "lat": "52.64244",
    "lng": "0.20857"
  },
  {
    "country": "GB",
    "name": "Emley",
    "lat": "53.61395",
    "lng": "-1.6313"
  },
  {
    "country": "GB",
    "name": "Embsay",
    "lat": "53.97664",
    "lng": "-1.99282"
  },
  {
    "country": "GB",
    "name": "Embleton",
    "lat": "55.49592",
    "lng": "-1.63619"
  },
  {
    "country": "GB",
    "name": "Emberton",
    "lat": "52.13691",
    "lng": "-0.70673"
  },
  {
    "country": "GB",
    "name": "Ely",
    "lat": "52.39964",
    "lng": "0.26196"
  },
  {
    "country": "GB",
    "name": "Elwick",
    "lat": "54.68455",
    "lng": "-1.29559"
  },
  {
    "country": "GB",
    "name": "Elvington",
    "lat": "53.92087",
    "lng": "-0.93495"
  },
  {
    "country": "GB",
    "name": "Elton",
    "lat": "54.55",
    "lng": "-1.36667"
  },
  {
    "country": "GB",
    "name": "Elton",
    "lat": "53.26667",
    "lng": "-2.81667"
  },
  {
    "country": "GB",
    "name": "Elton",
    "lat": "52.33333",
    "lng": "-2.8"
  },
  {
    "country": "GB",
    "name": "Elswick",
    "lat": "53.83836",
    "lng": "-2.88147"
  },
  {
    "country": "GB",
    "name": "Elstree",
    "lat": "51.6403",
    "lng": "-0.29693"
  },
  {
    "country": "GB",
    "name": "Elstow",
    "lat": "52.10727",
    "lng": "-0.4649"
  },
  {
    "country": "GB",
    "name": "Elstead",
    "lat": "51.18548",
    "lng": "-0.70536"
  },
  {
    "country": "GB",
    "name": "Elsenham",
    "lat": "51.91431",
    "lng": "0.22934"
  },
  {
    "country": "GB",
    "name": "Elmswell",
    "lat": "52.23616",
    "lng": "0.91247"
  },
  {
    "country": "GB",
    "name": "Ellon",
    "lat": "57.36405",
    "lng": "-2.07313"
  },
  {
    "country": "GB",
    "name": "Ellingham",
    "lat": "55.52589",
    "lng": "-1.73601"
  },
  {
    "country": "GB",
    "name": "Ellesmere Port",
    "lat": "53.27875",
    "lng": "-2.90134"
  },
  {
    "country": "GB",
    "name": "Ellesmere",
    "lat": "52.90838",
    "lng": "-2.89806"
  },
  {
    "country": "GB",
    "name": "Ellerton",
    "lat": "53.85",
    "lng": "-0.93333"
  },
  {
    "country": "GB",
    "name": "Ellerker",
    "lat": "53.75323",
    "lng": "-0.60416"
  },
  {
    "country": "GB",
    "name": "Elland",
    "lat": "53.6851",
    "lng": "-1.83878"
  },
  {
    "country": "GB",
    "name": "Elgin",
    "lat": "57.64947",
    "lng": "-3.31843"
  },
  {
    "country": "GB",
    "name": "Elderslie",
    "lat": "55.83327",
    "lng": "-4.48598"
  },
  {
    "country": "GB",
    "name": "Egremont",
    "lat": "54.47941",
    "lng": "-3.52756"
  },
  {
    "country": "GB",
    "name": "Eglinton",
    "lat": "55.01667",
    "lng": "-7.18333"
  },
  {
    "country": "GB",
    "name": "Egham",
    "lat": "51.43158",
    "lng": "-0.55239"
  },
  {
    "country": "GB",
    "name": "Eggleston",
    "lat": "54.60916",
    "lng": "-2.00312"
  },
  {
    "country": "GB",
    "name": "Edworth",
    "lat": "52.05597",
    "lng": "-0.21715"
  },
  {
    "country": "GB",
    "name": "Edwinstowe",
    "lat": "53.19454",
    "lng": "-1.06439"
  },
  {
    "country": "GB",
    "name": "Edith Weston",
    "lat": "52.63786",
    "lng": "-0.63189"
  },
  {
    "country": "GB",
    "name": "Edington",
    "lat": "51.27583",
    "lng": "-2.10639"
  },
  {
    "country": "GB",
    "name": "Edinburgh",
    "lat": "55.95206",
    "lng": "-3.19648"
  },
  {
    "country": "GB",
    "name": "Edgworth",
    "lat": "53.64636",
    "lng": "-2.39401"
  },
  {
    "country": "GB",
    "name": "Edgware",
    "lat": "51.6128",
    "lng": "-0.27539"
  },
  {
    "country": "GB",
    "name": "Edgmond",
    "lat": "52.774",
    "lng": "-2.40967"
  },
  {
    "country": "GB",
    "name": "Edenfield",
    "lat": "53.66674",
    "lng": "-2.30481"
  },
  {
    "country": "GB",
    "name": "Edenbridge",
    "lat": "51.19172",
    "lng": "0.06729"
  },
  {
    "country": "GB",
    "name": "Eckington",
    "lat": "52.06667",
    "lng": "-2.11667"
  },
  {
    "country": "GB",
    "name": "Eccleston",
    "lat": "53.64236",
    "lng": "-2.72162"
  },
  {
    "country": "GB",
    "name": "Eccleston",
    "lat": "53.45",
    "lng": "-2.78333"
  },
  {
    "country": "GB",
    "name": "Eccleston",
    "lat": "53.15",
    "lng": "-2.88333"
  },
  {
    "country": "GB",
    "name": "Eccleshall",
    "lat": "52.85789",
    "lng": "-2.24971"
  },
  {
    "country": "GB",
    "name": "Eccles",
    "lat": "53.48333",
    "lng": "-2.33333"
  },
  {
    "country": "GB",
    "name": "Ebbw Vale",
    "lat": "51.77714",
    "lng": "-3.20792"
  },
  {
    "country": "GB",
    "name": "Eaton Socon",
    "lat": "52.21752",
    "lng": "-0.28925"
  },
  {
    "country": "GB",
    "name": "Eaton Bray",
    "lat": "51.87697",
    "lng": "-0.59167"
  },
  {
    "country": "GB",
    "name": "Eaton",
    "lat": "53.18333",
    "lng": "-2.2"
  },
  {
    "country": "GB",
    "name": "Eattington",
    "lat": "52.13333",
    "lng": "-1.6"
  },
  {
    "country": "GB",
    "name": "Eastwood",
    "lat": "53",
    "lng": "-1.3"
  },
  {
    "country": "GB",
    "name": "East Wittering",
    "lat": "50.76969",
    "lng": "-0.87444"
  },
  {
    "country": "GB",
    "name": "East Wemyss",
    "lat": "56.16018",
    "lng": "-3.06422"
  },
  {
    "country": "GB",
    "name": "East Tilbury",
    "lat": "51.48053",
    "lng": "0.41714"
  },
  {
    "country": "GB",
    "name": "Eastry",
    "lat": "51.24639",
    "lng": "1.30776"
  },
  {
    "country": "GB",
    "name": "Eastrington",
    "lat": "53.76038",
    "lng": "-0.79325"
  },
  {
    "country": "GB",
    "name": "Retford",
    "lat": "53.32213",
    "lng": "-0.94315"
  },
  {
    "country": "GB",
    "name": "East Peckham",
    "lat": "51.21234",
    "lng": "0.38624"
  },
  {
    "country": "GB",
    "name": "Easton on the Hill",
    "lat": "52.62733",
    "lng": "-0.50571"
  },
  {
    "country": "GB",
    "name": "Easton",
    "lat": "50.53333",
    "lng": "-2.45"
  },
  {
    "country": "GB",
    "name": "Eastoft",
    "lat": "53.63624",
    "lng": "-0.78492"
  },
  {
    "country": "GB",
    "name": "East Molesey",
    "lat": "51.39872",
    "lng": "-0.34916"
  },
  {
    "country": "GB",
    "name": "East Markham",
    "lat": "53.25221",
    "lng": "-0.89385"
  },
  {
    "country": "GB",
    "name": "East Linton",
    "lat": "55.98737",
    "lng": "-2.65682"
  },
  {
    "country": "GB",
    "name": "Eastleigh",
    "lat": "50.96667",
    "lng": "-1.35"
  },
  {
    "country": "GB",
    "name": "East Leake",
    "lat": "52.83015",
    "lng": "-1.18103"
  },
  {
    "country": "GB",
    "name": "East Kilbride",
    "lat": "55.76412",
    "lng": "-4.17669"
  },
  {
    "country": "GB",
    "name": "East Horsley",
    "lat": "51.27358",
    "lng": "-0.43207"
  },
  {
    "country": "GB",
    "name": "East Harptree",
    "lat": "51.30111",
    "lng": "-2.62167"
  },
  {
    "country": "GB",
    "name": "East Harling",
    "lat": "52.43843",
    "lng": "0.93353"
  },
  {
    "country": "GB",
    "name": "East Hanney",
    "lat": "51.63443",
    "lng": "-1.39518"
  },
  {
    "country": "GB",
    "name": "East Ham",
    "lat": "51.53333",
    "lng": "0.05"
  },
  {
    "country": "GB",
    "name": "East Grinstead",
    "lat": "51.12382",
    "lng": "-0.0061"
  },
  {
    "country": "GB",
    "name": "East Dereham",
    "lat": "52.68333",
    "lng": "0.93333"
  },
  {
    "country": "GB",
    "name": "East Dean",
    "lat": "51.03979",
    "lng": "-1.60941"
  },
  {
    "country": "GB",
    "name": "Eastchurch",
    "lat": "51.40673",
    "lng": "0.85766"
  },
  {
    "country": "GB",
    "name": "East Chevington",
    "lat": "55.28333",
    "lng": "-1.58333"
  },
  {
    "country": "GB",
    "name": "East Calder",
    "lat": "55.89186",
    "lng": "-3.46372"
  },
  {
    "country": "GB",
    "name": "East Bridgford",
    "lat": "52.97954",
    "lng": "-0.96563"
  },
  {
    "country": "GB",
    "name": "Eastbourne",
    "lat": "50.76871",
    "lng": "0.28453"
  },
  {
    "country": "GB",
    "name": "East Boldon",
    "lat": "54.94452",
    "lng": "-1.42815"
  },
  {
    "country": "GB",
    "name": "East Bergholt",
    "lat": "51.97785",
    "lng": "1.01761"
  },
  {
    "country": "GB",
    "name": "Easingwold",
    "lat": "54.1201",
    "lng": "-1.1939"
  },
  {
    "country": "GB",
    "name": "Easington",
    "lat": "54.78528",
    "lng": "-1.35917"
  },
  {
    "country": "GB",
    "name": "Easington",
    "lat": "53.65359",
    "lng": "0.11501"
  },
  {
    "country": "GB",
    "name": "Earlston",
    "lat": "55.63856",
    "lng": "-2.67495"
  },
  {
    "country": "GB",
    "name": "Earls Colne",
    "lat": "51.92744",
    "lng": "0.70107"
  },
  {
    "country": "GB",
    "name": "Earls Barton",
    "lat": "52.26627",
    "lng": "-0.75248"
  },
  {
    "country": "GB",
    "name": "Earley",
    "lat": "51.44085",
    "lng": "-0.92384"
  },
  {
    "country": "GB",
    "name": "Earith",
    "lat": "52.35422",
    "lng": "0.03056"
  },
  {
    "country": "GB",
    "name": "Earby",
    "lat": "53.91546",
    "lng": "-2.14285"
  },
  {
    "country": "GB",
    "name": "Ealing",
    "lat": "51.51216",
    "lng": "-0.30204"
  },
  {
    "country": "GB",
    "name": "Eaglesham",
    "lat": "55.74119",
    "lng": "-4.27459"
  },
  {
    "country": "GB",
    "name": "Dyserth",
    "lat": "53.30032",
    "lng": "-3.41262"
  },
  {
    "country": "GB",
    "name": "Dymchurch",
    "lat": "51.02544",
    "lng": "0.99392"
  },
  {
    "country": "GB",
    "name": "Dyce",
    "lat": "57.20522",
    "lng": "-2.17676"
  },
  {
    "country": "GB",
    "name": "Duxford",
    "lat": "52.09393",
    "lng": "0.15917"
  },
  {
    "country": "GB",
    "name": "Dursley",
    "lat": "51.68139",
    "lng": "-2.35333"
  },
  {
    "country": "GB",
    "name": "Durrington",
    "lat": "51.19871",
    "lng": "-1.77185"
  },
  {
    "country": "GB",
    "name": "Durnford",
    "lat": "51.13333",
    "lng": "-1.81667"
  },
  {
    "country": "GB",
    "name": "Durham",
    "lat": "54.77676",
    "lng": "-1.57566"
  },
  {
    "country": "GB",
    "name": "Duntocher",
    "lat": "55.92437",
    "lng": "-4.41545"
  },
  {
    "country": "GB",
    "name": "Dunswell",
    "lat": "53.80106",
    "lng": "-0.37139"
  },
  {
    "country": "GB",
    "name": "Dunstable",
    "lat": "51.88571",
    "lng": "-0.52288"
  },
  {
    "country": "GB",
    "name": "Duns",
    "lat": "55.77704",
    "lng": "-2.34575"
  },
  {
    "country": "GB",
    "name": "Dunoon",
    "lat": "55.95031",
    "lng": "-4.92734"
  },
  {
    "country": "GB",
    "name": "Dunnington",
    "lat": "53.95",
    "lng": "-0.25"
  },
  {
    "country": "GB",
    "name": "Dunloy",
    "lat": "55.011",
    "lng": "-6.41087"
  },
  {
    "country": "GB",
    "name": "Dunlop",
    "lat": "55.71198",
    "lng": "-4.53622"
  },
  {
    "country": "GB",
    "name": "Dunkeswell",
    "lat": "50.86301",
    "lng": "-3.22289"
  },
  {
    "country": "GB",
    "name": "Dunipace",
    "lat": "56.027",
    "lng": "-3.91471"
  },
  {
    "country": "GB",
    "name": "Dunholme",
    "lat": "53.30067",
    "lng": "-0.46541"
  },
  {
    "country": "GB",
    "name": "Dungiven",
    "lat": "54.93333",
    "lng": "-6.91667"
  },
  {
    "country": "GB",
    "name": "Dungannon",
    "lat": "54.50344",
    "lng": "-6.76723"
  },
  {
    "country": "GB",
    "name": "Dunfermline",
    "lat": "56.07156",
    "lng": "-3.45887"
  },
  {
    "country": "GB",
    "name": "Dundry",
    "lat": "51.3988",
    "lng": "-2.63964"
  },
  {
    "country": "GB",
    "name": "Dundrum",
    "lat": "54.2575",
    "lng": "-5.84455"
  },
  {
    "country": "GB",
    "name": "Dundonald",
    "lat": "55.57939",
    "lng": "-4.59473"
  },
  {
    "country": "GB",
    "name": "Dundonald",
    "lat": "54.59196",
    "lng": "-5.79803"
  },
  {
    "country": "GB",
    "name": "Dundee",
    "lat": "56.46913",
    "lng": "-2.97489"
  },
  {
    "country": "GB",
    "name": "Dunchurch",
    "lat": "52.33757",
    "lng": "-1.29136"
  },
  {
    "country": "GB",
    "name": "Dunblane",
    "lat": "56.18843",
    "lng": "-3.96417"
  },
  {
    "country": "GB",
    "name": "Dunbar",
    "lat": "56.00062",
    "lng": "-2.51418"
  },
  {
    "country": "GB",
    "name": "Dumfries",
    "lat": "55.06959",
    "lng": "-3.61139"
  },
  {
    "country": "GB",
    "name": "Dumbarton",
    "lat": "55.94433",
    "lng": "-4.57061"
  },
  {
    "country": "GB",
    "name": "Dulverton",
    "lat": "51.04007",
    "lng": "-3.55035"
  },
  {
    "country": "GB",
    "name": "Duloe",
    "lat": "50.38333",
    "lng": "-4.48333"
  },
  {
    "country": "GB",
    "name": "Dukinfield",
    "lat": "53.47497",
    "lng": "-2.08809"
  },
  {
    "country": "GB",
    "name": "Dufftown",
    "lat": "57.44571",
    "lng": "-3.12708"
  },
  {
    "country": "GB",
    "name": "Duffield",
    "lat": "52.98627",
    "lng": "-1.48865"
  },
  {
    "country": "GB",
    "name": "Dudley",
    "lat": "52.5",
    "lng": "-2.08333"
  },
  {
    "country": "GB",
    "name": "Ducklington",
    "lat": "51.76763",
    "lng": "-1.48418"
  },
  {
    "country": "GB",
    "name": "Drybrook",
    "lat": "51.8555",
    "lng": "-2.51681"
  },
  {
    "country": "GB",
    "name": "Drumnadrochit",
    "lat": "57.33438",
    "lng": "-4.47989"
  },
  {
    "country": "GB",
    "name": "Droylsden",
    "lat": "53.48005",
    "lng": "-2.14543"
  },
  {
    "country": "GB",
    "name": "Dronfield",
    "lat": "53.30221",
    "lng": "-1.47507"
  },
  {
    "country": "GB",
    "name": "Dromore",
    "lat": "54.51331",
    "lng": "-7.45886"
  },
  {
    "country": "GB",
    "name": "Droitwich",
    "lat": "52.26667",
    "lng": "-2.15"
  },
  {
    "country": "GB",
    "name": "Drighlington",
    "lat": "53.75592",
    "lng": "-1.66443"
  },
  {
    "country": "GB",
    "name": "Dreghorn",
    "lat": "55.60807",
    "lng": "-4.62226"
  },
  {
    "country": "GB",
    "name": "Draycott",
    "lat": "51.25615",
    "lng": "-2.75116"
  },
  {
    "country": "GB",
    "name": "Draperstown",
    "lat": "54.8",
    "lng": "-6.76667"
  },
  {
    "country": "GB",
    "name": "Downton",
    "lat": "52.36667",
    "lng": "-2.83333"
  },
  {
    "country": "GB",
    "name": "Downton",
    "lat": "50.99366",
    "lng": "-1.75129"
  },
  {
    "country": "GB",
    "name": "Downpatrick",
    "lat": "54.32814",
    "lng": "-5.71529"
  },
  {
    "country": "GB",
    "name": "Downham Market",
    "lat": "52.60714",
    "lng": "0.38375"
  },
  {
    "country": "GB",
    "name": "Doveridge",
    "lat": "52.90526",
    "lng": "-1.8248"
  },
  {
    "country": "GB",
    "name": "Dovercourt",
    "lat": "51.93649",
    "lng": "1.27831"
  },
  {
    "country": "GB",
    "name": "Dover",
    "lat": "51.12598",
    "lng": "1.31257"
  },
  {
    "country": "GB",
    "name": "Dove Holes",
    "lat": "53.29828",
    "lng": "-1.88775"
  },
  {
    "country": "GB",
    "name": "Doune",
    "lat": "56.18995",
    "lng": "-4.05288"
  },
  {
    "country": "GB",
    "name": "Douglas",
    "lat": "55.55",
    "lng": "-3.85"
  },
  {
    "country": "GB",
    "name": "Dorstone",
    "lat": "52.06667",
    "lng": "-3"
  },
  {
    "country": "GB",
    "name": "Dorridge",
    "lat": "52.37259",
    "lng": "-1.75318"
  },
  {
    "country": "GB",
    "name": "Dornoch",
    "lat": "57.8805",
    "lng": "-4.02879"
  },
  {
    "country": "GB",
    "name": "Dormansland",
    "lat": "51.16024",
    "lng": "0.00618"
  },
  {
    "country": "GB",
    "name": "Dorking",
    "lat": "51.23228",
    "lng": "-0.3338"
  },
  {
    "country": "GB",
    "name": "Dorchester",
    "lat": "50.71667",
    "lng": "-2.43333"
  },
  {
    "country": "GB",
    "name": "Donnington",
    "lat": "52",
    "lng": "-2.41667"
  },
  {
    "country": "GB",
    "name": "Donisthorpe",
    "lat": "52.72401",
    "lng": "-1.538"
  },
  {
    "country": "GB",
    "name": "Donington",
    "lat": "52.90461",
    "lng": "-0.20505"
  },
  {
    "country": "GB",
    "name": "Doncaster",
    "lat": "53.52285",
    "lng": "-1.13116"
  },
  {
    "country": "GB",
    "name": "Donaghadee",
    "lat": "54.64126",
    "lng": "-5.53591"
  },
  {
    "country": "GB",
    "name": "Dollar",
    "lat": "56.16245",
    "lng": "-3.67135"
  },
  {
    "country": "GB",
    "name": "Dolgellau",
    "lat": "52.74222",
    "lng": "-3.88611"
  },
  {
    "country": "GB",
    "name": "Dodworth",
    "lat": "53.54306",
    "lng": "-1.52779"
  },
  {
    "country": "GB",
    "name": "Doddington",
    "lat": "55.58548",
    "lng": "-2.00415"
  },
  {
    "country": "GB",
    "name": "Doddington",
    "lat": "52.49671",
    "lng": "0.06017"
  },
  {
    "country": "GB",
    "name": "Dobwalls",
    "lat": "50.45768",
    "lng": "-4.51735"
  },
  {
    "country": "GB",
    "name": "Doagh",
    "lat": "54.75",
    "lng": "-6.08333"
  },
  {
    "country": "GB",
    "name": "Ditchling",
    "lat": "50.921",
    "lng": "-0.11536"
  },
  {
    "country": "GB",
    "name": "Ditchingham",
    "lat": "52.46729",
    "lng": "1.4437"
  },
  {
    "country": "GB",
    "name": "Distington",
    "lat": "54.59733",
    "lng": "-3.5388"
  },
  {
    "country": "GB",
    "name": "Diss",
    "lat": "52.37675",
    "lng": "1.1091"
  },
  {
    "country": "GB",
    "name": "Disley",
    "lat": "53.35865",
    "lng": "-2.03848"
  },
  {
    "country": "GB",
    "name": "Dinton",
    "lat": "51.08333",
    "lng": "-1.98333"
  },
  {
    "country": "GB",
    "name": "Dinnington",
    "lat": "55.05428",
    "lng": "-1.67542"
  },
  {
    "country": "GB",
    "name": "Dinnington",
    "lat": "53.36667",
    "lng": "-1.2"
  },
  {
    "country": "GB",
    "name": "Dinmore",
    "lat": "52.15",
    "lng": "-2.75"
  },
  {
    "country": "GB",
    "name": "Dingwall",
    "lat": "57.59531",
    "lng": "-4.42721"
  },
  {
    "country": "GB",
    "name": "Dinas Powys",
    "lat": "51.43486",
    "lng": "-3.21398"
  },
  {
    "country": "GB",
    "name": "Diggle",
    "lat": "53.56744",
    "lng": "-1.99723"
  },
  {
    "country": "GB",
    "name": "Didcot",
    "lat": "51.60928",
    "lng": "-1.24214"
  },
  {
    "country": "GB",
    "name": "Dickleburgh",
    "lat": "52.3965",
    "lng": "1.18498"
  },
  {
    "country": "GB",
    "name": "Dewsbury",
    "lat": "53.69076",
    "lng": "-1.62907"
  },
  {
    "country": "GB",
    "name": "Devizes",
    "lat": "51.35084",
    "lng": "-1.99421"
  },
  {
    "country": "GB",
    "name": "Desford",
    "lat": "52.62598",
    "lng": "-1.29395"
  },
  {
    "country": "GB",
    "name": "Desborough",
    "lat": "52.44183",
    "lng": "-0.82126"
  },
  {
    "country": "GB",
    "name": "Derwen",
    "lat": "53.03333",
    "lng": "-3.4"
  },
  {
    "country": "GB",
    "name": "Dersingham",
    "lat": "52.84549",
    "lng": "0.50339"
  },
  {
    "country": "GB",
    "name": "Deri",
    "lat": "51.70812",
    "lng": "-3.26312"
  },
  {
    "country": "GB",
    "name": "Derby",
    "lat": "52.92277",
    "lng": "-1.47663"
  },
  {
    "country": "GB",
    "name": "Denton",
    "lat": "54.56667",
    "lng": "-1.66667"
  },
  {
    "country": "GB",
    "name": "Denton",
    "lat": "53.45678",
    "lng": "-2.11822"
  },
  {
    "country": "GB",
    "name": "Denny",
    "lat": "56.0235",
    "lng": "-3.90812"
  },
  {
    "country": "GB",
    "name": "Denholme",
    "lat": "53.80189",
    "lng": "-1.89503"
  },
  {
    "country": "GB",
    "name": "Denham",
    "lat": "51.56667",
    "lng": "-0.5"
  },
  {
    "country": "GB",
    "name": "Denby Dale",
    "lat": "53.57228",
    "lng": "-1.65895"
  },
  {
    "country": "GB",
    "name": "Denbigh",
    "lat": "53.18333",
    "lng": "-3.41667"
  },
  {
    "country": "GB",
    "name": "Delph",
    "lat": "53.56667",
    "lng": "-2.01667"
  },
  {
    "country": "GB",
    "name": "Delabole",
    "lat": "50.62347",
    "lng": "-4.7319"
  },
  {
    "country": "GB",
    "name": "Deighton",
    "lat": "53.9",
    "lng": "-1.05"
  },
  {
    "country": "GB",
    "name": "Deganwy",
    "lat": "53.30446",
    "lng": "-3.82735"
  },
  {
    "country": "GB",
    "name": "Dedham",
    "lat": "51.95892",
    "lng": "0.99336"
  },
  {
    "country": "GB",
    "name": "Deddington",
    "lat": "51.9806",
    "lng": "-1.32055"
  },
  {
    "country": "GB",
    "name": "Debenham",
    "lat": "52.22422",
    "lng": "1.18172"
  },
  {
    "country": "GB",
    "name": "Dearham",
    "lat": "54.71175",
    "lng": "-3.44364"
  },
  {
    "country": "GB",
    "name": "Deanshanger",
    "lat": "52.04996",
    "lng": "-0.88663"
  },
  {
    "country": "GB",
    "name": "Deal",
    "lat": "51.22322",
    "lng": "1.40432"
  },
  {
    "country": "GB",
    "name": "Dawlish",
    "lat": "50.58118",
    "lng": "-3.46644"
  },
  {
    "country": "GB",
    "name": "Daventry",
    "lat": "52.25688",
    "lng": "-1.16066"
  },
  {
    "country": "GB",
    "name": "Datchworth",
    "lat": "51.85126",
    "lng": "-0.15956"
  },
  {
    "country": "GB",
    "name": "Datchet",
    "lat": "51.4839",
    "lng": "-0.57893"
  },
  {
    "country": "GB",
    "name": "Darwen",
    "lat": "53.69803",
    "lng": "-2.46494"
  },
  {
    "country": "GB",
    "name": "Darvel",
    "lat": "55.60976",
    "lng": "-4.28142"
  },
  {
    "country": "GB",
    "name": "Darton",
    "lat": "53.58705",
    "lng": "-1.52676"
  },
  {
    "country": "GB",
    "name": "Dartmouth",
    "lat": "50.3522",
    "lng": "-3.5794"
  },
  {
    "country": "GB",
    "name": "Dartford",
    "lat": "51.44657",
    "lng": "0.21423"
  },
  {
    "country": "GB",
    "name": "Darrington",
    "lat": "53.67566",
    "lng": "-1.26901"
  },
  {
    "country": "GB",
    "name": "Darlington",
    "lat": "54.52429",
    "lng": "-1.55039"
  },
  {
    "country": "GB",
    "name": "Darlaston",
    "lat": "52.56667",
    "lng": "-2.03333"
  },
  {
    "country": "GB",
    "name": "Darfield",
    "lat": "53.5339",
    "lng": "-1.37595"
  },
  {
    "country": "GB",
    "name": "Daresbury",
    "lat": "53.34184",
    "lng": "-2.635"
  },
  {
    "country": "GB",
    "name": "Darenth",
    "lat": "51.42137",
    "lng": "0.25784"
  },
  {
    "country": "GB",
    "name": "Danbury",
    "lat": "51.71645",
    "lng": "0.58245"
  },
  {
    "country": "GB",
    "name": "Dalton in Furness",
    "lat": "54.15796",
    "lng": "-3.17977"
  },
  {
    "country": "GB",
    "name": "Dalston",
    "lat": "54.84207",
    "lng": "-2.98459"
  },
  {
    "country": "GB",
    "name": "Dalserf",
    "lat": "55.73333",
    "lng": "-3.91667"
  },
  {
    "country": "GB",
    "name": "Dalrymple",
    "lat": "55.39757",
    "lng": "-4.59169"
  },
  {
    "country": "GB",
    "name": "Dalry",
    "lat": "55.70956",
    "lng": "-4.72167"
  },
  {
    "country": "GB",
    "name": "Dalmellington",
    "lat": "55.32419",
    "lng": "-4.402"
  },
  {
    "country": "GB",
    "name": "Dalkeith",
    "lat": "55.89317",
    "lng": "-3.06806"
  },
  {
    "country": "GB",
    "name": "Dale",
    "lat": "51.70917",
    "lng": "-5.17333"
  },
  {
    "country": "GB",
    "name": "Dalbeattie",
    "lat": "54.93278",
    "lng": "-3.82271"
  },
  {
    "country": "GB",
    "name": "Dagenham",
    "lat": "51.55",
    "lng": "0.16667"
  },
  {
    "country": "GB",
    "name": "Cwmbran",
    "lat": "51.65446",
    "lng": "-3.02281"
  },
  {
    "country": "GB",
    "name": "Cwmafan",
    "lat": "51.61671",
    "lng": "-3.76205"
  },
  {
    "country": "GB",
    "name": "Cwm",
    "lat": "53.28333",
    "lng": "-3.4"
  },
  {
    "country": "GB",
    "name": "Cwm",
    "lat": "51.74",
    "lng": "-3.18028"
  },
  {
    "country": "GB",
    "name": "Cuxton",
    "lat": "51.3743",
    "lng": "0.45688"
  },
  {
    "country": "GB",
    "name": "Cushendall",
    "lat": "55.08033",
    "lng": "-6.06291"
  },
  {
    "country": "GB",
    "name": "Curry Rivel",
    "lat": "51.02306",
    "lng": "-2.86753"
  },
  {
    "country": "GB",
    "name": "Currie",
    "lat": "55.8964",
    "lng": "-3.30845"
  },
  {
    "country": "GB",
    "name": "Cupar",
    "lat": "56.31876",
    "lng": "-3.01204"
  },
  {
    "country": "GB",
    "name": "Cumnock",
    "lat": "55.45445",
    "lng": "-4.26644"
  },
  {
    "country": "GB",
    "name": "Cumbernauld",
    "lat": "55.94685",
    "lng": "-3.99051"
  },
  {
    "country": "GB",
    "name": "Cults",
    "lat": "57.11667",
    "lng": "-2.16667"
  },
  {
    "country": "GB",
    "name": "Culmore",
    "lat": "55.05",
    "lng": "-7.26667"
  },
  {
    "country": "GB",
    "name": "Cullybackey",
    "lat": "54.88875",
    "lng": "-6.34701"
  },
  {
    "country": "GB",
    "name": "Cullompton",
    "lat": "50.8553",
    "lng": "-3.39268"
  },
  {
    "country": "GB",
    "name": "Cullingworth",
    "lat": "53.82444",
    "lng": "-1.8973"
  },
  {
    "country": "GB",
    "name": "Cullen",
    "lat": "57.69045",
    "lng": "-2.81818"
  },
  {
    "country": "GB",
    "name": "Culcheth",
    "lat": "53.4511",
    "lng": "-2.52104"
  },
  {
    "country": "GB",
    "name": "Cuffley",
    "lat": "51.70799",
    "lng": "-0.11209"
  },
  {
    "country": "GB",
    "name": "Cudworth",
    "lat": "53.57131",
    "lng": "-1.41595"
  },
  {
    "country": "GB",
    "name": "Cuddington",
    "lat": "53.24488",
    "lng": "-2.61879"
  },
  {
    "country": "GB",
    "name": "Cuckfield",
    "lat": "51.01073",
    "lng": "-0.14068"
  },
  {
    "country": "GB",
    "name": "Crynant",
    "lat": "51.72889",
    "lng": "-3.74806"
  },
  {
    "country": "GB",
    "name": "Crymych",
    "lat": "51.97361",
    "lng": "-4.64722"
  },
  {
    "country": "GB",
    "name": "Crumlin",
    "lat": "54.62054",
    "lng": "-6.21414"
  },
  {
    "country": "GB",
    "name": "Crumlin",
    "lat": "51.67778",
    "lng": "-3.13528"
  },
  {
    "country": "GB",
    "name": "Croydon",
    "lat": "51.38333",
    "lng": "-0.1"
  },
  {
    "country": "GB",
    "name": "Croxton",
    "lat": "53.5964",
    "lng": "-0.3483"
  },
  {
    "country": "GB",
    "name": "Crowthorne",
    "lat": "51.37027",
    "lng": "-0.79219"
  },
  {
    "country": "GB",
    "name": "Crowle",
    "lat": "53.60753",
    "lng": "-0.83256"
  },
  {
    "country": "GB",
    "name": "Crowland",
    "lat": "52.67571",
    "lng": "-0.16849"
  },
  {
    "country": "GB",
    "name": "Crowborough",
    "lat": "51.06098",
    "lng": "0.16342"
  },
  {
    "country": "GB",
    "name": "Croston",
    "lat": "53.66217",
    "lng": "-2.77523"
  },
  {
    "country": "GB",
    "name": "Crossmaglen",
    "lat": "54.08333",
    "lng": "-6.6"
  },
  {
    "country": "GB",
    "name": "Crosskeys",
    "lat": "51.61917",
    "lng": "-3.12361"
  },
  {
    "country": "GB",
    "name": "Crosshouse",
    "lat": "55.61258",
    "lng": "-4.55091"
  },
  {
    "country": "GB",
    "name": "Cross Hands",
    "lat": "51.79306",
    "lng": "-4.0875"
  },
  {
    "country": "GB",
    "name": "Crossgates",
    "lat": "56.08366",
    "lng": "-3.37712"
  },
  {
    "country": "GB",
    "name": "Crossgar",
    "lat": "54.39675",
    "lng": "-5.76061"
  },
  {
    "country": "GB",
    "name": "Crossford",
    "lat": "56.06303",
    "lng": "-3.49674"
  },
  {
    "country": "GB",
    "name": "Cropwell Bishop",
    "lat": "52.9148",
    "lng": "-0.98482"
  },
  {
    "country": "GB",
    "name": "Crook",
    "lat": "54.71252",
    "lng": "-1.7497"
  },
  {
    "country": "GB",
    "name": "Crondall",
    "lat": "51.23285",
    "lng": "-0.86329"
  },
  {
    "country": "GB",
    "name": "Cromford",
    "lat": "53.10848",
    "lng": "-1.56014"
  },
  {
    "country": "GB",
    "name": "Cromer",
    "lat": "52.93123",
    "lng": "1.29892"
  },
  {
    "country": "GB",
    "name": "Crofton",
    "lat": "53.65639",
    "lng": "-1.42968"
  },
  {
    "country": "GB",
    "name": "Croft",
    "lat": "53.43333",
    "lng": "-2.55"
  },
  {
    "country": "GB",
    "name": "Croft",
    "lat": "52.55668",
    "lng": "-1.24643"
  },
  {
    "country": "GB",
    "name": "Cringleford",
    "lat": "52.60482",
    "lng": "1.24334"
  },
  {
    "country": "GB",
    "name": "Crigglestone",
    "lat": "53.6424",
    "lng": "-1.52916"
  },
  {
    "country": "GB",
    "name": "Crieff",
    "lat": "56.37268",
    "lng": "-3.83891"
  },
  {
    "country": "GB",
    "name": "Cricklade",
    "lat": "51.64061",
    "lng": "-1.85738"
  },
  {
    "country": "GB",
    "name": "Crickhowell",
    "lat": "51.85992",
    "lng": "-3.13771"
  },
  {
    "country": "GB",
    "name": "Crick",
    "lat": "52.34808",
    "lng": "-1.13708"
  },
  {
    "country": "GB",
    "name": "Criccieth",
    "lat": "52.92053",
    "lng": "-4.2346"
  },
  {
    "country": "GB",
    "name": "Crewkerne",
    "lat": "50.88298",
    "lng": "-2.79588"
  },
  {
    "country": "GB",
    "name": "Crewe",
    "lat": "53.09787",
    "lng": "-2.44161"
  },
  {
    "country": "GB",
    "name": "Creswell",
    "lat": "53.26287",
    "lng": "-1.21987"
  },
  {
    "country": "GB",
    "name": "Cresswell",
    "lat": "55.21667",
    "lng": "-1.55"
  },
  {
    "country": "GB",
    "name": "Creech Saint Michael",
    "lat": "51.02333",
    "lng": "-3.03833"
  },
  {
    "country": "GB",
    "name": "Crediton",
    "lat": "50.78333",
    "lng": "-3.65"
  },
  {
    "country": "GB",
    "name": "Credenhill",
    "lat": "52.08351",
    "lng": "-2.80804"
  },
  {
    "country": "GB",
    "name": "Cray",
    "lat": "51.9",
    "lng": "-3.61667"
  },
  {
    "country": "GB",
    "name": "Crawley",
    "lat": "51.11303",
    "lng": "-0.18312"
  },
  {
    "country": "GB",
    "name": "Craven Arms",
    "lat": "52.44308",
    "lng": "-2.83562"
  },
  {
    "country": "GB",
    "name": "Cranwell",
    "lat": "53.03681",
    "lng": "-0.46176"
  },
  {
    "country": "GB",
    "name": "Cranleigh",
    "lat": "51.14209",
    "lng": "-0.48374"
  },
  {
    "country": "GB",
    "name": "Cranfield",
    "lat": "52.06869",
    "lng": "-0.60884"
  },
  {
    "country": "GB",
    "name": "Cranbrook",
    "lat": "51.09662",
    "lng": "0.53567"
  },
  {
    "country": "GB",
    "name": "Cramlington",
    "lat": "55.08652",
    "lng": "-1.58598"
  },
  {
    "country": "GB",
    "name": "Crail",
    "lat": "56.26042",
    "lng": "-2.62676"
  },
  {
    "country": "GB",
    "name": "Coylton",
    "lat": "55.44528",
    "lng": "-4.5195"
  },
  {
    "country": "GB",
    "name": "Coxhoe",
    "lat": "54.71475",
    "lng": "-1.50356"
  },
  {
    "country": "GB",
    "name": "Cowley",
    "lat": "51.73213",
    "lng": "-1.20631"
  },
  {
    "country": "GB",
    "name": "Cowie",
    "lat": "56.07974",
    "lng": "-3.86753"
  },
  {
    "country": "GB",
    "name": "Cowfold",
    "lat": "50.98945",
    "lng": "-0.27243"
  },
  {
    "country": "GB",
    "name": "Cowes",
    "lat": "50.76306",
    "lng": "-1.29772"
  },
  {
    "country": "GB",
    "name": "Cowdenbeath",
    "lat": "56.11194",
    "lng": "-3.34426"
  },
  {
    "country": "GB",
    "name": "Cowbridge",
    "lat": "51.46028",
    "lng": "-3.44167"
  },
  {
    "country": "GB",
    "name": "Cowbit",
    "lat": "52.74523",
    "lng": "-0.12978"
  },
  {
    "country": "GB",
    "name": "Coventry",
    "lat": "52.40656",
    "lng": "-1.51217"
  },
  {
    "country": "GB",
    "name": "Cove",
    "lat": "57.1",
    "lng": "-2.08333"
  },
  {
    "country": "GB",
    "name": "Coupar Angus",
    "lat": "56.54552",
    "lng": "-3.26774"
  },
  {
    "country": "GB",
    "name": "Countesthorpe",
    "lat": "52.55379",
    "lng": "-1.14526"
  },
  {
    "country": "GB",
    "name": "Coundon",
    "lat": "54.6628",
    "lng": "-1.62688"
  },
  {
    "country": "GB",
    "name": "Coulsdon",
    "lat": "51.32002",
    "lng": "-0.14088"
  },
  {
    "country": "GB",
    "name": "Cottingham",
    "lat": "53.78057",
    "lng": "-0.41542"
  },
  {
    "country": "GB",
    "name": "Cottingham",
    "lat": "52.50243",
    "lng": "-0.7554"
  },
  {
    "country": "GB",
    "name": "Cottesmore",
    "lat": "52.71384",
    "lng": "-0.6633"
  },
  {
    "country": "GB",
    "name": "Cottenham",
    "lat": "52.28743",
    "lng": "0.1254"
  },
  {
    "country": "GB",
    "name": "Cotgrave",
    "lat": "52.90859",
    "lng": "-1.03752"
  },
  {
    "country": "GB",
    "name": "Costessey",
    "lat": "52.65914",
    "lng": "1.2097"
  },
  {
    "country": "GB",
    "name": "Cosham",
    "lat": "50.84654",
    "lng": "-1.06344"
  },
  {
    "country": "GB",
    "name": "Cosby",
    "lat": "52.55127",
    "lng": "-1.19395"
  },
  {
    "country": "GB",
    "name": "Corston",
    "lat": "51.385",
    "lng": "-2.44028"
  },
  {
    "country": "GB",
    "name": "Corsley",
    "lat": "51.21933",
    "lng": "-2.2464"
  },
  {
    "country": "GB",
    "name": "Corsham",
    "lat": "51.43433",
    "lng": "-2.18437"
  },
  {
    "country": "GB",
    "name": "Corsenside",
    "lat": "55.18333",
    "lng": "-2.16667"
  },
  {
    "country": "GB",
    "name": "Corse",
    "lat": "51.95943",
    "lng": "-2.30636"
  },
  {
    "country": "GB",
    "name": "Corris",
    "lat": "52.65145",
    "lng": "-3.84315"
  },
  {
    "country": "GB",
    "name": "Cornholme",
    "lat": "53.7323",
    "lng": "-2.13851"
  },
  {
    "country": "GB",
    "name": "Corfe Castle",
    "lat": "50.63947",
    "lng": "-2.05672"
  },
  {
    "country": "GB",
    "name": "Corby",
    "lat": "52.49637",
    "lng": "-0.68939"
  },
  {
    "country": "GB",
    "name": "Corbridge",
    "lat": "54.97365",
    "lng": "-2.01798"
  },
  {
    "country": "GB",
    "name": "Coppull",
    "lat": "53.62527",
    "lng": "-2.65854"
  },
  {
    "country": "GB",
    "name": "Copplestone",
    "lat": "50.81073",
    "lng": "-3.74607"
  },
  {
    "country": "GB",
    "name": "Copmanthorpe",
    "lat": "53.91419",
    "lng": "-1.14209"
  },
  {
    "country": "GB",
    "name": "Cople",
    "lat": "52.12342",
    "lng": "-0.38933"
  },
  {
    "country": "GB",
    "name": "Cooling",
    "lat": "51.45474",
    "lng": "0.52395"
  },
  {
    "country": "GB",
    "name": "Cookstown",
    "lat": "54.64305",
    "lng": "-6.74595"
  },
  {
    "country": "GB",
    "name": "Cookley",
    "lat": "52.31667",
    "lng": "1.45"
  },
  {
    "country": "GB",
    "name": "Cookham",
    "lat": "51.55936",
    "lng": "-0.7081"
  },
  {
    "country": "GB",
    "name": "Conwy",
    "lat": "53.28077",
    "lng": "-3.83039"
  },
  {
    "country": "GB",
    "name": "Consett",
    "lat": "54.85404",
    "lng": "-1.8316"
  },
  {
    "country": "GB",
    "name": "Conon Bridge",
    "lat": "57.5663",
    "lng": "-4.43678"
  },
  {
    "country": "GB",
    "name": "Connor",
    "lat": "54.8",
    "lng": "-6.2"
  },
  {
    "country": "GB",
    "name": "Conisbrough",
    "lat": "53.48188",
    "lng": "-1.23214"
  },
  {
    "country": "GB",
    "name": "Coningsby",
    "lat": "53.10598",
    "lng": "-0.17595"
  },
  {
    "country": "GB",
    "name": "Congresbury",
    "lat": "51.37135",
    "lng": "-2.81018"
  },
  {
    "country": "GB",
    "name": "Congleton",
    "lat": "53.16314",
    "lng": "-2.21253"
  },
  {
    "country": "GB",
    "name": "Comrie",
    "lat": "56.3688",
    "lng": "-3.97882"
  },
  {
    "country": "GB",
    "name": "Compton Martin",
    "lat": "51.31056",
    "lng": "-2.65528"
  },
  {
    "country": "GB",
    "name": "Compton Dando",
    "lat": "51.37909",
    "lng": "-2.51445"
  },
  {
    "country": "GB",
    "name": "Compton",
    "lat": "51.51585",
    "lng": "-1.2551"
  },
  {
    "country": "GB",
    "name": "Compton",
    "lat": "51.02385",
    "lng": "-1.33713"
  },
  {
    "country": "GB",
    "name": "Comberton",
    "lat": "52.18709",
    "lng": "0.01905"
  },
  {
    "country": "GB",
    "name": "Comber",
    "lat": "54.54937",
    "lng": "-5.74379"
  },
  {
    "country": "GB",
    "name": "Combe Martin",
    "lat": "51.19873",
    "lng": "-4.02343"
  },
  {
    "country": "GB",
    "name": "Colyton",
    "lat": "50.74006",
    "lng": "-3.07021"
  },
  {
    "country": "GB",
    "name": "Colwyn Bay",
    "lat": "53.29483",
    "lng": "-3.72674"
  },
  {
    "country": "GB",
    "name": "Colwich",
    "lat": "52.78764",
    "lng": "-1.98206"
  },
  {
    "country": "GB",
    "name": "Coltishall",
    "lat": "52.72804",
    "lng": "1.36653"
  },
  {
    "country": "GB",
    "name": "Colsterworth",
    "lat": "52.8066",
    "lng": "-0.62056"
  },
  {
    "country": "GB",
    "name": "Colne",
    "lat": "53.85713",
    "lng": "-2.16851"
  },
  {
    "country": "GB",
    "name": "Colnbrook",
    "lat": "51.48384",
    "lng": "-0.52142"
  },
  {
    "country": "GB",
    "name": "Colmworth",
    "lat": "52.21681",
    "lng": "-0.37826"
  },
  {
    "country": "GB",
    "name": "Collington",
    "lat": "52.25",
    "lng": "-2.51667"
  },
  {
    "country": "GB",
    "name": "Collingham",
    "lat": "53.91167",
    "lng": "-1.41174"
  },
  {
    "country": "GB",
    "name": "Collingbourne Kingston",
    "lat": "51.30105",
    "lng": "-1.65876"
  },
  {
    "country": "GB",
    "name": "Colinton",
    "lat": "55.90739",
    "lng": "-3.25609"
  },
  {
    "country": "GB",
    "name": "Colerne",
    "lat": "51.43833",
    "lng": "-2.2628"
  },
  {
    "country": "GB",
    "name": "Coleraine",
    "lat": "55.13333",
    "lng": "-6.66667"
  },
  {
    "country": "GB",
    "name": "Coleford",
    "lat": "51.79535",
    "lng": "-2.61354"
  },
  {
    "country": "GB",
    "name": "Coldstream",
    "lat": "55.65111",
    "lng": "-2.25295"
  },
  {
    "country": "GB",
    "name": "Cold Norton",
    "lat": "51.67209",
    "lng": "0.66997"
  },
  {
    "country": "GB",
    "name": "Cold Ashton",
    "lat": "51.45083",
    "lng": "-2.36139"
  },
  {
    "country": "GB",
    "name": "Cold Ash",
    "lat": "51.42426",
    "lng": "-1.26463"
  },
  {
    "country": "GB",
    "name": "Colchester",
    "lat": "51.88921",
    "lng": "0.90421"
  },
  {
    "country": "GB",
    "name": "Coity",
    "lat": "51.522",
    "lng": "-3.55531"
  },
  {
    "country": "GB",
    "name": "Coggeshall",
    "lat": "51.87077",
    "lng": "0.68536"
  },
  {
    "country": "GB",
    "name": "Cogenhoe",
    "lat": "52.23758",
    "lng": "-0.78381"
  },
  {
    "country": "GB",
    "name": "Coedpoeth",
    "lat": "53.05391",
    "lng": "-3.06234"
  },
  {
    "country": "GB",
    "name": "Codsall",
    "lat": "52.62989",
    "lng": "-2.20148"
  },
  {
    "country": "GB",
    "name": "Codicote",
    "lat": "51.85052",
    "lng": "-0.2367"
  },
  {
    "country": "GB",
    "name": "Codford",
    "lat": "51.15",
    "lng": "-2.05"
  },
  {
    "country": "GB",
    "name": "Coddington",
    "lat": "53.08333",
    "lng": "-2.81667"
  },
  {
    "country": "GB",
    "name": "Cockfield",
    "lat": "54.61373",
    "lng": "-1.80897"
  },
  {
    "country": "GB",
    "name": "Cockermouth",
    "lat": "54.66209",
    "lng": "-3.36086"
  },
  {
    "country": "GB",
    "name": "Cockenzie",
    "lat": "55.96823",
    "lng": "-2.96562"
  },
  {
    "country": "GB",
    "name": "Cobham",
    "lat": "51.32997",
    "lng": "-0.4113"
  },
  {
    "country": "GB",
    "name": "Coates",
    "lat": "51.7075",
    "lng": "-2.03389"
  },
  {
    "country": "GB",
    "name": "Coatbridge",
    "lat": "55.86216",
    "lng": "-4.02469"
  },
  {
    "country": "GB",
    "name": "Coalville",
    "lat": "52.72247",
    "lng": "-1.3702"
  },
  {
    "country": "GB",
    "name": "Coalisland",
    "lat": "54.5418",
    "lng": "-6.70166"
  },
  {
    "country": "GB",
    "name": "Coalburn",
    "lat": "55.59295",
    "lng": "-3.88637"
  },
  {
    "country": "GB",
    "name": "Clydebank",
    "lat": "55.90137",
    "lng": "-4.4057"
  },
  {
    "country": "GB",
    "name": "Clydach",
    "lat": "51.68333",
    "lng": "-3.9"
  },
  {
    "country": "GB",
    "name": "Clutton",
    "lat": "51.32944",
    "lng": "-2.54306"
  },
  {
    "country": "GB",
    "name": "Clowne",
    "lat": "53.27449",
    "lng": "-1.26406"
  },
  {
    "country": "GB",
    "name": "Clophill",
    "lat": "52.02727",
    "lng": "-0.42377"
  },
  {
    "country": "GB",
    "name": "Clive",
    "lat": "52.81335",
    "lng": "-2.72295"
  },
  {
    "country": "GB",
    "name": "Clitheroe",
    "lat": "53.86667",
    "lng": "-2.4"
  },
  {
    "country": "GB",
    "name": "Clipsham",
    "lat": "52.73608",
    "lng": "-0.56545"
  },
  {
    "country": "GB",
    "name": "Clifton",
    "lat": "52.0399",
    "lng": "-0.30051"
  },
  {
    "country": "GB",
    "name": "Clifford",
    "lat": "52.1",
    "lng": "-3.1"
  },
  {
    "country": "GB",
    "name": "Cliffe",
    "lat": "51.46224",
    "lng": "0.49833"
  },
  {
    "country": "GB",
    "name": "Cleveleys",
    "lat": "53.8775",
    "lng": "-3.03987"
  },
  {
    "country": "GB",
    "name": "Clevedon",
    "lat": "51.44227",
    "lng": "-2.85786"
  },
  {
    "country": "GB",
    "name": "Cleobury Mortimer",
    "lat": "52.37853",
    "lng": "-2.48196"
  },
  {
    "country": "GB",
    "name": "Clenchwarton",
    "lat": "52.75604",
    "lng": "0.3579"
  },
  {
    "country": "GB",
    "name": "Cleland",
    "lat": "55.80243",
    "lng": "-3.9142"
  },
  {
    "country": "GB",
    "name": "Cleethorpes",
    "lat": "53.56047",
    "lng": "-0.03225"
  },
  {
    "country": "GB",
    "name": "Cleckheaton",
    "lat": "53.72405",
    "lng": "-1.71294"
  },
  {
    "country": "GB",
    "name": "Cleator Moor",
    "lat": "54.52143",
    "lng": "-3.5159"
  },
  {
    "country": "GB",
    "name": "Clayton West",
    "lat": "53.59501",
    "lng": "-1.61107"
  },
  {
    "country": "GB",
    "name": "Clayton le Moors",
    "lat": "53.76667",
    "lng": "-2.38333"
  },
  {
    "country": "GB",
    "name": "Clayton",
    "lat": "53.76667",
    "lng": "-1.81667"
  },
  {
    "country": "GB",
    "name": "Claypole",
    "lat": "53.03144",
    "lng": "-0.73407"
  },
  {
    "country": "GB",
    "name": "Claydon",
    "lat": "52.14813",
    "lng": "-1.33295"
  },
  {
    "country": "GB",
    "name": "Claydon",
    "lat": "52.10672",
    "lng": "1.11134"
  },
  {
    "country": "GB",
    "name": "Clare",
    "lat": "52.07861",
    "lng": "0.58167"
  },
  {
    "country": "GB",
    "name": "Clarborough",
    "lat": "53.34549",
    "lng": "-0.90382"
  },
  {
    "country": "GB",
    "name": "Clapham",
    "lat": "52.16085",
    "lng": "-0.49529"
  },
  {
    "country": "GB",
    "name": "Clacton-on-Sea",
    "lat": "51.78967",
    "lng": "1.15597"
  },
  {
    "country": "GB",
    "name": "Clackmannan",
    "lat": "56.10743",
    "lng": "-3.75098"
  },
  {
    "country": "GB",
    "name": "Cirencester",
    "lat": "51.71927",
    "lng": "-1.97145"
  },
  {
    "country": "GB",
    "name": "Cinderford",
    "lat": "51.82421",
    "lng": "-2.4987"
  },
  {
    "country": "GB",
    "name": "Church Stretton",
    "lat": "52.53778",
    "lng": "-2.80149"
  },
  {
    "country": "GB",
    "name": "Churchill",
    "lat": "51.34291",
    "lng": "-2.78338"
  },
  {
    "country": "GB",
    "name": "Honeybourne",
    "lat": "52.09513",
    "lng": "-1.83129"
  },
  {
    "country": "GB",
    "name": "Church Fenton",
    "lat": "53.82626",
    "lng": "-1.2189"
  },
  {
    "country": "GB",
    "name": "Churchdown",
    "lat": "51.87739",
    "lng": "-2.17087"
  },
  {
    "country": "GB",
    "name": "Church",
    "lat": "53.75177",
    "lng": "-2.39121"
  },
  {
    "country": "GB",
    "name": "Chulmleigh",
    "lat": "50.91289",
    "lng": "-3.86938"
  },
  {
    "country": "GB",
    "name": "Chudleigh Knighton",
    "lat": "50.58507",
    "lng": "-3.63187"
  },
  {
    "country": "GB",
    "name": "Chudleigh",
    "lat": "50.60496",
    "lng": "-3.60031"
  },
  {
    "country": "GB",
    "name": "Chryston",
    "lat": "55.9028",
    "lng": "-4.10759"
  },
  {
    "country": "GB",
    "name": "Christchurch",
    "lat": "50.73583",
    "lng": "-1.78129"
  },
  {
    "country": "GB",
    "name": "Chorleywood",
    "lat": "51.65472",
    "lng": "-0.51404"
  },
  {
    "country": "GB",
    "name": "Chorley",
    "lat": "53.65",
    "lng": "-2.61667"
  },
  {
    "country": "GB",
    "name": "Choppington",
    "lat": "55.15004",
    "lng": "-1.60332"
  },
  {
    "country": "GB",
    "name": "Cholsey",
    "lat": "51.5728",
    "lng": "-1.15356"
  },
  {
    "country": "GB",
    "name": "Chobham",
    "lat": "51.34836",
    "lng": "-0.60639"
  },
  {
    "country": "GB",
    "name": "Chislehurst",
    "lat": "51.41709",
    "lng": "0.06858"
  },
  {
    "country": "GB",
    "name": "Chirnside",
    "lat": "55.80215",
    "lng": "-2.20927"
  },
  {
    "country": "GB",
    "name": "Chirk",
    "lat": "52.93586",
    "lng": "-3.05738"
  },
  {
    "country": "GB",
    "name": "Chipping Sodbury",
    "lat": "51.53813",
    "lng": "-2.39379"
  },
  {
    "country": "GB",
    "name": "Chipping Ongar",
    "lat": "51.70379",
    "lng": "0.24548"
  },
  {
    "country": "GB",
    "name": "Chipping Norton",
    "lat": "51.94109",
    "lng": "-1.5453"
  },
  {
    "country": "GB",
    "name": "Chipping Campden",
    "lat": "52.04964",
    "lng": "-1.7767"
  },
  {
    "country": "GB",
    "name": "Chippenham",
    "lat": "51.46",
    "lng": "-2.12472"
  },
  {
    "country": "GB",
    "name": "Chinnor",
    "lat": "51.70177",
    "lng": "-0.91161"
  },
  {
    "country": "GB",
    "name": "Chinley",
    "lat": "53.34025",
    "lng": "-1.939"
  },
  {
    "country": "GB",
    "name": "Chilworth",
    "lat": "51.21635",
    "lng": "-0.53129"
  },
  {
    "country": "GB",
    "name": "Chilton Foliat",
    "lat": "51.43245",
    "lng": "-1.53912"
  },
  {
    "country": "GB",
    "name": "Child Okeford",
    "lat": "50.9137",
    "lng": "-2.23679"
  },
  {
    "country": "GB",
    "name": "Chilcompton",
    "lat": "51.26391",
    "lng": "-2.50502"
  },
  {
    "country": "GB",
    "name": "Chigwell",
    "lat": "51.61999",
    "lng": "0.07596"
  },
  {
    "country": "GB",
    "name": "Chiddingfold",
    "lat": "51.11866",
    "lng": "-0.62262"
  },
  {
    "country": "GB",
    "name": "Chicksands",
    "lat": "52.04585",
    "lng": "-0.3639"
  },
  {
    "country": "GB",
    "name": "Chicklade",
    "lat": "51.10917",
    "lng": "-2.12667"
  },
  {
    "country": "GB",
    "name": "Chickerell",
    "lat": "50.62429",
    "lng": "-2.5028"
  },
  {
    "country": "GB",
    "name": "Chichester",
    "lat": "50.83673",
    "lng": "-0.78003"
  },
  {
    "country": "GB",
    "name": "Chicheley",
    "lat": "52.10303",
    "lng": "-0.68647"
  },
  {
    "country": "GB",
    "name": "Chew Magna",
    "lat": "51.36611",
    "lng": "-2.61028"
  },
  {
    "country": "GB",
    "name": "Chetwynd",
    "lat": "52.78333",
    "lng": "-2.4"
  },
  {
    "country": "GB",
    "name": "Chester-le-Street",
    "lat": "54.85862",
    "lng": "-1.57408"
  },
  {
    "country": "GB",
    "name": "Chesterfield",
    "lat": "53.25",
    "lng": "-1.41667"
  },
  {
    "country": "GB",
    "name": "Chester",
    "lat": "53.1905",
    "lng": "-2.89189"
  },
  {
    "country": "GB",
    "name": "Chessington",
    "lat": "51.3624",
    "lng": "-0.30427"
  },
  {
    "country": "GB",
    "name": "Cheshunt",
    "lat": "51.7002",
    "lng": "-0.03026"
  },
  {
    "country": "GB",
    "name": "Chesham",
    "lat": "51.7",
    "lng": "-0.6"
  },
  {
    "country": "GB",
    "name": "Chertsey",
    "lat": "51.38812",
    "lng": "-0.50782"
  },
  {
    "country": "GB",
    "name": "Cherry Burton",
    "lat": "53.86667",
    "lng": "-0.5"
  },
  {
    "country": "GB",
    "name": "Chepstow",
    "lat": "51.64087",
    "lng": "-2.67683"
  },
  {
    "country": "GB",
    "name": "Cheltenham",
    "lat": "51.90006",
    "lng": "-2.07972"
  },
  {
    "country": "GB",
    "name": "Chelsea",
    "lat": "51.48755",
    "lng": "-0.16936"
  },
  {
    "country": "GB",
    "name": "Chelmsford",
    "lat": "51.73575",
    "lng": "0.46958"
  },
  {
    "country": "GB",
    "name": "Chelford",
    "lat": "53.2709",
    "lng": "-2.28329"
  },
  {
    "country": "GB",
    "name": "Cheddleton",
    "lat": "53.0691",
    "lng": "-2.04228"
  },
  {
    "country": "GB",
    "name": "Cheddington",
    "lat": "51.84784",
    "lng": "-0.66429"
  },
  {
    "country": "GB",
    "name": "Cheddar",
    "lat": "51.27537",
    "lng": "-2.77662"
  },
  {
    "country": "GB",
    "name": "Cheam",
    "lat": "51.36179",
    "lng": "-0.21977"
  },
  {
    "country": "GB",
    "name": "Cheadle Hulme",
    "lat": "53.3761",
    "lng": "-2.1897"
  },
  {
    "country": "GB",
    "name": "Cheadle",
    "lat": "52.98333",
    "lng": "-1.98333"
  },
  {
    "country": "GB",
    "name": "Chatteris",
    "lat": "52.45624",
    "lng": "0.05236"
  },
  {
    "country": "GB",
    "name": "Chatham",
    "lat": "51.37891",
    "lng": "0.52786"
  },
  {
    "country": "GB",
    "name": "Chatburn",
    "lat": "53.89228",
    "lng": "-2.35495"
  },
  {
    "country": "GB",
    "name": "Chasetown",
    "lat": "52.67232",
    "lng": "-1.92535"
  },
  {
    "country": "GB",
    "name": "Chartham",
    "lat": "51.2562",
    "lng": "1.01836"
  },
  {
    "country": "GB",
    "name": "Charmouth",
    "lat": "50.73889",
    "lng": "-2.90055"
  },
  {
    "country": "GB",
    "name": "Charminster",
    "lat": "50.73333",
    "lng": "-2.45"
  },
  {
    "country": "GB",
    "name": "Charlton Marshall",
    "lat": "50.83591",
    "lng": "-2.14231"
  },
  {
    "country": "GB",
    "name": "Charlton Kings",
    "lat": "51.88374",
    "lng": "-2.04239"
  },
  {
    "country": "GB",
    "name": "Charlton",
    "lat": "51.59917",
    "lng": "-2.05639"
  },
  {
    "country": "GB",
    "name": "Charlbury",
    "lat": "51.8727",
    "lng": "-1.48247"
  },
  {
    "country": "GB",
    "name": "Charing",
    "lat": "51.21073",
    "lng": "0.79466"
  },
  {
    "country": "GB",
    "name": "Charfield",
    "lat": "51.62722",
    "lng": "-2.40667"
  },
  {
    "country": "GB",
    "name": "Chard",
    "lat": "50.8727",
    "lng": "-2.96597"
  },
  {
    "country": "GB",
    "name": "Chapletown",
    "lat": "53.46506",
    "lng": "-1.47217"
  },
  {
    "country": "GB",
    "name": "Chapel Saint Leonards",
    "lat": "53.21667",
    "lng": "0.31667"
  },
  {
    "country": "GB",
    "name": "Chapelhall",
    "lat": "55.84349",
    "lng": "-3.94881"
  },
  {
    "country": "GB",
    "name": "Chapel en le Frith",
    "lat": "53.32407",
    "lng": "-1.91291"
  },
  {
    "country": "GB",
    "name": "Chalgrove",
    "lat": "51.66476",
    "lng": "-1.0764"
  },
  {
    "country": "GB",
    "name": "Chalford",
    "lat": "51.72583",
    "lng": "-2.15139"
  },
  {
    "country": "GB",
    "name": "Chalfont Saint Peter",
    "lat": "51.60885",
    "lng": "-0.55618"
  },
  {
    "country": "GB",
    "name": "Chalfont St Giles",
    "lat": "51.63184",
    "lng": "-0.57026"
  },
  {
    "country": "GB",
    "name": "Chale",
    "lat": "50.59561",
    "lng": "-1.31836"
  },
  {
    "country": "GB",
    "name": "Chagford",
    "lat": "50.67504",
    "lng": "-3.83936"
  },
  {
    "country": "GB",
    "name": "Chacewater",
    "lat": "50.25675",
    "lng": "-5.15757"
  },
  {
    "country": "GB",
    "name": "Cemaes Bay",
    "lat": "53.41211",
    "lng": "-4.4519"
  },
  {
    "country": "GB",
    "name": "Caythorpe",
    "lat": "53.01667",
    "lng": "-0.6"
  },
  {
    "country": "GB",
    "name": "Cawthorne",
    "lat": "53.56687",
    "lng": "-1.57259"
  },
  {
    "country": "GB",
    "name": "Cawston",
    "lat": "52.76667",
    "lng": "1.16667"
  },
  {
    "country": "GB",
    "name": "Cawood",
    "lat": "53.83303",
    "lng": "-1.12962"
  },
  {
    "country": "GB",
    "name": "Catterick",
    "lat": "54.37542",
    "lng": "-1.63328"
  },
  {
    "country": "GB",
    "name": "Catterall",
    "lat": "53.87965",
    "lng": "-2.76478"
  },
  {
    "country": "GB",
    "name": "Catrine",
    "lat": "55.50422",
    "lng": "-4.33026"
  },
  {
    "country": "GB",
    "name": "Caton",
    "lat": "54.07624",
    "lng": "-2.71903"
  },
  {
    "country": "GB",
    "name": "Catford",
    "lat": "51.44491",
    "lng": "-0.02043"
  },
  {
    "country": "GB",
    "name": "Caterham",
    "lat": "51.2823",
    "lng": "-0.07889"
  },
  {
    "country": "GB",
    "name": "Castor",
    "lat": "52.57319",
    "lng": "-0.34603"
  },
  {
    "country": "GB",
    "name": "Castlewellan",
    "lat": "54.2569",
    "lng": "-5.94446"
  },
  {
    "country": "GB",
    "name": "Castlethorpe",
    "lat": "52.0923",
    "lng": "-0.83539"
  },
  {
    "country": "GB",
    "name": "Castleside",
    "lat": "54.83429",
    "lng": "-1.87849"
  },
  {
    "country": "GB",
    "name": "Castlerock",
    "lat": "55.15",
    "lng": "-6.78333"
  },
  {
    "country": "GB",
    "name": "Castlereagh",
    "lat": "54.5735",
    "lng": "-5.88472"
  },
  {
    "country": "GB",
    "name": "Castlemartin",
    "lat": "51.64528",
    "lng": "-5.01694"
  },
  {
    "country": "GB",
    "name": "Castle Hedingham",
    "lat": "51.99015",
    "lng": "0.59882"
  },
  {
    "country": "GB",
    "name": "Castleford",
    "lat": "53.72587",
    "lng": "-1.36256"
  },
  {
    "country": "GB",
    "name": "Castle Douglas",
    "lat": "54.94095",
    "lng": "-3.92784"
  },
  {
    "country": "GB",
    "name": "Castle Donington",
    "lat": "52.84291",
    "lng": "-1.34188"
  },
  {
    "country": "GB",
    "name": "Castlederg",
    "lat": "54.70699",
    "lng": "-7.59336"
  },
  {
    "country": "GB",
    "name": "Castledawson",
    "lat": "54.77723",
    "lng": "-6.56227"
  },
  {
    "country": "GB",
    "name": "Castle Cary",
    "lat": "51.09",
    "lng": "-2.51417"
  },
  {
    "country": "GB",
    "name": "Carterton",
    "lat": "51.75905",
    "lng": "-1.59435"
  },
  {
    "country": "GB",
    "name": "Carshalton",
    "lat": "51.36829",
    "lng": "-0.16755"
  },
  {
    "country": "GB",
    "name": "Carryduff",
    "lat": "54.51799",
    "lng": "-5.88713"
  },
  {
    "country": "GB",
    "name": "Carron",
    "lat": "56.02611",
    "lng": "-3.79251"
  },
  {
    "country": "GB",
    "name": "Carrington",
    "lat": "53.43333",
    "lng": "-2.38333"
  },
  {
    "country": "GB",
    "name": "Carrickfergus",
    "lat": "54.7158",
    "lng": "-5.8058"
  },
  {
    "country": "GB",
    "name": "Carnwath",
    "lat": "55.70036",
    "lng": "-3.62579"
  },
  {
    "country": "GB",
    "name": "Carnoustie",
    "lat": "56.50263",
    "lng": "-2.7053"
  },
  {
    "country": "GB",
    "name": "Carnmoney",
    "lat": "54.68333",
    "lng": "-5.95"
  },
  {
    "country": "GB",
    "name": "Carnlough",
    "lat": "54.99185",
    "lng": "-5.99038"
  },
  {
    "country": "GB",
    "name": "Carnforth",
    "lat": "54.13163",
    "lng": "-2.76914"
  },
  {
    "country": "GB",
    "name": "Carnaby",
    "lat": "54.0607",
    "lng": "-0.25957"
  },
  {
    "country": "GB",
    "name": "Carmunnock",
    "lat": "55.79062",
    "lng": "-4.23584"
  },
  {
    "country": "GB",
    "name": "Carmarthen",
    "lat": "51.85552",
    "lng": "-4.30535"
  },
  {
    "country": "GB",
    "name": "Carluke",
    "lat": "55.73595",
    "lng": "-3.83019"
  },
  {
    "country": "GB",
    "name": "Carlton",
    "lat": "54.59004",
    "lng": "-1.39117"
  },
  {
    "country": "GB",
    "name": "Carlisle",
    "lat": "54.8951",
    "lng": "-2.9382"
  },
  {
    "country": "GB",
    "name": "Carfin",
    "lat": "55.80502",
    "lng": "-3.96076"
  },
  {
    "country": "GB",
    "name": "Cardross",
    "lat": "55.96184",
    "lng": "-4.65316"
  },
  {
    "country": "GB",
    "name": "Cardington",
    "lat": "52.55",
    "lng": "-2.73333"
  },
  {
    "country": "GB",
    "name": "Cardington",
    "lat": "52.11742",
    "lng": "-0.41289"
  },
  {
    "country": "GB",
    "name": "Cardigan",
    "lat": "52.08373",
    "lng": "-4.66228"
  },
  {
    "country": "GB",
    "name": "Cardiff",
    "lat": "51.48",
    "lng": "-3.18"
  },
  {
    "country": "GB",
    "name": "Cardenden",
    "lat": "56.1431",
    "lng": "-3.25687"
  },
  {
    "country": "GB",
    "name": "Carcroft",
    "lat": "53.58282",
    "lng": "-1.17648"
  },
  {
    "country": "GB",
    "name": "Capel Saint Mary",
    "lat": "52.00369",
    "lng": "1.04482"
  },
  {
    "country": "GB",
    "name": "Capel",
    "lat": "51.14942",
    "lng": "-0.32375"
  },
  {
    "country": "GB",
    "name": "Cantley",
    "lat": "53.5",
    "lng": "-1.05"
  },
  {
    "country": "GB",
    "name": "Canterbury",
    "lat": "51.27904",
    "lng": "1.07992"
  },
  {
    "country": "GB",
    "name": "Cannock",
    "lat": "52.69045",
    "lng": "-2.03085"
  },
  {
    "country": "GB",
    "name": "Canewdon",
    "lat": "51.61759",
    "lng": "0.74458"
  },
  {
    "country": "GB",
    "name": "Camrose",
    "lat": "51.84139",
    "lng": "-5.01"
  },
  {
    "country": "GB",
    "name": "Campsall",
    "lat": "53.61917",
    "lng": "-1.18002"
  },
  {
    "country": "GB",
    "name": "Campbeltown",
    "lat": "55.42583",
    "lng": "-5.60764"
  },
  {
    "country": "GB",
    "name": "Camerton",
    "lat": "51.31611",
    "lng": "-2.45611"
  },
  {
    "country": "GB",
    "name": "Camelford",
    "lat": "50.62185",
    "lng": "-4.67963"
  },
  {
    "country": "GB",
    "name": "Cambuslang",
    "lat": "55.80966",
    "lng": "-4.16096"
  },
  {
    "country": "GB",
    "name": "Cambridge",
    "lat": "52.2",
    "lng": "0.11667"
  },
  {
    "country": "GB",
    "name": "Camborne",
    "lat": "50.21306",
    "lng": "-5.29731"
  },
  {
    "country": "GB",
    "name": "Camberley",
    "lat": "51.33705",
    "lng": "-0.74261"
  },
  {
    "country": "GB",
    "name": "Calverton",
    "lat": "53.03728",
    "lng": "-1.08263"
  },
  {
    "country": "GB",
    "name": "Calverton",
    "lat": "52.04119",
    "lng": "-0.85041"
  },
  {
    "country": "GB",
    "name": "Calne",
    "lat": "51.43879",
    "lng": "-2.00571"
  },
  {
    "country": "GB",
    "name": "Callow",
    "lat": "52.01667",
    "lng": "-2.73333"
  },
  {
    "country": "GB",
    "name": "Callington",
    "lat": "50.50147",
    "lng": "-4.31314"
  },
  {
    "country": "GB",
    "name": "Callander",
    "lat": "56.2441",
    "lng": "-4.21637"
  },
  {
    "country": "GB",
    "name": "Caldicot",
    "lat": "51.58661",
    "lng": "-2.75736"
  },
  {
    "country": "GB",
    "name": "Caldercruix",
    "lat": "55.88886",
    "lng": "-3.88664"
  },
  {
    "country": "GB",
    "name": "Caistor",
    "lat": "53.49673",
    "lng": "-0.31538"
  },
  {
    "country": "GB",
    "name": "Caister-on-Sea",
    "lat": "52.64809",
    "lng": "1.72648"
  },
  {
    "country": "GB",
    "name": "Cairnryan",
    "lat": "54.97104",
    "lng": "-5.01982"
  },
  {
    "country": "GB",
    "name": "Cairneyhill",
    "lat": "56.05908",
    "lng": "-3.53518"
  },
  {
    "country": "GB",
    "name": "Caerwent",
    "lat": "51.6112",
    "lng": "-2.76865"
  },
  {
    "country": "GB",
    "name": "Caerphilly",
    "lat": "51.57452",
    "lng": "-3.218"
  },
  {
    "country": "GB",
    "name": "Caernarfon",
    "lat": "53.14126",
    "lng": "-4.27016"
  },
  {
    "country": "GB",
    "name": "Caerleon",
    "lat": "51.60952",
    "lng": "-2.95378"
  },
  {
    "country": "GB",
    "name": "Caergwrle",
    "lat": "53.10953",
    "lng": "-3.03808"
  },
  {
    "country": "GB",
    "name": "Cadnam",
    "lat": "50.92047",
    "lng": "-1.5797"
  },
  {
    "country": "GB",
    "name": "Caddington",
    "lat": "51.86621",
    "lng": "-0.45679"
  },
  {
    "country": "GB",
    "name": "Byfield",
    "lat": "52.17546",
    "lng": "-1.24566"
  },
  {
    "country": "GB",
    "name": "Buxton",
    "lat": "53.25741",
    "lng": "-1.90982"
  },
  {
    "country": "GB",
    "name": "Buxton",
    "lat": "52.75255",
    "lng": "1.29982"
  },
  {
    "country": "GB",
    "name": "Buxted",
    "lat": "50.99003",
    "lng": "0.13441"
  },
  {
    "country": "GB",
    "name": "Butterwick",
    "lat": "52.98333",
    "lng": "0.06667"
  },
  {
    "country": "GB",
    "name": "Butcombe",
    "lat": "51.35194",
    "lng": "-2.69778"
  },
  {
    "country": "GB",
    "name": "Bushmills",
    "lat": "55.20493",
    "lng": "-6.51918"
  },
  {
    "country": "GB",
    "name": "Bushey",
    "lat": "51.64316",
    "lng": "-0.36053"
  },
  {
    "country": "GB",
    "name": "Busby",
    "lat": "55.77995",
    "lng": "-4.27711"
  },
  {
    "country": "GB",
    "name": "Bury St Edmunds",
    "lat": "52.2463",
    "lng": "0.71111"
  },
  {
    "country": "GB",
    "name": "Bury",
    "lat": "53.6",
    "lng": "-2.3"
  },
  {
    "country": "GB",
    "name": "Burwell",
    "lat": "53.29305",
    "lng": "0.03463"
  },
  {
    "country": "GB",
    "name": "Burwell",
    "lat": "52.27632",
    "lng": "0.32732"
  },
  {
    "country": "GB",
    "name": "Burwash",
    "lat": "50.99755",
    "lng": "0.38504"
  },
  {
    "country": "GB",
    "name": "Burtonwood",
    "lat": "53.42948",
    "lng": "-2.65852"
  },
  {
    "country": "GB",
    "name": "Burton upon Trent",
    "lat": "52.80728",
    "lng": "-1.64263"
  },
  {
    "country": "GB",
    "name": "Burton upon Stather",
    "lat": "53.64911",
    "lng": "-0.68453"
  },
  {
    "country": "GB",
    "name": "Burton Pidsea",
    "lat": "53.76327",
    "lng": "-0.10703"
  },
  {
    "country": "GB",
    "name": "Burton on the Wolds",
    "lat": "52.78574",
    "lng": "-1.12988"
  },
  {
    "country": "GB",
    "name": "Burton Latimer",
    "lat": "52.36368",
    "lng": "-0.67853"
  },
  {
    "country": "GB",
    "name": "Burton Joyce",
    "lat": "52.98825",
    "lng": "-1.03407"
  },
  {
    "country": "GB",
    "name": "Burton Constable",
    "lat": "53.81667",
    "lng": "-0.2"
  },
  {
    "country": "GB",
    "name": "Burton",
    "lat": "53.26667",
    "lng": "-0.56667"
  },
  {
    "country": "GB",
    "name": "Burton",
    "lat": "51.71556",
    "lng": "-4.92222"
  },
  {
    "country": "GB",
    "name": "Burstwick",
    "lat": "53.73211",
    "lng": "-0.13956"
  },
  {
    "country": "GB",
    "name": "Bursledon",
    "lat": "50.88658",
    "lng": "-1.31596"
  },
  {
    "country": "GB",
    "name": "Burscough",
    "lat": "53.5964",
    "lng": "-2.83972"
  },
  {
    "country": "GB",
    "name": "Burry Port",
    "lat": "51.68435",
    "lng": "-4.24687"
  },
  {
    "country": "GB",
    "name": "Burrington",
    "lat": "52.35",
    "lng": "-2.81667"
  },
  {
    "country": "GB",
    "name": "Burrington",
    "lat": "51.32884",
    "lng": "-2.74868"
  },
  {
    "country": "GB",
    "name": "Burringham",
    "lat": "53.57402",
    "lng": "-0.73957"
  },
  {
    "country": "GB",
    "name": "Burntwood",
    "lat": "52.68075",
    "lng": "-1.92759"
  },
  {
    "country": "GB",
    "name": "Burntisland",
    "lat": "56.06248",
    "lng": "-3.23176"
  },
  {
    "country": "GB",
    "name": "Burnopfield",
    "lat": "54.90624",
    "lng": "-1.72486"
  },
  {
    "country": "GB",
    "name": "Burnley",
    "lat": "53.8",
    "lng": "-2.23333"
  },
  {
    "country": "GB",
    "name": "Burniston",
    "lat": "54.32385",
    "lng": "-0.44813"
  },
  {
    "country": "GB",
    "name": "Burnham-on-Sea",
    "lat": "51.23862",
    "lng": "-2.9978"
  },
  {
    "country": "GB",
    "name": "Burnham-on-Crouch",
    "lat": "51.63272",
    "lng": "0.81488"
  },
  {
    "country": "GB",
    "name": "Burneside",
    "lat": "54.35271",
    "lng": "-2.76151"
  },
  {
    "country": "GB",
    "name": "Burley in Wharfedale",
    "lat": "53.9102",
    "lng": "-1.75798"
  },
  {
    "country": "GB",
    "name": "Burley",
    "lat": "52.68512",
    "lng": "-0.69609"
  },
  {
    "country": "GB",
    "name": "Burley",
    "lat": "50.828",
    "lng": "-1.69977"
  },
  {
    "country": "GB",
    "name": "Burham",
    "lat": "51.33243",
    "lng": "0.47833"
  },
  {
    "country": "GB",
    "name": "Burgh le Marsh",
    "lat": "53.16158",
    "lng": "0.24484"
  },
  {
    "country": "GB",
    "name": "Burghead",
    "lat": "57.70113",
    "lng": "-3.48992"
  },
  {
    "country": "GB",
    "name": "Burgess Hill",
    "lat": "50.95843",
    "lng": "-0.13287"
  },
  {
    "country": "GB",
    "name": "Burford",
    "lat": "51.80915",
    "lng": "-1.63628"
  },
  {
    "country": "GB",
    "name": "Bures Saint Mary",
    "lat": "51.9724",
    "lng": "0.77488"
  },
  {
    "country": "GB",
    "name": "Burbage",
    "lat": "51.35184",
    "lng": "-1.67087"
  },
  {
    "country": "GB",
    "name": "Buntingford",
    "lat": "51.94612",
    "lng": "-0.01841"
  },
  {
    "country": "GB",
    "name": "Bungay",
    "lat": "52.45434",
    "lng": "1.43818"
  },
  {
    "country": "GB",
    "name": "Bunbury",
    "lat": "53.11559",
    "lng": "-2.65151"
  },
  {
    "country": "GB",
    "name": "Bulkington",
    "lat": "51.32361",
    "lng": "-2.08361"
  },
  {
    "country": "GB",
    "name": "Bulford",
    "lat": "51.1893",
    "lng": "-1.76009"
  },
  {
    "country": "GB",
    "name": "Builth Wells",
    "lat": "52.1494",
    "lng": "-3.40469"
  },
  {
    "country": "GB",
    "name": "Bugthorpe",
    "lat": "54.01082",
    "lng": "-0.8226"
  },
  {
    "country": "GB",
    "name": "Bugle",
    "lat": "50.39577",
    "lng": "-4.79334"
  },
  {
    "country": "GB",
    "name": "Bugbrooke",
    "lat": "52.21006",
    "lng": "-1.01304"
  },
  {
    "country": "GB",
    "name": "Budleigh Salterton",
    "lat": "50.62983",
    "lng": "-3.32181"
  },
  {
    "country": "GB",
    "name": "Bude",
    "lat": "50.82435",
    "lng": "-4.5413"
  },
  {
    "country": "GB",
    "name": "Bucknell",
    "lat": "52.35997",
    "lng": "-2.95066"
  },
  {
    "country": "GB",
    "name": "Buckley",
    "lat": "53.16667",
    "lng": "-3.08333"
  },
  {
    "country": "GB",
    "name": "Buckingham",
    "lat": "51.99968",
    "lng": "-0.98779"
  },
  {
    "country": "GB",
    "name": "Buckie",
    "lat": "57.6757",
    "lng": "-2.96238"
  },
  {
    "country": "GB",
    "name": "Buckhurst Hill",
    "lat": "51.62409",
    "lng": "0.03262"
  },
  {
    "country": "GB",
    "name": "Buckhaven",
    "lat": "56.17149",
    "lng": "-3.03377"
  },
  {
    "country": "GB",
    "name": "Buckfastleigh",
    "lat": "50.48132",
    "lng": "-3.77913"
  },
  {
    "country": "GB",
    "name": "Buckden",
    "lat": "52.29415",
    "lng": "-0.24912"
  },
  {
    "country": "GB",
    "name": "Bubwith",
    "lat": "53.81905",
    "lng": "-0.91968"
  },
  {
    "country": "GB",
    "name": "Brynmawr",
    "lat": "51.8",
    "lng": "-3.18333"
  },
  {
    "country": "GB",
    "name": "Bryneglwys",
    "lat": "53.01667",
    "lng": "-3.28333"
  },
  {
    "country": "GB",
    "name": "Brynamman",
    "lat": "51.8",
    "lng": "-3.86667"
  },
  {
    "country": "GB",
    "name": "Bryn",
    "lat": "51.61639",
    "lng": "-3.71167"
  },
  {
    "country": "GB",
    "name": "Brymbo",
    "lat": "53.06667",
    "lng": "-3.06667"
  },
  {
    "country": "GB",
    "name": "Bruton",
    "lat": "51.1125",
    "lng": "-2.45278"
  },
  {
    "country": "GB",
    "name": "Brundall",
    "lat": "52.62426",
    "lng": "1.43509"
  },
  {
    "country": "GB",
    "name": "Broxburn",
    "lat": "55.93415",
    "lng": "-3.47133"
  },
  {
    "country": "GB",
    "name": "Broxbourne",
    "lat": "51.74712",
    "lng": "-0.01923"
  },
  {
    "country": "GB",
    "name": "Brownhills",
    "lat": "52.63333",
    "lng": "-1.93333"
  },
  {
    "country": "GB",
    "name": "Broughton Astley",
    "lat": "52.52787",
    "lng": "-1.21768"
  },
  {
    "country": "GB",
    "name": "Broughton",
    "lat": "53.56667",
    "lng": "-0.55"
  },
  {
    "country": "GB",
    "name": "Broughton",
    "lat": "53.16303",
    "lng": "-2.99309"
  },
  {
    "country": "GB",
    "name": "Broughton",
    "lat": "52.37331",
    "lng": "-0.77493"
  },
  {
    "country": "GB",
    "name": "Broughton",
    "lat": "52.05038",
    "lng": "-0.69351"
  },
  {
    "country": "GB",
    "name": "Broughshane",
    "lat": "54.8926",
    "lng": "-6.20899"
  },
  {
    "country": "GB",
    "name": "Brough",
    "lat": "53.72861",
    "lng": "-0.57215"
  },
  {
    "country": "GB",
    "name": "Brotton",
    "lat": "54.56661",
    "lng": "-0.93929"
  },
  {
    "country": "GB",
    "name": "Broseley",
    "lat": "52.61321",
    "lng": "-2.48269"
  },
  {
    "country": "GB",
    "name": "Brora",
    "lat": "58.00989",
    "lng": "-3.85182"
  },
  {
    "country": "GB",
    "name": "Broomfleet",
    "lat": "53.73333",
    "lng": "-0.66667"
  },
  {
    "country": "GB",
    "name": "Brooke",
    "lat": "52.64317",
    "lng": "-0.74638"
  },
  {
    "country": "GB",
    "name": "Brooke",
    "lat": "52.54175",
    "lng": "1.37076"
  },
  {
    "country": "GB",
    "name": "Bromyard",
    "lat": "52.19019",
    "lng": "-2.50875"
  },
  {
    "country": "GB",
    "name": "Bromsgrove",
    "lat": "52.33574",
    "lng": "-2.05983"
  },
  {
    "country": "GB",
    "name": "Brompton",
    "lat": "54.36015",
    "lng": "-1.42422"
  },
  {
    "country": "GB",
    "name": "Bromley",
    "lat": "51.40606",
    "lng": "0.01519"
  },
  {
    "country": "GB",
    "name": "Bromham",
    "lat": "52.14508",
    "lng": "-0.52906"
  },
  {
    "country": "GB",
    "name": "Bromfield",
    "lat": "52.38333",
    "lng": "-2.76667"
  },
  {
    "country": "GB",
    "name": "Bromborough",
    "lat": "53.3485",
    "lng": "-2.97935"
  },
  {
    "country": "GB",
    "name": "Brockley",
    "lat": "51.4",
    "lng": "-2.76667"
  },
  {
    "country": "GB",
    "name": "Brockhampton",
    "lat": "51.98333",
    "lng": "-2.58333"
  },
  {
    "country": "GB",
    "name": "Brockenhurst",
    "lat": "50.81936",
    "lng": "-1.57303"
  },
  {
    "country": "GB",
    "name": "Broadway",
    "lat": "52.03825",
    "lng": "-1.86079"
  },
  {
    "country": "GB",
    "name": "Broadwater",
    "lat": "50.82887",
    "lng": "-0.37594"
  },
  {
    "country": "GB",
    "name": "Broadstone",
    "lat": "50.75717",
    "lng": "-1.99406"
  },
  {
    "country": "GB",
    "name": "Broadstairs",
    "lat": "51.35908",
    "lng": "1.43938"
  },
  {
    "country": "GB",
    "name": "Broad Blunsdon",
    "lat": "51.61339",
    "lng": "-1.7787"
  },
  {
    "country": "GB",
    "name": "Brixworth",
    "lat": "52.32912",
    "lng": "-0.9035"
  },
  {
    "country": "GB",
    "name": "Brixton",
    "lat": "50.35",
    "lng": "-4.03333"
  },
  {
    "country": "GB",
    "name": "Brixham",
    "lat": "50.39431",
    "lng": "-3.51585"
  },
  {
    "country": "GB",
    "name": "Briton Ferry",
    "lat": "51.63106",
    "lng": "-3.81898"
  },
  {
    "country": "GB",
    "name": "Briston",
    "lat": "52.85369",
    "lng": "1.05899"
  },
  {
    "country": "GB",
    "name": "Bristol",
    "lat": "51.45523",
    "lng": "-2.59665"
  },
  {
    "country": "GB",
    "name": "Brinscall",
    "lat": "53.689",
    "lng": "-2.57208"
  },
  {
    "country": "GB",
    "name": "Brinklow",
    "lat": "52.41091",
    "lng": "-1.364"
  },
  {
    "country": "GB",
    "name": "Brimscombe",
    "lat": "51.71973",
    "lng": "-2.18553"
  },
  {
    "country": "GB",
    "name": "Brill",
    "lat": "51.81667",
    "lng": "-1.05"
  },
  {
    "country": "GB",
    "name": "Brigstock",
    "lat": "52.45775",
    "lng": "-0.60834"
  },
  {
    "country": "GB",
    "name": "Brignall",
    "lat": "54.50534",
    "lng": "-1.88896"
  },
  {
    "country": "GB",
    "name": "Brighton",
    "lat": "50.82838",
    "lng": "-0.13947"
  },
  {
    "country": "GB",
    "name": "Brightlingsea",
    "lat": "51.81164",
    "lng": "1.02336"
  },
  {
    "country": "GB",
    "name": "Brighstone",
    "lat": "50.64263",
    "lng": "-1.39479"
  },
  {
    "country": "GB",
    "name": "Brighouse",
    "lat": "53.70322",
    "lng": "-1.78428"
  },
  {
    "country": "GB",
    "name": "Brigg",
    "lat": "53.55201",
    "lng": "-0.49214"
  },
  {
    "country": "GB",
    "name": "Brierley Hill",
    "lat": "52.48173",
    "lng": "-2.12139"
  },
  {
    "country": "GB",
    "name": "Brierfield",
    "lat": "53.82468",
    "lng": "-2.23415"
  },
  {
    "country": "GB",
    "name": "Bridport",
    "lat": "50.7338",
    "lng": "-2.75831"
  },
  {
    "country": "GB",
    "name": "Bridlington",
    "lat": "54.08306",
    "lng": "-0.19192"
  },
  {
    "country": "GB",
    "name": "Bridgwater",
    "lat": "51.12837",
    "lng": "-3.00356"
  },
  {
    "country": "GB",
    "name": "Bridgnorth",
    "lat": "52.53661",
    "lng": "-2.42033"
  },
  {
    "country": "GB",
    "name": "Bridge of Weir",
    "lat": "55.85582",
    "lng": "-4.57894"
  },
  {
    "country": "GB",
    "name": "Bridge of Earn",
    "lat": "56.34842",
    "lng": "-3.4065"
  },
  {
    "country": "GB",
    "name": "Bridge of Allan",
    "lat": "56.15402",
    "lng": "-3.94631"
  },
  {
    "country": "GB",
    "name": "Bridgend",
    "lat": "51.50583",
    "lng": "-3.57722"
  },
  {
    "country": "GB",
    "name": "Bridge",
    "lat": "51.24513",
    "lng": "1.1264"
  },
  {
    "country": "GB",
    "name": "Brewood",
    "lat": "52.67712",
    "lng": "-2.17414"
  },
  {
    "country": "GB",
    "name": "Brentwood",
    "lat": "51.62127",
    "lng": "0.30556"
  },
  {
    "country": "GB",
    "name": "Brent Knoll",
    "lat": "51.25219",
    "lng": "-2.95744"
  },
  {
    "country": "GB",
    "name": "Brentford",
    "lat": "51.48619",
    "lng": "-0.3083"
  },
  {
    "country": "GB",
    "name": "Brenchley",
    "lat": "51.15141",
    "lng": "0.39825"
  },
  {
    "country": "GB",
    "name": "Bremhill",
    "lat": "51.45667",
    "lng": "-2.03028"
  },
  {
    "country": "GB",
    "name": "Bredon",
    "lat": "52.03008",
    "lng": "-2.11671"
  },
  {
    "country": "GB",
    "name": "Bredbury",
    "lat": "53.41667",
    "lng": "-2.11667"
  },
  {
    "country": "GB",
    "name": "Brecon",
    "lat": "51.94612",
    "lng": "-3.38887"
  },
  {
    "country": "GB",
    "name": "Brechin",
    "lat": "56.72993",
    "lng": "-2.65729"
  },
  {
    "country": "GB",
    "name": "Bream",
    "lat": "51.74822",
    "lng": "-2.57747"
  },
  {
    "country": "GB",
    "name": "Brayton",
    "lat": "53.7651",
    "lng": "-1.08921"
  },
  {
    "country": "GB",
    "name": "Bray",
    "lat": "51.5034",
    "lng": "-0.68768"
  },
  {
    "country": "GB",
    "name": "Braunton",
    "lat": "51.10847",
    "lng": "-4.16131"
  },
  {
    "country": "GB",
    "name": "Braunston",
    "lat": "52.28979",
    "lng": "-1.20266"
  },
  {
    "country": "GB",
    "name": "Bratton",
    "lat": "51.27056",
    "lng": "-2.12444"
  },
  {
    "country": "GB",
    "name": "Brantingham",
    "lat": "53.75181",
    "lng": "-0.57704"
  },
  {
    "country": "GB",
    "name": "Branston",
    "lat": "53.19544",
    "lng": "-0.47482"
  },
  {
    "country": "GB",
    "name": "Bransgore",
    "lat": "50.78153",
    "lng": "-1.73771"
  },
  {
    "country": "GB",
    "name": "Brandon",
    "lat": "54.75",
    "lng": "-1.61667"
  },
  {
    "country": "GB",
    "name": "Brandon",
    "lat": "52.38432",
    "lng": "-1.3996"
  },
  {
    "country": "GB",
    "name": "Brandesburton",
    "lat": "53.9111",
    "lng": "-0.30122"
  },
  {
    "country": "GB",
    "name": "Brampton",
    "lat": "54.95",
    "lng": "-2.73333"
  },
  {
    "country": "GB",
    "name": "Brampton",
    "lat": "52.32039",
    "lng": "-0.22007"
  },
  {
    "country": "GB",
    "name": "Bramley",
    "lat": "53.41667",
    "lng": "-1.26667"
  },
  {
    "country": "GB",
    "name": "Bramley",
    "lat": "51.32677",
    "lng": "-1.05938"
  },
  {
    "country": "GB",
    "name": "Bramley",
    "lat": "51.19451",
    "lng": "-0.55927"
  },
  {
    "country": "GB",
    "name": "Bramhope",
    "lat": "53.88489",
    "lng": "-1.61641"
  },
  {
    "country": "GB",
    "name": "Bramham",
    "lat": "53.88118",
    "lng": "-1.35452"
  },
  {
    "country": "GB",
    "name": "Bramhall",
    "lat": "53.35801",
    "lng": "-2.16539"
  },
  {
    "country": "GB",
    "name": "Bramford",
    "lat": "52.07631",
    "lng": "1.09687"
  },
  {
    "country": "GB",
    "name": "Braintree",
    "lat": "51.87819",
    "lng": "0.55292"
  },
  {
    "country": "GB",
    "name": "Bradwell",
    "lat": "52.04857",
    "lng": "-0.78771"
  },
  {
    "country": "GB",
    "name": "Bradninch",
    "lat": "50.82491",
    "lng": "-3.42465"
  },
  {
    "country": "GB",
    "name": "Bradley",
    "lat": "53.55",
    "lng": "-0.13333"
  },
  {
    "country": "GB",
    "name": "Brading",
    "lat": "50.6799",
    "lng": "-1.14571"
  },
  {
    "country": "GB",
    "name": "Bradford-on-Avon",
    "lat": "51.34772",
    "lng": "-2.25065"
  },
  {
    "country": "GB",
    "name": "Bradford",
    "lat": "53.79391",
    "lng": "-1.75206"
  },
  {
    "country": "GB",
    "name": "Bradfield",
    "lat": "53.41667",
    "lng": "-1.6"
  },
  {
    "country": "GB",
    "name": "Bradfield",
    "lat": "51.44914",
    "lng": "-1.13082"
  },
  {
    "country": "GB",
    "name": "Bracknell",
    "lat": "51.41363",
    "lng": "-0.75054"
  },
  {
    "country": "GB",
    "name": "Brackley",
    "lat": "52.03333",
    "lng": "-1.15"
  },
  {
    "country": "GB",
    "name": "Bozeat",
    "lat": "52.2227",
    "lng": "-0.67326"
  },
  {
    "country": "GB",
    "name": "Boyton",
    "lat": "50.7",
    "lng": "-4.38333"
  },
  {
    "country": "GB",
    "name": "Boynton",
    "lat": "54.09746",
    "lng": "-0.26479"
  },
  {
    "country": "GB",
    "name": "Boxted",
    "lat": "51.94878",
    "lng": "0.91002"
  },
  {
    "country": "GB",
    "name": "Boxgrove",
    "lat": "50.85884",
    "lng": "-0.7136"
  },
  {
    "country": "GB",
    "name": "Box",
    "lat": "51.41472",
    "lng": "-2.24556"
  },
  {
    "country": "GB",
    "name": "Bow Street",
    "lat": "52.44213",
    "lng": "-4.02783"
  },
  {
    "country": "GB",
    "name": "Bowes",
    "lat": "54.5164",
    "lng": "-2.01599"
  },
  {
    "country": "GB",
    "name": "Bower Chalke",
    "lat": "51",
    "lng": "-1.96667"
  },
  {
    "country": "GB",
    "name": "Bowdon",
    "lat": "53.37644",
    "lng": "-2.36532"
  },
  {
    "country": "GB",
    "name": "Bow Brickhill",
    "lat": "52.0028",
    "lng": "-0.68064"
  },
  {
    "country": "GB",
    "name": "Bow",
    "lat": "50.8",
    "lng": "-3.81667"
  },
  {
    "country": "GB",
    "name": "Bovington Camp",
    "lat": "50.69782",
    "lng": "-2.23506"
  },
  {
    "country": "GB",
    "name": "Bovingdon",
    "lat": "51.72312",
    "lng": "-0.5367"
  },
  {
    "country": "GB",
    "name": "Bovey Tracey",
    "lat": "50.59259",
    "lng": "-3.67543"
  },
  {
    "country": "GB",
    "name": "Bourton on the Water",
    "lat": "51.88584",
    "lng": "-1.75492"
  },
  {
    "country": "GB",
    "name": "Bourton",
    "lat": "51.07444",
    "lng": "-2.32778"
  },
  {
    "country": "GB",
    "name": "Bournemouth",
    "lat": "50.72048",
    "lng": "-1.8795"
  },
  {
    "country": "GB",
    "name": "Bourne End",
    "lat": "51.57622",
    "lng": "-0.71291"
  },
  {
    "country": "GB",
    "name": "Bourne",
    "lat": "52.76667",
    "lng": "-0.38333"
  },
  {
    "country": "GB",
    "name": "Boughton",
    "lat": "53.2",
    "lng": "-0.98333"
  },
  {
    "country": "GB",
    "name": "Bottisham",
    "lat": "52.2228",
    "lng": "0.25878"
  },
  {
    "country": "GB",
    "name": "Bottesford",
    "lat": "53.55",
    "lng": "-0.65"
  },
  {
    "country": "GB",
    "name": "Bottesford",
    "lat": "52.94131",
    "lng": "-0.8006"
  },
  {
    "country": "GB",
    "name": "Botley",
    "lat": "50.91433",
    "lng": "-1.26984"
  },
  {
    "country": "GB",
    "name": "Bothwell",
    "lat": "55.80272",
    "lng": "-4.06835"
  },
  {
    "country": "GB",
    "name": "Botesdale",
    "lat": "52.34216",
    "lng": "1.00405"
  },
  {
    "country": "GB",
    "name": "Boston Spa",
    "lat": "53.90419",
    "lng": "-1.34523"
  },
  {
    "country": "GB",
    "name": "Boston",
    "lat": "52.97633",
    "lng": "-0.02664"
  },
  {
    "country": "GB",
    "name": "Bosham",
    "lat": "50.83088",
    "lng": "-0.85384"
  },
  {
    "country": "GB",
    "name": "Borth",
    "lat": "52.48887",
    "lng": "-4.05039"
  },
  {
    "country": "GB",
    "name": "Borrowash",
    "lat": "52.90673",
    "lng": "-1.38411"
  },
  {
    "country": "GB",
    "name": "Borough Green",
    "lat": "51.29158",
    "lng": "0.30478"
  },
  {
    "country": "GB",
    "name": "Boroughbridge",
    "lat": "54.0895",
    "lng": "-1.4011"
  },
  {
    "country": "GB",
    "name": "Borehamwood",
    "lat": "51.65468",
    "lng": "-0.27762"
  },
  {
    "country": "GB",
    "name": "Boreham",
    "lat": "51.75955",
    "lng": "0.54116"
  },
  {
    "country": "GB",
    "name": "Boreham",
    "lat": "51.19944",
    "lng": "-2.16556"
  },
  {
    "country": "GB",
    "name": "Bootle",
    "lat": "53.46667",
    "lng": "-3.01667"
  },
  {
    "country": "GB",
    "name": "Boosbeck",
    "lat": "54.54265",
    "lng": "-0.98139"
  },
  {
    "country": "GB",
    "name": "Bonnyrigg",
    "lat": "55.87329",
    "lng": "-3.1051"
  },
  {
    "country": "GB",
    "name": "Bonnybridge",
    "lat": "56.00152",
    "lng": "-3.8886"
  },
  {
    "country": "GB",
    "name": "Bonhill",
    "lat": "55.97944",
    "lng": "-4.5638"
  },
  {
    "country": "GB",
    "name": "Bo’ness",
    "lat": "56.01667",
    "lng": "-3.61667"
  },
  {
    "country": "GB",
    "name": "Bolton upon Dearne",
    "lat": "53.51667",
    "lng": "-1.31667"
  },
  {
    "country": "GB",
    "name": "Bolton le Sands",
    "lat": "54.09632",
    "lng": "-2.80017"
  },
  {
    "country": "GB",
    "name": "Bolton",
    "lat": "53.58333",
    "lng": "-2.43333"
  },
  {
    "country": "GB",
    "name": "Bolsover",
    "lat": "53.22846",
    "lng": "-1.29204"
  },
  {
    "country": "GB",
    "name": "Bollington",
    "lat": "53.29446",
    "lng": "-2.10963"
  },
  {
    "country": "GB",
    "name": "The Boldons",
    "lat": "54.9426",
    "lng": "-1.45349"
  },
  {
    "country": "GB",
    "name": "Bognor Regis",
    "lat": "50.78206",
    "lng": "-0.67978"
  },
  {
    "country": "GB",
    "name": "Bodmin",
    "lat": "50.47151",
    "lng": "-4.7243"
  },
  {
    "country": "GB",
    "name": "Bodenham",
    "lat": "52.15",
    "lng": "-2.68333"
  },
  {
    "country": "GB",
    "name": "Bodelwyddan",
    "lat": "53.26827",
    "lng": "-3.50078"
  },
  {
    "country": "GB",
    "name": "Bodedern",
    "lat": "53.29232",
    "lng": "-4.50303"
  },
  {
    "country": "GB",
    "name": "Boddam",
    "lat": "57.47076",
    "lng": "-1.78009"
  },
  {
    "country": "GB",
    "name": "Blyton",
    "lat": "53.44384",
    "lng": "-0.71753"
  },
  {
    "country": "GB",
    "name": "Blyth",
    "lat": "55.12708",
    "lng": "-1.50856"
  },
  {
    "country": "GB",
    "name": "Bluntisham",
    "lat": "52.35479",
    "lng": "0.00854"
  },
  {
    "country": "GB",
    "name": "Blunham",
    "lat": "52.14695",
    "lng": "-0.32178"
  },
  {
    "country": "GB",
    "name": "Bloxwich",
    "lat": "52.61806",
    "lng": "-2.00431"
  },
  {
    "country": "GB",
    "name": "Bloxham",
    "lat": "52.02039",
    "lng": "-1.37321"
  },
  {
    "country": "GB",
    "name": "Blockley",
    "lat": "52.0122",
    "lng": "-1.76268"
  },
  {
    "country": "GB",
    "name": "Blisworth",
    "lat": "52.17498",
    "lng": "-0.94131"
  },
  {
    "country": "GB",
    "name": "Blindley Heath",
    "lat": "51.19344",
    "lng": "-0.05116"
  },
  {
    "country": "GB",
    "name": "Blidworth",
    "lat": "53.09849",
    "lng": "-1.11689"
  },
  {
    "country": "GB",
    "name": "Blewbury",
    "lat": "51.5688",
    "lng": "-1.23261"
  },
  {
    "country": "GB",
    "name": "Bletchley",
    "lat": "51.99334",
    "lng": "-0.73471"
  },
  {
    "country": "GB",
    "name": "Bletchingley",
    "lat": "51.24059",
    "lng": "-0.10038"
  },
  {
    "country": "GB",
    "name": "Blean",
    "lat": "51.30679",
    "lng": "1.04301"
  },
  {
    "country": "GB",
    "name": "Bleadon",
    "lat": "51.30861",
    "lng": "-2.9475"
  },
  {
    "country": "GB",
    "name": "Blaydon-on-Tyne",
    "lat": "54.96461",
    "lng": "-1.71392"
  },
  {
    "country": "GB",
    "name": "Blandford Forum",
    "lat": "50.86073",
    "lng": "-2.16174"
  },
  {
    "country": "GB",
    "name": "Blairgowrie",
    "lat": "56.59157",
    "lng": "-3.34045"
  },
  {
    "country": "GB",
    "name": "Blagdon",
    "lat": "51.32688",
    "lng": "-2.71731"
  },
  {
    "country": "GB",
    "name": "Blaenavon",
    "lat": "51.77402",
    "lng": "-3.08537"
  },
  {
    "country": "GB",
    "name": "Blaenau-Ffestiniog",
    "lat": "52.99464",
    "lng": "-3.93697"
  },
  {
    "country": "GB",
    "name": "Blackwood",
    "lat": "55.66667",
    "lng": "-3.91667"
  },
  {
    "country": "GB",
    "name": "Blackwell",
    "lat": "53.11667",
    "lng": "-1.33333"
  },
  {
    "country": "GB",
    "name": "Blackrod",
    "lat": "53.59229",
    "lng": "-2.58026"
  },
  {
    "country": "GB",
    "name": "Blackpool",
    "lat": "53.81667",
    "lng": "-3.05"
  },
  {
    "country": "GB",
    "name": "Black Notley",
    "lat": "51.85301",
    "lng": "0.56846"
  },
  {
    "country": "GB",
    "name": "Blackburn",
    "lat": "57.20376",
    "lng": "-2.28842"
  },
  {
    "country": "GB",
    "name": "Blackburn",
    "lat": "55.86667",
    "lng": "-3.63333"
  },
  {
    "country": "GB",
    "name": "Blackburn",
    "lat": "53.75",
    "lng": "-2.48333"
  },
  {
    "country": "GB",
    "name": "Blaby",
    "lat": "52.57577",
    "lng": "-1.16403"
  },
  {
    "country": "GB",
    "name": "Bitton",
    "lat": "51.42479",
    "lng": "-2.45965"
  },
  {
    "country": "GB",
    "name": "Bishton",
    "lat": "51.58194",
    "lng": "-2.87833"
  },
  {
    "country": "GB",
    "name": "Bishopton",
    "lat": "55.90969",
    "lng": "-4.5056"
  },
  {
    "country": "GB",
    "name": "Bishopton",
    "lat": "54.58333",
    "lng": "-1.43333"
  },
  {
    "country": "GB",
    "name": "Bishopthorpe",
    "lat": "53.9191",
    "lng": "-1.09915"
  },
  {
    "country": "GB",
    "name": "Bishops Waltham",
    "lat": "50.95595",
    "lng": "-1.21476"
  },
  {
    "country": "GB",
    "name": "Bishopstrow",
    "lat": "51.19306",
    "lng": "-2.15528"
  },
  {
    "country": "GB",
    "name": "Bishopstone",
    "lat": "51.5513",
    "lng": "-1.64701"
  },
  {
    "country": "GB",
    "name": "Bishopstone",
    "lat": "51.03028",
    "lng": "-1.90269"
  },
  {
    "country": "GB",
    "name": "Bishopston",
    "lat": "51.5775",
    "lng": "-4.04806"
  },
  {
    "country": "GB",
    "name": "Bishopstoke",
    "lat": "50.96643",
    "lng": "-1.32832"
  },
  {
    "country": "GB",
    "name": "Bishopsteignton",
    "lat": "50.55193",
    "lng": "-3.53852"
  },
  {
    "country": "GB",
    "name": "Bishops Stortford",
    "lat": "51.87113",
    "lng": "0.15868"
  },
  {
    "country": "GB",
    "name": "Bishops Lydeard",
    "lat": "51.05917",
    "lng": "-3.18778"
  },
  {
    "country": "GB",
    "name": "Bishops Cleeve",
    "lat": "51.94749",
    "lng": "-2.06277"
  },
  {
    "country": "GB",
    "name": "Bishop's Castle",
    "lat": "52.49208",
    "lng": "-3.0021"
  },
  {
    "country": "GB",
    "name": "Bishop Middleham",
    "lat": "54.67778",
    "lng": "-1.48826"
  },
  {
    "country": "GB",
    "name": "Bishopbriggs",
    "lat": "55.90669",
    "lng": "-4.21869"
  },
  {
    "country": "GB",
    "name": "Bishop Auckland",
    "lat": "54.65554",
    "lng": "-1.67706"
  },
  {
    "country": "GB",
    "name": "Bisham",
    "lat": "51.56104",
    "lng": "-0.77788"
  },
  {
    "country": "GB",
    "name": "Birtley",
    "lat": "55.08333",
    "lng": "-2.18333"
  },
  {
    "country": "GB",
    "name": "Birmingham",
    "lat": "52.48142",
    "lng": "-1.89983"
  },
  {
    "country": "GB",
    "name": "Birkenhead",
    "lat": "53.39337",
    "lng": "-3.01479"
  },
  {
    "country": "GB",
    "name": "Birdwell",
    "lat": "53.51398",
    "lng": "-1.47929"
  },
  {
    "country": "GB",
    "name": "Birdham",
    "lat": "50.79606",
    "lng": "-0.83067"
  },
  {
    "country": "GB",
    "name": "Bircotes",
    "lat": "53.41933",
    "lng": "-1.04905"
  },
  {
    "country": "GB",
    "name": "Birchington-on-Sea",
    "lat": "51.37575",
    "lng": "1.3048"
  },
  {
    "country": "GB",
    "name": "Bingley",
    "lat": "53.84861",
    "lng": "-1.83857"
  },
  {
    "country": "GB",
    "name": "Bingham",
    "lat": "52.94978",
    "lng": "-0.95907"
  },
  {
    "country": "GB",
    "name": "Binfield",
    "lat": "51.43159",
    "lng": "-0.7881"
  },
  {
    "country": "GB",
    "name": "Bilston",
    "lat": "52.56568",
    "lng": "-2.07367"
  },
  {
    "country": "GB",
    "name": "Bilsthorpe",
    "lat": "53.14024",
    "lng": "-1.03392"
  },
  {
    "country": "GB",
    "name": "Billingshurst",
    "lat": "51.02312",
    "lng": "-0.45359"
  },
  {
    "country": "GB",
    "name": "Billinghay",
    "lat": "53.07959",
    "lng": "-0.27689"
  },
  {
    "country": "GB",
    "name": "Billingham",
    "lat": "54.58881",
    "lng": "-1.29034"
  },
  {
    "country": "GB",
    "name": "Billinge",
    "lat": "53.49795",
    "lng": "-2.7081"
  },
  {
    "country": "GB",
    "name": "Billingborough",
    "lat": "52.89384",
    "lng": "-0.34186"
  },
  {
    "country": "GB",
    "name": "Billericay",
    "lat": "51.62867",
    "lng": "0.41963"
  },
  {
    "country": "GB",
    "name": "Bildeston",
    "lat": "52.10658",
    "lng": "0.90916"
  },
  {
    "country": "GB",
    "name": "Biggleswade",
    "lat": "52.08652",
    "lng": "-0.26493"
  },
  {
    "country": "GB",
    "name": "Biggin Hill",
    "lat": "51.31329",
    "lng": "0.03433"
  },
  {
    "country": "GB",
    "name": "Biggar",
    "lat": "55.62297",
    "lng": "-3.52455"
  },
  {
    "country": "GB",
    "name": "Bidford-on-Avon",
    "lat": "52.16964",
    "lng": "-1.85955"
  },
  {
    "country": "GB",
    "name": "Bideford",
    "lat": "51.01678",
    "lng": "-4.20832"
  },
  {
    "country": "GB",
    "name": "Biddulph",
    "lat": "53.11724",
    "lng": "-2.17584"
  },
  {
    "country": "GB",
    "name": "Biddestone",
    "lat": "51.46083",
    "lng": "-2.19833"
  },
  {
    "country": "GB",
    "name": "Biddenham",
    "lat": "52.13847",
    "lng": "-0.50687"
  },
  {
    "country": "GB",
    "name": "Biddenden",
    "lat": "51.11489",
    "lng": "0.63819"
  },
  {
    "country": "GB",
    "name": "Bicton",
    "lat": "52.72829",
    "lng": "-2.81649"
  },
  {
    "country": "GB",
    "name": "Bicknacre",
    "lat": "51.69403",
    "lng": "0.58519"
  },
  {
    "country": "GB",
    "name": "Bickley",
    "lat": "53.03333",
    "lng": "-2.7"
  },
  {
    "country": "GB",
    "name": "Bickenhill",
    "lat": "52.43974",
    "lng": "-1.72545"
  },
  {
    "country": "GB",
    "name": "Bicester",
    "lat": "51.89998",
    "lng": "-1.15357"
  },
  {
    "country": "GB",
    "name": "Bexleyheath",
    "lat": "51.46291",
    "lng": "0.13943"
  },
  {
    "country": "GB",
    "name": "Bexley",
    "lat": "51.44162",
    "lng": "0.14866"
  },
  {
    "country": "GB",
    "name": "Bexhill-on-Sea",
    "lat": "50.85023",
    "lng": "0.47095"
  },
  {
    "country": "GB",
    "name": "Bewdley",
    "lat": "52.3757",
    "lng": "-2.31833"
  },
  {
    "country": "GB",
    "name": "Beverley",
    "lat": "53.84587",
    "lng": "-0.42332"
  },
  {
    "country": "GB",
    "name": "Betws-y-Coed",
    "lat": "53.09382",
    "lng": "-3.80668"
  },
  {
    "country": "GB",
    "name": "Betws",
    "lat": "51.56917",
    "lng": "-3.58833"
  },
  {
    "country": "GB",
    "name": "Betley",
    "lat": "53.03439",
    "lng": "-2.36865"
  },
  {
    "country": "GB",
    "name": "Bethesda",
    "lat": "53.1815",
    "lng": "-4.05828"
  },
  {
    "country": "GB",
    "name": "Berwick-Upon-Tweed",
    "lat": "55.76536",
    "lng": "-2.01186"
  },
  {
    "country": "GB",
    "name": "Berrington",
    "lat": "52.65",
    "lng": "-2.7"
  },
  {
    "country": "GB",
    "name": "Berkswell",
    "lat": "52.40902",
    "lng": "-1.6422"
  },
  {
    "country": "GB",
    "name": "Berkhamsted",
    "lat": "51.7604",
    "lng": "-0.56528"
  },
  {
    "country": "GB",
    "name": "Berkeley",
    "lat": "51.69111",
    "lng": "-2.45917"
  },
  {
    "country": "GB",
    "name": "Bere Regis",
    "lat": "50.75371",
    "lng": "-2.21553"
  },
  {
    "country": "GB",
    "name": "Bere Alston",
    "lat": "50.48233",
    "lng": "-4.19034"
  },
  {
    "country": "GB",
    "name": "Bentley",
    "lat": "53.53333",
    "lng": "-1.15"
  },
  {
    "country": "GB",
    "name": "Benson",
    "lat": "51.62073",
    "lng": "-1.10979"
  },
  {
    "country": "GB",
    "name": "Bempton",
    "lat": "54.13036",
    "lng": "-0.17853"
  },
  {
    "country": "GB",
    "name": "Bembridge",
    "lat": "50.68634",
    "lng": "-1.08275"
  },
  {
    "country": "GB",
    "name": "Belvedere",
    "lat": "51.49114",
    "lng": "0.15136"
  },
  {
    "country": "GB",
    "name": "Belton",
    "lat": "53.55",
    "lng": "-0.81667"
  },
  {
    "country": "GB",
    "name": "Belper",
    "lat": "53.0233",
    "lng": "-1.48119"
  },
  {
    "country": "GB",
    "name": "Bellshill",
    "lat": "55.81667",
    "lng": "-4.01667"
  },
  {
    "country": "GB",
    "name": "Bellingham",
    "lat": "55.14464",
    "lng": "-2.25383"
  },
  {
    "country": "GB",
    "name": "Bellaghy",
    "lat": "54.8087",
    "lng": "-6.51918"
  },
  {
    "country": "GB",
    "name": "Belford",
    "lat": "55.6",
    "lng": "-1.83333"
  },
  {
    "country": "GB",
    "name": "Belfast",
    "lat": "54.59682",
    "lng": "-5.92541"
  },
  {
    "country": "GB",
    "name": "Belbroughton",
    "lat": "52.39177",
    "lng": "-2.11884"
  },
  {
    "country": "GB",
    "name": "Beith",
    "lat": "55.74923",
    "lng": "-4.6368"
  },
  {
    "country": "GB",
    "name": "Beighton",
    "lat": "53.33333",
    "lng": "-1.33333"
  },
  {
    "country": "GB",
    "name": "Beeston",
    "lat": "53.11667",
    "lng": "-2.68333"
  },
  {
    "country": "GB",
    "name": "Beeford",
    "lat": "53.96999",
    "lng": "-0.28913"
  },
  {
    "country": "GB",
    "name": "Bedworth",
    "lat": "52.4791",
    "lng": "-1.46909"
  },
  {
    "country": "GB",
    "name": "Bedwas",
    "lat": "51.59183",
    "lng": "-3.19886"
  },
  {
    "country": "GB",
    "name": "Bedlington",
    "lat": "55.13061",
    "lng": "-1.59319"
  },
  {
    "country": "GB",
    "name": "Bedford",
    "lat": "52.13459",
    "lng": "-0.46632"
  },
  {
    "country": "GB",
    "name": "Bedale",
    "lat": "54.28811",
    "lng": "-1.59181"
  },
  {
    "country": "GB",
    "name": "Beckingham",
    "lat": "53.4",
    "lng": "-0.83333"
  },
  {
    "country": "GB",
    "name": "Beckenham",
    "lat": "51.40878",
    "lng": "-0.02526"
  },
  {
    "country": "GB",
    "name": "Beccles",
    "lat": "52.45936",
    "lng": "1.56465"
  },
  {
    "country": "GB",
    "name": "Bebington",
    "lat": "53.35",
    "lng": "-3.01667"
  },
  {
    "country": "GB",
    "name": "Beaumaris",
    "lat": "53.26315",
    "lng": "-4.09233"
  },
  {
    "country": "GB",
    "name": "Beauly",
    "lat": "57.48345",
    "lng": "-4.46144"
  },
  {
    "country": "GB",
    "name": "Bearsden",
    "lat": "55.91536",
    "lng": "-4.33279"
  },
  {
    "country": "GB",
    "name": "Beaminster",
    "lat": "50.809",
    "lng": "-2.7391"
  },
  {
    "country": "GB",
    "name": "Beadnell",
    "lat": "55.5567",
    "lng": "-1.6325"
  },
  {
    "country": "GB",
    "name": "Beaconsfield",
    "lat": "51.61219",
    "lng": "-0.64732"
  },
  {
    "country": "GB",
    "name": "Bayston Hill",
    "lat": "52.6755",
    "lng": "-2.76156"
  },
  {
    "country": "GB",
    "name": "Bawtry",
    "lat": "53.43146",
    "lng": "-1.01878"
  },
  {
    "country": "GB",
    "name": "Battlesden",
    "lat": "51.94814",
    "lng": "-0.59564"
  },
  {
    "country": "GB",
    "name": "Battle",
    "lat": "50.91732",
    "lng": "0.48417"
  },
  {
    "country": "GB",
    "name": "Batley",
    "lat": "53.70291",
    "lng": "-1.6337"
  },
  {
    "country": "GB",
    "name": "Bathgate",
    "lat": "55.90204",
    "lng": "-3.64398"
  },
  {
    "country": "GB",
    "name": "Bathford",
    "lat": "51.4002",
    "lng": "-2.30161"
  },
  {
    "country": "GB",
    "name": "Bath",
    "lat": "51.3751",
    "lng": "-2.36172"
  },
  {
    "country": "GB",
    "name": "Baston",
    "lat": "52.71311",
    "lng": "-0.35173"
  },
  {
    "country": "GB",
    "name": "Bassingham",
    "lat": "53.12881",
    "lng": "-0.63765"
  },
  {
    "country": "GB",
    "name": "Bassingbourn",
    "lat": "52.07821",
    "lng": "-0.0539"
  },
  {
    "country": "GB",
    "name": "Baslow",
    "lat": "53.24811",
    "lng": "-1.62246"
  },
  {
    "country": "GB",
    "name": "Basingstoke",
    "lat": "51.26249",
    "lng": "-1.08708"
  },
  {
    "country": "GB",
    "name": "Old Basing",
    "lat": "51.26667",
    "lng": "-1.03333"
  },
  {
    "country": "GB",
    "name": "Basildon",
    "lat": "51.56844",
    "lng": "0.45782"
  },
  {
    "country": "GB",
    "name": "Upper Basildon",
    "lat": "51.48165",
    "lng": "-1.14075"
  },
  {
    "country": "GB",
    "name": "Basford",
    "lat": "52.96667",
    "lng": "-1.18333"
  },
  {
    "country": "GB",
    "name": "Baschurch",
    "lat": "52.78848",
    "lng": "-2.85284"
  },
  {
    "country": "GB",
    "name": "Barton upon Humber",
    "lat": "53.68915",
    "lng": "-0.44377"
  },
  {
    "country": "GB",
    "name": "Barton under Needwood",
    "lat": "52.76268",
    "lng": "-1.724"
  },
  {
    "country": "GB",
    "name": "Barton-le-Clay",
    "lat": "51.96598",
    "lng": "-0.42731"
  },
  {
    "country": "GB",
    "name": "Barston",
    "lat": "52.39991",
    "lng": "-1.6955"
  },
  {
    "country": "GB",
    "name": "Barry",
    "lat": "51.39979",
    "lng": "-3.2838"
  },
  {
    "country": "GB",
    "name": "Barrow upon Soar",
    "lat": "52.75178",
    "lng": "-1.14601"
  },
  {
    "country": "GB",
    "name": "Barrow upon Humber",
    "lat": "53.6755",
    "lng": "-0.38062"
  },
  {
    "country": "GB",
    "name": "Barrow in Furness",
    "lat": "54.11094",
    "lng": "-3.22758"
  },
  {
    "country": "GB",
    "name": "Barrowford",
    "lat": "53.8465",
    "lng": "-2.21838"
  },
  {
    "country": "GB",
    "name": "Barrowby",
    "lat": "52.91636",
    "lng": "-0.69094"
  },
  {
    "country": "GB",
    "name": "Barrhead",
    "lat": "55.79916",
    "lng": "-4.39285"
  },
  {
    "country": "GB",
    "name": "Barnt Green",
    "lat": "52.35902",
    "lng": "-2.00715"
  },
  {
    "country": "GB",
    "name": "Barnstaple",
    "lat": "51.08022",
    "lng": "-4.05808"
  },
  {
    "country": "GB",
    "name": "Barnsley",
    "lat": "53.55",
    "lng": "-1.48333"
  },
  {
    "country": "GB",
    "name": "Barnoldswick",
    "lat": "53.91711",
    "lng": "-2.18705"
  },
  {
    "country": "GB",
    "name": "Barningham",
    "lat": "54.48809",
    "lng": "-1.87008"
  },
  {
    "country": "GB",
    "name": "Barnham",
    "lat": "50.8312",
    "lng": "-0.63789"
  },
  {
    "country": "GB",
    "name": "Barnetby le Wold",
    "lat": "53.5748",
    "lng": "-0.40607"
  },
  {
    "country": "GB",
    "name": "Barnet",
    "lat": "51.65",
    "lng": "-0.2"
  },
  {
    "country": "GB",
    "name": "Barnburgh",
    "lat": "53.52408",
    "lng": "-1.273"
  },
  {
    "country": "GB",
    "name": "Barnard Castle",
    "lat": "54.5415",
    "lng": "-1.919"
  },
  {
    "country": "GB",
    "name": "Barnack",
    "lat": "52.63181",
    "lng": "-0.40821"
  },
  {
    "country": "GB",
    "name": "Barmston",
    "lat": "54.01412",
    "lng": "-0.22857"
  },
  {
    "country": "GB",
    "name": "Barmouth",
    "lat": "52.72377",
    "lng": "-4.05748"
  },
  {
    "country": "GB",
    "name": "Barmby on the Marsh",
    "lat": "53.74896",
    "lng": "-0.95607"
  },
  {
    "country": "GB",
    "name": "Barlestone",
    "lat": "52.64718",
    "lng": "-1.37013"
  },
  {
    "country": "GB",
    "name": "Barlborough",
    "lat": "53.28795",
    "lng": "-1.28815"
  },
  {
    "country": "GB",
    "name": "Barlaston",
    "lat": "52.942",
    "lng": "-2.1705"
  },
  {
    "country": "GB",
    "name": "Barkisland",
    "lat": "53.67614",
    "lng": "-1.9184"
  },
  {
    "country": "GB",
    "name": "Barking",
    "lat": "51.53333",
    "lng": "0.08333"
  },
  {
    "country": "GB",
    "name": "Barkham",
    "lat": "51.39805",
    "lng": "-0.8759"
  },
  {
    "country": "GB",
    "name": "Bargoed",
    "lat": "51.68333",
    "lng": "-3.23333"
  },
  {
    "country": "GB",
    "name": "Bardsey",
    "lat": "53.88492",
    "lng": "-1.44539"
  },
  {
    "country": "GB",
    "name": "Bardon Mill",
    "lat": "54.97547",
    "lng": "-2.34309"
  },
  {
    "country": "GB",
    "name": "Bardney",
    "lat": "53.21005",
    "lng": "-0.32371"
  },
  {
    "country": "GB",
    "name": "Banwell",
    "lat": "51.32894",
    "lng": "-2.86914"
  },
  {
    "country": "GB",
    "name": "Banstead",
    "lat": "51.32233",
    "lng": "-0.20685"
  },
  {
    "country": "GB",
    "name": "Bannockburn",
    "lat": "56.08978",
    "lng": "-3.91092"
  },
  {
    "country": "GB",
    "name": "Banks",
    "lat": "53.68333",
    "lng": "-2.91667"
  },
  {
    "country": "GB",
    "name": "Bankfoot",
    "lat": "56.50058",
    "lng": "-3.51707"
  },
  {
    "country": "GB",
    "name": "Banham",
    "lat": "52.4524",
    "lng": "1.03683"
  },
  {
    "country": "GB",
    "name": "Bangor",
    "lat": "54.65338",
    "lng": "-5.66895"
  },
  {
    "country": "GB",
    "name": "Bangor",
    "lat": "53.22752",
    "lng": "-4.12936"
  },
  {
    "country": "GB",
    "name": "Banff",
    "lat": "57.66477",
    "lng": "-2.52964"
  },
  {
    "country": "GB",
    "name": "Banchory",
    "lat": "57.05168",
    "lng": "-2.48824"
  },
  {
    "country": "GB",
    "name": "Banbury",
    "lat": "52.0632",
    "lng": "-1.34222"
  },
  {
    "country": "GB",
    "name": "Banbridge",
    "lat": "54.35",
    "lng": "-6.28333"
  },
  {
    "country": "GB",
    "name": "Bampton",
    "lat": "51.72634",
    "lng": "-1.54547"
  },
  {
    "country": "GB",
    "name": "Bamburgh",
    "lat": "55.60652",
    "lng": "-1.71704"
  },
  {
    "country": "GB",
    "name": "Balsham",
    "lat": "52.13238",
    "lng": "0.31586"
  },
  {
    "country": "GB",
    "name": "Balmullo",
    "lat": "56.37694",
    "lng": "-2.9294"
  },
  {
    "country": "GB",
    "name": "Balmedie",
    "lat": "57.25052",
    "lng": "-2.06163"
  },
  {
    "country": "GB",
    "name": "Ballywalter",
    "lat": "54.54329",
    "lng": "-5.48475"
  },
  {
    "country": "GB",
    "name": "Ballynahinch",
    "lat": "54.4023",
    "lng": "-5.89717"
  },
  {
    "country": "GB",
    "name": "Ballymoney",
    "lat": "55.0708",
    "lng": "-6.51009"
  },
  {
    "country": "GB",
    "name": "Ballymena",
    "lat": "54.86357",
    "lng": "-6.27628"
  },
  {
    "country": "GB",
    "name": "Ballykelly",
    "lat": "55.04425",
    "lng": "-7.01855"
  },
  {
    "country": "GB",
    "name": "Ballygowan",
    "lat": "54.50165",
    "lng": "-5.79168"
  },
  {
    "country": "GB",
    "name": "Ballyclare",
    "lat": "54.75089",
    "lng": "-5.99944"
  },
  {
    "country": "GB",
    "name": "Ballycastle",
    "lat": "55.20444",
    "lng": "-6.24298"
  },
  {
    "country": "GB",
    "name": "Balloch",
    "lat": "56",
    "lng": "-4.58333"
  },
  {
    "country": "GB",
    "name": "Ballingry",
    "lat": "56.16392",
    "lng": "-3.32841"
  },
  {
    "country": "GB",
    "name": "Ballinamallard",
    "lat": "54.4",
    "lng": "-7.58333"
  },
  {
    "country": "GB",
    "name": "Ballater",
    "lat": "57.05011",
    "lng": "-3.03798"
  },
  {
    "country": "GB",
    "name": "Balintore",
    "lat": "57.75564",
    "lng": "-3.91232"
  },
  {
    "country": "GB",
    "name": "Balfron",
    "lat": "56.06809",
    "lng": "-4.33559"
  },
  {
    "country": "GB",
    "name": "Balerno",
    "lat": "55.88437",
    "lng": "-3.33975"
  },
  {
    "country": "GB",
    "name": "Baldock",
    "lat": "51.98781",
    "lng": "-0.18835"
  },
  {
    "country": "GB",
    "name": "Balcombe",
    "lat": "51.05726",
    "lng": "-0.1345"
  },
  {
    "country": "GB",
    "name": "Bala",
    "lat": "52.91111",
    "lng": "-3.59722"
  },
  {
    "country": "GB",
    "name": "Bakewell",
    "lat": "53.21338",
    "lng": "-1.67481"
  },
  {
    "country": "GB",
    "name": "Bainton",
    "lat": "53.95",
    "lng": "-0.53333"
  },
  {
    "country": "GB",
    "name": "Baildon",
    "lat": "53.84711",
    "lng": "-1.78785"
  },
  {
    "country": "GB",
    "name": "Bagworth",
    "lat": "52.67265",
    "lng": "-1.34274"
  },
  {
    "country": "GB",
    "name": "Bagshot",
    "lat": "51.36069",
    "lng": "-0.68802"
  },
  {
    "country": "GB",
    "name": "Bagillt",
    "lat": "53.2654",
    "lng": "-3.16551"
  },
  {
    "country": "GB",
    "name": "Badsworth",
    "lat": "53.62876",
    "lng": "-1.30128"
  },
  {
    "country": "GB",
    "name": "Badsey",
    "lat": "52.08819",
    "lng": "-1.89925"
  },
  {
    "country": "GB",
    "name": "Bacup",
    "lat": "53.70336",
    "lng": "-2.2007"
  },
  {
    "country": "GB",
    "name": "Bacton",
    "lat": "52.26667",
    "lng": "1.01667"
  },
  {
    "country": "GB",
    "name": "Bacton",
    "lat": "51.98333",
    "lng": "-2.91667"
  },
  {
    "country": "GB",
    "name": "Backworth",
    "lat": "55.04229",
    "lng": "-1.52779"
  },
  {
    "country": "GB",
    "name": "Ayr",
    "lat": "55.46273",
    "lng": "-4.63393"
  },
  {
    "country": "GB",
    "name": "Aylsham",
    "lat": "52.79672",
    "lng": "1.25107"
  },
  {
    "country": "GB",
    "name": "Aylesford",
    "lat": "51.30374",
    "lng": "0.47936"
  },
  {
    "country": "GB",
    "name": "Aylesbury",
    "lat": "51.81665",
    "lng": "-0.81458"
  },
  {
    "country": "GB",
    "name": "Axminster",
    "lat": "50.78259",
    "lng": "-2.99787"
  },
  {
    "country": "GB",
    "name": "Axbridge",
    "lat": "51.28466",
    "lng": "-2.82078"
  },
  {
    "country": "GB",
    "name": "Awsworth",
    "lat": "52.98912",
    "lng": "-1.28354"
  },
  {
    "country": "GB",
    "name": "Aviemore",
    "lat": "57.19553",
    "lng": "-3.8259"
  },
  {
    "country": "GB",
    "name": "Avening",
    "lat": "51.6801",
    "lng": "-2.16903"
  },
  {
    "country": "GB",
    "name": "Aveley",
    "lat": "51.49987",
    "lng": "0.25174"
  },
  {
    "country": "GB",
    "name": "Avebury",
    "lat": "51.41667",
    "lng": "-1.86667"
  },
  {
    "country": "GB",
    "name": "Audley",
    "lat": "53.05",
    "lng": "-2.3"
  },
  {
    "country": "GB",
    "name": "Audlem",
    "lat": "52.98956",
    "lng": "-2.50706"
  },
  {
    "country": "GB",
    "name": "Auckley",
    "lat": "53.50386",
    "lng": "-1.02174"
  },
  {
    "country": "GB",
    "name": "Auchtermuchty",
    "lat": "56.29158",
    "lng": "-3.23428"
  },
  {
    "country": "GB",
    "name": "Auchterarder",
    "lat": "56.29612",
    "lng": "-3.70692"
  },
  {
    "country": "GB",
    "name": "Auchinleck",
    "lat": "55.47157",
    "lng": "-4.29337"
  },
  {
    "country": "GB",
    "name": "Atworth",
    "lat": "51.39234",
    "lng": "-2.19297"
  },
  {
    "country": "GB",
    "name": "Atwick",
    "lat": "53.94012",
    "lng": "-0.189"
  },
  {
    "country": "GB",
    "name": "Attleborough",
    "lat": "52.51779",
    "lng": "1.01572"
  },
  {
    "country": "GB",
    "name": "Attleborough",
    "lat": "52.51293",
    "lng": "-1.45487"
  },
  {
    "country": "GB",
    "name": "Atherton",
    "lat": "53.52371",
    "lng": "-2.49354"
  },
  {
    "country": "GB",
    "name": "Atherstone",
    "lat": "52.57536",
    "lng": "-1.54693"
  },
  {
    "country": "GB",
    "name": "Astwood Bank",
    "lat": "52.25993",
    "lng": "-1.93754"
  },
  {
    "country": "GB",
    "name": "Astwood",
    "lat": "52.1",
    "lng": "-0.6"
  },
  {
    "country": "GB",
    "name": "Astwick",
    "lat": "52.0323",
    "lng": "-0.23127"
  },
  {
    "country": "GB",
    "name": "Aston Clinton",
    "lat": "51.8002",
    "lng": "-0.7254"
  },
  {
    "country": "GB",
    "name": "Aston",
    "lat": "52.5",
    "lng": "-1.88333"
  },
  {
    "country": "GB",
    "name": "Astley",
    "lat": "52.76667",
    "lng": "-2.7"
  },
  {
    "country": "GB",
    "name": "Aspley Guise",
    "lat": "52.01199",
    "lng": "-0.633"
  },
  {
    "country": "GB",
    "name": "Aspatria",
    "lat": "54.76574",
    "lng": "-3.32783"
  },
  {
    "country": "GB",
    "name": "Aslockton",
    "lat": "52.95299",
    "lng": "-0.897"
  },
  {
    "country": "GB",
    "name": "Askham Richard",
    "lat": "53.92491",
    "lng": "-1.18481"
  },
  {
    "country": "GB",
    "name": "Askern",
    "lat": "53.61639",
    "lng": "-1.15237"
  },
  {
    "country": "GB",
    "name": "Askam in Furness",
    "lat": "54.18718",
    "lng": "-3.20467"
  },
  {
    "country": "GB",
    "name": "Ashwell",
    "lat": "52.71298",
    "lng": "-0.71969"
  },
  {
    "country": "GB",
    "name": "Ashwell",
    "lat": "52.03866",
    "lng": "-0.15398"
  },
  {
    "country": "GB",
    "name": "Ashurst",
    "lat": "50.93236",
    "lng": "-0.32375"
  },
  {
    "country": "GB",
    "name": "Ashton-under-Lyne",
    "lat": "53.48876",
    "lng": "-2.0989"
  },
  {
    "country": "GB",
    "name": "Ashton Keynes",
    "lat": "51.64521",
    "lng": "-1.93232"
  },
  {
    "country": "GB",
    "name": "Ashton in Makerfield",
    "lat": "53.48333",
    "lng": "-2.65"
  },
  {
    "country": "GB",
    "name": "Ashtead",
    "lat": "51.30873",
    "lng": "-0.29972"
  },
  {
    "country": "GB",
    "name": "Ashley",
    "lat": "53.35",
    "lng": "-2.33333"
  },
  {
    "country": "GB",
    "name": "Ashington",
    "lat": "55.17719",
    "lng": "-1.56412"
  },
  {
    "country": "GB",
    "name": "Ashington",
    "lat": "50.93312",
    "lng": "-0.39087"
  },
  {
    "country": "GB",
    "name": "Ashill",
    "lat": "52.60435",
    "lng": "0.78574"
  },
  {
    "country": "GB",
    "name": "Ashford",
    "lat": "51.43173",
    "lng": "-0.45761"
  },
  {
    "country": "GB",
    "name": "Ashford",
    "lat": "51.14648",
    "lng": "0.87376"
  },
  {
    "country": "GB",
    "name": "Ashby de la Zouch",
    "lat": "52.74632",
    "lng": "-1.4732"
  },
  {
    "country": "GB",
    "name": "Ashburton",
    "lat": "50.51559",
    "lng": "-3.75572"
  },
  {
    "country": "GB",
    "name": "Ashbourne",
    "lat": "53.01667",
    "lng": "-1.73333"
  },
  {
    "country": "GB",
    "name": "Ash",
    "lat": "52.95",
    "lng": "-2.65"
  },
  {
    "country": "GB",
    "name": "Ascot",
    "lat": "51.41082",
    "lng": "-0.6748"
  },
  {
    "country": "GB",
    "name": "Arundel",
    "lat": "50.85423",
    "lng": "-0.55393"
  },
  {
    "country": "GB",
    "name": "Arnside",
    "lat": "54.20179",
    "lng": "-2.83374"
  },
  {
    "country": "GB",
    "name": "Arnold",
    "lat": "53",
    "lng": "-1.13333"
  },
  {
    "country": "GB",
    "name": "Armthorpe",
    "lat": "53.53518",
    "lng": "-1.05341"
  },
  {
    "country": "GB",
    "name": "Armitage",
    "lat": "52.74193",
    "lng": "-1.88266"
  },
  {
    "country": "GB",
    "name": "Armagh",
    "lat": "54.35",
    "lng": "-6.66667"
  },
  {
    "country": "GB",
    "name": "Armadale",
    "lat": "55.88333",
    "lng": "-3.7"
  },
  {
    "country": "GB",
    "name": "Arlesey",
    "lat": "52.00713",
    "lng": "-0.26565"
  },
  {
    "country": "GB",
    "name": "Ardrossan",
    "lat": "55.65018",
    "lng": "-4.80659"
  },
  {
    "country": "GB",
    "name": "Ardrishaig",
    "lat": "56.01566",
    "lng": "-5.44806"
  },
  {
    "country": "GB",
    "name": "Ardingly",
    "lat": "51.04865",
    "lng": "-0.07716"
  },
  {
    "country": "GB",
    "name": "Ardglass",
    "lat": "54.26312",
    "lng": "-5.60981"
  },
  {
    "country": "GB",
    "name": "Ardersier",
    "lat": "57.56681",
    "lng": "-4.03784"
  },
  {
    "country": "GB",
    "name": "Arbroath",
    "lat": "56.56317",
    "lng": "-2.58736"
  },
  {
    "country": "GB",
    "name": "Appley Bridge",
    "lat": "53.57781",
    "lng": "-2.7209"
  },
  {
    "country": "GB",
    "name": "Appleton",
    "lat": "53.3524",
    "lng": "-2.57183"
  },
  {
    "country": "GB",
    "name": "Appledore",
    "lat": "51.05",
    "lng": "-4.2"
  },
  {
    "country": "GB",
    "name": "Appleby",
    "lat": "53.62198",
    "lng": "-0.56612"
  },
  {
    "country": "GB",
    "name": "Antrim",
    "lat": "54.7",
    "lng": "-6.2"
  },
  {
    "country": "GB",
    "name": "Anstruther",
    "lat": "56.22315",
    "lng": "-2.70229"
  },
  {
    "country": "GB",
    "name": "Anstey",
    "lat": "52.67368",
    "lng": "-1.18841"
  },
  {
    "country": "GB",
    "name": "Ansty",
    "lat": "51.03639",
    "lng": "-2.06389"
  },
  {
    "country": "GB",
    "name": "Annfield Plain",
    "lat": "54.85749",
    "lng": "-1.73827"
  },
  {
    "country": "GB",
    "name": "Annan",
    "lat": "54.98839",
    "lng": "-3.25647"
  },
  {
    "country": "GB",
    "name": "Annalong",
    "lat": "54.10823",
    "lng": "-5.89966"
  },
  {
    "country": "GB",
    "name": "Annahilt",
    "lat": "54.43333",
    "lng": "-6"
  },
  {
    "country": "GB",
    "name": "Andover",
    "lat": "51.21135",
    "lng": "-1.49393"
  },
  {
    "country": "GB",
    "name": "Ancroft",
    "lat": "55.7",
    "lng": "-2"
  },
  {
    "country": "GB",
    "name": "Ancaster",
    "lat": "52.98276",
    "lng": "-0.53593"
  },
  {
    "country": "GB",
    "name": "Ampthill",
    "lat": "52.02694",
    "lng": "-0.49567"
  },
  {
    "country": "GB",
    "name": "Ammanford",
    "lat": "51.79279",
    "lng": "-3.98833"
  },
  {
    "country": "GB",
    "name": "Amlwch",
    "lat": "53.40986",
    "lng": "-4.34712"
  },
  {
    "country": "GB",
    "name": "Amesbury",
    "lat": "51.17509",
    "lng": "-1.78064"
  },
  {
    "country": "GB",
    "name": "Amersham",
    "lat": "51.66667",
    "lng": "-0.61667"
  },
  {
    "country": "GB",
    "name": "Ambrosden",
    "lat": "51.87087",
    "lng": "-1.12129"
  },
  {
    "country": "GB",
    "name": "Ambleside",
    "lat": "54.43261",
    "lng": "-2.96167"
  },
  {
    "country": "GB",
    "name": "Amble",
    "lat": "55.33333",
    "lng": "-1.58333"
  },
  {
    "country": "GB",
    "name": "Alyth",
    "lat": "56.62209",
    "lng": "-3.23005"
  },
  {
    "country": "GB",
    "name": "Alveston",
    "lat": "51.58806",
    "lng": "-2.53139"
  },
  {
    "country": "GB",
    "name": "Alveley",
    "lat": "52.45709",
    "lng": "-2.35434"
  },
  {
    "country": "GB",
    "name": "Alvechurch",
    "lat": "52.35173",
    "lng": "-1.96531"
  },
  {
    "country": "GB",
    "name": "Alva",
    "lat": "56.15284",
    "lng": "-3.80505"
  },
  {
    "country": "GB",
    "name": "Altrincham",
    "lat": "53.38752",
    "lng": "-2.34848"
  },
  {
    "country": "GB",
    "name": "Alton",
    "lat": "51.14931",
    "lng": "-0.97469"
  },
  {
    "country": "GB",
    "name": "Althorne",
    "lat": "51.65722",
    "lng": "0.76085"
  },
  {
    "country": "GB",
    "name": "Alston",
    "lat": "54.809",
    "lng": "-2.43931"
  },
  {
    "country": "GB",
    "name": "Alsager",
    "lat": "53.09617",
    "lng": "-2.30649"
  },
  {
    "country": "GB",
    "name": "Alrewas",
    "lat": "52.73278",
    "lng": "-1.74968"
  },
  {
    "country": "GB",
    "name": "Alresford",
    "lat": "51.85389",
    "lng": "1.00203"
  },
  {
    "country": "GB",
    "name": "Alnwick",
    "lat": "55.41318",
    "lng": "-1.70563"
  },
  {
    "country": "GB",
    "name": "Alnmouth",
    "lat": "55.4",
    "lng": "-1.6"
  },
  {
    "country": "GB",
    "name": "Alness",
    "lat": "57.69596",
    "lng": "-4.2551"
  },
  {
    "country": "GB",
    "name": "Almondsbury",
    "lat": "51.55407",
    "lng": "-2.57114"
  },
  {
    "country": "GB",
    "name": "Almondbank",
    "lat": "56.41729",
    "lng": "-3.51733"
  },
  {
    "country": "GB",
    "name": "Alloa",
    "lat": "56.11586",
    "lng": "-3.78997"
  },
  {
    "country": "GB",
    "name": "Allington",
    "lat": "51.15",
    "lng": "-1.7"
  },
  {
    "country": "GB",
    "name": "Allhallows",
    "lat": "51.46866",
    "lng": "0.63686"
  },
  {
    "country": "GB",
    "name": "Allanton",
    "lat": "55.78333",
    "lng": "-2.21667"
  },
  {
    "country": "GB",
    "name": "Alfreton",
    "lat": "53.09766",
    "lng": "-1.38376"
  },
  {
    "country": "GB",
    "name": "Alford",
    "lat": "57.23257",
    "lng": "-2.70298"
  },
  {
    "country": "GB",
    "name": "Alford",
    "lat": "53.25943",
    "lng": "0.17625"
  },
  {
    "country": "GB",
    "name": "Alexandria",
    "lat": "55.99379",
    "lng": "-4.5864"
  },
  {
    "country": "GB",
    "name": "Aldridge",
    "lat": "52.60549",
    "lng": "-1.91715"
  },
  {
    "country": "GB",
    "name": "Aldford",
    "lat": "53.12762",
    "lng": "-2.86812"
  },
  {
    "country": "GB",
    "name": "Aldershot",
    "lat": "51.24827",
    "lng": "-0.76389"
  },
  {
    "country": "GB",
    "name": "Alderley Edge",
    "lat": "53.30393",
    "lng": "-2.23773"
  },
  {
    "country": "GB",
    "name": "Alderholt",
    "lat": "50.91195",
    "lng": "-1.83083"
  },
  {
    "country": "GB",
    "name": "Alderbury",
    "lat": "51.04354",
    "lng": "-1.73382"
  },
  {
    "country": "GB",
    "name": "Aldeburgh",
    "lat": "52.15259",
    "lng": "1.60124"
  },
  {
    "country": "GB",
    "name": "Aldbrough",
    "lat": "53.82893",
    "lng": "-0.11467"
  },
  {
    "country": "GB",
    "name": "Aldbourne",
    "lat": "51.48098",
    "lng": "-1.61827"
  },
  {
    "country": "GB",
    "name": "Alconbury",
    "lat": "52.369",
    "lng": "-0.26009"
  },
  {
    "country": "GB",
    "name": "Alcester",
    "lat": "52.21667",
    "lng": "-1.86667"
  },
  {
    "country": "GB",
    "name": "Albrighton",
    "lat": "52.6364",
    "lng": "-2.27966"
  },
  {
    "country": "GB",
    "name": "Airth",
    "lat": "56.06983",
    "lng": "-3.77209"
  },
  {
    "country": "GB",
    "name": "Airmyn",
    "lat": "53.72074",
    "lng": "-0.89959"
  },
  {
    "country": "GB",
    "name": "Airdrie",
    "lat": "55.86602",
    "lng": "-3.98025"
  },
  {
    "country": "GB",
    "name": "Ahoghill",
    "lat": "54.86667",
    "lng": "-6.36667"
  },
  {
    "country": "GB",
    "name": "Adwick le Street",
    "lat": "53.57077",
    "lng": "-1.18454"
  },
  {
    "country": "GB",
    "name": "Adlington",
    "lat": "53.61323",
    "lng": "-2.60676"
  },
  {
    "country": "GB",
    "name": "Addlestone",
    "lat": "51.37135",
    "lng": "-0.49353"
  },
  {
    "country": "GB",
    "name": "Addingham",
    "lat": "53.94452",
    "lng": "-1.88424"
  },
  {
    "country": "GB",
    "name": "Adderbury",
    "lat": "52.0169",
    "lng": "-1.31192"
  },
  {
    "country": "GB",
    "name": "Acton",
    "lat": "52.45",
    "lng": "-3.01667"
  },
  {
    "country": "GB",
    "name": "Acton",
    "lat": "51.50901",
    "lng": "-0.2762"
  },
  {
    "country": "GB",
    "name": "Acomb",
    "lat": "54.99229",
    "lng": "-2.11229"
  },
  {
    "country": "GB",
    "name": "Acocks Green",
    "lat": "52.45",
    "lng": "-1.81667"
  },
  {
    "country": "GB",
    "name": "Acle",
    "lat": "52.63681",
    "lng": "1.54757"
  },
  {
    "country": "GB",
    "name": "Acklington",
    "lat": "55.3",
    "lng": "-1.63333"
  },
  {
    "country": "GB",
    "name": "Accrington",
    "lat": "53.75379",
    "lng": "-2.35863"
  },
  {
    "country": "GB",
    "name": "Abram",
    "lat": "53.50855",
    "lng": "-2.59266"
  },
  {
    "country": "GB",
    "name": "Aboyne",
    "lat": "57.07546",
    "lng": "-2.78023"
  },
  {
    "country": "GB",
    "name": "Abingdon",
    "lat": "51.67109",
    "lng": "-1.28278"
  },
  {
    "country": "GB",
    "name": "Aberystwyth",
    "lat": "52.41548",
    "lng": "-4.08292"
  },
  {
    "country": "GB",
    "name": "Abertillery",
    "lat": "51.72981",
    "lng": "-3.13432"
  },
  {
    "country": "GB",
    "name": "Aberporth",
    "lat": "52.13248",
    "lng": "-4.54173"
  },
  {
    "country": "GB",
    "name": "Abernethy",
    "lat": "56.33247",
    "lng": "-3.31226"
  },
  {
    "country": "GB",
    "name": "Abernant",
    "lat": "51.88139",
    "lng": "-4.41556"
  },
  {
    "country": "GB",
    "name": "Aberlour",
    "lat": "57.47076",
    "lng": "-3.22509"
  },
  {
    "country": "GB",
    "name": "Aberlady",
    "lat": "56.00884",
    "lng": "-2.85851"
  },
  {
    "country": "GB",
    "name": "Aberkenfig",
    "lat": "51.54",
    "lng": "-3.59556"
  },
  {
    "country": "GB",
    "name": "Abergele",
    "lat": "53.28436",
    "lng": "-3.5822"
  },
  {
    "country": "GB",
    "name": "Abergavenny",
    "lat": "51.82098",
    "lng": "-3.01743"
  },
  {
    "country": "GB",
    "name": "Aberford",
    "lat": "53.82604",
    "lng": "-1.34231"
  },
  {
    "country": "GB",
    "name": "Aberfeldy",
    "lat": "56.62196",
    "lng": "-3.86693"
  },
  {
    "country": "GB",
    "name": "Aberfan",
    "lat": "51.68892",
    "lng": "-3.34178"
  },
  {
    "country": "GB",
    "name": "Aberdour",
    "lat": "56.05417",
    "lng": "-3.30058"
  },
  {
    "country": "GB",
    "name": "Aberdeen",
    "lat": "57.14369",
    "lng": "-2.09814"
  },
  {
    "country": "GB",
    "name": "Aberdare",
    "lat": "51.71438",
    "lng": "-3.44918"
  },
  {
    "country": "GB",
    "name": "Abercynon",
    "lat": "51.64548",
    "lng": "-3.32727"
  },
  {
    "country": "GB",
    "name": "Aberchirder",
    "lat": "57.56012",
    "lng": "-2.62856"
  },
  {
    "country": "GB",
    "name": "Abercarn",
    "lat": "51.64733",
    "lng": "-3.13476"
  },
  {
    "country": "GB",
    "name": "Abercanaid",
    "lat": "51.72361",
    "lng": "-3.36611"
  },
  {
    "country": "GB",
    "name": "Aberaeron",
    "lat": "52.24247",
    "lng": "-4.25871"
  },
  {
    "country": "GB",
    "name": "Aber",
    "lat": "53.23333",
    "lng": "-4.01667"
  },
  {
    "country": "GB",
    "name": "Abbotts Ann",
    "lat": "51.19016",
    "lng": "-1.53234"
  },
  {
    "country": "GB",
    "name": "Abbots Langley",
    "lat": "51.70573",
    "lng": "-0.41757"
  },
  {
    "country": "GB",
    "name": "Abbotskerswell",
    "lat": "50.50816",
    "lng": "-3.61342"
  },
  {
    "country": "GB",
    "name": "Abbots Bromley",
    "lat": "52.81705",
    "lng": "-1.87694"
  },
  {
    "country": "GB",
    "name": "Abbey Dore",
    "lat": "51.96667",
    "lng": "-2.9"
  },
  {
    "country": "GB",
    "name": "Benllech",
    "lat": "53.32044",
    "lng": "-4.22607"
  },
  {
    "country": "GB",
    "name": "Crosby",
    "lat": "53.47778",
    "lng": "-3.03333"
  },
  {
    "country": "GB",
    "name": "Overcombe",
    "lat": "50.63509",
    "lng": "-2.43207"
  },
  {
    "country": "GB",
    "name": "Lynemouth",
    "lat": "55.21306",
    "lng": "-1.5425"
  },
  {
    "country": "GB",
    "name": "Hadston",
    "lat": "55.29428",
    "lng": "-1.60392"
  },
  {
    "country": "GB",
    "name": "East Cowes",
    "lat": "50.75774",
    "lng": "-1.28815"
  },
  {
    "country": "GB",
    "name": "Shiremoor",
    "lat": "55.03535",
    "lng": "-1.5095"
  },
  {
    "country": "GB",
    "name": "Looe",
    "lat": "50.35778",
    "lng": "-4.45418"
  },
  {
    "country": "GB",
    "name": "Pensilva",
    "lat": "50.50302",
    "lng": "-4.41491"
  },
  {
    "country": "GB",
    "name": "Flexbury",
    "lat": "50.83509",
    "lng": "-4.54499"
  },
  {
    "country": "GB",
    "name": "Steynton",
    "lat": "51.72917",
    "lng": "-5.01722"
  },
  {
    "country": "GB",
    "name": "Hundleton",
    "lat": "51.66694",
    "lng": "-4.94917"
  },
  {
    "country": "GB",
    "name": "Glandwr",
    "lat": "51.92833",
    "lng": "-4.63333"
  },
  {
    "country": "GB",
    "name": "Trimsaran",
    "lat": "51.71988",
    "lng": "-4.24168"
  },
  {
    "country": "GB",
    "name": "Tumble",
    "lat": "51.78361",
    "lng": "-4.10972"
  },
  {
    "country": "GB",
    "name": "Llangynog",
    "lat": "51.82111",
    "lng": "-4.40972"
  },
  {
    "country": "GB",
    "name": "Crofty",
    "lat": "51.63448",
    "lng": "-4.12937"
  },
  {
    "country": "GB",
    "name": "Pennard",
    "lat": "51.57627",
    "lng": "-4.08691"
  },
  {
    "country": "GB",
    "name": "Southgate",
    "lat": "51.56944",
    "lng": "-4.08972"
  },
  {
    "country": "GB",
    "name": "Three Crosses",
    "lat": "51.62865",
    "lng": "-4.06263"
  },
  {
    "country": "GB",
    "name": "Grovesend",
    "lat": "51.68472",
    "lng": "-4.03833"
  },
  {
    "country": "GB",
    "name": "Pontlliw",
    "lat": "51.69139",
    "lng": "-4.01056"
  },
  {
    "country": "GB",
    "name": "Ambleston",
    "lat": "51.89583",
    "lng": "-4.90722"
  },
  {
    "country": "GB",
    "name": "Scleddau",
    "lat": "51.96833",
    "lng": "-4.99333"
  },
  {
    "country": "GB",
    "name": "Hook",
    "lat": "51.765",
    "lng": "-4.93167"
  },
  {
    "country": "GB",
    "name": "Croeserw",
    "lat": "51.64472",
    "lng": "-3.64028"
  },
  {
    "country": "GB",
    "name": "Pont Rhyd-y-cyff",
    "lat": "51.58694",
    "lng": "-3.63639"
  },
  {
    "country": "GB",
    "name": "Price Town",
    "lat": "51.61832",
    "lng": "-3.53662"
  },
  {
    "country": "GB",
    "name": "Ogmore Vale",
    "lat": "51.6023",
    "lng": "-3.54217"
  },
  {
    "country": "GB",
    "name": "Tonypandy",
    "lat": "51.62202",
    "lng": "-3.45544"
  },
  {
    "country": "GB",
    "name": "Clydach Vale",
    "lat": "51.62665",
    "lng": "-3.48015"
  },
  {
    "country": "GB",
    "name": "Cefn Cribwr",
    "lat": "51.53167",
    "lng": "-3.65278"
  },
  {
    "country": "GB",
    "name": "Merthyr Mawr",
    "lat": "51.48611",
    "lng": "-3.60861"
  },
  {
    "country": "GB",
    "name": "Brynna",
    "lat": "51.53845",
    "lng": "-3.46378"
  },
  {
    "country": "GB",
    "name": "Abertridwr",
    "lat": "51.59583",
    "lng": "-3.26833"
  },
  {
    "country": "GB",
    "name": "Beddau",
    "lat": "51.55398",
    "lng": "-3.35814"
  },
  {
    "country": "GB",
    "name": "Blackwood",
    "lat": "51.66778",
    "lng": "-3.2075"
  },
  {
    "country": "GB",
    "name": "Cwmbach",
    "lat": "51.70556",
    "lng": "-3.40944"
  },
  {
    "country": "GB",
    "name": "Blaengwynfi",
    "lat": "51.65623",
    "lng": "-3.60371"
  },
  {
    "country": "GB",
    "name": "New Inn",
    "lat": "51.69056",
    "lng": "-3.00917"
  },
  {
    "country": "GB",
    "name": "Rogiet",
    "lat": "51.58854",
    "lng": "-2.77868"
  },
  {
    "country": "GB",
    "name": "Eastington",
    "lat": "51.74722",
    "lng": "-2.32639"
  },
  {
    "country": "GB",
    "name": "Whitley",
    "lat": "51.39528",
    "lng": "-2.16444"
  },
  {
    "country": "GB",
    "name": "Woolavington",
    "lat": "51.16493",
    "lng": "-2.93814"
  },
  {
    "country": "GB",
    "name": "Kewstoke",
    "lat": "51.3653",
    "lng": "-2.95901"
  },
  {
    "country": "GB",
    "name": "Pucklechurch",
    "lat": "51.48583",
    "lng": "-2.43389"
  },
  {
    "country": "GB",
    "name": "Peasedown Saint John",
    "lat": "51.31667",
    "lng": "-2.42417"
  },
  {
    "country": "GB",
    "name": "Severn Beach",
    "lat": "51.56036",
    "lng": "-2.66279"
  },
  {
    "country": "GB",
    "name": "Easton-in-Gordano",
    "lat": "51.47592",
    "lng": "-2.69987"
  },
  {
    "country": "GB",
    "name": "Bishop Sutton",
    "lat": "51.33444",
    "lng": "-2.59472"
  },
  {
    "country": "GB",
    "name": "Chapmanslade",
    "lat": "51.22917",
    "lng": "-2.24889"
  },
  {
    "country": "GB",
    "name": "Stockton",
    "lat": "51.14528",
    "lng": "-2.03194"
  },
  {
    "country": "GB",
    "name": "Boyton",
    "lat": "51.155",
    "lng": "-2.07111"
  },
  {
    "country": "GB",
    "name": "Marston",
    "lat": "51.31083",
    "lng": "-2.04972"
  },
  {
    "country": "GB",
    "name": "Neston",
    "lat": "51.41222",
    "lng": "-2.20056"
  },
  {
    "country": "GB",
    "name": "Camden Town",
    "lat": "51.54057",
    "lng": "-0.14334"
  },
  {
    "country": "GB",
    "name": "Camberwell",
    "lat": "51.4739",
    "lng": "-0.09381"
  },
  {
    "country": "GB",
    "name": "Telford",
    "lat": "52.67659",
    "lng": "-2.44926"
  },
  {
    "country": "GB",
    "name": "Craigavon",
    "lat": "54.44709",
    "lng": "-6.387"
  },
  {
    "country": "GB",
    "name": "Caol",
    "lat": "56.83721",
    "lng": "-5.10062"
  },
  {
    "country": "GB",
    "name": "Wideopen",
    "lat": "55.04514",
    "lng": "-1.62246"
  },
  {
    "country": "GB",
    "name": "Hazlerigg",
    "lat": "55.04135",
    "lng": "-1.63912"
  },
  {
    "country": "GB",
    "name": "Lamesley",
    "lat": "54.91567",
    "lng": "-1.60945"
  },
  {
    "country": "GB",
    "name": "Walton",
    "lat": "53.92501",
    "lng": "-1.32746"
  },
  {
    "country": "GB",
    "name": "Clifford",
    "lat": "53.89513",
    "lng": "-1.34557"
  },
  {
    "country": "GB",
    "name": "East Keswick",
    "lat": "53.8943",
    "lng": "-1.45221"
  },
  {
    "country": "GB",
    "name": "Shadwell",
    "lat": "53.8546",
    "lng": "-1.4726"
  },
  {
    "country": "GB",
    "name": "Barlby",
    "lat": "53.79964",
    "lng": "-1.04061"
  },
  {
    "country": "GB",
    "name": "Bar Hill",
    "lat": "52.24899",
    "lng": "0.02883"
  },
  {
    "country": "GB",
    "name": "Camber",
    "lat": "50.93473",
    "lng": "0.79848"
  },
  {
    "country": "GB",
    "name": "Winchelsea Beach",
    "lat": "50.91691",
    "lng": "0.72158"
  },
  {
    "country": "GB",
    "name": "Kesgrave",
    "lat": "52.06241",
    "lng": "1.2365"
  },
  {
    "country": "GB",
    "name": "Blackmoorfoot",
    "lat": "53.61423",
    "lng": "-1.85588"
  },
  {
    "country": "GB",
    "name": "Meltham Mills",
    "lat": "53.59388",
    "lng": "-1.83989"
  },
  {
    "country": "GB",
    "name": "Polzeath",
    "lat": "50.56956",
    "lng": "-4.91759"
  },
  {
    "country": "GB",
    "name": "Rock",
    "lat": "50.54978",
    "lng": "-4.90462"
  },
  {
    "country": "GB",
    "name": "Camblesforth",
    "lat": "53.7268",
    "lng": "-1.01998"
  },
  {
    "country": "GB",
    "name": "Fontwell",
    "lat": "50.8552",
    "lng": "-0.64831"
  },
  {
    "country": "GB",
    "name": "Sharlston",
    "lat": "53.66956",
    "lng": "-1.41294"
  },
  {
    "country": "GB",
    "name": "Kennington",
    "lat": "51.48796",
    "lng": "-0.10566"
  },
  {
    "country": "GB",
    "name": "Bayswater",
    "lat": "51.51116",
    "lng": "-0.18426"
  },
  {
    "country": "GB",
    "name": "Lambeth",
    "lat": "51.49635",
    "lng": "-0.11152"
  },
  {
    "country": "GB",
    "name": "Tywyn",
    "lat": "52.58578",
    "lng": "-4.09276"
  },
  {
    "country": "GB",
    "name": "West End of London",
    "lat": "51.51414",
    "lng": "-0.1551"
  },
  {
    "country": "GB",
    "name": "Tankerton",
    "lat": "51.3637",
    "lng": "1.04913"
  },
  {
    "country": "GB",
    "name": "Thorpe Hamlet",
    "lat": "52.6277",
    "lng": "1.31175"
  },
  {
    "country": "GB",
    "name": "Cheadle Heath",
    "lat": "53.40186",
    "lng": "-2.19088"
  },
  {
    "country": "GB",
    "name": "Cameley",
    "lat": "51.31616",
    "lng": "-2.56079"
  },
  {
    "country": "GB",
    "name": "Bradley Cross",
    "lat": "51.27488",
    "lng": "-2.76256"
  },
  {
    "country": "GB",
    "name": "South Chailey",
    "lat": "50.93831",
    "lng": "-0.02105"
  },
  {
    "country": "GB",
    "name": "Copthorne",
    "lat": "51.13929",
    "lng": "-0.11742"
  },
  {
    "country": "GB",
    "name": "Muirhead",
    "lat": "55.89803",
    "lng": "-4.1058"
  },
  {
    "country": "GB",
    "name": "Yateley",
    "lat": "51.34305",
    "lng": "-0.82985"
  },
  {
    "country": "GB",
    "name": "Oakmere",
    "lat": "53.21996",
    "lng": "-2.64054"
  },
  {
    "country": "GB",
    "name": "East Ayton",
    "lat": "54.2548",
    "lng": "-0.47483"
  },
  {
    "country": "GB",
    "name": "Westcliff-on-Sea",
    "lat": "51.54424",
    "lng": "0.69179"
  },
  {
    "country": "GB",
    "name": "Didsbury",
    "lat": "53.41698",
    "lng": "-2.23145"
  },
  {
    "country": "GB",
    "name": "Hellaby",
    "lat": "53.42257",
    "lng": "-1.24125"
  },
  {
    "country": "GB",
    "name": "Langstone",
    "lat": "51.60554",
    "lng": "-2.91206"
  },
  {
    "country": "GB",
    "name": "Tintern",
    "lat": "51.69677",
    "lng": "-2.68142"
  },
  {
    "country": "GB",
    "name": "Barham",
    "lat": "51.2057",
    "lng": "1.15734"
  },
  {
    "country": "GB",
    "name": "Bowthorpe",
    "lat": "52.63884",
    "lng": "1.21885"
  },
  {
    "country": "GB",
    "name": "Hedge End",
    "lat": "50.91234",
    "lng": "-1.30076"
  },
  {
    "country": "GB",
    "name": "Moodiesburn",
    "lat": "55.91501",
    "lng": "-4.08331"
  },
  {
    "country": "GB",
    "name": "Virginia Water",
    "lat": "51.40343",
    "lng": "-0.56651"
  },
  {
    "country": "GB",
    "name": "Churt",
    "lat": "51.13603",
    "lng": "-0.77534"
  },
  {
    "country": "GB",
    "name": "Danby",
    "lat": "54.46606",
    "lng": "-0.91073"
  },
  {
    "country": "GB",
    "name": "Wychbold",
    "lat": "52.29045",
    "lng": "-2.11555"
  },
  {
    "country": "GB",
    "name": "Gerrards Cross",
    "lat": "51.5861",
    "lng": "-0.55543"
  },
  {
    "country": "GB",
    "name": "Maidenbower",
    "lat": "51.10781",
    "lng": "-0.15286"
  },
  {
    "country": "GB",
    "name": "Furnace Green",
    "lat": "51.10742",
    "lng": "-0.16889"
  },
  {
    "country": "GB",
    "name": "Broadfield",
    "lat": "51.09714",
    "lng": "-0.20664"
  },
  {
    "country": "GB",
    "name": "Bewbush",
    "lat": "51.10329",
    "lng": "-0.22312"
  },
  {
    "country": "GB",
    "name": "Gossops Green",
    "lat": "51.11105",
    "lng": "-0.21728"
  },
  {
    "country": "GB",
    "name": "Langley Green",
    "lat": "51.12817",
    "lng": "-0.19835"
  },
  {
    "country": "GB",
    "name": "St. Buryan",
    "lat": "50.07441",
    "lng": "-5.6226"
  },
  {
    "country": "GB",
    "name": "Erskine",
    "lat": "55.9005",
    "lng": "-4.45028"
  },
  {
    "country": "GB",
    "name": "Hale",
    "lat": "53.37831",
    "lng": "-2.33271"
  },
  {
    "country": "GB",
    "name": "Bidford-on-avon",
    "lat": "52.16725",
    "lng": "-1.85652"
  },
  {
    "country": "GB",
    "name": "Westhill",
    "lat": "57.15263",
    "lng": "-2.27966"
  },
  {
    "country": "GB",
    "name": "Clarkston",
    "lat": "55.78594",
    "lng": "-4.27651"
  },
  {
    "country": "GB",
    "name": "Smithton",
    "lat": "57.47956",
    "lng": "-4.15141"
  },
  {
    "country": "GB",
    "name": "Kings Hill",
    "lat": "51.27437",
    "lng": "0.40237"
  },
  {
    "country": "GB",
    "name": "Crouch End",
    "lat": "51.57971",
    "lng": "-0.12373"
  },
  {
    "country": "GB",
    "name": "Clerkenwell",
    "lat": "51.52438",
    "lng": "-0.11022"
  },
  {
    "country": "GB",
    "name": "Belsize Park",
    "lat": "51.54767",
    "lng": "-0.17228"
  },
  {
    "country": "GB",
    "name": "Barnsbury",
    "lat": "51.54067",
    "lng": "-0.11675"
  },
  {
    "country": "GB",
    "name": "Little Chalfont",
    "lat": "51.66829",
    "lng": "-0.57038"
  },
  {
    "country": "GB",
    "name": "Amersham on the Hill",
    "lat": "51.67468",
    "lng": "-0.60742"
  },
  {
    "country": "GB",
    "name": "Barbican",
    "lat": "51.51988",
    "lng": "-0.09446"
  },
  {
    "country": "GB",
    "name": "Battersea",
    "lat": "51.47475",
    "lng": "-0.15547"
  },
  {
    "country": "GB",
    "name": "Grange Hill",
    "lat": "51.61185",
    "lng": "0.08612"
  },
  {
    "country": "GB",
    "name": "Collier Row",
    "lat": "51.59893",
    "lng": "0.166"
  },
  {
    "country": "GB",
    "name": "Elm Park",
    "lat": "51.5497",
    "lng": "0.20136"
  },
  {
    "country": "GB",
    "name": "Cranham",
    "lat": "51.56565",
    "lng": "0.2659"
  },
  {
    "country": "GB",
    "name": "Chafford Hundred",
    "lat": "51.4892",
    "lng": "0.2944"
  },
  {
    "country": "GB",
    "name": "Chadwell St Mary",
    "lat": "51.4814",
    "lng": "0.36343"
  },
  {
    "country": "GB",
    "name": "Culverstone Green",
    "lat": "51.34085",
    "lng": "0.34686"
  },
  {
    "country": "GB",
    "name": "Kingston upon Thames",
    "lat": "51.41259",
    "lng": "-0.2974"
  },
  {
    "country": "GB",
    "name": "Ditton Hill",
    "lat": "51.37947",
    "lng": "-0.31281"
  },
  {
    "country": "GB",
    "name": "Hinchley Wood",
    "lat": "51.37461",
    "lng": "-0.33838"
  },
  {
    "country": "GB",
    "name": "South Croydon",
    "lat": "51.36217",
    "lng": "-0.09421"
  },
  {
    "country": "GB",
    "name": "Hornchurch",
    "lat": "51.55685",
    "lng": "0.21664"
  },
  {
    "country": "GB",
    "name": "Hainault",
    "lat": "51.60836",
    "lng": "0.10716"
  },
  {
    "country": "GB",
    "name": "Surbiton",
    "lat": "51.39148",
    "lng": "-0.29825"
  },
  {
    "country": "GB",
    "name": "Ewell",
    "lat": "51.34948",
    "lng": "-0.2494"
  },
  {
    "country": "GB",
    "name": "Harold Wood",
    "lat": "51.59462",
    "lng": "0.23294"
  },
  {
    "country": "GB",
    "name": "Chadwell Heath",
    "lat": "51.57121",
    "lng": "0.13271"
  },
  {
    "country": "GB",
    "name": "Becontree",
    "lat": "51.5529",
    "lng": "0.129"
  },
  {
    "country": "GB",
    "name": "Brixton",
    "lat": "51.46593",
    "lng": "-0.10652"
  },
  {
    "country": "GB",
    "name": "Bethnal Green",
    "lat": "51.52718",
    "lng": "-0.06109"
  },
  {
    "country": "GB",
    "name": "Cheetham Hill",
    "lat": "53.49862",
    "lng": "-2.23846"
  },
  {
    "country": "GB",
    "name": "Failsworth",
    "lat": "53.50484",
    "lng": "-2.16568"
  },
  {
    "country": "GB",
    "name": "Crumpsall",
    "lat": "53.51827",
    "lng": "-2.24447"
  },
  {
    "country": "GB",
    "name": "Blackley",
    "lat": "53.51765",
    "lng": "-2.21443"
  },
  {
    "country": "GB",
    "name": "Radcliffe",
    "lat": "53.56178",
    "lng": "-2.32455"
  },
  {
    "country": "GB",
    "name": "Heywood",
    "lat": "53.59245",
    "lng": "-2.21941"
  },
  {
    "country": "GB",
    "name": "Hollingworth",
    "lat": "53.463",
    "lng": "-1.991"
  },
  {
    "country": "GB",
    "name": "Chorlton cum Hardy",
    "lat": "53.43505",
    "lng": "-2.2631"
  },
  {
    "country": "GB",
    "name": "Burnage",
    "lat": "53.43265",
    "lng": "-2.19967"
  },
  {
    "country": "GB",
    "name": "Fallowfield",
    "lat": "53.43981",
    "lng": "-2.21572"
  },
  {
    "country": "GB",
    "name": "Heaton Chapel",
    "lat": "53.43015",
    "lng": "-2.17538"
  },
  {
    "country": "GB",
    "name": "Haughton Green",
    "lat": "53.44118",
    "lng": "-2.09827"
  },
  {
    "country": "GB",
    "name": "Hulme",
    "lat": "53.46572",
    "lng": "-2.24885"
  },
  {
    "country": "GB",
    "name": "Longsight",
    "lat": "53.45801",
    "lng": "-2.20104"
  },
  {
    "country": "GB",
    "name": "Heavitree",
    "lat": "50.72044",
    "lng": "-3.49646"
  },
  {
    "country": "GB",
    "name": "Ferndown",
    "lat": "50.80743",
    "lng": "-1.89975"
  },
  {
    "country": "GB",
    "name": "Clayton-le-Woods",
    "lat": "53.69689",
    "lng": "-2.66818"
  },
  {
    "country": "GB",
    "name": "Portland",
    "lat": "50.56748",
    "lng": "-2.44472"
  },
  {
    "country": "GB",
    "name": "Canary Wharf",
    "lat": "51.50519",
    "lng": "-0.02085"
  },
  {
    "country": "GB",
    "name": "Coatham Mundeville",
    "lat": "54.58002",
    "lng": "-1.55645"
  },
  {
    "country": "GB",
    "name": "Billington",
    "lat": "53.8157",
    "lng": "-2.4236"
  },
  {
    "country": "GB",
    "name": "Brixton Hill",
    "lat": "51.45213",
    "lng": "-0.123"
  },
  {
    "country": "GB",
    "name": "Nether Heyford",
    "lat": "52.22123",
    "lng": "-1.03452"
  },
  {
    "country": "GB",
    "name": "Featherstone",
    "lat": "52.64483",
    "lng": "-2.09315"
  },
  {
    "country": "GB",
    "name": "Belmont",
    "lat": "52.04272",
    "lng": "-2.74169"
  },
  {
    "country": "GB",
    "name": "Calcot",
    "lat": "51.44058",
    "lng": "-1.05091"
  },
  {
    "country": "GB",
    "name": "Benwell",
    "lat": "54.97296",
    "lng": "-1.66926"
  },
  {
    "country": "GB",
    "name": "Earl Shilton",
    "lat": "52.57682",
    "lng": "-1.31536"
  },
  {
    "country": "GB",
    "name": "St. Georges",
    "lat": "51.36224",
    "lng": "-2.89799"
  },
  {
    "country": "GB",
    "name": "Carden",
    "lat": "53.07214",
    "lng": "-2.79735"
  },
  {
    "country": "GB",
    "name": "Bay Horse",
    "lat": "53.96867",
    "lng": "-2.77603"
  },
  {
    "country": "GB",
    "name": "Adlington",
    "lat": "53.32042",
    "lng": "-2.13658"
  },
  {
    "country": "GB",
    "name": "Colden Common",
    "lat": "50.99483",
    "lng": "-1.31143"
  },
  {
    "country": "GB",
    "name": "Winterbourne",
    "lat": "51.52327",
    "lng": "-2.50437"
  },
  {
    "country": "GB",
    "name": "Charvil",
    "lat": "51.47573",
    "lng": "-0.88591"
  },
  {
    "country": "GB",
    "name": "Essington",
    "lat": "52.6291",
    "lng": "-2.0577"
  },
  {
    "country": "GB",
    "name": "Bordon",
    "lat": "51.11357",
    "lng": "-0.86245"
  },
  {
    "country": "GB",
    "name": "Knaphill",
    "lat": "51.3201",
    "lng": "-0.61584"
  },
  {
    "country": "GB",
    "name": "Lytham St Annes",
    "lat": "53.7426",
    "lng": "-2.997"
  },
  {
    "country": "GB",
    "name": "Curdworth",
    "lat": "52.53382",
    "lng": "-1.73687"
  },
  {
    "country": "GB",
    "name": "Chorlton",
    "lat": "53.05029",
    "lng": "-2.40541"
  },
  {
    "country": "GB",
    "name": "Little Hallingbury",
    "lat": "51.83324",
    "lng": "0.18151"
  },
  {
    "country": "GB",
    "name": "Hoole",
    "lat": "53.1998",
    "lng": "-2.87689"
  },
  {
    "country": "GB",
    "name": "Eight Ash Green",
    "lat": "51.89587",
    "lng": "0.8228"
  },
  {
    "country": "GB",
    "name": "Peaslake",
    "lat": "51.19156",
    "lng": "-0.44658"
  },
  {
    "country": "GB",
    "name": "Woodbury",
    "lat": "50.67664",
    "lng": "-3.4016"
  },
  {
    "country": "GB",
    "name": "Larkfield",
    "lat": "51.30143",
    "lng": "0.44855"
  },
  {
    "country": "GB",
    "name": "Catcliffe",
    "lat": "53.39316",
    "lng": "-1.36207"
  },
  {
    "country": "GB",
    "name": "Walton",
    "lat": "53.64886",
    "lng": "-1.46582"
  },
  {
    "country": "GB",
    "name": "Hadley Wood",
    "lat": "51.66669",
    "lng": "-0.16981"
  },
  {
    "country": "GB",
    "name": "Greenhill",
    "lat": "51.58342",
    "lng": "-0.3386"
  },
  {
    "country": "GB",
    "name": "Grappenhall",
    "lat": "53.37204",
    "lng": "-2.54675"
  },
  {
    "country": "GB",
    "name": "Prenton",
    "lat": "53.36762",
    "lng": "-3.05479"
  },
  {
    "country": "GB",
    "name": "Silver End",
    "lat": "51.84734",
    "lng": "0.62399"
  },
  {
    "country": "GB",
    "name": "Great Marton",
    "lat": "53.81185",
    "lng": "-3.02261"
  },
  {
    "country": "GB",
    "name": "Whiston",
    "lat": "53.41997",
    "lng": "-2.78907"
  },
  {
    "country": "GB",
    "name": "Eaglescliffe",
    "lat": "54.52521",
    "lng": "-1.35043"
  },
  {
    "country": "GB",
    "name": "Mottram St. Andrew",
    "lat": "53.30616",
    "lng": "-2.18147"
  },
  {
    "country": "GB",
    "name": "Barnwood",
    "lat": "51.86393",
    "lng": "-2.20087"
  },
  {
    "country": "GB",
    "name": "Chapel Allerton",
    "lat": "53.82901",
    "lng": "-1.53834"
  },
  {
    "country": "GB",
    "name": "Ash",
    "lat": "51.27883",
    "lng": "1.27974"
  },
  {
    "country": "GB",
    "name": "Greenfield",
    "lat": "52.00278",
    "lng": "-0.46605"
  },
  {
    "country": "GB",
    "name": "Byram",
    "lat": "53.72394",
    "lng": "-1.26128"
  },
  {
    "country": "GB",
    "name": "New Marske",
    "lat": "54.57848",
    "lng": "-1.04224"
  },
  {
    "country": "GB",
    "name": "Winscombe",
    "lat": "51.3181",
    "lng": "-2.83224"
  },
  {
    "country": "GB",
    "name": "Newcastle",
    "lat": "54.21804",
    "lng": "-5.88979"
  },
  {
    "country": "GB",
    "name": "Chiseldon",
    "lat": "51.51606",
    "lng": "-1.73206"
  },
  {
    "country": "GB",
    "name": "Milton of Campsie",
    "lat": "55.9612",
    "lng": "-4.16508"
  },
  {
    "country": "GB",
    "name": "Southchurch Village",
    "lat": "51.54049",
    "lng": "0.72935"
  },
  {
    "country": "GB",
    "name": "Darras Hall",
    "lat": "55.0356",
    "lng": "-1.76425"
  },
  {
    "country": "GB",
    "name": "Bodle Street",
    "lat": "50.91299",
    "lng": "0.34332"
  },
  {
    "country": "GB",
    "name": "Donnington",
    "lat": "51.95135",
    "lng": "-1.72142"
  },
  {
    "country": "GB",
    "name": "Babworth",
    "lat": "53.31799",
    "lng": "-0.97583"
  },
  {
    "country": "GB",
    "name": "Appleton Thorn",
    "lat": "53.35045",
    "lng": "-2.54488"
  },
  {
    "country": "GB",
    "name": "Guilden Sutton",
    "lat": "53.20809",
    "lng": "-2.82984"
  },
  {
    "country": "GB",
    "name": "Blacon",
    "lat": "53.20832",
    "lng": "-2.9253"
  },
  {
    "country": "GB",
    "name": "Chelmsley Wood",
    "lat": "52.4781",
    "lng": "-1.73813"
  },
  {
    "country": "GB",
    "name": "Crawley Down",
    "lat": "51.12061",
    "lng": "-0.0773"
  },
  {
    "country": "GB",
    "name": "Roslin",
    "lat": "55.85749",
    "lng": "-3.16895"
  },
  {
    "country": "GB",
    "name": "Bilston",
    "lat": "55.8703",
    "lng": "-3.17814"
  },
  {
    "country": "GB",
    "name": "Grange-over-Sands",
    "lat": "54.18508",
    "lng": "-2.92488"
  },
  {
    "country": "GB",
    "name": "Cowplain",
    "lat": "50.89411",
    "lng": "-1.01824"
  },
  {
    "country": "GB",
    "name": "Ruardean",
    "lat": "51.85501",
    "lng": "-2.55054"
  },
  {
    "country": "GB",
    "name": "Canford Heath",
    "lat": "50.751",
    "lng": "-1.96862"
  },
  {
    "country": "GB",
    "name": "High Barnet",
    "lat": "51.65621",
    "lng": "-0.20768"
  },
  {
    "country": "GB",
    "name": "Balsall Common",
    "lat": "52.39186",
    "lng": "-1.6504"
  },
  {
    "country": "GB",
    "name": "Ingleton",
    "lat": "54.15392",
    "lng": "-2.46849"
  },
  {
    "country": "GB",
    "name": "Eton Wick",
    "lat": "51.49722",
    "lng": "-0.63437"
  },
  {
    "country": "GB",
    "name": "St Mary's",
    "lat": "49.91719",
    "lng": "-6.29517"
  },
  {
    "country": "GB",
    "name": "Penparcau",
    "lat": "52.40333",
    "lng": "-4.07417"
  },
  {
    "country": "GB",
    "name": "Chalton",
    "lat": "51.9279",
    "lng": "-0.50147"
  },
  {
    "country": "GB",
    "name": "Husborne Crawley",
    "lat": "52.01637",
    "lng": "-0.61056"
  },
  {
    "country": "GB",
    "name": "Blackheath",
    "lat": "51.4647",
    "lng": "0.0079"
  },
  {
    "country": "GB",
    "name": "Stewartby",
    "lat": "52.07044",
    "lng": "-0.5149"
  },
  {
    "country": "GB",
    "name": "Kempston Hardwick",
    "lat": "52.08956",
    "lng": "-0.49908"
  },
  {
    "country": "GB",
    "name": "Bilsdale",
    "lat": "54.37356",
    "lng": "-1.11923"
  },
  {
    "country": "GB",
    "name": "Hameldon Hill",
    "lat": "53.7557",
    "lng": "-2.2919"
  },
  {
    "country": "GB",
    "name": "Mendip",
    "lat": "51.2372",
    "lng": "-2.6266"
  },
  {
    "country": "GB",
    "name": "Eversley",
    "lat": "51.35387",
    "lng": "-0.88888"
  },
  {
    "country": "GB",
    "name": "Y Felinheli",
    "lat": "53.18737",
    "lng": "-4.20476"
  },
  {
    "country": "GB",
    "name": "St Mary's Bay",
    "lat": "51.01003",
    "lng": "0.9771"
  },
  {
    "country": "GB",
    "name": "Murton",
    "lat": "53.96607",
    "lng": "-1.0107"
  },
  {
    "country": "GB",
    "name": "Aylesham",
    "lat": "51.22539",
    "lng": "1.20157"
  },
  {
    "country": "GB",
    "name": "Lightwater",
    "lat": "51.34846",
    "lng": "-0.67147"
  },
  {
    "country": "GB",
    "name": "Gartcosh",
    "lat": "55.88841",
    "lng": "-4.0817"
  },
  {
    "country": "GB",
    "name": "Kelloe",
    "lat": "54.71894",
    "lng": "-1.47495"
  },
  {
    "country": "GB",
    "name": "Easington Colliery",
    "lat": "54.78792",
    "lng": "-1.32819"
  },
  {
    "country": "GB",
    "name": "Llanrhaeadr-ym-Mochnant",
    "lat": "52.82507",
    "lng": "-3.30225"
  },
  {
    "country": "GB",
    "name": "Lower Earley",
    "lat": "51.42708",
    "lng": "-0.91979"
  },
  {
    "country": "GB",
    "name": "Isle Of Mull",
    "lat": "56.44703",
    "lng": "-5.77404"
  },
  {
    "country": "GB",
    "name": "Iver Heath",
    "lat": "51.53642",
    "lng": "-0.5179"
  },
  {
    "country": "GB",
    "name": "Bartley Green",
    "lat": "52.43532",
    "lng": "-1.99707"
  },
  {
    "country": "GB",
    "name": "Grimethorpe",
    "lat": "53.5765",
    "lng": "-1.37688"
  },
  {
    "country": "GB",
    "name": "Abbey Wood",
    "lat": "51.48688",
    "lng": "0.10747"
  },
  {
    "country": "GB",
    "name": "Ovington",
    "lat": "54.52791",
    "lng": "-1.79824"
  },
  {
    "country": "GB",
    "name": "Summerhouse",
    "lat": "54.56728",
    "lng": "-1.68923"
  },
  {
    "country": "GB",
    "name": "Seer Green",
    "lat": "51.61796",
    "lng": "-0.60592"
  },
  {
    "country": "GB",
    "name": "Elmstead Market",
    "lat": "51.88219",
    "lng": "0.99482"
  },
  {
    "country": "GB",
    "name": "Danderhall",
    "lat": "55.91434",
    "lng": "-3.11062"
  },
  {
    "country": "GB",
    "name": "Denmead",
    "lat": "50.90395",
    "lng": "-1.06744"
  },
  {
    "country": "GB",
    "name": "Nanpean",
    "lat": "50.36884",
    "lng": "-4.86935"
  },
  {
    "country": "GB",
    "name": "Cross Hills",
    "lat": "53.90606",
    "lng": "-1.98492"
  },
  {
    "country": "GB",
    "name": "Canvey Island",
    "lat": "51.52199",
    "lng": "0.5809"
  },
  {
    "country": "GB",
    "name": "Shotts",
    "lat": "55.81951",
    "lng": "-3.79749"
  },
  {
    "country": "GB",
    "name": "North Duffield",
    "lat": "53.82579",
    "lng": "-0.96414"
  },
  {
    "country": "GB",
    "name": "Earlsfield",
    "lat": "51.4439",
    "lng": "-0.1854"
  },
  {
    "country": "GB",
    "name": "Eastriggs",
    "lat": "54.98597",
    "lng": "-3.18051"
  },
  {
    "country": "GB",
    "name": "Westergate",
    "lat": "50.83988",
    "lng": "-0.67123"
  },
  {
    "country": "GB",
    "name": "Peacehaven",
    "lat": "50.7927",
    "lng": "-0.00652"
  },
  {
    "country": "GB",
    "name": "North Baddesley",
    "lat": "50.97745",
    "lng": "-1.44547"
  },
  {
    "country": "GB",
    "name": "Bedlinog",
    "lat": "51.70432",
    "lng": "-3.31306"
  },
  {
    "country": "GB",
    "name": "Appleby-in-Westmorland",
    "lat": "54.57704",
    "lng": "-2.48978"
  },
  {
    "country": "GB",
    "name": "Bracebridge Heath",
    "lat": "53.19647",
    "lng": "-0.53421"
  },
  {
    "country": "GB",
    "name": "Glapwell",
    "lat": "53.18917",
    "lng": "-1.28334"
  },
  {
    "country": "GB",
    "name": "Asfordby",
    "lat": "52.76331",
    "lng": "-0.95856"
  },
  {
    "country": "GB",
    "name": "Letchworth Garden City",
    "lat": "51.97938",
    "lng": "-0.22664"
  },
  {
    "country": "GB",
    "name": "Pevensey Bay",
    "lat": "50.81242",
    "lng": "0.34864"
  },
  {
    "country": "GB",
    "name": "Peckham",
    "lat": "51.47403",
    "lng": "-0.06969"
  },
  {
    "country": "GB",
    "name": "Cradley Heath",
    "lat": "52.47214",
    "lng": "-2.08212"
  },
  {
    "country": "GB",
    "name": "Shirley",
    "lat": "52.41074",
    "lng": "-1.81952"
  },
  {
    "country": "GB",
    "name": "Stanley",
    "lat": "54.86796",
    "lng": "-1.69846"
  },
  {
    "country": "GB",
    "name": "Stockton Heath",
    "lat": "53.37084",
    "lng": "-2.57406"
  },
  {
    "country": "GB",
    "name": "Waterloo",
    "lat": "53.47454",
    "lng": "-3.03017"
  },
  {
    "country": "GB",
    "name": "Pontyclun",
    "lat": "51.52162",
    "lng": "-3.39145"
  },
  {
    "country": "GB",
    "name": "Pentre",
    "lat": "51.65429",
    "lng": "-3.49133"
  },
  {
    "country": "GB",
    "name": "Catterick Garrison",
    "lat": "54.37748",
    "lng": "-1.72232"
  },
  {
    "country": "GB",
    "name": "Maple Cross",
    "lat": "51.625",
    "lng": "-0.508"
  },
  {
    "country": "GB",
    "name": "Rossendale",
    "lat": "53.68456",
    "lng": "-2.2769"
  },
  {
    "country": "GB",
    "name": "Thornton-Cleveleys",
    "lat": "53.87389",
    "lng": "-3.02244"
  },
  {
    "country": "GB",
    "name": "Deeside",
    "lat": "53.20053",
    "lng": "-3.03841"
  },
  {
    "country": "GB",
    "name": "High Peak",
    "lat": "53.36797",
    "lng": "-1.84536"
  },
  {
    "country": "GB",
    "name": "Romney Marsh",
    "lat": "51.02299",
    "lng": "0.91504"
  },
  {
    "country": "GB",
    "name": "Hayling Island",
    "lat": "50.7838",
    "lng": "-0.96869"
  },
  {
    "country": "GB",
    "name": "Isle of Lewis",
    "lat": "58.21901",
    "lng": "-6.38803"
  },
  {
    "country": "GB",
    "name": "Isle of Bute",
    "lat": "55.83663",
    "lng": "-5.05586"
  },
  {
    "country": "GB",
    "name": "Orkney",
    "lat": "58.98465",
    "lng": "-2.95953"
  },
  {
    "country": "GB",
    "name": "Hope Valley",
    "lat": "53.34819",
    "lng": "-1.74485"
  },
  {
    "country": "GB",
    "name": "Isle of Arran",
    "lat": "55.58145",
    "lng": "-5.21233"
  },
  {
    "country": "GB",
    "name": "Stoke-sub-Hamdon",
    "lat": "50.95397",
    "lng": "-2.74971"
  },
  {
    "country": "GB",
    "name": "Tintagel",
    "lat": "50.66317",
    "lng": "-4.75047"
  },
  {
    "country": "GB",
    "name": "Isle of North Uist",
    "lat": "57.60581",
    "lng": "-7.34024"
  },
  {
    "country": "GB",
    "name": "Isle of South Uist",
    "lat": "57.24562",
    "lng": "-7.33337"
  },
  {
    "country": "GB",
    "name": "Menstrie",
    "lat": "56.15138",
    "lng": "-3.85466"
  },
  {
    "country": "GB",
    "name": "Isle of Cumbrae",
    "lat": "55.76933",
    "lng": "-4.91913"
  },
  {
    "country": "GB",
    "name": "Isles of Scilly",
    "lat": "49.92515",
    "lng": "-6.29894"
  },
  {
    "country": "GB",
    "name": "Harris",
    "lat": "57.89934",
    "lng": "-6.80285"
  },
  {
    "country": "GB",
    "name": "Rosewell",
    "lat": "55.85075",
    "lng": "-3.13625"
  },
  {
    "country": "GB",
    "name": "Isle of Islay",
    "lat": "55.78526",
    "lng": "-6.23886"
  },
  {
    "country": "GB",
    "name": "Dyffryn Ardudwy",
    "lat": "52.77748",
    "lng": "-4.06468"
  },
  {
    "country": "GB",
    "name": "Merriott",
    "lat": "50.91275",
    "lng": "-2.79538"
  },
  {
    "country": "GB",
    "name": "Barra",
    "lat": "56.98035",
    "lng": "-7.45731"
  },
  {
    "country": "GB",
    "name": "Benbecula",
    "lat": "57.44737",
    "lng": "-7.34273"
  },
  {
    "country": "GB",
    "name": "Holloway",
    "lat": "51.55237",
    "lng": "-0.12497"
  },
  {
    "country": "GB",
    "name": "Ballintoy Harbour",
    "lat": "55.24422",
    "lng": "-6.36919"
  },
  {
    "country": "GB",
    "name": "Penyffordd",
    "lat": "53.14829",
    "lng": "-3.04584"
  },
  {
    "country": "GB",
    "name": "Water Eaton",
    "lat": "51.98697",
    "lng": "-0.72188"
  },
  {
    "country": "GB",
    "name": "Harringay",
    "lat": "51.5824",
    "lng": "-0.09956"
  },
  {
    "country": "GB",
    "name": "Sonning Common",
    "lat": "51.51873",
    "lng": "-0.97753"
  },
  {
    "country": "GB",
    "name": "Four Lanes",
    "lat": "50.20163",
    "lng": "-5.24014"
  },
  {
    "country": "GB",
    "name": "Dalgety Bay",
    "lat": "56.03496",
    "lng": "-3.35049"
  },
  {
    "country": "GB",
    "name": "Tweedbank",
    "lat": "55.60449",
    "lng": "-2.76692"
  },
  {
    "country": "GB",
    "name": "Abridge",
    "lat": "51.6495",
    "lng": "0.12033"
  },
  {
    "country": "GB",
    "name": "Lower Broadheath",
    "lat": "52.21379",
    "lng": "-2.27724"
  },
  {
    "country": "GB",
    "name": "Chopwell",
    "lat": "54.91797",
    "lng": "-1.82013"
  },
  {
    "country": "GB",
    "name": "Hinton",
    "lat": "52.16798",
    "lng": "-1.21837"
  },
  {
    "country": "GB",
    "name": "Cambourne",
    "lat": "52.22115",
    "lng": "-0.07025"
  },
  {
    "country": "GB",
    "name": "Moreton Jeffries",
    "lat": "52.13586",
    "lng": "-2.5796"
  },
  {
    "country": "GB",
    "name": "Perranarworthal",
    "lat": "50.20575",
    "lng": "-5.11993"
  },
  {
    "country": "GB",
    "name": "Mount Hawke",
    "lat": "50.28229",
    "lng": "-5.20855"
  },
  {
    "country": "GB",
    "name": "Anna Valley",
    "lat": "51.19317",
    "lng": "-1.50719"
  },
  {
    "country": "GB",
    "name": "Stanton Drew",
    "lat": "51.36749",
    "lng": "-2.58646"
  },
  {
    "country": "GB",
    "name": "Bishopsworth",
    "lat": "51.41479",
    "lng": "-2.6208"
  },
  {
    "country": "GB",
    "name": "Hoveton",
    "lat": "52.7149",
    "lng": "1.41054"
  },
  {
    "country": "GB",
    "name": "Greenham",
    "lat": "51.38689",
    "lng": "-1.31145"
  },
  {
    "country": "GB",
    "name": "Bridge Sollers",
    "lat": "52.0766",
    "lng": "-2.86099"
  },
  {
    "country": "GB",
    "name": "Deiniolen",
    "lat": "53.14819",
    "lng": "-4.13185"
  },
  {
    "country": "GB",
    "name": "Tidbury Green",
    "lat": "52.38092",
    "lng": "-1.85617"
  },
  {
    "country": "GB",
    "name": "Dickens Heath",
    "lat": "52.38568",
    "lng": "-1.83935"
  },
  {
    "country": "GB",
    "name": "Cheswick Green",
    "lat": "52.38037",
    "lng": "-1.81373"
  },
  {
    "country": "GB",
    "name": "Five Oak Green",
    "lat": "51.18338",
    "lng": "0.35517"
  },
  {
    "country": "GB",
    "name": "Town Row",
    "lat": "51.05302",
    "lng": "0.23217"
  },
  {
    "country": "GB",
    "name": "Ynysybwl",
    "lat": "51.63922",
    "lng": "-3.36036"
  },
  {
    "country": "GB",
    "name": "Wormley",
    "lat": "51.13622",
    "lng": "-0.64673"
  },
  {
    "country": "GB",
    "name": "Windygates",
    "lat": "56.19546",
    "lng": "-3.05274"
  },
  {
    "country": "GB",
    "name": "Swarthmoor",
    "lat": "54.18466",
    "lng": "-3.11707"
  },
  {
    "country": "GB",
    "name": "Talysarn",
    "lat": "53.05365",
    "lng": "-4.25767"
  },
  {
    "country": "GB",
    "name": "Carronshore",
    "lat": "56.03146",
    "lng": "-3.7829"
  },
  {
    "country": "GB",
    "name": "West Kingsdown",
    "lat": "51.34281",
    "lng": "0.26127"
  },
  {
    "country": "GB",
    "name": "Bellsbank",
    "lat": "55.3131",
    "lng": "-4.39869"
  },
  {
    "country": "GB",
    "name": "Rusthall",
    "lat": "51.13643",
    "lng": "0.22931"
  },
  {
    "country": "GB",
    "name": "Logan",
    "lat": "55.45466",
    "lng": "-4.23514"
  },
  {
    "country": "GB",
    "name": "East Rainton",
    "lat": "54.82513",
    "lng": "-1.48036"
  },
  {
    "country": "GB",
    "name": "Capel le Ferne",
    "lat": "51.10339",
    "lng": "1.21165"
  },
  {
    "country": "GB",
    "name": "Wood Street Village",
    "lat": "51.25098",
    "lng": "-0.63695"
  },
  {
    "country": "GB",
    "name": "Fairlands",
    "lat": "51.26178",
    "lng": "-0.62141"
  },
  {
    "country": "GB",
    "name": "Wolvercote",
    "lat": "51.78406",
    "lng": "-1.29338"
  },
  {
    "country": "GB",
    "name": "Stratton",
    "lat": "51.73394",
    "lng": "-1.97968"
  },
  {
    "country": "GB",
    "name": "Gronant",
    "lat": "53.33669",
    "lng": "-3.36031"
  },
  {
    "country": "GB",
    "name": "Shortlands",
    "lat": "51.39914",
    "lng": "0.0044"
  },
  {
    "country": "GB",
    "name": "Hockley Heath",
    "lat": "52.35294",
    "lng": "-1.77816"
  },
  {
    "country": "GB",
    "name": "St Just",
    "lat": "50.12379",
    "lng": "-5.68065"
  },
  {
    "country": "GB",
    "name": "Fleckney",
    "lat": "52.53497",
    "lng": "-1.04598"
  },
  {
    "country": "GB",
    "name": "Aston-on-Trent",
    "lat": "52.86172",
    "lng": "-1.38642"
  },
  {
    "country": "GB",
    "name": "Ravenshead",
    "lat": "53.0865",
    "lng": "-1.16026"
  },
  {
    "country": "GB",
    "name": "Flimwell",
    "lat": "51.05502",
    "lng": "0.44531"
  },
  {
    "country": "GB",
    "name": "Houghton",
    "lat": "52.33282",
    "lng": "-0.12068"
  },
  {
    "country": "GB",
    "name": "Bulphan",
    "lat": "51.54612",
    "lng": "0.36066"
  },
  {
    "country": "GB",
    "name": "Holywell Green",
    "lat": "53.67406",
    "lng": "-1.86682"
  },
  {
    "country": "GB",
    "name": "Keyworth",
    "lat": "52.87122",
    "lng": "-1.08991"
  },
  {
    "country": "GB",
    "name": "Cockington",
    "lat": "50.46335",
    "lng": "-3.55691"
  },
  {
    "country": "GB",
    "name": "Culloden",
    "lat": "57.48699",
    "lng": "-4.1415"
  },
  {
    "country": "GB",
    "name": "Greasby",
    "lat": "53.373",
    "lng": "-3.1233"
  },
  {
    "country": "GB",
    "name": "Ailsworth",
    "lat": "52.57585",
    "lng": "-0.35032"
  },
  {
    "country": "GB",
    "name": "Monkton Farleigh",
    "lat": "51.38812",
    "lng": "-2.28078"
  },
  {
    "country": "GB",
    "name": "Bowburn",
    "lat": "54.7385",
    "lng": "-1.52521"
  },
  {
    "country": "GB",
    "name": "Walton",
    "lat": "53.22284",
    "lng": "-1.46084"
  },
  {
    "country": "GB",
    "name": "Great Haywood",
    "lat": "52.80785",
    "lng": "-2.00024"
  },
  {
    "country": "GB",
    "name": "Hyde Heath",
    "lat": "51.69336",
    "lng": "-0.65437"
  },
  {
    "country": "GB",
    "name": "Ratby",
    "lat": "52.64989",
    "lng": "-1.24137"
  },
  {
    "country": "GB",
    "name": "Tal-y-bont",
    "lat": "52.77471",
    "lng": "-4.09224"
  },
  {
    "country": "GB",
    "name": "Stakeford",
    "lat": "55.1611",
    "lng": "-1.57529"
  },
  {
    "country": "GB",
    "name": "Linwood",
    "lat": "55.84834",
    "lng": "-4.49337"
  },
  {
    "country": "GB",
    "name": "Coven",
    "lat": "52.65587",
    "lng": "-2.1353"
  },
  {
    "country": "GB",
    "name": "Highland",
    "lat": "57.48566",
    "lng": "-4.22823"
  },
  {
    "country": "GB",
    "name": "Winchburgh",
    "lat": "55.95795",
    "lng": "-3.46464"
  },
  {
    "country": "GB",
    "name": "Addiebrownhill",
    "lat": "55.84289",
    "lng": "-3.61667"
  },
  {
    "country": "GB",
    "name": "Ashgill",
    "lat": "55.73119",
    "lng": "-3.93019"
  },
  {
    "country": "GB",
    "name": "Balloch",
    "lat": "57.49194",
    "lng": "-4.11713"
  },
  {
    "country": "GB",
    "name": "Banknock",
    "lat": "55.98967",
    "lng": "-3.95611"
  },
  {
    "country": "GB",
    "name": "Bargeddie",
    "lat": "55.85366",
    "lng": "-4.07846"
  },
  {
    "country": "GB",
    "name": "Blantyre",
    "lat": "55.79634",
    "lng": "-4.09485"
  },
  {
    "country": "GB",
    "name": "Brightons",
    "lat": "55.98028",
    "lng": "-3.71613"
  },
  {
    "country": "GB",
    "name": "Head of Muir",
    "lat": "56.00623",
    "lng": "-3.91358"
  },
  {
    "country": "GB",
    "name": "Allanton",
    "lat": "55.79945",
    "lng": "-3.83492"
  },
  {
    "country": "GB",
    "name": "Calderbank",
    "lat": "55.84318",
    "lng": "-3.9707"
  },
  {
    "country": "GB",
    "name": "Blackridge",
    "lat": "55.88523",
    "lng": "-3.77479"
  },
  {
    "country": "GB",
    "name": "Salsburgh",
    "lat": "55.84277",
    "lng": "-3.87264"
  },
  {
    "country": "GB",
    "name": "Croy",
    "lat": "55.96064",
    "lng": "-4.03932"
  },
  {
    "country": "GB",
    "name": "Drongan",
    "lat": "55.43498",
    "lng": "-4.45551"
  },
  {
    "country": "GB",
    "name": "Cruden Bay",
    "lat": "57.41797",
    "lng": "-1.85313"
  },
  {
    "country": "GB",
    "name": "Fallin",
    "lat": "56.10479",
    "lng": "-3.87616"
  },
  {
    "country": "GB",
    "name": "Glenmavis",
    "lat": "55.88913",
    "lng": "-3.98726"
  },
  {
    "country": "GB",
    "name": "Hallglen",
    "lat": "55.98573",
    "lng": "-3.78535"
  },
  {
    "country": "GB",
    "name": "Kingswells",
    "lat": "57.15798",
    "lng": "-2.22426"
  },
  {
    "country": "GB",
    "name": "Milton of Leys",
    "lat": "57.45125",
    "lng": "-4.17592"
  },
  {
    "country": "GB",
    "name": "Mossblown",
    "lat": "55.48941",
    "lng": "-4.52787"
  },
  {
    "country": "GB",
    "name": "Plains",
    "lat": "55.88044",
    "lng": "-3.92349"
  },
  {
    "country": "GB",
    "name": "Ratho Station",
    "lat": "55.9367",
    "lng": "-3.3889"
  },
  {
    "country": "GB",
    "name": "Seafield",
    "lat": "55.87791",
    "lng": "-3.58781"
  },
  {
    "country": "GB",
    "name": "Stoneyburn",
    "lat": "55.84371",
    "lng": "-3.63862"
  },
  {
    "country": "GB",
    "name": "Twechar",
    "lat": "55.95415",
    "lng": "-4.08219"
  },
  {
    "country": "GB",
    "name": "Waterfoot",
    "lat": "55.76938",
    "lng": "-4.28372"
  },
  {
    "country": "GB",
    "name": "Tullibody",
    "lat": "56.13364",
    "lng": "-3.83835"
  },
  {
    "country": "GB",
    "name": "Vale of Leven",
    "lat": "55.97132",
    "lng": "-4.57928"
  },
  {
    "country": "GB",
    "name": "Whitecraig",
    "lat": "55.91937",
    "lng": "-3.04231"
  },
  {
    "country": "GB",
    "name": "Dennyloanhead",
    "lat": "55.99886",
    "lng": "-3.91306"
  },
  {
    "country": "GB",
    "name": "Maryburgh",
    "lat": "57.5742",
    "lng": "-4.44178"
  },
  {
    "country": "GB",
    "name": "East Whitburn",
    "lat": "55.86855",
    "lng": "-3.66295"
  },
  {
    "country": "GB",
    "name": "Faifley",
    "lat": "55.92853",
    "lng": "-4.38509"
  },
  {
    "country": "GB",
    "name": "Laurieston",
    "lat": "55.99562",
    "lng": "-3.74801"
  },
  {
    "country": "GB",
    "name": "Lenzie",
    "lat": "55.92762",
    "lng": "-4.15399"
  },
  {
    "country": "GB",
    "name": "Maddiston",
    "lat": "55.97365",
    "lng": "-3.699"
  },
  {
    "country": "GB",
    "name": "Mayfield",
    "lat": "55.87172",
    "lng": "-3.03875"
  },
  {
    "country": "GB",
    "name": "New Stevenston",
    "lat": "55.81669",
    "lng": "-3.97357"
  },
  {
    "country": "GB",
    "name": "Polbeth",
    "lat": "55.86072",
    "lng": "-3.54901"
  },
  {
    "country": "GB",
    "name": "Redding",
    "lat": "55.98861",
    "lng": "-3.7323"
  },
  {
    "country": "GB",
    "name": "Reddingmuirhead",
    "lat": "55.98026",
    "lng": "-3.74853"
  },
  {
    "country": "GB",
    "name": "Stenhousemuir",
    "lat": "56.02676",
    "lng": "-3.81462"
  },
  {
    "country": "GB",
    "name": "Thornliebank",
    "lat": "55.80454",
    "lng": "-4.31746"
  },
  {
    "country": "GB",
    "name": "Viewpark",
    "lat": "55.82737",
    "lng": "-4.0573"
  },
  {
    "country": "GB",
    "name": "Westhill",
    "lat": "57.47323",
    "lng": "-4.14893"
  },
  {
    "country": "GB",
    "name": "Westquarter",
    "lat": "55.99142",
    "lng": "-3.74016"
  },
  {
    "country": "GB",
    "name": "Netherlee",
    "lat": "55.80157",
    "lng": "-4.27325"
  },
  {
    "country": "GB",
    "name": "Greenhill",
    "lat": "55.99204",
    "lng": "-3.89096"
  },
  {
    "country": "GB",
    "name": "Coaltown of Balgonie",
    "lat": "56.18474",
    "lng": "-3.12578"
  },
  {
    "country": "GB",
    "name": "Maxwellheugh",
    "lat": "55.59253",
    "lng": "-2.42871"
  },
  {
    "country": "GB",
    "name": "Torrance",
    "lat": "55.93995",
    "lng": "-4.21025"
  },
  {
    "country": "GB",
    "name": "Shieldhill",
    "lat": "55.97277",
    "lng": "-3.76788"
  },
  {
    "country": "GB",
    "name": "Denton Holme",
    "lat": "54.885",
    "lng": "-2.941"
  },
  {
    "country": "GB",
    "name": "West Ilsley",
    "lat": "51.53993",
    "lng": "-1.32368"
  },
  {
    "country": "GB",
    "name": "Ballypatrick",
    "lat": "55.18112",
    "lng": "-6.1502"
  },
  {
    "country": "GB",
    "name": "Holbeck",
    "lat": "53.78359",
    "lng": "-1.56791"
  },
  {
    "country": "GB",
    "name": "Burngreave",
    "lat": "53.39302",
    "lng": "-1.45789"
  },
  {
    "country": "GB",
    "name": "Archway",
    "lat": "51.56733",
    "lng": "-0.13415"
  },
  {
    "country": "GB",
    "name": "Castle Vale",
    "lat": "52.51879",
    "lng": "-1.79683"
  },
  {
    "country": "GB",
    "name": "Old Harlow",
    "lat": "51.78353",
    "lng": "0.13381"
  },
  {
    "country": "GB",
    "name": "King's Clipstone",
    "lat": "53.1769",
    "lng": "-1.10129"
  },
  {
    "country": "GB",
    "name": "Sinfin",
    "lat": "52.88157",
    "lng": "-1.48681"
  },
  {
    "country": "GB",
    "name": "Newhaven",
    "lat": "53.13987",
    "lng": "-1.75261"
  },
  {
    "country": "GB",
    "name": "Hardwick Village",
    "lat": "53.27372",
    "lng": "-1.0432"
  },
  {
    "country": "GB",
    "name": "New Basford",
    "lat": "52.97336",
    "lng": "-1.16564"
  },
  {
    "country": "GB",
    "name": "Chaddleworth",
    "lat": "51.49274",
    "lng": "-1.40361"
  },
  {
    "country": "GB",
    "name": "Clubmoor",
    "lat": "53.43332",
    "lng": "-2.93358"
  },
  {
    "country": "GB",
    "name": "Tunstall",
    "lat": "53.0583",
    "lng": "-2.2114"
  },
  {
    "country": "GB",
    "name": "Bradwell",
    "lat": "52.57353",
    "lng": "1.69979"
  },
  {
    "country": "GB",
    "name": "Sauchen",
    "lat": "57.18685",
    "lng": "-2.49868"
  },
  {
    "country": "GD",
    "name": "Victoria",
    "lat": "12.19021",
    "lng": "-61.70677"
  },
  {
    "country": "GD",
    "name": "Sauteurs",
    "lat": "12.21833",
    "lng": "-61.63917"
  },
  {
    "country": "GD",
    "name": "Saint George's",
    "lat": "12.05288",
    "lng": "-61.75226"
  },
  {
    "country": "GD",
    "name": "Saint David’s",
    "lat": "12.04903",
    "lng": "-61.66875"
  },
  {
    "country": "GD",
    "name": "Hillsborough",
    "lat": "12.48292",
    "lng": "-61.45597"
  },
  {
    "country": "GD",
    "name": "Grenville",
    "lat": "12.12278",
    "lng": "-61.62498"
  },
  {
    "country": "GD",
    "name": "Gouyave",
    "lat": "12.16462",
    "lng": "-61.72965"
  },
  {
    "country": "GE",
    "name": "Abastumani",
    "lat": "41.7075",
    "lng": "42.84571"
  },
  {
    "country": "GE",
    "name": "Zugdidi",
    "lat": "42.5088",
    "lng": "41.87088"
  },
  {
    "country": "GE",
    "name": "Zhinvali",
    "lat": "42.13181",
    "lng": "44.77264"
  },
  {
    "country": "GE",
    "name": "Zestap’oni",
    "lat": "42.11",
    "lng": "43.0525"
  },
  {
    "country": "GE",
    "name": "Zahesi",
    "lat": "41.82458",
    "lng": "44.75361"
  },
  {
    "country": "GE",
    "name": "Vani",
    "lat": "42.0832",
    "lng": "42.52163"
  },
  {
    "country": "GE",
    "name": "Vale",
    "lat": "41.61558",
    "lng": "42.87224"
  },
  {
    "country": "GE",
    "name": "Urek’i",
    "lat": "41.99556",
    "lng": "41.77861"
  },
  {
    "country": "GE",
    "name": "Tsnori",
    "lat": "41.62088",
    "lng": "45.96943"
  },
  {
    "country": "GE",
    "name": "Tsqnet’i",
    "lat": "41.69472",
    "lng": "44.69861"
  },
  {
    "country": "GE",
    "name": "Ts’khinvali",
    "lat": "42.22764",
    "lng": "43.96861"
  },
  {
    "country": "GE",
    "name": "Tsinandali",
    "lat": "41.89315",
    "lng": "45.57129"
  },
  {
    "country": "GE",
    "name": "Tsikhisdziri",
    "lat": "41.76659",
    "lng": "41.75517"
  },
  {
    "country": "GE",
    "name": "Tsalka",
    "lat": "41.5946",
    "lng": "44.08909"
  },
  {
    "country": "GE",
    "name": "Tsalenjikha",
    "lat": "42.60444",
    "lng": "42.06825"
  },
  {
    "country": "GE",
    "name": "Tsaghveri",
    "lat": "41.80365",
    "lng": "43.48194"
  },
  {
    "country": "GE",
    "name": "Tqvarch'eli",
    "lat": "42.84035",
    "lng": "41.68007"
  },
  {
    "country": "GE",
    "name": "Tqibuli",
    "lat": "42.35121",
    "lng": "42.99874"
  },
  {
    "country": "GE",
    "name": "T’ianet’i",
    "lat": "42.10833",
    "lng": "44.96389"
  },
  {
    "country": "GE",
    "name": "T’et’ri Tsqaro",
    "lat": "41.54448",
    "lng": "44.46153"
  },
  {
    "country": "GE",
    "name": "Telavi",
    "lat": "41.91978",
    "lng": "45.47315"
  },
  {
    "country": "GE",
    "name": "Tbilisi",
    "lat": "41.69411",
    "lng": "44.83368"
  },
  {
    "country": "GE",
    "name": "Surami",
    "lat": "42.02431",
    "lng": "43.55556"
  },
  {
    "country": "GE",
    "name": "Sokhumi",
    "lat": "43.00697",
    "lng": "40.9893"
  },
  {
    "country": "GE",
    "name": "Sighnaghi",
    "lat": "41.62046",
    "lng": "45.92198"
  },
  {
    "country": "GE",
    "name": "Shuakhevi",
    "lat": "41.63",
    "lng": "42.19083"
  },
  {
    "country": "GE",
    "name": "Shorapani",
    "lat": "42.0898",
    "lng": "43.08662"
  },
  {
    "country": "GE",
    "name": "Naghvarevi",
    "lat": "41.35272",
    "lng": "44.76178"
  },
  {
    "country": "GE",
    "name": "Senak’i",
    "lat": "42.27042",
    "lng": "42.0675"
  },
  {
    "country": "GE",
    "name": "Samtredia",
    "lat": "42.1537",
    "lng": "42.33517"
  },
  {
    "country": "GE",
    "name": "Sagarejo",
    "lat": "41.73397",
    "lng": "45.33149"
  },
  {
    "country": "GE",
    "name": "Sach’khere",
    "lat": "42.34528",
    "lng": "43.41944"
  },
  {
    "country": "GE",
    "name": "Rust’avi",
    "lat": "41.54949",
    "lng": "44.99323"
  },
  {
    "country": "GE",
    "name": "Qvareli",
    "lat": "41.95493",
    "lng": "45.81716"
  },
  {
    "country": "GE",
    "name": "P’ot’i",
    "lat": "42.14616",
    "lng": "41.67197"
  },
  {
    "country": "GE",
    "name": "P’asanauri",
    "lat": "42.3506",
    "lng": "44.68912"
  },
  {
    "country": "GE",
    "name": "Ozurgeti",
    "lat": "41.92442",
    "lng": "42.00682"
  },
  {
    "country": "GE",
    "name": "Orsant’ia",
    "lat": "42.46777",
    "lng": "41.67377"
  },
  {
    "country": "GE",
    "name": "Oni",
    "lat": "42.57944",
    "lng": "43.4425"
  },
  {
    "country": "GE",
    "name": "Ochkhamuri",
    "lat": "41.85975",
    "lng": "41.85309"
  },
  {
    "country": "GE",
    "name": "Och’amch’ire",
    "lat": "42.71232",
    "lng": "41.46863"
  },
  {
    "country": "GE",
    "name": "Ninotsminda",
    "lat": "41.26458",
    "lng": "43.59161"
  },
  {
    "country": "GE",
    "name": "Mtskheta",
    "lat": "41.84514",
    "lng": "44.71875"
  },
  {
    "country": "GE",
    "name": "Mest’ia",
    "lat": "43.04581",
    "lng": "42.7278"
  },
  {
    "country": "GE",
    "name": "Mart’vili",
    "lat": "42.41436",
    "lng": "42.37924"
  },
  {
    "country": "GE",
    "name": "Marneuli",
    "lat": "41.47588",
    "lng": "44.80895"
  },
  {
    "country": "GE",
    "name": "Manglisi",
    "lat": "41.69698",
    "lng": "44.38448"
  },
  {
    "country": "GE",
    "name": "Makhinjauri",
    "lat": "41.67385",
    "lng": "41.69401"
  },
  {
    "country": "GE",
    "name": "Lent’ekhi",
    "lat": "42.78893",
    "lng": "42.72226"
  },
  {
    "country": "GE",
    "name": "Lanchkhuti",
    "lat": "42.09027",
    "lng": "42.03239"
  },
  {
    "country": "GE",
    "name": "Lagodekhi",
    "lat": "41.82681",
    "lng": "46.27667"
  },
  {
    "country": "GE",
    "name": "Kveda Chkhorots’q’u",
    "lat": "42.48103",
    "lng": "42.09661"
  },
  {
    "country": "GE",
    "name": "Kutaisi",
    "lat": "42.26791",
    "lng": "42.69459"
  },
  {
    "country": "GE",
    "name": "K’ulashi",
    "lat": "42.20405",
    "lng": "42.34289"
  },
  {
    "country": "GE",
    "name": "Kobuleti",
    "lat": "41.82143",
    "lng": "41.77921"
  },
  {
    "country": "GE",
    "name": "Khulo",
    "lat": "41.64353",
    "lng": "42.30397"
  },
  {
    "country": "GE",
    "name": "Khoni",
    "lat": "42.3226",
    "lng": "42.42061"
  },
  {
    "country": "GE",
    "name": "Khobi",
    "lat": "42.31558",
    "lng": "41.89871"
  },
  {
    "country": "GE",
    "name": "Khelvachauri",
    "lat": "41.58556",
    "lng": "41.66889"
  },
  {
    "country": "GE",
    "name": "Khashuri",
    "lat": "41.99414",
    "lng": "43.59994"
  },
  {
    "country": "GE",
    "name": "Keda",
    "lat": "41.60093",
    "lng": "41.94008"
  },
  {
    "country": "GE",
    "name": "Step’antsminda",
    "lat": "42.65667",
    "lng": "44.64333"
  },
  {
    "country": "GE",
    "name": "Kats’khi",
    "lat": "42.29236",
    "lng": "43.20888"
  },
  {
    "country": "GE",
    "name": "Kaspi",
    "lat": "41.9252",
    "lng": "44.42568"
  },
  {
    "country": "GE",
    "name": "Java",
    "lat": "42.39972",
    "lng": "43.93667"
  },
  {
    "country": "GE",
    "name": "Gurjaani",
    "lat": "41.74292",
    "lng": "45.80111"
  },
  {
    "country": "GE",
    "name": "Gulrip’shi",
    "lat": "42.92694",
    "lng": "41.09639"
  },
  {
    "country": "GE",
    "name": "Gudauta",
    "lat": "43.10547",
    "lng": "40.62067"
  },
  {
    "country": "GE",
    "name": "Gudauri",
    "lat": "42.47797",
    "lng": "44.47616"
  },
  {
    "country": "GE",
    "name": "Gori",
    "lat": "42.51667",
    "lng": "43.16667"
  },
  {
    "country": "GE",
    "name": "Gori",
    "lat": "41.98422",
    "lng": "44.11578"
  },
  {
    "country": "GE",
    "name": "Gardabani",
    "lat": "41.46054",
    "lng": "45.09283"
  },
  {
    "country": "GE",
    "name": "Gantiadi",
    "lat": "43.38111",
    "lng": "40.07944"
  },
  {
    "country": "GE",
    "name": "Gali",
    "lat": "42.62655",
    "lng": "41.73808"
  },
  {
    "country": "GE",
    "name": "Gagra",
    "lat": "43.27858",
    "lng": "40.27124"
  },
  {
    "country": "GE",
    "name": "Jvari",
    "lat": "42.71693",
    "lng": "42.052"
  },
  {
    "country": "GE",
    "name": "Dzegvi",
    "lat": "41.84569",
    "lng": "44.60097"
  },
  {
    "country": "GE",
    "name": "Dranda",
    "lat": "42.87167",
    "lng": "41.15333"
  },
  {
    "country": "GE",
    "name": "Dmanisi",
    "lat": "41.52514",
    "lng": "44.3472"
  },
  {
    "country": "GE",
    "name": "Dioknisi",
    "lat": "41.62933",
    "lng": "42.39171"
  },
  {
    "country": "GE",
    "name": "Didi Lilo",
    "lat": "41.73611",
    "lng": "44.96472"
  },
  {
    "country": "GE",
    "name": "Chiat’ura",
    "lat": "42.29806",
    "lng": "43.29889"
  },
  {
    "country": "GE",
    "name": "Chakvi",
    "lat": "41.72528",
    "lng": "41.73278"
  },
  {
    "country": "GE",
    "name": "Borjomi",
    "lat": "41.85272",
    "lng": "43.41284"
  },
  {
    "country": "GE",
    "name": "Bolnisi",
    "lat": "41.44794",
    "lng": "44.53838"
  },
  {
    "country": "GE",
    "name": "Bich’vinta",
    "lat": "43.16197",
    "lng": "40.34102"
  },
  {
    "country": "GE",
    "name": "Batumi",
    "lat": "41.64228",
    "lng": "41.63392"
  },
  {
    "country": "GE",
    "name": "Bakuriani",
    "lat": "41.74972",
    "lng": "43.5325"
  },
  {
    "country": "GE",
    "name": "Bagdadi",
    "lat": "41.81667",
    "lng": "46.03333"
  },
  {
    "country": "GE",
    "name": "Aspindza",
    "lat": "41.57389",
    "lng": "43.24826"
  },
  {
    "country": "GE",
    "name": "Ambrolauri",
    "lat": "42.52111",
    "lng": "43.16222"
  },
  {
    "country": "GE",
    "name": "Akhmet’a",
    "lat": "42.03111",
    "lng": "45.2075"
  },
  {
    "country": "GE",
    "name": "Akhaltsikhe",
    "lat": "41.63901",
    "lng": "42.98262"
  },
  {
    "country": "GE",
    "name": "Akhalk’alak’i",
    "lat": "41.40514",
    "lng": "43.48629"
  },
  {
    "country": "GE",
    "name": "Stantsiya Novyy Afon",
    "lat": "43.08056",
    "lng": "40.83833"
  },
  {
    "country": "GE",
    "name": "Akhalgori",
    "lat": "42.12597",
    "lng": "44.48333"
  },
  {
    "country": "GE",
    "name": "Akhaldaba",
    "lat": "41.92945",
    "lng": "43.48762"
  },
  {
    "country": "GE",
    "name": "Akhaldaba",
    "lat": "41.65395",
    "lng": "42.15163"
  },
  {
    "country": "GE",
    "name": "Agara",
    "lat": "42.03761",
    "lng": "43.82382"
  },
  {
    "country": "GE",
    "name": "Adigeni",
    "lat": "41.68191",
    "lng": "42.69867"
  },
  {
    "country": "GE",
    "name": "Abasha",
    "lat": "42.20959",
    "lng": "42.22111"
  },
  {
    "country": "GE",
    "name": "P’rimorsk’oe",
    "lat": "43.09236",
    "lng": "40.6965"
  },
  {
    "country": "GE",
    "name": "Tsqaltubo",
    "lat": "42.34129",
    "lng": "42.5976"
  },
  {
    "country": "GE",
    "name": "Naruja",
    "lat": "41.90694",
    "lng": "41.95417"
  },
  {
    "country": "GE",
    "name": "Bakurianis Andeziti",
    "lat": "41.73371",
    "lng": "43.47242"
  },
  {
    "country": "GE",
    "name": "Kelasuri",
    "lat": "42.97877",
    "lng": "41.07067"
  },
  {
    "country": "GE",
    "name": "Kharagauli",
    "lat": "42.02137",
    "lng": "43.19773"
  },
  {
    "country": "GF",
    "name": "Sinnamary",
    "lat": "5.37676",
    "lng": "-52.95679"
  },
  {
    "country": "GF",
    "name": "Saint-Laurent-du-Maroni",
    "lat": "5.50153",
    "lng": "-54.02916"
  },
  {
    "country": "GF",
    "name": "Saint-Georges",
    "lat": "3.88857",
    "lng": "-51.80243"
  },
  {
    "country": "GF",
    "name": "Roura",
    "lat": "4.72874",
    "lng": "-52.32495"
  },
  {
    "country": "GF",
    "name": "Rémire",
    "lat": "4.88585",
    "lng": "-52.27857"
  },
  {
    "country": "GF",
    "name": "Régina",
    "lat": "4.313",
    "lng": "-52.13083"
  },
  {
    "country": "GF",
    "name": "Rémire-Montjoly",
    "lat": "4.91667",
    "lng": "-52.26667"
  },
  {
    "country": "GF",
    "name": "Matoury",
    "lat": "4.84921",
    "lng": "-52.32355"
  },
  {
    "country": "GF",
    "name": "Maripasoula",
    "lat": "3.64155",
    "lng": "-54.03167"
  },
  {
    "country": "GF",
    "name": "Mana",
    "lat": "5.66906",
    "lng": "-53.77897"
  },
  {
    "country": "GF",
    "name": "Macouria",
    "lat": "4.91216",
    "lng": "-52.37432"
  },
  {
    "country": "GF",
    "name": "Kourou",
    "lat": "5.16281",
    "lng": "-52.64265"
  },
  {
    "country": "GF",
    "name": "Iracoubo",
    "lat": "5.47952",
    "lng": "-53.20524"
  },
  {
    "country": "GF",
    "name": "Grand-Santi",
    "lat": "4.27295",
    "lng": "-54.38146"
  },
  {
    "country": "GF",
    "name": "Cayenne",
    "lat": "4.93333",
    "lng": "-52.33333"
  },
  {
    "country": "GF",
    "name": "Camopi",
    "lat": "3.16887",
    "lng": "-52.33525"
  },
  {
    "country": "GF",
    "name": "Apatou",
    "lat": "5.15526",
    "lng": "-54.34311"
  },
  {
    "country": "GG",
    "name": "Torteval",
    "lat": "49.43333",
    "lng": "-2.65"
  },
  {
    "country": "GG",
    "name": "Saint Sampson",
    "lat": "49.48389",
    "lng": "-2.52333"
  },
  {
    "country": "GG",
    "name": "Saint Peter Port",
    "lat": "49.45981",
    "lng": "-2.53527"
  },
  {
    "country": "GG",
    "name": "St Anne",
    "lat": "49.71549",
    "lng": "-2.20757"
  },
  {
    "country": "GG",
    "name": "Saint Saviour",
    "lat": "49.45694",
    "lng": "-2.63583"
  },
  {
    "country": "GG",
    "name": "Castel",
    "lat": "49.46757",
    "lng": "-2.60015"
  },
  {
    "country": "GG",
    "name": "St. Andrew`s",
    "lat": "49.45195",
    "lng": "-2.57286"
  },
  {
    "country": "GG",
    "name": "St Martin",
    "lat": "49.43713",
    "lng": "-2.55479"
  },
  {
    "country": "GH",
    "name": "Yendi",
    "lat": "9.44272",
    "lng": "-0.00991"
  },
  {
    "country": "GH",
    "name": "Winneba",
    "lat": "5.35113",
    "lng": "-0.62313"
  },
  {
    "country": "GH",
    "name": "Wenchi",
    "lat": "7.73916",
    "lng": "-2.10456"
  },
  {
    "country": "GH",
    "name": "Wa",
    "lat": "10.06069",
    "lng": "-2.50192"
  },
  {
    "country": "GH",
    "name": "Teshi Old Town",
    "lat": "5.58365",
    "lng": "-0.10722"
  },
  {
    "country": "GH",
    "name": "Tema",
    "lat": "5.6698",
    "lng": "-0.01657"
  },
  {
    "country": "GH",
    "name": "Techiman",
    "lat": "7.58417",
    "lng": "-1.93815"
  },
  {
    "country": "GH",
    "name": "Tarkwa",
    "lat": "5.30383",
    "lng": "-1.98956"
  },
  {
    "country": "GH",
    "name": "Tamale",
    "lat": "9.40079",
    "lng": "-0.8393"
  },
  {
    "country": "GH",
    "name": "Takoradi",
    "lat": "4.89816",
    "lng": "-1.76029"
  },
  {
    "country": "GH",
    "name": "Tafo",
    "lat": "6.73156",
    "lng": "-1.6137"
  },
  {
    "country": "GH",
    "name": "Swedru",
    "lat": "5.53711",
    "lng": "-0.69984"
  },
  {
    "country": "GH",
    "name": "Sunyani",
    "lat": "7.33991",
    "lng": "-2.32676"
  },
  {
    "country": "GH",
    "name": "Suhum",
    "lat": "6.04089",
    "lng": "-0.45004"
  },
  {
    "country": "GH",
    "name": "Shama Junction",
    "lat": "5.01806",
    "lng": "-1.66437"
  },
  {
    "country": "GH",
    "name": "Sekondi-Takoradi",
    "lat": "4.92678",
    "lng": "-1.75773"
  },
  {
    "country": "GH",
    "name": "Savelugu",
    "lat": "9.62441",
    "lng": "-0.8253"
  },
  {
    "country": "GH",
    "name": "Saltpond",
    "lat": "5.20913",
    "lng": "-1.06058"
  },
  {
    "country": "GH",
    "name": "Salaga",
    "lat": "8.55083",
    "lng": "-0.51875"
  },
  {
    "country": "GH",
    "name": "Prestea",
    "lat": "5.43274",
    "lng": "-2.14284"
  },
  {
    "country": "GH",
    "name": "Kasoa",
    "lat": "5.53449",
    "lng": "-0.41679"
  },
  {
    "country": "GH",
    "name": "Akim Oda",
    "lat": "5.92665",
    "lng": "-0.98577"
  },
  {
    "country": "GH",
    "name": "Obuase",
    "lat": "6.20228",
    "lng": "-1.66796"
  },
  {
    "country": "GH",
    "name": "Nungua",
    "lat": "5.60105",
    "lng": "-0.07713"
  },
  {
    "country": "GH",
    "name": "Nsawam",
    "lat": "5.80893",
    "lng": "-0.35026"
  },
  {
    "country": "GH",
    "name": "Nkawkaw",
    "lat": "6.55121",
    "lng": "-0.7662"
  },
  {
    "country": "GH",
    "name": "Navrongo",
    "lat": "10.89557",
    "lng": "-1.0921"
  },
  {
    "country": "GH",
    "name": "Mumford",
    "lat": "5.26176",
    "lng": "-0.75897"
  },
  {
    "country": "GH",
    "name": "Mpraeso",
    "lat": "6.59321",
    "lng": "-0.73462"
  },
  {
    "country": "GH",
    "name": "Mampong",
    "lat": "7.06273",
    "lng": "-1.4001"
  },
  {
    "country": "GH",
    "name": "Medina Estates",
    "lat": "5.6658",
    "lng": "-0.16307"
  },
  {
    "country": "GH",
    "name": "Kumasi",
    "lat": "6.68848",
    "lng": "-1.62443"
  },
  {
    "country": "GH",
    "name": "Kpandu",
    "lat": "6.99536",
    "lng": "0.29306"
  },
  {
    "country": "GH",
    "name": "Kpandae",
    "lat": "8.46885",
    "lng": "-0.01127"
  },
  {
    "country": "GH",
    "name": "Konongo",
    "lat": "6.61667",
    "lng": "-1.21667"
  },
  {
    "country": "GH",
    "name": "Koforidua",
    "lat": "6.09408",
    "lng": "-0.25913"
  },
  {
    "country": "GH",
    "name": "Kintampo",
    "lat": "8.05627",
    "lng": "-1.73058"
  },
  {
    "country": "GH",
    "name": "Kibi",
    "lat": "6.16494",
    "lng": "-0.55376"
  },
  {
    "country": "GH",
    "name": "Kete Krachi",
    "lat": "7.79391",
    "lng": "-0.0498"
  },
  {
    "country": "GH",
    "name": "Keta",
    "lat": "5.91793",
    "lng": "0.98789"
  },
  {
    "country": "GH",
    "name": "Japekrom",
    "lat": "7.5758",
    "lng": "-2.78516"
  },
  {
    "country": "GH",
    "name": "Hohoe",
    "lat": "7.15181",
    "lng": "0.47362"
  },
  {
    "country": "GH",
    "name": "Ho",
    "lat": "6.60084",
    "lng": "0.4713"
  },
  {
    "country": "GH",
    "name": "Gbawe",
    "lat": "5.57692",
    "lng": "-0.31038"
  },
  {
    "country": "GH",
    "name": "Foso",
    "lat": "5.70119",
    "lng": "-1.28657"
  },
  {
    "country": "GH",
    "name": "Elmina",
    "lat": "5.0847",
    "lng": "-1.35093"
  },
  {
    "country": "GH",
    "name": "Ejura",
    "lat": "7.38558",
    "lng": "-1.35617"
  },
  {
    "country": "GH",
    "name": "Dunkwa",
    "lat": "5.95996",
    "lng": "-1.77792"
  },
  {
    "country": "GH",
    "name": "Duayaw Nkwanta",
    "lat": "7.17242",
    "lng": "-2.10281"
  },
  {
    "country": "GH",
    "name": "Dome",
    "lat": "5.65003",
    "lng": "-0.2361"
  },
  {
    "country": "GH",
    "name": "Cape Coast",
    "lat": "5.10535",
    "lng": "-1.2466"
  },
  {
    "country": "GH",
    "name": "Bolgatanga",
    "lat": "10.78556",
    "lng": "-0.85139"
  },
  {
    "country": "GH",
    "name": "Bibiani",
    "lat": "6.46346",
    "lng": "-2.31938"
  },
  {
    "country": "GH",
    "name": "Berekum",
    "lat": "7.4534",
    "lng": "-2.58404"
  },
  {
    "country": "GH",
    "name": "Bekwai",
    "lat": "6.45195",
    "lng": "-1.57866"
  },
  {
    "country": "GH",
    "name": "Begoro",
    "lat": "6.38706",
    "lng": "-0.37738"
  },
  {
    "country": "GH",
    "name": "Bechem",
    "lat": "7.09034",
    "lng": "-2.02498"
  },
  {
    "country": "GH",
    "name": "Bawku",
    "lat": "11.0616",
    "lng": "-0.24169"
  },
  {
    "country": "GH",
    "name": "Axim",
    "lat": "4.86641",
    "lng": "-2.24181"
  },
  {
    "country": "GH",
    "name": "Asamankese",
    "lat": "5.86006",
    "lng": "-0.6635"
  },
  {
    "country": "GH",
    "name": "Apam",
    "lat": "5.28483",
    "lng": "-0.73711"
  },
  {
    "country": "GH",
    "name": "Anloga",
    "lat": "5.79473",
    "lng": "0.89728"
  },
  {
    "country": "GH",
    "name": "Akwatia",
    "lat": "6.04024",
    "lng": "-0.80876"
  },
  {
    "country": "GH",
    "name": "Akropong",
    "lat": "5.97462",
    "lng": "-0.08542"
  },
  {
    "country": "GH",
    "name": "Akim Swedru",
    "lat": "5.8938",
    "lng": "-1.01636"
  },
  {
    "country": "GH",
    "name": "Agogo",
    "lat": "6.80004",
    "lng": "-1.08193"
  },
  {
    "country": "GH",
    "name": "Aflao",
    "lat": "6.11982",
    "lng": "1.19012"
  },
  {
    "country": "GH",
    "name": "Atsiaman",
    "lat": "5.69775",
    "lng": "-0.32824"
  },
  {
    "country": "GH",
    "name": "Accra",
    "lat": "5.55602",
    "lng": "-0.1969"
  },
  {
    "country": "GH",
    "name": "Aburi",
    "lat": "5.84802",
    "lng": "-0.17449"
  },
  {
    "country": "GH",
    "name": "Aboso",
    "lat": "5.36073",
    "lng": "-1.94856"
  },
  {
    "country": "GH",
    "name": "Mamponteng",
    "lat": "6.73333",
    "lng": "-1.55"
  },
  {
    "country": "GH",
    "name": "Wassa-Akropong",
    "lat": "5.78722",
    "lng": "-2.08361"
  },
  {
    "country": "GH",
    "name": "Odumase Krobo",
    "lat": "6.53333",
    "lng": "-0.81667"
  },
  {
    "country": "GI",
    "name": "Gibraltar",
    "lat": "36.14474",
    "lng": "-5.35257"
  },
  {
    "country": "GL",
    "name": "Upernavik",
    "lat": "72.7872",
    "lng": "-56.14436"
  },
  {
    "country": "GL",
    "name": "Sisimiut",
    "lat": "66.93946",
    "lng": "-53.6735"
  },
  {
    "country": "GL",
    "name": "Qasigiannguit",
    "lat": "68.81926",
    "lng": "-51.19221"
  },
  {
    "country": "GL",
    "name": "Qaqortoq",
    "lat": "60.71839",
    "lng": "-46.03561"
  },
  {
    "country": "GL",
    "name": "Paamiut",
    "lat": "61.99402",
    "lng": "-49.66776"
  },
  {
    "country": "GL",
    "name": "Nuuk",
    "lat": "64.18347",
    "lng": "-51.72157"
  },
  {
    "country": "GL",
    "name": "Narsaq",
    "lat": "60.91298",
    "lng": "-46.05055"
  },
  {
    "country": "GL",
    "name": "Nanortalik",
    "lat": "60.14169",
    "lng": "-45.24069"
  },
  {
    "country": "GL",
    "name": "Maniitsoq",
    "lat": "65.41506",
    "lng": "-52.89822"
  },
  {
    "country": "GL",
    "name": "Ilulissat",
    "lat": "69.21981",
    "lng": "-51.09861"
  },
  {
    "country": "GL",
    "name": "Tasiilaq",
    "lat": "65.61451",
    "lng": "-37.63676"
  },
  {
    "country": "GL",
    "name": "Aasiaat",
    "lat": "68.70981",
    "lng": "-52.86988"
  },
  {
    "country": "GL",
    "name": "Uummannaq",
    "lat": "70.67442",
    "lng": "-52.12545"
  },
  {
    "country": "GM",
    "name": "Wellingara Ba",
    "lat": "13.41667",
    "lng": "-15.4"
  },
  {
    "country": "GM",
    "name": "Wassu",
    "lat": "13.69094",
    "lng": "-14.87884"
  },
  {
    "country": "GM",
    "name": "Toniataba",
    "lat": "13.43333",
    "lng": "-15.58333"
  },
  {
    "country": "GM",
    "name": "Sutukung",
    "lat": "13.46667",
    "lng": "-15.26667"
  },
  {
    "country": "GM",
    "name": "Sutukoba",
    "lat": "13.5",
    "lng": "-14.01667"
  },
  {
    "country": "GM",
    "name": "Sun Kunda",
    "lat": "13.38333",
    "lng": "-13.85"
  },
  {
    "country": "GM",
    "name": "Sukuta",
    "lat": "13.61667",
    "lng": "-14.91667"
  },
  {
    "country": "GM",
    "name": "Sukuta",
    "lat": "13.41033",
    "lng": "-16.70815"
  },
  {
    "country": "GM",
    "name": "Sudowol",
    "lat": "13.36667",
    "lng": "-13.96667"
  },
  {
    "country": "GM",
    "name": "Somita",
    "lat": "13.20583",
    "lng": "-16.30556"
  },
  {
    "country": "GM",
    "name": "Soma",
    "lat": "13.43333",
    "lng": "-15.53333"
  },
  {
    "country": "GM",
    "name": "Si Kunda",
    "lat": "13.43333",
    "lng": "-15.56667"
  },
  {
    "country": "GM",
    "name": "Serekunda",
    "lat": "13.43833",
    "lng": "-16.67806"
  },
  {
    "country": "GM",
    "name": "Saruja",
    "lat": "13.55",
    "lng": "-14.91667"
  },
  {
    "country": "GM",
    "name": "Sara Kunda",
    "lat": "13.53333",
    "lng": "-15.41667"
  },
  {
    "country": "GM",
    "name": "Sankwia",
    "lat": "13.46667",
    "lng": "-15.51667"
  },
  {
    "country": "GM",
    "name": "Sami",
    "lat": "13.58333",
    "lng": "-15.2"
  },
  {
    "country": "GM",
    "name": "Sabi",
    "lat": "13.23333",
    "lng": "-14.2"
  },
  {
    "country": "GM",
    "name": "Saba",
    "lat": "13.51639",
    "lng": "-16.04917"
  },
  {
    "country": "GM",
    "name": "Perai",
    "lat": "13.38333",
    "lng": "-14.03333"
  },
  {
    "country": "GM",
    "name": "Pateh Sam",
    "lat": "13.61667",
    "lng": "-15.06667"
  },
  {
    "country": "GM",
    "name": "Nyamanari",
    "lat": "13.33333",
    "lng": "-13.86667"
  },
  {
    "country": "GM",
    "name": "No Kunda",
    "lat": "13.56667",
    "lng": "-15.83333"
  },
  {
    "country": "GM",
    "name": "Nioro",
    "lat": "13.35",
    "lng": "-15.75"
  },
  {
    "country": "GM",
    "name": "Mansa Konko",
    "lat": "13.44325",
    "lng": "-15.5357"
  },
  {
    "country": "GM",
    "name": "Lamin",
    "lat": "13.35222",
    "lng": "-16.43389"
  },
  {
    "country": "GM",
    "name": "Kunting",
    "lat": "13.53333",
    "lng": "-14.66667"
  },
  {
    "country": "GM",
    "name": "Kuntaur",
    "lat": "13.67085",
    "lng": "-14.88977"
  },
  {
    "country": "GM",
    "name": "Kumbija",
    "lat": "13.26667",
    "lng": "-14.18333"
  },
  {
    "country": "GM",
    "name": "Koina",
    "lat": "13.48333",
    "lng": "-13.86667"
  },
  {
    "country": "GM",
    "name": "Kerewan",
    "lat": "13.4898",
    "lng": "-16.08879"
  },
  {
    "country": "GM",
    "name": "Keneba",
    "lat": "13.32889",
    "lng": "-16.015"
  },
  {
    "country": "GM",
    "name": "Katchang",
    "lat": "13.5",
    "lng": "-15.75"
  },
  {
    "country": "GM",
    "name": "Kass Wollof",
    "lat": "13.78333",
    "lng": "-14.93333"
  },
  {
    "country": "GM",
    "name": "Karantaba",
    "lat": "13.66667",
    "lng": "-15.03333"
  },
  {
    "country": "GM",
    "name": "Karantaba",
    "lat": "13.43333",
    "lng": "-15.51667"
  },
  {
    "country": "GM",
    "name": "Kaiaf",
    "lat": "13.4",
    "lng": "-15.61667"
  },
  {
    "country": "GM",
    "name": "Jifarong",
    "lat": "13.3",
    "lng": "-15.86667"
  },
  {
    "country": "GM",
    "name": "Jenoi",
    "lat": "13.48333",
    "lng": "-15.56667"
  },
  {
    "country": "GM",
    "name": "Jarreng",
    "lat": "13.61667",
    "lng": "-15.18333"
  },
  {
    "country": "GM",
    "name": "Jali",
    "lat": "13.35",
    "lng": "-15.96667"
  },
  {
    "country": "GM",
    "name": "Jakhaly",
    "lat": "13.55",
    "lng": "-14.96667"
  },
  {
    "country": "GM",
    "name": "Gunjur Kuta",
    "lat": "13.53333",
    "lng": "-14.11667"
  },
  {
    "country": "GM",
    "name": "Gunjur",
    "lat": "13.52278",
    "lng": "-16.02778"
  },
  {
    "country": "GM",
    "name": "Gunjur",
    "lat": "13.20194",
    "lng": "-16.73389"
  },
  {
    "country": "GM",
    "name": "Georgetown",
    "lat": "13.54039",
    "lng": "-14.76374"
  },
  {
    "country": "GM",
    "name": "Galleh Manda",
    "lat": "13.43333",
    "lng": "-14.78333"
  },
  {
    "country": "GM",
    "name": "Farafenni",
    "lat": "13.56667",
    "lng": "-15.6"
  },
  {
    "country": "GM",
    "name": "Essau",
    "lat": "13.48389",
    "lng": "-16.53472"
  },
  {
    "country": "GM",
    "name": "Diabugu Basilla",
    "lat": "13.33333",
    "lng": "-13.95"
  },
  {
    "country": "GM",
    "name": "Diabugu",
    "lat": "13.38333",
    "lng": "-14.4"
  },
  {
    "country": "GM",
    "name": "Denton",
    "lat": "13.5",
    "lng": "-14.93333"
  },
  {
    "country": "GM",
    "name": "Demba Kunda",
    "lat": "13.25",
    "lng": "-14.26667"
  },
  {
    "country": "GM",
    "name": "Daru Rilwan",
    "lat": "13.55",
    "lng": "-15.98333"
  },
  {
    "country": "GM",
    "name": "Dankunku",
    "lat": "13.56667",
    "lng": "-15.31667"
  },
  {
    "country": "GM",
    "name": "Daba Kunda",
    "lat": "13.31667",
    "lng": "-14.3"
  },
  {
    "country": "GM",
    "name": "Chilla",
    "lat": "13.55",
    "lng": "-16.28333"
  },
  {
    "country": "GM",
    "name": "Bureng",
    "lat": "13.41667",
    "lng": "-15.28333"
  },
  {
    "country": "GM",
    "name": "Brikama Nding",
    "lat": "13.53333",
    "lng": "-14.93333"
  },
  {
    "country": "GM",
    "name": "Brikama",
    "lat": "13.27136",
    "lng": "-16.64944"
  },
  {
    "country": "GM",
    "name": "Brifu",
    "lat": "13.5",
    "lng": "-13.93333"
  },
  {
    "country": "GM",
    "name": "Basse Santa Su",
    "lat": "13.30995",
    "lng": "-14.21373"
  },
  {
    "country": "GM",
    "name": "Barra",
    "lat": "13.48278",
    "lng": "-16.54556"
  },
  {
    "country": "GM",
    "name": "Baro Kunda",
    "lat": "13.48333",
    "lng": "-15.26667"
  },
  {
    "country": "GM",
    "name": "Bantanto",
    "lat": "13.41667",
    "lng": "-14.65"
  },
  {
    "country": "GM",
    "name": "Bansang",
    "lat": "13.43333",
    "lng": "-14.65"
  },
  {
    "country": "GM",
    "name": "Banjul",
    "lat": "13.45274",
    "lng": "-16.57803"
  },
  {
    "country": "GM",
    "name": "Bambali",
    "lat": "13.48333",
    "lng": "-15.33333"
  },
  {
    "country": "GM",
    "name": "Bakau",
    "lat": "13.47806",
    "lng": "-16.68194"
  },
  {
    "country": "GM",
    "name": "Bakadagy",
    "lat": "13.3",
    "lng": "-14.38333"
  },
  {
    "country": "GM",
    "name": "Abuko",
    "lat": "13.40417",
    "lng": "-16.65583"
  },
  {
    "country": "GN",
    "name": "Youkounkoun",
    "lat": "12.5311",
    "lng": "-13.1224"
  },
  {
    "country": "GN",
    "name": "Yomou",
    "lat": "7.56748",
    "lng": "-9.26283"
  },
  {
    "country": "GN",
    "name": "Tougué",
    "lat": "11.44503",
    "lng": "-11.66422"
  },
  {
    "country": "GN",
    "name": "Tondon",
    "lat": "10.36667",
    "lng": "-13.35"
  },
  {
    "country": "GN",
    "name": "Tokonou",
    "lat": "9.65",
    "lng": "-9.78333"
  },
  {
    "country": "GN",
    "name": "Télimélé",
    "lat": "10.9",
    "lng": "-13.03333"
  },
  {
    "country": "GN",
    "name": "Siguiri",
    "lat": "11.42282",
    "lng": "-9.16852"
  },
  {
    "country": "GN",
    "name": "Sanguéya",
    "lat": "10.7",
    "lng": "-14.36667"
  },
  {
    "country": "GN",
    "name": "Pita",
    "lat": "11.05915",
    "lng": "-12.39498"
  },
  {
    "country": "GN",
    "name": "Nzérékoré",
    "lat": "7.75624",
    "lng": "-8.8179"
  },
  {
    "country": "GN",
    "name": "Mandiana",
    "lat": "10.62577",
    "lng": "-8.69413"
  },
  {
    "country": "GN",
    "name": "Mamou",
    "lat": "10.37546",
    "lng": "-12.09148"
  },
  {
    "country": "GN",
    "name": "Mali",
    "lat": "12.079",
    "lng": "-12.2982"
  },
  {
    "country": "GN",
    "name": "Macenta",
    "lat": "8.54351",
    "lng": "-9.47099"
  },
  {
    "country": "GN",
    "name": "Lola",
    "lat": "7.8",
    "lng": "-8.53333"
  },
  {
    "country": "GN",
    "name": "Labé",
    "lat": "11.31823",
    "lng": "-12.28332"
  },
  {
    "country": "GN",
    "name": "Kouroussa",
    "lat": "10.65",
    "lng": "-9.88333"
  },
  {
    "country": "GN",
    "name": "Koundara",
    "lat": "12.48333",
    "lng": "-13.3"
  },
  {
    "country": "GN",
    "name": "Koubia",
    "lat": "11.58632",
    "lng": "-11.89485"
  },
  {
    "country": "GN",
    "name": "Kissidougou",
    "lat": "9.1848",
    "lng": "-10.09987"
  },
  {
    "country": "GN",
    "name": "Kindia",
    "lat": "10.05692",
    "lng": "-12.86576"
  },
  {
    "country": "GN",
    "name": "Kimbo",
    "lat": "10.4",
    "lng": "-13.55"
  },
  {
    "country": "GN",
    "name": "Kérouané",
    "lat": "9.26667",
    "lng": "-9.01667"
  },
  {
    "country": "GN",
    "name": "Kankan",
    "lat": "10.38542",
    "lng": "-9.30568"
  },
  {
    "country": "GN",
    "name": "Kamsar",
    "lat": "10.66667",
    "lng": "-14.6"
  },
  {
    "country": "GN",
    "name": "Gueckedou",
    "lat": "8.56744",
    "lng": "-10.1336"
  },
  {
    "country": "GN",
    "name": "Gaoual",
    "lat": "11.75",
    "lng": "-13.2"
  },
  {
    "country": "GN",
    "name": "Fria",
    "lat": "10.36676",
    "lng": "-13.58253"
  },
  {
    "country": "GN",
    "name": "Forécariah",
    "lat": "9.43056",
    "lng": "-13.08806"
  },
  {
    "country": "GN",
    "name": "Faranah",
    "lat": "10.04036",
    "lng": "-10.74343"
  },
  {
    "country": "GN",
    "name": "Dubréka",
    "lat": "9.79111",
    "lng": "-13.52333"
  },
  {
    "country": "GN",
    "name": "Dinguiraye",
    "lat": "11.29062",
    "lng": "-10.7121"
  },
  {
    "country": "GN",
    "name": "Dalaba",
    "lat": "10.69249",
    "lng": "-12.24967"
  },
  {
    "country": "GN",
    "name": "Dabola",
    "lat": "10.7433",
    "lng": "-11.10778"
  },
  {
    "country": "GN",
    "name": "Coyah",
    "lat": "9.70643",
    "lng": "-13.38465"
  },
  {
    "country": "GN",
    "name": "Conakry",
    "lat": "9.53795",
    "lng": "-13.67729"
  },
  {
    "country": "GN",
    "name": "Camayenne",
    "lat": "9.535",
    "lng": "-13.68778"
  },
  {
    "country": "GN",
    "name": "Boké",
    "lat": "10.93217",
    "lng": "-14.29055"
  },
  {
    "country": "GN",
    "name": "Boffa",
    "lat": "10.16667",
    "lng": "-14.03333"
  },
  {
    "country": "GN",
    "name": "Beyla",
    "lat": "8.69011",
    "lng": "-8.64869"
  },
  {
    "country": "GN",
    "name": "Lélouma",
    "lat": "11.42383",
    "lng": "-12.68183"
  },
  {
    "country": "GP",
    "name": "Vieux-Habitants",
    "lat": "16.05866",
    "lng": "-61.76667"
  },
  {
    "country": "GP",
    "name": "Trois-Rivières",
    "lat": "15.97595",
    "lng": "-61.64492"
  },
  {
    "country": "GP",
    "name": "Petites Anses",
    "lat": "15.84993",
    "lng": "-61.64457"
  },
  {
    "country": "GP",
    "name": "Saint-François",
    "lat": "16.25236",
    "lng": "-61.27332"
  },
  {
    "country": "GP",
    "name": "Sainte-Rose",
    "lat": "16.33264",
    "lng": "-61.6969"
  },
  {
    "country": "GP",
    "name": "Sainte-Anne",
    "lat": "16.22564",
    "lng": "-61.38098"
  },
  {
    "country": "GP",
    "name": "Saint-Claude",
    "lat": "16.02515",
    "lng": "-61.69975"
  },
  {
    "country": "GP",
    "name": "Port-Louis",
    "lat": "16.41749",
    "lng": "-61.53045"
  },
  {
    "country": "GP",
    "name": "Pointe-Noire",
    "lat": "16.23218",
    "lng": "-61.78917"
  },
  {
    "country": "GP",
    "name": "Pointe-à-Pitre",
    "lat": "16.24125",
    "lng": "-61.53614"
  },
  {
    "country": "GP",
    "name": "Petit-Canal",
    "lat": "16.37913",
    "lng": "-61.48716"
  },
  {
    "country": "GP",
    "name": "Petit-Bourg",
    "lat": "16.19163",
    "lng": "-61.5914"
  },
  {
    "country": "GP",
    "name": "Les Abymes",
    "lat": "16.273",
    "lng": "-61.50507"
  },
  {
    "country": "GP",
    "name": "Le Moule",
    "lat": "16.33164",
    "lng": "-61.34656"
  },
  {
    "country": "GP",
    "name": "Le Gosier",
    "lat": "16.20618",
    "lng": "-61.49306"
  },
  {
    "country": "GP",
    "name": "Lamentin",
    "lat": "16.27047",
    "lng": "-61.63166"
  },
  {
    "country": "GP",
    "name": "Beauséjour",
    "lat": "16.30413",
    "lng": "-61.07375"
  },
  {
    "country": "GP",
    "name": "Grand-Bourg",
    "lat": "15.88402",
    "lng": "-61.3148"
  },
  {
    "country": "GP",
    "name": "Gourbeyre",
    "lat": "15.99454",
    "lng": "-61.69203"
  },
  {
    "country": "GP",
    "name": "Capesterre-Belle-Eau",
    "lat": "16.04495",
    "lng": "-61.56425"
  },
  {
    "country": "GP",
    "name": "Bouillante",
    "lat": "16.13043",
    "lng": "-61.76895"
  },
  {
    "country": "GP",
    "name": "Basse-Terre",
    "lat": "15.99714",
    "lng": "-61.73214"
  },
  {
    "country": "GP",
    "name": "Baillif",
    "lat": "16.02037",
    "lng": "-61.74611"
  },
  {
    "country": "GP",
    "name": "Baie-Mahault",
    "lat": "16.26738",
    "lng": "-61.58543"
  },
  {
    "country": "GP",
    "name": "Anse-Bertrand",
    "lat": "16.47239",
    "lng": "-61.50739"
  },
  {
    "country": "GQ",
    "name": "Santiago de Baney",
    "lat": "3.6992",
    "lng": "8.9084"
  },
  {
    "country": "GQ",
    "name": "San Antonio de Palé",
    "lat": "-1.4068",
    "lng": "5.63178"
  },
  {
    "country": "GQ",
    "name": "Río Campo",
    "lat": "2.33812",
    "lng": "9.82212"
  },
  {
    "country": "GQ",
    "name": "Rebola",
    "lat": "3.71667",
    "lng": "8.83333"
  },
  {
    "country": "GQ",
    "name": "Nsok",
    "lat": "1.12985",
    "lng": "11.26603"
  },
  {
    "country": "GQ",
    "name": "Nsang",
    "lat": "2.02475",
    "lng": "10.94599"
  },
  {
    "country": "GQ",
    "name": "Ncue",
    "lat": "2.01643",
    "lng": "10.47066"
  },
  {
    "country": "GQ",
    "name": "Mongomo",
    "lat": "1.62742",
    "lng": "11.31346"
  },
  {
    "country": "GQ",
    "name": "Mikomeseng",
    "lat": "2.13609",
    "lng": "10.61322"
  },
  {
    "country": "GQ",
    "name": "Mbini",
    "lat": "1.58267",
    "lng": "9.61478"
  },
  {
    "country": "GQ",
    "name": "Machinda",
    "lat": "1.88262",
    "lng": "9.95133"
  },
  {
    "country": "GQ",
    "name": "Evinayong",
    "lat": "1.43677",
    "lng": "10.55124"
  },
  {
    "country": "GQ",
    "name": "Ebebiyin",
    "lat": "2.15106",
    "lng": "11.33528"
  },
  {
    "country": "GQ",
    "name": "Malabo",
    "lat": "3.75578",
    "lng": "8.78166"
  },
  {
    "country": "GQ",
    "name": "Luba",
    "lat": "3.45683",
    "lng": "8.55465"
  },
  {
    "country": "GQ",
    "name": "Bitica",
    "lat": "1.4261",
    "lng": "9.62316"
  },
  {
    "country": "GQ",
    "name": "Bicurga",
    "lat": "1.58113",
    "lng": "10.46716"
  },
  {
    "country": "GQ",
    "name": "Bata",
    "lat": "1.86391",
    "lng": "9.76582"
  },
  {
    "country": "GQ",
    "name": "Ayene",
    "lat": "1.85592",
    "lng": "10.68994"
  },
  {
    "country": "GQ",
    "name": "Añisoc",
    "lat": "1.8658",
    "lng": "10.76892"
  },
  {
    "country": "GQ",
    "name": "Acurenam",
    "lat": "1.03225",
    "lng": "10.64882"
  },
  {
    "country": "GQ",
    "name": "Aconibe",
    "lat": "1.29683",
    "lng": "10.93691"
  },
  {
    "country": "GR",
    "name": "Zonianá",
    "lat": "35.29502",
    "lng": "24.82944"
  },
  {
    "country": "GR",
    "name": "Zevgolateió",
    "lat": "37.93333",
    "lng": "22.8"
  },
  {
    "country": "GR",
    "name": "Zarós",
    "lat": "35.1303",
    "lng": "24.90412"
  },
  {
    "country": "GR",
    "name": "Zárkos",
    "lat": "39.6086",
    "lng": "22.12336"
  },
  {
    "country": "GR",
    "name": "Zakynthos",
    "lat": "37.78022",
    "lng": "20.89555"
  },
  {
    "country": "GR",
    "name": "Zacháro",
    "lat": "37.48333",
    "lng": "21.65"
  },
  {
    "country": "GR",
    "name": "Zagorá",
    "lat": "39.45",
    "lng": "23.1"
  },
  {
    "country": "GR",
    "name": "Gýtheio",
    "lat": "36.755",
    "lng": "22.56417"
  },
  {
    "country": "GR",
    "name": "Yimnón",
    "lat": "38.44048",
    "lng": "23.884"
  },
  {
    "country": "GR",
    "name": "Giánnouli",
    "lat": "39.66717",
    "lng": "22.39597"
  },
  {
    "country": "GR",
    "name": "Gérgeri",
    "lat": "35.13281",
    "lng": "24.94963"
  },
  {
    "country": "GR",
    "name": "Geráni",
    "lat": "35.51721",
    "lng": "23.87818"
  },
  {
    "country": "GR",
    "name": "Geráki",
    "lat": "36.99227",
    "lng": "22.70663"
  },
  {
    "country": "GR",
    "name": "Géfyra",
    "lat": "36.68715",
    "lng": "23.03509"
  },
  {
    "country": "GR",
    "name": "Xylókastro",
    "lat": "38.07762",
    "lng": "22.63166"
  },
  {
    "country": "GR",
    "name": "Vrontádos",
    "lat": "38.40876",
    "lng": "26.12948"
  },
  {
    "country": "GR",
    "name": "Vrýses",
    "lat": "35.37585",
    "lng": "24.20109"
  },
  {
    "country": "GR",
    "name": "Vraná",
    "lat": "38.12497",
    "lng": "23.95198"
  },
  {
    "country": "GR",
    "name": "Vrachnaíika",
    "lat": "38.16253",
    "lng": "21.66693"
  },
  {
    "country": "GR",
    "name": "Vrakháti",
    "lat": "37.95895",
    "lng": "22.80573"
  },
  {
    "country": "GR",
    "name": "Vounoplagiá",
    "lat": "39.69161",
    "lng": "20.78597"
  },
  {
    "country": "GR",
    "name": "Vouliagméni",
    "lat": "37.81423",
    "lng": "23.77892"
  },
  {
    "country": "GR",
    "name": "Voúla",
    "lat": "37.84221",
    "lng": "23.77651"
  },
  {
    "country": "GR",
    "name": "Vónitsa",
    "lat": "38.91639",
    "lng": "20.88639"
  },
  {
    "country": "GR",
    "name": "Volos",
    "lat": "39.36103",
    "lng": "22.94248"
  },
  {
    "country": "GR",
    "name": "Vokhaïkó",
    "lat": "37.94843",
    "lng": "22.79203"
  },
  {
    "country": "GR",
    "name": "Vlachópoulo",
    "lat": "37.03186",
    "lng": "21.79158"
  },
  {
    "country": "GR",
    "name": "Vlachiótis",
    "lat": "36.86094",
    "lng": "22.70831"
  },
  {
    "country": "GR",
    "name": "Výronas",
    "lat": "37.96105",
    "lng": "23.753"
  },
  {
    "country": "GR",
    "name": "Vília",
    "lat": "38.16716",
    "lng": "23.33659"
  },
  {
    "country": "GR",
    "name": "Aktaío",
    "lat": "38.30444",
    "lng": "21.7944"
  },
  {
    "country": "GR",
    "name": "Verdikoússa",
    "lat": "39.78175",
    "lng": "21.97728"
  },
  {
    "country": "GR",
    "name": "Vélo",
    "lat": "37.9761",
    "lng": "22.75985"
  },
  {
    "country": "GR",
    "name": "Velestíno",
    "lat": "39.38181",
    "lng": "22.74616"
  },
  {
    "country": "GR",
    "name": "Vágia",
    "lat": "38.31748",
    "lng": "23.17752"
  },
  {
    "country": "GR",
    "name": "Vathí",
    "lat": "38.4049",
    "lng": "23.60332"
  },
  {
    "country": "GR",
    "name": "Vathý",
    "lat": "37.7642",
    "lng": "23.48011"
  },
  {
    "country": "GR",
    "name": "Vathý",
    "lat": "37.74692",
    "lng": "26.98316"
  },
  {
    "country": "GR",
    "name": "Vasilikón",
    "lat": "38.42586",
    "lng": "23.67189"
  },
  {
    "country": "GR",
    "name": "Vasilikí",
    "lat": "39.63984",
    "lng": "21.70448"
  },
  {
    "country": "GR",
    "name": "Varvásaina",
    "lat": "37.67106",
    "lng": "21.49886"
  },
  {
    "country": "GR",
    "name": "Vartholomió",
    "lat": "37.86219",
    "lng": "21.20575"
  },
  {
    "country": "GR",
    "name": "Varnávas",
    "lat": "38.22358",
    "lng": "23.92307"
  },
  {
    "country": "GR",
    "name": "Vareiá",
    "lat": "39.07941",
    "lng": "26.57777"
  },
  {
    "country": "GR",
    "name": "Vári",
    "lat": "37.8332",
    "lng": "23.80311"
  },
  {
    "country": "GR",
    "name": "Vári",
    "lat": "37.39859",
    "lng": "24.94904"
  },
  {
    "country": "GR",
    "name": "Várda",
    "lat": "38.03058",
    "lng": "21.36506"
  },
  {
    "country": "GR",
    "name": "Vanáton",
    "lat": "37.79446",
    "lng": "20.85188"
  },
  {
    "country": "GR",
    "name": "Vamvakoú",
    "lat": "39.33708",
    "lng": "22.41983"
  },
  {
    "country": "GR",
    "name": "Valsamáta",
    "lat": "38.176",
    "lng": "20.58392"
  },
  {
    "country": "GR",
    "name": "Tsikalariá",
    "lat": "35.47623",
    "lng": "24.06274"
  },
  {
    "country": "GR",
    "name": "Tsarítsani",
    "lat": "39.88117",
    "lng": "22.22758"
  },
  {
    "country": "GR",
    "name": "Trípoli",
    "lat": "37.50889",
    "lng": "22.37944"
  },
  {
    "country": "GR",
    "name": "Tríkeri",
    "lat": "39.10114",
    "lng": "23.07669"
  },
  {
    "country": "GR",
    "name": "Tríkala",
    "lat": "39.55493",
    "lng": "21.76837"
  },
  {
    "country": "GR",
    "name": "Triandaíika",
    "lat": "38.6553",
    "lng": "21.38315"
  },
  {
    "country": "GR",
    "name": "Ialysós",
    "lat": "36.41352",
    "lng": "28.15516"
  },
  {
    "country": "GR",
    "name": "Traganón",
    "lat": "37.89789",
    "lng": "21.31245"
  },
  {
    "country": "GR",
    "name": "Tolón",
    "lat": "37.52021",
    "lng": "22.8586"
  },
  {
    "country": "GR",
    "name": "Týrnavos",
    "lat": "39.73778",
    "lng": "22.28917"
  },
  {
    "country": "GR",
    "name": "Tínos",
    "lat": "37.53753",
    "lng": "25.16343"
  },
  {
    "country": "GR",
    "name": "Tympáki",
    "lat": "35.07286",
    "lng": "24.76851"
  },
  {
    "country": "GR",
    "name": "Tílisos",
    "lat": "35.29607",
    "lng": "25.01587"
  },
  {
    "country": "GR",
    "name": "Thrapsanón",
    "lat": "35.18798",
    "lng": "25.28091"
  },
  {
    "country": "GR",
    "name": "Thouría",
    "lat": "37.08356",
    "lng": "22.04891"
  },
  {
    "country": "GR",
    "name": "Thívai",
    "lat": "38.325",
    "lng": "23.31889"
  },
  {
    "country": "GR",
    "name": "Firá",
    "lat": "36.42107",
    "lng": "25.43087"
  },
  {
    "country": "GR",
    "name": "Thymianá",
    "lat": "38.31439",
    "lng": "26.13259"
  },
  {
    "country": "GR",
    "name": "Thesprotikó",
    "lat": "39.25114",
    "lng": "20.78528"
  },
  {
    "country": "GR",
    "name": "Thespiés",
    "lat": "38.303",
    "lng": "23.15016"
  },
  {
    "country": "GR",
    "name": "Thérmo",
    "lat": "38.57358",
    "lng": "21.66628"
  },
  {
    "country": "GR",
    "name": "Terpsithéa",
    "lat": "39.61898",
    "lng": "22.35087"
  },
  {
    "country": "GR",
    "name": "Témeni",
    "lat": "38.23707",
    "lng": "22.12533"
  },
  {
    "country": "GR",
    "name": "Távros",
    "lat": "37.97064",
    "lng": "23.69043"
  },
  {
    "country": "GR",
    "name": "Steíri",
    "lat": "38.40831",
    "lng": "22.71162"
  },
  {
    "country": "GR",
    "name": "Stýpsi",
    "lat": "39.31121",
    "lng": "26.22056"
  },
  {
    "country": "GR",
    "name": "Stylída",
    "lat": "38.91667",
    "lng": "22.61667"
  },
  {
    "country": "GR",
    "name": "Stefanovíkeio",
    "lat": "39.46354",
    "lng": "22.74198"
  },
  {
    "country": "GR",
    "name": "Stavrós",
    "lat": "38.89641",
    "lng": "22.37082"
  },
  {
    "country": "GR",
    "name": "Stavráki",
    "lat": "39.65614",
    "lng": "20.81806"
  },
  {
    "country": "GR",
    "name": "Stános",
    "lat": "38.80453",
    "lng": "21.17461"
  },
  {
    "country": "GR",
    "name": "Stamáta",
    "lat": "38.12546",
    "lng": "23.88038"
  },
  {
    "country": "GR",
    "name": "Stalís",
    "lat": "35.29257",
    "lng": "25.43292"
  },
  {
    "country": "GR",
    "name": "Spétses",
    "lat": "37.26191",
    "lng": "23.15943"
  },
  {
    "country": "GR",
    "name": "Sperchógeia",
    "lat": "37.07405",
    "lng": "22.06248"
  },
  {
    "country": "GR",
    "name": "Spercheiáda",
    "lat": "38.90656",
    "lng": "22.12792"
  },
  {
    "country": "GR",
    "name": "Spáta",
    "lat": "37.96163",
    "lng": "23.91514"
  },
  {
    "country": "GR",
    "name": "Spárti",
    "lat": "37.07446",
    "lng": "22.43009"
  },
  {
    "country": "GR",
    "name": "Soúrpi",
    "lat": "39.10319",
    "lng": "22.89789"
  },
  {
    "country": "GR",
    "name": "Soúda",
    "lat": "35.48717",
    "lng": "24.07344"
  },
  {
    "country": "GR",
    "name": "Sofikón",
    "lat": "37.79412",
    "lng": "23.05204"
  },
  {
    "country": "GR",
    "name": "Sofádes",
    "lat": "39.33333",
    "lng": "22.1"
  },
  {
    "country": "GR",
    "name": "Skópelos",
    "lat": "39.12144",
    "lng": "23.72686"
  },
  {
    "country": "GR",
    "name": "Skópelos",
    "lat": "39.02922",
    "lng": "26.44836"
  },
  {
    "country": "GR",
    "name": "Skýros",
    "lat": "38.90417",
    "lng": "24.56306"
  },
  {
    "country": "GR",
    "name": "Skiáthos",
    "lat": "39.16227",
    "lng": "23.49089"
  },
  {
    "country": "GR",
    "name": "Schísma Eloúndas",
    "lat": "35.25757",
    "lng": "25.72796"
  },
  {
    "country": "GR",
    "name": "Schimatári",
    "lat": "38.35",
    "lng": "23.58333"
  },
  {
    "country": "GR",
    "name": "Skarmagkás",
    "lat": "38.01133",
    "lng": "23.60303"
  },
  {
    "country": "GR",
    "name": "Skála Oropoú",
    "lat": "38.31964",
    "lng": "23.78763"
  },
  {
    "country": "GR",
    "name": "Skalánion",
    "lat": "35.28262",
    "lng": "25.18684"
  },
  {
    "country": "GR",
    "name": "Skála",
    "lat": "37.32218",
    "lng": "26.543"
  },
  {
    "country": "GR",
    "name": "Skála",
    "lat": "36.85",
    "lng": "22.66667"
  },
  {
    "country": "GR",
    "name": "Sitia",
    "lat": "35.20783",
    "lng": "26.10467"
  },
  {
    "country": "GR",
    "name": "Sísion",
    "lat": "35.3077",
    "lng": "25.52021"
  },
  {
    "country": "GR",
    "name": "Synoikismós Chavaríou",
    "lat": "37.85575",
    "lng": "21.38789"
  },
  {
    "country": "GR",
    "name": "Sými",
    "lat": "36.61547",
    "lng": "27.83619"
  },
  {
    "country": "GR",
    "name": "Sylivainiótika",
    "lat": "38.16139",
    "lng": "22.33156"
  },
  {
    "country": "GR",
    "name": "Sykoúrio",
    "lat": "39.75947",
    "lng": "22.58"
  },
  {
    "country": "GR",
    "name": "Sikyón",
    "lat": "37.9823",
    "lng": "22.72462"
  },
  {
    "country": "GR",
    "name": "Síkinos",
    "lat": "36.7",
    "lng": "25.11667"
  },
  {
    "country": "GR",
    "name": "Sykiá",
    "lat": "36.76398",
    "lng": "22.94302"
  },
  {
    "country": "GR",
    "name": "Sérifos",
    "lat": "37.15397",
    "lng": "24.50614"
  },
  {
    "country": "GR",
    "name": "Selínia",
    "lat": "37.9332",
    "lng": "23.53147"
  },
  {
    "country": "GR",
    "name": "Savália",
    "lat": "37.82158",
    "lng": "21.29425"
  },
  {
    "country": "GR",
    "name": "Sardínia",
    "lat": "38.89003",
    "lng": "21.20619"
  },
  {
    "country": "GR",
    "name": "Samos",
    "lat": "37.75744",
    "lng": "26.97616"
  },
  {
    "country": "GR",
    "name": "Sámi",
    "lat": "38.25081",
    "lng": "20.64686"
  },
  {
    "country": "GR",
    "name": "Salamína",
    "lat": "37.96427",
    "lng": "23.49649"
  },
  {
    "country": "GR",
    "name": "Royítika",
    "lat": "38.18268",
    "lng": "21.68414"
  },
  {
    "country": "GR",
    "name": "Roviés",
    "lat": "38.80971",
    "lng": "23.23073"
  },
  {
    "country": "GR",
    "name": "Neápolis",
    "lat": "38.67144",
    "lng": "21.36274"
  },
  {
    "country": "GR",
    "name": "Rodotópi",
    "lat": "39.70822",
    "lng": "20.72656"
  },
  {
    "country": "GR",
    "name": "Rododáfni",
    "lat": "38.26976",
    "lng": "22.04875"
  },
  {
    "country": "GR",
    "name": "Rodhítsa",
    "lat": "38.88829",
    "lng": "22.4641"
  },
  {
    "country": "GR",
    "name": "Rizómylos",
    "lat": "39.42763",
    "lng": "22.74717"
  },
  {
    "country": "GR",
    "name": "Rízoma",
    "lat": "39.66432",
    "lng": "21.73541"
  },
  {
    "country": "GR",
    "name": "Río",
    "lat": "38.29558",
    "lng": "21.78504"
  },
  {
    "country": "GR",
    "name": "Rethymno",
    "lat": "35.36555",
    "lng": "24.48232"
  },
  {
    "country": "GR",
    "name": "Rafína",
    "lat": "38.01812",
    "lng": "24.00599"
  },
  {
    "country": "GR",
    "name": "Pteleós",
    "lat": "39.05261",
    "lng": "22.95271"
  },
  {
    "country": "GR",
    "name": "Psychikó",
    "lat": "38.01324",
    "lng": "23.77223"
  },
  {
    "country": "GR",
    "name": "Psachná",
    "lat": "38.57852",
    "lng": "23.64326"
  },
  {
    "country": "GR",
    "name": "Prokópi",
    "lat": "38.73402",
    "lng": "23.4906"
  },
  {
    "country": "GR",
    "name": "Profítis Ilías",
    "lat": "35.20555",
    "lng": "25.09985"
  },
  {
    "country": "GR",
    "name": "Préveza",
    "lat": "38.95617",
    "lng": "20.7505"
  },
  {
    "country": "GR",
    "name": "Prámanta",
    "lat": "39.52306",
    "lng": "21.10139"
  },
  {
    "country": "GR",
    "name": "Pórto Chéli",
    "lat": "37.32786",
    "lng": "23.14384"
  },
  {
    "country": "GR",
    "name": "Portariá",
    "lat": "39.3895",
    "lng": "22.99948"
  },
  {
    "country": "GR",
    "name": "Póros",
    "lat": "38.15369",
    "lng": "20.7712"
  },
  {
    "country": "GR",
    "name": "Póros",
    "lat": "37.49944",
    "lng": "23.45361"
  },
  {
    "country": "GR",
    "name": "Politiká",
    "lat": "38.59673",
    "lng": "23.54457"
  },
  {
    "country": "GR",
    "name": "Polichnítos",
    "lat": "39.07911",
    "lng": "26.18215"
  },
  {
    "country": "GR",
    "name": "Polydéndri",
    "lat": "38.216",
    "lng": "23.86806"
  },
  {
    "country": "GR",
    "name": "Plomári",
    "lat": "38.97527",
    "lng": "26.37137"
  },
  {
    "country": "GR",
    "name": "Platýkampos",
    "lat": "39.61667",
    "lng": "22.53333"
  },
  {
    "country": "GR",
    "name": "Platariá",
    "lat": "39.45044",
    "lng": "20.27781"
  },
  {
    "country": "GR",
    "name": "Plátanos",
    "lat": "37.66731",
    "lng": "21.61108"
  },
  {
    "country": "GR",
    "name": "Pigí",
    "lat": "39.51061",
    "lng": "21.70103"
  },
  {
    "country": "GR",
    "name": "Pithári",
    "lat": "35.51672",
    "lng": "24.08653"
  },
  {
    "country": "GR",
    "name": "Pythagóreio",
    "lat": "37.69102",
    "lng": "26.94341"
  },
  {
    "country": "GR",
    "name": "Pyrgetós",
    "lat": "39.91869",
    "lng": "22.59339"
  },
  {
    "country": "GR",
    "name": "Pyrgetós",
    "lat": "39.55276",
    "lng": "21.74846"
  },
  {
    "country": "GR",
    "name": "Pýrgos",
    "lat": "37.67513",
    "lng": "21.44102"
  },
  {
    "country": "GR",
    "name": "Pýrgos",
    "lat": "35.00611",
    "lng": "25.15191"
  },
  {
    "country": "GR",
    "name": "Piraeus",
    "lat": "37.94745",
    "lng": "23.63708"
  },
  {
    "country": "GR",
    "name": "Pýlos",
    "lat": "36.91298",
    "lng": "21.6965"
  },
  {
    "country": "GR",
    "name": "Pylí",
    "lat": "36.84472",
    "lng": "27.15932"
  },
  {
    "country": "GR",
    "name": "Pýli",
    "lat": "39.45806",
    "lng": "21.61889"
  },
  {
    "country": "GR",
    "name": "Pikérmi",
    "lat": "38.00161",
    "lng": "23.94075"
  },
  {
    "country": "GR",
    "name": "Petroúpolis",
    "lat": "38.04187",
    "lng": "23.68494"
  },
  {
    "country": "GR",
    "name": "Pétra",
    "lat": "39.32682",
    "lng": "26.17648"
  },
  {
    "country": "GR",
    "name": "Péta",
    "lat": "39.16667",
    "lng": "21.03472"
  },
  {
    "country": "GR",
    "name": "Periyiáli",
    "lat": "37.94041",
    "lng": "22.83946"
  },
  {
    "country": "GR",
    "name": "Perivóli",
    "lat": "39.41936",
    "lng": "20.01469"
  },
  {
    "country": "GR",
    "name": "Perivólia",
    "lat": "35.48491",
    "lng": "23.99421"
  },
  {
    "country": "GR",
    "name": "Peristéri",
    "lat": "38.01539",
    "lng": "23.69187"
  },
  {
    "country": "GR",
    "name": "Pérdika",
    "lat": "39.36967",
    "lng": "20.30419"
  },
  {
    "country": "GR",
    "name": "Pérama",
    "lat": "39.69331",
    "lng": "20.84656"
  },
  {
    "country": "GR",
    "name": "Pérama",
    "lat": "37.96775",
    "lng": "23.5721"
  },
  {
    "country": "GR",
    "name": "Pérama",
    "lat": "35.3703",
    "lng": "24.70345"
  },
  {
    "country": "GR",
    "name": "Perachóra",
    "lat": "38.03021",
    "lng": "22.94902"
  },
  {
    "country": "GR",
    "name": "Pentéli",
    "lat": "38.05",
    "lng": "23.86667"
  },
  {
    "country": "GR",
    "name": "Pelópi",
    "lat": "37.67444",
    "lng": "21.59344"
  },
  {
    "country": "GR",
    "name": "Pelasgía",
    "lat": "38.94813",
    "lng": "22.8398"
  },
  {
    "country": "GR",
    "name": "Pediní",
    "lat": "39.59994",
    "lng": "20.84261"
  },
  {
    "country": "GR",
    "name": "Gáïos",
    "lat": "39.19722",
    "lng": "20.18556"
  },
  {
    "country": "GR",
    "name": "Pátra",
    "lat": "38.24444",
    "lng": "21.73444"
  },
  {
    "country": "GR",
    "name": "Pátmos",
    "lat": "37.30895",
    "lng": "26.54723"
  },
  {
    "country": "GR",
    "name": "Patitírion",
    "lat": "39.14657",
    "lng": "23.86494"
  },
  {
    "country": "GR",
    "name": "Pásion",
    "lat": "38.01294",
    "lng": "22.72814"
  },
  {
    "country": "GR",
    "name": "Páros",
    "lat": "37.08333",
    "lng": "25.15"
  },
  {
    "country": "GR",
    "name": "Párga",
    "lat": "39.28572",
    "lng": "20.40044"
  },
  {
    "country": "GR",
    "name": "Paravóla",
    "lat": "38.61472",
    "lng": "21.52046"
  },
  {
    "country": "GR",
    "name": "Proástio",
    "lat": "39.48682",
    "lng": "21.90288"
  },
  {
    "country": "GR",
    "name": "Parapótamos",
    "lat": "39.54858",
    "lng": "20.32436"
  },
  {
    "country": "GR",
    "name": "Paramythiá",
    "lat": "39.47111",
    "lng": "20.51111"
  },
  {
    "country": "GR",
    "name": "Paralía Avlídhos",
    "lat": "38.38002",
    "lng": "23.62842"
  },
  {
    "country": "GR",
    "name": "Paralía",
    "lat": "38.19833",
    "lng": "21.70263"
  },
  {
    "country": "GR",
    "name": "Pappádos",
    "lat": "39.03905",
    "lng": "26.45598"
  },
  {
    "country": "GR",
    "name": "Pappadátes",
    "lat": "39.31444",
    "lng": "20.79314"
  },
  {
    "country": "GR",
    "name": "Pappadhátai",
    "lat": "38.52816",
    "lng": "21.45016"
  },
  {
    "country": "GR",
    "name": "Pánormos",
    "lat": "35.41815",
    "lng": "24.69091"
  },
  {
    "country": "GR",
    "name": "Panaitólion",
    "lat": "38.58316",
    "lng": "21.44729"
  },
  {
    "country": "GR",
    "name": "Pámfila",
    "lat": "39.15697",
    "lng": "26.5217"
  },
  {
    "country": "GR",
    "name": "Pallíni",
    "lat": "38.00514",
    "lng": "23.88302"
  },
  {
    "country": "GR",
    "name": "Palamás",
    "lat": "39.46667",
    "lng": "22.08333"
  },
  {
    "country": "GR",
    "name": "Pálairos",
    "lat": "38.783",
    "lng": "20.88183"
  },
  {
    "country": "GR",
    "name": "Palaiópyrgos",
    "lat": "39.60845",
    "lng": "21.8172"
  },
  {
    "country": "GR",
    "name": "Palaió Fáliro",
    "lat": "37.92812",
    "lng": "23.70105"
  },
  {
    "country": "GR",
    "name": "Palaiomonástiro",
    "lat": "39.46269",
    "lng": "21.65793"
  },
  {
    "country": "GR",
    "name": "Palaiókipos",
    "lat": "39.05563",
    "lng": "26.45053"
  },
  {
    "country": "GR",
    "name": "Palaióchora",
    "lat": "35.23128",
    "lng": "23.68185"
  },
  {
    "country": "GR",
    "name": "Palekastro",
    "lat": "35.19793",
    "lng": "26.25429"
  },
  {
    "country": "GR",
    "name": "Psará",
    "lat": "38.54097",
    "lng": "25.56287"
  },
  {
    "country": "GR",
    "name": "Palaiá Fókaia",
    "lat": "37.71998",
    "lng": "23.94792"
  },
  {
    "country": "GR",
    "name": "Palaiá Epídavros",
    "lat": "37.63847",
    "lng": "23.15609"
  },
  {
    "country": "GR",
    "name": "Paianía",
    "lat": "37.95527",
    "lng": "23.85443"
  },
  {
    "country": "GR",
    "name": "Oxílithos",
    "lat": "38.57988",
    "lng": "24.11184"
  },
  {
    "country": "GR",
    "name": "Ovriá",
    "lat": "38.18866",
    "lng": "21.72903"
  },
  {
    "country": "GR",
    "name": "Oropós",
    "lat": "38.30326",
    "lng": "23.75549"
  },
  {
    "country": "GR",
    "name": "Orchomenós",
    "lat": "38.4929",
    "lng": "22.97962"
  },
  {
    "country": "GR",
    "name": "Oreoí",
    "lat": "38.95034",
    "lng": "23.09191"
  },
  {
    "country": "GR",
    "name": "Omvriakí",
    "lat": "39.10118",
    "lng": "22.27106"
  },
  {
    "country": "GR",
    "name": "Oinoússes",
    "lat": "38.51458",
    "lng": "26.22241"
  },
  {
    "country": "GR",
    "name": "Oinófyta",
    "lat": "38.31163",
    "lng": "23.64"
  },
  {
    "country": "GR",
    "name": "Papágou",
    "lat": "37.98642",
    "lng": "23.79347"
  },
  {
    "country": "GR",
    "name": "Oía",
    "lat": "36.4626",
    "lng": "25.37637"
  },
  {
    "country": "GR",
    "name": "Níkaia",
    "lat": "39.56667",
    "lng": "22.46667"
  },
  {
    "country": "GR",
    "name": "Níkaia",
    "lat": "37.96667",
    "lng": "23.65"
  },
  {
    "country": "GR",
    "name": "Nerokoúros",
    "lat": "35.47587",
    "lng": "24.03995"
  },
  {
    "country": "GR",
    "name": "Néon Monastírion",
    "lat": "39.23988",
    "lng": "22.27465"
  },
  {
    "country": "GR",
    "name": "Néon Karlovásion",
    "lat": "37.79209",
    "lng": "26.7049"
  },
  {
    "country": "GR",
    "name": "Neochorópoulo",
    "lat": "39.62553",
    "lng": "20.83558"
  },
  {
    "country": "GR",
    "name": "Oichalía",
    "lat": "39.60827",
    "lng": "21.97996"
  },
  {
    "country": "GR",
    "name": "Neochóri",
    "lat": "39.07025",
    "lng": "21.01892"
  },
  {
    "country": "GR",
    "name": "Neochórion",
    "lat": "38.40847",
    "lng": "21.27511"
  },
  {
    "country": "GR",
    "name": "Neochóri",
    "lat": "37.90794",
    "lng": "21.20392"
  },
  {
    "country": "GR",
    "name": "Neméa",
    "lat": "37.82068",
    "lng": "22.66102"
  },
  {
    "country": "GR",
    "name": "Néa Tírins",
    "lat": "37.60793",
    "lng": "22.81996"
  },
  {
    "country": "GR",
    "name": "Néa Stíra",
    "lat": "38.17935",
    "lng": "24.20842"
  },
  {
    "country": "GR",
    "name": "Néa Smýrni",
    "lat": "37.94504",
    "lng": "23.71416"
  },
  {
    "country": "GR",
    "name": "Néa Seléfkeia",
    "lat": "39.52461",
    "lng": "20.25519"
  },
  {
    "country": "GR",
    "name": "Neápoli",
    "lat": "35.25627",
    "lng": "25.60415"
  },
  {
    "country": "GR",
    "name": "Néa Péramos",
    "lat": "38.00647",
    "lng": "23.42348"
  },
  {
    "country": "GR",
    "name": "Néa Palátia",
    "lat": "38.31942",
    "lng": "23.79649"
  },
  {
    "country": "GR",
    "name": "Néa Manoláda",
    "lat": "38.05378",
    "lng": "21.38189"
  },
  {
    "country": "GR",
    "name": "Néa Mákri",
    "lat": "38.08733",
    "lng": "23.97642"
  },
  {
    "country": "GR",
    "name": "Ílion",
    "lat": "38.03333",
    "lng": "23.7"
  },
  {
    "country": "GR",
    "name": "Néa Lámpsakos",
    "lat": "38.43729",
    "lng": "23.62824"
  },
  {
    "country": "GR",
    "name": "Néa Kíos",
    "lat": "37.59023",
    "lng": "22.74342"
  },
  {
    "country": "GR",
    "name": "Néa Ionía",
    "lat": "38.0357",
    "lng": "23.75733"
  },
  {
    "country": "GR",
    "name": "Néa Filadélfeia",
    "lat": "38.03491",
    "lng": "23.73811"
  },
  {
    "country": "GR",
    "name": "Néa Erythraía",
    "lat": "38.0927",
    "lng": "23.82223"
  },
  {
    "country": "GR",
    "name": "Néa Artáki",
    "lat": "38.52027",
    "lng": "23.63296"
  },
  {
    "country": "GR",
    "name": "Néa Anchiálos",
    "lat": "39.28015",
    "lng": "22.81819"
  },
  {
    "country": "GR",
    "name": "Náxos",
    "lat": "37.10556",
    "lng": "25.37639"
  },
  {
    "country": "GR",
    "name": "Náfplio",
    "lat": "37.56863",
    "lng": "22.80691"
  },
  {
    "country": "GR",
    "name": "Náfpaktos",
    "lat": "38.39167",
    "lng": "21.8275"
  },
  {
    "country": "GR",
    "name": "Náousa",
    "lat": "37.12181",
    "lng": "25.24014"
  },
  {
    "country": "GR",
    "name": "Mouzourás",
    "lat": "35.53885",
    "lng": "24.15554"
  },
  {
    "country": "GR",
    "name": "Mouzáki",
    "lat": "39.42972",
    "lng": "21.66361"
  },
  {
    "country": "GR",
    "name": "Mouzaki",
    "lat": "37.73565",
    "lng": "20.82291"
  },
  {
    "country": "GR",
    "name": "Mourniés",
    "lat": "35.48228",
    "lng": "24.01253"
  },
  {
    "country": "GR",
    "name": "Moúlki",
    "lat": "37.99319",
    "lng": "22.72531"
  },
  {
    "country": "GR",
    "name": "Moskháton",
    "lat": "37.94789",
    "lng": "23.6788"
  },
  {
    "country": "GR",
    "name": "Mória",
    "lat": "39.13248",
    "lng": "26.51698"
  },
  {
    "country": "GR",
    "name": "Morfovoúni",
    "lat": "39.3525",
    "lng": "21.75"
  },
  {
    "country": "GR",
    "name": "Monastiráki",
    "lat": "38.85053",
    "lng": "20.94458"
  },
  {
    "country": "GR",
    "name": "Mólos",
    "lat": "38.80998",
    "lng": "22.64544"
  },
  {
    "country": "GR",
    "name": "Moláoi",
    "lat": "36.80757",
    "lng": "22.85132"
  },
  {
    "country": "GR",
    "name": "Mokhós",
    "lat": "35.26342",
    "lng": "25.42305"
  },
  {
    "country": "GR",
    "name": "Moíres",
    "lat": "35.05143",
    "lng": "24.8733"
  },
  {
    "country": "GR",
    "name": "Mitrópoli",
    "lat": "39.33933",
    "lng": "21.83751"
  },
  {
    "country": "GR",
    "name": "Mytilinioí",
    "lat": "37.72716",
    "lng": "26.90747"
  },
  {
    "country": "GR",
    "name": "Mytilene",
    "lat": "39.10772",
    "lng": "26.55529"
  },
  {
    "country": "GR",
    "name": "Mytikas",
    "lat": "38.44373",
    "lng": "23.65365"
  },
  {
    "country": "GR",
    "name": "Míthymna",
    "lat": "39.36781",
    "lng": "26.17639"
  },
  {
    "country": "GR",
    "name": "Myrsíni",
    "lat": "37.92117",
    "lng": "21.237"
  },
  {
    "country": "GR",
    "name": "Mýrina",
    "lat": "39.87483",
    "lng": "25.06359"
  },
  {
    "country": "GR",
    "name": "Mindilóglion",
    "lat": "38.18387",
    "lng": "21.70133"
  },
  {
    "country": "GR",
    "name": "Mílos",
    "lat": "36.74536",
    "lng": "24.4265"
  },
  {
    "country": "GR",
    "name": "Mykonos",
    "lat": "37.44529",
    "lng": "25.32872"
  },
  {
    "country": "GR",
    "name": "Megísti",
    "lat": "36.14889",
    "lng": "29.59361"
  },
  {
    "country": "GR",
    "name": "Metsovo",
    "lat": "39.76944",
    "lng": "21.18222"
  },
  {
    "country": "GR",
    "name": "Methóni",
    "lat": "36.81973",
    "lng": "21.70486"
  },
  {
    "country": "GR",
    "name": "Messíni",
    "lat": "37.05111",
    "lng": "22.00778"
  },
  {
    "country": "GR",
    "name": "Mesolóngi",
    "lat": "38.37138",
    "lng": "21.43151"
  },
  {
    "country": "GR",
    "name": "Mesariá",
    "lat": "36.39893",
    "lng": "25.44807"
  },
  {
    "country": "GR",
    "name": "Agía Triáda",
    "lat": "39.46361",
    "lng": "21.89848"
  },
  {
    "country": "GR",
    "name": "Menídi",
    "lat": "39.04213",
    "lng": "21.11875"
  },
  {
    "country": "GR",
    "name": "Melíssia",
    "lat": "38.05",
    "lng": "23.83333"
  },
  {
    "country": "GR",
    "name": "Meligalás",
    "lat": "37.21667",
    "lng": "21.96667"
  },
  {
    "country": "GR",
    "name": "Mégara",
    "lat": "37.99471",
    "lng": "23.34324"
  },
  {
    "country": "GR",
    "name": "Megalópoli",
    "lat": "37.40111",
    "lng": "22.14222"
  },
  {
    "country": "GR",
    "name": "Megálo Chorió",
    "lat": "36.44917",
    "lng": "27.34833"
  },
  {
    "country": "GR",
    "name": "Megalochóri",
    "lat": "39.55982",
    "lng": "21.84195"
  },
  {
    "country": "GR",
    "name": "Megáli Khóra",
    "lat": "38.64629",
    "lng": "21.37309"
  },
  {
    "country": "GR",
    "name": "Megála Kalývia",
    "lat": "39.49693",
    "lng": "21.78802"
  },
  {
    "country": "GR",
    "name": "Mavrommáti",
    "lat": "39.42386",
    "lng": "21.69379"
  },
  {
    "country": "GR",
    "name": "Mataránga",
    "lat": "38.52359",
    "lng": "21.47325"
  },
  {
    "country": "GR",
    "name": "Martínon",
    "lat": "38.56817",
    "lng": "23.21458"
  },
  {
    "country": "GR",
    "name": "Marmárion",
    "lat": "38.04839",
    "lng": "24.32039"
  },
  {
    "country": "GR",
    "name": "Markópoulo Oropoú",
    "lat": "38.2898",
    "lng": "23.82475"
  },
  {
    "country": "GR",
    "name": "Markópoulo",
    "lat": "37.88333",
    "lng": "23.93333"
  },
  {
    "country": "GR",
    "name": "Marathónas",
    "lat": "38.15317",
    "lng": "23.96278"
  },
  {
    "country": "GR",
    "name": "Marathókampos",
    "lat": "37.72674",
    "lng": "26.68964"
  },
  {
    "country": "GR",
    "name": "Manoláda",
    "lat": "38.04708",
    "lng": "21.34814"
  },
  {
    "country": "GR",
    "name": "Mandráki",
    "lat": "36.61139",
    "lng": "27.13333"
  },
  {
    "country": "GR",
    "name": "Mándra",
    "lat": "38.06667",
    "lng": "23.5"
  },
  {
    "country": "GR",
    "name": "Mantoúdi",
    "lat": "38.79808",
    "lng": "23.47967"
  },
  {
    "country": "GR",
    "name": "Mantamádos",
    "lat": "39.31003",
    "lng": "26.33629"
  },
  {
    "country": "GR",
    "name": "Mália",
    "lat": "35.28367",
    "lng": "25.46262"
  },
  {
    "country": "GR",
    "name": "Malesína",
    "lat": "38.62225",
    "lng": "23.2337"
  },
  {
    "country": "GR",
    "name": "Malakónta",
    "lat": "38.4",
    "lng": "23.76667"
  },
  {
    "country": "GR",
    "name": "Makrísia",
    "lat": "37.60957",
    "lng": "21.60509"
  },
  {
    "country": "GR",
    "name": "Makrychóri",
    "lat": "39.8",
    "lng": "22.48333"
  },
  {
    "country": "GR",
    "name": "Makrychóri",
    "lat": "39.43978",
    "lng": "21.96582"
  },
  {
    "country": "GR",
    "name": "Makrakómi",
    "lat": "38.9415",
    "lng": "22.11535"
  },
  {
    "country": "GR",
    "name": "Magoúla",
    "lat": "38.41178",
    "lng": "23.82128"
  },
  {
    "country": "GR",
    "name": "Magoúla",
    "lat": "38.07989",
    "lng": "23.52108"
  },
  {
    "country": "GR",
    "name": "Magoúla",
    "lat": "37.08007",
    "lng": "22.40469"
  },
  {
    "country": "GR",
    "name": "Artémida",
    "lat": "37.96727",
    "lng": "23.99684"
  },
  {
    "country": "GR",
    "name": "Loutráki",
    "lat": "37.9783",
    "lng": "22.97781"
  },
  {
    "country": "GR",
    "name": "Loutrá Aidhipsoú",
    "lat": "38.85695",
    "lng": "23.04739"
  },
  {
    "country": "GR",
    "name": "Loutrá",
    "lat": "39.05695",
    "lng": "26.54476"
  },
  {
    "country": "GR",
    "name": "Loúros",
    "lat": "39.166",
    "lng": "20.75608"
  },
  {
    "country": "GR",
    "name": "Loukísia",
    "lat": "38.47946",
    "lng": "23.44796"
  },
  {
    "country": "GR",
    "name": "Lixoúri",
    "lat": "38.20133",
    "lng": "20.43706"
  },
  {
    "country": "GR",
    "name": "Livanátes",
    "lat": "38.711",
    "lng": "23.0503"
  },
  {
    "country": "GR",
    "name": "Lithakiá",
    "lat": "37.71935",
    "lng": "20.83013"
  },
  {
    "country": "GR",
    "name": "Leipsoí",
    "lat": "37.28333",
    "lng": "26.76667"
  },
  {
    "country": "GR",
    "name": "Limnokhórion",
    "lat": "38.14115",
    "lng": "21.48047"
  },
  {
    "country": "GR",
    "name": "Límni",
    "lat": "38.76667",
    "lng": "23.31667"
  },
  {
    "country": "GR",
    "name": "Limín Mesoyaías",
    "lat": "37.89108",
    "lng": "24.00307"
  },
  {
    "country": "GR",
    "name": "Limín Khersonísou",
    "lat": "35.32297",
    "lng": "25.39275"
  },
  {
    "country": "GR",
    "name": "Lykóvrysi",
    "lat": "38.06933",
    "lng": "23.78223"
  },
  {
    "country": "GR",
    "name": "Ligourión",
    "lat": "37.61233",
    "lng": "23.03773"
  },
  {
    "country": "GR",
    "name": "Lidoríki",
    "lat": "38.52389",
    "lng": "22.19972"
  },
  {
    "country": "GR",
    "name": "Lianokládhion",
    "lat": "38.91655",
    "lng": "22.30336"
  },
  {
    "country": "GR",
    "name": "Lefkímmi",
    "lat": "39.42336",
    "lng": "20.07094"
  },
  {
    "country": "GR",
    "name": "Lefkáda",
    "lat": "38.83036",
    "lng": "20.70442"
  },
  {
    "country": "GR",
    "name": "Levídion",
    "lat": "37.68269",
    "lng": "22.29586"
  },
  {
    "country": "GR",
    "name": "Livadeiá",
    "lat": "38.43616",
    "lng": "22.87665"
  },
  {
    "country": "GR",
    "name": "Lepenoú",
    "lat": "38.70839",
    "lng": "21.2897"
  },
  {
    "country": "GR",
    "name": "Leonídio",
    "lat": "37.16679",
    "lng": "22.85773"
  },
  {
    "country": "GR",
    "name": "Leondárion",
    "lat": "37.987",
    "lng": "23.85518"
  },
  {
    "country": "GR",
    "name": "Lékhaio",
    "lat": "37.93279",
    "lng": "22.85002"
  },
  {
    "country": "GR",
    "name": "Lechainá",
    "lat": "37.93333",
    "lng": "21.26667"
  },
  {
    "country": "GR",
    "name": "Lávrio",
    "lat": "37.71445",
    "lng": "24.05647"
  },
  {
    "country": "GR",
    "name": "Lárisa",
    "lat": "39.63689",
    "lng": "22.41761"
  },
  {
    "country": "GR",
    "name": "Lápas",
    "lat": "38.09755",
    "lng": "21.41861"
  },
  {
    "country": "GR",
    "name": "Langádhia",
    "lat": "37.68186",
    "lng": "22.03002"
  },
  {
    "country": "GR",
    "name": "Lamía",
    "lat": "38.9",
    "lng": "22.43333"
  },
  {
    "country": "GR",
    "name": "Lálas",
    "lat": "37.70936",
    "lng": "21.72117"
  },
  {
    "country": "GR",
    "name": "Lakkí",
    "lat": "37.13344",
    "lng": "26.85237"
  },
  {
    "country": "GR",
    "name": "Krousón",
    "lat": "35.23062",
    "lng": "24.98291"
  },
  {
    "country": "GR",
    "name": "Krokeés",
    "lat": "36.88297",
    "lng": "22.54683"
  },
  {
    "country": "GR",
    "name": "Taxiárches",
    "lat": "39.57565",
    "lng": "21.89245"
  },
  {
    "country": "GR",
    "name": "Kritsá",
    "lat": "35.15821",
    "lng": "25.64459"
  },
  {
    "country": "GR",
    "name": "Kryonéri",
    "lat": "38.13712",
    "lng": "23.83055"
  },
  {
    "country": "GR",
    "name": "Kríkellos",
    "lat": "38.94532",
    "lng": "21.1791"
  },
  {
    "country": "GR",
    "name": "Kréstena",
    "lat": "37.59193",
    "lng": "21.62034"
  },
  {
    "country": "GR",
    "name": "Kranídi",
    "lat": "37.37974",
    "lng": "23.15969"
  },
  {
    "country": "GR",
    "name": "Kraniá Elassónas",
    "lat": "39.95094",
    "lng": "21.97078"
  },
  {
    "country": "GR",
    "name": "Kouvarás",
    "lat": "37.82711",
    "lng": "23.96715"
  },
  {
    "country": "GR",
    "name": "Koutsopódi",
    "lat": "37.68426",
    "lng": "22.71355"
  },
  {
    "country": "GR",
    "name": "Koutselió",
    "lat": "39.58808",
    "lng": "20.91197"
  },
  {
    "country": "GR",
    "name": "Metamórfosi",
    "lat": "38.06576",
    "lng": "23.76356"
  },
  {
    "country": "GR",
    "name": "Kostakioí",
    "lat": "39.13672",
    "lng": "20.95761"
  },
  {
    "country": "GR",
    "name": "Kos",
    "lat": "36.89333",
    "lng": "27.28889"
  },
  {
    "country": "GR",
    "name": "Koropí",
    "lat": "37.89886",
    "lng": "23.87181"
  },
  {
    "country": "GR",
    "name": "Koróni",
    "lat": "36.79526",
    "lng": "21.95794"
  },
  {
    "country": "GR",
    "name": "Kórinthos",
    "lat": "37.94007",
    "lng": "22.9513"
  },
  {
    "country": "GR",
    "name": "Domvraína",
    "lat": "38.253",
    "lng": "22.98211"
  },
  {
    "country": "GR",
    "name": "Kompóti",
    "lat": "39.10255",
    "lng": "21.08389"
  },
  {
    "country": "GR",
    "name": "Kolympári",
    "lat": "35.54115",
    "lng": "23.77995"
  },
  {
    "country": "GR",
    "name": "Kokkónion",
    "lat": "37.97061",
    "lng": "22.78018"
  },
  {
    "country": "GR",
    "name": "Kokkíni Cháni",
    "lat": "35.32827",
    "lng": "25.2581"
  },
  {
    "country": "GR",
    "name": "Kokkári",
    "lat": "37.77908",
    "lng": "26.89179"
  },
  {
    "country": "GR",
    "name": "Koilás",
    "lat": "37.4123",
    "lng": "23.12553"
  },
  {
    "country": "GR",
    "name": "Kýthnos",
    "lat": "37.41237",
    "lng": "24.43068"
  },
  {
    "country": "GR",
    "name": "Kýthira",
    "lat": "36.14955",
    "lng": "22.98979"
  },
  {
    "country": "GR",
    "name": "Kíssamos",
    "lat": "35.49459",
    "lng": "23.65375"
  },
  {
    "country": "GR",
    "name": "Kírra",
    "lat": "38.42944",
    "lng": "22.44443"
  },
  {
    "country": "GR",
    "name": "Kyriáki",
    "lat": "38.35365",
    "lng": "22.78841"
  },
  {
    "country": "GR",
    "name": "Kyrás Vrýsi",
    "lat": "37.91295",
    "lng": "22.98651"
  },
  {
    "country": "GR",
    "name": "Kipséli",
    "lat": "38.00288",
    "lng": "23.73755"
  },
  {
    "country": "GR",
    "name": "Kypséli",
    "lat": "37.76021",
    "lng": "23.45448"
  },
  {
    "country": "GR",
    "name": "Kyparissía",
    "lat": "37.25111",
    "lng": "21.67361"
  },
  {
    "country": "GR",
    "name": "Kinéta",
    "lat": "37.96843",
    "lng": "23.21351"
  },
  {
    "country": "GR",
    "name": "Kímolos",
    "lat": "36.79368",
    "lng": "24.57577"
  },
  {
    "country": "GR",
    "name": "Kými",
    "lat": "38.63477",
    "lng": "24.10287"
  },
  {
    "country": "GR",
    "name": "Kyllíni",
    "lat": "37.93542",
    "lng": "21.14503"
  },
  {
    "country": "GR",
    "name": "Kifisiá",
    "lat": "38.07438",
    "lng": "23.81106"
  },
  {
    "country": "GR",
    "name": "Kiáto",
    "lat": "38.01321",
    "lng": "22.74839"
  },
  {
    "country": "GR",
    "name": "Chóra Sfakíon",
    "lat": "35.20176",
    "lng": "24.13711"
  },
  {
    "country": "GR",
    "name": "Chóra",
    "lat": "37.70374",
    "lng": "26.90454"
  },
  {
    "country": "GR",
    "name": "Chóra",
    "lat": "37.05106",
    "lng": "21.7169"
  },
  {
    "country": "GR",
    "name": "Cholargós",
    "lat": "38",
    "lng": "23.8"
  },
  {
    "country": "GR",
    "name": "Chios",
    "lat": "38.36778",
    "lng": "26.13583"
  },
  {
    "country": "GR",
    "name": "Khiliomódhi",
    "lat": "37.81016",
    "lng": "22.86972"
  },
  {
    "country": "GR",
    "name": "Chávari",
    "lat": "37.84842",
    "lng": "21.38403"
  },
  {
    "country": "GR",
    "name": "Chaniá",
    "lat": "35.51124",
    "lng": "24.02921"
  },
  {
    "country": "GR",
    "name": "Khalkoútsion",
    "lat": "38.33263",
    "lng": "23.73188"
  },
  {
    "country": "GR",
    "name": "Chalkída",
    "lat": "38.46354",
    "lng": "23.60284"
  },
  {
    "country": "GR",
    "name": "Chalkiádes",
    "lat": "39.15981",
    "lng": "20.93292"
  },
  {
    "country": "GR",
    "name": "Chálki",
    "lat": "39.56853",
    "lng": "22.54017"
  },
  {
    "country": "GR",
    "name": "Chálki",
    "lat": "36.22243",
    "lng": "27.61191"
  },
  {
    "country": "GR",
    "name": "Chalandrítsa",
    "lat": "38.10843",
    "lng": "21.78349"
  },
  {
    "country": "GR",
    "name": "Khalándrion",
    "lat": "38.02369",
    "lng": "23.80068"
  },
  {
    "country": "GR",
    "name": "Chairóneia",
    "lat": "38.49551",
    "lng": "22.84424"
  },
  {
    "country": "GR",
    "name": "Chaïdári",
    "lat": "38.01135",
    "lng": "23.66597"
  },
  {
    "country": "GR",
    "name": "Keratsíni",
    "lat": "37.9625",
    "lng": "23.61972"
  },
  {
    "country": "GR",
    "name": "Keratéa",
    "lat": "37.80585",
    "lng": "23.9774"
  },
  {
    "country": "GR",
    "name": "Kerasochóri",
    "lat": "39.00556",
    "lng": "21.63778"
  },
  {
    "country": "GR",
    "name": "Kentrí",
    "lat": "35.03258",
    "lng": "25.7528"
  },
  {
    "country": "GR",
    "name": "Kéfalos",
    "lat": "36.74507",
    "lng": "26.95961"
  },
  {
    "country": "GR",
    "name": "Kéa",
    "lat": "37.63333",
    "lng": "24.35"
  },
  {
    "country": "GR",
    "name": "Kavásila",
    "lat": "37.87581",
    "lng": "21.26422"
  },
  {
    "country": "GR",
    "name": "Katsikás",
    "lat": "39.62281",
    "lng": "20.88758"
  },
  {
    "country": "GR",
    "name": "Katoúna",
    "lat": "38.78547",
    "lng": "21.11417"
  },
  {
    "country": "GR",
    "name": "Káto Tithoréa",
    "lat": "38.60751",
    "lng": "22.71348"
  },
  {
    "country": "GR",
    "name": "Káto Soúlion",
    "lat": "38.16803",
    "lng": "24.01628"
  },
  {
    "country": "GR",
    "name": "Káto Mazaráki",
    "lat": "38.07035",
    "lng": "21.65097"
  },
  {
    "country": "GR",
    "name": "Káto Lekhónia",
    "lat": "39.33091",
    "lng": "23.03957"
  },
  {
    "country": "GR",
    "name": "Katochí",
    "lat": "38.41237",
    "lng": "21.25258"
  },
  {
    "country": "GR",
    "name": "Káto Glykóvrysi",
    "lat": "36.82791",
    "lng": "22.77732"
  },
  {
    "country": "GR",
    "name": "Káto Dhiminió",
    "lat": "38.0249",
    "lng": "22.73294"
  },
  {
    "country": "GR",
    "name": "Káto Asítai",
    "lat": "35.20271",
    "lng": "24.99827"
  },
  {
    "country": "GR",
    "name": "Káto Achaḯa",
    "lat": "38.15",
    "lng": "21.55"
  },
  {
    "country": "GR",
    "name": "Katastárion",
    "lat": "37.83012",
    "lng": "20.75755"
  },
  {
    "country": "GR",
    "name": "Kastrí",
    "lat": "34.8346",
    "lng": "24.08572"
  },
  {
    "country": "GR",
    "name": "Kastráki",
    "lat": "39.71692",
    "lng": "21.61865"
  },
  {
    "country": "GR",
    "name": "Kastélli",
    "lat": "35.20902",
    "lng": "25.33773"
  },
  {
    "country": "GR",
    "name": "Kastélla",
    "lat": "38.57048",
    "lng": "23.63131"
  },
  {
    "country": "GR",
    "name": "Karpochóri",
    "lat": "39.33575",
    "lng": "22.01129"
  },
  {
    "country": "GR",
    "name": "Karpenísi",
    "lat": "38.91218",
    "lng": "21.79836"
  },
  {
    "country": "GR",
    "name": "Karpathos",
    "lat": "35.50701",
    "lng": "27.21322"
  },
  {
    "country": "GR",
    "name": "Kárystos",
    "lat": "38.01333",
    "lng": "24.41611"
  },
  {
    "country": "GR",
    "name": "Karyés",
    "lat": "37.29119",
    "lng": "22.50066"
  },
  {
    "country": "GR",
    "name": "Karditsomagoúla",
    "lat": "39.39061",
    "lng": "21.9233"
  },
  {
    "country": "GR",
    "name": "Kardítsa",
    "lat": "39.36485",
    "lng": "21.92191"
  },
  {
    "country": "GR",
    "name": "Kardamýli",
    "lat": "36.88778",
    "lng": "22.23317"
  },
  {
    "country": "GR",
    "name": "Kardamás",
    "lat": "37.76729",
    "lng": "21.33946"
  },
  {
    "country": "GR",
    "name": "Kardámaina",
    "lat": "36.78305",
    "lng": "27.14289"
  },
  {
    "country": "GR",
    "name": "Karátoula",
    "lat": "37.73564",
    "lng": "21.53578"
  },
  {
    "country": "GR",
    "name": "Pefkochóri",
    "lat": "39.98784",
    "lng": "23.61219"
  },
  {
    "country": "GR",
    "name": "Kaparéllion",
    "lat": "38.23697",
    "lng": "23.21411"
  },
  {
    "country": "GR",
    "name": "Kapandríti",
    "lat": "38.21579",
    "lng": "23.87938"
  },
  {
    "country": "GR",
    "name": "Kandíla",
    "lat": "38.70564",
    "lng": "20.94749"
  },
  {
    "country": "GR",
    "name": "Kanaláki",
    "lat": "39.23361",
    "lng": "20.6"
  },
  {
    "country": "GR",
    "name": "Kanália",
    "lat": "39.49928",
    "lng": "22.88589"
  },
  {
    "country": "GR",
    "name": "Kaména Voúrla",
    "lat": "38.77844",
    "lng": "22.78573"
  },
  {
    "country": "GR",
    "name": "Kamaterón",
    "lat": "38.05586",
    "lng": "23.70515"
  },
  {
    "country": "GR",
    "name": "Kamárai",
    "lat": "38.29881",
    "lng": "21.99892"
  },
  {
    "country": "GR",
    "name": "Kalpáki",
    "lat": "39.88778",
    "lng": "20.62389"
  },
  {
    "country": "GR",
    "name": "Kalloní",
    "lat": "39.23318",
    "lng": "26.20724"
  },
  {
    "country": "GR",
    "name": "Kallíthiro",
    "lat": "39.28099",
    "lng": "21.90491"
  },
  {
    "country": "GR",
    "name": "Kallithéa",
    "lat": "37.95",
    "lng": "23.7"
  },
  {
    "country": "GR",
    "name": "Kallifóni",
    "lat": "39.27712",
    "lng": "21.96128"
  },
  {
    "country": "GR",
    "name": "Kalývia Thorikoú",
    "lat": "37.83894",
    "lng": "23.92505"
  },
  {
    "country": "GR",
    "name": "Kalýves",
    "lat": "35.45046",
    "lng": "24.17507"
  },
  {
    "country": "GR",
    "name": "Kálymnos",
    "lat": "36.95447",
    "lng": "26.9769"
  },
  {
    "country": "GR",
    "name": "Kalávryta",
    "lat": "38.03222",
    "lng": "22.1125"
  },
  {
    "country": "GR",
    "name": "Kálamos",
    "lat": "38.28447",
    "lng": "23.86308"
  },
  {
    "country": "GR",
    "name": "Kalamiá",
    "lat": "39.16528",
    "lng": "20.93206"
  },
  {
    "country": "GR",
    "name": "Kalampáka",
    "lat": "39.70444",
    "lng": "21.62694"
  },
  {
    "country": "GR",
    "name": "Kalamata",
    "lat": "37.03913",
    "lng": "22.11265"
  },
  {
    "country": "GR",
    "name": "Álimos",
    "lat": "37.91033",
    "lng": "23.72361"
  },
  {
    "country": "GR",
    "name": "Kaisarianí",
    "lat": "37.9634",
    "lng": "23.76523"
  },
  {
    "country": "GR",
    "name": "Kainoúryion",
    "lat": "38.79283",
    "lng": "22.7247"
  },
  {
    "country": "GR",
    "name": "Kainoúryion",
    "lat": "38.60453",
    "lng": "21.48776"
  },
  {
    "country": "GR",
    "name": "Itháki",
    "lat": "38.36421",
    "lng": "20.71848"
  },
  {
    "country": "GR",
    "name": "Itéa",
    "lat": "39.45669",
    "lng": "22.16577"
  },
  {
    "country": "GR",
    "name": "Itéa",
    "lat": "38.43201",
    "lng": "22.42443"
  },
  {
    "country": "GR",
    "name": "Istiaía",
    "lat": "38.9552",
    "lng": "23.1521"
  },
  {
    "country": "GR",
    "name": "Isthmía",
    "lat": "37.91356",
    "lng": "23.0046"
  },
  {
    "country": "GR",
    "name": "Irákleio",
    "lat": "38.05282",
    "lng": "23.76523"
  },
  {
    "country": "GR",
    "name": "Irákleion",
    "lat": "35.32787",
    "lng": "25.14341"
  },
  {
    "country": "GR",
    "name": "Íos",
    "lat": "36.73333",
    "lng": "25.28333"
  },
  {
    "country": "GR",
    "name": "Ioánnina",
    "lat": "39.66486",
    "lng": "20.85189"
  },
  {
    "country": "GR",
    "name": "Igoumenítsa",
    "lat": "39.50342",
    "lng": "20.26728"
  },
  {
    "country": "GR",
    "name": "Ierápetra",
    "lat": "35.01186",
    "lng": "25.74234"
  },
  {
    "country": "GR",
    "name": "Ýdra",
    "lat": "37.34976",
    "lng": "23.4656"
  },
  {
    "country": "GR",
    "name": "Grizáno",
    "lat": "39.63192",
    "lng": "22.05258"
  },
  {
    "country": "GR",
    "name": "Grammenítsa",
    "lat": "39.18444",
    "lng": "20.97933"
  },
  {
    "country": "GR",
    "name": "Grammatikó",
    "lat": "38.20251",
    "lng": "23.96504"
  },
  {
    "country": "GR",
    "name": "Gra Liyiá",
    "lat": "35.01467",
    "lng": "25.69127"
  },
  {
    "country": "GR",
    "name": "Graikochóri",
    "lat": "39.49789",
    "lng": "20.27608"
  },
  {
    "country": "GR",
    "name": "Goúrnes",
    "lat": "35.32626",
    "lng": "25.2774"
  },
  {
    "country": "GR",
    "name": "Goúmero",
    "lat": "37.76236",
    "lng": "21.61853"
  },
  {
    "country": "GR",
    "name": "Gónnoi",
    "lat": "39.86153",
    "lng": "22.47647"
  },
  {
    "country": "GR",
    "name": "Gómfoi",
    "lat": "39.46413",
    "lng": "21.69342"
  },
  {
    "country": "GR",
    "name": "Glyfáda",
    "lat": "37.86289",
    "lng": "23.75802"
  },
  {
    "country": "GR",
    "name": "Gázi",
    "lat": "35.32531",
    "lng": "25.06694"
  },
  {
    "country": "GR",
    "name": "Gavaloú",
    "lat": "38.52903",
    "lng": "21.53226"
  },
  {
    "country": "GR",
    "name": "Gastoúni",
    "lat": "37.85",
    "lng": "21.25"
  },
  {
    "country": "GR",
    "name": "Gargaliánoi",
    "lat": "37.06518",
    "lng": "21.63809"
  },
  {
    "country": "GR",
    "name": "Galaxídhion",
    "lat": "38.38067",
    "lng": "22.38001"
  },
  {
    "country": "GR",
    "name": "Galátsi",
    "lat": "38.01667",
    "lng": "23.75"
  },
  {
    "country": "GR",
    "name": "Galatás",
    "lat": "38.35742",
    "lng": "21.56222"
  },
  {
    "country": "GR",
    "name": "Galatás",
    "lat": "37.49618",
    "lng": "23.44886"
  },
  {
    "country": "GR",
    "name": "Galatás",
    "lat": "35.49864",
    "lng": "23.96341"
  },
  {
    "country": "GR",
    "name": "Gaïtánion",
    "lat": "37.79134",
    "lng": "20.87407"
  },
  {
    "country": "GR",
    "name": "Fry",
    "lat": "35.41623",
    "lng": "26.92328"
  },
  {
    "country": "GR",
    "name": "Folégandros",
    "lat": "36.62794",
    "lng": "24.92021"
  },
  {
    "country": "GR",
    "name": "Fyteíes",
    "lat": "38.69524",
    "lng": "21.18467"
  },
  {
    "country": "GR",
    "name": "Filótion",
    "lat": "37.05167",
    "lng": "25.49829"
  },
  {
    "country": "GR",
    "name": "Filothéi",
    "lat": "38.02524",
    "lng": "23.78257"
  },
  {
    "country": "GR",
    "name": "Fílla",
    "lat": "38.44177",
    "lng": "23.68306"
  },
  {
    "country": "GR",
    "name": "Filippiáda",
    "lat": "39.20472",
    "lng": "20.88222"
  },
  {
    "country": "GR",
    "name": "Filiatrá",
    "lat": "37.15637",
    "lng": "21.58532"
  },
  {
    "country": "GR",
    "name": "Filiátes",
    "lat": "39.60111",
    "lng": "20.31194"
  },
  {
    "country": "GR",
    "name": "Fylí",
    "lat": "38.10235",
    "lng": "23.66901"
  },
  {
    "country": "GR",
    "name": "Fíki",
    "lat": "39.51602",
    "lng": "21.65556"
  },
  {
    "country": "GR",
    "name": "Fársala",
    "lat": "39.29472",
    "lng": "22.38472"
  },
  {
    "country": "GR",
    "name": "Fáros",
    "lat": "38.39959",
    "lng": "23.62275"
  },
  {
    "country": "GR",
    "name": "Farkadóna",
    "lat": "39.6",
    "lng": "22.06667"
  },
  {
    "country": "GR",
    "name": "Magoúla",
    "lat": "39.45395",
    "lng": "21.80351"
  },
  {
    "country": "GR",
    "name": "Fálanna",
    "lat": "39.71986",
    "lng": "22.39733"
  },
  {
    "country": "GR",
    "name": "Examília",
    "lat": "37.89736",
    "lng": "22.92832"
  },
  {
    "country": "GR",
    "name": "Evxinoúpolis",
    "lat": "39.18414",
    "lng": "22.73831"
  },
  {
    "country": "GR",
    "name": "Ermoúpolis",
    "lat": "37.44227",
    "lng": "24.94248"
  },
  {
    "country": "GR",
    "name": "Ermióni",
    "lat": "37.38492",
    "lng": "23.24686"
  },
  {
    "country": "GR",
    "name": "Erythrés",
    "lat": "38.21741",
    "lng": "23.32234"
  },
  {
    "country": "GR",
    "name": "Erétria",
    "lat": "38.40097",
    "lng": "23.8022"
  },
  {
    "country": "GR",
    "name": "Eresós",
    "lat": "39.16973",
    "lng": "25.93437"
  },
  {
    "country": "GR",
    "name": "Epitálio",
    "lat": "37.62675",
    "lng": "21.49528"
  },
  {
    "country": "GR",
    "name": "Ano Arhanes",
    "lat": "35.23333",
    "lng": "25.16667"
  },
  {
    "country": "GR",
    "name": "Emporeío",
    "lat": "36.35816",
    "lng": "25.44615"
  },
  {
    "country": "GR",
    "name": "Émponas",
    "lat": "36.22683",
    "lng": "27.85645"
  },
  {
    "country": "GR",
    "name": "Eloúnda",
    "lat": "35.265",
    "lng": "25.72127"
  },
  {
    "country": "GR",
    "name": "Ellinikó",
    "lat": "37.89013",
    "lng": "23.74406"
  },
  {
    "country": "GR",
    "name": "Elefsína",
    "lat": "38.04135",
    "lng": "23.54295"
  },
  {
    "country": "GR",
    "name": "Eleoúsa",
    "lat": "39.70639",
    "lng": "20.7925"
  },
  {
    "country": "GR",
    "name": "Eleoúsa",
    "lat": "39.15278",
    "lng": "20.96214"
  },
  {
    "country": "GR",
    "name": "Eláteia",
    "lat": "38.6277",
    "lng": "22.76492"
  },
  {
    "country": "GR",
    "name": "Elassóna",
    "lat": "39.89472",
    "lng": "22.18861"
  },
  {
    "country": "GR",
    "name": "Ekáli",
    "lat": "38.11035",
    "lng": "23.83505"
  },
  {
    "country": "GR",
    "name": "Voulgaréli",
    "lat": "39.37194",
    "lng": "21.18333"
  },
  {
    "country": "GR",
    "name": "Dhrosiá",
    "lat": "38.48413",
    "lng": "23.54774"
  },
  {
    "country": "GR",
    "name": "Drosiá",
    "lat": "38.11977",
    "lng": "23.86428"
  },
  {
    "country": "GR",
    "name": "Drépanon",
    "lat": "37.53888",
    "lng": "22.89323"
  },
  {
    "country": "GR",
    "name": "Dhráfi",
    "lat": "38.02375",
    "lng": "23.90788"
  },
  {
    "country": "GR",
    "name": "Domokós",
    "lat": "39.12722",
    "lng": "22.30028"
  },
  {
    "country": "GR",
    "name": "Dhokímion",
    "lat": "38.61352",
    "lng": "21.38072"
  },
  {
    "country": "GR",
    "name": "Dístomo",
    "lat": "38.42892",
    "lng": "22.66728"
  },
  {
    "country": "GR",
    "name": "Diónysos",
    "lat": "38.10458",
    "lng": "23.87938"
  },
  {
    "country": "GR",
    "name": "Dimitsána",
    "lat": "37.59524",
    "lng": "22.04025"
  },
  {
    "country": "GR",
    "name": "Dílesi",
    "lat": "38.33762",
    "lng": "23.67077"
  },
  {
    "country": "GR",
    "name": "Dídyma",
    "lat": "37.4625",
    "lng": "23.17183"
  },
  {
    "country": "GR",
    "name": "Deskáti",
    "lat": "39.92422",
    "lng": "21.81031"
  },
  {
    "country": "GR",
    "name": "Delphi",
    "lat": "38.47942",
    "lng": "22.49357"
  },
  {
    "country": "GR",
    "name": "Darátsos",
    "lat": "35.49955",
    "lng": "23.97488"
  },
  {
    "country": "GR",
    "name": "Dhafní",
    "lat": "37.95002",
    "lng": "23.73437"
  },
  {
    "country": "GR",
    "name": "Rodópoli",
    "lat": "38.11669",
    "lng": "23.87572"
  },
  {
    "country": "GR",
    "name": "Ágios Geórgios",
    "lat": "38.39343",
    "lng": "22.93189"
  },
  {
    "country": "GR",
    "name": "Áyios Vasílios",
    "lat": "37.79763",
    "lng": "22.79727"
  },
  {
    "country": "GR",
    "name": "Áyios Thomás",
    "lat": "38.27717",
    "lng": "23.58906"
  },
  {
    "country": "GR",
    "name": "Ágios Stéfanos",
    "lat": "38.14657",
    "lng": "23.85608"
  },
  {
    "country": "GR",
    "name": "Áyios Nikólaos",
    "lat": "38.42051",
    "lng": "23.64772"
  },
  {
    "country": "GR",
    "name": "Arkoúdi",
    "lat": "37.84681",
    "lng": "21.11022"
  },
  {
    "country": "GR",
    "name": "Ágios Nikólaos",
    "lat": "35.19106",
    "lng": "25.71524"
  },
  {
    "country": "GR",
    "name": "Áyios Konstandínos",
    "lat": "38.75612",
    "lng": "22.85757"
  },
  {
    "country": "GR",
    "name": "Áyios Konstandínos",
    "lat": "38.63337",
    "lng": "21.3995"
  },
  {
    "country": "GR",
    "name": "Agios Kirykos",
    "lat": "37.61472",
    "lng": "26.29444"
  },
  {
    "country": "GR",
    "name": "Ágios Efstrátios",
    "lat": "39.53889",
    "lng": "24.99167"
  },
  {
    "country": "GR",
    "name": "Agios Dimitrios",
    "lat": "37.93333",
    "lng": "23.73333"
  },
  {
    "country": "GR",
    "name": "Ágios Andréas",
    "lat": "37.34519",
    "lng": "22.76466"
  },
  {
    "country": "GR",
    "name": "Áyios Adhrianós",
    "lat": "37.59975",
    "lng": "22.8456"
  },
  {
    "country": "GR",
    "name": "Ágioi Theódoroi",
    "lat": "37.92736",
    "lng": "23.14221"
  },
  {
    "country": "GR",
    "name": "Ágioi Déka",
    "lat": "35.06667",
    "lng": "24.96667"
  },
  {
    "country": "GR",
    "name": "Áyioi Apóstoloi",
    "lat": "38.29169",
    "lng": "23.91011"
  },
  {
    "country": "GR",
    "name": "Agía Varvára",
    "lat": "37.98938",
    "lng": "23.66011"
  },
  {
    "country": "GR",
    "name": "Agía Varvára",
    "lat": "35.13715",
    "lng": "25.00131"
  },
  {
    "country": "GR",
    "name": "Agía Triáda",
    "lat": "38.35505",
    "lng": "22.90881"
  },
  {
    "country": "GR",
    "name": "Ayía Triás",
    "lat": "37.63707",
    "lng": "22.80504"
  },
  {
    "country": "GR",
    "name": "Agiásos",
    "lat": "39.08295",
    "lng": "26.37218"
  },
  {
    "country": "GR",
    "name": "Agía Paraskeví",
    "lat": "39.24792",
    "lng": "26.27178"
  },
  {
    "country": "GR",
    "name": "Agía Paraskeví",
    "lat": "38.01667",
    "lng": "23.83333"
  },
  {
    "country": "GR",
    "name": "Agía Marína",
    "lat": "37.1543",
    "lng": "26.85162"
  },
  {
    "country": "GR",
    "name": "Agía Marína",
    "lat": "35.51778",
    "lng": "23.92675"
  },
  {
    "country": "GR",
    "name": "Agía Galíni",
    "lat": "35.09707",
    "lng": "24.68818"
  },
  {
    "country": "GR",
    "name": "Agiá",
    "lat": "39.71901",
    "lng": "22.75869"
  },
  {
    "country": "GR",
    "name": "Avlónas",
    "lat": "38.25149",
    "lng": "23.69554"
  },
  {
    "country": "GR",
    "name": "Atsipópoulo",
    "lat": "35.35253",
    "lng": "24.43378"
  },
  {
    "country": "GR",
    "name": "Athens",
    "lat": "37.97945",
    "lng": "23.71622"
  },
  {
    "country": "GR",
    "name": "Athíkia",
    "lat": "37.81675",
    "lng": "22.92939"
  },
  {
    "country": "GR",
    "name": "Atalánti",
    "lat": "38.65111",
    "lng": "22.99917"
  },
  {
    "country": "GR",
    "name": "Ástros",
    "lat": "37.40395",
    "lng": "22.72118"
  },
  {
    "country": "GR",
    "name": "Astypálaia",
    "lat": "36.55",
    "lng": "26.35"
  },
  {
    "country": "GR",
    "name": "Astakós",
    "lat": "38.53556",
    "lng": "21.08135"
  },
  {
    "country": "GR",
    "name": "Ássos",
    "lat": "37.93955",
    "lng": "22.82223"
  },
  {
    "country": "GR",
    "name": "Asprópyrgos",
    "lat": "38.06134",
    "lng": "23.58971"
  },
  {
    "country": "GR",
    "name": "Asprángeloi",
    "lat": "39.82328",
    "lng": "20.72862"
  },
  {
    "country": "GR",
    "name": "Asopós",
    "lat": "36.72986",
    "lng": "22.85455"
  },
  {
    "country": "GR",
    "name": "Asopía",
    "lat": "38.29882",
    "lng": "23.50189"
  },
  {
    "country": "GR",
    "name": "Asíni",
    "lat": "37.54431",
    "lng": "22.86435"
  },
  {
    "country": "GR",
    "name": "Asímion",
    "lat": "35.04321",
    "lng": "25.09277"
  },
  {
    "country": "GR",
    "name": "Argyroúpoli",
    "lat": "37.90594",
    "lng": "23.75035"
  },
  {
    "country": "GR",
    "name": "Argyropoúli",
    "lat": "39.82567",
    "lng": "22.30689"
  },
  {
    "country": "GR",
    "name": "Artesianó",
    "lat": "39.40194",
    "lng": "21.89649"
  },
  {
    "country": "GR",
    "name": "Árta",
    "lat": "39.16014",
    "lng": "20.98561"
  },
  {
    "country": "GR",
    "name": "Árma",
    "lat": "38.35121",
    "lng": "23.48599"
  },
  {
    "country": "GR",
    "name": "Archontochóri",
    "lat": "38.70053",
    "lng": "21.03896"
  },
  {
    "country": "GR",
    "name": "Archaía Olympía",
    "lat": "37.64788",
    "lng": "21.6271"
  },
  {
    "country": "GR",
    "name": "Arkhaía Kórinthos",
    "lat": "37.90953",
    "lng": "22.88353"
  },
  {
    "country": "GR",
    "name": "Arkalochóri",
    "lat": "35.14634",
    "lng": "25.26538"
  },
  {
    "country": "GR",
    "name": "Áris",
    "lat": "37.0992",
    "lng": "22.00443"
  },
  {
    "country": "GR",
    "name": "Aria",
    "lat": "37.57372",
    "lng": "22.83539"
  },
  {
    "country": "GR",
    "name": "Argostólion",
    "lat": "38.18109",
    "lng": "20.48903"
  },
  {
    "country": "GR",
    "name": "Árgos",
    "lat": "37.63333",
    "lng": "22.73333"
  },
  {
    "country": "GR",
    "name": "Argalastí",
    "lat": "39.22627",
    "lng": "23.21868"
  },
  {
    "country": "GR",
    "name": "Arfará",
    "lat": "37.15619",
    "lng": "22.04485"
  },
  {
    "country": "GR",
    "name": "Aráchova",
    "lat": "38.47958",
    "lng": "22.5835"
  },
  {
    "country": "GR",
    "name": "Anthiró",
    "lat": "39.34722",
    "lng": "21.45833"
  },
  {
    "country": "GR",
    "name": "Anthíli",
    "lat": "38.85",
    "lng": "22.47906"
  },
  {
    "country": "GR",
    "name": "Anógeia",
    "lat": "35.29084",
    "lng": "24.88412"
  },
  {
    "country": "GR",
    "name": "Áno Sýros",
    "lat": "37.44997",
    "lng": "24.93562"
  },
  {
    "country": "GR",
    "name": "Áno Merá",
    "lat": "37.44904",
    "lng": "25.39095"
  },
  {
    "country": "GR",
    "name": "Áno Liósia",
    "lat": "38.08333",
    "lng": "23.7"
  },
  {
    "country": "GR",
    "name": "Áno Lekhónia",
    "lat": "39.32763",
    "lng": "23.05395"
  },
  {
    "country": "GR",
    "name": "Kopanáki",
    "lat": "37.28913",
    "lng": "21.81854"
  },
  {
    "country": "GR",
    "name": "Áno Kastrítsi",
    "lat": "38.27228",
    "lng": "21.836"
  },
  {
    "country": "GR",
    "name": "Áno Kalentíni",
    "lat": "39.25",
    "lng": "21.18528"
  },
  {
    "country": "GR",
    "name": "Anoixi",
    "lat": "38.13267",
    "lng": "23.85874"
  },
  {
    "country": "GR",
    "name": "Megalochóri",
    "lat": "37.71051",
    "lng": "23.34659"
  },
  {
    "country": "GR",
    "name": "Angelókastro",
    "lat": "38.56585",
    "lng": "21.29631"
  },
  {
    "country": "GR",
    "name": "Anéza",
    "lat": "39.08658",
    "lng": "20.923"
  },
  {
    "country": "GR",
    "name": "Andros",
    "lat": "37.83333",
    "lng": "24.93333"
  },
  {
    "country": "GR",
    "name": "Andravída",
    "lat": "37.90588",
    "lng": "21.26936"
  },
  {
    "country": "GR",
    "name": "Antirrio",
    "lat": "38.33014",
    "lng": "21.76413"
  },
  {
    "country": "GR",
    "name": "Antíparos",
    "lat": "37.0394",
    "lng": "25.08258"
  },
  {
    "country": "GR",
    "name": "Antimácheia",
    "lat": "36.80888",
    "lng": "27.09764"
  },
  {
    "country": "GR",
    "name": "Antikyra",
    "lat": "38.38333",
    "lng": "22.63333"
  },
  {
    "country": "GR",
    "name": "Anávra",
    "lat": "39.18996",
    "lng": "22.09308"
  },
  {
    "country": "GR",
    "name": "Anávyssos",
    "lat": "37.73414",
    "lng": "23.94389"
  },
  {
    "country": "GR",
    "name": "Anatolí",
    "lat": "39.63531",
    "lng": "20.86578"
  },
  {
    "country": "GR",
    "name": "Anáfi",
    "lat": "36.35",
    "lng": "25.76667"
  },
  {
    "country": "GR",
    "name": "Amorgós",
    "lat": "36.83175",
    "lng": "25.89821"
  },
  {
    "country": "GR",
    "name": "Ámfissa",
    "lat": "38.52813",
    "lng": "22.37713"
  },
  {
    "country": "GR",
    "name": "Amfilochía",
    "lat": "38.85944",
    "lng": "21.16639"
  },
  {
    "country": "GR",
    "name": "Amfíkleia",
    "lat": "38.63912",
    "lng": "22.59171"
  },
  {
    "country": "GR",
    "name": "Ampelóna",
    "lat": "39.74481",
    "lng": "22.36575"
  },
  {
    "country": "GR",
    "name": "Ambelókipoi",
    "lat": "37.75809",
    "lng": "20.87248"
  },
  {
    "country": "GR",
    "name": "Ampelákia",
    "lat": "37.95055",
    "lng": "23.52803"
  },
  {
    "country": "GR",
    "name": "Maroúsi",
    "lat": "38.05",
    "lng": "23.8"
  },
  {
    "country": "GR",
    "name": "Amárynthos",
    "lat": "38.393",
    "lng": "23.88492"
  },
  {
    "country": "GR",
    "name": "Amaliáda",
    "lat": "37.79842",
    "lng": "21.35068"
  },
  {
    "country": "GR",
    "name": "Almyrós",
    "lat": "39.18222",
    "lng": "22.75944"
  },
  {
    "country": "GR",
    "name": "Álli Meriá",
    "lat": "39.37039",
    "lng": "22.9835"
  },
  {
    "country": "GR",
    "name": "Alivéri",
    "lat": "38.41667",
    "lng": "24.03333"
  },
  {
    "country": "GR",
    "name": "Alíartos",
    "lat": "38.36667",
    "lng": "23.1"
  },
  {
    "country": "GR",
    "name": "Alfeioúsa",
    "lat": "37.64019",
    "lng": "21.5375"
  },
  {
    "country": "GR",
    "name": "Akráta",
    "lat": "38.15469",
    "lng": "22.3183"
  },
  {
    "country": "GR",
    "name": "Akraifnía",
    "lat": "38.45663",
    "lng": "23.22093"
  },
  {
    "country": "GR",
    "name": "Acharnés",
    "lat": "38.08333",
    "lng": "23.73333"
  },
  {
    "country": "GR",
    "name": "Aíyira",
    "lat": "38.14846",
    "lng": "22.35426"
  },
  {
    "country": "GR",
    "name": "Aígio",
    "lat": "38.24861",
    "lng": "22.08194"
  },
  {
    "country": "GR",
    "name": "Aegina",
    "lat": "37.74667",
    "lng": "23.4275"
  },
  {
    "country": "GR",
    "name": "Aitolikó",
    "lat": "38.43704",
    "lng": "21.35358"
  },
  {
    "country": "GR",
    "name": "Aigáleo",
    "lat": "37.98333",
    "lng": "23.68333"
  },
  {
    "country": "GR",
    "name": "Aidipsós",
    "lat": "38.87924",
    "lng": "23.04691"
  },
  {
    "country": "GR",
    "name": "Aiánteio",
    "lat": "37.92135",
    "lng": "23.45877"
  },
  {
    "country": "GR",
    "name": "Agrínio",
    "lat": "38.62139",
    "lng": "21.40778"
  },
  {
    "country": "GR",
    "name": "Agriá",
    "lat": "39.34078",
    "lng": "23.01258"
  },
  {
    "country": "GR",
    "name": "Agnanteró",
    "lat": "39.48586",
    "lng": "21.84789"
  },
  {
    "country": "GR",
    "name": "Afrátion",
    "lat": "38.45212",
    "lng": "23.68775"
  },
  {
    "country": "GR",
    "name": "Afidnés",
    "lat": "38.20332",
    "lng": "23.83982"
  },
  {
    "country": "GR",
    "name": "Adámas",
    "lat": "36.72506",
    "lng": "24.44685"
  },
  {
    "country": "GR",
    "name": "Ródos",
    "lat": "36.43556",
    "lng": "28.22199"
  },
  {
    "country": "GR",
    "name": "Néa Alikarnassós",
    "lat": "35.33977",
    "lng": "25.15895"
  },
  {
    "country": "GR",
    "name": "Kremastí",
    "lat": "36.40981",
    "lng": "28.1192"
  },
  {
    "country": "GR",
    "name": "Afántou",
    "lat": "36.29354",
    "lng": "28.16225"
  },
  {
    "country": "GR",
    "name": "Archángelos",
    "lat": "36.21492",
    "lng": "28.11487"
  },
  {
    "country": "GR",
    "name": "Lárdos",
    "lat": "36.09419",
    "lng": "28.01565"
  },
  {
    "country": "GR",
    "name": "Zipári",
    "lat": "36.87696",
    "lng": "27.20532"
  },
  {
    "country": "GR",
    "name": "Néos Oropós",
    "lat": "39.15064",
    "lng": "20.73636"
  },
  {
    "country": "GR",
    "name": "Zygós",
    "lat": "41.0132",
    "lng": "24.38132"
  },
  {
    "country": "GR",
    "name": "Akrolímni",
    "lat": "40.6802",
    "lng": "22.2645"
  },
  {
    "country": "GR",
    "name": "Giannitsá",
    "lat": "40.79194",
    "lng": "22.4075"
  },
  {
    "country": "GR",
    "name": "Gerakaroú",
    "lat": "40.62666",
    "lng": "23.21566"
  },
  {
    "country": "GR",
    "name": "Genisséa",
    "lat": "41.06165",
    "lng": "24.96248"
  },
  {
    "country": "GR",
    "name": "Géfyra",
    "lat": "40.73253",
    "lng": "22.69359"
  },
  {
    "country": "GR",
    "name": "Xiropótamos",
    "lat": "41.19206",
    "lng": "24.10385"
  },
  {
    "country": "GR",
    "name": "Xinó Neró",
    "lat": "40.69028",
    "lng": "21.62324"
  },
  {
    "country": "GR",
    "name": "Xilópolis",
    "lat": "40.92713",
    "lng": "23.17944"
  },
  {
    "country": "GR",
    "name": "Xylaganí",
    "lat": "40.97437",
    "lng": "25.42022"
  },
  {
    "country": "GR",
    "name": "Xánthi",
    "lat": "41.13488",
    "lng": "24.888"
  },
  {
    "country": "GR",
    "name": "Vrontoú",
    "lat": "40.19356",
    "lng": "22.43203"
  },
  {
    "country": "GR",
    "name": "Vólakas",
    "lat": "41.31661",
    "lng": "24.00215"
  },
  {
    "country": "GR",
    "name": "Vergína",
    "lat": "40.48654",
    "lng": "22.31735"
  },
  {
    "country": "GR",
    "name": "Véroia",
    "lat": "40.52437",
    "lng": "22.20242"
  },
  {
    "country": "GR",
    "name": "Velventós",
    "lat": "40.25532",
    "lng": "22.07543"
  },
  {
    "country": "GR",
    "name": "Vathýlakkos",
    "lat": "40.76942",
    "lng": "22.7088"
  },
  {
    "country": "GR",
    "name": "Vasiliká",
    "lat": "40.47966",
    "lng": "23.13695"
  },
  {
    "country": "GR",
    "name": "Vamvakófyto",
    "lat": "41.17916",
    "lng": "23.39602"
  },
  {
    "country": "GR",
    "name": "Valteró",
    "lat": "41.17927",
    "lng": "23.32022"
  },
  {
    "country": "GR",
    "name": "Tsotíli",
    "lat": "40.26147",
    "lng": "21.32533"
  },
  {
    "country": "GR",
    "name": "Trílofos",
    "lat": "40.46898",
    "lng": "22.9718"
  },
  {
    "country": "GR",
    "name": "Tríkala",
    "lat": "40.59814",
    "lng": "22.55733"
  },
  {
    "country": "GR",
    "name": "Tycheró",
    "lat": "41.02878",
    "lng": "26.29455"
  },
  {
    "country": "GR",
    "name": "Thessaloníki",
    "lat": "40.64361",
    "lng": "22.93086"
  },
  {
    "country": "GR",
    "name": "Thérmi",
    "lat": "40.54712",
    "lng": "23.01967"
  },
  {
    "country": "GR",
    "name": "Thásos",
    "lat": "40.77806",
    "lng": "24.70944"
  },
  {
    "country": "GR",
    "name": "Terpní",
    "lat": "40.91643",
    "lng": "23.48137"
  },
  {
    "country": "GR",
    "name": "Svorónos",
    "lat": "40.26805",
    "lng": "22.46366"
  },
  {
    "country": "GR",
    "name": "Strymonikó",
    "lat": "41.04144",
    "lng": "23.31487"
  },
  {
    "country": "GR",
    "name": "Stratónion",
    "lat": "40.51406",
    "lng": "23.82471"
  },
  {
    "country": "GR",
    "name": "Stavroúpoli",
    "lat": "40.66944",
    "lng": "22.93806"
  },
  {
    "country": "GR",
    "name": "Stavrós",
    "lat": "40.66498",
    "lng": "23.70015"
  },
  {
    "country": "GR",
    "name": "Stavrós",
    "lat": "40.58939",
    "lng": "22.30861"
  },
  {
    "country": "GR",
    "name": "Sourotí",
    "lat": "40.47274",
    "lng": "23.09197"
  },
  {
    "country": "GR",
    "name": "Souflí",
    "lat": "41.19194",
    "lng": "26.29944"
  },
  {
    "country": "GR",
    "name": "Sosándra",
    "lat": "40.99894",
    "lng": "22.03254"
  },
  {
    "country": "GR",
    "name": "Sochós",
    "lat": "40.81788",
    "lng": "23.35546"
  },
  {
    "country": "GR",
    "name": "Smínthi",
    "lat": "41.23333",
    "lng": "24.86667"
  },
  {
    "country": "GR",
    "name": "Skoútari",
    "lat": "41.01871",
    "lng": "23.51971"
  },
  {
    "country": "GR",
    "name": "Skotoússa",
    "lat": "41.12844",
    "lng": "23.38174"
  },
  {
    "country": "GR",
    "name": "Skýdra",
    "lat": "40.76722",
    "lng": "22.15194"
  },
  {
    "country": "GR",
    "name": "Leptokaryá",
    "lat": "40.06032",
    "lng": "22.5612"
  },
  {
    "country": "GR",
    "name": "Sitagroí",
    "lat": "41.11067",
    "lng": "24.02755"
  },
  {
    "country": "GR",
    "name": "Síndos",
    "lat": "40.67045",
    "lng": "22.80545"
  },
  {
    "country": "GR",
    "name": "Sykiá",
    "lat": "40.03874",
    "lng": "23.94046"
  },
  {
    "country": "GR",
    "name": "Sykiés",
    "lat": "40.64944",
    "lng": "22.95083"
  },
  {
    "country": "GR",
    "name": "Sidirókastro",
    "lat": "41.23499",
    "lng": "23.38899"
  },
  {
    "country": "GR",
    "name": "Siátista",
    "lat": "40.26194",
    "lng": "21.54417"
  },
  {
    "country": "GR",
    "name": "Sfendámi",
    "lat": "40.41307",
    "lng": "22.54677"
  },
  {
    "country": "GR",
    "name": "Sevastianá",
    "lat": "40.76874",
    "lng": "22.12346"
  },
  {
    "country": "GR",
    "name": "Sérvia",
    "lat": "40.17972",
    "lng": "21.99444"
  },
  {
    "country": "GR",
    "name": "Sérres",
    "lat": "41.08499",
    "lng": "23.54757"
  },
  {
    "country": "GR",
    "name": "Sélero",
    "lat": "41.13382",
    "lng": "24.99408"
  },
  {
    "country": "GR",
    "name": "Sárti",
    "lat": "40.09369",
    "lng": "23.97859"
  },
  {
    "country": "GR",
    "name": "Sápes",
    "lat": "41.02861",
    "lng": "25.69306"
  },
  {
    "country": "GR",
    "name": "Samothráki",
    "lat": "40.47333",
    "lng": "25.52222"
  },
  {
    "country": "GR",
    "name": "Rodolívos",
    "lat": "40.92055",
    "lng": "23.97489"
  },
  {
    "country": "GR",
    "name": "Rizó",
    "lat": "40.73331",
    "lng": "22.13674"
  },
  {
    "country": "GR",
    "name": "Rizómata",
    "lat": "40.35061",
    "lng": "22.21079"
  },
  {
    "country": "GR",
    "name": "Rízia",
    "lat": "41.6249",
    "lng": "26.42771"
  },
  {
    "country": "GR",
    "name": "Rizári",
    "lat": "40.78373",
    "lng": "22.088"
  },
  {
    "country": "GR",
    "name": "Ritíni",
    "lat": "40.28835",
    "lng": "22.28361"
  },
  {
    "country": "GR",
    "name": "Péfka",
    "lat": "40.65806",
    "lng": "22.99378"
  },
  {
    "country": "GR",
    "name": "Ptolemaḯda",
    "lat": "40.51472",
    "lng": "21.67861"
  },
  {
    "country": "GR",
    "name": "Fteliá",
    "lat": "41.08266",
    "lng": "24.18968"
  },
  {
    "country": "GR",
    "name": "Provatás",
    "lat": "41.06825",
    "lng": "23.3903"
  },
  {
    "country": "GR",
    "name": "Próti",
    "lat": "40.94411",
    "lng": "24.00118"
  },
  {
    "country": "GR",
    "name": "Prosotsáni",
    "lat": "41.18333",
    "lng": "23.96667"
  },
  {
    "country": "GR",
    "name": "Prómachoi",
    "lat": "41.02517",
    "lng": "22.00437"
  },
  {
    "country": "GR",
    "name": "Próchoma",
    "lat": "40.79826",
    "lng": "22.66659"
  },
  {
    "country": "GR",
    "name": "Profítis Ilías",
    "lat": "40.81373",
    "lng": "22.16166"
  },
  {
    "country": "GR",
    "name": "Potamiá",
    "lat": "40.71633",
    "lng": "24.72859"
  },
  {
    "country": "GR",
    "name": "Portariá",
    "lat": "40.28405",
    "lng": "23.29549"
  },
  {
    "country": "GR",
    "name": "Pontisméno",
    "lat": "41.20885",
    "lng": "23.28325"
  },
  {
    "country": "GR",
    "name": "Polýgyros",
    "lat": "40.37704",
    "lng": "23.44135"
  },
  {
    "country": "GR",
    "name": "Políchni",
    "lat": "40.66671",
    "lng": "22.94881"
  },
  {
    "country": "GR",
    "name": "Polýkastro",
    "lat": "40.99444",
    "lng": "22.56909"
  },
  {
    "country": "GR",
    "name": "Polykárpi",
    "lat": "40.92598",
    "lng": "22.01634"
  },
  {
    "country": "GR",
    "name": "Plagiári",
    "lat": "40.47276",
    "lng": "22.9579"
  },
  {
    "country": "GR",
    "name": "Platý",
    "lat": "40.64241",
    "lng": "22.53458"
  },
  {
    "country": "GR",
    "name": "Platanórevma",
    "lat": "40.20083",
    "lng": "22.02488"
  },
  {
    "country": "GR",
    "name": "Chalástra",
    "lat": "40.62643",
    "lng": "22.73291"
  },
  {
    "country": "GR",
    "name": "Pylaía",
    "lat": "40.59918",
    "lng": "22.98613"
  },
  {
    "country": "GR",
    "name": "Petroússa",
    "lat": "41.1947",
    "lng": "24.01731"
  },
  {
    "country": "GR",
    "name": "Petrochóri",
    "lat": "41.08742",
    "lng": "24.84092"
  },
  {
    "country": "GR",
    "name": "Peteinós",
    "lat": "41.10056",
    "lng": "24.89847"
  },
  {
    "country": "GR",
    "name": "Peristerá",
    "lat": "40.54881",
    "lng": "23.1654"
  },
  {
    "country": "GR",
    "name": "Perístasi",
    "lat": "40.27443",
    "lng": "22.54164"
  },
  {
    "country": "GR",
    "name": "Peraía",
    "lat": "40.49874",
    "lng": "22.92617"
  },
  {
    "country": "GR",
    "name": "Péplos",
    "lat": "40.95755",
    "lng": "26.26577"
  },
  {
    "country": "GR",
    "name": "Pentaplátano",
    "lat": "40.81902",
    "lng": "22.41903"
  },
  {
    "country": "GR",
    "name": "Pentálofos",
    "lat": "40.74296",
    "lng": "22.85256"
  },
  {
    "country": "GR",
    "name": "Pélla",
    "lat": "40.76169",
    "lng": "22.52637"
  },
  {
    "country": "GR",
    "name": "Pedinó",
    "lat": "40.91013",
    "lng": "22.87253"
  },
  {
    "country": "GR",
    "name": "Patrída",
    "lat": "40.56071",
    "lng": "22.18545"
  },
  {
    "country": "GR",
    "name": "Paranésti",
    "lat": "41.26667",
    "lng": "24.5"
  },
  {
    "country": "GR",
    "name": "Paralía",
    "lat": "40.2671",
    "lng": "22.59615"
  },
  {
    "country": "GR",
    "name": "Panórama",
    "lat": "40.58779",
    "lng": "23.0315"
  },
  {
    "country": "GR",
    "name": "Palaió Tsiflíki",
    "lat": "40.90495",
    "lng": "24.35083"
  },
  {
    "country": "GR",
    "name": "Axós",
    "lat": "40.80223",
    "lng": "22.36158"
  },
  {
    "country": "GR",
    "name": "Palaiokómi",
    "lat": "40.87068",
    "lng": "23.90121"
  },
  {
    "country": "GR",
    "name": "Palaiochóri",
    "lat": "40.94338",
    "lng": "24.17747"
  },
  {
    "country": "GR",
    "name": "Palaiochóri",
    "lat": "40.49186",
    "lng": "23.64928"
  },
  {
    "country": "GR",
    "name": "Palaífyto",
    "lat": "40.78283",
    "lng": "22.27388"
  },
  {
    "country": "GR",
    "name": "Páchni",
    "lat": "41.30506",
    "lng": "24.89438"
  },
  {
    "country": "GR",
    "name": "Ouranoupolis",
    "lat": "40.33333",
    "lng": "23.98333"
  },
  {
    "country": "GR",
    "name": "Ormýlia",
    "lat": "40.29451",
    "lng": "23.54332"
  },
  {
    "country": "GR",
    "name": "Orestiáda",
    "lat": "41.50306",
    "lng": "26.52972"
  },
  {
    "country": "GR",
    "name": "Oraiókastro",
    "lat": "40.73083",
    "lng": "22.91722"
  },
  {
    "country": "GR",
    "name": "Nisí",
    "lat": "40.6361",
    "lng": "22.38884"
  },
  {
    "country": "GR",
    "name": "Níkiti",
    "lat": "40.22204",
    "lng": "23.66837"
  },
  {
    "country": "GR",
    "name": "Nikísiani",
    "lat": "40.94739",
    "lng": "24.14311"
  },
  {
    "country": "GR",
    "name": "Nigríta",
    "lat": "40.90528",
    "lng": "23.49944"
  },
  {
    "country": "GR",
    "name": "Nestório",
    "lat": "40.41278",
    "lng": "21.06222"
  },
  {
    "country": "GR",
    "name": "Néos Skopós",
    "lat": "41.0239",
    "lng": "23.60927"
  },
  {
    "country": "GR",
    "name": "Néos Mylótopos",
    "lat": "40.81872",
    "lng": "22.35489"
  },
  {
    "country": "GR",
    "name": "Néos Marmarás",
    "lat": "40.0961",
    "lng": "23.78323"
  },
  {
    "country": "GR",
    "name": "Néo Soúli",
    "lat": "41.09397",
    "lng": "23.64376"
  },
  {
    "country": "GR",
    "name": "Néo Rýsi",
    "lat": "40.49605",
    "lng": "22.98794"
  },
  {
    "country": "GR",
    "name": "Néo Petrítsi",
    "lat": "41.27459",
    "lng": "23.29381"
  },
  {
    "country": "GR",
    "name": "Néo Agionéri",
    "lat": "40.80826",
    "lng": "22.70733"
  },
  {
    "country": "GR",
    "name": "Neochoroúda",
    "lat": "40.73817",
    "lng": "22.87557"
  },
  {
    "country": "GR",
    "name": "Neochóri",
    "lat": "41.51131",
    "lng": "26.4574"
  },
  {
    "country": "GR",
    "name": "Neochóri",
    "lat": "41.05231",
    "lng": "23.57997"
  },
  {
    "country": "GR",
    "name": "Néoi Epivátes",
    "lat": "40.49863",
    "lng": "22.91192"
  },
  {
    "country": "GR",
    "name": "Néa Zíchni",
    "lat": "41.03204",
    "lng": "23.8287"
  },
  {
    "country": "GR",
    "name": "Néa Výssa",
    "lat": "41.58449",
    "lng": "26.54318"
  },
  {
    "country": "GR",
    "name": "Néa Tríglia",
    "lat": "40.30575",
    "lng": "23.2066"
  },
  {
    "country": "GR",
    "name": "Néa Sánta",
    "lat": "40.84084",
    "lng": "22.92163"
  },
  {
    "country": "GR",
    "name": "Néa Róda",
    "lat": "40.38119",
    "lng": "23.92374"
  },
  {
    "country": "GR",
    "name": "Néa Poteídaia",
    "lat": "40.19409",
    "lng": "23.32832"
  },
  {
    "country": "GR",
    "name": "Néa Plágia",
    "lat": "40.26537",
    "lng": "23.20376"
  },
  {
    "country": "GR",
    "name": "Néa Péramos",
    "lat": "40.83854",
    "lng": "24.3013"
  },
  {
    "country": "GR",
    "name": "Néa Pélla",
    "lat": "40.76516",
    "lng": "22.49173"
  },
  {
    "country": "GR",
    "name": "Ólynthos",
    "lat": "40.29147",
    "lng": "23.34205"
  },
  {
    "country": "GR",
    "name": "Néa Moudhaniá",
    "lat": "40.2439",
    "lng": "23.28484"
  },
  {
    "country": "GR",
    "name": "Néa Michanióna",
    "lat": "40.46371",
    "lng": "22.8617"
  },
  {
    "country": "GR",
    "name": "Néa Mesimvría",
    "lat": "40.75158",
    "lng": "22.76904"
  },
  {
    "country": "GR",
    "name": "Néa Málgara",
    "lat": "40.60985",
    "lng": "22.68196"
  },
  {
    "country": "GR",
    "name": "Néa Magnisía",
    "lat": "40.68785",
    "lng": "22.84582"
  },
  {
    "country": "GR",
    "name": "Néa Karváli",
    "lat": "40.96148",
    "lng": "24.51132"
  },
  {
    "country": "GR",
    "name": "Néa Karyá",
    "lat": "40.90621",
    "lng": "24.70726"
  },
  {
    "country": "GR",
    "name": "Néa Kallikráteia",
    "lat": "40.31312",
    "lng": "23.06343"
  },
  {
    "country": "GR",
    "name": "Néa Iraklítsa",
    "lat": "40.86442",
    "lng": "24.3165"
  },
  {
    "country": "GR",
    "name": "Néa Fókaia",
    "lat": "40.13333",
    "lng": "23.39754"
  },
  {
    "country": "GR",
    "name": "Néa Éfesos",
    "lat": "40.22923",
    "lng": "22.49811"
  },
  {
    "country": "GR",
    "name": "Néa Apollonía",
    "lat": "40.62558",
    "lng": "23.44074"
  },
  {
    "country": "GR",
    "name": "Náousa",
    "lat": "40.62944",
    "lng": "22.06806"
  },
  {
    "country": "GR",
    "name": "Mikrópolis",
    "lat": "41.19351",
    "lng": "23.8157"
  },
  {
    "country": "GR",
    "name": "Mikró Monastíri",
    "lat": "40.7043",
    "lng": "22.54112"
  },
  {
    "country": "GR",
    "name": "Mikrókampos",
    "lat": "40.84098",
    "lng": "22.77483"
  },
  {
    "country": "GR",
    "name": "Mýki",
    "lat": "41.24384",
    "lng": "24.92084"
  },
  {
    "country": "GR",
    "name": "Mesopotamía",
    "lat": "40.50252",
    "lng": "21.1611"
  },
  {
    "country": "GR",
    "name": "Mesiméri",
    "lat": "40.41344",
    "lng": "23.0075"
  },
  {
    "country": "GR",
    "name": "Meneméni",
    "lat": "40.65829",
    "lng": "22.89712"
  },
  {
    "country": "GR",
    "name": "Melíti",
    "lat": "40.83434",
    "lng": "21.58426"
  },
  {
    "country": "GR",
    "name": "Melissochóri",
    "lat": "40.76796",
    "lng": "22.92858"
  },
  {
    "country": "GR",
    "name": "Melíki",
    "lat": "40.51685",
    "lng": "22.39599"
  },
  {
    "country": "GR",
    "name": "Megáli Panagía",
    "lat": "40.44505",
    "lng": "23.67999"
  },
  {
    "country": "GR",
    "name": "Mavrovoúni",
    "lat": "40.78243",
    "lng": "22.15629"
  },
  {
    "country": "GR",
    "name": "Mavrothálassa",
    "lat": "40.89427",
    "lng": "23.75048"
  },
  {
    "country": "GR",
    "name": "Mavrochóri",
    "lat": "40.51224",
    "lng": "21.32038"
  },
  {
    "country": "GR",
    "name": "Marína",
    "lat": "40.692",
    "lng": "22.10099"
  },
  {
    "country": "GR",
    "name": "Maniákoi",
    "lat": "40.50064",
    "lng": "21.24446"
  },
  {
    "country": "GR",
    "name": "Mándalo",
    "lat": "40.85677",
    "lng": "22.21264"
  },
  {
    "country": "GR",
    "name": "Díon",
    "lat": "40.17169",
    "lng": "22.48463"
  },
  {
    "country": "GR",
    "name": "Makrochóri",
    "lat": "40.55125",
    "lng": "22.24955"
  },
  {
    "country": "GR",
    "name": "Makrýgialos",
    "lat": "40.41551",
    "lng": "22.60392"
  },
  {
    "country": "GR",
    "name": "Loutrós",
    "lat": "40.58873",
    "lng": "22.39976"
  },
  {
    "country": "GR",
    "name": "Lófos",
    "lat": "40.24395",
    "lng": "22.38033"
  },
  {
    "country": "GR",
    "name": "Livádi",
    "lat": "40.12625",
    "lng": "22.15753"
  },
  {
    "country": "GR",
    "name": "Livaderó",
    "lat": "40.03455",
    "lng": "21.94279"
  },
  {
    "country": "GR",
    "name": "Litóchoro",
    "lat": "40.10056",
    "lng": "22.49778"
  },
  {
    "country": "GR",
    "name": "Lití",
    "lat": "40.74533",
    "lng": "22.97982"
  },
  {
    "country": "GR",
    "name": "Limenária",
    "lat": "40.62741",
    "lng": "24.5765"
  },
  {
    "country": "GR",
    "name": "Lýkeio",
    "lat": "41.06413",
    "lng": "25.6857"
  },
  {
    "country": "GR",
    "name": "Lianovérgi",
    "lat": "40.63526",
    "lng": "22.5082"
  },
  {
    "country": "GR",
    "name": "Lefkónas",
    "lat": "41.10029",
    "lng": "23.49658"
  },
  {
    "country": "GR",
    "name": "Lagyná",
    "lat": "40.72351",
    "lng": "23.0042"
  },
  {
    "country": "GR",
    "name": "Lávara",
    "lat": "41.26957",
    "lng": "26.38522"
  },
  {
    "country": "GR",
    "name": "Lagkadás",
    "lat": "40.75",
    "lng": "23.06667"
  },
  {
    "country": "GR",
    "name": "Lákkoma",
    "lat": "40.39139",
    "lng": "23.05578"
  },
  {
    "country": "GR",
    "name": "Laimós",
    "lat": "40.83628",
    "lng": "21.14061"
  },
  {
    "country": "GR",
    "name": "Lagós",
    "lat": "41.45102",
    "lng": "26.46067"
  },
  {
    "country": "GR",
    "name": "Krókos",
    "lat": "40.26349",
    "lng": "21.8176"
  },
  {
    "country": "GR",
    "name": "Krithiá",
    "lat": "40.84184",
    "lng": "22.98292"
  },
  {
    "country": "GR",
    "name": "Kristóni",
    "lat": "40.95962",
    "lng": "22.85929"
  },
  {
    "country": "GR",
    "name": "Krinídes",
    "lat": "41.01396",
    "lng": "24.29647"
  },
  {
    "country": "GR",
    "name": "Krýa Vrýsi",
    "lat": "40.68738",
    "lng": "22.30516"
  },
  {
    "country": "GR",
    "name": "Kozáni",
    "lat": "40.30069",
    "lng": "21.78896"
  },
  {
    "country": "GR",
    "name": "Kouloúra",
    "lat": "40.54652",
    "lng": "22.31795"
  },
  {
    "country": "GR",
    "name": "Koufália",
    "lat": "40.77778",
    "lng": "22.57194"
  },
  {
    "country": "GR",
    "name": "Korinós",
    "lat": "40.31659",
    "lng": "22.58817"
  },
  {
    "country": "GR",
    "name": "Koryfí",
    "lat": "40.60286",
    "lng": "22.50681"
  },
  {
    "country": "GR",
    "name": "Kopanós",
    "lat": "40.63382",
    "lng": "22.12893"
  },
  {
    "country": "GR",
    "name": "Kónitsa",
    "lat": "40.04861",
    "lng": "20.75667"
  },
  {
    "country": "GR",
    "name": "Kontariótissa",
    "lat": "40.22754",
    "lng": "22.461"
  },
  {
    "country": "GR",
    "name": "Komotiní",
    "lat": "41.11917",
    "lng": "25.40535"
  },
  {
    "country": "GR",
    "name": "Komniná",
    "lat": "40.59057",
    "lng": "21.77671"
  },
  {
    "country": "GR",
    "name": "Kolchikón",
    "lat": "40.75662",
    "lng": "23.13377"
  },
  {
    "country": "GR",
    "name": "Kolindrós",
    "lat": "40.47888",
    "lng": "22.48319"
  },
  {
    "country": "GR",
    "name": "Kokkinóchoma",
    "lat": "40.9269",
    "lng": "24.30805"
  },
  {
    "country": "GR",
    "name": "Koímisi",
    "lat": "41.21282",
    "lng": "23.30035"
  },
  {
    "country": "GR",
    "name": "Koíla",
    "lat": "40.33055",
    "lng": "21.79102"
  },
  {
    "country": "GR",
    "name": "Kleítos",
    "lat": "40.4314",
    "lng": "21.85806"
  },
  {
    "country": "GR",
    "name": "Kleidí",
    "lat": "40.56632",
    "lng": "22.59033"
  },
  {
    "country": "GR",
    "name": "Kítros",
    "lat": "40.37399",
    "lng": "22.57862"
  },
  {
    "country": "GR",
    "name": "Kýria",
    "lat": "41.099",
    "lng": "24.28915"
  },
  {
    "country": "GR",
    "name": "Kyprínos",
    "lat": "41.57542",
    "lng": "26.22905"
  },
  {
    "country": "GR",
    "name": "Kimméria",
    "lat": "41.14788",
    "lng": "24.93869"
  },
  {
    "country": "GR",
    "name": "Kýmina",
    "lat": "40.61354",
    "lng": "22.69278"
  },
  {
    "country": "GR",
    "name": "Kilkís",
    "lat": "40.99302",
    "lng": "22.87433"
  },
  {
    "country": "GR",
    "name": "Chrysoúpolis",
    "lat": "40.98556",
    "lng": "24.69389"
  },
  {
    "country": "GR",
    "name": "Chrysó",
    "lat": "41.05806",
    "lng": "23.65108"
  },
  {
    "country": "GR",
    "name": "Chrysochóri",
    "lat": "40.93328",
    "lng": "24.71088"
  },
  {
    "country": "GR",
    "name": "Chrysochórafa",
    "lat": "41.18097",
    "lng": "23.23551"
  },
  {
    "country": "GR",
    "name": "Chortiátis",
    "lat": "40.60954",
    "lng": "23.10014"
  },
  {
    "country": "GR",
    "name": "Choristí",
    "lat": "41.13056",
    "lng": "24.20843"
  },
  {
    "country": "GR",
    "name": "Charopó",
    "lat": "41.26031",
    "lng": "23.37279"
  },
  {
    "country": "GR",
    "name": "Chalkidóna",
    "lat": "40.73184",
    "lng": "22.59992"
  },
  {
    "country": "GR",
    "name": "Keramotí",
    "lat": "40.85591",
    "lng": "24.70595"
  },
  {
    "country": "GR",
    "name": "Kavýli",
    "lat": "41.56225",
    "lng": "26.5147"
  },
  {
    "country": "GR",
    "name": "Kavallári",
    "lat": "40.71539",
    "lng": "23.04588"
  },
  {
    "country": "GR",
    "name": "Kavála",
    "lat": "40.93959",
    "lng": "24.40687"
  },
  {
    "country": "GR",
    "name": "Káto Scholári",
    "lat": "40.42906",
    "lng": "23.02978"
  },
  {
    "country": "GR",
    "name": "Káto Nevrokópi",
    "lat": "41.35",
    "lng": "23.86667"
  },
  {
    "country": "GR",
    "name": "Káto Miliá",
    "lat": "40.25403",
    "lng": "22.34342"
  },
  {
    "country": "GR",
    "name": "Loutráki",
    "lat": "40.97116",
    "lng": "21.94659"
  },
  {
    "country": "GR",
    "name": "Káto Lipochóri",
    "lat": "40.75754",
    "lng": "22.17962"
  },
  {
    "country": "GR",
    "name": "Káto Kamíla",
    "lat": "41.02119",
    "lng": "23.48336"
  },
  {
    "country": "GR",
    "name": "Kateríni",
    "lat": "40.26956",
    "lng": "22.50608"
  },
  {
    "country": "GR",
    "name": "Kastoria",
    "lat": "40.52165",
    "lng": "21.26341"
  },
  {
    "country": "GR",
    "name": "Kastaniés",
    "lat": "41.64551",
    "lng": "26.47676"
  },
  {
    "country": "GR",
    "name": "Kassándreia",
    "lat": "40.04835",
    "lng": "23.41362"
  },
  {
    "country": "GR",
    "name": "Símantra",
    "lat": "40.34563",
    "lng": "23.31026"
  },
  {
    "country": "GR",
    "name": "Karítsa",
    "lat": "40.18745",
    "lng": "22.48171"
  },
  {
    "country": "GR",
    "name": "Karyótissa",
    "lat": "40.76915",
    "lng": "22.31331"
  },
  {
    "country": "GR",
    "name": "Karyes",
    "lat": "40.25715",
    "lng": "24.24498"
  },
  {
    "country": "GR",
    "name": "Kardiá",
    "lat": "40.46909",
    "lng": "22.99378"
  },
  {
    "country": "GR",
    "name": "Kampánis",
    "lat": "40.88951",
    "lng": "22.91682"
  },
  {
    "country": "GR",
    "name": "Kamariótissa",
    "lat": "40.47501",
    "lng": "25.47456"
  },
  {
    "country": "GR",
    "name": "Kalós Agrós",
    "lat": "41.10543",
    "lng": "24.0857"
  },
  {
    "country": "GR",
    "name": "Kalochóri",
    "lat": "40.64189",
    "lng": "22.85734"
  },
  {
    "country": "GR",
    "name": "Kallithéa",
    "lat": "40.2739",
    "lng": "22.57775"
  },
  {
    "country": "GR",
    "name": "Kallithéa",
    "lat": "40.07374",
    "lng": "23.44637"
  },
  {
    "country": "GR",
    "name": "Kallífytos",
    "lat": "41.1728",
    "lng": "24.21527"
  },
  {
    "country": "GR",
    "name": "Kalí Vrýsi",
    "lat": "41.14653",
    "lng": "23.90667"
  },
  {
    "country": "GR",
    "name": "Kalýves Polygýrou",
    "lat": "40.28659",
    "lng": "23.39033"
  },
  {
    "country": "GR",
    "name": "Ágios Spyrídon",
    "lat": "40.20778",
    "lng": "22.44311"
  },
  {
    "country": "GR",
    "name": "Kalývia",
    "lat": "40.75508",
    "lng": "22.21753"
  },
  {
    "country": "GR",
    "name": "Prínos",
    "lat": "40.7409",
    "lng": "24.57787"
  },
  {
    "country": "GR",
    "name": "Kalí",
    "lat": "40.81931",
    "lng": "22.17761"
  },
  {
    "country": "GR",
    "name": "Kalampáki",
    "lat": "41.05",
    "lng": "24.18333"
  },
  {
    "country": "GR",
    "name": "Kalamariá",
    "lat": "40.5825",
    "lng": "22.95028"
  },
  {
    "country": "GR",
    "name": "Kalá Déndra",
    "lat": "41.09941",
    "lng": "23.42396"
  },
  {
    "country": "GR",
    "name": "Léchovo",
    "lat": "40.58442",
    "lng": "21.49218"
  },
  {
    "country": "GR",
    "name": "Irákleia",
    "lat": "41.18217",
    "lng": "23.28243"
  },
  {
    "country": "GR",
    "name": "Ierissós",
    "lat": "40.39748",
    "lng": "23.87505"
  },
  {
    "country": "GR",
    "name": "Íasmos",
    "lat": "41.12747",
    "lng": "25.18573"
  },
  {
    "country": "GR",
    "name": "Grevená",
    "lat": "40.08452",
    "lng": "21.42744"
  },
  {
    "country": "GR",
    "name": "Gouménissa",
    "lat": "40.94604",
    "lng": "22.44974"
  },
  {
    "country": "GR",
    "name": "Gázoros",
    "lat": "41.02557",
    "lng": "23.77574"
  },
  {
    "country": "GR",
    "name": "Gallikós",
    "lat": "40.85817",
    "lng": "22.87604"
  },
  {
    "country": "GR",
    "name": "Galátista",
    "lat": "40.4682",
    "lng": "23.28015"
  },
  {
    "country": "GR",
    "name": "Galatiní",
    "lat": "40.31966",
    "lng": "21.55148"
  },
  {
    "country": "GR",
    "name": "Galatádes",
    "lat": "40.7559",
    "lng": "22.28062"
  },
  {
    "country": "GR",
    "name": "Fotolívos",
    "lat": "41.06013",
    "lng": "24.04724"
  },
  {
    "country": "GR",
    "name": "Néa Flogitá",
    "lat": "40.26108",
    "lng": "23.22107"
  },
  {
    "country": "GR",
    "name": "Flórina",
    "lat": "40.78197",
    "lng": "21.40981"
  },
  {
    "country": "GR",
    "name": "Filótas",
    "lat": "40.6252",
    "lng": "21.70851"
  },
  {
    "country": "GR",
    "name": "Fillýra",
    "lat": "41.11667",
    "lng": "25.63333"
  },
  {
    "country": "GR",
    "name": "Fíliro",
    "lat": "40.69151",
    "lng": "23.0046"
  },
  {
    "country": "GR",
    "name": "Féres",
    "lat": "40.89305",
    "lng": "26.17234"
  },
  {
    "country": "GR",
    "name": "Exaplátanos",
    "lat": "40.97643",
    "lng": "22.12958"
  },
  {
    "country": "GR",
    "name": "Evropós",
    "lat": "40.89703",
    "lng": "22.55277"
  },
  {
    "country": "GR",
    "name": "Évosmos",
    "lat": "40.67056",
    "lng": "22.90833"
  },
  {
    "country": "GR",
    "name": "Évlalo",
    "lat": "40.98333",
    "lng": "24.8"
  },
  {
    "country": "GR",
    "name": "Efkarpía",
    "lat": "40.68797",
    "lng": "22.95348"
  },
  {
    "country": "GR",
    "name": "Erátyra",
    "lat": "40.34253",
    "lng": "21.51333"
  },
  {
    "country": "GR",
    "name": "Episkopí",
    "lat": "40.68748",
    "lng": "22.1364"
  },
  {
    "country": "GR",
    "name": "Epanomí",
    "lat": "40.42614",
    "lng": "22.92782"
  },
  {
    "country": "GR",
    "name": "Empório",
    "lat": "40.48866",
    "lng": "21.55768"
  },
  {
    "country": "GR",
    "name": "Eleftheroúpolis",
    "lat": "40.91389",
    "lng": "24.25139"
  },
  {
    "country": "GR",
    "name": "Eleftherés",
    "lat": "40.84666",
    "lng": "24.25431"
  },
  {
    "country": "GR",
    "name": "Elaiochóri",
    "lat": "40.8203",
    "lng": "24.24373"
  },
  {
    "country": "GR",
    "name": "Echínos",
    "lat": "41.27558",
    "lng": "24.97237"
  },
  {
    "country": "GR",
    "name": "Édessa",
    "lat": "40.8026",
    "lng": "22.04751"
  },
  {
    "country": "GR",
    "name": "Dráma",
    "lat": "41.15283",
    "lng": "24.1473"
  },
  {
    "country": "GR",
    "name": "Drosáto",
    "lat": "41.16641",
    "lng": "22.80298"
  },
  {
    "country": "GR",
    "name": "Drymós",
    "lat": "40.78099",
    "lng": "22.95889"
  },
  {
    "country": "GR",
    "name": "Dravískos",
    "lat": "40.92393",
    "lng": "23.87119"
  },
  {
    "country": "GR",
    "name": "Didymóteicho",
    "lat": "41.34806",
    "lng": "26.49611"
  },
  {
    "country": "GR",
    "name": "Diavatós",
    "lat": "40.54606",
    "lng": "22.26686"
  },
  {
    "country": "GR",
    "name": "Diavatá",
    "lat": "40.68744",
    "lng": "22.85799"
  },
  {
    "country": "GR",
    "name": "Ágios Geórgios",
    "lat": "40.60215",
    "lng": "22.1943"
  },
  {
    "country": "GR",
    "name": "Ágios Vasíleios",
    "lat": "40.66424",
    "lng": "23.11373"
  },
  {
    "country": "GR",
    "name": "Ágios Pétros",
    "lat": "40.86725",
    "lng": "22.58298"
  },
  {
    "country": "GR",
    "name": "Ágios Nikólaos",
    "lat": "40.24926",
    "lng": "23.69616"
  },
  {
    "country": "GR",
    "name": "Ágios Loukás",
    "lat": "40.71799",
    "lng": "22.29545"
  },
  {
    "country": "GR",
    "name": "Ágios Athanásios",
    "lat": "41.07463",
    "lng": "24.24545"
  },
  {
    "country": "GR",
    "name": "Ágios Athanásios",
    "lat": "40.71598",
    "lng": "22.72841"
  },
  {
    "country": "GR",
    "name": "Ágio Pnévma",
    "lat": "41.10142",
    "lng": "23.67992"
  },
  {
    "country": "GR",
    "name": "Agía Triáda",
    "lat": "40.50003",
    "lng": "22.87351"
  },
  {
    "country": "GR",
    "name": "Agía Paraskeví",
    "lat": "40.4815",
    "lng": "23.04863"
  },
  {
    "country": "GR",
    "name": "Axioúpoli",
    "lat": "40.98582",
    "lng": "22.54165"
  },
  {
    "country": "GR",
    "name": "Ávato",
    "lat": "40.96279",
    "lng": "24.80441"
  },
  {
    "country": "GR",
    "name": "Áthyra",
    "lat": "40.82615",
    "lng": "22.59279"
  },
  {
    "country": "GR",
    "name": "Asvestochóri",
    "lat": "40.64125",
    "lng": "23.02528"
  },
  {
    "country": "GR",
    "name": "Ássiros",
    "lat": "40.82143",
    "lng": "23.03008"
  },
  {
    "country": "GR",
    "name": "Asproválta",
    "lat": "40.73049",
    "lng": "23.7118"
  },
  {
    "country": "GR",
    "name": "Askós",
    "lat": "40.75105",
    "lng": "23.38721"
  },
  {
    "country": "GR",
    "name": "Arsénio",
    "lat": "40.71412",
    "lng": "22.15923"
  },
  {
    "country": "GR",
    "name": "Arrianá",
    "lat": "41.08131",
    "lng": "25.69494"
  },
  {
    "country": "GR",
    "name": "Árnissa",
    "lat": "40.79555",
    "lng": "21.83577"
  },
  {
    "country": "GR",
    "name": "Arnaía",
    "lat": "40.48652",
    "lng": "23.59537"
  },
  {
    "country": "GR",
    "name": "Arísvi",
    "lat": "41.07",
    "lng": "25.59041"
  },
  {
    "country": "GR",
    "name": "Aridaía",
    "lat": "40.97306",
    "lng": "22.05639"
  },
  {
    "country": "GR",
    "name": "Argos Orestiko",
    "lat": "40.45354",
    "lng": "21.25889"
  },
  {
    "country": "GR",
    "name": "Aravissós",
    "lat": "40.84352",
    "lng": "22.30178"
  },
  {
    "country": "GR",
    "name": "Áratos",
    "lat": "41.08139",
    "lng": "25.55186"
  },
  {
    "country": "GR",
    "name": "Ápsalos",
    "lat": "40.8924",
    "lng": "22.05709"
  },
  {
    "country": "GR",
    "name": "Mitroúsi",
    "lat": "41.07041",
    "lng": "23.46064"
  },
  {
    "country": "GR",
    "name": "Áno Kómi",
    "lat": "40.2266",
    "lng": "21.82827"
  },
  {
    "country": "GR",
    "name": "Angelochóri",
    "lat": "40.67862",
    "lng": "22.19933"
  },
  {
    "country": "GR",
    "name": "Agkathiá",
    "lat": "40.55535",
    "lng": "22.47083"
  },
  {
    "country": "GR",
    "name": "Anatolikó",
    "lat": "40.66152",
    "lng": "22.7119"
  },
  {
    "country": "GR",
    "name": "Anaráchi",
    "lat": "40.49234",
    "lng": "21.57279"
  },
  {
    "country": "GR",
    "name": "Ammochóri",
    "lat": "40.78203",
    "lng": "21.48458"
  },
  {
    "country": "GR",
    "name": "Amýntaio",
    "lat": "40.68967",
    "lng": "21.67974"
  },
  {
    "country": "GR",
    "name": "Amygdaleónas",
    "lat": "40.96346",
    "lng": "24.36007"
  },
  {
    "country": "GR",
    "name": "Ampeleíes",
    "lat": "40.83417",
    "lng": "22.38767"
  },
  {
    "country": "GR",
    "name": "Alistráti",
    "lat": "41.06443",
    "lng": "23.95751"
  },
  {
    "country": "GR",
    "name": "Alexandroupoli",
    "lat": "40.84995",
    "lng": "25.87644"
  },
  {
    "country": "GR",
    "name": "Alexándreia",
    "lat": "40.62667",
    "lng": "22.44417"
  },
  {
    "country": "GR",
    "name": "Akriní",
    "lat": "40.43492",
    "lng": "21.90609"
  },
  {
    "country": "GR",
    "name": "Aigínio",
    "lat": "40.50139",
    "lng": "22.54"
  },
  {
    "country": "GR",
    "name": "Aianí",
    "lat": "40.16381",
    "lng": "21.81945"
  },
  {
    "country": "GR",
    "name": "Áfytos",
    "lat": "40.09915",
    "lng": "23.4367"
  },
  {
    "country": "GR",
    "name": "Ádendro",
    "lat": "40.67131",
    "lng": "22.60466"
  },
  {
    "country": "GR",
    "name": "Eirinoúpoli",
    "lat": "40.67806",
    "lng": "22.19278"
  },
  {
    "country": "GR",
    "name": "Ágios Pávlos",
    "lat": "40.64075",
    "lng": "22.96039"
  },
  {
    "country": "GR",
    "name": "Triandría",
    "lat": "40.615",
    "lng": "22.9762"
  },
  {
    "country": "GR",
    "name": "Melíssi",
    "lat": "40.77406",
    "lng": "22.35304"
  },
  {
    "country": "GR",
    "name": "Virós",
    "lat": "39.5834",
    "lng": "19.8827"
  },
  {
    "country": "GR",
    "name": "Potamós",
    "lat": "39.6242",
    "lng": "19.87826"
  },
  {
    "country": "GR",
    "name": "Kontokáli",
    "lat": "39.64436",
    "lng": "19.85194"
  },
  {
    "country": "GR",
    "name": "Kynopiástes",
    "lat": "39.56785",
    "lng": "19.88362"
  },
  {
    "country": "GR",
    "name": "Corfu",
    "lat": "39.62069",
    "lng": "19.91975"
  },
  {
    "country": "GR",
    "name": "Kanáli",
    "lat": "39.60556",
    "lng": "19.8925"
  },
  {
    "country": "GR",
    "name": "Ágios Matthaíos",
    "lat": "39.49506",
    "lng": "19.87336"
  },
  {
    "country": "GR",
    "name": "Alepoú",
    "lat": "39.61594",
    "lng": "19.89564"
  },
  {
    "country": "GR",
    "name": "Vrilissia",
    "lat": "38.03381",
    "lng": "23.82962"
  },
  {
    "country": "GR",
    "name": "Faliraki",
    "lat": "36.33981",
    "lng": "28.19942"
  },
  {
    "country": "GR",
    "name": "Acharávi",
    "lat": "39.7936",
    "lng": "19.81736"
  },
  {
    "country": "GR",
    "name": "Agios Georgis",
    "lat": "39.72363",
    "lng": "19.69969"
  },
  {
    "country": "GR",
    "name": "Georgioupolis",
    "lat": "35.36225",
    "lng": "24.26013"
  },
  {
    "country": "GR",
    "name": "Ornós",
    "lat": "37.42391",
    "lng": "25.32248"
  },
  {
    "country": "GR",
    "name": "Pánormos",
    "lat": "36.97156",
    "lng": "26.93727"
  },
  {
    "country": "GR",
    "name": "Káto Goúves",
    "lat": "35.32934",
    "lng": "25.31353"
  },
  {
    "country": "GR",
    "name": "Saronída",
    "lat": "37.74809",
    "lng": "23.91059"
  },
  {
    "country": "GR",
    "name": "Ymittos",
    "lat": "37.95342",
    "lng": "23.74897"
  },
  {
    "country": "GR",
    "name": "Gérakas",
    "lat": "38.02277",
    "lng": "23.8576"
  },
  {
    "country": "GR",
    "name": "Megálo Chorió",
    "lat": "37.4582",
    "lng": "26.97272"
  },
  {
    "country": "GR",
    "name": "Paralía Ofryníou",
    "lat": "40.76663",
    "lng": "23.90039"
  },
  {
    "country": "GR",
    "name": "Agía Kyriakí",
    "lat": "39.52264",
    "lng": "20.88358"
  },
  {
    "country": "GR",
    "name": "Agía Foteiní",
    "lat": "35.25459",
    "lng": "24.63495"
  },
  {
    "country": "GR",
    "name": "Ilioúpoli",
    "lat": "37.93149",
    "lng": "23.76779"
  },
  {
    "country": "GR",
    "name": "Korydallós",
    "lat": "37.98468",
    "lng": "23.64711"
  },
  {
    "country": "GR",
    "name": "Zográfos",
    "lat": "37.97574",
    "lng": "23.76911"
  },
  {
    "country": "GR",
    "name": "Péfki",
    "lat": "38.06019",
    "lng": "23.79264"
  },
  {
    "country": "GR",
    "name": "Ágioi Anárgyroi",
    "lat": "38.03013",
    "lng": "23.72379"
  },
  {
    "country": "GR",
    "name": "Ampelókipoi",
    "lat": "40.65304",
    "lng": "22.92624"
  },
  {
    "country": "GR",
    "name": "Foúrnoi",
    "lat": "37.5785",
    "lng": "26.48069"
  },
  {
    "country": "GR",
    "name": "Néa Potídhaia",
    "lat": "40.19428",
    "lng": "23.32874"
  },
  {
    "country": "GR",
    "name": "Agios Ioannis Rentis",
    "lat": "37.96491",
    "lng": "23.66511"
  },
  {
    "country": "GR",
    "name": "Violí Charáki",
    "lat": "35.35864",
    "lng": "24.43857"
  },
  {
    "country": "GR",
    "name": "Néa Anatolí",
    "lat": "35.0092",
    "lng": "25.6617"
  },
  {
    "country": "GR",
    "name": "Drapetsóna",
    "lat": "37.94988",
    "lng": "23.62309"
  },
  {
    "country": "GR",
    "name": "Néo Psychikó",
    "lat": "38.00624",
    "lng": "23.78373"
  },
  {
    "country": "GR",
    "name": "Chlói",
    "lat": "40.53918",
    "lng": "21.25923"
  },
  {
    "country": "GR",
    "name": "Varybóbi",
    "lat": "38.12723",
    "lng": "23.78729"
  },
  {
    "country": "GR",
    "name": "Aghios Panteleímon",
    "lat": "38.11643",
    "lng": "23.98182"
  },
  {
    "country": "GR",
    "name": "Anthoúsa",
    "lat": "38.02544",
    "lng": "23.87617"
  },
  {
    "country": "GR",
    "name": "Néa Vrasná",
    "lat": "40.70592",
    "lng": "23.6985"
  },
  {
    "country": "GR",
    "name": "Néa Ionía",
    "lat": "39.37904",
    "lng": "22.92752"
  },
  {
    "country": "GR",
    "name": "Zefyri",
    "lat": "38.06647",
    "lng": "23.71701"
  },
  {
    "country": "GR",
    "name": "Thrakomakedónes",
    "lat": "38.12964",
    "lng": "23.75751"
  },
  {
    "country": "GR",
    "name": "Néa Pentéli",
    "lat": "38.06059",
    "lng": "23.85926"
  },
  {
    "country": "GR",
    "name": "Néa Chalkidóna",
    "lat": "38.0271",
    "lng": "23.73051"
  },
  {
    "country": "GR",
    "name": "Kítsi",
    "lat": "37.85181",
    "lng": "23.84068"
  },
  {
    "country": "GR",
    "name": "Agía Marína",
    "lat": "37.82036",
    "lng": "23.84424"
  },
  {
    "country": "GR",
    "name": "Agios Dimítrios Kropiás",
    "lat": "37.80612",
    "lng": "23.85793"
  },
  {
    "country": "GR",
    "name": "Karellás",
    "lat": "37.93445",
    "lng": "23.86484"
  },
  {
    "country": "GR",
    "name": "Neos Voutzás",
    "lat": "38.04312",
    "lng": "23.97749"
  },
  {
    "country": "GR",
    "name": "Argithéa",
    "lat": "37.97506",
    "lng": "23.88556"
  },
  {
    "country": "GR",
    "name": "Dióni",
    "lat": "38.02328",
    "lng": "23.93286"
  },
  {
    "country": "GR",
    "name": "Vlycháda",
    "lat": "38.02734",
    "lng": "23.43663"
  },
  {
    "country": "GR",
    "name": "Perama",
    "lat": "39.58289",
    "lng": "19.9122"
  },
  {
    "country": "GR",
    "name": "Loutrá Oraías Elénis",
    "lat": "37.86466",
    "lng": "22.99614"
  },
  {
    "country": "GR",
    "name": "Paralía Vérgas",
    "lat": "37.00708",
    "lng": "22.15676"
  },
  {
    "country": "GR",
    "name": "Kardamítsia",
    "lat": "39.67816",
    "lng": "20.81956"
  },
  {
    "country": "GR",
    "name": "Tsiflikópoulo",
    "lat": "39.65624",
    "lng": "20.83882"
  },
  {
    "country": "GR",
    "name": "Eksochí",
    "lat": "39.68744",
    "lng": "20.8224"
  },
  {
    "country": "GR",
    "name": "Pláka Dílesi",
    "lat": "38.3495",
    "lng": "23.65056"
  },
  {
    "country": "GR",
    "name": "Anakasiá",
    "lat": "39.38112",
    "lng": "22.97484"
  },
  {
    "country": "GR",
    "name": "Iliokentima",
    "lat": "40.94931",
    "lng": "24.78859"
  },
  {
    "country": "GR",
    "name": "Neapoli",
    "lat": "40.6532",
    "lng": "22.94156"
  },
  {
    "country": "GR",
    "name": "Nea Lava",
    "lat": "40.19048",
    "lng": "22.0132"
  },
  {
    "country": "GS",
    "name": "Grytviken",
    "lat": "-54.28111",
    "lng": "-36.5092"
  },
  {
    "country": "GT",
    "name": "Zunilito",
    "lat": "14.61667",
    "lng": "-91.51667"
  },
  {
    "country": "GT",
    "name": "Zunil",
    "lat": "14.78333",
    "lng": "-91.48333"
  },
  {
    "country": "GT",
    "name": "Zaragoza",
    "lat": "14.65444",
    "lng": "-90.88944"
  },
  {
    "country": "GT",
    "name": "Zapotitlán",
    "lat": "14.13333",
    "lng": "-89.83333"
  },
  {
    "country": "GT",
    "name": "Zacualpa",
    "lat": "15.08333",
    "lng": "-90.83333"
  },
  {
    "country": "GT",
    "name": "Zacapa",
    "lat": "14.97222",
    "lng": "-89.53056"
  },
  {
    "country": "GT",
    "name": "Yupiltepeque",
    "lat": "14.2",
    "lng": "-89.78333"
  },
  {
    "country": "GT",
    "name": "Yepocapa",
    "lat": "14.50417",
    "lng": "-90.95694"
  },
  {
    "country": "GT",
    "name": "Villa Nueva",
    "lat": "14.52694",
    "lng": "-90.5875"
  },
  {
    "country": "GT",
    "name": "Villa Canales",
    "lat": "14.48139",
    "lng": "-90.53167"
  },
  {
    "country": "GT",
    "name": "Usumatlán",
    "lat": "14.95",
    "lng": "-89.78333"
  },
  {
    "country": "GT",
    "name": "Uspantán",
    "lat": "15.38333",
    "lng": "-90.83333"
  },
  {
    "country": "GT",
    "name": "Unión",
    "lat": "15.92176",
    "lng": "-91.77647"
  },
  {
    "country": "GT",
    "name": "Tucurú",
    "lat": "15.3",
    "lng": "-90.06667"
  },
  {
    "country": "GT",
    "name": "Totonicapán",
    "lat": "14.91167",
    "lng": "-91.36111"
  },
  {
    "country": "GT",
    "name": "Todos Santos Cuchumatán",
    "lat": "15.50846",
    "lng": "-91.60382"
  },
  {
    "country": "GT",
    "name": "Tejutla",
    "lat": "15.12254",
    "lng": "-91.80635"
  },
  {
    "country": "GT",
    "name": "Teculután",
    "lat": "14.98333",
    "lng": "-89.71667"
  },
  {
    "country": "GT",
    "name": "Tectitán",
    "lat": "15.3063",
    "lng": "-92.06051"
  },
  {
    "country": "GT",
    "name": "Tecpán Guatemala",
    "lat": "14.76694",
    "lng": "-90.99417"
  },
  {
    "country": "GT",
    "name": "Taxisco",
    "lat": "14.06719",
    "lng": "-90.46791"
  },
  {
    "country": "GT",
    "name": "Tamahú",
    "lat": "15.3089",
    "lng": "-90.23599"
  },
  {
    "country": "GT",
    "name": "Tajumulco",
    "lat": "15.08349",
    "lng": "-91.92225"
  },
  {
    "country": "GT",
    "name": "Tactic",
    "lat": "15.32218",
    "lng": "-90.35448"
  },
  {
    "country": "GT",
    "name": "Tacaná",
    "lat": "15.24058",
    "lng": "-92.06721"
  },
  {
    "country": "GT",
    "name": "Sumpango",
    "lat": "14.64639",
    "lng": "-90.73389"
  },
  {
    "country": "GT",
    "name": "Soloma",
    "lat": "15.65841",
    "lng": "-91.42994"
  },
  {
    "country": "GT",
    "name": "Sololá",
    "lat": "14.77222",
    "lng": "-91.18333"
  },
  {
    "country": "GT",
    "name": "Siquinalá",
    "lat": "14.30611",
    "lng": "-90.965"
  },
  {
    "country": "GT",
    "name": "Sipacapa",
    "lat": "15.21246",
    "lng": "-91.63416"
  },
  {
    "country": "GT",
    "name": "Sibinal",
    "lat": "15.14963",
    "lng": "-92.04892"
  },
  {
    "country": "GT",
    "name": "Sibilia",
    "lat": "15",
    "lng": "-91.61667"
  },
  {
    "country": "GT",
    "name": "Senahú",
    "lat": "15.4",
    "lng": "-89.83333"
  },
  {
    "country": "GT",
    "name": "Sayaxché",
    "lat": "16.52446",
    "lng": "-90.18801"
  },
  {
    "country": "GT",
    "name": "San Vicente Pacaya",
    "lat": "14.41611",
    "lng": "-90.63917"
  },
  {
    "country": "GT",
    "name": "Santo Tomás La Unión",
    "lat": "14.63333",
    "lng": "-91.38333"
  },
  {
    "country": "GT",
    "name": "Santo Domingo Xenacoj",
    "lat": "14.67778",
    "lng": "-90.69778"
  },
  {
    "country": "GT",
    "name": "Santo Domingo Suchitepéquez",
    "lat": "14.46667",
    "lng": "-91.48333"
  },
  {
    "country": "GT",
    "name": "Santiago Sacatepéquez",
    "lat": "14.63528",
    "lng": "-90.67639"
  },
  {
    "country": "GT",
    "name": "Santiago Chimaltenango",
    "lat": "15.47658",
    "lng": "-91.69656"
  },
  {
    "country": "GT",
    "name": "Santiago Atitlán",
    "lat": "14.63823",
    "lng": "-91.22901"
  },
  {
    "country": "GT",
    "name": "Santa Rosa de Lima",
    "lat": "14.38806",
    "lng": "-90.29556"
  },
  {
    "country": "GT",
    "name": "Santa María Visitación",
    "lat": "14.71667",
    "lng": "-91.31667"
  },
  {
    "country": "GT",
    "name": "Santa María Ixhuatán",
    "lat": "14.19",
    "lng": "-90.27472"
  },
  {
    "country": "GT",
    "name": "Santa María de Jesús",
    "lat": "14.51833",
    "lng": "-90.72667"
  },
  {
    "country": "GT",
    "name": "Santa María Chiquimula",
    "lat": "15.02992",
    "lng": "-91.3292"
  },
  {
    "country": "GT",
    "name": "Santa Lucía Utatlán",
    "lat": "14.76667",
    "lng": "-91.26667"
  },
  {
    "country": "GT",
    "name": "Santa Lucía Milpas Altas",
    "lat": "14.57583",
    "lng": "-90.67861"
  },
  {
    "country": "GT",
    "name": "Santa Lucia La Reforma",
    "lat": "15.12819",
    "lng": "-91.23619"
  },
  {
    "country": "GT",
    "name": "Santa Lucía Cotzumalguapa",
    "lat": "14.33333",
    "lng": "-91.01667"
  },
  {
    "country": "GT",
    "name": "Santa Eulalia",
    "lat": "15.7306",
    "lng": "-91.45846"
  },
  {
    "country": "GT",
    "name": "Santa Cruz Verapaz",
    "lat": "15.36667",
    "lng": "-90.43333"
  },
  {
    "country": "GT",
    "name": "Santa Cruz Naranjo",
    "lat": "14.38806",
    "lng": "-90.36972"
  },
  {
    "country": "GT",
    "name": "Santa Cruz Muluá",
    "lat": "14.58333",
    "lng": "-91.61667"
  },
  {
    "country": "GT",
    "name": "Santa Cruz La Laguna",
    "lat": "14.75",
    "lng": "-91.21667"
  },
  {
    "country": "GT",
    "name": "Santa Cruz del Quiché",
    "lat": "15.03085",
    "lng": "-91.14871"
  },
  {
    "country": "GT",
    "name": "Santa Cruz Balanyá",
    "lat": "14.68722",
    "lng": "-90.915"
  },
  {
    "country": "GT",
    "name": "Santa Clara La Laguna",
    "lat": "14.71667",
    "lng": "-91.3"
  },
  {
    "country": "GT",
    "name": "Santa Catarina Pinula",
    "lat": "14.56889",
    "lng": "-90.49528"
  },
  {
    "country": "GT",
    "name": "Santa Catarina Palopó",
    "lat": "14.71667",
    "lng": "-91.13333"
  },
  {
    "country": "GT",
    "name": "Santa Catarina Mita",
    "lat": "14.45",
    "lng": "-89.75"
  },
  {
    "country": "GT",
    "name": "Santa Catarina Ixtahuacán",
    "lat": "14.8",
    "lng": "-91.36667"
  },
  {
    "country": "GT",
    "name": "Santa Catarina Barahona",
    "lat": "14.54889",
    "lng": "-90.78833"
  },
  {
    "country": "GT",
    "name": "Santa Bárbara",
    "lat": "15.31617",
    "lng": "-91.63279"
  },
  {
    "country": "GT",
    "name": "Santa Bárbara",
    "lat": "14.43333",
    "lng": "-91.23333"
  },
  {
    "country": "GT",
    "name": "Santa Apolonia",
    "lat": "14.79139",
    "lng": "-90.97083"
  },
  {
    "country": "GT",
    "name": "Santa Ana Huista",
    "lat": "15.68085",
    "lng": "-91.82005"
  },
  {
    "country": "GT",
    "name": "Santa Ana",
    "lat": "16.8",
    "lng": "-89.83333"
  },
  {
    "country": "GT",
    "name": "San Sebastián Huehuetenango",
    "lat": "15.38768",
    "lng": "-91.6153"
  },
  {
    "country": "GT",
    "name": "San Sebastián Coatán",
    "lat": "15.73584",
    "lng": "-91.56285"
  },
  {
    "country": "GT",
    "name": "San Sebastián",
    "lat": "14.56667",
    "lng": "-91.65"
  },
  {
    "country": "GT",
    "name": "Sansare",
    "lat": "14.74722",
    "lng": "-90.1125"
  },
  {
    "country": "GT",
    "name": "San Raimundo",
    "lat": "14.76472",
    "lng": "-90.59556"
  },
  {
    "country": "GT",
    "name": "San Rafael Pie de La Cuesta",
    "lat": "14.93333",
    "lng": "-91.91667"
  },
  {
    "country": "GT",
    "name": "San Rafael Petzal",
    "lat": "15.40487",
    "lng": "-91.66451"
  },
  {
    "country": "GT",
    "name": "San Rafael Las Flores",
    "lat": "14.48139",
    "lng": "-90.17333"
  },
  {
    "country": "GT",
    "name": "San Rafael La Independencia",
    "lat": "15.7015",
    "lng": "-91.53553"
  },
  {
    "country": "GT",
    "name": "San Pedro Sacatepéquez",
    "lat": "14.96667",
    "lng": "-91.76667"
  },
  {
    "country": "GT",
    "name": "San Pedro Sacatepéquez",
    "lat": "14.68417",
    "lng": "-90.64417"
  },
  {
    "country": "GT",
    "name": "San Pedro Pinula",
    "lat": "14.66667",
    "lng": "-89.85"
  },
  {
    "country": "GT",
    "name": "San Pedro Necta",
    "lat": "15.49142",
    "lng": "-91.76551"
  },
  {
    "country": "GT",
    "name": "San Pedro La Laguna",
    "lat": "14.69297",
    "lng": "-91.27201"
  },
  {
    "country": "GT",
    "name": "San Pédro Jocopilas",
    "lat": "15.09525",
    "lng": "-91.15135"
  },
  {
    "country": "GT",
    "name": "San Pedro Carchá",
    "lat": "15.48333",
    "lng": "-90.26667"
  },
  {
    "country": "GT",
    "name": "San Pedro Ayampuc",
    "lat": "14.78667",
    "lng": "-90.45111"
  },
  {
    "country": "GT",
    "name": "San Pablo La Laguna",
    "lat": "14.71667",
    "lng": "-91.26667"
  },
  {
    "country": "GT",
    "name": "San Pablo Jocopilas",
    "lat": "14.58333",
    "lng": "-91.45"
  },
  {
    "country": "GT",
    "name": "San Pablo",
    "lat": "14.93281",
    "lng": "-92.00414"
  },
  {
    "country": "GT",
    "name": "San Miguel Sigüilá",
    "lat": "14.9",
    "lng": "-91.61667"
  },
  {
    "country": "GT",
    "name": "San Miguel Panán",
    "lat": "14.53333",
    "lng": "-91.36667"
  },
  {
    "country": "GT",
    "name": "San Miguel Ixtahuacán",
    "lat": "15.27247",
    "lng": "-91.74785"
  },
  {
    "country": "GT",
    "name": "San Miguel Dueñas",
    "lat": "14.52389",
    "lng": "-90.79833"
  },
  {
    "country": "GT",
    "name": "San Miguel Chicaj",
    "lat": "15.1",
    "lng": "-90.4"
  },
  {
    "country": "GT",
    "name": "San Miguel Acatán",
    "lat": "15.70401",
    "lng": "-91.59771"
  },
  {
    "country": "GT",
    "name": "San Mateo Ixtatán",
    "lat": "15.83194",
    "lng": "-91.47806"
  },
  {
    "country": "GT",
    "name": "San Mateo",
    "lat": "14.86667",
    "lng": "-91.58333"
  },
  {
    "country": "GT",
    "name": "San Martín Zapotitlán",
    "lat": "14.6",
    "lng": "-91.6"
  },
  {
    "country": "GT",
    "name": "San Martín Sacatepéquez",
    "lat": "14.81667",
    "lng": "-91.65"
  },
  {
    "country": "GT",
    "name": "San Martín Jilotepeque",
    "lat": "14.78778",
    "lng": "-90.7925"
  },
  {
    "country": "GT",
    "name": "San Marcos La Laguna",
    "lat": "14.71667",
    "lng": "-91.26667"
  },
  {
    "country": "GT",
    "name": "San Marcos",
    "lat": "14.96389",
    "lng": "-91.79444"
  },
  {
    "country": "GT",
    "name": "San Manuel Chaparrón",
    "lat": "14.51667",
    "lng": "-89.76667"
  },
  {
    "country": "GT",
    "name": "San Luis Jilotepeque",
    "lat": "14.65",
    "lng": "-89.73333"
  },
  {
    "country": "GT",
    "name": "San Luis Ixcán",
    "lat": "15.78722",
    "lng": "-91.095"
  },
  {
    "country": "GT",
    "name": "San Luis",
    "lat": "16.19889",
    "lng": "-89.44028"
  },
  {
    "country": "GT",
    "name": "San Lucas Tolimán",
    "lat": "14.59471",
    "lng": "-91.14659"
  },
  {
    "country": "GT",
    "name": "San Lucas Sacatepéquez",
    "lat": "14.60972",
    "lng": "-90.65694"
  },
  {
    "country": "GT",
    "name": "San Lorenzo",
    "lat": "15.03087",
    "lng": "-91.73534"
  },
  {
    "country": "GT",
    "name": "San Lorenzo",
    "lat": "14.48333",
    "lng": "-91.51667"
  },
  {
    "country": "GT",
    "name": "San Juan Tecuaco",
    "lat": "14.08222",
    "lng": "-90.26111"
  },
  {
    "country": "GT",
    "name": "San Juan Sacatepéquez",
    "lat": "14.71889",
    "lng": "-90.64417"
  },
  {
    "country": "GT",
    "name": "San Juan La Laguna",
    "lat": "14.7",
    "lng": "-91.28333"
  },
  {
    "country": "GT",
    "name": "San Juan Ixcoy",
    "lat": "15.60022",
    "lng": "-91.44639"
  },
  {
    "country": "GT",
    "name": "San Juan Ermita",
    "lat": "14.76667",
    "lng": "-89.43333"
  },
  {
    "country": "GT",
    "name": "San Juan Cotzal",
    "lat": "15.43368",
    "lng": "-91.03481"
  },
  {
    "country": "GT",
    "name": "San Juan Chamelco",
    "lat": "15.43333",
    "lng": "-90.33333"
  },
  {
    "country": "GT",
    "name": "San Juan Bautista",
    "lat": "14.41667",
    "lng": "-91.18333"
  },
  {
    "country": "GT",
    "name": "San Juan Atitán",
    "lat": "15.42886",
    "lng": "-91.62398"
  },
  {
    "country": "GT",
    "name": "San José Poaquil",
    "lat": "14.81972",
    "lng": "-90.90639"
  },
  {
    "country": "GT",
    "name": "San José Pinula",
    "lat": "14.54611",
    "lng": "-90.41139"
  },
  {
    "country": "GT",
    "name": "San José Ojetenán",
    "lat": "15.21667",
    "lng": "-91.96667"
  },
  {
    "country": "GT",
    "name": "San José Ojetenam",
    "lat": "15.23443",
    "lng": "-91.97317"
  },
  {
    "country": "GT",
    "name": "San José La Arada",
    "lat": "14.71667",
    "lng": "-89.58333"
  },
  {
    "country": "GT",
    "name": "San José El Ídolo",
    "lat": "14.45",
    "lng": "-91.41667"
  },
  {
    "country": "GT",
    "name": "San José del Golfo",
    "lat": "14.76278",
    "lng": "-90.37639"
  },
  {
    "country": "GT",
    "name": "San José Chacayá",
    "lat": "14.76667",
    "lng": "-91.21667"
  },
  {
    "country": "GT",
    "name": "San José Acatempa",
    "lat": "14.26528",
    "lng": "-90.12694"
  },
  {
    "country": "GT",
    "name": "San José",
    "lat": "16.98333",
    "lng": "-89.9"
  },
  {
    "country": "GT",
    "name": "San Jorge",
    "lat": "14.93333",
    "lng": "-89.58333"
  },
  {
    "country": "GT",
    "name": "San Jerónimo",
    "lat": "15.06032",
    "lng": "-90.2405"
  },
  {
    "country": "GT",
    "name": "San Jacinto",
    "lat": "14.66667",
    "lng": "-89.5"
  },
  {
    "country": "GT",
    "name": "San Gaspar Ixchil",
    "lat": "15.38796",
    "lng": "-91.72564"
  },
  {
    "country": "GT",
    "name": "San Gabriel",
    "lat": "14.51667",
    "lng": "-91.51667"
  },
  {
    "country": "GT",
    "name": "San Francisco Zapotitlán",
    "lat": "14.58333",
    "lng": "-91.51667"
  },
  {
    "country": "GT",
    "name": "San Francisco La Unión",
    "lat": "14.91667",
    "lng": "-91.53333"
  },
  {
    "country": "GT",
    "name": "San Francisco El Alto",
    "lat": "14.95",
    "lng": "-91.45"
  },
  {
    "country": "GT",
    "name": "San Francisco",
    "lat": "16.8",
    "lng": "-89.93333"
  },
  {
    "country": "GT",
    "name": "San Felipe",
    "lat": "14.61667",
    "lng": "-91.6"
  },
  {
    "country": "GT",
    "name": "San Diego",
    "lat": "14.78333",
    "lng": "-89.78333"
  },
  {
    "country": "GT",
    "name": "San Cristóbal Verapaz",
    "lat": "15.39632",
    "lng": "-90.56513"
  },
  {
    "country": "GT",
    "name": "San Cristóbal Totonicapán",
    "lat": "14.91667",
    "lng": "-91.43333"
  },
  {
    "country": "GT",
    "name": "San Cristóbal Cucho",
    "lat": "14.9",
    "lng": "-91.78333"
  },
  {
    "country": "GT",
    "name": "San Cristóbal Acasaguastlán",
    "lat": "14.91667",
    "lng": "-89.88333"
  },
  {
    "country": "GT",
    "name": "San Carlos Sija",
    "lat": "14.98333",
    "lng": "-91.55"
  },
  {
    "country": "GT",
    "name": "San Carlos Alzatate",
    "lat": "14.49778",
    "lng": "-90.06028"
  },
  {
    "country": "GT",
    "name": "San Bernardino",
    "lat": "14.53333",
    "lng": "-91.45"
  },
  {
    "country": "GT",
    "name": "San Benito",
    "lat": "16.91675",
    "lng": "-89.91898"
  },
  {
    "country": "GT",
    "name": "San Bartolomé Milpas Altas",
    "lat": "14.60611",
    "lng": "-90.68"
  },
  {
    "country": "GT",
    "name": "San Bartolomé Jocotenango",
    "lat": "15.19153",
    "lng": "-91.07806"
  },
  {
    "country": "GT",
    "name": "San Bartolo",
    "lat": "15.08438",
    "lng": "-91.45606"
  },
  {
    "country": "GT",
    "name": "Sanarate",
    "lat": "14.795",
    "lng": "-90.19222"
  },
  {
    "country": "GT",
    "name": "San Antonio Suchitepéquez",
    "lat": "14.53333",
    "lng": "-91.41667"
  },
  {
    "country": "GT",
    "name": "San Antonio Sacatepéquez",
    "lat": "14.96667",
    "lng": "-91.73333"
  },
  {
    "country": "GT",
    "name": "San Antonio Palopó",
    "lat": "14.7",
    "lng": "-91.11667"
  },
  {
    "country": "GT",
    "name": "San Antonio La Paz",
    "lat": "14.74972",
    "lng": "-90.28667"
  },
  {
    "country": "GT",
    "name": "San Antonio Ilotenango",
    "lat": "15.05472",
    "lng": "-91.22986"
  },
  {
    "country": "GT",
    "name": "San Antonio Huista",
    "lat": "15.6501",
    "lng": "-91.77163"
  },
  {
    "country": "GT",
    "name": "San Antonio Aguas Calientes",
    "lat": "14.53972",
    "lng": "-90.76944"
  },
  {
    "country": "GT",
    "name": "San Andrés Xecul",
    "lat": "14.9",
    "lng": "-91.48333"
  },
  {
    "country": "GT",
    "name": "San Andrés Villa Seca",
    "lat": "14.56667",
    "lng": "-91.58333"
  },
  {
    "country": "GT",
    "name": "San Andrés Semetabaj",
    "lat": "14.75",
    "lng": "-91.13333"
  },
  {
    "country": "GT",
    "name": "San Andrés Sajcabajá",
    "lat": "15.21667",
    "lng": "-90.91667"
  },
  {
    "country": "GT",
    "name": "San Andrés Itzapa",
    "lat": "14.62",
    "lng": "-90.84417"
  },
  {
    "country": "GT",
    "name": "San Andrés",
    "lat": "16.96667",
    "lng": "-89.91667"
  },
  {
    "country": "GT",
    "name": "San Agustín Acasaguastlán",
    "lat": "14.95",
    "lng": "-89.96667"
  },
  {
    "country": "GT",
    "name": "Samayac",
    "lat": "14.58084",
    "lng": "-91.46135"
  },
  {
    "country": "GT",
    "name": "Salcajá",
    "lat": "14.88333",
    "lng": "-91.45"
  },
  {
    "country": "GT",
    "name": "Salamá",
    "lat": "15.10278",
    "lng": "-90.31806"
  },
  {
    "country": "GT",
    "name": "Sacapulas",
    "lat": "15.28801",
    "lng": "-91.08914"
  },
  {
    "country": "GT",
    "name": "Río Hondo",
    "lat": "15.06667",
    "lng": "-89.58333"
  },
  {
    "country": "GT",
    "name": "Río Bravo",
    "lat": "14.40042",
    "lng": "-91.31713"
  },
  {
    "country": "GT",
    "name": "Río Blanco",
    "lat": "15.0382",
    "lng": "-91.68463"
  },
  {
    "country": "GT",
    "name": "Retalhuleu",
    "lat": "14.53611",
    "lng": "-91.67778"
  },
  {
    "country": "GT",
    "name": "Raxruhá",
    "lat": "15.86667",
    "lng": "-90.03333"
  },
  {
    "country": "GT",
    "name": "Rabinal",
    "lat": "15.1",
    "lng": "-90.45"
  },
  {
    "country": "GT",
    "name": "Quezaltepeque",
    "lat": "14.63333",
    "lng": "-89.45"
  },
  {
    "country": "GT",
    "name": "Quetzaltenango",
    "lat": "14.83472",
    "lng": "-91.51806"
  },
  {
    "country": "GT",
    "name": "Quesada",
    "lat": "14.27028",
    "lng": "-90.04028"
  },
  {
    "country": "GT",
    "name": "Purulhá",
    "lat": "15.26667",
    "lng": "-90.2"
  },
  {
    "country": "GT",
    "name": "Puerto San José",
    "lat": "13.9274",
    "lng": "-90.82166"
  },
  {
    "country": "GT",
    "name": "Puerto Barrios",
    "lat": "15.72778",
    "lng": "-88.59444"
  },
  {
    "country": "GT",
    "name": "Pueblo Nuevo Viñas",
    "lat": "14.22583",
    "lng": "-90.47417"
  },
  {
    "country": "GT",
    "name": "Tiquisate",
    "lat": "14.28356",
    "lng": "-91.36063"
  },
  {
    "country": "GT",
    "name": "Pueblo Nuevo",
    "lat": "14.65",
    "lng": "-91.53333"
  },
  {
    "country": "GT",
    "name": "Poptún",
    "lat": "16.33111",
    "lng": "-89.41694"
  },
  {
    "country": "GT",
    "name": "Pochuta",
    "lat": "14.55",
    "lng": "-91.08333"
  },
  {
    "country": "GT",
    "name": "Playa Grande",
    "lat": "15.93333",
    "lng": "-90.73333"
  },
  {
    "country": "GT",
    "name": "Petapa",
    "lat": "14.50278",
    "lng": "-90.55167"
  },
  {
    "country": "GT",
    "name": "Patzún",
    "lat": "14.68333",
    "lng": "-91.01667"
  },
  {
    "country": "GT",
    "name": "Patzité",
    "lat": "14.96667",
    "lng": "-91.21667"
  },
  {
    "country": "GT",
    "name": "Patzicía",
    "lat": "14.63167",
    "lng": "-90.92694"
  },
  {
    "country": "GT",
    "name": "Patulul",
    "lat": "14.41667",
    "lng": "-91.16667"
  },
  {
    "country": "GT",
    "name": "Pastores",
    "lat": "14.59667",
    "lng": "-90.75472"
  },
  {
    "country": "GT",
    "name": "Pasaco",
    "lat": "13.97722",
    "lng": "-90.20639"
  },
  {
    "country": "GT",
    "name": "Parramos",
    "lat": "14.60778",
    "lng": "-90.80306"
  },
  {
    "country": "GT",
    "name": "Panzós",
    "lat": "15.4",
    "lng": "-89.66667"
  },
  {
    "country": "GT",
    "name": "Panajachel",
    "lat": "14.73333",
    "lng": "-91.15"
  },
  {
    "country": "GT",
    "name": "Palín",
    "lat": "14.40556",
    "lng": "-90.69833"
  },
  {
    "country": "GT",
    "name": "Palestina de los Altos",
    "lat": "14.93333",
    "lng": "-91.7"
  },
  {
    "country": "GT",
    "name": "Palencia",
    "lat": "14.66472",
    "lng": "-90.35861"
  },
  {
    "country": "GT",
    "name": "Pajapita",
    "lat": "14.72152",
    "lng": "-92.03521"
  },
  {
    "country": "GT",
    "name": "Pachalun",
    "lat": "14.92472",
    "lng": "-90.66278"
  },
  {
    "country": "GT",
    "name": "Ostuncalco",
    "lat": "14.86667",
    "lng": "-91.61667"
  },
  {
    "country": "GT",
    "name": "Oratorio",
    "lat": "14.22806",
    "lng": "-90.17583"
  },
  {
    "country": "GT",
    "name": "Olopa",
    "lat": "14.68333",
    "lng": "-89.35"
  },
  {
    "country": "GT",
    "name": "Olintepeque",
    "lat": "14.88333",
    "lng": "-91.51667"
  },
  {
    "country": "GT",
    "name": "Ocós",
    "lat": "14.50998",
    "lng": "-92.19298"
  },
  {
    "country": "GT",
    "name": "Nuevo San Carlos",
    "lat": "14.6",
    "lng": "-91.7"
  },
  {
    "country": "GT",
    "name": "Nuevo Progreso",
    "lat": "14.8",
    "lng": "-91.91667"
  },
  {
    "country": "GT",
    "name": "Nueva Santa Rosa",
    "lat": "14.38111",
    "lng": "-90.27611"
  },
  {
    "country": "GT",
    "name": "Nueva Concepción",
    "lat": "14.2",
    "lng": "-91.3"
  },
  {
    "country": "GT",
    "name": "Nentón",
    "lat": "15.8007",
    "lng": "-91.75464"
  },
  {
    "country": "GT",
    "name": "Nebaj",
    "lat": "15.40614",
    "lng": "-91.14682"
  },
  {
    "country": "GT",
    "name": "Nahualá",
    "lat": "14.85",
    "lng": "-91.31667"
  },
  {
    "country": "GT",
    "name": "Moyuta",
    "lat": "14.03861",
    "lng": "-90.08083"
  },
  {
    "country": "GT",
    "name": "Morazán",
    "lat": "14.93278",
    "lng": "-90.14306"
  },
  {
    "country": "GT",
    "name": "Morales",
    "lat": "15.48333",
    "lng": "-88.81667"
  },
  {
    "country": "GT",
    "name": "Monjas",
    "lat": "14.5",
    "lng": "-89.86667"
  },
  {
    "country": "GT",
    "name": "Momostenango",
    "lat": "15.04437",
    "lng": "-91.40864"
  },
  {
    "country": "GT",
    "name": "Mixco",
    "lat": "14.63333",
    "lng": "-90.60639"
  },
  {
    "country": "GT",
    "name": "Mazatenango",
    "lat": "14.53417",
    "lng": "-91.50333"
  },
  {
    "country": "GT",
    "name": "Mataquescuintla",
    "lat": "14.52917",
    "lng": "-90.18417"
  },
  {
    "country": "GT",
    "name": "Masagua",
    "lat": "14.20306",
    "lng": "-90.84806"
  },
  {
    "country": "GT",
    "name": "Malacatancito",
    "lat": "15.24457",
    "lng": "-91.49901"
  },
  {
    "country": "GT",
    "name": "Malacatán",
    "lat": "14.91065",
    "lng": "-92.05795"
  },
  {
    "country": "GT",
    "name": "Magdalena Milpas Altas",
    "lat": "14.54528",
    "lng": "-90.67528"
  },
  {
    "country": "GT",
    "name": "Los Amates",
    "lat": "15.25645",
    "lng": "-89.09723"
  },
  {
    "country": "GT",
    "name": "Lívingston",
    "lat": "15.82826",
    "lng": "-88.75039"
  },
  {
    "country": "GT",
    "name": "La Unión",
    "lat": "14.96667",
    "lng": "-89.28333"
  },
  {
    "country": "GT",
    "name": "La Tinta",
    "lat": "15.31667",
    "lng": "-89.88333"
  },
  {
    "country": "GT",
    "name": "La Reforma",
    "lat": "14.8",
    "lng": "-91.81667"
  },
  {
    "country": "GT",
    "name": "Lanquín",
    "lat": "15.56667",
    "lng": "-89.96667"
  },
  {
    "country": "GT",
    "name": "La Libertad",
    "lat": "16.7885",
    "lng": "-90.11698"
  },
  {
    "country": "GT",
    "name": "La Libertad",
    "lat": "15.51421",
    "lng": "-91.86944"
  },
  {
    "country": "GT",
    "name": "La Gomera",
    "lat": "14.08333",
    "lng": "-91.05"
  },
  {
    "country": "GT",
    "name": "La Esperanza",
    "lat": "14.86667",
    "lng": "-91.56667"
  },
  {
    "country": "GT",
    "name": "La Democracia",
    "lat": "14.23083",
    "lng": "-90.94722"
  },
  {
    "country": "GT",
    "name": "La Democracia",
    "lat": "15.62544",
    "lng": "-91.8867"
  },
  {
    "country": "GT",
    "name": "La Blanca",
    "lat": "14.57889",
    "lng": "-92.14137"
  },
  {
    "country": "GT",
    "name": "Jutiapa",
    "lat": "14.29167",
    "lng": "-89.89583"
  },
  {
    "country": "GT",
    "name": "Joyabaj",
    "lat": "14.995",
    "lng": "-90.80611"
  },
  {
    "country": "GT",
    "name": "Jocotenango",
    "lat": "14.58194",
    "lng": "-90.74361"
  },
  {
    "country": "GT",
    "name": "Jocotán",
    "lat": "14.81667",
    "lng": "-89.38333"
  },
  {
    "country": "GT",
    "name": "Jerez",
    "lat": "14.1",
    "lng": "-89.75"
  },
  {
    "country": "GT",
    "name": "Jalpatagua",
    "lat": "14.14167",
    "lng": "-90.00861"
  },
  {
    "country": "GT",
    "name": "Jalapa",
    "lat": "14.63472",
    "lng": "-89.98889"
  },
  {
    "country": "GT",
    "name": "Jacaltenango",
    "lat": "15.66662",
    "lng": "-91.71177"
  },
  {
    "country": "GT",
    "name": "Iztapa",
    "lat": "13.93333",
    "lng": "-90.7075"
  },
  {
    "country": "GT",
    "name": "Ixtahuacán",
    "lat": "15.41688",
    "lng": "-91.76927"
  },
  {
    "country": "GT",
    "name": "Ixchiguán",
    "lat": "15.16375",
    "lng": "-91.93256"
  },
  {
    "country": "GT",
    "name": "Ipala",
    "lat": "14.61667",
    "lng": "-89.61667"
  },
  {
    "country": "GT",
    "name": "Huité",
    "lat": "14.93333",
    "lng": "-89.71667"
  },
  {
    "country": "GT",
    "name": "Huitán",
    "lat": "15.0492",
    "lng": "-91.63944"
  },
  {
    "country": "GT",
    "name": "Huehuetenango",
    "lat": "15.31918",
    "lng": "-91.47241"
  },
  {
    "country": "GT",
    "name": "Guazacapán",
    "lat": "14.07417",
    "lng": "-90.41667"
  },
  {
    "country": "GT",
    "name": "Guanagazapa",
    "lat": "14.22528",
    "lng": "-90.64333"
  },
  {
    "country": "GT",
    "name": "Gualán",
    "lat": "15.11952",
    "lng": "-89.35721"
  },
  {
    "country": "GT",
    "name": "Granados",
    "lat": "14.91361",
    "lng": "-90.52278"
  },
  {
    "country": "GT",
    "name": "Génova",
    "lat": "14.61667",
    "lng": "-91.83333"
  },
  {
    "country": "GT",
    "name": "Fraijanes",
    "lat": "14.46528",
    "lng": "-90.44083"
  },
  {
    "country": "GT",
    "name": "Flores Costa Cuca",
    "lat": "14.63238",
    "lng": "-91.86341"
  },
  {
    "country": "GT",
    "name": "Flores",
    "lat": "16.92258",
    "lng": "-89.89941"
  },
  {
    "country": "GT",
    "name": "Estanzuela",
    "lat": "15",
    "lng": "-89.56667"
  },
  {
    "country": "GT",
    "name": "Esquipulas Palo Gordo",
    "lat": "14.93333",
    "lng": "-91.81667"
  },
  {
    "country": "GT",
    "name": "Esquipulas",
    "lat": "14.56667",
    "lng": "-89.35"
  },
  {
    "country": "GT",
    "name": "Escuintla",
    "lat": "14.305",
    "lng": "-90.785"
  },
  {
    "country": "GT",
    "name": "El Tumbador",
    "lat": "14.86667",
    "lng": "-91.93333"
  },
  {
    "country": "GT",
    "name": "El Tejar",
    "lat": "14.64778",
    "lng": "-90.79278"
  },
  {
    "country": "GT",
    "name": "El Rodeo",
    "lat": "14.91667",
    "lng": "-91.96667"
  },
  {
    "country": "GT",
    "name": "El Quetzal",
    "lat": "14.76667",
    "lng": "-91.81667"
  },
  {
    "country": "GT",
    "name": "Guastatoya",
    "lat": "14.85417",
    "lng": "-90.06944"
  },
  {
    "country": "GT",
    "name": "El Progreso",
    "lat": "14.35",
    "lng": "-89.85"
  },
  {
    "country": "GT",
    "name": "El Palmar",
    "lat": "14.65",
    "lng": "-91.58333"
  },
  {
    "country": "GT",
    "name": "El Jícaro",
    "lat": "14.91667",
    "lng": "-89.9"
  },
  {
    "country": "GT",
    "name": "El Estor",
    "lat": "15.53333",
    "lng": "-89.35"
  },
  {
    "country": "GT",
    "name": "El Chol",
    "lat": "14.96417",
    "lng": "-90.48056"
  },
  {
    "country": "GT",
    "name": "El Chal",
    "lat": "16.66667",
    "lng": "-89.63333"
  },
  {
    "country": "GT",
    "name": "El Asintal",
    "lat": "14.6",
    "lng": "-91.73333"
  },
  {
    "country": "GT",
    "name": "El Adelanto",
    "lat": "14.16667",
    "lng": "-89.83333"
  },
  {
    "country": "GT",
    "name": "Dolores",
    "lat": "16.51417",
    "lng": "-89.41583"
  },
  {
    "country": "GT",
    "name": "Cuyotenango",
    "lat": "14.53333",
    "lng": "-91.56667"
  },
  {
    "country": "GT",
    "name": "Cunén",
    "lat": "15.33626",
    "lng": "-91.02776"
  },
  {
    "country": "GT",
    "name": "Cuilco",
    "lat": "15.40719",
    "lng": "-91.94667"
  },
  {
    "country": "GT",
    "name": "Cuilapa",
    "lat": "14.27639",
    "lng": "-90.29889"
  },
  {
    "country": "GT",
    "name": "Cubulco",
    "lat": "15.13333",
    "lng": "-90.58333"
  },
  {
    "country": "GT",
    "name": "Conguaco",
    "lat": "14.04417",
    "lng": "-90.03111"
  },
  {
    "country": "GT",
    "name": "Concepción Tutuapa",
    "lat": "15.2394",
    "lng": "-91.8446"
  },
  {
    "country": "GT",
    "name": "Concepción Las Minas",
    "lat": "14.51667",
    "lng": "-89.45"
  },
  {
    "country": "GT",
    "name": "Concepción Chiquirichapa",
    "lat": "14.85",
    "lng": "-91.61667"
  },
  {
    "country": "GT",
    "name": "Concepción Huista",
    "lat": "15.62378",
    "lng": "-91.66521"
  },
  {
    "country": "GT",
    "name": "Concepción",
    "lat": "14.78333",
    "lng": "-91.15"
  },
  {
    "country": "GT",
    "name": "Comitancillo",
    "lat": "15.08937",
    "lng": "-91.74971"
  },
  {
    "country": "GT",
    "name": "Comapa",
    "lat": "14.11667",
    "lng": "-89.91667"
  },
  {
    "country": "GT",
    "name": "Comalapa",
    "lat": "14.74111",
    "lng": "-90.8875"
  },
  {
    "country": "GT",
    "name": "Colotenango",
    "lat": "15.40602",
    "lng": "-91.71267"
  },
  {
    "country": "GT",
    "name": "Colomba",
    "lat": "14.71667",
    "lng": "-91.73333"
  },
  {
    "country": "GT",
    "name": "Cobán",
    "lat": "15.47083",
    "lng": "-90.37083"
  },
  {
    "country": "GT",
    "name": "Coatepeque",
    "lat": "14.7",
    "lng": "-91.86667"
  },
  {
    "country": "GT",
    "name": "Ciudad Vieja",
    "lat": "14.52639",
    "lng": "-90.75972"
  },
  {
    "country": "GT",
    "name": "Ciudad Tecún Umán",
    "lat": "14.67737",
    "lng": "-92.14039"
  },
  {
    "country": "GT",
    "name": "Melchor de Mencos",
    "lat": "17.06606",
    "lng": "-89.15229"
  },
  {
    "country": "GT",
    "name": "Guatemala City",
    "lat": "14.64072",
    "lng": "-90.51327"
  },
  {
    "country": "GT",
    "name": "Chuarrancho",
    "lat": "14.82167",
    "lng": "-90.50861"
  },
  {
    "country": "GT",
    "name": "Chisec",
    "lat": "15.81667",
    "lng": "-90.28333"
  },
  {
    "country": "GT",
    "name": "Chiquimulilla",
    "lat": "14.0838",
    "lng": "-90.38547"
  },
  {
    "country": "GT",
    "name": "Chiquimula",
    "lat": "14.8",
    "lng": "-89.54583"
  },
  {
    "country": "GT",
    "name": "Chinique",
    "lat": "15.04147",
    "lng": "-91.02594"
  },
  {
    "country": "GT",
    "name": "Chinautla",
    "lat": "14.70833",
    "lng": "-90.49944"
  },
  {
    "country": "GT",
    "name": "Chimaltenango",
    "lat": "14.66111",
    "lng": "-90.81944"
  },
  {
    "country": "GT",
    "name": "Chichicastenango",
    "lat": "14.93333",
    "lng": "-91.11667"
  },
  {
    "country": "GT",
    "name": "Chiché",
    "lat": "15.00885",
    "lng": "-91.06379"
  },
  {
    "country": "GT",
    "name": "Chicamán",
    "lat": "15.4",
    "lng": "-90.76667"
  },
  {
    "country": "GT",
    "name": "Chicacao",
    "lat": "14.53333",
    "lng": "-91.31667"
  },
  {
    "country": "GT",
    "name": "Chiantla",
    "lat": "15.35484",
    "lng": "-91.45807"
  },
  {
    "country": "GT",
    "name": "Champerico",
    "lat": "14.3",
    "lng": "-91.91667"
  },
  {
    "country": "GT",
    "name": "Chajul",
    "lat": "15.48523",
    "lng": "-91.0352"
  },
  {
    "country": "GT",
    "name": "Chahal Guatemala",
    "lat": "15.79122",
    "lng": "-89.60518"
  },
  {
    "country": "GT",
    "name": "Catarina",
    "lat": "14.8515",
    "lng": "-92.07646"
  },
  {
    "country": "GT",
    "name": "Casillas",
    "lat": "14.42222",
    "lng": "-90.24417"
  },
  {
    "country": "GT",
    "name": "Cantel",
    "lat": "14.81667",
    "lng": "-91.45"
  },
  {
    "country": "GT",
    "name": "Canillá",
    "lat": "15.16667",
    "lng": "-90.85"
  },
  {
    "country": "GT",
    "name": "Camotán",
    "lat": "14.81667",
    "lng": "-89.36667"
  },
  {
    "country": "GT",
    "name": "Cajolá",
    "lat": "14.91667",
    "lng": "-91.61667"
  },
  {
    "country": "GT",
    "name": "Cahabón",
    "lat": "15.56667",
    "lng": "-89.81667"
  },
  {
    "country": "GT",
    "name": "Cabricán",
    "lat": "15.07485",
    "lng": "-91.648"
  },
  {
    "country": "GT",
    "name": "Cabañas",
    "lat": "14.93333",
    "lng": "-89.8"
  },
  {
    "country": "GT",
    "name": "Barillas",
    "lat": "15.80361",
    "lng": "-91.31583"
  },
  {
    "country": "GT",
    "name": "Barberena",
    "lat": "14.30944",
    "lng": "-90.36111"
  },
  {
    "country": "GT",
    "name": "Atescatempa",
    "lat": "14.17444",
    "lng": "-89.7425"
  },
  {
    "country": "GT",
    "name": "Asunción Mita",
    "lat": "14.33083",
    "lng": "-89.71083"
  },
  {
    "country": "GT",
    "name": "Antigua Guatemala",
    "lat": "14.56111",
    "lng": "-90.73444"
  },
  {
    "country": "GT",
    "name": "Amatitlán",
    "lat": "14.4774",
    "lng": "-90.63489"
  },
  {
    "country": "GT",
    "name": "Alotenango",
    "lat": "14.48028",
    "lng": "-90.8075"
  },
  {
    "country": "GT",
    "name": "Almolonga",
    "lat": "14.81667",
    "lng": "-91.5"
  },
  {
    "country": "GT",
    "name": "Aguacatán",
    "lat": "15.34222",
    "lng": "-91.31141"
  },
  {
    "country": "GT",
    "name": "Agua Blanca",
    "lat": "14.5",
    "lng": "-89.65"
  },
  {
    "country": "GT",
    "name": "Acatenango",
    "lat": "14.55194",
    "lng": "-90.94222"
  },
  {
    "country": "GT",
    "name": "San Juan Ostuncalco",
    "lat": "14.87328",
    "lng": "-91.6897"
  },
  {
    "country": "GT",
    "name": "San José La Máquina",
    "lat": "14.30178",
    "lng": "-91.56707"
  },
  {
    "country": "GT",
    "name": "Fray Bartolomé de Las Casas",
    "lat": "15.81516",
    "lng": "-89.88931"
  },
  {
    "country": "GU",
    "name": "Piti Village",
    "lat": "13.46256",
    "lng": "144.69331"
  },
  {
    "country": "GU",
    "name": "Santa Rita Village",
    "lat": "13.38608",
    "lng": "144.67226"
  },
  {
    "country": "GU",
    "name": "Sinajana Village",
    "lat": "13.46334",
    "lng": "144.75406"
  },
  {
    "country": "GU",
    "name": "Talofofo Village",
    "lat": "13.35513",
    "lng": "144.75835"
  },
  {
    "country": "GU",
    "name": "Tamuning-Tumon-Harmon Village",
    "lat": "13.48773",
    "lng": "144.78138"
  },
  {
    "country": "GU",
    "name": "Umatac Village",
    "lat": "13.29843",
    "lng": "144.66314"
  },
  {
    "country": "GU",
    "name": "Yigo Village",
    "lat": "13.53605",
    "lng": "144.88855"
  },
  {
    "country": "GU",
    "name": "Yona Village",
    "lat": "13.40974",
    "lng": "144.77697"
  },
  {
    "country": "GU",
    "name": "Merizo Village",
    "lat": "13.26584",
    "lng": "144.66908"
  },
  {
    "country": "GU",
    "name": "Inarajan Village",
    "lat": "13.27363",
    "lng": "144.74845"
  },
  {
    "country": "GU",
    "name": "Agana Heights Village",
    "lat": "13.46559",
    "lng": "144.74795"
  },
  {
    "country": "GU",
    "name": "Guam Government House",
    "lat": "13.47191",
    "lng": "144.74978"
  },
  {
    "country": "GU",
    "name": "Chalan Pago-Ordot Village",
    "lat": "13.44741",
    "lng": "144.75902"
  },
  {
    "country": "GU",
    "name": "Barrigada Village",
    "lat": "13.46913",
    "lng": "144.79901"
  },
  {
    "country": "GU",
    "name": "Agat Village",
    "lat": "13.38855",
    "lng": "144.65852"
  },
  {
    "country": "GU",
    "name": "Asan-Maina Village",
    "lat": "13.47215",
    "lng": "144.71654"
  },
  {
    "country": "GU",
    "name": "Dededo Village",
    "lat": "13.51777",
    "lng": "144.8391"
  },
  {
    "country": "GU",
    "name": "Hagåtña",
    "lat": "13.47567",
    "lng": "144.74886"
  },
  {
    "country": "GU",
    "name": "Mangilao Village",
    "lat": "13.44761",
    "lng": "144.80109"
  },
  {
    "country": "GU",
    "name": "Mongmong-Toto-Maite Village",
    "lat": "13.46857",
    "lng": "144.78214"
  },
  {
    "country": "GU",
    "name": "Hagåtña Village",
    "lat": "13.47279",
    "lng": "144.75802"
  },
  {
    "country": "GU",
    "name": "Tamuning",
    "lat": "13.48754",
    "lng": "144.78143"
  },
  {
    "country": "GW",
    "name": "Quinhámel",
    "lat": "11.88694",
    "lng": "-15.85556"
  },
  {
    "country": "GW",
    "name": "Quebo",
    "lat": "11.33333",
    "lng": "-14.93333"
  },
  {
    "country": "GW",
    "name": "Mansôa",
    "lat": "12.07333",
    "lng": "-15.31889"
  },
  {
    "country": "GW",
    "name": "Gabú",
    "lat": "12.28",
    "lng": "-14.22222"
  },
  {
    "country": "GW",
    "name": "Farim",
    "lat": "12.48389",
    "lng": "-15.22167"
  },
  {
    "country": "GW",
    "name": "Catió",
    "lat": "11.2825",
    "lng": "-15.25472"
  },
  {
    "country": "GW",
    "name": "Canchungo",
    "lat": "12.06722",
    "lng": "-16.03333"
  },
  {
    "country": "GW",
    "name": "Cacheu",
    "lat": "12.27444",
    "lng": "-16.16528"
  },
  {
    "country": "GW",
    "name": "Bubaque",
    "lat": "11.28333",
    "lng": "-15.83333"
  },
  {
    "country": "GW",
    "name": "Buba",
    "lat": "11.58889",
    "lng": "-14.99583"
  },
  {
    "country": "GW",
    "name": "Bolama",
    "lat": "11.57694",
    "lng": "-15.47611"
  },
  {
    "country": "GW",
    "name": "Bissorã",
    "lat": "12.22306",
    "lng": "-15.4475"
  },
  {
    "country": "GW",
    "name": "Bissau",
    "lat": "11.86357",
    "lng": "-15.59767"
  },
  {
    "country": "GW",
    "name": "Bafatá",
    "lat": "12.16583",
    "lng": "-14.66167"
  },
  {
    "country": "GY",
    "name": "Vreed-en-Hoop",
    "lat": "6.80927",
    "lng": "-58.19798"
  },
  {
    "country": "GY",
    "name": "Skeldon",
    "lat": "5.88333",
    "lng": "-57.13333"
  },
  {
    "country": "GY",
    "name": "Rosignol",
    "lat": "6.27095",
    "lng": "-57.53697"
  },
  {
    "country": "GY",
    "name": "Parika",
    "lat": "6.83712",
    "lng": "-58.42941"
  },
  {
    "country": "GY",
    "name": "New Amsterdam",
    "lat": "6.24793",
    "lng": "-57.5171"
  },
  {
    "country": "GY",
    "name": "Mahdia",
    "lat": "5.26667",
    "lng": "-59.15"
  },
  {
    "country": "GY",
    "name": "Mahaicony Village",
    "lat": "6.57633",
    "lng": "-57.80486"
  },
  {
    "country": "GY",
    "name": "Mahaica Village",
    "lat": "6.68405",
    "lng": "-57.92181"
  },
  {
    "country": "GY",
    "name": "Mabaruma",
    "lat": "8.2",
    "lng": "-59.78333"
  },
  {
    "country": "GY",
    "name": "Linden",
    "lat": "6.00809",
    "lng": "-58.30714"
  },
  {
    "country": "GY",
    "name": "Lethem",
    "lat": "3.38333",
    "lng": "-59.8"
  },
  {
    "country": "GY",
    "name": "Georgetown",
    "lat": "6.80448",
    "lng": "-58.15527"
  },
  {
    "country": "GY",
    "name": "Bartica",
    "lat": "6.40799",
    "lng": "-58.62192"
  },
  {
    "country": "GY",
    "name": "Anna Regina",
    "lat": "7.26439",
    "lng": "-58.50769"
  },
  {
    "country": "GY",
    "name": "Fort Wellington",
    "lat": "6.39087",
    "lng": "-57.60381"
  },
  {
    "country": "HK",
    "name": "Tsuen Wan",
    "lat": "22.37066",
    "lng": "114.10479"
  },
  {
    "country": "HK",
    "name": "Yung Shue Wan",
    "lat": "22.22623",
    "lng": "114.11241"
  },
  {
    "country": "HK",
    "name": "Yuen Long Kau Hui",
    "lat": "22.45",
    "lng": "114.03333"
  },
  {
    "country": "HK",
    "name": "Wong Tai Sin",
    "lat": "22.35",
    "lng": "114.18333"
  },
  {
    "country": "HK",
    "name": "Wan Chai",
    "lat": "22.28142",
    "lng": "114.17258"
  },
  {
    "country": "HK",
    "name": "Tuen Mun",
    "lat": "22.39175",
    "lng": "113.97157"
  },
  {
    "country": "HK",
    "name": "Tai Po",
    "lat": "22.45007",
    "lng": "114.16877"
  },
  {
    "country": "HK",
    "name": "Tai O",
    "lat": "22.25515",
    "lng": "113.86309"
  },
  {
    "country": "HK",
    "name": "Sok Kwu Wan",
    "lat": "22.20453",
    "lng": "114.13159"
  },
  {
    "country": "HK",
    "name": "Sha Tin",
    "lat": "22.38333",
    "lng": "114.18333"
  },
  {
    "country": "HK",
    "name": "Sham Shui Po",
    "lat": "22.33023",
    "lng": "114.15945"
  },
  {
    "country": "HK",
    "name": "Sai Kung",
    "lat": "22.38333",
    "lng": "114.26667"
  },
  {
    "country": "HK",
    "name": "Ngong Ping",
    "lat": "22.25556",
    "lng": "113.90391"
  },
  {
    "country": "HK",
    "name": "Kowloon",
    "lat": "22.31667",
    "lng": "114.18333"
  },
  {
    "country": "HK",
    "name": "Hong Kong",
    "lat": "22.27832",
    "lng": "114.17469"
  },
  {
    "country": "HK",
    "name": "Central",
    "lat": "22.28299",
    "lng": "114.15846"
  },
  {
    "country": "HK",
    "name": "Tung Chung",
    "lat": "22.28783",
    "lng": "113.94243"
  },
  {
    "country": "HN",
    "name": "Puerto Cortez",
    "lat": "15.82562",
    "lng": "-87.92968"
  },
  {
    "country": "HN",
    "name": "Zopilotepe",
    "lat": "14.6",
    "lng": "-86.26667"
  },
  {
    "country": "HN",
    "name": "Zamora",
    "lat": "15.63333",
    "lng": "-86.06667"
  },
  {
    "country": "HN",
    "name": "Zambrano",
    "lat": "14.26667",
    "lng": "-87.4"
  },
  {
    "country": "HN",
    "name": "Yuscarán",
    "lat": "13.94389",
    "lng": "-86.85278"
  },
  {
    "country": "HN",
    "name": "Yoro",
    "lat": "15.1375",
    "lng": "-87.12778"
  },
  {
    "country": "HN",
    "name": "Yorito",
    "lat": "15.06667",
    "lng": "-87.28333"
  },
  {
    "country": "HN",
    "name": "Yarumela",
    "lat": "14.33333",
    "lng": "-87.63333"
  },
  {
    "country": "HN",
    "name": "Yaruchel",
    "lat": "14.53333",
    "lng": "-88.81667"
  },
  {
    "country": "HN",
    "name": "Yamaranguila",
    "lat": "14.28333",
    "lng": "-88.25"
  },
  {
    "country": "HN",
    "name": "Yaguacire",
    "lat": "14.01667",
    "lng": "-87.21667"
  },
  {
    "country": "HN",
    "name": "Wawina",
    "lat": "15.41667",
    "lng": "-84.43333"
  },
  {
    "country": "HN",
    "name": "Villanueva",
    "lat": "15.31667",
    "lng": "-88"
  },
  {
    "country": "HN",
    "name": "Villa Nueva",
    "lat": "14.03333",
    "lng": "-87.13333"
  },
  {
    "country": "HN",
    "name": "Villa de San Francisco",
    "lat": "14.16667",
    "lng": "-86.96667"
  },
  {
    "country": "HN",
    "name": "Villa de San Antonio",
    "lat": "14.31667",
    "lng": "-87.61667"
  },
  {
    "country": "HN",
    "name": "Victoria",
    "lat": "15.50381",
    "lng": "-87.82625"
  },
  {
    "country": "HN",
    "name": "Veracruz",
    "lat": "14.91667",
    "lng": "-88.78333"
  },
  {
    "country": "HN",
    "name": "Valle de Ángeles",
    "lat": "14.5",
    "lng": "-87.63333"
  },
  {
    "country": "HN",
    "name": "Valle de Ángeles",
    "lat": "14.15",
    "lng": "-87.03333"
  },
  {
    "country": "HN",
    "name": "Vallecillo",
    "lat": "14.51667",
    "lng": "-87.4"
  },
  {
    "country": "HN",
    "name": "Trujillo",
    "lat": "15.91667",
    "lng": "-85.95417"
  },
  {
    "country": "HN",
    "name": "Trojas",
    "lat": "15.35",
    "lng": "-86.7"
  },
  {
    "country": "HN",
    "name": "Trinidad de Copán",
    "lat": "14.95",
    "lng": "-88.75"
  },
  {
    "country": "HN",
    "name": "Trinidad",
    "lat": "15.13333",
    "lng": "-88.23333"
  },
  {
    "country": "HN",
    "name": "Travesía",
    "lat": "15.86667",
    "lng": "-87.9"
  },
  {
    "country": "HN",
    "name": "Tras Cerros",
    "lat": "15.3",
    "lng": "-88.66667"
  },
  {
    "country": "HN",
    "name": "Toyós",
    "lat": "15.55",
    "lng": "-87.65"
  },
  {
    "country": "HN",
    "name": "Tornabé",
    "lat": "15.75",
    "lng": "-87.55"
  },
  {
    "country": "HN",
    "name": "Tocoa",
    "lat": "15.68333",
    "lng": "-86"
  },
  {
    "country": "HN",
    "name": "Teupasenti",
    "lat": "14.21667",
    "lng": "-86.7"
  },
  {
    "country": "HN",
    "name": "Tepusteca",
    "lat": "15.41667",
    "lng": "-86.31667"
  },
  {
    "country": "HN",
    "name": "Tepanguare",
    "lat": "14.33333",
    "lng": "-87.75"
  },
  {
    "country": "HN",
    "name": "Tela",
    "lat": "15.77425",
    "lng": "-87.46731"
  },
  {
    "country": "HN",
    "name": "Tegucigalpa",
    "lat": "14.0818",
    "lng": "-87.20681"
  },
  {
    "country": "HN",
    "name": "Teguajinal",
    "lat": "15.36667",
    "lng": "-86.6"
  },
  {
    "country": "HN",
    "name": "Taulabé",
    "lat": "14.7",
    "lng": "-87.96667"
  },
  {
    "country": "HN",
    "name": "Taujica",
    "lat": "15.7",
    "lng": "-85.91667"
  },
  {
    "country": "HN",
    "name": "Taragual",
    "lat": "14.75",
    "lng": "-88.48333"
  },
  {
    "country": "HN",
    "name": "Támara",
    "lat": "14.15",
    "lng": "-87.33333"
  },
  {
    "country": "HN",
    "name": "Talanga",
    "lat": "14.4",
    "lng": "-87.08333"
  },
  {
    "country": "HN",
    "name": "Sulaco",
    "lat": "14.91667",
    "lng": "-87.26667"
  },
  {
    "country": "HN",
    "name": "Sula",
    "lat": "15.25",
    "lng": "-88.56667"
  },
  {
    "country": "HN",
    "name": "Subirana",
    "lat": "15.2",
    "lng": "-87.45"
  },
  {
    "country": "HN",
    "name": "Sinuapa",
    "lat": "14.45",
    "lng": "-89.18333"
  },
  {
    "country": "HN",
    "name": "Silca",
    "lat": "14.83333",
    "lng": "-86.53333"
  },
  {
    "country": "HN",
    "name": "Siguatepeque",
    "lat": "14.6",
    "lng": "-87.83333"
  },
  {
    "country": "HN",
    "name": "Sensenti",
    "lat": "14.48333",
    "lng": "-88.93333"
  },
  {
    "country": "HN",
    "name": "Savannah Bight",
    "lat": "16.45",
    "lng": "-85.85"
  },
  {
    "country": "HN",
    "name": "Sabá",
    "lat": "15.46667",
    "lng": "-86.25"
  },
  {
    "country": "HN",
    "name": "San Vicente Centenario",
    "lat": "14.88333",
    "lng": "-88.28333"
  },
  {
    "country": "HN",
    "name": "Santiago Puringla",
    "lat": "14.35",
    "lng": "-87.9"
  },
  {
    "country": "HN",
    "name": "Santa Rosa de Copán",
    "lat": "14.76667",
    "lng": "-88.77917"
  },
  {
    "country": "HN",
    "name": "Santa Rosa de Aguán",
    "lat": "15.95",
    "lng": "-85.71667"
  },
  {
    "country": "HN",
    "name": "Santa Rita",
    "lat": "15.16667",
    "lng": "-87.28333"
  },
  {
    "country": "HN",
    "name": "Santa Rita",
    "lat": "14.91667",
    "lng": "-88.21667"
  },
  {
    "country": "HN",
    "name": "Santa Rita, Copan",
    "lat": "14.86748",
    "lng": "-89.1"
  },
  {
    "country": "HN",
    "name": "Santa María del Real",
    "lat": "14.76667",
    "lng": "-85.95"
  },
  {
    "country": "HN",
    "name": "Santa Lucía",
    "lat": "14.41667",
    "lng": "-89.2"
  },
  {
    "country": "HN",
    "name": "Santa Lucía",
    "lat": "14.1",
    "lng": "-87.11667"
  },
  {
    "country": "HN",
    "name": "Santa Elena",
    "lat": "15.38333",
    "lng": "-88.13333"
  },
  {
    "country": "HN",
    "name": "Santa Cruz de Yojoa",
    "lat": "14.98333",
    "lng": "-87.9"
  },
  {
    "country": "HN",
    "name": "Santa Cruz",
    "lat": "13.86667",
    "lng": "-86.63333"
  },
  {
    "country": "HN",
    "name": "Santa Cruz",
    "lat": "13.25806",
    "lng": "-87.34833"
  },
  {
    "country": "HN",
    "name": "Santa Bárbara",
    "lat": "14.91944",
    "lng": "-88.23611"
  },
  {
    "country": "HN",
    "name": "Santa Ana de Yusguare",
    "lat": "13.30056",
    "lng": "-87.11389"
  },
  {
    "country": "HN",
    "name": "Santa Ana",
    "lat": "15.65",
    "lng": "-87.06667"
  },
  {
    "country": "HN",
    "name": "Santa Ana",
    "lat": "13.93167",
    "lng": "-87.27139"
  },
  {
    "country": "HN",
    "name": "San Sebastián",
    "lat": "14.25",
    "lng": "-87.63333"
  },
  {
    "country": "HN",
    "name": "San Pedro Zacapa",
    "lat": "14.75",
    "lng": "-88.11667"
  },
  {
    "country": "HN",
    "name": "San Pedro Sula",
    "lat": "15.50417",
    "lng": "-88.025"
  },
  {
    "country": "HN",
    "name": "San Pedro de Tutule",
    "lat": "14.25",
    "lng": "-87.85"
  },
  {
    "country": "HN",
    "name": "San Nicolás",
    "lat": "15",
    "lng": "-88.75"
  },
  {
    "country": "HN",
    "name": "San Nicolás",
    "lat": "14.93333",
    "lng": "-88.31667"
  },
  {
    "country": "HN",
    "name": "San Nicolás",
    "lat": "14.55",
    "lng": "-86.25"
  },
  {
    "country": "HN",
    "name": "San Matías",
    "lat": "13.98333",
    "lng": "-86.63333"
  },
  {
    "country": "HN",
    "name": "San Marcos de Colón",
    "lat": "13.43333",
    "lng": "-86.8"
  },
  {
    "country": "HN",
    "name": "San Marcos",
    "lat": "15.3",
    "lng": "-88.41667"
  },
  {
    "country": "HN",
    "name": "San Marcos",
    "lat": "14.4",
    "lng": "-88.95"
  },
  {
    "country": "HN",
    "name": "San Manuel",
    "lat": "15.33333",
    "lng": "-87.91667"
  },
  {
    "country": "HN",
    "name": "San Luis de Planes",
    "lat": "14.98333",
    "lng": "-88.13333"
  },
  {
    "country": "HN",
    "name": "San Luis",
    "lat": "15.08333",
    "lng": "-88.38333"
  },
  {
    "country": "HN",
    "name": "San Luis",
    "lat": "14.75",
    "lng": "-87.41667"
  },
  {
    "country": "HN",
    "name": "San Lucas",
    "lat": "13.73333",
    "lng": "-86.95"
  },
  {
    "country": "HN",
    "name": "San Lorenzo",
    "lat": "13.42417",
    "lng": "-87.44722"
  },
  {
    "country": "HN",
    "name": "San Juan Pueblo",
    "lat": "15.58333",
    "lng": "-87.23333"
  },
  {
    "country": "HN",
    "name": "San Juan de Planes",
    "lat": "14.93333",
    "lng": "-88.78333"
  },
  {
    "country": "HN",
    "name": "San Juan de Opoa",
    "lat": "14.78333",
    "lng": "-88.7"
  },
  {
    "country": "HN",
    "name": "San Juan de Flores",
    "lat": "14.26667",
    "lng": "-87.03333"
  },
  {
    "country": "HN",
    "name": "San José de Tarros",
    "lat": "15.3",
    "lng": "-88.7"
  },
  {
    "country": "HN",
    "name": "San José de Río Tinto",
    "lat": "14.93333",
    "lng": "-85.7"
  },
  {
    "country": "HN",
    "name": "San José del Potrero",
    "lat": "14.83333",
    "lng": "-87.28333"
  },
  {
    "country": "HN",
    "name": "San José del Boquerón",
    "lat": "15.48333",
    "lng": "-87.86667"
  },
  {
    "country": "HN",
    "name": "San José de Copán",
    "lat": "14.9",
    "lng": "-88.71667"
  },
  {
    "country": "HN",
    "name": "San José de Comayagua",
    "lat": "14.73333",
    "lng": "-88.03333"
  },
  {
    "country": "HN",
    "name": "San José de Colinas",
    "lat": "15.03333",
    "lng": "-88.3"
  },
  {
    "country": "HN",
    "name": "San José",
    "lat": "15.31667",
    "lng": "-87.16667"
  },
  {
    "country": "HN",
    "name": "San José",
    "lat": "14.25",
    "lng": "-87.95"
  },
  {
    "country": "HN",
    "name": "San Joaquín",
    "lat": "15.05",
    "lng": "-88.9"
  },
  {
    "country": "HN",
    "name": "San Jerónimo",
    "lat": "14.96667",
    "lng": "-88.86667"
  },
  {
    "country": "HN",
    "name": "San Jerónimo",
    "lat": "14.63333",
    "lng": "-87.6"
  },
  {
    "country": "HN",
    "name": "San Jerónimo",
    "lat": "13.17667",
    "lng": "-87.13639"
  },
  {
    "country": "HN",
    "name": "San Ignacio",
    "lat": "14.65",
    "lng": "-87.03333"
  },
  {
    "country": "HN",
    "name": "San Francisco de Yojoa",
    "lat": "15.01667",
    "lng": "-87.96667"
  },
  {
    "country": "HN",
    "name": "San Francisco del Valle",
    "lat": "14.43333",
    "lng": "-88.95"
  },
  {
    "country": "HN",
    "name": "San Francisco de la Paz",
    "lat": "14.9",
    "lng": "-86.2"
  },
  {
    "country": "HN",
    "name": "San Francisco de Coray",
    "lat": "13.66139",
    "lng": "-87.53278"
  },
  {
    "country": "HN",
    "name": "San Francisco de Cones",
    "lat": "14.51667",
    "lng": "-88.9"
  },
  {
    "country": "HN",
    "name": "San Francisco de Becerra",
    "lat": "14.63333",
    "lng": "-86.1"
  },
  {
    "country": "HN",
    "name": "San Francisco",
    "lat": "15.65",
    "lng": "-87.05"
  },
  {
    "country": "HN",
    "name": "San Fernando",
    "lat": "14.68333",
    "lng": "-89.11667"
  },
  {
    "country": "HN",
    "name": "San Esteban",
    "lat": "15.21231",
    "lng": "-85.76996"
  },
  {
    "country": "HN",
    "name": "Sandy Bay",
    "lat": "16.32923",
    "lng": "-86.56446"
  },
  {
    "country": "HN",
    "name": "San Diego",
    "lat": "14.05",
    "lng": "-86.46667"
  },
  {
    "country": "HN",
    "name": "San Buenaventura",
    "lat": "15.01667",
    "lng": "-88"
  },
  {
    "country": "HN",
    "name": "San Antonio del Norte",
    "lat": "13.88444",
    "lng": "-87.70306"
  },
  {
    "country": "HN",
    "name": "San Antonio de la Cuesta",
    "lat": "14.63333",
    "lng": "-87.6"
  },
  {
    "country": "HN",
    "name": "San Antonio de Cortés",
    "lat": "15.11667",
    "lng": "-88.03333"
  },
  {
    "country": "HN",
    "name": "San Antonio",
    "lat": "15.6",
    "lng": "-87.15"
  },
  {
    "country": "HN",
    "name": "San Antonio",
    "lat": "15.33333",
    "lng": "-87.15"
  },
  {
    "country": "HN",
    "name": "San Agustín",
    "lat": "14.81667",
    "lng": "-88.93333"
  },
  {
    "country": "HN",
    "name": "Sambo Creek",
    "lat": "15.81667",
    "lng": "-86.68333"
  },
  {
    "country": "HN",
    "name": "Salamá",
    "lat": "15.75",
    "lng": "-85.96667"
  },
  {
    "country": "HN",
    "name": "Salamá",
    "lat": "14.83333",
    "lng": "-86.58333"
  },
  {
    "country": "HN",
    "name": "Sabanagrande",
    "lat": "13.80778",
    "lng": "-87.25917"
  },
  {
    "country": "HN",
    "name": "Coxen Hole",
    "lat": "16.31759",
    "lng": "-86.53793"
  },
  {
    "country": "HN",
    "name": "Río Lindo",
    "lat": "15.03333",
    "lng": "-87.98333"
  },
  {
    "country": "HN",
    "name": "Río Esteban",
    "lat": "15.83333",
    "lng": "-86.3"
  },
  {
    "country": "HN",
    "name": "Río Chiquito",
    "lat": "15.63333",
    "lng": "-88.25"
  },
  {
    "country": "HN",
    "name": "Río Bonito",
    "lat": "14.76667",
    "lng": "-87.88333"
  },
  {
    "country": "HN",
    "name": "Río Blanquito",
    "lat": "15.73333",
    "lng": "-87.9"
  },
  {
    "country": "HN",
    "name": "Río Abajo",
    "lat": "14.16667",
    "lng": "-87.21667"
  },
  {
    "country": "HN",
    "name": "Reitoca",
    "lat": "13.82583",
    "lng": "-87.46528"
  },
  {
    "country": "HN",
    "name": "Quimistán",
    "lat": "15.35",
    "lng": "-88.4"
  },
  {
    "country": "HN",
    "name": "Quezailica",
    "lat": "14.88333",
    "lng": "-88.73333"
  },
  {
    "country": "HN",
    "name": "Quebrada Seca",
    "lat": "15.66667",
    "lng": "-87.95"
  },
  {
    "country": "HN",
    "name": "Quebradas",
    "lat": "14.5",
    "lng": "-87.35"
  },
  {
    "country": "HN",
    "name": "Quebrada Larga",
    "lat": "14.1",
    "lng": "-86.36667"
  },
  {
    "country": "HN",
    "name": "Quebrada de Arena",
    "lat": "15.76667",
    "lng": "-85.91667"
  },
  {
    "country": "HN",
    "name": "Punuare",
    "lat": "14.73333",
    "lng": "-85.96667"
  },
  {
    "country": "HN",
    "name": "Punta Piedra",
    "lat": "15.9",
    "lng": "-85.28333"
  },
  {
    "country": "HN",
    "name": "Punta Ocote",
    "lat": "15.2",
    "lng": "-87.28333"
  },
  {
    "country": "HN",
    "name": "Puerto Lempira",
    "lat": "15.26667",
    "lng": "-83.77222"
  },
  {
    "country": "HN",
    "name": "Puerto Castilla",
    "lat": "16.01667",
    "lng": "-85.96667"
  },
  {
    "country": "HN",
    "name": "Puerto Alto",
    "lat": "15.7",
    "lng": "-87.86667"
  },
  {
    "country": "HN",
    "name": "Pueblo Nuevo",
    "lat": "15.28333",
    "lng": "-88.01667"
  },
  {
    "country": "HN",
    "name": "Pueblo Nuevo",
    "lat": "15",
    "lng": "-88.75"
  },
  {
    "country": "HN",
    "name": "Protección",
    "lat": "15.03333",
    "lng": "-88.65"
  },
  {
    "country": "HN",
    "name": "Prieta",
    "lat": "15.5806",
    "lng": "-86.13664"
  },
  {
    "country": "HN",
    "name": "Potrerillos",
    "lat": "15.63333",
    "lng": "-88.3"
  },
  {
    "country": "HN",
    "name": "Potrerillos",
    "lat": "15.23333",
    "lng": "-87.96667"
  },
  {
    "country": "HN",
    "name": "Potrerillos",
    "lat": "14.55",
    "lng": "-87.86667"
  },
  {
    "country": "HN",
    "name": "Pinalejo",
    "lat": "15.38333",
    "lng": "-88.4"
  },
  {
    "country": "HN",
    "name": "Pimienta Vieja",
    "lat": "15.23333",
    "lng": "-87.96667"
  },
  {
    "country": "HN",
    "name": "Petoa",
    "lat": "15.26667",
    "lng": "-88.28333"
  },
  {
    "country": "HN",
    "name": "Pespire",
    "lat": "13.59222",
    "lng": "-87.36167"
  },
  {
    "country": "HN",
    "name": "Peña Blanca",
    "lat": "15.53333",
    "lng": "-88.05"
  },
  {
    "country": "HN",
    "name": "Paujiles",
    "lat": "15.1",
    "lng": "-87.35"
  },
  {
    "country": "HN",
    "name": "Paptalaya",
    "lat": "15.5",
    "lng": "-84.31667"
  },
  {
    "country": "HN",
    "name": "Oropolí",
    "lat": "13.81667",
    "lng": "-86.81667"
  },
  {
    "country": "HN",
    "name": "Oropéndolas",
    "lat": "15.01667",
    "lng": "-87.93333"
  },
  {
    "country": "HN",
    "name": "Orocuina",
    "lat": "13.48167",
    "lng": "-87.105"
  },
  {
    "country": "HN",
    "name": "Orica",
    "lat": "14.7",
    "lng": "-86.95"
  },
  {
    "country": "HN",
    "name": "Omoa",
    "lat": "15.76667",
    "lng": "-88.03333"
  },
  {
    "country": "HN",
    "name": "Olanchito",
    "lat": "15.48131",
    "lng": "-86.57415"
  },
  {
    "country": "HN",
    "name": "Ojos de Agua",
    "lat": "14.7",
    "lng": "-88.81667"
  },
  {
    "country": "HN",
    "name": "Ojos de Agua",
    "lat": "14.6",
    "lng": "-87.93333"
  },
  {
    "country": "HN",
    "name": "Ojojona",
    "lat": "13.93389",
    "lng": "-87.29583"
  },
  {
    "country": "HN",
    "name": "Ojo de Agua",
    "lat": "14.01667",
    "lng": "-86.35"
  },
  {
    "country": "HN",
    "name": "Ocote Paulino",
    "lat": "15.41667",
    "lng": "-87.6"
  },
  {
    "country": "HN",
    "name": "Nuevo Chamelecón",
    "lat": "15.38333",
    "lng": "-88.01667"
  },
  {
    "country": "HN",
    "name": "Nueva Ocotepeque",
    "lat": "14.43333",
    "lng": "-89.18333"
  },
  {
    "country": "HN",
    "name": "Nueva Jalapa",
    "lat": "14.91667",
    "lng": "-88.33333"
  },
  {
    "country": "HN",
    "name": "Nueva Esperanza",
    "lat": "15.26667",
    "lng": "-87.6"
  },
  {
    "country": "HN",
    "name": "Nueva Armenia",
    "lat": "15.79556",
    "lng": "-86.49845"
  },
  {
    "country": "HN",
    "name": "Nombre de Jesús",
    "lat": "15.35",
    "lng": "-86.68333"
  },
  {
    "country": "HN",
    "name": "Naranjito",
    "lat": "14.95",
    "lng": "-88.68333"
  },
  {
    "country": "HN",
    "name": "Namasigüe",
    "lat": "13.20472",
    "lng": "-87.13889"
  },
  {
    "country": "HN",
    "name": "Naco",
    "lat": "15.38333",
    "lng": "-88.18333"
  },
  {
    "country": "HN",
    "name": "Nacaome",
    "lat": "13.53611",
    "lng": "-87.4875"
  },
  {
    "country": "HN",
    "name": "Morocelí",
    "lat": "14.11667",
    "lng": "-86.86667"
  },
  {
    "country": "HN",
    "name": "Morazán",
    "lat": "15.31667",
    "lng": "-87.6"
  },
  {
    "country": "HN",
    "name": "Monterrey",
    "lat": "15.58333",
    "lng": "-87.88333"
  },
  {
    "country": "HN",
    "name": "Monjarás",
    "lat": "13.20056",
    "lng": "-87.37417"
  },
  {
    "country": "HN",
    "name": "Mojimán",
    "lat": "15.26667",
    "lng": "-87.6"
  },
  {
    "country": "HN",
    "name": "Minas de Oro",
    "lat": "14.8",
    "lng": "-87.35"
  },
  {
    "country": "HN",
    "name": "Mezapa",
    "lat": "15.58333",
    "lng": "-87.65"
  },
  {
    "country": "HN",
    "name": "Mateo",
    "lat": "14.08333",
    "lng": "-87.31667"
  },
  {
    "country": "HN",
    "name": "Mata de Plátano",
    "lat": "14.6",
    "lng": "-87.28333"
  },
  {
    "country": "HN",
    "name": "Marcovia",
    "lat": "13.28806",
    "lng": "-87.30972"
  },
  {
    "country": "HN",
    "name": "Marcala",
    "lat": "14.15",
    "lng": "-88.03333"
  },
  {
    "country": "HN",
    "name": "Marale",
    "lat": "14.88333",
    "lng": "-87.15"
  },
  {
    "country": "HN",
    "name": "Manto",
    "lat": "14.91667",
    "lng": "-86.38333"
  },
  {
    "country": "HN",
    "name": "Mangulile",
    "lat": "15.06667",
    "lng": "-86.8"
  },
  {
    "country": "HN",
    "name": "Lucerna",
    "lat": "14.55",
    "lng": "-88.93333"
  },
  {
    "country": "HN",
    "name": "Los Tangos",
    "lat": "15.15",
    "lng": "-88.68333"
  },
  {
    "country": "HN",
    "name": "Los Planes",
    "lat": "14.05",
    "lng": "-88.01667"
  },
  {
    "country": "HN",
    "name": "Los Naranjos",
    "lat": "14.9",
    "lng": "-88.05"
  },
  {
    "country": "HN",
    "name": "Los Llanitos",
    "lat": "13.28694",
    "lng": "-87.33444"
  },
  {
    "country": "HN",
    "name": "Los Caminos",
    "lat": "14.95",
    "lng": "-87.96667"
  },
  {
    "country": "HN",
    "name": "Lomitas",
    "lat": "15.1",
    "lng": "-87.21667"
  },
  {
    "country": "HN",
    "name": "Loma Alta",
    "lat": "15.39667",
    "lng": "-88.55972"
  },
  {
    "country": "HN",
    "name": "Liure",
    "lat": "13.53583",
    "lng": "-87.09194"
  },
  {
    "country": "HN",
    "name": "Lepaterique",
    "lat": "14.06667",
    "lng": "-87.46667"
  },
  {
    "country": "HN",
    "name": "Lepaera",
    "lat": "14.78333",
    "lng": "-88.58333"
  },
  {
    "country": "HN",
    "name": "Lejamaní",
    "lat": "14.36667",
    "lng": "-87.7"
  },
  {
    "country": "HN",
    "name": "La Zumbadora",
    "lat": "15.01667",
    "lng": "-88.9"
  },
  {
    "country": "HN",
    "name": "La Virtud",
    "lat": "14.05",
    "lng": "-88.7"
  },
  {
    "country": "HN",
    "name": "La Unión",
    "lat": "15.71667",
    "lng": "-87"
  },
  {
    "country": "HN",
    "name": "La Unión",
    "lat": "14.81667",
    "lng": "-88.4"
  },
  {
    "country": "HN",
    "name": "La Trinidad",
    "lat": "15.1",
    "lng": "-87.2"
  },
  {
    "country": "HN",
    "name": "Las Vegas",
    "lat": "15.01667",
    "lng": "-87.45"
  },
  {
    "country": "HN",
    "name": "Las Vegas, Santa Barbara",
    "lat": "14.87649",
    "lng": "-88.07473"
  },
  {
    "country": "HN",
    "name": "Las Trojes",
    "lat": "14.06667",
    "lng": "-85.98333"
  },
  {
    "country": "HN",
    "name": "Las Tejeras",
    "lat": "14.8",
    "lng": "-88.6"
  },
  {
    "country": "HN",
    "name": "Las Lajas",
    "lat": "14.78333",
    "lng": "-87.75"
  },
  {
    "country": "HN",
    "name": "San José de Las Conchas",
    "lat": "13.32528",
    "lng": "-87.39556"
  },
  {
    "country": "HN",
    "name": "La Sarrosa",
    "lat": "15.23333",
    "lng": "-87.83333"
  },
  {
    "country": "HN",
    "name": "Las Ánimas",
    "lat": "14.25",
    "lng": "-86.56667"
  },
  {
    "country": "HN",
    "name": "La Sabana",
    "lat": "15.36667",
    "lng": "-87.93333"
  },
  {
    "country": "HN",
    "name": "La Rosa",
    "lat": "15.35",
    "lng": "-87.06667"
  },
  {
    "country": "HN",
    "name": "La Playona",
    "lat": "15.11667",
    "lng": "-88.98333"
  },
  {
    "country": "HN",
    "name": "La Paz",
    "lat": "14.31944",
    "lng": "-87.67917"
  },
  {
    "country": "HN",
    "name": "Langue",
    "lat": "13.62083",
    "lng": "-87.6525"
  },
  {
    "country": "HN",
    "name": "La Mina",
    "lat": "15.31667",
    "lng": "-87.83333"
  },
  {
    "country": "HN",
    "name": "La Masica",
    "lat": "15.61667",
    "lng": "-87.11667"
  },
  {
    "country": "HN",
    "name": "Lamaní",
    "lat": "14.2",
    "lng": "-87.61667"
  },
  {
    "country": "HN",
    "name": "La Lima",
    "lat": "15.43333",
    "lng": "-87.91667"
  },
  {
    "country": "HN",
    "name": "La Libertad",
    "lat": "14.8",
    "lng": "-88.58333"
  },
  {
    "country": "HN",
    "name": "La Libertad",
    "lat": "14.75",
    "lng": "-87.61667"
  },
  {
    "country": "HN",
    "name": "La Labor",
    "lat": "14.48333",
    "lng": "-89"
  },
  {
    "country": "HN",
    "name": "La Jutosa",
    "lat": "15.63333",
    "lng": "-88"
  },
  {
    "country": "HN",
    "name": "La Huesa",
    "lat": "15.58333",
    "lng": "-87.88333"
  },
  {
    "country": "HN",
    "name": "Laguna Verde",
    "lat": "15.2",
    "lng": "-88.16667"
  },
  {
    "country": "HN",
    "name": "Laguna Seca",
    "lat": "14.7",
    "lng": "-86.1"
  },
  {
    "country": "HN",
    "name": "La Guata",
    "lat": "15.08333",
    "lng": "-86.38333"
  },
  {
    "country": "HN",
    "name": "La Guama",
    "lat": "14.88333",
    "lng": "-87.93333"
  },
  {
    "country": "HN",
    "name": "La Guacamaya",
    "lat": "15.25",
    "lng": "-87.8"
  },
  {
    "country": "HN",
    "name": "La Flecha",
    "lat": "15.28333",
    "lng": "-88.48333"
  },
  {
    "country": "HN",
    "name": "La Estancia",
    "lat": "15.28333",
    "lng": "-87.55"
  },
  {
    "country": "HN",
    "name": "La Estancia",
    "lat": "15.05",
    "lng": "-86.35"
  },
  {
    "country": "HN",
    "name": "La Esperanza",
    "lat": "15.63333",
    "lng": "-85.76667"
  },
  {
    "country": "HN",
    "name": "La Esperanza",
    "lat": "14.31111",
    "lng": "-88.18056"
  },
  {
    "country": "HN",
    "name": "La Ermita",
    "lat": "14.46667",
    "lng": "-87.06667"
  },
  {
    "country": "HN",
    "name": "La Entrada",
    "lat": "15.05",
    "lng": "-88.73333"
  },
  {
    "country": "HN",
    "name": "La Encarnación",
    "lat": "14.66667",
    "lng": "-89.08333"
  },
  {
    "country": "HN",
    "name": "La Criba",
    "lat": "13.45361",
    "lng": "-87.41333"
  },
  {
    "country": "HN",
    "name": "La Concepción",
    "lat": "14.7",
    "lng": "-86.23333"
  },
  {
    "country": "HN",
    "name": "La Ceiba",
    "lat": "15.75971",
    "lng": "-86.78221"
  },
  {
    "country": "HN",
    "name": "La Brea",
    "lat": "15.8",
    "lng": "-85.96667"
  },
  {
    "country": "HN",
    "name": "Jutiquile",
    "lat": "14.71667",
    "lng": "-86.08333"
  },
  {
    "country": "HN",
    "name": "Juticalpa",
    "lat": "14.66667",
    "lng": "-86.21944"
  },
  {
    "country": "HN",
    "name": "Jutiapa",
    "lat": "15.76667",
    "lng": "-86.51667"
  },
  {
    "country": "HN",
    "name": "Jutiapa",
    "lat": "13.98333",
    "lng": "-86.4"
  },
  {
    "country": "HN",
    "name": "Joconal",
    "lat": "15.35444",
    "lng": "-88.63556"
  },
  {
    "country": "HN",
    "name": "Jocón",
    "lat": "15.28333",
    "lng": "-86.96667"
  },
  {
    "country": "HN",
    "name": "Jiquinlaca",
    "lat": "14",
    "lng": "-88.35"
  },
  {
    "country": "HN",
    "name": "Jícaro Galán",
    "lat": "13.53167",
    "lng": "-87.43889"
  },
  {
    "country": "HN",
    "name": "Jesús de Otoro",
    "lat": "14.48333",
    "lng": "-87.98333"
  },
  {
    "country": "HN",
    "name": "Jericó",
    "lat": "15.95",
    "lng": "-85.96667"
  },
  {
    "country": "HN",
    "name": "Jamalteca",
    "lat": "14.7",
    "lng": "-87.58333"
  },
  {
    "country": "HN",
    "name": "Jacaleapa",
    "lat": "14.01667",
    "lng": "-86.66667"
  },
  {
    "country": "HN",
    "name": "Iralaya",
    "lat": "15",
    "lng": "-83.23333"
  },
  {
    "country": "HN",
    "name": "Intibucá",
    "lat": "14.31667",
    "lng": "-88.16667"
  },
  {
    "country": "HN",
    "name": "Ilama",
    "lat": "15.06667",
    "lng": "-88.21667"
  },
  {
    "country": "HN",
    "name": "Güinope",
    "lat": "13.88333",
    "lng": "-86.93333"
  },
  {
    "country": "HN",
    "name": "Guayape",
    "lat": "14.71667",
    "lng": "-86.83333"
  },
  {
    "country": "HN",
    "name": "Guarizama",
    "lat": "14.91667",
    "lng": "-86.33333"
  },
  {
    "country": "HN",
    "name": "Guanaja",
    "lat": "16.44795",
    "lng": "-85.89431"
  },
  {
    "country": "HN",
    "name": "Gualjoco",
    "lat": "14.95",
    "lng": "-88.23333"
  },
  {
    "country": "HN",
    "name": "Gualaco",
    "lat": "15.02521",
    "lng": "-86.07076"
  },
  {
    "country": "HN",
    "name": "Guaimitas",
    "lat": "15.5",
    "lng": "-87.71667"
  },
  {
    "country": "HN",
    "name": "Guaimaca",
    "lat": "14.53333",
    "lng": "-86.81667"
  },
  {
    "country": "HN",
    "name": "Guacamaya",
    "lat": "15.01667",
    "lng": "-88.15"
  },
  {
    "country": "HN",
    "name": "Gracias",
    "lat": "14.59028",
    "lng": "-88.58194"
  },
  {
    "country": "HN",
    "name": "Goascorán",
    "lat": "13.58333",
    "lng": "-87.61667"
  },
  {
    "country": "HN",
    "name": "French Harbor",
    "lat": "16.35",
    "lng": "-86.43333"
  },
  {
    "country": "HN",
    "name": "Francia",
    "lat": "15.85",
    "lng": "-85.58333"
  },
  {
    "country": "HN",
    "name": "Florida",
    "lat": "15.03333",
    "lng": "-88.83333"
  },
  {
    "country": "HN",
    "name": "Flores",
    "lat": "14.28333",
    "lng": "-87.56667"
  },
  {
    "country": "HN",
    "name": "Esquías",
    "lat": "14.73333",
    "lng": "-87.36667"
  },
  {
    "country": "HN",
    "name": "Erandique",
    "lat": "14.23333",
    "lng": "-88.46667"
  },
  {
    "country": "HN",
    "name": "El Zapotal del Norte",
    "lat": "15.51667",
    "lng": "-88.05"
  },
  {
    "country": "HN",
    "name": "El Tular",
    "lat": "13.46639",
    "lng": "-87.51528"
  },
  {
    "country": "HN",
    "name": "El Triunfo de la Cruz",
    "lat": "15.76667",
    "lng": "-87.43333"
  },
  {
    "country": "HN",
    "name": "El Triunfo",
    "lat": "13.11667",
    "lng": "-87"
  },
  {
    "country": "HN",
    "name": "El Tránsito",
    "lat": "14.38333",
    "lng": "-88.91667"
  },
  {
    "country": "HN",
    "name": "El Tigre",
    "lat": "14.93333",
    "lng": "-87.98333"
  },
  {
    "country": "HN",
    "name": "El Terrero",
    "lat": "14.06667",
    "lng": "-87.06667"
  },
  {
    "country": "HN",
    "name": "El Tablón",
    "lat": "14.03333",
    "lng": "-87.16667"
  },
  {
    "country": "HN",
    "name": "El Suyatal",
    "lat": "14.51667",
    "lng": "-87.21667"
  },
  {
    "country": "HN",
    "name": "El Socorro",
    "lat": "14.63333",
    "lng": "-87.91667"
  },
  {
    "country": "HN",
    "name": "El Sauce",
    "lat": "14.5285",
    "lng": "-87.66571"
  },
  {
    "country": "HN",
    "name": "El Rusio",
    "lat": "14.46667",
    "lng": "-86.36667"
  },
  {
    "country": "HN",
    "name": "El Rosario",
    "lat": "14.8",
    "lng": "-87.76667"
  },
  {
    "country": "HN",
    "name": "El Rincón",
    "lat": "14.58333",
    "lng": "-87.93333"
  },
  {
    "country": "HN",
    "name": "El Rancho",
    "lat": "15.66667",
    "lng": "-87.95"
  },
  {
    "country": "HN",
    "name": "El Rancho",
    "lat": "14.68333",
    "lng": "-87.5"
  },
  {
    "country": "HN",
    "name": "El Puente",
    "lat": "13.28333",
    "lng": "-87.11667"
  },
  {
    "country": "HN",
    "name": "El Progreso",
    "lat": "15.4",
    "lng": "-87.8"
  },
  {
    "country": "HN",
    "name": "El Porvenir",
    "lat": "15.83333",
    "lng": "-87.93333"
  },
  {
    "country": "HN",
    "name": "El Porvenir",
    "lat": "15.75",
    "lng": "-86.93333"
  },
  {
    "country": "HN",
    "name": "El Porvenir",
    "lat": "14.58333",
    "lng": "-87.88333"
  },
  {
    "country": "HN",
    "name": "El Porvenir",
    "lat": "13.76167",
    "lng": "-87.34583"
  },
  {
    "country": "HN",
    "name": "El Plan",
    "lat": "15.28333",
    "lng": "-87.96667"
  },
  {
    "country": "HN",
    "name": "El Pino",
    "lat": "15.7",
    "lng": "-86.93333"
  },
  {
    "country": "HN",
    "name": "El Perico",
    "lat": "15.08333",
    "lng": "-88.1"
  },
  {
    "country": "HN",
    "name": "El Pedernal",
    "lat": "14.7",
    "lng": "-87.11667"
  },
  {
    "country": "HN",
    "name": "El Paraíso",
    "lat": "13.86667",
    "lng": "-86.55"
  },
  {
    "country": "HN",
    "name": "El Olivar",
    "lat": "15.08333",
    "lng": "-87.88333"
  },
  {
    "country": "HN",
    "name": "El Ocotón",
    "lat": "15.03333",
    "lng": "-88.88333"
  },
  {
    "country": "HN",
    "name": "El Ocote",
    "lat": "15.41667",
    "lng": "-86.56667"
  },
  {
    "country": "HN",
    "name": "El Obraje",
    "lat": "14",
    "lng": "-86.43333"
  },
  {
    "country": "HN",
    "name": "El Obraje",
    "lat": "13.15417",
    "lng": "-87.13083"
  },
  {
    "country": "HN",
    "name": "El Níspero",
    "lat": "14.76667",
    "lng": "-88.33333"
  },
  {
    "country": "HN",
    "name": "El Negrito",
    "lat": "15.31667",
    "lng": "-87.7"
  },
  {
    "country": "HN",
    "name": "El Mochito",
    "lat": "14.86667",
    "lng": "-88.08333"
  },
  {
    "country": "HN",
    "name": "El Milagro",
    "lat": "15.4",
    "lng": "-87.96667"
  },
  {
    "country": "HN",
    "name": "El Marañón",
    "lat": "15.4",
    "lng": "-88.05"
  },
  {
    "country": "HN",
    "name": "El Lolo",
    "lat": "14.11667",
    "lng": "-87.26667"
  },
  {
    "country": "HN",
    "name": "El Llano",
    "lat": "15.15",
    "lng": "-87.88333"
  },
  {
    "country": "HN",
    "name": "El Juncal",
    "lat": "15.45",
    "lng": "-86.43333"
  },
  {
    "country": "HN",
    "name": "Elíxir",
    "lat": "15.48333",
    "lng": "-86.3"
  },
  {
    "country": "HN",
    "name": "El Guayabito",
    "lat": "14.83333",
    "lng": "-86.03333"
  },
  {
    "country": "HN",
    "name": "El Guapinol",
    "lat": "13.76667",
    "lng": "-87.46667"
  },
  {
    "country": "HN",
    "name": "El Guantillo",
    "lat": "14.6",
    "lng": "-87.3"
  },
  {
    "country": "HN",
    "name": "El Guante",
    "lat": "14.55",
    "lng": "-87.1"
  },
  {
    "country": "HN",
    "name": "El Escaño de Tepale",
    "lat": "14.75",
    "lng": "-87.06667"
  },
  {
    "country": "HN",
    "name": "El Escanito",
    "lat": "14.66667",
    "lng": "-87.1"
  },
  {
    "country": "HN",
    "name": "El Cubolero",
    "lat": "13.46667",
    "lng": "-87.66667"
  },
  {
    "country": "HN",
    "name": "El Corpus",
    "lat": "14.7",
    "lng": "-88.91667"
  },
  {
    "country": "HN",
    "name": "Corpus",
    "lat": "13.28889",
    "lng": "-87.03472"
  },
  {
    "country": "HN",
    "name": "El Corozal",
    "lat": "15.06667",
    "lng": "-88.61667"
  },
  {
    "country": "HN",
    "name": "El Ciruelo",
    "lat": "15.3",
    "lng": "-88.5"
  },
  {
    "country": "HN",
    "name": "El Chimbo",
    "lat": "14.13333",
    "lng": "-87.11667"
  },
  {
    "country": "HN",
    "name": "El Chichicaste",
    "lat": "14.06667",
    "lng": "-86.3"
  },
  {
    "country": "HN",
    "name": "El Benque",
    "lat": "14.03333",
    "lng": "-86.46667"
  },
  {
    "country": "HN",
    "name": "El Bálsamo",
    "lat": "15.06667",
    "lng": "-87.46667"
  },
  {
    "country": "HN",
    "name": "El Agua Dulcita",
    "lat": "14.7",
    "lng": "-87.75"
  },
  {
    "country": "HN",
    "name": "El Achiotal",
    "lat": "14.08333",
    "lng": "-88.75"
  },
  {
    "country": "HN",
    "name": "Duyure",
    "lat": "13.63333",
    "lng": "-86.81667"
  },
  {
    "country": "HN",
    "name": "Dulce Nombre de Culmí",
    "lat": "15.1",
    "lng": "-85.53333"
  },
  {
    "country": "HN",
    "name": "Dulce Nombre",
    "lat": "14.85",
    "lng": "-88.83333"
  },
  {
    "country": "HN",
    "name": "Dolores",
    "lat": "14.86667",
    "lng": "-88.83333"
  },
  {
    "country": "HN",
    "name": "Danlí",
    "lat": "14.03333",
    "lng": "-86.58333"
  },
  {
    "country": "HN",
    "name": "Cuyamel",
    "lat": "15.66667",
    "lng": "-88.2"
  },
  {
    "country": "HN",
    "name": "Cuyalí",
    "lat": "13.88333",
    "lng": "-86.55"
  },
  {
    "country": "HN",
    "name": "Cusuna",
    "lat": "15.85",
    "lng": "-85.23333"
  },
  {
    "country": "HN",
    "name": "Cucuyagua",
    "lat": "14.65",
    "lng": "-88.86667"
  },
  {
    "country": "HN",
    "name": "Coyoles Central",
    "lat": "15.4",
    "lng": "-86.66667"
  },
  {
    "country": "HN",
    "name": "Correderos",
    "lat": "15.41667",
    "lng": "-88.45"
  },
  {
    "country": "HN",
    "name": "Corquín",
    "lat": "14.56667",
    "lng": "-88.86667"
  },
  {
    "country": "HN",
    "name": "Corozal",
    "lat": "15.8",
    "lng": "-86.71667"
  },
  {
    "country": "HN",
    "name": "Corocito",
    "lat": "15.75",
    "lng": "-85.78333"
  },
  {
    "country": "HN",
    "name": "Copán",
    "lat": "14.83333",
    "lng": "-89.15"
  },
  {
    "country": "HN",
    "name": "Concordia",
    "lat": "14.61667",
    "lng": "-86.65"
  },
  {
    "country": "HN",
    "name": "Concepción del Sur",
    "lat": "14.8",
    "lng": "-88.16667"
  },
  {
    "country": "HN",
    "name": "Concepción de la Barranca",
    "lat": "15.16667",
    "lng": "-88.71667"
  },
  {
    "country": "HN",
    "name": "Concepción de Guasistagua",
    "lat": "14.6",
    "lng": "-87.65"
  },
  {
    "country": "HN",
    "name": "Comayagua",
    "lat": "14.45139",
    "lng": "-87.6375"
  },
  {
    "country": "HN",
    "name": "Cololaca",
    "lat": "14.3",
    "lng": "-88.88333"
  },
  {
    "country": "HN",
    "name": "Cofradía",
    "lat": "15.4",
    "lng": "-88.15"
  },
  {
    "country": "HN",
    "name": "Cofradía",
    "lat": "14.21667",
    "lng": "-87.18333"
  },
  {
    "country": "HN",
    "name": "Chotepe",
    "lat": "15.41667",
    "lng": "-87.98333"
  },
  {
    "country": "HN",
    "name": "Ciudad Choluteca",
    "lat": "13.30028",
    "lng": "-87.19083"
  },
  {
    "country": "HN",
    "name": "Choloma",
    "lat": "15.61444",
    "lng": "-87.95302"
  },
  {
    "country": "HN",
    "name": "Chivana",
    "lat": "15.75",
    "lng": "-87.98333"
  },
  {
    "country": "HN",
    "name": "Chalmeca",
    "lat": "15.1",
    "lng": "-88.68333"
  },
  {
    "country": "HN",
    "name": "Cerro Grande",
    "lat": "13.81667",
    "lng": "-87.25"
  },
  {
    "country": "HN",
    "name": "Cerro Blanco",
    "lat": "14.66667",
    "lng": "-87.78333"
  },
  {
    "country": "HN",
    "name": "Ceguaca",
    "lat": "14.8",
    "lng": "-88.2"
  },
  {
    "country": "HN",
    "name": "Cedros",
    "lat": "14.6",
    "lng": "-87.11667"
  },
  {
    "country": "HN",
    "name": "Casa Quemada",
    "lat": "15.26667",
    "lng": "-88.55"
  },
  {
    "country": "HN",
    "name": "Casa Quemada",
    "lat": "15.11667",
    "lng": "-88.08333"
  },
  {
    "country": "HN",
    "name": "Carbajales",
    "lat": "15.51667",
    "lng": "-86.35"
  },
  {
    "country": "HN",
    "name": "Cane",
    "lat": "14.28333",
    "lng": "-87.66667"
  },
  {
    "country": "HN",
    "name": "Cañaveral",
    "lat": "14.98333",
    "lng": "-88.01667"
  },
  {
    "country": "HN",
    "name": "Campamento",
    "lat": "14.55",
    "lng": "-86.65"
  },
  {
    "country": "HN",
    "name": "Camasca",
    "lat": "14",
    "lng": "-88.38333"
  },
  {
    "country": "HN",
    "name": "Camalote",
    "lat": "15.33333",
    "lng": "-88.33333"
  },
  {
    "country": "HN",
    "name": "Callejones",
    "lat": "15.16667",
    "lng": "-88.65"
  },
  {
    "country": "HN",
    "name": "Buenos Aires",
    "lat": "15.03333",
    "lng": "-88.96667"
  },
  {
    "country": "HN",
    "name": "Brus Laguna",
    "lat": "15.75",
    "lng": "-84.48333"
  },
  {
    "country": "HN",
    "name": "Bonito Oriental",
    "lat": "15.74765",
    "lng": "-85.73559"
  },
  {
    "country": "HN",
    "name": "Berlín",
    "lat": "14.83333",
    "lng": "-88.5"
  },
  {
    "country": "HN",
    "name": "Belén Gualcho",
    "lat": "14.48333",
    "lng": "-88.8"
  },
  {
    "country": "HN",
    "name": "Bejuco",
    "lat": "15.13333",
    "lng": "-87.93333"
  },
  {
    "country": "HN",
    "name": "Barra Patuca",
    "lat": "15.8",
    "lng": "-84.28333"
  },
  {
    "country": "HN",
    "name": "Baracoa",
    "lat": "15.76667",
    "lng": "-87.85"
  },
  {
    "country": "HN",
    "name": "Bálsamo Oriental",
    "lat": "15.48333",
    "lng": "-86.33333"
  },
  {
    "country": "HN",
    "name": "Baja Mar",
    "lat": "15.88333",
    "lng": "-87.85"
  },
  {
    "country": "HN",
    "name": "Azacualpa",
    "lat": "15.34333",
    "lng": "-88.55139"
  },
  {
    "country": "HN",
    "name": "Azacualpa",
    "lat": "14.71667",
    "lng": "-88.1"
  },
  {
    "country": "HN",
    "name": "Ayapa",
    "lat": "15.11174",
    "lng": "-87.17557"
  },
  {
    "country": "HN",
    "name": "Auka",
    "lat": "14.94087",
    "lng": "-83.83229"
  },
  {
    "country": "HN",
    "name": "Auas",
    "lat": "15.48333",
    "lng": "-84.33333"
  },
  {
    "country": "HN",
    "name": "Atima",
    "lat": "14.93333",
    "lng": "-88.48333"
  },
  {
    "country": "HN",
    "name": "Atenas de San Cristóbal",
    "lat": "15.68333",
    "lng": "-87.31667"
  },
  {
    "country": "HN",
    "name": "Armenta",
    "lat": "15.5",
    "lng": "-88.05"
  },
  {
    "country": "HN",
    "name": "Armenia",
    "lat": "15.46667",
    "lng": "-86.36667"
  },
  {
    "country": "HN",
    "name": "Arizona",
    "lat": "15.63333",
    "lng": "-87.31667"
  },
  {
    "country": "HN",
    "name": "Arimís",
    "lat": "14.78333",
    "lng": "-86"
  },
  {
    "country": "HN",
    "name": "Arenal",
    "lat": "15.35",
    "lng": "-86.83333"
  },
  {
    "country": "HN",
    "name": "Araulí",
    "lat": "13.95",
    "lng": "-86.55"
  },
  {
    "country": "HN",
    "name": "Aramecina",
    "lat": "13.74222",
    "lng": "-87.71028"
  },
  {
    "country": "HN",
    "name": "Arada",
    "lat": "14.85",
    "lng": "-88.3"
  },
  {
    "country": "HN",
    "name": "Antigua Ocotepeque",
    "lat": "14.4",
    "lng": "-89.2"
  },
  {
    "country": "HN",
    "name": "Amapala",
    "lat": "13.29222",
    "lng": "-87.65389"
  },
  {
    "country": "HN",
    "name": "La Alianza",
    "lat": "13.51222",
    "lng": "-87.72444"
  },
  {
    "country": "HN",
    "name": "Ajuterique",
    "lat": "14.38333",
    "lng": "-87.7"
  },
  {
    "country": "HN",
    "name": "Aguas del Padre",
    "lat": "14.56667",
    "lng": "-87.88333"
  },
  {
    "country": "HN",
    "name": "Agualote",
    "lat": "15.33528",
    "lng": "-88.55306"
  },
  {
    "country": "HN",
    "name": "Agua Fría",
    "lat": "13.46889",
    "lng": "-87.55111"
  },
  {
    "country": "HN",
    "name": "Agua Caliente",
    "lat": "14.88333",
    "lng": "-88.81667"
  },
  {
    "country": "HN",
    "name": "Agua Blanca Sur",
    "lat": "15.25",
    "lng": "-87.88333"
  },
  {
    "country": "HN",
    "name": "Agua Azul Rancho",
    "lat": "14.9",
    "lng": "-87.95"
  },
  {
    "country": "HN",
    "name": "Agua Azul",
    "lat": "14.91667",
    "lng": "-87.96667"
  },
  {
    "country": "HN",
    "name": "Agalteca",
    "lat": "14.45",
    "lng": "-87.26667"
  },
  {
    "country": "HN",
    "name": "Texíguat",
    "lat": "13.64972",
    "lng": "-87.0225"
  },
  {
    "country": "HR",
    "name": "Vranjic",
    "lat": "43.53333",
    "lng": "16.46667"
  },
  {
    "country": "HR",
    "name": "Županja",
    "lat": "45.0775",
    "lng": "18.6975"
  },
  {
    "country": "HR",
    "name": "Žumberak",
    "lat": "45.75",
    "lng": "15.43333"
  },
  {
    "country": "HR",
    "name": "Žrnovo",
    "lat": "42.95111",
    "lng": "17.11417"
  },
  {
    "country": "HR",
    "name": "Žrnovnica",
    "lat": "43.52111",
    "lng": "16.55917"
  },
  {
    "country": "HR",
    "name": "Žminj",
    "lat": "45.14278",
    "lng": "13.90889"
  },
  {
    "country": "HR",
    "name": "Zlatar",
    "lat": "46.09417",
    "lng": "16.07083"
  },
  {
    "country": "HR",
    "name": "Sveti Ivan Zelina",
    "lat": "45.95611",
    "lng": "16.24611"
  },
  {
    "country": "HR",
    "name": "Ždralovi",
    "lat": "45.87639",
    "lng": "16.875"
  },
  {
    "country": "HR",
    "name": "Zdenci Brdovečki",
    "lat": "45.86667",
    "lng": "15.75"
  },
  {
    "country": "HR",
    "name": "Zdenci",
    "lat": "45.58917",
    "lng": "17.95028"
  },
  {
    "country": "HR",
    "name": "Zaprešić",
    "lat": "45.85639",
    "lng": "15.80778"
  },
  {
    "country": "HR",
    "name": "Žakanje",
    "lat": "45.6",
    "lng": "15.35"
  },
  {
    "country": "HR",
    "name": "Zagvozd",
    "lat": "43.3975",
    "lng": "17.05694"
  },
  {
    "country": "HR",
    "name": "Dubrava",
    "lat": "45.83361",
    "lng": "16.06361"
  },
  {
    "country": "HR",
    "name": "Zagreb",
    "lat": "45.81444",
    "lng": "15.97798"
  },
  {
    "country": "HR",
    "name": "Zadvorsko",
    "lat": "45.71978",
    "lng": "15.9088"
  },
  {
    "country": "HR",
    "name": "Zadvarje",
    "lat": "43.43139",
    "lng": "16.88972"
  },
  {
    "country": "HR",
    "name": "Zadar",
    "lat": "44.11972",
    "lng": "15.24222"
  },
  {
    "country": "HR",
    "name": "Sveti Križ Začretje",
    "lat": "46.08083",
    "lng": "15.91111"
  },
  {
    "country": "HR",
    "name": "Zabok",
    "lat": "46.02944",
    "lng": "15.915"
  },
  {
    "country": "HR",
    "name": "Sveti Ivan Žabno",
    "lat": "45.94611",
    "lng": "16.61333"
  },
  {
    "country": "HR",
    "name": "Vukovar",
    "lat": "45.34333",
    "lng": "18.99972"
  },
  {
    "country": "HR",
    "name": "Vuka",
    "lat": "45.43389",
    "lng": "18.505"
  },
  {
    "country": "HR",
    "name": "Vrsi",
    "lat": "44.26472",
    "lng": "15.2325"
  },
  {
    "country": "HR",
    "name": "Vrsar",
    "lat": "45.14917",
    "lng": "13.60528"
  },
  {
    "country": "HR",
    "name": "Vrpolje",
    "lat": "45.21056",
    "lng": "18.40556"
  },
  {
    "country": "HR",
    "name": "Vrhovine",
    "lat": "44.85167",
    "lng": "15.41917"
  },
  {
    "country": "HR",
    "name": "Vrgorac",
    "lat": "43.20583",
    "lng": "17.37111"
  },
  {
    "country": "HR",
    "name": "Gvozd",
    "lat": "45.35305",
    "lng": "15.86563"
  },
  {
    "country": "HR",
    "name": "Vrbovsko",
    "lat": "45.36861",
    "lng": "15.07833"
  },
  {
    "country": "HR",
    "name": "Vrbovec",
    "lat": "45.88333",
    "lng": "16.42167"
  },
  {
    "country": "HR",
    "name": "Vrbnik",
    "lat": "45.07583",
    "lng": "14.6725"
  },
  {
    "country": "HR",
    "name": "Vrbje",
    "lat": "45.1875",
    "lng": "17.41917"
  },
  {
    "country": "HR",
    "name": "Vrbanja",
    "lat": "44.98139",
    "lng": "18.92722"
  },
  {
    "country": "HR",
    "name": "Vratišinec",
    "lat": "46.47806",
    "lng": "16.45778"
  },
  {
    "country": "HR",
    "name": "Seget Vranjica",
    "lat": "43.50999",
    "lng": "16.18704"
  },
  {
    "country": "HR",
    "name": "Voloder",
    "lat": "45.54806",
    "lng": "16.67889"
  },
  {
    "country": "HR",
    "name": "Vojnić",
    "lat": "45.32361",
    "lng": "15.69861"
  },
  {
    "country": "HR",
    "name": "Vodnjan",
    "lat": "44.95944",
    "lng": "13.85167"
  },
  {
    "country": "HR",
    "name": "Vođinci",
    "lat": "45.27556",
    "lng": "18.60972"
  },
  {
    "country": "HR",
    "name": "Vodice",
    "lat": "43.76083",
    "lng": "15.78278"
  },
  {
    "country": "HR",
    "name": "Voćin",
    "lat": "45.61778",
    "lng": "17.54778"
  },
  {
    "country": "HR",
    "name": "Vladislavci",
    "lat": "45.45944",
    "lng": "18.57417"
  },
  {
    "country": "HR",
    "name": "Vižinada",
    "lat": "45.32944",
    "lng": "13.75861"
  },
  {
    "country": "HR",
    "name": "Visoko",
    "lat": "46.09028",
    "lng": "16.325"
  },
  {
    "country": "HR",
    "name": "Višnjevac",
    "lat": "45.56861",
    "lng": "18.61389"
  },
  {
    "country": "HR",
    "name": "Visignano",
    "lat": "45.27639",
    "lng": "13.72083"
  },
  {
    "country": "HR",
    "name": "Viškovci",
    "lat": "45.345",
    "lng": "18.46222"
  },
  {
    "country": "HR",
    "name": "Vis",
    "lat": "43.06194",
    "lng": "16.18306"
  },
  {
    "country": "HR",
    "name": "Virovitica",
    "lat": "45.83194",
    "lng": "17.38389"
  },
  {
    "country": "HR",
    "name": "Virje",
    "lat": "46.06722",
    "lng": "16.99"
  },
  {
    "country": "HR",
    "name": "Vir",
    "lat": "44.30306",
    "lng": "15.08528"
  },
  {
    "country": "HR",
    "name": "Vinkovci",
    "lat": "45.28833",
    "lng": "18.80472"
  },
  {
    "country": "HR",
    "name": "Vinica",
    "lat": "46.33611",
    "lng": "16.14944"
  },
  {
    "country": "HR",
    "name": "Vinež",
    "lat": "45.09806",
    "lng": "14.10694"
  },
  {
    "country": "HR",
    "name": "Viljevo",
    "lat": "45.75139",
    "lng": "18.06306"
  },
  {
    "country": "HR",
    "name": "Vidovec",
    "lat": "46.28333",
    "lng": "16.24111"
  },
  {
    "country": "HR",
    "name": "Velimirovac",
    "lat": "45.52361",
    "lng": "18.10944"
  },
  {
    "country": "HR",
    "name": "Veliko Trojstvo",
    "lat": "45.93556",
    "lng": "16.93417"
  },
  {
    "country": "HR",
    "name": "Veliko Trgovišće",
    "lat": "46",
    "lng": "15.85"
  },
  {
    "country": "HR",
    "name": "Veliki Grđevac",
    "lat": "45.75028",
    "lng": "17.0475"
  },
  {
    "country": "HR",
    "name": "Veliki Drvenik",
    "lat": "43.45",
    "lng": "16.15"
  },
  {
    "country": "HR",
    "name": "Veliki Bukovec",
    "lat": "46.29444",
    "lng": "16.71306"
  },
  {
    "country": "HR",
    "name": "Velika Trnovitica",
    "lat": "45.6825",
    "lng": "16.95389"
  },
  {
    "country": "HR",
    "name": "Velika Pisanica",
    "lat": "45.8016",
    "lng": "17.06551"
  },
  {
    "country": "HR",
    "name": "Velika Ostrna",
    "lat": "45.78752",
    "lng": "16.28139"
  },
  {
    "country": "HR",
    "name": "Velika Mlaka",
    "lat": "45.73639",
    "lng": "16.03111"
  },
  {
    "country": "HR",
    "name": "Velika Ludina",
    "lat": "45.6",
    "lng": "16.6"
  },
  {
    "country": "HR",
    "name": "Velika Kopanica",
    "lat": "45.15611",
    "lng": "18.39306"
  },
  {
    "country": "HR",
    "name": "Velika Gorica",
    "lat": "45.7125",
    "lng": "16.07556"
  },
  {
    "country": "HR",
    "name": "Velika",
    "lat": "45.45444",
    "lng": "17.66139"
  },
  {
    "country": "HR",
    "name": "Vela Luka",
    "lat": "42.96333",
    "lng": "16.7225"
  },
  {
    "country": "HR",
    "name": "Varaždinske Toplice",
    "lat": "46.20917",
    "lng": "16.41917"
  },
  {
    "country": "HR",
    "name": "Varaždin",
    "lat": "46.30444",
    "lng": "16.33778"
  },
  {
    "country": "HR",
    "name": "Valpovo",
    "lat": "45.66083",
    "lng": "18.41861"
  },
  {
    "country": "HR",
    "name": "Unešić",
    "lat": "43.74056",
    "lng": "16.18972"
  },
  {
    "country": "HR",
    "name": "Umag",
    "lat": "45.43139",
    "lng": "13.52389"
  },
  {
    "country": "HR",
    "name": "Ugljan",
    "lat": "44.13083",
    "lng": "15.10306"
  },
  {
    "country": "HR",
    "name": "Udbina",
    "lat": "44.53056",
    "lng": "15.76556"
  },
  {
    "country": "HR",
    "name": "Tužno",
    "lat": "46.25667",
    "lng": "16.235"
  },
  {
    "country": "HR",
    "name": "Turjaci",
    "lat": "43.65",
    "lng": "16.66917"
  },
  {
    "country": "HR",
    "name": "Turanj",
    "lat": "43.97111",
    "lng": "15.41139"
  },
  {
    "country": "HR",
    "name": "Tuhelj",
    "lat": "46.07694",
    "lng": "15.74722"
  },
  {
    "country": "HR",
    "name": "Tučepi",
    "lat": "43.27222",
    "lng": "17.05444"
  },
  {
    "country": "HR",
    "name": "Trpinja",
    "lat": "45.41917",
    "lng": "18.89917"
  },
  {
    "country": "HR",
    "name": "Trpanj",
    "lat": "43.0075",
    "lng": "17.275"
  },
  {
    "country": "HR",
    "name": "Trogir",
    "lat": "43.5125",
    "lng": "16.25167"
  },
  {
    "country": "HR",
    "name": "Trnovec Bartolovečki",
    "lat": "46.29472",
    "lng": "16.39889"
  },
  {
    "country": "HR",
    "name": "Trnava",
    "lat": "45.26139",
    "lng": "18.25306"
  },
  {
    "country": "HR",
    "name": "Trilj",
    "lat": "43.61833",
    "lng": "16.72417"
  },
  {
    "country": "HR",
    "name": "Tribunj",
    "lat": "43.75547",
    "lng": "15.74444"
  },
  {
    "country": "HR",
    "name": "Tovarnik",
    "lat": "45.165",
    "lng": "19.15194"
  },
  {
    "country": "HR",
    "name": "Tounj",
    "lat": "45.25145",
    "lng": "15.3255"
  },
  {
    "country": "HR",
    "name": "Tordinci",
    "lat": "45.37028",
    "lng": "18.795"
  },
  {
    "country": "HR",
    "name": "Topusko",
    "lat": "45.29306",
    "lng": "15.97222"
  },
  {
    "country": "HR",
    "name": "Tompojevci",
    "lat": "45.23333",
    "lng": "19.09194"
  },
  {
    "country": "HR",
    "name": "Korenica",
    "lat": "44.74389",
    "lng": "15.70972"
  },
  {
    "country": "HR",
    "name": "Tinjan",
    "lat": "45.21806",
    "lng": "13.83944"
  },
  {
    "country": "HR",
    "name": "Tisno",
    "lat": "43.80417",
    "lng": "15.64333"
  },
  {
    "country": "HR",
    "name": "Tenja",
    "lat": "45.49806",
    "lng": "18.74722"
  },
  {
    "country": "HR",
    "name": "Tar",
    "lat": "45.30083",
    "lng": "13.62528"
  },
  {
    "country": "HR",
    "name": "Svetvinčenat",
    "lat": "45.08806",
    "lng": "13.88361"
  },
  {
    "country": "HR",
    "name": "Sveti Petar u Šumi",
    "lat": "45.18361",
    "lng": "13.86833"
  },
  {
    "country": "HR",
    "name": "Sveti Martin na Muri",
    "lat": "46.52694",
    "lng": "16.375"
  },
  {
    "country": "HR",
    "name": "Sveti Ilija",
    "lat": "46.24694",
    "lng": "16.32528"
  },
  {
    "country": "HR",
    "name": "Sveti Ðurđ",
    "lat": "46.28444",
    "lng": "16.60417"
  },
  {
    "country": "HR",
    "name": "Sveta Nedjelja",
    "lat": "45.79833",
    "lng": "15.78056"
  },
  {
    "country": "HR",
    "name": "Sveta Marija",
    "lat": "46.33556",
    "lng": "16.74194"
  },
  {
    "country": "HR",
    "name": "Sutivan",
    "lat": "43.38583",
    "lng": "16.47694"
  },
  {
    "country": "HR",
    "name": "Supetarska Draga",
    "lat": "44.7975",
    "lng": "14.72472"
  },
  {
    "country": "HR",
    "name": "Supetar",
    "lat": "43.38417",
    "lng": "16.55083"
  },
  {
    "country": "HR",
    "name": "Sunja",
    "lat": "45.3685",
    "lng": "16.56702"
  },
  {
    "country": "HR",
    "name": "Sukošan",
    "lat": "44.05",
    "lng": "15.31667"
  },
  {
    "country": "HR",
    "name": "Suhopolje",
    "lat": "45.79972",
    "lng": "17.49917"
  },
  {
    "country": "HR",
    "name": "Sućuraj",
    "lat": "43.12528",
    "lng": "17.18611"
  },
  {
    "country": "HR",
    "name": "Strmec",
    "lat": "45.70843",
    "lng": "15.91674"
  },
  {
    "country": "HR",
    "name": "Strizivojna",
    "lat": "45.22611",
    "lng": "18.42389"
  },
  {
    "country": "HR",
    "name": "Štrigova",
    "lat": "46.50222",
    "lng": "16.28833"
  },
  {
    "country": "HR",
    "name": "Strahoninec",
    "lat": "46.36889",
    "lng": "16.415"
  },
  {
    "country": "HR",
    "name": "Ston",
    "lat": "42.83861",
    "lng": "17.69639"
  },
  {
    "country": "HR",
    "name": "Stobreč",
    "lat": "43.5025",
    "lng": "16.52222"
  },
  {
    "country": "HR",
    "name": "Štitar",
    "lat": "45.09556",
    "lng": "18.64028"
  },
  {
    "country": "HR",
    "name": "Štefanje",
    "lat": "45.80472",
    "lng": "16.72028"
  },
  {
    "country": "HR",
    "name": "Staro Petrovo Selo",
    "lat": "45.23083",
    "lng": "17.52028"
  },
  {
    "country": "HR",
    "name": "Stari Perkovci",
    "lat": "45.2175",
    "lng": "18.34861"
  },
  {
    "country": "HR",
    "name": "Stari Mikanovci",
    "lat": "45.28167",
    "lng": "18.5425"
  },
  {
    "country": "HR",
    "name": "Stari Jankovci",
    "lat": "45.26194",
    "lng": "18.91444"
  },
  {
    "country": "HR",
    "name": "Starigrad",
    "lat": "44.29601",
    "lng": "15.43865"
  },
  {
    "country": "HR",
    "name": "Stari Grad",
    "lat": "43.18472",
    "lng": "16.59528"
  },
  {
    "country": "HR",
    "name": "Stara Gradiška",
    "lat": "45.14861",
    "lng": "17.24667"
  },
  {
    "country": "HR",
    "name": "Gradina",
    "lat": "45.855",
    "lng": "17.50722"
  },
  {
    "country": "HR",
    "name": "Stankovci",
    "lat": "43.90972",
    "lng": "15.69972"
  },
  {
    "country": "HR",
    "name": "Srinjine",
    "lat": "43.48333",
    "lng": "16.6"
  },
  {
    "country": "HR",
    "name": "Srebreno",
    "lat": "42.62333",
    "lng": "18.19611"
  },
  {
    "country": "HR",
    "name": "Sračinec",
    "lat": "46.32944",
    "lng": "16.27889"
  },
  {
    "country": "HR",
    "name": "Split",
    "lat": "43.50891",
    "lng": "16.43915"
  },
  {
    "country": "HR",
    "name": "Špišić-Bukovica",
    "lat": "45.85722",
    "lng": "17.29944"
  },
  {
    "country": "HR",
    "name": "Sopje",
    "lat": "45.80111",
    "lng": "17.7425"
  },
  {
    "country": "HR",
    "name": "Soljani",
    "lat": "44.95028",
    "lng": "18.97028"
  },
  {
    "country": "HR",
    "name": "Solin",
    "lat": "43.5432",
    "lng": "16.49314"
  },
  {
    "country": "HR",
    "name": "Sokolovac",
    "lat": "46.11083",
    "lng": "16.70639"
  },
  {
    "country": "HR",
    "name": "Šodolovci",
    "lat": "45.4",
    "lng": "18.62028"
  },
  {
    "country": "HR",
    "name": "Smokvica",
    "lat": "42.93056",
    "lng": "16.89639"
  },
  {
    "country": "HR",
    "name": "Slunj",
    "lat": "45.11507",
    "lng": "15.58458"
  },
  {
    "country": "HR",
    "name": "Slobodnica",
    "lat": "45.16222",
    "lng": "17.93278"
  },
  {
    "country": "HR",
    "name": "Slavonski Brod",
    "lat": "45.16028",
    "lng": "18.01556"
  },
  {
    "country": "HR",
    "name": "Požega",
    "lat": "45.34028",
    "lng": "17.68528"
  },
  {
    "country": "HR",
    "name": "Slatine",
    "lat": "43.49944",
    "lng": "16.33333"
  },
  {
    "country": "HR",
    "name": "Slano",
    "lat": "42.78611",
    "lng": "17.89194"
  },
  {
    "country": "HR",
    "name": "Škrljevo",
    "lat": "45.32053",
    "lng": "14.53268"
  },
  {
    "country": "HR",
    "name": "Skradin",
    "lat": "43.82028",
    "lng": "15.92361"
  },
  {
    "country": "HR",
    "name": "Skrad",
    "lat": "45.42778",
    "lng": "14.91111"
  },
  {
    "country": "HR",
    "name": "Škabrnje",
    "lat": "44.09139",
    "lng": "15.45389"
  },
  {
    "country": "HR",
    "name": "Sisak",
    "lat": "45.46611",
    "lng": "16.37833"
  },
  {
    "country": "HR",
    "name": "Široko Polje",
    "lat": "45.40528",
    "lng": "18.4725"
  },
  {
    "country": "HR",
    "name": "Sirač",
    "lat": "45.52333",
    "lng": "17.255"
  },
  {
    "country": "HR",
    "name": "Sinj",
    "lat": "43.70361",
    "lng": "16.63944"
  },
  {
    "country": "HR",
    "name": "Sikirevci",
    "lat": "45.10889",
    "lng": "18.46444"
  },
  {
    "country": "HR",
    "name": "Sigetec",
    "lat": "46.18833",
    "lng": "16.93583"
  },
  {
    "country": "HR",
    "name": "Sibinj",
    "lat": "45.19167",
    "lng": "17.90806"
  },
  {
    "country": "HR",
    "name": "Šibenik",
    "lat": "43.72722",
    "lng": "15.90583"
  },
  {
    "country": "HR",
    "name": "Sesvete",
    "lat": "45.83111",
    "lng": "16.11639"
  },
  {
    "country": "HR",
    "name": "Šestanovac",
    "lat": "43.45444",
    "lng": "16.91139"
  },
  {
    "country": "HR",
    "name": "Šenkovec",
    "lat": "46.40889",
    "lng": "16.42167"
  },
  {
    "country": "HR",
    "name": "Senj",
    "lat": "44.98944",
    "lng": "14.90583"
  },
  {
    "country": "HR",
    "name": "Semeljci",
    "lat": "45.36056",
    "lng": "18.54361"
  },
  {
    "country": "HR",
    "name": "Selnica",
    "lat": "46.49307",
    "lng": "16.38937"
  },
  {
    "country": "HR",
    "name": "Selce",
    "lat": "45.15639",
    "lng": "14.72111"
  },
  {
    "country": "HR",
    "name": "Selca",
    "lat": "43.29722",
    "lng": "16.85083"
  },
  {
    "country": "HR",
    "name": "Satnica Ðakovačka",
    "lat": "45.35583",
    "lng": "18.37806"
  },
  {
    "country": "HR",
    "name": "Sarvaš",
    "lat": "45.52722",
    "lng": "18.8375"
  },
  {
    "country": "HR",
    "name": "Šandrovac",
    "lat": "45.90556",
    "lng": "17.02111"
  },
  {
    "country": "HR",
    "name": "Samobor",
    "lat": "45.80306",
    "lng": "15.71806"
  },
  {
    "country": "HR",
    "name": "Slavonski Šamac",
    "lat": "45.06667",
    "lng": "18.48889"
  },
  {
    "country": "HR",
    "name": "Sali",
    "lat": "43.93972",
    "lng": "15.16333"
  },
  {
    "country": "HR",
    "name": "Saborsko",
    "lat": "44.98333",
    "lng": "15.47806"
  },
  {
    "country": "HR",
    "name": "Ružić",
    "lat": "43.82412",
    "lng": "16.25668"
  },
  {
    "country": "HR",
    "name": "Ruščica",
    "lat": "45.14667",
    "lng": "18.07944"
  },
  {
    "country": "HR",
    "name": "Runović",
    "lat": "43.37667",
    "lng": "17.23667"
  },
  {
    "country": "HR",
    "name": "Rugvica",
    "lat": "45.73611",
    "lng": "16.23306"
  },
  {
    "country": "HR",
    "name": "Rude",
    "lat": "45.76667",
    "lng": "15.66667"
  },
  {
    "country": "HR",
    "name": "Rubeši",
    "lat": "45.36694",
    "lng": "14.34806"
  },
  {
    "country": "HR",
    "name": "Rovišće",
    "lat": "45.94472",
    "lng": "16.735"
  },
  {
    "country": "HR",
    "name": "Rovinj",
    "lat": "45.08",
    "lng": "13.64"
  },
  {
    "country": "HR",
    "name": "Rokovci",
    "lat": "45.23111",
    "lng": "18.74389"
  },
  {
    "country": "HR",
    "name": "Rogoznica",
    "lat": "43.52472",
    "lng": "15.97"
  },
  {
    "country": "HR",
    "name": "Rijeka",
    "lat": "45.32673",
    "lng": "14.44241"
  },
  {
    "country": "HR",
    "name": "Ribnik",
    "lat": "45.57944",
    "lng": "15.35139"
  },
  {
    "country": "HR",
    "name": "Rezovac",
    "lat": "45.78333",
    "lng": "17.41667"
  },
  {
    "country": "HR",
    "name": "Retkovci",
    "lat": "45.23333",
    "lng": "18.65306"
  },
  {
    "country": "HR",
    "name": "Rešetari",
    "lat": "45.26232",
    "lng": "17.42346"
  },
  {
    "country": "HR",
    "name": "Repušnica",
    "lat": "45.49278",
    "lng": "16.73083"
  },
  {
    "country": "HR",
    "name": "Remetinec",
    "lat": "46.18528",
    "lng": "16.32778"
  },
  {
    "country": "HR",
    "name": "Reka",
    "lat": "46.13028",
    "lng": "16.76694"
  },
  {
    "country": "HR",
    "name": "Ražanac",
    "lat": "44.28194",
    "lng": "15.34806"
  },
  {
    "country": "HR",
    "name": "Ravna Gora",
    "lat": "45.37278",
    "lng": "14.93528"
  },
  {
    "country": "HR",
    "name": "Rasinja",
    "lat": "46.18389",
    "lng": "16.70667"
  },
  {
    "country": "HR",
    "name": "Raša",
    "lat": "45.08028",
    "lng": "14.07889"
  },
  {
    "country": "HR",
    "name": "Rakov Potok",
    "lat": "45.73806",
    "lng": "15.79722"
  },
  {
    "country": "HR",
    "name": "Rakovica",
    "lat": "44.99315",
    "lng": "15.65028"
  },
  {
    "country": "HR",
    "name": "Rakovec",
    "lat": "45.93028",
    "lng": "16.3225"
  },
  {
    "country": "HR",
    "name": "Rakitje",
    "lat": "45.79389",
    "lng": "15.82222"
  },
  {
    "country": "HR",
    "name": "Radoboj",
    "lat": "46.16639",
    "lng": "15.92361"
  },
  {
    "country": "HR",
    "name": "Rabac",
    "lat": "45.07944",
    "lng": "14.1575"
  },
  {
    "country": "HR",
    "name": "Rab",
    "lat": "44.75694",
    "lng": "14.76083"
  },
  {
    "country": "HR",
    "name": "Punitovci",
    "lat": "45.43306",
    "lng": "18.41639"
  },
  {
    "country": "HR",
    "name": "Punat",
    "lat": "45.01472",
    "lng": "14.62889"
  },
  {
    "country": "HR",
    "name": "Pula",
    "lat": "44.86833",
    "lng": "13.84806"
  },
  {
    "country": "HR",
    "name": "Pučišća",
    "lat": "43.34778",
    "lng": "16.73389"
  },
  {
    "country": "HR",
    "name": "Privlaka",
    "lat": "45.19472",
    "lng": "18.8375"
  },
  {
    "country": "HR",
    "name": "Privlaka",
    "lat": "44.26667",
    "lng": "15.13333"
  },
  {
    "country": "HR",
    "name": "Primošten",
    "lat": "43.58632",
    "lng": "15.92302"
  },
  {
    "country": "HR",
    "name": "Primorski Dolac",
    "lat": "43.63083",
    "lng": "16.17611"
  },
  {
    "country": "HR",
    "name": "Prigorje Brdovečko",
    "lat": "45.87944",
    "lng": "15.73806"
  },
  {
    "country": "HR",
    "name": "Pridraga",
    "lat": "44.16667",
    "lng": "15.56667"
  },
  {
    "country": "HR",
    "name": "Pribislavec",
    "lat": "46.3925",
    "lng": "16.4825"
  },
  {
    "country": "HR",
    "name": "Prgomet",
    "lat": "43.60631",
    "lng": "16.22912"
  },
  {
    "country": "HR",
    "name": "Prelog",
    "lat": "46.335",
    "lng": "16.61556"
  },
  {
    "country": "HR",
    "name": "Osljak",
    "lat": "44.07667",
    "lng": "15.20722"
  },
  {
    "country": "HR",
    "name": "Pregrada",
    "lat": "46.16417",
    "lng": "15.75083"
  },
  {
    "country": "HR",
    "name": "Predavac",
    "lat": "45.93583",
    "lng": "16.78333"
  },
  {
    "country": "HR",
    "name": "Povljana",
    "lat": "44.34667",
    "lng": "15.11556"
  },
  {
    "country": "HR",
    "name": "Postira",
    "lat": "43.37551",
    "lng": "16.63091"
  },
  {
    "country": "HR",
    "name": "Posedarje",
    "lat": "44.21361",
    "lng": "15.47667"
  },
  {
    "country": "HR",
    "name": "Poreč",
    "lat": "45.22567",
    "lng": "13.59511"
  },
  {
    "country": "HR",
    "name": "Popovača",
    "lat": "45.56972",
    "lng": "16.625"
  },
  {
    "country": "HR",
    "name": "Popovac",
    "lat": "45.80917",
    "lng": "18.65833"
  },
  {
    "country": "HR",
    "name": "Poljanica Bistranska",
    "lat": "45.90076",
    "lng": "15.87584"
  },
  {
    "country": "HR",
    "name": "Poličnik",
    "lat": "44.17806",
    "lng": "15.37556"
  },
  {
    "country": "HR",
    "name": "Polača",
    "lat": "44.01833",
    "lng": "15.5175"
  },
  {
    "country": "HR",
    "name": "Pokupsko",
    "lat": "45.48722",
    "lng": "15.99333"
  },
  {
    "country": "HR",
    "name": "Pojatno",
    "lat": "45.905",
    "lng": "15.80056"
  },
  {
    "country": "HR",
    "name": "Podvinje",
    "lat": "45.19028",
    "lng": "18.02694"
  },
  {
    "country": "HR",
    "name": "Podturen",
    "lat": "46.46472",
    "lng": "16.54306"
  },
  {
    "country": "HR",
    "name": "Podstrana",
    "lat": "43.48668",
    "lng": "16.55013"
  },
  {
    "country": "HR",
    "name": "Podravske Sesvete",
    "lat": "46.005",
    "lng": "17.21167"
  },
  {
    "country": "HR",
    "name": "Slatina",
    "lat": "45.70333",
    "lng": "17.70278"
  },
  {
    "country": "HR",
    "name": "Podhum",
    "lat": "45.38722",
    "lng": "14.47944"
  },
  {
    "country": "HR",
    "name": "Podgorač",
    "lat": "45.45861",
    "lng": "18.22278"
  },
  {
    "country": "HR",
    "name": "Podgora",
    "lat": "43.24333",
    "lng": "17.07722"
  },
  {
    "country": "HR",
    "name": "Podcrkavlje",
    "lat": "45.22389",
    "lng": "18.01"
  },
  {
    "country": "HR",
    "name": "Ploče",
    "lat": "43.05611",
    "lng": "17.43278"
  },
  {
    "country": "HR",
    "name": "Pleternica",
    "lat": "45.28861",
    "lng": "17.80639"
  },
  {
    "country": "HR",
    "name": "Plaški",
    "lat": "45.07639",
    "lng": "15.36806"
  },
  {
    "country": "HR",
    "name": "Pitomača",
    "lat": "45.95056",
    "lng": "17.22944"
  },
  {
    "country": "HR",
    "name": "Piškorevci",
    "lat": "45.25528",
    "lng": "18.40417"
  },
  {
    "country": "HR",
    "name": "Pisarovina",
    "lat": "45.58639",
    "lng": "15.85917"
  },
  {
    "country": "HR",
    "name": "Pirovac",
    "lat": "43.81917",
    "lng": "15.67278"
  },
  {
    "country": "HR",
    "name": "Pićan",
    "lat": "45.20611",
    "lng": "14.04278"
  },
  {
    "country": "HR",
    "name": "Petrovsko",
    "lat": "46.16806",
    "lng": "15.84083"
  },
  {
    "country": "HR",
    "name": "Petrinja",
    "lat": "45.4375",
    "lng": "16.29"
  },
  {
    "country": "HR",
    "name": "Petrijevci",
    "lat": "45.61278",
    "lng": "18.53528"
  },
  {
    "country": "HR",
    "name": "Petrijanec",
    "lat": "46.34917",
    "lng": "16.225"
  },
  {
    "country": "HR",
    "name": "Petlovac",
    "lat": "45.75833",
    "lng": "18.52806"
  },
  {
    "country": "HR",
    "name": "Peteranec",
    "lat": "46.19222",
    "lng": "16.89167"
  },
  {
    "country": "HR",
    "name": "Perušić",
    "lat": "44.64944",
    "lng": "15.38333"
  },
  {
    "country": "HR",
    "name": "Peklenica",
    "lat": "46.49528",
    "lng": "16.47611"
  },
  {
    "country": "HR",
    "name": "Pazin",
    "lat": "45.24028",
    "lng": "13.93667"
  },
  {
    "country": "HR",
    "name": "Pašman",
    "lat": "43.9575",
    "lng": "15.385"
  },
  {
    "country": "HR",
    "name": "Pakrac",
    "lat": "45.43639",
    "lng": "17.18889"
  },
  {
    "country": "HR",
    "name": "Pakoštane",
    "lat": "43.91222",
    "lng": "15.50889"
  },
  {
    "country": "HR",
    "name": "Pag",
    "lat": "44.445",
    "lng": "15.0575"
  },
  {
    "country": "HR",
    "name": "Ozalj",
    "lat": "45.60667",
    "lng": "15.46194"
  },
  {
    "country": "HR",
    "name": "Otok",
    "lat": "45.14667",
    "lng": "18.88389"
  },
  {
    "country": "HR",
    "name": "Otok",
    "lat": "43.68643",
    "lng": "16.73329"
  },
  {
    "country": "HR",
    "name": "Otočac",
    "lat": "44.86944",
    "lng": "15.2375"
  },
  {
    "country": "HR",
    "name": "Oštarije",
    "lat": "45.22472",
    "lng": "15.27333"
  },
  {
    "country": "HR",
    "name": "Osijek",
    "lat": "45.55111",
    "lng": "18.69389"
  },
  {
    "country": "HR",
    "name": "Oroslavje",
    "lat": "45.99672",
    "lng": "15.91507"
  },
  {
    "country": "HR",
    "name": "Orle",
    "lat": "45.68333",
    "lng": "16.23333"
  },
  {
    "country": "HR",
    "name": "Oriovac",
    "lat": "45.16611",
    "lng": "17.76"
  },
  {
    "country": "HR",
    "name": "Orešje",
    "lat": "45.81618",
    "lng": "15.80246"
  },
  {
    "country": "HR",
    "name": "Orehovica",
    "lat": "46.33167",
    "lng": "16.50694"
  },
  {
    "country": "HR",
    "name": "Sveti Petar Orehovec",
    "lat": "46.07556",
    "lng": "16.45167"
  },
  {
    "country": "HR",
    "name": "Orebić",
    "lat": "42.98556",
    "lng": "17.17472"
  },
  {
    "country": "HR",
    "name": "Orahovica",
    "lat": "45.54",
    "lng": "17.88472"
  },
  {
    "country": "HR",
    "name": "Opuzen",
    "lat": "43.01528",
    "lng": "17.56556"
  },
  {
    "country": "HR",
    "name": "Oprtalj",
    "lat": "45.38167",
    "lng": "13.82611"
  },
  {
    "country": "HR",
    "name": "Oprisavci",
    "lat": "45.15111",
    "lng": "18.22972"
  },
  {
    "country": "HR",
    "name": "Opatija",
    "lat": "45.33771",
    "lng": "14.30515"
  },
  {
    "country": "HR",
    "name": "Omišalj",
    "lat": "45.21134",
    "lng": "14.55495"
  },
  {
    "country": "HR",
    "name": "Omiš",
    "lat": "43.44472",
    "lng": "16.68861"
  },
  {
    "country": "HR",
    "name": "Okučani",
    "lat": "45.26034",
    "lng": "17.19925"
  },
  {
    "country": "HR",
    "name": "Oklaj",
    "lat": "43.95056",
    "lng": "16.08222"
  },
  {
    "country": "HR",
    "name": "Ogulin",
    "lat": "45.26611",
    "lng": "15.22861"
  },
  {
    "country": "HR",
    "name": "Odra",
    "lat": "45.72979",
    "lng": "15.9924"
  },
  {
    "country": "HR",
    "name": "Obrovac",
    "lat": "44.20056",
    "lng": "15.68222"
  },
  {
    "country": "HR",
    "name": "Nuštar",
    "lat": "45.3325",
    "lng": "18.84139"
  },
  {
    "country": "HR",
    "name": "Novska",
    "lat": "45.34056",
    "lng": "16.97694"
  },
  {
    "country": "HR",
    "name": "Novo Selo Rok",
    "lat": "46.42839",
    "lng": "16.46215"
  },
  {
    "country": "HR",
    "name": "Novoselec",
    "lat": "45.6525",
    "lng": "16.53639"
  },
  {
    "country": "HR",
    "name": "Novo Čiče",
    "lat": "45.7",
    "lng": "16.11667"
  },
  {
    "country": "HR",
    "name": "Novi Vinodolski",
    "lat": "45.12806",
    "lng": "14.78889"
  },
  {
    "country": "HR",
    "name": "Novi Marof",
    "lat": "46.16194",
    "lng": "16.33028"
  },
  {
    "country": "HR",
    "name": "Novigrad Podravski",
    "lat": "46.07806",
    "lng": "16.95389"
  },
  {
    "country": "HR",
    "name": "Novigrad",
    "lat": "45.315",
    "lng": "13.55806"
  },
  {
    "country": "HR",
    "name": "Novigrad",
    "lat": "44.18389",
    "lng": "15.55417"
  },
  {
    "country": "HR",
    "name": "Novi Golubovec",
    "lat": "46.17252",
    "lng": "15.9809"
  },
  {
    "country": "HR",
    "name": "Nova Rača",
    "lat": "45.79694",
    "lng": "16.95361"
  },
  {
    "country": "HR",
    "name": "Novalja",
    "lat": "44.55778",
    "lng": "14.88667"
  },
  {
    "country": "HR",
    "name": "Nova Kapela",
    "lat": "45.19889",
    "lng": "17.63917"
  },
  {
    "country": "HR",
    "name": "Nova Gradiška",
    "lat": "45.255",
    "lng": "17.38306"
  },
  {
    "country": "HR",
    "name": "Nova Bukovica",
    "lat": "45.66472",
    "lng": "17.76694"
  },
  {
    "country": "HR",
    "name": "Njivice",
    "lat": "45.15806",
    "lng": "14.53861"
  },
  {
    "country": "HR",
    "name": "Nijemci",
    "lat": "45.14028",
    "lng": "19.03556"
  },
  {
    "country": "HR",
    "name": "Nerežišće",
    "lat": "43.33111",
    "lng": "16.57861"
  },
  {
    "country": "HR",
    "name": "Negoslavci",
    "lat": "45.27944",
    "lng": "18.99667"
  },
  {
    "country": "HR",
    "name": "Nedeščina",
    "lat": "45.14",
    "lng": "14.11194"
  },
  {
    "country": "HR",
    "name": "Nedeljanec",
    "lat": "46.28778",
    "lng": "16.28333"
  },
  {
    "country": "HR",
    "name": "Nedelišće",
    "lat": "46.37583",
    "lng": "16.3875"
  },
  {
    "country": "HR",
    "name": "Našice",
    "lat": "45.48861",
    "lng": "18.08778"
  },
  {
    "country": "HR",
    "name": "Mursko Središće",
    "lat": "46.50944",
    "lng": "16.44111"
  },
  {
    "country": "HR",
    "name": "Murter",
    "lat": "43.82043",
    "lng": "15.58988"
  },
  {
    "country": "HR",
    "name": "Mrkopalj",
    "lat": "45.31556",
    "lng": "14.85528"
  },
  {
    "country": "HR",
    "name": "Mravince",
    "lat": "43.53333",
    "lng": "16.52194"
  },
  {
    "country": "HR",
    "name": "Mraclin",
    "lat": "45.66667",
    "lng": "16.09556"
  },
  {
    "country": "HR",
    "name": "Motovun",
    "lat": "45.33667",
    "lng": "13.82861"
  },
  {
    "country": "HR",
    "name": "Mošćenička Draga",
    "lat": "45.23778",
    "lng": "14.25222"
  },
  {
    "country": "HR",
    "name": "Molve",
    "lat": "46.10917",
    "lng": "17.03167"
  },
  {
    "country": "HR",
    "name": "Mokošica",
    "lat": "42.67556",
    "lng": "18.09028"
  },
  {
    "country": "HR",
    "name": "Mirkovci",
    "lat": "45.26972",
    "lng": "18.85111"
  },
  {
    "country": "HR",
    "name": "Ðulovac",
    "lat": "45.66611",
    "lng": "17.43333"
  },
  {
    "country": "HR",
    "name": "Milna",
    "lat": "43.32667",
    "lng": "16.45083"
  },
  {
    "country": "HR",
    "name": "Mikleuš",
    "lat": "45.61861",
    "lng": "17.80389"
  },
  {
    "country": "HR",
    "name": "Mihovljan",
    "lat": "46.40861",
    "lng": "16.44806"
  },
  {
    "country": "HR",
    "name": "Mihovljan",
    "lat": "46.13306",
    "lng": "15.97222"
  },
  {
    "country": "HR",
    "name": "Mičevec",
    "lat": "45.75",
    "lng": "16.06667"
  },
  {
    "country": "HR",
    "name": "Metković",
    "lat": "43.05417",
    "lng": "17.64833"
  },
  {
    "country": "HR",
    "name": "Medulin",
    "lat": "44.8225",
    "lng": "13.935"
  },
  {
    "country": "HR",
    "name": "Matulji",
    "lat": "45.36167",
    "lng": "14.325"
  },
  {
    "country": "HR",
    "name": "Maruševec",
    "lat": "46.28889",
    "lng": "16.18306"
  },
  {
    "country": "HR",
    "name": "Martin",
    "lat": "45.49222",
    "lng": "18.06667"
  },
  {
    "country": "HR",
    "name": "Martijanec",
    "lat": "46.26583",
    "lng": "16.54"
  },
  {
    "country": "HR",
    "name": "Markušica",
    "lat": "45.37389",
    "lng": "18.70583"
  },
  {
    "country": "HR",
    "name": "Markovac Našički",
    "lat": "45.49389",
    "lng": "18.12556"
  },
  {
    "country": "HR",
    "name": "Marjanci",
    "lat": "45.66694",
    "lng": "18.29222"
  },
  {
    "country": "HR",
    "name": "Marinići",
    "lat": "45.365",
    "lng": "14.39389"
  },
  {
    "country": "HR",
    "name": "Marina",
    "lat": "43.51472",
    "lng": "16.10639"
  },
  {
    "country": "HR",
    "name": "Marina",
    "lat": "43.35",
    "lng": "16.45"
  },
  {
    "country": "HR",
    "name": "Marija Gorica",
    "lat": "45.91097",
    "lng": "15.7277"
  },
  {
    "country": "HR",
    "name": "Marija Bistrica",
    "lat": "46.00611",
    "lng": "16.11111"
  },
  {
    "country": "HR",
    "name": "Marčelji",
    "lat": "45.39611",
    "lng": "14.38944"
  },
  {
    "country": "HR",
    "name": "Marčana",
    "lat": "44.95528",
    "lng": "13.95389"
  },
  {
    "country": "HR",
    "name": "Mali Lošinj",
    "lat": "44.53056",
    "lng": "14.46861"
  },
  {
    "country": "HR",
    "name": "Mali Bukovec",
    "lat": "46.28306",
    "lng": "16.73917"
  },
  {
    "country": "HR",
    "name": "Mala Subotica",
    "lat": "46.37616",
    "lng": "16.52893"
  },
  {
    "country": "HR",
    "name": "Makarska",
    "lat": "43.29694",
    "lng": "17.01778"
  },
  {
    "country": "HR",
    "name": "Mačkovec",
    "lat": "46.42417",
    "lng": "16.43361"
  },
  {
    "country": "HR",
    "name": "Mače",
    "lat": "46.09472",
    "lng": "16.03528"
  },
  {
    "country": "HR",
    "name": "Lužani",
    "lat": "45.16806",
    "lng": "17.70694"
  },
  {
    "country": "HR",
    "name": "Lupoglav",
    "lat": "45.79639",
    "lng": "16.34639"
  },
  {
    "country": "HR",
    "name": "Lumbarda",
    "lat": "42.92278",
    "lng": "17.16722"
  },
  {
    "country": "HR",
    "name": "Lukavec",
    "lat": "45.70444",
    "lng": "15.99"
  },
  {
    "country": "HR",
    "name": "Lukač",
    "lat": "45.8725",
    "lng": "17.41944"
  },
  {
    "country": "HR",
    "name": "Luka",
    "lat": "45.95795",
    "lng": "15.81954"
  },
  {
    "country": "HR",
    "name": "Ludbreg",
    "lat": "46.25194",
    "lng": "16.61472"
  },
  {
    "country": "HR",
    "name": "Lučko",
    "lat": "45.76111",
    "lng": "15.87028"
  },
  {
    "country": "HR",
    "name": "Sveti Lovreč Pazenatički",
    "lat": "45.17583",
    "lng": "13.74194"
  },
  {
    "country": "HR",
    "name": "Lovreć",
    "lat": "43.48761",
    "lng": "16.98632"
  },
  {
    "country": "HR",
    "name": "Lovran",
    "lat": "45.29194",
    "lng": "14.27417"
  },
  {
    "country": "HR",
    "name": "Lovinac",
    "lat": "44.39139",
    "lng": "15.68556"
  },
  {
    "country": "HR",
    "name": "Lovas",
    "lat": "45.22639",
    "lng": "19.17111"
  },
  {
    "country": "HR",
    "name": "Lopatinec",
    "lat": "46.43333",
    "lng": "16.38333"
  },
  {
    "country": "HR",
    "name": "Lopar",
    "lat": "44.8325",
    "lng": "14.73028"
  },
  {
    "country": "HR",
    "name": "Lonjica",
    "lat": "45.855",
    "lng": "16.33"
  },
  {
    "country": "HR",
    "name": "Lokvičič",
    "lat": "43.46345",
    "lng": "17.09155"
  },
  {
    "country": "HR",
    "name": "Lokve",
    "lat": "45.35889",
    "lng": "14.74861"
  },
  {
    "country": "HR",
    "name": "Lobor",
    "lat": "46.15278",
    "lng": "16.06778"
  },
  {
    "country": "HR",
    "name": "Ljubešćica",
    "lat": "46.16667",
    "lng": "16.38333"
  },
  {
    "country": "HR",
    "name": "Ližnjan",
    "lat": "44.82833",
    "lng": "13.95694"
  },
  {
    "country": "HR",
    "name": "Lišane Ostrovičke",
    "lat": "43.96861",
    "lng": "15.77417"
  },
  {
    "country": "HR",
    "name": "Lipik",
    "lat": "45.41139",
    "lng": "17.15222"
  },
  {
    "country": "HR",
    "name": "Martinska Ves",
    "lat": "45.58368",
    "lng": "16.37617"
  },
  {
    "country": "HR",
    "name": "Lički Osik",
    "lat": "44.60389",
    "lng": "15.42472"
  },
  {
    "country": "HR",
    "name": "Levanjska Varoš",
    "lat": "45.31556",
    "lng": "18.18361"
  },
  {
    "country": "HR",
    "name": "Lepoglava",
    "lat": "46.21056",
    "lng": "16.03556"
  },
  {
    "country": "HR",
    "name": "Lekenik",
    "lat": "45.58556",
    "lng": "16.21139"
  },
  {
    "country": "HR",
    "name": "Legrad",
    "lat": "46.2975",
    "lng": "16.85667"
  },
  {
    "country": "HR",
    "name": "Lećevica",
    "lat": "43.64191",
    "lng": "16.34954"
  },
  {
    "country": "HR",
    "name": "Lastovo",
    "lat": "42.76806",
    "lng": "16.90083"
  },
  {
    "country": "HR",
    "name": "Laslovo",
    "lat": "45.415",
    "lng": "18.69611"
  },
  {
    "country": "HR",
    "name": "Lasinja",
    "lat": "45.52806",
    "lng": "15.85911"
  },
  {
    "country": "HR",
    "name": "Lanišće",
    "lat": "45.40722",
    "lng": "14.11639"
  },
  {
    "country": "HR",
    "name": "Ladimirevci",
    "lat": "45.62556",
    "lng": "18.44861"
  },
  {
    "country": "HR",
    "name": "Labin",
    "lat": "45.095",
    "lng": "14.11972"
  },
  {
    "country": "HR",
    "name": "Kutjevo",
    "lat": "45.42611",
    "lng": "17.8825"
  },
  {
    "country": "HR",
    "name": "Kutina",
    "lat": "45.475",
    "lng": "16.78194"
  },
  {
    "country": "HR",
    "name": "Kuševac",
    "lat": "45.34778",
    "lng": "18.42889"
  },
  {
    "country": "HR",
    "name": "Kuršanec",
    "lat": "46.33028",
    "lng": "16.40167"
  },
  {
    "country": "HR",
    "name": "Kumrovec",
    "lat": "46.0775",
    "lng": "15.67556"
  },
  {
    "country": "HR",
    "name": "Kula Norinska",
    "lat": "43.03111",
    "lng": "17.605"
  },
  {
    "country": "HR",
    "name": "Kuče",
    "lat": "45.67694",
    "lng": "16.145"
  },
  {
    "country": "HR",
    "name": "Kućan Marof",
    "lat": "46.28944",
    "lng": "16.37222"
  },
  {
    "country": "HR",
    "name": "Kruševo",
    "lat": "44.18333",
    "lng": "15.65"
  },
  {
    "country": "HR",
    "name": "Kruševica",
    "lat": "45.0775",
    "lng": "18.48278"
  },
  {
    "country": "HR",
    "name": "Kršan",
    "lat": "45.17333",
    "lng": "14.13861"
  },
  {
    "country": "HR",
    "name": "Krnjak",
    "lat": "45.33333",
    "lng": "15.6"
  },
  {
    "country": "HR",
    "name": "Krk",
    "lat": "45.02744",
    "lng": "14.57542"
  },
  {
    "country": "HR",
    "name": "Križevci",
    "lat": "46.02194",
    "lng": "16.5425"
  },
  {
    "country": "HR",
    "name": "Križ",
    "lat": "45.665",
    "lng": "16.52333"
  },
  {
    "country": "HR",
    "name": "Kravarsko",
    "lat": "45.58333",
    "lng": "16.05"
  },
  {
    "country": "HR",
    "name": "Krasica",
    "lat": "45.30972",
    "lng": "14.55556"
  },
  {
    "country": "HR",
    "name": "Krašić",
    "lat": "45.65583",
    "lng": "15.51778"
  },
  {
    "country": "HR",
    "name": "Krapinske Toplice",
    "lat": "46.09333",
    "lng": "15.84333"
  },
  {
    "country": "HR",
    "name": "Krapina",
    "lat": "46.16083",
    "lng": "15.87889"
  },
  {
    "country": "HR",
    "name": "Kraljevica",
    "lat": "45.27395",
    "lng": "14.5683"
  },
  {
    "country": "HR",
    "name": "Kraljevec na Sutli",
    "lat": "45.99106",
    "lng": "15.7247"
  },
  {
    "country": "HR",
    "name": "Kotoriba",
    "lat": "46.355",
    "lng": "16.81806"
  },
  {
    "country": "HR",
    "name": "Košute",
    "lat": "43.63083",
    "lng": "16.695"
  },
  {
    "country": "HR",
    "name": "Kostrena",
    "lat": "45.30111",
    "lng": "14.50556"
  },
  {
    "country": "HR",
    "name": "Majur",
    "lat": "45.255",
    "lng": "16.53194"
  },
  {
    "country": "HR",
    "name": "Hrvatska Kostajnica",
    "lat": "45.23167",
    "lng": "16.53917"
  },
  {
    "country": "HR",
    "name": "Koška",
    "lat": "45.54528",
    "lng": "18.28583"
  },
  {
    "country": "HR",
    "name": "Korčula",
    "lat": "42.96038",
    "lng": "17.13525"
  },
  {
    "country": "HR",
    "name": "Koprivnica",
    "lat": "46.16278",
    "lng": "16.8275"
  },
  {
    "country": "HR",
    "name": "Končanica",
    "lat": "45.63611",
    "lng": "17.16639"
  },
  {
    "country": "HR",
    "name": "Komletinci",
    "lat": "45.14972",
    "lng": "18.94917"
  },
  {
    "country": "HR",
    "name": "Komiža",
    "lat": "43.04306",
    "lng": "16.09306"
  },
  {
    "country": "HR",
    "name": "Komin",
    "lat": "43.04083",
    "lng": "17.53694"
  },
  {
    "country": "HR",
    "name": "Kolan",
    "lat": "44.49417",
    "lng": "14.96139"
  },
  {
    "country": "HR",
    "name": "Knin",
    "lat": "44.04063",
    "lng": "16.19662"
  },
  {
    "country": "HR",
    "name": "Kneževi Vinogradi",
    "lat": "45.75028",
    "lng": "18.73306"
  },
  {
    "country": "HR",
    "name": "Kloštar Podravski",
    "lat": "45.98111",
    "lng": "17.15583"
  },
  {
    "country": "HR",
    "name": "Kloštar Ivanić",
    "lat": "45.74056",
    "lng": "16.42417"
  },
  {
    "country": "HR",
    "name": "Klis",
    "lat": "43.55944",
    "lng": "16.51944"
  },
  {
    "country": "HR",
    "name": "Klinča Sela",
    "lat": "45.69028",
    "lng": "15.74111"
  },
  {
    "country": "HR",
    "name": "Klenovnik",
    "lat": "46.27028",
    "lng": "16.07"
  },
  {
    "country": "HR",
    "name": "Klanjec",
    "lat": "46.04982",
    "lng": "15.74418"
  },
  {
    "country": "HR",
    "name": "Klana",
    "lat": "45.44694",
    "lng": "14.37694"
  },
  {
    "country": "HR",
    "name": "Klakar",
    "lat": "45.09861",
    "lng": "18.13222"
  },
  {
    "country": "HR",
    "name": "Kistanje",
    "lat": "43.98278",
    "lng": "15.965"
  },
  {
    "country": "HR",
    "name": "Kijevo",
    "lat": "43.97725",
    "lng": "16.3571"
  },
  {
    "country": "HR",
    "name": "Kerestinec",
    "lat": "45.7701",
    "lng": "15.80864"
  },
  {
    "country": "HR",
    "name": "Kaštel Sućurac",
    "lat": "43.55028",
    "lng": "16.42639"
  },
  {
    "country": "HR",
    "name": "Kaštel Stari",
    "lat": "43.55",
    "lng": "16.35"
  },
  {
    "country": "HR",
    "name": "Kaštel Štafilić",
    "lat": "43.55",
    "lng": "16.33333"
  },
  {
    "country": "HR",
    "name": "Kaštel Novi",
    "lat": "43.55",
    "lng": "16.33333"
  },
  {
    "country": "HR",
    "name": "Kaštel Lukšić",
    "lat": "43.55528",
    "lng": "16.3675"
  },
  {
    "country": "HR",
    "name": "Kaštel Kambelovac",
    "lat": "43.55",
    "lng": "16.38333"
  },
  {
    "country": "HR",
    "name": "Kaštelir",
    "lat": "45.30333",
    "lng": "13.68528"
  },
  {
    "country": "HR",
    "name": "Kaštel Gomilica",
    "lat": "43.55",
    "lng": "16.4"
  },
  {
    "country": "HR",
    "name": "Kastav",
    "lat": "45.37528",
    "lng": "14.34861"
  },
  {
    "country": "HR",
    "name": "Kašina",
    "lat": "45.91134",
    "lng": "16.12436"
  },
  {
    "country": "HR",
    "name": "Karojba",
    "lat": "45.30083",
    "lng": "13.82306"
  },
  {
    "country": "HR",
    "name": "Karlobag",
    "lat": "44.5275",
    "lng": "15.07389"
  },
  {
    "country": "HR",
    "name": "Karanac",
    "lat": "45.76056",
    "lng": "18.68444"
  },
  {
    "country": "HR",
    "name": "Kaptol",
    "lat": "45.43472",
    "lng": "17.72611"
  },
  {
    "country": "HR",
    "name": "Kapela",
    "lat": "45.98833",
    "lng": "16.85139"
  },
  {
    "country": "HR",
    "name": "Kanfanar",
    "lat": "45.12194",
    "lng": "13.83917"
  },
  {
    "country": "HR",
    "name": "Kamanje",
    "lat": "45.63528",
    "lng": "15.39583"
  },
  {
    "country": "HR",
    "name": "Kalnik",
    "lat": "46.12833",
    "lng": "16.4625"
  },
  {
    "country": "HR",
    "name": "Kalinovac",
    "lat": "46.02944",
    "lng": "17.11556"
  },
  {
    "country": "HR",
    "name": "Kali",
    "lat": "44.06278",
    "lng": "15.20556"
  },
  {
    "country": "HR",
    "name": "Josipovac",
    "lat": "45.58278",
    "lng": "18.58139"
  },
  {
    "country": "HR",
    "name": "Josipdol",
    "lat": "45.185",
    "lng": "15.28667"
  },
  {
    "country": "HR",
    "name": "Ježdovec",
    "lat": "45.78333",
    "lng": "15.85"
  },
  {
    "country": "HR",
    "name": "Jesenice",
    "lat": "44.23",
    "lng": "15.5775"
  },
  {
    "country": "HR",
    "name": "Jesenice",
    "lat": "43.46158",
    "lng": "16.60197"
  },
  {
    "country": "HR",
    "name": "Jelsa",
    "lat": "43.16139",
    "lng": "16.69306"
  },
  {
    "country": "HR",
    "name": "Jelisavac",
    "lat": "45.52889",
    "lng": "18.15611"
  },
  {
    "country": "HR",
    "name": "Jelenje",
    "lat": "45.38611",
    "lng": "14.45111"
  },
  {
    "country": "HR",
    "name": "Jastrebarsko",
    "lat": "45.66833",
    "lng": "15.64861"
  },
  {
    "country": "HR",
    "name": "Jasenovac",
    "lat": "45.27167",
    "lng": "16.91167"
  },
  {
    "country": "HR",
    "name": "Jarmina",
    "lat": "45.31806",
    "lng": "18.72917"
  },
  {
    "country": "HR",
    "name": "Janjina",
    "lat": "42.92528",
    "lng": "17.42833"
  },
  {
    "country": "HR",
    "name": "Jalžabet",
    "lat": "46.26083",
    "lng": "16.475"
  },
  {
    "country": "HR",
    "name": "Jalkovec",
    "lat": "46.28083",
    "lng": "16.31972"
  },
  {
    "country": "HR",
    "name": "Jakšić",
    "lat": "45.35806",
    "lng": "17.76389"
  },
  {
    "country": "HR",
    "name": "Jakovlje",
    "lat": "45.93611",
    "lng": "15.85559"
  },
  {
    "country": "HR",
    "name": "Jagodnjak",
    "lat": "45.69917",
    "lng": "18.57694"
  },
  {
    "country": "HR",
    "name": "Jadranovo",
    "lat": "45.23111",
    "lng": "14.61833"
  },
  {
    "country": "HR",
    "name": "Jablanovec",
    "lat": "45.87583",
    "lng": "15.85361"
  },
  {
    "country": "HR",
    "name": "Ivanska",
    "lat": "45.77889",
    "lng": "16.81194"
  },
  {
    "country": "HR",
    "name": "Ivanovec",
    "lat": "46.36833",
    "lng": "16.47667"
  },
  {
    "country": "HR",
    "name": "Ivankovo",
    "lat": "45.28861",
    "lng": "18.68389"
  },
  {
    "country": "HR",
    "name": "Ivanić-Grad",
    "lat": "45.70833",
    "lng": "16.39694"
  },
  {
    "country": "HR",
    "name": "Ivanec",
    "lat": "46.22306",
    "lng": "16.12"
  },
  {
    "country": "HR",
    "name": "Imotski",
    "lat": "43.44667",
    "lng": "17.21667"
  },
  {
    "country": "HR",
    "name": "Ilok",
    "lat": "45.22222",
    "lng": "19.37694"
  },
  {
    "country": "HR",
    "name": "Hvar",
    "lat": "43.1725",
    "lng": "16.44278"
  },
  {
    "country": "HR",
    "name": "Hum na Sutli",
    "lat": "46.21139",
    "lng": "15.69083"
  },
  {
    "country": "HR",
    "name": "Breznički Hum",
    "lat": "46.10722",
    "lng": "16.27667"
  },
  {
    "country": "HR",
    "name": "Hrvace",
    "lat": "43.76333",
    "lng": "16.615"
  },
  {
    "country": "HR",
    "name": "Hreljin",
    "lat": "45.2825",
    "lng": "14.59917"
  },
  {
    "country": "HR",
    "name": "Hrašćina",
    "lat": "46.1125",
    "lng": "16.2275"
  },
  {
    "country": "HR",
    "name": "Horvati",
    "lat": "45.7",
    "lng": "15.81667"
  },
  {
    "country": "HR",
    "name": "Hodošan",
    "lat": "46.39528",
    "lng": "16.64389"
  },
  {
    "country": "HR",
    "name": "Hlebine",
    "lat": "46.15694",
    "lng": "16.96278"
  },
  {
    "country": "HR",
    "name": "Hercegovac",
    "lat": "45.65861",
    "lng": "17.01361"
  },
  {
    "country": "HR",
    "name": "Gunja",
    "lat": "44.88",
    "lng": "18.85333"
  },
  {
    "country": "HR",
    "name": "Gundinci",
    "lat": "45.15833",
    "lng": "18.49139"
  },
  {
    "country": "HR",
    "name": "Gudovac",
    "lat": "45.88028",
    "lng": "16.78083"
  },
  {
    "country": "HR",
    "name": "Grubišno Polje",
    "lat": "45.70214",
    "lng": "17.17268"
  },
  {
    "country": "HR",
    "name": "Grožnjan",
    "lat": "45.37889",
    "lng": "13.72389"
  },
  {
    "country": "HR",
    "name": "Gradište",
    "lat": "45.14806",
    "lng": "18.70667"
  },
  {
    "country": "HR",
    "name": "Gradići",
    "lat": "45.7",
    "lng": "16.05"
  },
  {
    "country": "HR",
    "name": "Gradec",
    "lat": "45.91111",
    "lng": "16.48278"
  },
  {
    "country": "HR",
    "name": "Gradac",
    "lat": "43.10583",
    "lng": "17.34167"
  },
  {
    "country": "HR",
    "name": "Gračišće",
    "lat": "45.21889",
    "lng": "14.01056"
  },
  {
    "country": "HR",
    "name": "Gračec",
    "lat": "45.83333",
    "lng": "16.31667"
  },
  {
    "country": "HR",
    "name": "Gračac",
    "lat": "44.29916",
    "lng": "15.84752"
  },
  {
    "country": "HR",
    "name": "Gospić",
    "lat": "44.54611",
    "lng": "15.37472"
  },
  {
    "country": "HR",
    "name": "Okrug Gornji",
    "lat": "43.49473",
    "lng": "16.26531"
  },
  {
    "country": "HR",
    "name": "Gornji Mihaljevec",
    "lat": "46.42864",
    "lng": "16.33328"
  },
  {
    "country": "HR",
    "name": "Gornji Kneginec",
    "lat": "46.25051",
    "lng": "16.37555"
  },
  {
    "country": "HR",
    "name": "Gornji Karin",
    "lat": "44.13598",
    "lng": "15.63423"
  },
  {
    "country": "HR",
    "name": "Gornji Bogičevci",
    "lat": "45.25944",
    "lng": "17.23611"
  },
  {
    "country": "HR",
    "name": "Gornje Vratno",
    "lat": "46.35917",
    "lng": "16.15444"
  },
  {
    "country": "HR",
    "name": "Podbablje",
    "lat": "43.39314",
    "lng": "17.17953"
  },
  {
    "country": "HR",
    "name": "Gornje Jesenje",
    "lat": "46.20639",
    "lng": "15.9125"
  },
  {
    "country": "HR",
    "name": "Gornja Vrba",
    "lat": "45.15528",
    "lng": "18.06556"
  },
  {
    "country": "HR",
    "name": "Gornja Stubica",
    "lat": "45.97519",
    "lng": "16.01931"
  },
  {
    "country": "HR",
    "name": "Gornja Bistra",
    "lat": "45.91667",
    "lng": "15.9"
  },
  {
    "country": "HR",
    "name": "Gorjani",
    "lat": "45.39889",
    "lng": "18.37222"
  },
  {
    "country": "HR",
    "name": "Goričan",
    "lat": "46.38417",
    "lng": "16.68083"
  },
  {
    "country": "HR",
    "name": "Gola",
    "lat": "46.19583",
    "lng": "17.05806"
  },
  {
    "country": "HR",
    "name": "Glina",
    "lat": "45.33806",
    "lng": "16.08806"
  },
  {
    "country": "HR",
    "name": "Generalski Stol",
    "lat": "45.34778",
    "lng": "15.38306"
  },
  {
    "country": "HR",
    "name": "Garešnica",
    "lat": "45.57444",
    "lng": "16.94139"
  },
  {
    "country": "HR",
    "name": "Garčin",
    "lat": "45.18278",
    "lng": "18.18306"
  },
  {
    "country": "HR",
    "name": "Galovac",
    "lat": "44.07139",
    "lng": "15.39333"
  },
  {
    "country": "HR",
    "name": "Galižana",
    "lat": "44.93167",
    "lng": "13.86861"
  },
  {
    "country": "HR",
    "name": "Gala",
    "lat": "43.715",
    "lng": "16.72694"
  },
  {
    "country": "HR",
    "name": "Fužine",
    "lat": "45.30528",
    "lng": "14.71556"
  },
  {
    "country": "HR",
    "name": "Funtana",
    "lat": "45.17472",
    "lng": "13.605"
  },
  {
    "country": "HR",
    "name": "Sveti Filip i Jakov",
    "lat": "43.96472",
    "lng": "15.43"
  },
  {
    "country": "HR",
    "name": "Feričanci",
    "lat": "45.52889",
    "lng": "17.97583"
  },
  {
    "country": "HR",
    "name": "Ferdinandovac",
    "lat": "46.05",
    "lng": "17.2"
  },
  {
    "country": "HR",
    "name": "Fažana",
    "lat": "44.9275",
    "lng": "13.80361"
  },
  {
    "country": "HR",
    "name": "Ervenik",
    "lat": "44.09944",
    "lng": "15.94528"
  },
  {
    "country": "HR",
    "name": "Ernestinovo",
    "lat": "45.45194",
    "lng": "18.65917"
  },
  {
    "country": "HR",
    "name": "Erdut",
    "lat": "45.52639",
    "lng": "19.06028"
  },
  {
    "country": "HR",
    "name": "Dvor",
    "lat": "45.07306",
    "lng": "16.37083"
  },
  {
    "country": "HR",
    "name": "Ðurmanec",
    "lat": "46.19639",
    "lng": "15.84083"
  },
  {
    "country": "HR",
    "name": "Đurđevac",
    "lat": "46.04111",
    "lng": "17.06972"
  },
  {
    "country": "HR",
    "name": "Ðurđenovac",
    "lat": "45.54333",
    "lng": "18.04583"
  },
  {
    "country": "HR",
    "name": "Dugo Selo",
    "lat": "45.80611",
    "lng": "16.24444"
  },
  {
    "country": "HR",
    "name": "Dugopolje",
    "lat": "43.58056",
    "lng": "16.60278"
  },
  {
    "country": "HR",
    "name": "Dugi Rat",
    "lat": "43.44611",
    "lng": "16.63972"
  },
  {
    "country": "HR",
    "name": "Duga Resa",
    "lat": "45.42861",
    "lng": "15.48833"
  },
  {
    "country": "HR",
    "name": "Duće",
    "lat": "43.44278",
    "lng": "16.66833"
  },
  {
    "country": "HR",
    "name": "Dubrovnik",
    "lat": "42.64807",
    "lng": "18.09216"
  },
  {
    "country": "HR",
    "name": "Dubravica",
    "lat": "45.95",
    "lng": "15.73333"
  },
  {
    "country": "HR",
    "name": "Dubrava",
    "lat": "45.83777",
    "lng": "16.53751"
  },
  {
    "country": "HR",
    "name": "Hrvatska Dubica",
    "lat": "45.19111",
    "lng": "16.80028"
  },
  {
    "country": "HR",
    "name": "Drnje",
    "lat": "46.20694",
    "lng": "16.91694"
  },
  {
    "country": "HR",
    "name": "Drniš",
    "lat": "43.8625",
    "lng": "16.15556"
  },
  {
    "country": "HR",
    "name": "Novo Virje",
    "lat": "46.09139",
    "lng": "17.15167"
  },
  {
    "country": "HR",
    "name": "Drenovci",
    "lat": "44.92056",
    "lng": "18.91222"
  },
  {
    "country": "HR",
    "name": "Drenova",
    "lat": "45.35",
    "lng": "14.43028"
  },
  {
    "country": "HR",
    "name": "Drenje",
    "lat": "45.38111",
    "lng": "18.28194"
  },
  {
    "country": "HR",
    "name": "Dražice",
    "lat": "45.39083",
    "lng": "14.47028"
  },
  {
    "country": "HR",
    "name": "Draž",
    "lat": "45.84222",
    "lng": "18.78861"
  },
  {
    "country": "HR",
    "name": "Draganići",
    "lat": "45.6",
    "lng": "15.6"
  },
  {
    "country": "HR",
    "name": "Dragalić",
    "lat": "45.24417",
    "lng": "17.28861"
  },
  {
    "country": "HR",
    "name": "Zemunik Donji",
    "lat": "44.10667",
    "lng": "15.38056"
  },
  {
    "country": "HR",
    "name": "Donji Vidovec",
    "lat": "46.32917",
    "lng": "16.78667"
  },
  {
    "country": "HR",
    "name": "Donji Seget",
    "lat": "43.51667",
    "lng": "16.23333"
  },
  {
    "country": "HR",
    "name": "Donji Proložac",
    "lat": "43.46972",
    "lng": "17.15639"
  },
  {
    "country": "HR",
    "name": "Donji Miholjac",
    "lat": "45.76083",
    "lng": "18.16722"
  },
  {
    "country": "HR",
    "name": "Donji Lapac",
    "lat": "44.55306",
    "lng": "15.96194"
  },
  {
    "country": "HR",
    "name": "Donji Kraljevec",
    "lat": "46.36611",
    "lng": "16.65278"
  },
  {
    "country": "HR",
    "name": "Donji Andrijevci",
    "lat": "45.18833",
    "lng": "18.29972"
  },
  {
    "country": "HR",
    "name": "Donje Ladanje",
    "lat": "46.3",
    "lng": "16.16667"
  },
  {
    "country": "HR",
    "name": "Donja Zdenčina",
    "lat": "45.66667",
    "lng": "15.76667"
  },
  {
    "country": "HR",
    "name": "Donja Voća",
    "lat": "46.30083",
    "lng": "16.105"
  },
  {
    "country": "HR",
    "name": "Donja Stubica",
    "lat": "45.98333",
    "lng": "15.96667"
  },
  {
    "country": "HR",
    "name": "Donja Pušća",
    "lat": "45.91667",
    "lng": "15.77778"
  },
  {
    "country": "HR",
    "name": "Donja Motičina",
    "lat": "45.49472",
    "lng": "18.02417"
  },
  {
    "country": "HR",
    "name": "Donja Lomnica",
    "lat": "45.71194",
    "lng": "16.02694"
  },
  {
    "country": "HR",
    "name": "Donja Dubrava",
    "lat": "46.31472",
    "lng": "16.81194"
  },
  {
    "country": "HR",
    "name": "Brela",
    "lat": "43.36889",
    "lng": "16.93417"
  },
  {
    "country": "HR",
    "name": "Donja Bistra",
    "lat": "45.90778",
    "lng": "15.85444"
  },
  {
    "country": "HR",
    "name": "Domašinec",
    "lat": "46.4325",
    "lng": "16.6"
  },
  {
    "country": "HR",
    "name": "Dobrinj",
    "lat": "45.12667",
    "lng": "14.60333"
  },
  {
    "country": "HR",
    "name": "Dežanovac",
    "lat": "45.57056",
    "lng": "17.08667"
  },
  {
    "country": "HR",
    "name": "Desinić",
    "lat": "46.14861",
    "lng": "15.66861"
  },
  {
    "country": "HR",
    "name": "Delnice",
    "lat": "45.40083",
    "lng": "14.79972"
  },
  {
    "country": "HR",
    "name": "Ðelekovec",
    "lat": "46.24861",
    "lng": "16.86667"
  },
  {
    "country": "HR",
    "name": "Dekanovec",
    "lat": "46.44861",
    "lng": "16.58472"
  },
  {
    "country": "HR",
    "name": "Davor",
    "lat": "45.11528",
    "lng": "17.51639"
  },
  {
    "country": "HR",
    "name": "Daruvar",
    "lat": "45.59056",
    "lng": "17.225"
  },
  {
    "country": "HR",
    "name": "Darda",
    "lat": "45.62806",
    "lng": "18.69972"
  },
  {
    "country": "HR",
    "name": "Dalj",
    "lat": "45.49",
    "lng": "18.98472"
  },
  {
    "country": "HR",
    "name": "Đakovo",
    "lat": "45.30833",
    "lng": "18.41056"
  },
  {
    "country": "HR",
    "name": "Crnac",
    "lat": "45.69611",
    "lng": "17.93722"
  },
  {
    "country": "HR",
    "name": "Crikvenica",
    "lat": "45.17722",
    "lng": "14.69278"
  },
  {
    "country": "HR",
    "name": "Cres",
    "lat": "44.96092",
    "lng": "14.41246"
  },
  {
    "country": "HR",
    "name": "Civljane",
    "lat": "43.95",
    "lng": "16.4"
  },
  {
    "country": "HR",
    "name": "Cista Provo",
    "lat": "43.50333",
    "lng": "16.94778"
  },
  {
    "country": "HR",
    "name": "Čibača",
    "lat": "42.62889",
    "lng": "18.17111"
  },
  {
    "country": "HR",
    "name": "Cetingrad",
    "lat": "45.15972",
    "lng": "15.73944"
  },
  {
    "country": "HR",
    "name": "Cestica",
    "lat": "46.37167",
    "lng": "16.12528"
  },
  {
    "country": "HR",
    "name": "Cerovlje",
    "lat": "45.27806",
    "lng": "14.01222"
  },
  {
    "country": "HR",
    "name": "Cernik",
    "lat": "45.34361",
    "lng": "14.50222"
  },
  {
    "country": "HR",
    "name": "Cernik",
    "lat": "45.28861",
    "lng": "17.38194"
  },
  {
    "country": "HR",
    "name": "Cerna",
    "lat": "45.18194",
    "lng": "18.68944"
  },
  {
    "country": "HR",
    "name": "Cerić",
    "lat": "45.31139",
    "lng": "18.85611"
  },
  {
    "country": "HR",
    "name": "Čepin",
    "lat": "45.52361",
    "lng": "18.56333"
  },
  {
    "country": "HR",
    "name": "Čeminac",
    "lat": "45.68639",
    "lng": "18.6675"
  },
  {
    "country": "HR",
    "name": "Čazma",
    "lat": "45.74818",
    "lng": "16.6139"
  },
  {
    "country": "HR",
    "name": "Cavtat",
    "lat": "42.58111",
    "lng": "18.21806"
  },
  {
    "country": "HR",
    "name": "Čavle",
    "lat": "45.35194",
    "lng": "14.48389"
  },
  {
    "country": "HR",
    "name": "Čakovec",
    "lat": "46.38444",
    "lng": "16.43389"
  },
  {
    "country": "HR",
    "name": "Čaglin",
    "lat": "45.34972",
    "lng": "17.98972"
  },
  {
    "country": "HR",
    "name": "Čađavica",
    "lat": "45.74417",
    "lng": "17.85472"
  },
  {
    "country": "HR",
    "name": "Čačinci",
    "lat": "45.60389",
    "lng": "17.87028"
  },
  {
    "country": "HR",
    "name": "Buzet",
    "lat": "45.40944",
    "lng": "13.96667"
  },
  {
    "country": "HR",
    "name": "Bukovlje",
    "lat": "45.18528",
    "lng": "18.07"
  },
  {
    "country": "HR",
    "name": "Buje",
    "lat": "45.41",
    "lng": "13.66194"
  },
  {
    "country": "HR",
    "name": "Budrovci",
    "lat": "45.27111",
    "lng": "18.44861"
  },
  {
    "country": "HR",
    "name": "Budinšćina",
    "lat": "46.12894",
    "lng": "16.20595"
  },
  {
    "country": "HR",
    "name": "Budaševo",
    "lat": "45.47472",
    "lng": "16.43667"
  },
  {
    "country": "HR",
    "name": "Brtonigla",
    "lat": "45.38139",
    "lng": "13.62944"
  },
  {
    "country": "HR",
    "name": "Bršadin",
    "lat": "45.36278",
    "lng": "18.91111"
  },
  {
    "country": "HR",
    "name": "Brodski Varoš",
    "lat": "45.18111",
    "lng": "17.97861"
  },
  {
    "country": "HR",
    "name": "Brodski Stupnik",
    "lat": "45.16778",
    "lng": "17.80361"
  },
  {
    "country": "HR",
    "name": "Brod Moravice",
    "lat": "45.46528",
    "lng": "14.97444"
  },
  {
    "country": "HR",
    "name": "Brnaze",
    "lat": "43.68",
    "lng": "16.64972"
  },
  {
    "country": "HR",
    "name": "Brinje",
    "lat": "45.0025",
    "lng": "15.13389"
  },
  {
    "country": "HR",
    "name": "Bribir",
    "lat": "45.16111",
    "lng": "14.76472"
  },
  {
    "country": "HR",
    "name": "Brezovica",
    "lat": "45.72919",
    "lng": "15.91069"
  },
  {
    "country": "HR",
    "name": "Brezovac",
    "lat": "45.8675",
    "lng": "16.84083"
  },
  {
    "country": "HR",
    "name": "Breznica",
    "lat": "46.07111",
    "lng": "16.27111"
  },
  {
    "country": "HR",
    "name": "Brestovac",
    "lat": "45.33056",
    "lng": "17.59694"
  },
  {
    "country": "HR",
    "name": "Koprivnički Bregi",
    "lat": "46.13861",
    "lng": "16.90583"
  },
  {
    "country": "HR",
    "name": "Bregana",
    "lat": "45.84013",
    "lng": "15.68792"
  },
  {
    "country": "HR",
    "name": "Brdovec",
    "lat": "45.86666",
    "lng": "15.77102"
  },
  {
    "country": "HR",
    "name": "Brckovljani",
    "lat": "45.83333",
    "lng": "16.3"
  },
  {
    "country": "HR",
    "name": "Bošnjaci",
    "lat": "45.05028",
    "lng": "18.75556"
  },
  {
    "country": "HR",
    "name": "Bosiljevo",
    "lat": "45.40139",
    "lng": "15.28833"
  },
  {
    "country": "HR",
    "name": "Borovo",
    "lat": "45.37639",
    "lng": "18.96694"
  },
  {
    "country": "HR",
    "name": "Bol",
    "lat": "43.26194",
    "lng": "16.655"
  },
  {
    "country": "HR",
    "name": "Bogdanovci",
    "lat": "45.34083",
    "lng": "18.93083"
  },
  {
    "country": "HR",
    "name": "Bobota",
    "lat": "45.42111",
    "lng": "18.85389"
  },
  {
    "country": "HR",
    "name": "Blato",
    "lat": "42.94083",
    "lng": "16.79167"
  },
  {
    "country": "HR",
    "name": "Blato",
    "lat": "42.7625",
    "lng": "17.48222"
  },
  {
    "country": "HR",
    "name": "Bjelovar",
    "lat": "45.89861",
    "lng": "16.84889"
  },
  {
    "country": "HR",
    "name": "Bizovac",
    "lat": "45.59278",
    "lng": "18.45889"
  },
  {
    "country": "HR",
    "name": "Bistrinci",
    "lat": "45.69167",
    "lng": "18.39861"
  },
  {
    "country": "HR",
    "name": "Biskupija",
    "lat": "44.01139",
    "lng": "16.23722"
  },
  {
    "country": "HR",
    "name": "Biograd na Moru",
    "lat": "43.94333",
    "lng": "15.45194"
  },
  {
    "country": "HR",
    "name": "Bilje",
    "lat": "45.60694",
    "lng": "18.74389"
  },
  {
    "country": "HR",
    "name": "Bilice",
    "lat": "43.78869",
    "lng": "15.87473"
  },
  {
    "country": "HR",
    "name": "Bijelo Brdo",
    "lat": "45.51722",
    "lng": "18.87083"
  },
  {
    "country": "HR",
    "name": "Bibinje",
    "lat": "44.07288",
    "lng": "15.28396"
  },
  {
    "country": "HR",
    "name": "Beretinec",
    "lat": "46.25",
    "lng": "16.3"
  },
  {
    "country": "HR",
    "name": "Berek",
    "lat": "45.73833",
    "lng": "16.83028"
  },
  {
    "country": "HR",
    "name": "Benkovac",
    "lat": "44.03444",
    "lng": "15.61278"
  },
  {
    "country": "HR",
    "name": "Belišće",
    "lat": "45.68028",
    "lng": "18.40583"
  },
  {
    "country": "HR",
    "name": "Beli Manastir",
    "lat": "45.77",
    "lng": "18.60361"
  },
  {
    "country": "HR",
    "name": "Belica",
    "lat": "46.40417",
    "lng": "16.51833"
  },
  {
    "country": "HR",
    "name": "Bednja",
    "lat": "46.23056",
    "lng": "15.98278"
  },
  {
    "country": "HR",
    "name": "Bedenica",
    "lat": "46.03333",
    "lng": "16.24278"
  },
  {
    "country": "HR",
    "name": "Bedekovčina",
    "lat": "46.04111",
    "lng": "15.99639"
  },
  {
    "country": "HR",
    "name": "Bebrina",
    "lat": "45.09833",
    "lng": "17.83417"
  },
  {
    "country": "HR",
    "name": "Batrina",
    "lat": "45.18944",
    "lng": "17.66639"
  },
  {
    "country": "HR",
    "name": "Baška Voda",
    "lat": "43.35694",
    "lng": "16.95028"
  },
  {
    "country": "HR",
    "name": "Baška",
    "lat": "44.97028",
    "lng": "14.75333"
  },
  {
    "country": "HR",
    "name": "Barilović",
    "lat": "45.38333",
    "lng": "15.55"
  },
  {
    "country": "HR",
    "name": "Barban",
    "lat": "45.06444",
    "lng": "14.01361"
  },
  {
    "country": "HR",
    "name": "Banjol",
    "lat": "44.75",
    "lng": "14.78333"
  },
  {
    "country": "HR",
    "name": "Bale",
    "lat": "45.04056",
    "lng": "13.78361"
  },
  {
    "country": "HR",
    "name": "Bakar",
    "lat": "45.30861",
    "lng": "14.53028"
  },
  {
    "country": "HR",
    "name": "Babino Polje",
    "lat": "42.73333",
    "lng": "17.56194"
  },
  {
    "country": "HR",
    "name": "Babina Greda",
    "lat": "45.11722",
    "lng": "18.53694"
  },
  {
    "country": "HR",
    "name": "Antunovac",
    "lat": "45.49083",
    "lng": "18.675"
  },
  {
    "country": "HR",
    "name": "Andrijaševci",
    "lat": "45.22472",
    "lng": "18.73806"
  },
  {
    "country": "HR",
    "name": "Jankomir",
    "lat": "45.79167",
    "lng": "15.9"
  },
  {
    "country": "HR",
    "name": "Stenjevec",
    "lat": "45.80846",
    "lng": "15.88245"
  },
  {
    "country": "HR",
    "name": "Bestovje",
    "lat": "45.80833",
    "lng": "15.81667"
  },
  {
    "country": "HR",
    "name": "Novi Zagreb",
    "lat": "45.78333",
    "lng": "15.98333"
  },
  {
    "country": "HR",
    "name": "Brodarica",
    "lat": "43.68",
    "lng": "15.91972"
  },
  {
    "country": "HR",
    "name": "Zagorska Sela",
    "lat": "46.09694",
    "lng": "15.635"
  },
  {
    "country": "HR",
    "name": "Buzdohanj",
    "lat": "45.34528",
    "lng": "14.48833"
  },
  {
    "country": "HR",
    "name": "Otrić-Seoci",
    "lat": "43.15861",
    "lng": "17.45083"
  },
  {
    "country": "HR",
    "name": "Donji Vinjani",
    "lat": "43.44613",
    "lng": "17.24064"
  },
  {
    "country": "HR",
    "name": "Netretić",
    "lat": "45.50889",
    "lng": "15.41333"
  },
  {
    "country": "HR",
    "name": "Donji Kukuruzari",
    "lat": "45.26639",
    "lng": "16.48333"
  },
  {
    "country": "HR",
    "name": "Lipovljani",
    "lat": "45.39667",
    "lng": "16.88972"
  },
  {
    "country": "HR",
    "name": "Kukljica",
    "lat": "44.03472",
    "lng": "15.24556"
  },
  {
    "country": "HR",
    "name": "Preko",
    "lat": "44.08111",
    "lng": "15.1875"
  },
  {
    "country": "HR",
    "name": "Stari Grad",
    "lat": "46.13667",
    "lng": "16.80528"
  },
  {
    "country": "HR",
    "name": "Koprivnički Ivanec",
    "lat": "46.20278",
    "lng": "16.81667"
  },
  {
    "country": "HR",
    "name": "Farkaševac",
    "lat": "45.87944",
    "lng": "16.64083"
  },
  {
    "country": "HR",
    "name": "Nin",
    "lat": "44.24139",
    "lng": "15.17833"
  },
  {
    "country": "HR",
    "name": "Stari Grad",
    "lat": "44.43",
    "lng": "15.06222"
  },
  {
    "country": "HR",
    "name": "Popovača",
    "lat": "44.63917",
    "lng": "15.17917"
  },
  {
    "country": "HR",
    "name": "Kampor",
    "lat": "44.775",
    "lng": "14.71861"
  },
  {
    "country": "HR",
    "name": "Vidovci",
    "lat": "45.3325",
    "lng": "17.71472"
  },
  {
    "country": "HR",
    "name": "Borovo Selo",
    "lat": "45.40528",
    "lng": "18.97583"
  },
  {
    "country": "HR",
    "name": "Podgora",
    "lat": "42.84861",
    "lng": "17.83639"
  },
  {
    "country": "HR",
    "name": "Kamen",
    "lat": "43.51417",
    "lng": "16.51472"
  },
  {
    "country": "HR",
    "name": "Zmijavci",
    "lat": "43.41083",
    "lng": "17.20556"
  },
  {
    "country": "HR",
    "name": "Greda",
    "lat": "43.61528",
    "lng": "16.69361"
  },
  {
    "country": "HR",
    "name": "Grabovci",
    "lat": "43.49278",
    "lng": "17.20111"
  },
  {
    "country": "HR",
    "name": "Grubine",
    "lat": "43.42986",
    "lng": "17.16292"
  },
  {
    "country": "HR",
    "name": "Vlaka",
    "lat": "42.99917",
    "lng": "17.52417"
  },
  {
    "country": "HR",
    "name": "Korenica",
    "lat": "45.22472",
    "lng": "18.16556"
  },
  {
    "country": "HR",
    "name": "Brijest",
    "lat": "45.52056",
    "lng": "18.67194"
  },
  {
    "country": "HR",
    "name": "Karlovac",
    "lat": "45.49167",
    "lng": "15.55"
  },
  {
    "country": "HR",
    "name": "Centar",
    "lat": "45.81313",
    "lng": "15.97753"
  },
  {
    "country": "HR",
    "name": "Stubičke Toplice",
    "lat": "45.97585",
    "lng": "15.93238"
  },
  {
    "country": "HR",
    "name": "Viškovo",
    "lat": "45.37572",
    "lng": "14.384"
  },
  {
    "country": "HR",
    "name": "Donji Stupnik",
    "lat": "45.73971",
    "lng": "15.85975"
  },
  {
    "country": "HR",
    "name": "Hrašćica",
    "lat": "46.32494",
    "lng": "16.29427"
  },
  {
    "country": "HR",
    "name": "Mihotići",
    "lat": "45.36125",
    "lng": "14.30553"
  },
  {
    "country": "HR",
    "name": "Valbandon",
    "lat": "44.91879",
    "lng": "13.81344"
  },
  {
    "country": "HR",
    "name": "Konjšćina",
    "lat": "46.0521",
    "lng": "16.17264"
  },
  {
    "country": "HT",
    "name": "Verrettes",
    "lat": "19.0505",
    "lng": "-72.46585"
  },
  {
    "country": "HT",
    "name": "Trou du Nord",
    "lat": "19.61668",
    "lng": "-72.02442"
  },
  {
    "country": "HT",
    "name": "Torbeck",
    "lat": "18.16338",
    "lng": "-73.80949"
  },
  {
    "country": "HT",
    "name": "Tiburon",
    "lat": "18.32589",
    "lng": "-74.39598"
  },
  {
    "country": "HT",
    "name": "Thomonde",
    "lat": "19.0173",
    "lng": "-71.96235"
  },
  {
    "country": "HT",
    "name": "Thomazeau",
    "lat": "18.65297",
    "lng": "-72.09391"
  },
  {
    "country": "HT",
    "name": "Thomassique",
    "lat": "19.08209",
    "lng": "-71.83855"
  },
  {
    "country": "HT",
    "name": "Thiotte",
    "lat": "18.24384",
    "lng": "-71.84157"
  },
  {
    "country": "HT",
    "name": "Saint-Raphaël",
    "lat": "19.43877",
    "lng": "-72.1991"
  },
  {
    "country": "HT",
    "name": "Saint-Marc",
    "lat": "19.10819",
    "lng": "-72.69379"
  },
  {
    "country": "HT",
    "name": "Saint-Louis du Sud",
    "lat": "18.26241",
    "lng": "-73.54603"
  },
  {
    "country": "HT",
    "name": "Saint-Louis du Nord",
    "lat": "19.93397",
    "lng": "-72.72138"
  },
  {
    "country": "HT",
    "name": "Roche-à-Bateau",
    "lat": "18.18182",
    "lng": "-74.00345"
  },
  {
    "country": "HT",
    "name": "Ranquitte",
    "lat": "19.41327",
    "lng": "-72.08077"
  },
  {
    "country": "HT",
    "name": "Quartier Morin",
    "lat": "19.69696",
    "lng": "-72.15712"
  },
  {
    "country": "HT",
    "name": "Port-Margot",
    "lat": "19.7518",
    "lng": "-72.43006"
  },
  {
    "country": "HT",
    "name": "Port-de-Paix",
    "lat": "19.9389",
    "lng": "-72.83257"
  },
  {
    "country": "HT",
    "name": "Port-au-Prince",
    "lat": "18.54349",
    "lng": "-72.33881"
  },
  {
    "country": "HT",
    "name": "Port-à-Piment",
    "lat": "18.24963",
    "lng": "-74.0971"
  },
  {
    "country": "HT",
    "name": "Plaisance",
    "lat": "19.59795",
    "lng": "-72.46994"
  },
  {
    "country": "HT",
    "name": "Plaine du Nord",
    "lat": "19.67707",
    "lng": "-72.26969"
  },
  {
    "country": "HT",
    "name": "Pilate",
    "lat": "19.66745",
    "lng": "-72.55229"
  },
  {
    "country": "HT",
    "name": "Pignon",
    "lat": "19.33594",
    "lng": "-72.11662"
  },
  {
    "country": "HT",
    "name": "Phaëton",
    "lat": "19.67525",
    "lng": "-71.89691"
  },
  {
    "country": "HT",
    "name": "Petit Trou de Nippes",
    "lat": "18.52535",
    "lng": "-73.50815"
  },
  {
    "country": "HT",
    "name": "Tigwav",
    "lat": "18.43117",
    "lng": "-72.86521"
  },
  {
    "country": "HT",
    "name": "Petite Rivière de Nippes",
    "lat": "18.47611",
    "lng": "-73.23495"
  },
  {
    "country": "HT",
    "name": "Petite Anse",
    "lat": "19.63011",
    "lng": "-73.15499"
  },
  {
    "country": "HT",
    "name": "Pétionville",
    "lat": "18.5125",
    "lng": "-72.28528"
  },
  {
    "country": "HT",
    "name": "Perches",
    "lat": "19.52201",
    "lng": "-71.92323"
  },
  {
    "country": "HT",
    "name": "Ouanaminthe",
    "lat": "19.54934",
    "lng": "-71.72475"
  },
  {
    "country": "HT",
    "name": "Moron",
    "lat": "18.56039",
    "lng": "-74.25777"
  },
  {
    "country": "HT",
    "name": "Montòrganize",
    "lat": "19.40815",
    "lng": "-71.78132"
  },
  {
    "country": "HT",
    "name": "Môle Saint-Nicolas",
    "lat": "19.807",
    "lng": "-73.37605"
  },
  {
    "country": "HT",
    "name": "Mirebalais",
    "lat": "18.83455",
    "lng": "-72.1048"
  },
  {
    "country": "HT",
    "name": "Miragoâne",
    "lat": "18.44232",
    "lng": "-73.08758"
  },
  {
    "country": "HT",
    "name": "Milot",
    "lat": "19.60837",
    "lng": "-72.21319"
  },
  {
    "country": "HT",
    "name": "Marmelade",
    "lat": "19.51736",
    "lng": "-72.36133"
  },
  {
    "country": "HT",
    "name": "Marigot",
    "lat": "18.23167",
    "lng": "-72.32289"
  },
  {
    "country": "HT",
    "name": "Mayisad",
    "lat": "19.17607",
    "lng": "-72.13958"
  },
  {
    "country": "HT",
    "name": "Limonade",
    "lat": "19.67014",
    "lng": "-72.1243"
  },
  {
    "country": "HT",
    "name": "Lenbe",
    "lat": "19.70603",
    "lng": "-72.40336"
  },
  {
    "country": "HT",
    "name": "Les Irois",
    "lat": "18.4049",
    "lng": "-74.4528"
  },
  {
    "country": "HT",
    "name": "Les Anglais",
    "lat": "18.3054",
    "lng": "-74.21968"
  },
  {
    "country": "HT",
    "name": "Léogâne",
    "lat": "18.5111",
    "lng": "-72.63343"
  },
  {
    "country": "HT",
    "name": "Borgne",
    "lat": "19.84507",
    "lng": "-72.52349"
  },
  {
    "country": "HT",
    "name": "Lascahobas",
    "lat": "18.83047",
    "lng": "-71.93563"
  },
  {
    "country": "HT",
    "name": "Kenscoff",
    "lat": "18.44773",
    "lng": "-72.28398"
  },
  {
    "country": "HT",
    "name": "Jérémie",
    "lat": "18.65",
    "lng": "-74.11667"
  },
  {
    "country": "HT",
    "name": "Jean-Rabel",
    "lat": "19.85379",
    "lng": "-73.19131"
  },
  {
    "country": "HT",
    "name": "Jacmel",
    "lat": "18.23427",
    "lng": "-72.53539"
  },
  {
    "country": "HT",
    "name": "Hinche",
    "lat": "19.15",
    "lng": "-72.01667"
  },
  {
    "country": "HT",
    "name": "Gros Morne",
    "lat": "19.6708",
    "lng": "-72.67808"
  },
  {
    "country": "HT",
    "name": "Gressier",
    "lat": "18.54091",
    "lng": "-72.52679"
  },
  {
    "country": "HT",
    "name": "Grangwav",
    "lat": "18.4259",
    "lng": "-72.76995"
  },
  {
    "country": "HT",
    "name": "Grande Saline",
    "lat": "19.26513",
    "lng": "-72.76897"
  },
  {
    "country": "HT",
    "name": "Grande Rivière du Nord",
    "lat": "19.57744",
    "lng": "-72.16872"
  },
  {
    "country": "HT",
    "name": "Gonayiv",
    "lat": "19.44749",
    "lng": "-72.68903"
  },
  {
    "country": "HT",
    "name": "Fort Liberté",
    "lat": "19.66273",
    "lng": "-71.83798"
  },
  {
    "country": "HT",
    "name": "Fonds Verrettes",
    "lat": "18.39566",
    "lng": "-71.85634"
  },
  {
    "country": "HT",
    "name": "Fond Parisien",
    "lat": "18.50547",
    "lng": "-71.98122"
  },
  {
    "country": "HT",
    "name": "Fond des Blancs",
    "lat": "18.27782",
    "lng": "-73.12733"
  },
  {
    "country": "HT",
    "name": "Fond Bassin Bleu",
    "lat": "19.79445",
    "lng": "-72.79949"
  },
  {
    "country": "HT",
    "name": "Ferrier",
    "lat": "19.61549",
    "lng": "-71.77792"
  },
  {
    "country": "HT",
    "name": "Ennery",
    "lat": "19.48342",
    "lng": "-72.48537"
  },
  {
    "country": "HT",
    "name": "Dondon",
    "lat": "19.52734",
    "lng": "-72.24337"
  },
  {
    "country": "HT",
    "name": "Dessalines",
    "lat": "19.26177",
    "lng": "-72.51611"
  },
  {
    "country": "HT",
    "name": "Désarmes",
    "lat": "18.99345",
    "lng": "-72.39058"
  },
  {
    "country": "HT",
    "name": "Dérac",
    "lat": "19.65476",
    "lng": "-71.81451"
  },
  {
    "country": "HT",
    "name": "Delmas 73",
    "lat": "18.54472",
    "lng": "-72.30278"
  },
  {
    "country": "HT",
    "name": "Dame-Marie",
    "lat": "18.56107",
    "lng": "-74.42167"
  },
  {
    "country": "HT",
    "name": "Croix-des-Bouquets",
    "lat": "18.57677",
    "lng": "-72.22625"
  },
  {
    "country": "HT",
    "name": "Kotdefè",
    "lat": "18.18872",
    "lng": "-73.00287"
  },
  {
    "country": "HT",
    "name": "Koto",
    "lat": "18.20601",
    "lng": "-74.04013"
  },
  {
    "country": "HT",
    "name": "Cornillon",
    "lat": "18.67546",
    "lng": "-71.95271"
  },
  {
    "country": "HT",
    "name": "Corail",
    "lat": "18.56766",
    "lng": "-73.88942"
  },
  {
    "country": "HT",
    "name": "Chardonnière",
    "lat": "18.27484",
    "lng": "-74.16613"
  },
  {
    "country": "HT",
    "name": "Chantal",
    "lat": "18.20169",
    "lng": "-73.88957"
  },
  {
    "country": "HT",
    "name": "Chambellan",
    "lat": "18.55037",
    "lng": "-74.31317"
  },
  {
    "country": "HT",
    "name": "Cerca la Source",
    "lat": "19.16696",
    "lng": "-71.79015"
  },
  {
    "country": "HT",
    "name": "Cayes-Jacmel",
    "lat": "18.2311",
    "lng": "-72.39545"
  },
  {
    "country": "HT",
    "name": "Les Cayes",
    "lat": "18.19331",
    "lng": "-73.74601"
  },
  {
    "country": "HT",
    "name": "Cavaillon",
    "lat": "18.29987",
    "lng": "-73.65455"
  },
  {
    "country": "HT",
    "name": "Carrefour",
    "lat": "18.54114",
    "lng": "-72.39922"
  },
  {
    "country": "HT",
    "name": "Carice",
    "lat": "19.37795",
    "lng": "-71.8303"
  },
  {
    "country": "HT",
    "name": "Caracol",
    "lat": "19.69274",
    "lng": "-72.01733"
  },
  {
    "country": "HT",
    "name": "Okap",
    "lat": "19.75938",
    "lng": "-72.19815"
  },
  {
    "country": "HT",
    "name": "Cabaret",
    "lat": "18.73582",
    "lng": "-72.41929"
  },
  {
    "country": "HT",
    "name": "Bombardopolis",
    "lat": "19.69142",
    "lng": "-73.33769"
  },
  {
    "country": "HT",
    "name": "Belle-Anse",
    "lat": "18.23768",
    "lng": "-72.06638"
  },
  {
    "country": "HT",
    "name": "Baradères",
    "lat": "18.48255",
    "lng": "-73.63884"
  },
  {
    "country": "HT",
    "name": "Baie de Henne",
    "lat": "19.66307",
    "lng": "-73.20943"
  },
  {
    "country": "HT",
    "name": "Bahon",
    "lat": "19.46959",
    "lng": "-72.11466"
  },
  {
    "country": "HT",
    "name": "Arcahaie",
    "lat": "19.81667",
    "lng": "-72.91667"
  },
  {
    "country": "HT",
    "name": "Aquin",
    "lat": "18.27974",
    "lng": "-73.39433"
  },
  {
    "country": "HT",
    "name": "Anse Rouge",
    "lat": "19.63382",
    "lng": "-73.0553"
  },
  {
    "country": "HT",
    "name": "Anse-à-Veau",
    "lat": "18.5011",
    "lng": "-73.3449"
  },
  {
    "country": "HT",
    "name": "Anse-à-Pitre",
    "lat": "18.05",
    "lng": "-71.75"
  },
  {
    "country": "HT",
    "name": "Anse à Galets",
    "lat": "18.83449",
    "lng": "-72.86644"
  },
  {
    "country": "HT",
    "name": "Acul du Nord",
    "lat": "19.68075",
    "lng": "-72.31978"
  },
  {
    "country": "HT",
    "name": "Les Abricots",
    "lat": "18.64901",
    "lng": "-74.30786"
  },
  {
    "country": "HT",
    "name": "Ti Port-de-Paix",
    "lat": "19.93333",
    "lng": "-72.83333"
  },
  {
    "country": "HU",
    "name": "Záhony",
    "lat": "48.40906",
    "lng": "22.17614"
  },
  {
    "country": "HU",
    "name": "Zagyvarékas",
    "lat": "47.26667",
    "lng": "20.13333"
  },
  {
    "country": "HU",
    "name": "Vésztő",
    "lat": "46.91667",
    "lng": "21.26667"
  },
  {
    "country": "HU",
    "name": "Verpelét",
    "lat": "47.85",
    "lng": "20.23333"
  },
  {
    "country": "HU",
    "name": "Vásárosnamény",
    "lat": "48.12542",
    "lng": "22.31325"
  },
  {
    "country": "HU",
    "name": "Vámospércs",
    "lat": "47.53333",
    "lng": "21.9"
  },
  {
    "country": "HU",
    "name": "Vaja",
    "lat": "48.00574",
    "lng": "22.16761"
  },
  {
    "country": "HU",
    "name": "Újszász",
    "lat": "47.3",
    "lng": "20.08333"
  },
  {
    "country": "HU",
    "name": "Újkígyós",
    "lat": "46.58333",
    "lng": "21.03333"
  },
  {
    "country": "HU",
    "name": "Újfehértó",
    "lat": "47.8",
    "lng": "21.68333"
  },
  {
    "country": "HU",
    "name": "Tyukod",
    "lat": "47.85378",
    "lng": "22.5633"
  },
  {
    "country": "HU",
    "name": "Tuzsér",
    "lat": "48.34407",
    "lng": "22.11762"
  },
  {
    "country": "HU",
    "name": "Túrkeve",
    "lat": "47.1",
    "lng": "20.75"
  },
  {
    "country": "HU",
    "name": "Tunyogmatolcs",
    "lat": "47.96667",
    "lng": "22.46667"
  },
  {
    "country": "HU",
    "name": "Tótkomlós",
    "lat": "46.41667",
    "lng": "20.73333"
  },
  {
    "country": "HU",
    "name": "Tószeg",
    "lat": "47.1",
    "lng": "20.15"
  },
  {
    "country": "HU",
    "name": "Törökszentmiklós",
    "lat": "47.18333",
    "lng": "20.41667"
  },
  {
    "country": "HU",
    "name": "Tornyospálca",
    "lat": "48.26667",
    "lng": "22.18333"
  },
  {
    "country": "HU",
    "name": "Tömörkény",
    "lat": "46.61716",
    "lng": "20.04357"
  },
  {
    "country": "HU",
    "name": "Tolcsva",
    "lat": "48.28333",
    "lng": "21.45"
  },
  {
    "country": "HU",
    "name": "Tokaj",
    "lat": "48.11667",
    "lng": "21.41667"
  },
  {
    "country": "HU",
    "name": "Tiszavasvári",
    "lat": "47.96667",
    "lng": "21.35"
  },
  {
    "country": "HU",
    "name": "Tiszaújváros",
    "lat": "47.93333",
    "lng": "21.08333"
  },
  {
    "country": "HU",
    "name": "Tiszaszentimre",
    "lat": "47.48333",
    "lng": "20.73333"
  },
  {
    "country": "HU",
    "name": "Tiszasüly",
    "lat": "47.38333",
    "lng": "20.4"
  },
  {
    "country": "HU",
    "name": "Tiszaroff",
    "lat": "47.4",
    "lng": "20.45"
  },
  {
    "country": "HU",
    "name": "Tiszapüspöki",
    "lat": "47.21667",
    "lng": "20.31667"
  },
  {
    "country": "HU",
    "name": "Tiszanána",
    "lat": "47.56667",
    "lng": "20.53333"
  },
  {
    "country": "HU",
    "name": "Tiszanagyfalu",
    "lat": "48.1",
    "lng": "21.48333"
  },
  {
    "country": "HU",
    "name": "Tiszalúc",
    "lat": "48.03774",
    "lng": "21.07261"
  },
  {
    "country": "HU",
    "name": "Tiszalök",
    "lat": "48.01667",
    "lng": "21.38333"
  },
  {
    "country": "HU",
    "name": "Tiszakeszi",
    "lat": "47.78333",
    "lng": "21"
  },
  {
    "country": "HU",
    "name": "Tiszakécske",
    "lat": "46.93261",
    "lng": "20.10349"
  },
  {
    "country": "HU",
    "name": "Tiszakarád",
    "lat": "48.2",
    "lng": "21.71667"
  },
  {
    "country": "HU",
    "name": "Tiszafüred",
    "lat": "47.61667",
    "lng": "20.76667"
  },
  {
    "country": "HU",
    "name": "Tiszaföldvár",
    "lat": "46.98333",
    "lng": "20.25"
  },
  {
    "country": "HU",
    "name": "Tiszaeszlár",
    "lat": "48.05",
    "lng": "21.46667"
  },
  {
    "country": "HU",
    "name": "Tiszadob",
    "lat": "48.01667",
    "lng": "21.16667"
  },
  {
    "country": "HU",
    "name": "Tiszadada",
    "lat": "48.03333",
    "lng": "21.25"
  },
  {
    "country": "HU",
    "name": "Tiszacsege",
    "lat": "47.7",
    "lng": "21"
  },
  {
    "country": "HU",
    "name": "Tiszabura",
    "lat": "47.45",
    "lng": "20.46667"
  },
  {
    "country": "HU",
    "name": "Tiszabő",
    "lat": "47.3",
    "lng": "20.48333"
  },
  {
    "country": "HU",
    "name": "Tiszabezdéd",
    "lat": "48.36667",
    "lng": "22.15"
  },
  {
    "country": "HU",
    "name": "Tiszabercel",
    "lat": "48.15",
    "lng": "21.65"
  },
  {
    "country": "HU",
    "name": "Téglás",
    "lat": "47.71667",
    "lng": "21.68333"
  },
  {
    "country": "HU",
    "name": "Tarpa",
    "lat": "48.1048",
    "lng": "22.53744"
  },
  {
    "country": "HU",
    "name": "Tarnaörs",
    "lat": "47.59499",
    "lng": "20.05254"
  },
  {
    "country": "HU",
    "name": "Tarnalelesz",
    "lat": "48.05",
    "lng": "20.18333"
  },
  {
    "country": "HU",
    "name": "Tarcal",
    "lat": "48.13333",
    "lng": "21.35"
  },
  {
    "country": "HU",
    "name": "Tállya",
    "lat": "48.23333",
    "lng": "21.23333"
  },
  {
    "country": "HU",
    "name": "Taktaszada",
    "lat": "48.11667",
    "lng": "21.18333"
  },
  {
    "country": "HU",
    "name": "Taktaharkány",
    "lat": "48.08333",
    "lng": "21.13333"
  },
  {
    "country": "HU",
    "name": "Szolnok",
    "lat": "47.18333",
    "lng": "20.2"
  },
  {
    "country": "HU",
    "name": "Szirmabesenyő",
    "lat": "48.15",
    "lng": "20.8"
  },
  {
    "country": "HU",
    "name": "Szilvásvárad",
    "lat": "48.1",
    "lng": "20.4"
  },
  {
    "country": "HU",
    "name": "Szikszó",
    "lat": "48.2",
    "lng": "20.93333"
  },
  {
    "country": "HU",
    "name": "Szihalom",
    "lat": "47.76667",
    "lng": "20.48333"
  },
  {
    "country": "HU",
    "name": "Szerencs",
    "lat": "48.15993",
    "lng": "21.2097"
  },
  {
    "country": "HU",
    "name": "Szentistván",
    "lat": "47.76667",
    "lng": "20.66667"
  },
  {
    "country": "HU",
    "name": "Szentes",
    "lat": "46.65834",
    "lng": "20.2608"
  },
  {
    "country": "HU",
    "name": "Szendrő",
    "lat": "48.4",
    "lng": "20.73333"
  },
  {
    "country": "HU",
    "name": "Székkutas",
    "lat": "46.5",
    "lng": "20.53333"
  },
  {
    "country": "HU",
    "name": "Szegvár",
    "lat": "46.5874",
    "lng": "20.22408"
  },
  {
    "country": "HU",
    "name": "Szeghalom",
    "lat": "47.03333",
    "lng": "21.16667"
  },
  {
    "country": "HU",
    "name": "Szeged",
    "lat": "46.253",
    "lng": "20.14824"
  },
  {
    "country": "HU",
    "name": "Szatymaz",
    "lat": "46.34306",
    "lng": "20.0402"
  },
  {
    "country": "HU",
    "name": "Szarvas",
    "lat": "46.86667",
    "lng": "20.55"
  },
  {
    "country": "HU",
    "name": "Szamosszeg",
    "lat": "48.04561",
    "lng": "22.36582"
  },
  {
    "country": "HU",
    "name": "Szakoly",
    "lat": "47.76667",
    "lng": "21.91667"
  },
  {
    "country": "HU",
    "name": "Szajol",
    "lat": "47.18333",
    "lng": "20.3"
  },
  {
    "country": "HU",
    "name": "Szabadkígyós",
    "lat": "46.61667",
    "lng": "21.1"
  },
  {
    "country": "HU",
    "name": "Sirok",
    "lat": "47.93333",
    "lng": "20.2"
  },
  {
    "country": "HU",
    "name": "Sátoraljaújhely",
    "lat": "48.39492",
    "lng": "21.65871"
  },
  {
    "country": "HU",
    "name": "Sárrétudvari",
    "lat": "47.23333",
    "lng": "21.2"
  },
  {
    "country": "HU",
    "name": "Sárospatak",
    "lat": "48.3245",
    "lng": "21.57383"
  },
  {
    "country": "HU",
    "name": "Sarkad",
    "lat": "46.75",
    "lng": "21.38333"
  },
  {
    "country": "HU",
    "name": "Sáránd",
    "lat": "47.4",
    "lng": "21.63333"
  },
  {
    "country": "HU",
    "name": "Sándorfalva",
    "lat": "46.36087",
    "lng": "20.09889"
  },
  {
    "country": "HU",
    "name": "Sály",
    "lat": "47.95",
    "lng": "20.66667"
  },
  {
    "country": "HU",
    "name": "Sajóvámos",
    "lat": "48.18171",
    "lng": "20.83149"
  },
  {
    "country": "HU",
    "name": "Sajószöged",
    "lat": "47.95",
    "lng": "21"
  },
  {
    "country": "HU",
    "name": "Sajószentpéter",
    "lat": "48.21667",
    "lng": "20.71667"
  },
  {
    "country": "HU",
    "name": "Sajóörös",
    "lat": "47.95",
    "lng": "21.03333"
  },
  {
    "country": "HU",
    "name": "Sajólád",
    "lat": "48.05",
    "lng": "20.9"
  },
  {
    "country": "HU",
    "name": "Sajókaza",
    "lat": "48.28333",
    "lng": "20.58333"
  },
  {
    "country": "HU",
    "name": "Sajóbábony",
    "lat": "48.16667",
    "lng": "20.73333"
  },
  {
    "country": "HU",
    "name": "Rudabánya",
    "lat": "48.38333",
    "lng": "20.63333"
  },
  {
    "country": "HU",
    "name": "Röszke",
    "lat": "46.18796",
    "lng": "20.03372"
  },
  {
    "country": "HU",
    "name": "Ricse",
    "lat": "48.32565",
    "lng": "21.97069"
  },
  {
    "country": "HU",
    "name": "Recsk",
    "lat": "47.93333",
    "lng": "20.11667"
  },
  {
    "country": "HU",
    "name": "Rákócziújfalu",
    "lat": "47.06667",
    "lng": "20.26667"
  },
  {
    "country": "HU",
    "name": "Rákóczifalva",
    "lat": "47.08333",
    "lng": "20.23333"
  },
  {
    "country": "HU",
    "name": "Rakamaz",
    "lat": "48.12372",
    "lng": "21.46429"
  },
  {
    "country": "HU",
    "name": "Putnok",
    "lat": "48.3",
    "lng": "20.43333"
  },
  {
    "country": "HU",
    "name": "Pusztaföldvár",
    "lat": "46.53333",
    "lng": "20.8"
  },
  {
    "country": "HU",
    "name": "Püspökladány",
    "lat": "47.31667",
    "lng": "21.11667"
  },
  {
    "country": "HU",
    "name": "Prügy",
    "lat": "48.08333",
    "lng": "21.25"
  },
  {
    "country": "HU",
    "name": "Poroszló",
    "lat": "47.65",
    "lng": "20.66667"
  },
  {
    "country": "HU",
    "name": "Porcsalma",
    "lat": "47.88333",
    "lng": "22.56667"
  },
  {
    "country": "HU",
    "name": "Polgár",
    "lat": "47.86667",
    "lng": "21.11667"
  },
  {
    "country": "HU",
    "name": "Pocsaj",
    "lat": "47.28333",
    "lng": "21.81667"
  },
  {
    "country": "HU",
    "name": "Petneháza",
    "lat": "48.06084",
    "lng": "22.07485"
  },
  {
    "country": "HU",
    "name": "Pétervására",
    "lat": "48.01667",
    "lng": "20.1"
  },
  {
    "country": "HU",
    "name": "Pátroha",
    "lat": "48.16667",
    "lng": "22"
  },
  {
    "country": "HU",
    "name": "Parád",
    "lat": "47.92323",
    "lng": "20.02972"
  },
  {
    "country": "HU",
    "name": "Ózd",
    "lat": "48.21667",
    "lng": "20.3"
  },
  {
    "country": "HU",
    "name": "Ostoros",
    "lat": "47.86667",
    "lng": "20.43333"
  },
  {
    "country": "HU",
    "name": "Orosháza",
    "lat": "46.56667",
    "lng": "20.66667"
  },
  {
    "country": "HU",
    "name": "Ópusztaszer",
    "lat": "46.48592",
    "lng": "20.08722"
  },
  {
    "country": "HU",
    "name": "Ópályi",
    "lat": "47.99771",
    "lng": "22.32617"
  },
  {
    "country": "HU",
    "name": "Ónod",
    "lat": "48",
    "lng": "20.91667"
  },
  {
    "country": "HU",
    "name": "Onga",
    "lat": "48.11667",
    "lng": "20.91667"
  },
  {
    "country": "HU",
    "name": "Olaszliszka",
    "lat": "48.25",
    "lng": "21.43333"
  },
  {
    "country": "HU",
    "name": "Ököritófülpös",
    "lat": "47.91862",
    "lng": "22.5081"
  },
  {
    "country": "HU",
    "name": "Okány",
    "lat": "46.9",
    "lng": "21.35"
  },
  {
    "country": "HU",
    "name": "Ófehértó",
    "lat": "47.93333",
    "lng": "22.05"
  },
  {
    "country": "HU",
    "name": "Öcsöd",
    "lat": "46.9",
    "lng": "20.4"
  },
  {
    "country": "HU",
    "name": "Nyírvasvári",
    "lat": "47.81667",
    "lng": "22.18683"
  },
  {
    "country": "HU",
    "name": "Nyírtelek",
    "lat": "48.01667",
    "lng": "21.63333"
  },
  {
    "country": "HU",
    "name": "Nyírtass",
    "lat": "48.11667",
    "lng": "22.03333"
  },
  {
    "country": "HU",
    "name": "Nyírpazony",
    "lat": "47.98333",
    "lng": "21.8"
  },
  {
    "country": "HU",
    "name": "Nyírmihálydi",
    "lat": "47.73976",
    "lng": "21.96445"
  },
  {
    "country": "HU",
    "name": "Nyírmeggyes",
    "lat": "47.91667",
    "lng": "22.26667"
  },
  {
    "country": "HU",
    "name": "Nyírmártonfalva",
    "lat": "47.58333",
    "lng": "21.9"
  },
  {
    "country": "HU",
    "name": "Nyírmada",
    "lat": "48.06667",
    "lng": "22.2"
  },
  {
    "country": "HU",
    "name": "Nyírlugos",
    "lat": "47.69315",
    "lng": "22.04476"
  },
  {
    "country": "HU",
    "name": "Nyírkarász",
    "lat": "48.09477",
    "lng": "22.10463"
  },
  {
    "country": "HU",
    "name": "Nyírgyulaj",
    "lat": "47.88622",
    "lng": "22.09781"
  },
  {
    "country": "HU",
    "name": "Nyíregyháza",
    "lat": "47.95539",
    "lng": "21.71671"
  },
  {
    "country": "HU",
    "name": "Nyírcsaholy",
    "lat": "47.90383",
    "lng": "22.3363"
  },
  {
    "country": "HU",
    "name": "Nyírbogdány",
    "lat": "48.05723",
    "lng": "21.88242"
  },
  {
    "country": "HU",
    "name": "Nyírbogát",
    "lat": "47.8034",
    "lng": "22.06561"
  },
  {
    "country": "HU",
    "name": "Nyírbéltek",
    "lat": "47.7",
    "lng": "22.13333"
  },
  {
    "country": "HU",
    "name": "Nyírbátor",
    "lat": "47.83333",
    "lng": "22.13333"
  },
  {
    "country": "HU",
    "name": "Nyíradony",
    "lat": "47.69746",
    "lng": "21.91878"
  },
  {
    "country": "HU",
    "name": "Nyíracsád",
    "lat": "47.6033",
    "lng": "21.97208"
  },
  {
    "country": "HU",
    "name": "Nyírábrány",
    "lat": "47.55311",
    "lng": "22.02401"
  },
  {
    "country": "HU",
    "name": "Nyékládháza",
    "lat": "47.98333",
    "lng": "20.83333"
  },
  {
    "country": "HU",
    "name": "Napkor",
    "lat": "47.93797",
    "lng": "21.86763"
  },
  {
    "country": "HU",
    "name": "Nagyszénás",
    "lat": "46.68333",
    "lng": "20.66667"
  },
  {
    "country": "HU",
    "name": "Nagyrábé",
    "lat": "47.2",
    "lng": "21.33333"
  },
  {
    "country": "HU",
    "name": "Nagykálló",
    "lat": "47.87491",
    "lng": "21.84082"
  },
  {
    "country": "HU",
    "name": "Nagyhalász",
    "lat": "48.13266",
    "lng": "21.76104"
  },
  {
    "country": "HU",
    "name": "Nagyecsed",
    "lat": "47.86547",
    "lng": "22.39159"
  },
  {
    "country": "HU",
    "name": "Nagydobos",
    "lat": "48.05759",
    "lng": "22.30423"
  },
  {
    "country": "HU",
    "name": "Nagycserkesz",
    "lat": "47.96667",
    "lng": "21.53333"
  },
  {
    "country": "HU",
    "name": "Nádudvar",
    "lat": "47.41667",
    "lng": "21.16667"
  },
  {
    "country": "HU",
    "name": "Múcsony",
    "lat": "48.26667",
    "lng": "20.68333"
  },
  {
    "country": "HU",
    "name": "Monostorpályi",
    "lat": "47.4",
    "lng": "21.78333"
  },
  {
    "country": "HU",
    "name": "Monok",
    "lat": "48.21102",
    "lng": "21.15052"
  },
  {
    "country": "HU",
    "name": "Miskolc",
    "lat": "48.1",
    "lng": "20.78333"
  },
  {
    "country": "HU",
    "name": "Mindszent",
    "lat": "46.52362",
    "lng": "20.19038"
  },
  {
    "country": "HU",
    "name": "Mikepércs",
    "lat": "47.45",
    "lng": "21.63333"
  },
  {
    "country": "HU",
    "name": "Mezőzombor",
    "lat": "48.15",
    "lng": "21.26667"
  },
  {
    "country": "HU",
    "name": "Mezőtúr",
    "lat": "47",
    "lng": "20.63333"
  },
  {
    "country": "HU",
    "name": "Mezőkövesd",
    "lat": "47.81667",
    "lng": "20.58333"
  },
  {
    "country": "HU",
    "name": "Mezőkovácsháza",
    "lat": "46.4",
    "lng": "20.91667"
  },
  {
    "country": "HU",
    "name": "Mezőkeresztes",
    "lat": "47.83333",
    "lng": "20.7"
  },
  {
    "country": "HU",
    "name": "Mezőhegyes",
    "lat": "46.31667",
    "lng": "20.81667"
  },
  {
    "country": "HU",
    "name": "Mezőcsát",
    "lat": "47.81667",
    "lng": "20.91667"
  },
  {
    "country": "HU",
    "name": "Mezőberény",
    "lat": "46.81667",
    "lng": "21.03333"
  },
  {
    "country": "HU",
    "name": "Mérk",
    "lat": "47.78824",
    "lng": "22.38038"
  },
  {
    "country": "HU",
    "name": "Méhkerék",
    "lat": "46.78333",
    "lng": "21.45"
  },
  {
    "country": "HU",
    "name": "Megyaszó",
    "lat": "48.18333",
    "lng": "21.05"
  },
  {
    "country": "HU",
    "name": "Medgyesegyháza",
    "lat": "46.5",
    "lng": "21.03333"
  },
  {
    "country": "HU",
    "name": "Mátraderecske",
    "lat": "47.95",
    "lng": "20.08333"
  },
  {
    "country": "HU",
    "name": "Mátészalka",
    "lat": "47.95528",
    "lng": "22.32348"
  },
  {
    "country": "HU",
    "name": "Maroslele",
    "lat": "46.26667",
    "lng": "20.35"
  },
  {
    "country": "HU",
    "name": "Máriapócs",
    "lat": "47.88303",
    "lng": "22.02501"
  },
  {
    "country": "HU",
    "name": "Mándok",
    "lat": "48.32149",
    "lng": "22.19107"
  },
  {
    "country": "HU",
    "name": "Mályi",
    "lat": "48.01667",
    "lng": "20.83333"
  },
  {
    "country": "HU",
    "name": "Makó",
    "lat": "46.21667",
    "lng": "20.48333"
  },
  {
    "country": "HU",
    "name": "Maklár",
    "lat": "47.8",
    "lng": "20.41667"
  },
  {
    "country": "HU",
    "name": "Magyarbánhegyes",
    "lat": "46.45",
    "lng": "20.96667"
  },
  {
    "country": "HU",
    "name": "Mád",
    "lat": "48.19442",
    "lng": "21.28208"
  },
  {
    "country": "HU",
    "name": "Lőkösháza",
    "lat": "46.43333",
    "lng": "21.23333"
  },
  {
    "country": "HU",
    "name": "Levelek",
    "lat": "47.96282",
    "lng": "21.98537"
  },
  {
    "country": "HU",
    "name": "Létavértes",
    "lat": "47.38333",
    "lng": "21.9"
  },
  {
    "country": "HU",
    "name": "Kunszentmárton",
    "lat": "46.83916",
    "lng": "20.28879"
  },
  {
    "country": "HU",
    "name": "Kunmadaras",
    "lat": "47.43333",
    "lng": "20.8"
  },
  {
    "country": "HU",
    "name": "Kunhegyes",
    "lat": "47.36667",
    "lng": "20.63333"
  },
  {
    "country": "HU",
    "name": "Kunágota",
    "lat": "46.43333",
    "lng": "21.05"
  },
  {
    "country": "HU",
    "name": "Kótaj",
    "lat": "48.05",
    "lng": "21.71667"
  },
  {
    "country": "HU",
    "name": "Köröstarcsa",
    "lat": "46.88333",
    "lng": "21.03333"
  },
  {
    "country": "HU",
    "name": "Körösladány",
    "lat": "46.96667",
    "lng": "21.08333"
  },
  {
    "country": "HU",
    "name": "Konyár",
    "lat": "47.31667",
    "lng": "21.66667"
  },
  {
    "country": "HU",
    "name": "Kondoros",
    "lat": "46.76667",
    "lng": "20.8"
  },
  {
    "country": "HU",
    "name": "Kompolt",
    "lat": "47.73333",
    "lng": "20.25"
  },
  {
    "country": "HU",
    "name": "Komádi",
    "lat": "47",
    "lng": "21.5"
  },
  {
    "country": "HU",
    "name": "Kocsord",
    "lat": "47.93912",
    "lng": "22.38333"
  },
  {
    "country": "HU",
    "name": "Kiszombor",
    "lat": "46.18333",
    "lng": "20.43333"
  },
  {
    "country": "HU",
    "name": "Kisvárda",
    "lat": "48.21667",
    "lng": "22.08333"
  },
  {
    "country": "HU",
    "name": "Kisújszállás",
    "lat": "47.21667",
    "lng": "20.76667"
  },
  {
    "country": "HU",
    "name": "Kisléta",
    "lat": "47.84244",
    "lng": "22.00393"
  },
  {
    "country": "HU",
    "name": "Kisköre",
    "lat": "47.5",
    "lng": "20.5"
  },
  {
    "country": "HU",
    "name": "Kevermes",
    "lat": "46.41667",
    "lng": "21.18333"
  },
  {
    "country": "HU",
    "name": "Kétegyháza",
    "lat": "46.53333",
    "lng": "21.18333"
  },
  {
    "country": "HU",
    "name": "Kerecsend",
    "lat": "47.8",
    "lng": "20.35"
  },
  {
    "country": "HU",
    "name": "Kengyel",
    "lat": "47.08333",
    "lng": "20.33333"
  },
  {
    "country": "HU",
    "name": "Kenderes",
    "lat": "47.25",
    "lng": "20.68333"
  },
  {
    "country": "HU",
    "name": "Kemecse",
    "lat": "48.07532",
    "lng": "21.80625"
  },
  {
    "country": "HU",
    "name": "Kék",
    "lat": "48.11667",
    "lng": "21.88333"
  },
  {
    "country": "HU",
    "name": "Kazincbarcika",
    "lat": "48.25",
    "lng": "20.63333"
  },
  {
    "country": "HU",
    "name": "Kaszaper",
    "lat": "46.46667",
    "lng": "20.83333"
  },
  {
    "country": "HU",
    "name": "Karcsa",
    "lat": "48.3113",
    "lng": "21.80537"
  },
  {
    "country": "HU",
    "name": "Karcag",
    "lat": "47.31667",
    "lng": "20.93333"
  },
  {
    "country": "HU",
    "name": "Karácsond",
    "lat": "47.72962",
    "lng": "20.03076"
  },
  {
    "country": "HU",
    "name": "Kántorjánosi",
    "lat": "47.93333",
    "lng": "22.15"
  },
  {
    "country": "HU",
    "name": "Kálmánháza",
    "lat": "47.88333",
    "lng": "21.58333"
  },
  {
    "country": "HU",
    "name": "Kállósemjén",
    "lat": "47.86081",
    "lng": "21.93929"
  },
  {
    "country": "HU",
    "name": "Kál",
    "lat": "47.73333",
    "lng": "20.26667"
  },
  {
    "country": "HU",
    "name": "Kaba",
    "lat": "47.35",
    "lng": "21.28333"
  },
  {
    "country": "HU",
    "name": "Jászszentandrás",
    "lat": "47.58333",
    "lng": "20.18333"
  },
  {
    "country": "HU",
    "name": "Jászladány",
    "lat": "47.36667",
    "lng": "20.16667"
  },
  {
    "country": "HU",
    "name": "Jászkisér",
    "lat": "47.45",
    "lng": "20.21667"
  },
  {
    "country": "HU",
    "name": "Jászkarajenő",
    "lat": "47.05",
    "lng": "20.06667"
  },
  {
    "country": "HU",
    "name": "Jászjákóhalma",
    "lat": "47.52038",
    "lng": "19.99086"
  },
  {
    "country": "HU",
    "name": "Jászdózsa",
    "lat": "47.5661",
    "lng": "20.01534"
  },
  {
    "country": "HU",
    "name": "Jászapáti",
    "lat": "47.51667",
    "lng": "20.15"
  },
  {
    "country": "HU",
    "name": "Jászalsószentgyörgy",
    "lat": "47.36667",
    "lng": "20.1"
  },
  {
    "country": "HU",
    "name": "Járdánháza",
    "lat": "48.15",
    "lng": "20.25"
  },
  {
    "country": "HU",
    "name": "Jánoshida",
    "lat": "47.38333",
    "lng": "20.06667"
  },
  {
    "country": "HU",
    "name": "Izsófalva",
    "lat": "48.3",
    "lng": "20.66667"
  },
  {
    "country": "HU",
    "name": "Ibrány",
    "lat": "48.12329",
    "lng": "21.70953"
  },
  {
    "country": "HU",
    "name": "Hosszúpályi",
    "lat": "47.39303",
    "lng": "21.7328"
  },
  {
    "country": "HU",
    "name": "Hortobágy",
    "lat": "47.58278",
    "lng": "21.15108"
  },
  {
    "country": "HU",
    "name": "Hódmezővásárhely",
    "lat": "46.41667",
    "lng": "20.33333"
  },
  {
    "country": "HU",
    "name": "Hodász",
    "lat": "47.91834",
    "lng": "22.20153"
  },
  {
    "country": "HU",
    "name": "Heves",
    "lat": "47.6",
    "lng": "20.28333"
  },
  {
    "country": "HU",
    "name": "Hernádnémeti",
    "lat": "48.06667",
    "lng": "20.98333"
  },
  {
    "country": "HU",
    "name": "Hejőbába",
    "lat": "47.9",
    "lng": "20.95"
  },
  {
    "country": "HU",
    "name": "Harsány",
    "lat": "47.96667",
    "lng": "20.75"
  },
  {
    "country": "HU",
    "name": "Halmaj",
    "lat": "48.25",
    "lng": "21"
  },
  {
    "country": "HU",
    "name": "Hajdúszovát",
    "lat": "47.38333",
    "lng": "21.48333"
  },
  {
    "country": "HU",
    "name": "Hajdúszoboszló",
    "lat": "47.45",
    "lng": "21.4"
  },
  {
    "country": "HU",
    "name": "Hajdúsámson",
    "lat": "47.6",
    "lng": "21.76667"
  },
  {
    "country": "HU",
    "name": "Hajdúnánás",
    "lat": "47.85",
    "lng": "21.43333"
  },
  {
    "country": "HU",
    "name": "Hajdúhadház",
    "lat": "47.68333",
    "lng": "21.66667"
  },
  {
    "country": "HU",
    "name": "Hajdúdorog",
    "lat": "47.81667",
    "lng": "21.5"
  },
  {
    "country": "HU",
    "name": "Hajdúböszörmény",
    "lat": "47.66667",
    "lng": "21.51667"
  },
  {
    "country": "HU",
    "name": "Hajdúbagos",
    "lat": "47.39295",
    "lng": "21.66551"
  },
  {
    "country": "HU",
    "name": "Gyulaháza",
    "lat": "48.13333",
    "lng": "22.11667"
  },
  {
    "country": "HU",
    "name": "Gyula",
    "lat": "46.65",
    "lng": "21.28333"
  },
  {
    "country": "HU",
    "name": "Gyomaendrőd",
    "lat": "46.93333",
    "lng": "20.83333"
  },
  {
    "country": "HU",
    "name": "Görbeháza",
    "lat": "47.83333",
    "lng": "21.23333"
  },
  {
    "country": "HU",
    "name": "Gönc",
    "lat": "48.46667",
    "lng": "21.28333"
  },
  {
    "country": "HU",
    "name": "Gesztely",
    "lat": "48.1",
    "lng": "20.96667"
  },
  {
    "country": "HU",
    "name": "Gégény",
    "lat": "48.15",
    "lng": "21.95"
  },
  {
    "country": "HU",
    "name": "Gádoros",
    "lat": "46.66667",
    "lng": "20.6"
  },
  {
    "country": "HU",
    "name": "Füzesgyarmat",
    "lat": "47.1",
    "lng": "21.21667"
  },
  {
    "country": "HU",
    "name": "Füzesabony",
    "lat": "47.75",
    "lng": "20.41667"
  },
  {
    "country": "HU",
    "name": "Földes",
    "lat": "47.3",
    "lng": "21.36667"
  },
  {
    "country": "HU",
    "name": "Földeák",
    "lat": "46.31667",
    "lng": "20.5"
  },
  {
    "country": "HU",
    "name": "Fényeslitke",
    "lat": "48.27133",
    "lng": "22.10009"
  },
  {
    "country": "HU",
    "name": "Felsőzsolca",
    "lat": "48.1",
    "lng": "20.86667"
  },
  {
    "country": "HU",
    "name": "Felsőtárkány",
    "lat": "47.96667",
    "lng": "20.41667"
  },
  {
    "country": "HU",
    "name": "Fehérgyarmat",
    "lat": "47.98333",
    "lng": "22.51667"
  },
  {
    "country": "HU",
    "name": "Fegyvernek",
    "lat": "47.26667",
    "lng": "20.53333"
  },
  {
    "country": "HU",
    "name": "Farkaslyuk",
    "lat": "48.18333",
    "lng": "20.31667"
  },
  {
    "country": "HU",
    "name": "Fábiánsebestyén",
    "lat": "46.68333",
    "lng": "20.46667"
  },
  {
    "country": "HU",
    "name": "Erdőtelek",
    "lat": "47.68333",
    "lng": "20.31667"
  },
  {
    "country": "HU",
    "name": "Encsencs",
    "lat": "47.73333",
    "lng": "22.11667"
  },
  {
    "country": "HU",
    "name": "Encs",
    "lat": "48.33333",
    "lng": "21.13333"
  },
  {
    "country": "HU",
    "name": "Emőd",
    "lat": "47.93333",
    "lng": "20.81667"
  },
  {
    "country": "HU",
    "name": "Elek",
    "lat": "46.53333",
    "lng": "21.25"
  },
  {
    "country": "HU",
    "name": "Egyek",
    "lat": "47.63333",
    "lng": "20.9"
  },
  {
    "country": "HU",
    "name": "Egerszalók",
    "lat": "47.86667",
    "lng": "20.33333"
  },
  {
    "country": "HU",
    "name": "Eger",
    "lat": "47.90265",
    "lng": "20.37329"
  },
  {
    "country": "HU",
    "name": "Edelény",
    "lat": "48.3",
    "lng": "20.73333"
  },
  {
    "country": "HU",
    "name": "Ebes",
    "lat": "47.46667",
    "lng": "21.5"
  },
  {
    "country": "HU",
    "name": "Domoszló",
    "lat": "47.83333",
    "lng": "20.11667"
  },
  {
    "country": "HU",
    "name": "Dombrád",
    "lat": "48.23333",
    "lng": "21.93333"
  },
  {
    "country": "HU",
    "name": "Dombegyház",
    "lat": "46.33333",
    "lng": "21.13333"
  },
  {
    "country": "HU",
    "name": "Domaszék",
    "lat": "46.24917",
    "lng": "20.01111"
  },
  {
    "country": "HU",
    "name": "Döge",
    "lat": "48.26246",
    "lng": "22.06339"
  },
  {
    "country": "HU",
    "name": "Doboz",
    "lat": "46.73333",
    "lng": "21.25"
  },
  {
    "country": "HU",
    "name": "Dévaványa",
    "lat": "47.03333",
    "lng": "20.96667"
  },
  {
    "country": "HU",
    "name": "Deszk",
    "lat": "46.21802",
    "lng": "20.24322"
  },
  {
    "country": "HU",
    "name": "Derecske",
    "lat": "47.35",
    "lng": "21.56667"
  },
  {
    "country": "HU",
    "name": "Demecser",
    "lat": "48.11648",
    "lng": "21.92624"
  },
  {
    "country": "HU",
    "name": "Debrecen",
    "lat": "47.53333",
    "lng": "21.63333"
  },
  {
    "country": "HU",
    "name": "Csorvás",
    "lat": "46.63333",
    "lng": "20.83333"
  },
  {
    "country": "HU",
    "name": "Csongrád",
    "lat": "46.71332",
    "lng": "20.14241"
  },
  {
    "country": "HU",
    "name": "Csökmő",
    "lat": "47.03333",
    "lng": "21.3"
  },
  {
    "country": "HU",
    "name": "Cserkeszőlő",
    "lat": "46.8632",
    "lng": "20.18701"
  },
  {
    "country": "HU",
    "name": "Csenger",
    "lat": "47.83582",
    "lng": "22.68096"
  },
  {
    "country": "HU",
    "name": "Csanytelek",
    "lat": "46.59501",
    "lng": "20.12342"
  },
  {
    "country": "HU",
    "name": "Csanádpalota",
    "lat": "46.25",
    "lng": "20.73333"
  },
  {
    "country": "HU",
    "name": "Csanádapáca",
    "lat": "46.55",
    "lng": "20.88333"
  },
  {
    "country": "HU",
    "name": "Cigánd",
    "lat": "48.25561",
    "lng": "21.89195"
  },
  {
    "country": "HU",
    "name": "Cibakháza",
    "lat": "46.95976",
    "lng": "20.19753"
  },
  {
    "country": "HU",
    "name": "Buj",
    "lat": "48.1",
    "lng": "21.65"
  },
  {
    "country": "HU",
    "name": "Bucsa",
    "lat": "47.2",
    "lng": "21"
  },
  {
    "country": "HU",
    "name": "Borsodnádasd",
    "lat": "48.11667",
    "lng": "20.25"
  },
  {
    "country": "HU",
    "name": "Boldva",
    "lat": "48.21667",
    "lng": "20.8"
  },
  {
    "country": "HU",
    "name": "Bököny",
    "lat": "47.73333",
    "lng": "21.75"
  },
  {
    "country": "HU",
    "name": "Bogács",
    "lat": "47.9",
    "lng": "20.53333"
  },
  {
    "country": "HU",
    "name": "Bőcs",
    "lat": "48.05",
    "lng": "20.96667"
  },
  {
    "country": "HU",
    "name": "Biharnagybajom",
    "lat": "47.21667",
    "lng": "21.23333"
  },
  {
    "country": "HU",
    "name": "Biharkeresztes",
    "lat": "47.13333",
    "lng": "21.71667"
  },
  {
    "country": "HU",
    "name": "Besenyszög",
    "lat": "47.3",
    "lng": "20.26667"
  },
  {
    "country": "HU",
    "name": "Besenyőtelek",
    "lat": "47.7",
    "lng": "20.43333"
  },
  {
    "country": "HU",
    "name": "Berettyóújfalu",
    "lat": "47.21667",
    "lng": "21.55"
  },
  {
    "country": "HU",
    "name": "Bélapátfalva",
    "lat": "48.05",
    "lng": "20.36667"
  },
  {
    "country": "HU",
    "name": "Békésszentandrás",
    "lat": "46.86667",
    "lng": "20.48333"
  },
  {
    "country": "HU",
    "name": "Békéssámson",
    "lat": "46.41667",
    "lng": "20.63333"
  },
  {
    "country": "HU",
    "name": "Békéscsaba",
    "lat": "46.68333",
    "lng": "21.1"
  },
  {
    "country": "HU",
    "name": "Békés",
    "lat": "46.76667",
    "lng": "21.13333"
  },
  {
    "country": "HU",
    "name": "Bekecs",
    "lat": "48.15",
    "lng": "21.18333"
  },
  {
    "country": "HU",
    "name": "Battonya",
    "lat": "46.28333",
    "lng": "21.01667"
  },
  {
    "country": "HU",
    "name": "Báránd",
    "lat": "47.3",
    "lng": "21.23333"
  },
  {
    "country": "HU",
    "name": "Balmazújváros",
    "lat": "47.61667",
    "lng": "21.35"
  },
  {
    "country": "HU",
    "name": "Balkány",
    "lat": "47.77066",
    "lng": "21.86314"
  },
  {
    "country": "HU",
    "name": "Balástya",
    "lat": "46.42277",
    "lng": "20.00816"
  },
  {
    "country": "HU",
    "name": "Baktalórántháza",
    "lat": "48",
    "lng": "22.08333"
  },
  {
    "country": "HU",
    "name": "Baks",
    "lat": "46.54297",
    "lng": "20.10213"
  },
  {
    "country": "HU",
    "name": "Bagamér",
    "lat": "47.44882",
    "lng": "21.989"
  },
  {
    "country": "HU",
    "name": "Aszaló",
    "lat": "48.21667",
    "lng": "20.96667"
  },
  {
    "country": "HU",
    "name": "Arnót",
    "lat": "48.13058",
    "lng": "20.85832"
  },
  {
    "country": "HU",
    "name": "Arló",
    "lat": "48.18333",
    "lng": "20.26667"
  },
  {
    "country": "HU",
    "name": "Aranyosapáti",
    "lat": "48.20595",
    "lng": "22.25916"
  },
  {
    "country": "HU",
    "name": "Apátfalva",
    "lat": "46.16667",
    "lng": "20.58333"
  },
  {
    "country": "HU",
    "name": "Apagy",
    "lat": "47.96431",
    "lng": "21.93539"
  },
  {
    "country": "HU",
    "name": "Andornaktálya",
    "lat": "47.85",
    "lng": "20.41667"
  },
  {
    "country": "HU",
    "name": "Anarcs",
    "lat": "48.17642",
    "lng": "22.11167"
  },
  {
    "country": "HU",
    "name": "Alsózsolca",
    "lat": "48.06982",
    "lng": "20.88046"
  },
  {
    "country": "HU",
    "name": "Alattyán",
    "lat": "47.42705",
    "lng": "20.04219"
  },
  {
    "country": "HU",
    "name": "Ajak",
    "lat": "48.17664",
    "lng": "22.06273"
  },
  {
    "country": "HU",
    "name": "Abony",
    "lat": "47.1899",
    "lng": "20.00476"
  },
  {
    "country": "HU",
    "name": "Abaújszántó",
    "lat": "48.28333",
    "lng": "21.2"
  },
  {
    "country": "HU",
    "name": "Abasár",
    "lat": "47.79705",
    "lng": "20.00324"
  },
  {
    "country": "HU",
    "name": "Abádszalók",
    "lat": "47.46667",
    "lng": "20.6"
  },
  {
    "country": "HU",
    "name": "Zugló",
    "lat": "47.51758",
    "lng": "19.10549"
  },
  {
    "country": "HU",
    "name": "Zsombó",
    "lat": "46.32566",
    "lng": "19.97464"
  },
  {
    "country": "HU",
    "name": "Zsámbok",
    "lat": "47.54381",
    "lng": "19.61048"
  },
  {
    "country": "HU",
    "name": "Zsámbék",
    "lat": "47.54814",
    "lng": "18.72011"
  },
  {
    "country": "HU",
    "name": "Zomba",
    "lat": "46.41084",
    "lng": "18.56577"
  },
  {
    "country": "HU",
    "name": "Zirc",
    "lat": "47.26362",
    "lng": "17.87373"
  },
  {
    "country": "HU",
    "name": "Zánka",
    "lat": "46.87146",
    "lng": "17.68473"
  },
  {
    "country": "HU",
    "name": "Zámoly",
    "lat": "47.31667",
    "lng": "18.4081"
  },
  {
    "country": "HU",
    "name": "Zamárdi",
    "lat": "46.88488",
    "lng": "17.95366"
  },
  {
    "country": "HU",
    "name": "Zalaszentgrót",
    "lat": "46.94474",
    "lng": "17.07925"
  },
  {
    "country": "HU",
    "name": "Zalalövő",
    "lat": "46.84802",
    "lng": "16.5875"
  },
  {
    "country": "HU",
    "name": "Zalakomár",
    "lat": "46.53795",
    "lng": "17.18094"
  },
  {
    "country": "HU",
    "name": "Zalaegerszeg",
    "lat": "46.84",
    "lng": "16.84389"
  },
  {
    "country": "HU",
    "name": "Zákányszék",
    "lat": "46.27453",
    "lng": "19.88975"
  },
  {
    "country": "HU",
    "name": "Zagyvaszántó",
    "lat": "47.77703",
    "lng": "19.67092"
  },
  {
    "country": "HU",
    "name": "Vonyarcvashegy",
    "lat": "46.75742",
    "lng": "17.31172"
  },
  {
    "country": "HU",
    "name": "Visegrád",
    "lat": "47.78526",
    "lng": "18.9709"
  },
  {
    "country": "HU",
    "name": "Villány",
    "lat": "45.86889",
    "lng": "18.45389"
  },
  {
    "country": "HU",
    "name": "Veszprém",
    "lat": "47.09327",
    "lng": "17.91149"
  },
  {
    "country": "HU",
    "name": "Vértesszőlős",
    "lat": "47.62106",
    "lng": "18.3813"
  },
  {
    "country": "HU",
    "name": "Verőce",
    "lat": "47.82468",
    "lng": "19.03484"
  },
  {
    "country": "HU",
    "name": "Veresegyház",
    "lat": "47.6459",
    "lng": "19.29536"
  },
  {
    "country": "HU",
    "name": "Vép",
    "lat": "47.23041",
    "lng": "16.72248"
  },
  {
    "country": "HU",
    "name": "Velence",
    "lat": "47.23855",
    "lng": "18.65484"
  },
  {
    "country": "HU",
    "name": "Vecsés",
    "lat": "47.40705",
    "lng": "19.28648"
  },
  {
    "country": "HU",
    "name": "Vasvár",
    "lat": "47.04928",
    "lng": "16.79954"
  },
  {
    "country": "HU",
    "name": "Vaskút",
    "lat": "46.10782",
    "lng": "18.98514"
  },
  {
    "country": "HU",
    "name": "Várpalota",
    "lat": "47.19936",
    "lng": "18.13954"
  },
  {
    "country": "HU",
    "name": "Városföld",
    "lat": "46.81674",
    "lng": "19.75668"
  },
  {
    "country": "HU",
    "name": "Vámosgyörk",
    "lat": "47.68429",
    "lng": "19.92924"
  },
  {
    "country": "HU",
    "name": "Valkó",
    "lat": "47.56391",
    "lng": "19.51267"
  },
  {
    "country": "HU",
    "name": "Vál",
    "lat": "47.36264",
    "lng": "18.67931"
  },
  {
    "country": "HU",
    "name": "Vajszló",
    "lat": "45.85957",
    "lng": "17.98406"
  },
  {
    "country": "HU",
    "name": "Vácszentlászló",
    "lat": "47.574",
    "lng": "19.53771"
  },
  {
    "country": "HU",
    "name": "Vác",
    "lat": "47.77591",
    "lng": "19.13612"
  },
  {
    "country": "HU",
    "name": "Üröm",
    "lat": "47.59674",
    "lng": "19.01583"
  },
  {
    "country": "HU",
    "name": "Úrkút",
    "lat": "47.08505",
    "lng": "17.64393"
  },
  {
    "country": "HU",
    "name": "Úri",
    "lat": "47.41429",
    "lng": "19.52762"
  },
  {
    "country": "HU",
    "name": "Üllő",
    "lat": "47.38771",
    "lng": "19.35533"
  },
  {
    "country": "HU",
    "name": "Üllés",
    "lat": "46.33611",
    "lng": "19.84454"
  },
  {
    "country": "HU",
    "name": "Újszilvás",
    "lat": "47.27477",
    "lng": "19.92477"
  },
  {
    "country": "HU",
    "name": "Újhartyán",
    "lat": "47.21981",
    "lng": "19.38638"
  },
  {
    "country": "HU",
    "name": "Türje",
    "lat": "46.98366",
    "lng": "17.10742"
  },
  {
    "country": "HU",
    "name": "Tura",
    "lat": "47.60924",
    "lng": "19.60279"
  },
  {
    "country": "HU",
    "name": "Törtel",
    "lat": "47.12209",
    "lng": "19.93714"
  },
  {
    "country": "HU",
    "name": "Törökbálint",
    "lat": "47.42931",
    "lng": "18.91356"
  },
  {
    "country": "HU",
    "name": "Tompa",
    "lat": "46.20605",
    "lng": "19.5391"
  },
  {
    "country": "HU",
    "name": "Töltéstava",
    "lat": "47.62609",
    "lng": "17.73376"
  },
  {
    "country": "HU",
    "name": "Tolna",
    "lat": "46.42677",
    "lng": "18.78248"
  },
  {
    "country": "HU",
    "name": "Tököl",
    "lat": "47.32178",
    "lng": "18.96249"
  },
  {
    "country": "HU",
    "name": "Tokod",
    "lat": "47.72277",
    "lng": "18.65889"
  },
  {
    "country": "HU",
    "name": "Tóalmás",
    "lat": "47.50782",
    "lng": "19.66657"
  },
  {
    "country": "HU",
    "name": "Tihany",
    "lat": "46.91369",
    "lng": "17.88918"
  },
  {
    "country": "HU",
    "name": "Tét",
    "lat": "47.51922",
    "lng": "17.50802"
  },
  {
    "country": "HU",
    "name": "Tengelic",
    "lat": "46.52878",
    "lng": "18.71117"
  },
  {
    "country": "HU",
    "name": "Telki",
    "lat": "47.54791",
    "lng": "18.82816"
  },
  {
    "country": "HU",
    "name": "Tázlár",
    "lat": "46.54824",
    "lng": "19.51436"
  },
  {
    "country": "HU",
    "name": "Tatabánya",
    "lat": "47.58494",
    "lng": "18.39325"
  },
  {
    "country": "HU",
    "name": "Tata",
    "lat": "47.65289",
    "lng": "18.31838"
  },
  {
    "country": "HU",
    "name": "Tát",
    "lat": "47.74148",
    "lng": "18.64813"
  },
  {
    "country": "HU",
    "name": "Taszár",
    "lat": "46.37467",
    "lng": "17.90594"
  },
  {
    "country": "HU",
    "name": "Tass",
    "lat": "47.02095",
    "lng": "19.02988"
  },
  {
    "country": "HU",
    "name": "Tárnok",
    "lat": "47.37327",
    "lng": "18.84579"
  },
  {
    "country": "HU",
    "name": "Tarján",
    "lat": "47.61042",
    "lng": "18.5107"
  },
  {
    "country": "HU",
    "name": "Tardos",
    "lat": "47.66192",
    "lng": "18.44416"
  },
  {
    "country": "HU",
    "name": "Tar",
    "lat": "47.95371",
    "lng": "19.7461"
  },
  {
    "country": "HU",
    "name": "Tapolca",
    "lat": "46.88152",
    "lng": "17.44117"
  },
  {
    "country": "HU",
    "name": "Táplánszentkereszt",
    "lat": "47.19496",
    "lng": "16.69613"
  },
  {
    "country": "HU",
    "name": "Tápiószőlős",
    "lat": "47.30248",
    "lng": "19.85133"
  },
  {
    "country": "HU",
    "name": "Tápiószentmárton",
    "lat": "47.3399",
    "lng": "19.74648"
  },
  {
    "country": "HU",
    "name": "Tápiószele",
    "lat": "47.33609",
    "lng": "19.87724"
  },
  {
    "country": "HU",
    "name": "Tápiószecső",
    "lat": "47.45",
    "lng": "19.60923"
  },
  {
    "country": "HU",
    "name": "Sülysáp",
    "lat": "47.45206",
    "lng": "19.53369"
  },
  {
    "country": "HU",
    "name": "Tápióság",
    "lat": "47.402",
    "lng": "19.63047"
  },
  {
    "country": "HU",
    "name": "Tápiógyörgye",
    "lat": "47.33505",
    "lng": "19.95276"
  },
  {
    "country": "HU",
    "name": "Tápióbicske",
    "lat": "47.36096",
    "lng": "19.68609"
  },
  {
    "country": "HU",
    "name": "Tamási",
    "lat": "46.63333",
    "lng": "18.28333"
  },
  {
    "country": "HU",
    "name": "Taksony",
    "lat": "47.32968",
    "lng": "19.06695"
  },
  {
    "country": "HU",
    "name": "Tahitótfalu",
    "lat": "47.75",
    "lng": "19.1"
  },
  {
    "country": "HU",
    "name": "Táborfalva",
    "lat": "47.09942",
    "lng": "19.47837"
  },
  {
    "country": "HU",
    "name": "Tab",
    "lat": "46.73135",
    "lng": "18.03201"
  },
  {
    "country": "HU",
    "name": "Szurdokpüspöki",
    "lat": "47.85923",
    "lng": "19.69218"
  },
  {
    "country": "HU",
    "name": "Szomód",
    "lat": "47.68492",
    "lng": "18.34061"
  },
  {
    "country": "HU",
    "name": "Szombathely",
    "lat": "47.23088",
    "lng": "16.62155"
  },
  {
    "country": "HU",
    "name": "Sződliget",
    "lat": "47.73259",
    "lng": "19.14749"
  },
  {
    "country": "HU",
    "name": "Sződ",
    "lat": "47.72439",
    "lng": "19.17046"
  },
  {
    "country": "HU",
    "name": "Szob",
    "lat": "47.81921",
    "lng": "18.8702"
  },
  {
    "country": "HU",
    "name": "Szigetvár",
    "lat": "46.04865",
    "lng": "17.80554"
  },
  {
    "country": "HU",
    "name": "Szigetújfalu",
    "lat": "47.23417",
    "lng": "18.92746"
  },
  {
    "country": "HU",
    "name": "Szigetszentmiklós",
    "lat": "47.34382",
    "lng": "19.04335"
  },
  {
    "country": "HU",
    "name": "Szigethalom",
    "lat": "47.32228",
    "lng": "19.00262"
  },
  {
    "country": "HU",
    "name": "Szigetcsép",
    "lat": "47.26492",
    "lng": "18.97048"
  },
  {
    "country": "HU",
    "name": "Szentmártonkáta",
    "lat": "47.45419",
    "lng": "19.70143"
  },
  {
    "country": "HU",
    "name": "Szentlőrinckáta",
    "lat": "47.51947",
    "lng": "19.75286"
  },
  {
    "country": "HU",
    "name": "Szentlőrinc",
    "lat": "46.04016",
    "lng": "17.98719"
  },
  {
    "country": "HU",
    "name": "Szentkirályszabadja",
    "lat": "47.0576",
    "lng": "17.97052"
  },
  {
    "country": "HU",
    "name": "Szentkirály",
    "lat": "46.91892",
    "lng": "19.91846"
  },
  {
    "country": "HU",
    "name": "Szentgotthárd",
    "lat": "46.95261",
    "lng": "16.27358"
  },
  {
    "country": "HU",
    "name": "Szentgálpuszta",
    "lat": "46.37479",
    "lng": "18.62601"
  },
  {
    "country": "HU",
    "name": "Szentendre",
    "lat": "47.66943",
    "lng": "19.07561"
  },
  {
    "country": "HU",
    "name": "Szekszárd",
    "lat": "46.35014",
    "lng": "18.70905"
  },
  {
    "country": "HU",
    "name": "Székesfehérvár",
    "lat": "47.18995",
    "lng": "18.41034"
  },
  {
    "country": "HU",
    "name": "Szedres",
    "lat": "46.47551",
    "lng": "18.68305"
  },
  {
    "country": "HU",
    "name": "Szécsény",
    "lat": "48.08057",
    "lng": "19.52019"
  },
  {
    "country": "HU",
    "name": "Százhalombatta",
    "lat": "47.32579",
    "lng": "18.92141"
  },
  {
    "country": "HU",
    "name": "Szászvár",
    "lat": "46.27673",
    "lng": "18.37566"
  },
  {
    "country": "HU",
    "name": "Szárliget",
    "lat": "47.51581",
    "lng": "18.4948"
  },
  {
    "country": "HU",
    "name": "Szany",
    "lat": "47.46423",
    "lng": "17.30402"
  },
  {
    "country": "HU",
    "name": "Szank",
    "lat": "46.55713",
    "lng": "19.66103"
  },
  {
    "country": "HU",
    "name": "Szalkszentmárton",
    "lat": "46.97565",
    "lng": "19.01178"
  },
  {
    "country": "HU",
    "name": "Szada",
    "lat": "47.63333",
    "lng": "19.31667"
  },
  {
    "country": "HU",
    "name": "Szabadszállás",
    "lat": "46.87575",
    "lng": "19.22324"
  },
  {
    "country": "HU",
    "name": "Szabadbattyán",
    "lat": "47.11902",
    "lng": "18.36823"
  },
  {
    "country": "HU",
    "name": "Süttő",
    "lat": "47.75887",
    "lng": "18.44873"
  },
  {
    "country": "HU",
    "name": "Sümeg",
    "lat": "46.97703",
    "lng": "17.28209"
  },
  {
    "country": "HU",
    "name": "Sükösd",
    "lat": "46.28181",
    "lng": "18.99524"
  },
  {
    "country": "HU",
    "name": "Sóskút",
    "lat": "47.40665",
    "lng": "18.82247"
  },
  {
    "country": "HU",
    "name": "Sopron",
    "lat": "47.68501",
    "lng": "16.59049"
  },
  {
    "country": "HU",
    "name": "Soponya",
    "lat": "47.01485",
    "lng": "18.45343"
  },
  {
    "country": "HU",
    "name": "Somoskőújfalu",
    "lat": "48.16374",
    "lng": "19.82303"
  },
  {
    "country": "HU",
    "name": "Somogyvár",
    "lat": "46.5814",
    "lng": "17.66289"
  },
  {
    "country": "HU",
    "name": "Solymár",
    "lat": "47.59246",
    "lng": "18.93212"
  },
  {
    "country": "HU",
    "name": "Soltvadkert",
    "lat": "46.57889",
    "lng": "19.39389"
  },
  {
    "country": "HU",
    "name": "Solt",
    "lat": "46.80067",
    "lng": "18.99993"
  },
  {
    "country": "HU",
    "name": "Siófok",
    "lat": "46.90413",
    "lng": "18.058"
  },
  {
    "country": "HU",
    "name": "Simontornya",
    "lat": "46.75462",
    "lng": "18.5549"
  },
  {
    "country": "HU",
    "name": "Siklós",
    "lat": "45.85499",
    "lng": "18.29752"
  },
  {
    "country": "HU",
    "name": "Seregélyes",
    "lat": "47.1105",
    "lng": "18.565"
  },
  {
    "country": "HU",
    "name": "Sellye",
    "lat": "45.87247",
    "lng": "17.84711"
  },
  {
    "country": "HU",
    "name": "Segesd",
    "lat": "46.34142",
    "lng": "17.35132"
  },
  {
    "country": "HU",
    "name": "Sásd",
    "lat": "46.2552",
    "lng": "18.10776"
  },
  {
    "country": "HU",
    "name": "Sárvár",
    "lat": "47.25395",
    "lng": "16.93525"
  },
  {
    "country": "HU",
    "name": "Sárszentmihály",
    "lat": "47.15321",
    "lng": "18.33879"
  },
  {
    "country": "HU",
    "name": "Sárosd",
    "lat": "47.04273",
    "lng": "18.64357"
  },
  {
    "country": "HU",
    "name": "Sármellék",
    "lat": "46.71221",
    "lng": "17.16865"
  },
  {
    "country": "HU",
    "name": "Sárkeresztúr",
    "lat": "47.0054",
    "lng": "18.54391"
  },
  {
    "country": "HU",
    "name": "Sárisáp",
    "lat": "47.677",
    "lng": "18.67933"
  },
  {
    "country": "HU",
    "name": "Sárbogárd",
    "lat": "46.88692",
    "lng": "18.62041"
  },
  {
    "country": "HU",
    "name": "Salgótarján",
    "lat": "48.09872",
    "lng": "19.80303"
  },
  {
    "country": "HU",
    "name": "Ruzsa",
    "lat": "46.28806",
    "lng": "19.74714"
  },
  {
    "country": "HU",
    "name": "Rózsaszentmárton",
    "lat": "47.782",
    "lng": "19.7421"
  },
  {
    "country": "HU",
    "name": "Romhány",
    "lat": "47.92618",
    "lng": "19.25723"
  },
  {
    "country": "HU",
    "name": "Rimóc",
    "lat": "48.03695",
    "lng": "19.5301"
  },
  {
    "country": "HU",
    "name": "Révfülöp",
    "lat": "46.82573",
    "lng": "17.61967"
  },
  {
    "country": "HU",
    "name": "Rétság",
    "lat": "47.92816",
    "lng": "19.1372"
  },
  {
    "country": "HU",
    "name": "Répcelak",
    "lat": "47.42105",
    "lng": "17.01795"
  },
  {
    "country": "HU",
    "name": "Rajka",
    "lat": "47.99643",
    "lng": "17.19821"
  },
  {
    "country": "HU",
    "name": "Ráckeve",
    "lat": "47.16095",
    "lng": "18.94478"
  },
  {
    "country": "HU",
    "name": "Ráckeresztúr",
    "lat": "47.2736",
    "lng": "18.83343"
  },
  {
    "country": "HU",
    "name": "Rácalmás",
    "lat": "47.02263",
    "lng": "18.94056"
  },
  {
    "country": "HU",
    "name": "Rábapatona",
    "lat": "47.63224",
    "lng": "17.48004"
  },
  {
    "country": "HU",
    "name": "Pusztavám",
    "lat": "47.42948",
    "lng": "18.22648"
  },
  {
    "country": "HU",
    "name": "Pusztaszer",
    "lat": "46.55083",
    "lng": "19.98823"
  },
  {
    "country": "HU",
    "name": "Pusztaszabolcs",
    "lat": "47.13718",
    "lng": "18.76704"
  },
  {
    "country": "HU",
    "name": "Pomáz",
    "lat": "47.64227",
    "lng": "19.02784"
  },
  {
    "country": "HU",
    "name": "Polgárdi",
    "lat": "47.06099",
    "lng": "18.302"
  },
  {
    "country": "HU",
    "name": "Pincehely",
    "lat": "46.68095",
    "lng": "18.43935"
  },
  {
    "country": "HU",
    "name": "Pilisvörösvár",
    "lat": "47.61386",
    "lng": "18.90893"
  },
  {
    "country": "HU",
    "name": "Pilisszentkereszt",
    "lat": "47.69143",
    "lng": "18.90503"
  },
  {
    "country": "HU",
    "name": "Pilisszentiván",
    "lat": "47.60964",
    "lng": "18.8994"
  },
  {
    "country": "HU",
    "name": "Pilisszántó",
    "lat": "47.66909",
    "lng": "18.88762"
  },
  {
    "country": "HU",
    "name": "Pilismarót",
    "lat": "47.78464",
    "lng": "18.87539"
  },
  {
    "country": "HU",
    "name": "Piliscsév",
    "lat": "47.67924",
    "lng": "18.81872"
  },
  {
    "country": "HU",
    "name": "Piliscsaba",
    "lat": "47.63417",
    "lng": "18.82886"
  },
  {
    "country": "HU",
    "name": "Pilisborosjenő",
    "lat": "47.60744",
    "lng": "18.99322"
  },
  {
    "country": "HU",
    "name": "Pilis",
    "lat": "47.28904",
    "lng": "19.54848"
  },
  {
    "country": "HU",
    "name": "Petőfibánya",
    "lat": "47.77943",
    "lng": "19.7055"
  },
  {
    "country": "HU",
    "name": "Pétfürdő",
    "lat": "47.16667",
    "lng": "18.11667"
  },
  {
    "country": "HU",
    "name": "Péteri",
    "lat": "47.39104",
    "lng": "19.40981"
  },
  {
    "country": "HU",
    "name": "Perkáta",
    "lat": "47.04701",
    "lng": "18.78734"
  },
  {
    "country": "HU",
    "name": "Perbál",
    "lat": "47.58957",
    "lng": "18.76099"
  },
  {
    "country": "HU",
    "name": "Pér",
    "lat": "47.61153",
    "lng": "17.80632"
  },
  {
    "country": "HU",
    "name": "Pellérd",
    "lat": "46.03438",
    "lng": "18.15403"
  },
  {
    "country": "HU",
    "name": "Pécsvárad",
    "lat": "46.16033",
    "lng": "18.42321"
  },
  {
    "country": "HU",
    "name": "Pécs",
    "lat": "46.08333",
    "lng": "18.23333"
  },
  {
    "country": "HU",
    "name": "Pécel",
    "lat": "47.48962",
    "lng": "19.34162"
  },
  {
    "country": "HU",
    "name": "Pázmánd",
    "lat": "47.28755",
    "lng": "18.65356"
  },
  {
    "country": "HU",
    "name": "Páty",
    "lat": "47.51709",
    "lng": "18.82851"
  },
  {
    "country": "HU",
    "name": "Pásztó",
    "lat": "47.92019",
    "lng": "19.69829"
  },
  {
    "country": "HU",
    "name": "Parádsasvár",
    "lat": "47.9126",
    "lng": "19.97709"
  },
  {
    "country": "HU",
    "name": "Pápa",
    "lat": "47.33004",
    "lng": "17.4674"
  },
  {
    "country": "HU",
    "name": "Pannonhalma",
    "lat": "47.54946",
    "lng": "17.75535"
  },
  {
    "country": "HU",
    "name": "Pánd",
    "lat": "47.35333",
    "lng": "19.63571"
  },
  {
    "country": "HU",
    "name": "Palotás",
    "lat": "47.79528",
    "lng": "19.59618"
  },
  {
    "country": "HU",
    "name": "Pálmonostora",
    "lat": "46.62417",
    "lng": "19.95156"
  },
  {
    "country": "HU",
    "name": "Paks",
    "lat": "46.62648",
    "lng": "18.85962"
  },
  {
    "country": "HU",
    "name": "Pákozd",
    "lat": "47.21369",
    "lng": "18.53306"
  },
  {
    "country": "HU",
    "name": "Pacsa",
    "lat": "46.71981",
    "lng": "17.01401"
  },
  {
    "country": "HU",
    "name": "Ozora",
    "lat": "46.75133",
    "lng": "18.4001"
  },
  {
    "country": "HU",
    "name": "Öttevény",
    "lat": "47.71946",
    "lng": "17.48474"
  },
  {
    "country": "HU",
    "name": "Ősi",
    "lat": "47.14722",
    "lng": "18.18833"
  },
  {
    "country": "HU",
    "name": "Oroszlány",
    "lat": "47.48671",
    "lng": "18.31225"
  },
  {
    "country": "HU",
    "name": "Örkény",
    "lat": "47.12991",
    "lng": "19.43324"
  },
  {
    "country": "HU",
    "name": "Orgovány",
    "lat": "46.75087",
    "lng": "19.47259"
  },
  {
    "country": "HU",
    "name": "Őrbottyán",
    "lat": "47.68711",
    "lng": "19.28239"
  },
  {
    "country": "HU",
    "name": "Őcsény",
    "lat": "46.3137",
    "lng": "18.75749"
  },
  {
    "country": "HU",
    "name": "Ócsa",
    "lat": "47.29986",
    "lng": "19.23057"
  },
  {
    "country": "HU",
    "name": "Nyúl",
    "lat": "47.59047",
    "lng": "17.68904"
  },
  {
    "country": "HU",
    "name": "Nyergesújfalu",
    "lat": "47.76027",
    "lng": "18.55694"
  },
  {
    "country": "HU",
    "name": "Nyárlőrinc",
    "lat": "46.86017",
    "lng": "19.87836"
  },
  {
    "country": "HU",
    "name": "Nyáregyháza",
    "lat": "47.26175",
    "lng": "19.50146"
  },
  {
    "country": "HU",
    "name": "Neszmély",
    "lat": "47.73585",
    "lng": "18.35966"
  },
  {
    "country": "HU",
    "name": "Németkér",
    "lat": "46.71637",
    "lng": "18.76311"
  },
  {
    "country": "HU",
    "name": "Nemesvámos",
    "lat": "47.05514",
    "lng": "17.87477"
  },
  {
    "country": "HU",
    "name": "Nemesnádudvar",
    "lat": "46.34051",
    "lng": "19.05115"
  },
  {
    "country": "HU",
    "name": "Naszály",
    "lat": "47.70329",
    "lng": "18.25751"
  },
  {
    "country": "HU",
    "name": "dunaújváros",
    "lat": "46.96737",
    "lng": "18.93288"
  },
  {
    "country": "HU",
    "name": "Nagytarcsa",
    "lat": "47.53128",
    "lng": "19.28343"
  },
  {
    "country": "HU",
    "name": "Nagyréde",
    "lat": "47.76543",
    "lng": "19.84819"
  },
  {
    "country": "HU",
    "name": "Nagyoroszi",
    "lat": "48.00503",
    "lng": "19.0905"
  },
  {
    "country": "HU",
    "name": "Nagymaros",
    "lat": "47.7928",
    "lng": "18.95984"
  },
  {
    "country": "HU",
    "name": "Nagymányok",
    "lat": "46.27911",
    "lng": "18.45489"
  },
  {
    "country": "HU",
    "name": "Nagykovácsi",
    "lat": "47.65",
    "lng": "19.01667"
  },
  {
    "country": "HU",
    "name": "Nagykőrös",
    "lat": "47.03419",
    "lng": "19.77857"
  },
  {
    "country": "HU",
    "name": "Nagykáta",
    "lat": "47.41514",
    "lng": "19.7441"
  },
  {
    "country": "HU",
    "name": "Nagykanizsa",
    "lat": "46.45347",
    "lng": "16.99104"
  },
  {
    "country": "HU",
    "name": "Nagyigmánd",
    "lat": "47.64093",
    "lng": "18.0813"
  },
  {
    "country": "HU",
    "name": "Nagydorog",
    "lat": "46.62749",
    "lng": "18.65565"
  },
  {
    "country": "HU",
    "name": "Nagycenk",
    "lat": "47.60435",
    "lng": "16.69732"
  },
  {
    "country": "HU",
    "name": "Nagybaracska",
    "lat": "46.04248",
    "lng": "18.9059"
  },
  {
    "country": "HU",
    "name": "Nagybajom",
    "lat": "46.39232",
    "lng": "17.51147"
  },
  {
    "country": "HU",
    "name": "Nagyatád",
    "lat": "46.22961",
    "lng": "17.35788"
  },
  {
    "country": "HU",
    "name": "Murakeresztúr",
    "lat": "46.36422",
    "lng": "16.88177"
  },
  {
    "country": "HU",
    "name": "Mosonmagyaróvár",
    "lat": "47.86789",
    "lng": "17.26994"
  },
  {
    "country": "HU",
    "name": "Mórahalom",
    "lat": "46.21806",
    "lng": "19.8851"
  },
  {
    "country": "HU",
    "name": "Mór",
    "lat": "47.37787",
    "lng": "18.20353"
  },
  {
    "country": "HU",
    "name": "Monor",
    "lat": "47.35133",
    "lng": "19.44733"
  },
  {
    "country": "HU",
    "name": "Mohács",
    "lat": "45.99306",
    "lng": "18.68306"
  },
  {
    "country": "HU",
    "name": "Mogyoród",
    "lat": "47.59748",
    "lng": "19.2407"
  },
  {
    "country": "HU",
    "name": "Mocsa",
    "lat": "47.66999",
    "lng": "18.18505"
  },
  {
    "country": "HU",
    "name": "Mihályi",
    "lat": "47.51384",
    "lng": "17.09507"
  },
  {
    "country": "HU",
    "name": "Mezőszilas",
    "lat": "46.81109",
    "lng": "18.47789"
  },
  {
    "country": "HU",
    "name": "Mezőfalva",
    "lat": "46.93184",
    "lng": "18.77177"
  },
  {
    "country": "HU",
    "name": "Mende",
    "lat": "47.43133",
    "lng": "19.45628"
  },
  {
    "country": "HU",
    "name": "Mélykút",
    "lat": "46.21509",
    "lng": "19.38102"
  },
  {
    "country": "HU",
    "name": "Mecseknádasd",
    "lat": "46.22468",
    "lng": "18.47076"
  },
  {
    "country": "HU",
    "name": "Mátraverebély",
    "lat": "47.97421",
    "lng": "19.78049"
  },
  {
    "country": "HU",
    "name": "Mátraterenye",
    "lat": "48.03267",
    "lng": "19.94762"
  },
  {
    "country": "HU",
    "name": "Mátranovák",
    "lat": "48.03809",
    "lng": "19.98257"
  },
  {
    "country": "HU",
    "name": "Martonvásár",
    "lat": "47.31601",
    "lng": "18.79045"
  },
  {
    "country": "HU",
    "name": "Marcali",
    "lat": "46.58498",
    "lng": "17.41196"
  },
  {
    "country": "HU",
    "name": "Mány",
    "lat": "47.53352",
    "lng": "18.65627"
  },
  {
    "country": "HU",
    "name": "Mágocs",
    "lat": "46.34998",
    "lng": "18.2324"
  },
  {
    "country": "HU",
    "name": "Maglód",
    "lat": "47.44258",
    "lng": "19.36438"
  },
  {
    "country": "HU",
    "name": "Madocsa",
    "lat": "46.6879",
    "lng": "18.95791"
  },
  {
    "country": "HU",
    "name": "Madaras",
    "lat": "46.0587",
    "lng": "19.26121"
  },
  {
    "country": "HU",
    "name": "Lovasberény",
    "lat": "47.30997",
    "lng": "18.55177"
  },
  {
    "country": "HU",
    "name": "Lőrinci",
    "lat": "47.73295",
    "lng": "19.67867"
  },
  {
    "country": "HU",
    "name": "Litér",
    "lat": "47.10104",
    "lng": "18.00454"
  },
  {
    "country": "HU",
    "name": "Letenye",
    "lat": "46.43301",
    "lng": "16.72583"
  },
  {
    "country": "HU",
    "name": "Lepsény",
    "lat": "46.99036",
    "lng": "18.24357"
  },
  {
    "country": "HU",
    "name": "Lenti",
    "lat": "46.62403",
    "lng": "16.53863"
  },
  {
    "country": "HU",
    "name": "Lengyeltóti",
    "lat": "46.67013",
    "lng": "17.64398"
  },
  {
    "country": "HU",
    "name": "Lébény",
    "lat": "47.73574",
    "lng": "17.39076"
  },
  {
    "country": "HU",
    "name": "Leányfalu",
    "lat": "47.71778",
    "lng": "19.08585"
  },
  {
    "country": "HU",
    "name": "Lánycsók",
    "lat": "46.00543",
    "lng": "18.62526"
  },
  {
    "country": "HU",
    "name": "Lakitelek",
    "lat": "46.87601",
    "lng": "19.99504"
  },
  {
    "country": "HU",
    "name": "Lajosmizse",
    "lat": "47.02133",
    "lng": "19.56171"
  },
  {
    "country": "HU",
    "name": "Lajoskomárom",
    "lat": "46.84201",
    "lng": "18.33763"
  },
  {
    "country": "HU",
    "name": "Lábod",
    "lat": "46.20535",
    "lng": "17.45419"
  },
  {
    "country": "HU",
    "name": "Lábatlan",
    "lat": "47.74735",
    "lng": "18.49623"
  },
  {
    "country": "HU",
    "name": "Kunszentmiklós",
    "lat": "47.02699",
    "lng": "19.12575"
  },
  {
    "country": "HU",
    "name": "Kunfehértó",
    "lat": "46.36091",
    "lng": "19.41454"
  },
  {
    "country": "HU",
    "name": "Kozármisleny",
    "lat": "46.02967",
    "lng": "18.2921"
  },
  {
    "country": "HU",
    "name": "Kőszeg",
    "lat": "47.38922",
    "lng": "16.541"
  },
  {
    "country": "HU",
    "name": "Kosd",
    "lat": "47.80791",
    "lng": "19.17821"
  },
  {
    "country": "HU",
    "name": "Környe",
    "lat": "47.54668",
    "lng": "18.32081"
  },
  {
    "country": "HU",
    "name": "Körmend",
    "lat": "47.01096",
    "lng": "16.60596"
  },
  {
    "country": "HU",
    "name": "Kóny",
    "lat": "47.63053",
    "lng": "17.35717"
  },
  {
    "country": "HU",
    "name": "Komló",
    "lat": "46.19278",
    "lng": "18.26494"
  },
  {
    "country": "HU",
    "name": "Komárom",
    "lat": "47.74318",
    "lng": "18.11913"
  },
  {
    "country": "HU",
    "name": "Kóka",
    "lat": "47.48552",
    "lng": "19.57876"
  },
  {
    "country": "HU",
    "name": "Kocsér",
    "lat": "47.00165",
    "lng": "19.92067"
  },
  {
    "country": "HU",
    "name": "Kocs",
    "lat": "47.6075",
    "lng": "18.21517"
  },
  {
    "country": "HU",
    "name": "Kistelek",
    "lat": "46.4725",
    "lng": "19.97972"
  },
  {
    "country": "HU",
    "name": "Kisszállás",
    "lat": "46.28009",
    "lng": "19.48954"
  },
  {
    "country": "HU",
    "name": "Kispest",
    "lat": "47.4515",
    "lng": "19.14017"
  },
  {
    "country": "HU",
    "name": "Kisláng",
    "lat": "46.95744",
    "lng": "18.38813"
  },
  {
    "country": "HU",
    "name": "Kiskunmajsa",
    "lat": "46.49028",
    "lng": "19.74"
  },
  {
    "country": "HU",
    "name": "Kiskunlacháza",
    "lat": "47.18839",
    "lng": "19.0093"
  },
  {
    "country": "HU",
    "name": "Kiskunhalas",
    "lat": "46.43402",
    "lng": "19.48479"
  },
  {
    "country": "HU",
    "name": "Kiskunfélegyháza",
    "lat": "46.71213",
    "lng": "19.84458"
  },
  {
    "country": "HU",
    "name": "Kiskőrös",
    "lat": "46.62139",
    "lng": "19.28528"
  },
  {
    "country": "HU",
    "name": "Kisbér",
    "lat": "47.50289",
    "lng": "18.03665"
  },
  {
    "country": "HU",
    "name": "Kincsesbánya",
    "lat": "47.26444",
    "lng": "18.2779"
  },
  {
    "country": "HU",
    "name": "Kimle",
    "lat": "47.81726",
    "lng": "17.36642"
  },
  {
    "country": "HU",
    "name": "Kéthely",
    "lat": "46.64605",
    "lng": "17.39362"
  },
  {
    "country": "HU",
    "name": "Kesztölc",
    "lat": "47.71266",
    "lng": "18.80177"
  },
  {
    "country": "HU",
    "name": "Keszthely",
    "lat": "46.76812",
    "lng": "17.24317"
  },
  {
    "country": "HU",
    "name": "Kistarcsa",
    "lat": "47.54757",
    "lng": "19.26247"
  },
  {
    "country": "HU",
    "name": "Kerekegyháza",
    "lat": "46.93722",
    "lng": "19.47806"
  },
  {
    "country": "HU",
    "name": "Kelebia",
    "lat": "46.1968",
    "lng": "19.61659"
  },
  {
    "country": "HU",
    "name": "Kecskemét",
    "lat": "46.90618",
    "lng": "19.69128"
  },
  {
    "country": "HU",
    "name": "Kecskéd",
    "lat": "47.52298",
    "lng": "18.30939"
  },
  {
    "country": "HU",
    "name": "Kecel",
    "lat": "46.52528",
    "lng": "19.25194"
  },
  {
    "country": "HU",
    "name": "Kazár",
    "lat": "48.04952",
    "lng": "19.86143"
  },
  {
    "country": "HU",
    "name": "Katymár",
    "lat": "46.03398",
    "lng": "19.20935"
  },
  {
    "country": "HU",
    "name": "Kartal",
    "lat": "47.67133",
    "lng": "19.542"
  },
  {
    "country": "HU",
    "name": "Karancslapujtő",
    "lat": "48.15",
    "lng": "19.73333"
  },
  {
    "country": "HU",
    "name": "Karancskeszi",
    "lat": "48.16353",
    "lng": "19.69686"
  },
  {
    "country": "HU",
    "name": "Karád",
    "lat": "46.69076",
    "lng": "17.84136"
  },
  {
    "country": "HU",
    "name": "Kapuvár",
    "lat": "47.59224",
    "lng": "17.02886"
  },
  {
    "country": "HU",
    "name": "Kaposvár",
    "lat": "46.36667",
    "lng": "17.8"
  },
  {
    "country": "HU",
    "name": "Kaposmérő",
    "lat": "46.36167",
    "lng": "17.704"
  },
  {
    "country": "HU",
    "name": "Kápolnásnyék",
    "lat": "47.24004",
    "lng": "18.67564"
  },
  {
    "country": "HU",
    "name": "Káloz",
    "lat": "46.95464",
    "lng": "18.48259"
  },
  {
    "country": "HU",
    "name": "Kalocsa",
    "lat": "46.52639",
    "lng": "18.98583"
  },
  {
    "country": "HU",
    "name": "Kakucs",
    "lat": "47.242",
    "lng": "19.36467"
  },
  {
    "country": "HU",
    "name": "Kadarkút",
    "lat": "46.23623",
    "lng": "17.62014"
  },
  {
    "country": "HU",
    "name": "Jobbágyi",
    "lat": "47.83238",
    "lng": "19.67762"
  },
  {
    "country": "HU",
    "name": "Jászszentlászló",
    "lat": "46.56685",
    "lng": "19.76065"
  },
  {
    "country": "HU",
    "name": "Jászberény",
    "lat": "47.5",
    "lng": "19.91667"
  },
  {
    "country": "HU",
    "name": "Jászárokszállás",
    "lat": "47.64238",
    "lng": "19.98038"
  },
  {
    "country": "HU",
    "name": "Jánossomorja",
    "lat": "47.78621",
    "lng": "17.13603"
  },
  {
    "country": "HU",
    "name": "Jánosháza",
    "lat": "47.11937",
    "lng": "17.16503"
  },
  {
    "country": "HU",
    "name": "Jánoshalma",
    "lat": "46.29861",
    "lng": "19.32583"
  },
  {
    "country": "HU",
    "name": "Fülöpjakab",
    "lat": "46.74221",
    "lng": "19.72132"
  },
  {
    "country": "HU",
    "name": "Ják",
    "lat": "47.14249",
    "lng": "16.58148"
  },
  {
    "country": "HU",
    "name": "Izsák",
    "lat": "46.80454",
    "lng": "19.35172"
  },
  {
    "country": "HU",
    "name": "Iváncsa",
    "lat": "47.1567",
    "lng": "18.8203"
  },
  {
    "country": "HU",
    "name": "Isaszeg",
    "lat": "47.53011",
    "lng": "19.40205"
  },
  {
    "country": "HU",
    "name": "Iregszemcse",
    "lat": "46.69286",
    "lng": "18.18581"
  },
  {
    "country": "HU",
    "name": "Inárcs",
    "lat": "47.262",
    "lng": "19.327"
  },
  {
    "country": "HU",
    "name": "Iklad",
    "lat": "47.66533",
    "lng": "19.4361"
  },
  {
    "country": "HU",
    "name": "Hosszúhetény",
    "lat": "46.16414",
    "lng": "18.35077"
  },
  {
    "country": "HU",
    "name": "Hort",
    "lat": "47.69081",
    "lng": "19.7893"
  },
  {
    "country": "HU",
    "name": "Hőgyész",
    "lat": "46.49697",
    "lng": "18.41841"
  },
  {
    "country": "HU",
    "name": "Hidas",
    "lat": "46.2568",
    "lng": "18.4954"
  },
  {
    "country": "HU",
    "name": "Hévízgyörk",
    "lat": "47.63333",
    "lng": "19.51667"
  },
  {
    "country": "HU",
    "name": "Hévíz",
    "lat": "46.79031",
    "lng": "17.18408"
  },
  {
    "country": "HU",
    "name": "Hernád",
    "lat": "47.16238",
    "lng": "19.43295"
  },
  {
    "country": "HU",
    "name": "Herend",
    "lat": "47.13333",
    "lng": "17.75"
  },
  {
    "country": "HU",
    "name": "Heréd",
    "lat": "47.70638",
    "lng": "19.63314"
  },
  {
    "country": "HU",
    "name": "Hercegszántó",
    "lat": "45.95",
    "lng": "18.93917"
  },
  {
    "country": "HU",
    "name": "Helvécia",
    "lat": "46.83661",
    "lng": "19.62251"
  },
  {
    "country": "HU",
    "name": "Hatvan",
    "lat": "47.66667",
    "lng": "19.68333"
  },
  {
    "country": "HU",
    "name": "Harta",
    "lat": "46.69846",
    "lng": "19.03053"
  },
  {
    "country": "HU",
    "name": "Harkány",
    "lat": "45.85002",
    "lng": "18.23668"
  },
  {
    "country": "HU",
    "name": "Halásztelek",
    "lat": "47.36173",
    "lng": "18.98119"
  },
  {
    "country": "HU",
    "name": "Halászi",
    "lat": "47.8893",
    "lng": "17.32615"
  },
  {
    "country": "HU",
    "name": "Hajós",
    "lat": "46.39861",
    "lng": "19.12056"
  },
  {
    "country": "HU",
    "name": "Hajmáskér",
    "lat": "47.14513",
    "lng": "18.01964"
  },
  {
    "country": "HU",
    "name": "Győrújbarát",
    "lat": "47.60643",
    "lng": "17.64875"
  },
  {
    "country": "HU",
    "name": "Győrszemere",
    "lat": "47.55256",
    "lng": "17.56356"
  },
  {
    "country": "HU",
    "name": "Győr",
    "lat": "47.68333",
    "lng": "17.63512"
  },
  {
    "country": "HU",
    "name": "Gyönk",
    "lat": "46.55603",
    "lng": "18.47694"
  },
  {
    "country": "HU",
    "name": "Gyöngyöstarján",
    "lat": "47.81369",
    "lng": "19.86724"
  },
  {
    "country": "HU",
    "name": "Gyöngyössolymos",
    "lat": "47.81724",
    "lng": "19.93619"
  },
  {
    "country": "HU",
    "name": "Gyöngyöspata",
    "lat": "47.81505",
    "lng": "19.78925"
  },
  {
    "country": "HU",
    "name": "Gyöngyöshalász",
    "lat": "47.74161",
    "lng": "19.92876"
  },
  {
    "country": "HU",
    "name": "Gyöngyös",
    "lat": "47.78257",
    "lng": "19.928"
  },
  {
    "country": "HU",
    "name": "Gyömrő",
    "lat": "47.42733",
    "lng": "19.40133"
  },
  {
    "country": "HU",
    "name": "Gyenesdiás",
    "lat": "46.77058",
    "lng": "17.2866"
  },
  {
    "country": "HU",
    "name": "Gyál",
    "lat": "47.38449",
    "lng": "19.2214"
  },
  {
    "country": "HU",
    "name": "Gomba",
    "lat": "47.37095",
    "lng": "19.53057"
  },
  {
    "country": "HU",
    "name": "Gödöllő",
    "lat": "47.59657",
    "lng": "19.35515"
  },
  {
    "country": "HU",
    "name": "Göd",
    "lat": "47.68324",
    "lng": "19.13417"
  },
  {
    "country": "HU",
    "name": "Gencsapáti",
    "lat": "47.28496",
    "lng": "16.59575"
  },
  {
    "country": "HU",
    "name": "Gárdony",
    "lat": "47.20942",
    "lng": "18.63607"
  },
  {
    "country": "HU",
    "name": "Gara",
    "lat": "46.03194",
    "lng": "19.04278"
  },
  {
    "country": "HU",
    "name": "Galgamácsa",
    "lat": "47.69562",
    "lng": "19.38724"
  },
  {
    "country": "HU",
    "name": "Galgahévíz",
    "lat": "47.61667",
    "lng": "19.56667"
  },
  {
    "country": "HU",
    "name": "Fülöpszállás",
    "lat": "46.82075",
    "lng": "19.23748"
  },
  {
    "country": "HU",
    "name": "Fót",
    "lat": "47.6177",
    "lng": "19.1887"
  },
  {
    "country": "HU",
    "name": "Forrópuszta",
    "lat": "47.45504",
    "lng": "19.66001"
  },
  {
    "country": "HU",
    "name": "Forráskút",
    "lat": "46.36528",
    "lng": "19.90973"
  },
  {
    "country": "HU",
    "name": "Fonyód",
    "lat": "46.75552",
    "lng": "17.57945"
  },
  {
    "country": "HU",
    "name": "Fertőszentmiklós",
    "lat": "47.58996",
    "lng": "16.87517"
  },
  {
    "country": "HU",
    "name": "Fertőrákos",
    "lat": "47.72017",
    "lng": "16.6504"
  },
  {
    "country": "HU",
    "name": "Fertőd",
    "lat": "47.62173",
    "lng": "16.87088"
  },
  {
    "country": "HU",
    "name": "Felsőszentiván",
    "lat": "46.19713",
    "lng": "19.18686"
  },
  {
    "country": "HU",
    "name": "Felsőpakony",
    "lat": "47.34329",
    "lng": "19.23698"
  },
  {
    "country": "HU",
    "name": "Fehérvárcsurgó",
    "lat": "47.29349",
    "lng": "18.2646"
  },
  {
    "country": "HU",
    "name": "Farmos",
    "lat": "47.36067",
    "lng": "19.84619"
  },
  {
    "country": "HU",
    "name": "Farád",
    "lat": "47.60633",
    "lng": "17.20024"
  },
  {
    "country": "HU",
    "name": "Fadd",
    "lat": "46.46476",
    "lng": "18.81925"
  },
  {
    "country": "HU",
    "name": "Etyek",
    "lat": "47.44794",
    "lng": "18.75328"
  },
  {
    "country": "HU",
    "name": "Esztergom",
    "lat": "47.7928",
    "lng": "18.74148"
  },
  {
    "country": "HU",
    "name": "Erzsébetváros",
    "lat": "47.50207",
    "lng": "19.07218"
  },
  {
    "country": "HU",
    "name": "Érsekvadkert",
    "lat": "47.99619",
    "lng": "19.20231"
  },
  {
    "country": "HU",
    "name": "Érsekcsanád",
    "lat": "46.25352",
    "lng": "18.98457"
  },
  {
    "country": "HU",
    "name": "Erdőkertes",
    "lat": "47.67261",
    "lng": "19.30786"
  },
  {
    "country": "HU",
    "name": "Érd",
    "lat": "47.39489",
    "lng": "18.91361"
  },
  {
    "country": "HU",
    "name": "Ercsi",
    "lat": "47.25194",
    "lng": "18.89623"
  },
  {
    "country": "HU",
    "name": "Enying",
    "lat": "46.93046",
    "lng": "18.24202"
  },
  {
    "country": "HU",
    "name": "Előszállás",
    "lat": "46.83094",
    "lng": "18.83481"
  },
  {
    "country": "HU",
    "name": "Ecser",
    "lat": "47.44389",
    "lng": "19.3245"
  },
  {
    "country": "HU",
    "name": "Ecséd",
    "lat": "47.73267",
    "lng": "19.76696"
  },
  {
    "country": "HU",
    "name": "Dusnok",
    "lat": "46.39085",
    "lng": "18.96296"
  },
  {
    "country": "HU",
    "name": "Dunavecse",
    "lat": "46.91407",
    "lng": "18.97433"
  },
  {
    "country": "HU",
    "name": "Dunavarsány",
    "lat": "47.27859",
    "lng": "19.06617"
  },
  {
    "country": "HU",
    "name": "Dunaújváros",
    "lat": "46.96479",
    "lng": "18.93974"
  },
  {
    "country": "HU",
    "name": "Dunaszentgyörgy",
    "lat": "46.52852",
    "lng": "18.81771"
  },
  {
    "country": "HU",
    "name": "Dunaszekcső",
    "lat": "46.08663",
    "lng": "18.75865"
  },
  {
    "country": "HU",
    "name": "Dunapataj",
    "lat": "46.644",
    "lng": "18.99632"
  },
  {
    "country": "HU",
    "name": "Dunakeszi",
    "lat": "47.63641",
    "lng": "19.13864"
  },
  {
    "country": "HU",
    "name": "Dunaharaszti",
    "lat": "47.3545",
    "lng": "19.09822"
  },
  {
    "country": "HU",
    "name": "Dunaföldvár",
    "lat": "46.80799",
    "lng": "18.92638"
  },
  {
    "country": "HU",
    "name": "Dunabogdány",
    "lat": "47.79052",
    "lng": "19.04125"
  },
  {
    "country": "HU",
    "name": "Dunaalmás",
    "lat": "47.72868",
    "lng": "18.32235"
  },
  {
    "country": "HU",
    "name": "Dorog",
    "lat": "47.72095",
    "lng": "18.73641"
  },
  {
    "country": "HU",
    "name": "Dömsöd",
    "lat": "47.09005",
    "lng": "19.01106"
  },
  {
    "country": "HU",
    "name": "Domony",
    "lat": "47.65552",
    "lng": "19.43229"
  },
  {
    "country": "HU",
    "name": "Dombóvár",
    "lat": "46.37657",
    "lng": "18.13696"
  },
  {
    "country": "HU",
    "name": "Döbrököz",
    "lat": "46.42178",
    "lng": "18.23953"
  },
  {
    "country": "HU",
    "name": "Diósjenő",
    "lat": "47.93968",
    "lng": "19.04317"
  },
  {
    "country": "HU",
    "name": "Diósd",
    "lat": "47.4095",
    "lng": "18.94898"
  },
  {
    "country": "HU",
    "name": "Devecser",
    "lat": "47.10316",
    "lng": "17.43802"
  },
  {
    "country": "HU",
    "name": "Délegyháza",
    "lat": "47.24135",
    "lng": "19.09019"
  },
  {
    "country": "HU",
    "name": "Dég",
    "lat": "46.86807",
    "lng": "18.45042"
  },
  {
    "country": "HU",
    "name": "Decs",
    "lat": "46.28428",
    "lng": "18.76"
  },
  {
    "country": "HU",
    "name": "Dávod",
    "lat": "45.995",
    "lng": "18.91722"
  },
  {
    "country": "HU",
    "name": "Dány",
    "lat": "47.52",
    "lng": "19.544"
  },
  {
    "country": "HU",
    "name": "Dánszentmiklós",
    "lat": "47.21486",
    "lng": "19.54695"
  },
  {
    "country": "HU",
    "name": "Dabas",
    "lat": "47.18594",
    "lng": "19.31091"
  },
  {
    "country": "HU",
    "name": "Csurgó",
    "lat": "46.25314",
    "lng": "17.1006"
  },
  {
    "country": "HU",
    "name": "Csorna",
    "lat": "47.61155",
    "lng": "17.25012"
  },
  {
    "country": "HU",
    "name": "Csopak",
    "lat": "46.97709",
    "lng": "17.91819"
  },
  {
    "country": "HU",
    "name": "Csömör",
    "lat": "47.55",
    "lng": "19.23333"
  },
  {
    "country": "HU",
    "name": "Csolnok",
    "lat": "47.69116",
    "lng": "18.71611"
  },
  {
    "country": "HU",
    "name": "Csobánka",
    "lat": "47.64637",
    "lng": "18.96189"
  },
  {
    "country": "HU",
    "name": "Csetény",
    "lat": "47.31806",
    "lng": "17.99208"
  },
  {
    "country": "HU",
    "name": "Cserszegtomaj",
    "lat": "46.80165",
    "lng": "17.22096"
  },
  {
    "country": "HU",
    "name": "Csepreg",
    "lat": "47.40098",
    "lng": "16.70881"
  },
  {
    "country": "HU",
    "name": "Csengőd",
    "lat": "46.71543",
    "lng": "19.26802"
  },
  {
    "country": "HU",
    "name": "Csengele",
    "lat": "46.54234",
    "lng": "19.86358"
  },
  {
    "country": "HU",
    "name": "Csemő",
    "lat": "47.11799",
    "lng": "19.69092"
  },
  {
    "country": "HU",
    "name": "Csávoly",
    "lat": "46.18917",
    "lng": "19.14667"
  },
  {
    "country": "HU",
    "name": "Császártöltés",
    "lat": "46.42194",
    "lng": "19.18361"
  },
  {
    "country": "HU",
    "name": "Császár",
    "lat": "47.498",
    "lng": "18.14272"
  },
  {
    "country": "HU",
    "name": "Csány",
    "lat": "47.64829",
    "lng": "19.82972"
  },
  {
    "country": "HU",
    "name": "Csákvár",
    "lat": "47.39184",
    "lng": "18.46501"
  },
  {
    "country": "HU",
    "name": "Csabrendek",
    "lat": "47.01356",
    "lng": "17.29108"
  },
  {
    "country": "HU",
    "name": "Celldömölk",
    "lat": "47.25713",
    "lng": "17.15027"
  },
  {
    "country": "HU",
    "name": "Ceglédbercel",
    "lat": "47.2237",
    "lng": "19.66828"
  },
  {
    "country": "HU",
    "name": "Cegléd",
    "lat": "47.17266",
    "lng": "19.79952"
  },
  {
    "country": "HU",
    "name": "Cece",
    "lat": "46.77056",
    "lng": "18.62826"
  },
  {
    "country": "HU",
    "name": "Bükkösd",
    "lat": "46.10751",
    "lng": "17.9882"
  },
  {
    "country": "HU",
    "name": "Bük",
    "lat": "47.38486",
    "lng": "16.75065"
  },
  {
    "country": "HU",
    "name": "Buják",
    "lat": "47.88352",
    "lng": "19.54381"
  },
  {
    "country": "HU",
    "name": "Bugyi",
    "lat": "47.22748",
    "lng": "19.14664"
  },
  {
    "country": "HU",
    "name": "Bugac",
    "lat": "46.68704",
    "lng": "19.68074"
  },
  {
    "country": "HU",
    "name": "Budapest",
    "lat": "47.49801",
    "lng": "19.03991"
  },
  {
    "country": "HU",
    "name": "Budaörs",
    "lat": "47.46181",
    "lng": "18.95845"
  },
  {
    "country": "HU",
    "name": "Budakeszi",
    "lat": "47.51083",
    "lng": "18.92717"
  },
  {
    "country": "HU",
    "name": "Budakalász",
    "lat": "47.61667",
    "lng": "19.05"
  },
  {
    "country": "HU",
    "name": "Aszód",
    "lat": "47.65174",
    "lng": "19.4785"
  },
  {
    "country": "HU",
    "name": "Bősárkány",
    "lat": "47.68821",
    "lng": "17.25"
  },
  {
    "country": "HU",
    "name": "Bordány",
    "lat": "46.31843",
    "lng": "19.92306"
  },
  {
    "country": "HU",
    "name": "Bonyhád",
    "lat": "46.29921",
    "lng": "18.53024"
  },
  {
    "country": "HU",
    "name": "Bőny",
    "lat": "47.65",
    "lng": "17.86977"
  },
  {
    "country": "HU",
    "name": "Bóly",
    "lat": "45.96722",
    "lng": "18.51833"
  },
  {
    "country": "HU",
    "name": "Boldog",
    "lat": "47.60285",
    "lng": "19.68839"
  },
  {
    "country": "HU",
    "name": "Bölcske",
    "lat": "46.74102",
    "lng": "18.96736"
  },
  {
    "country": "HU",
    "name": "Bokod",
    "lat": "47.49186",
    "lng": "18.24743"
  },
  {
    "country": "HU",
    "name": "Böhönye",
    "lat": "46.41345",
    "lng": "17.38037"
  },
  {
    "country": "HU",
    "name": "Bogyiszló",
    "lat": "46.38638",
    "lng": "18.82962"
  },
  {
    "country": "HU",
    "name": "Bodajk",
    "lat": "47.32352",
    "lng": "18.23312"
  },
  {
    "country": "HU",
    "name": "Bicske",
    "lat": "47.48419",
    "lng": "18.64404"
  },
  {
    "country": "HU",
    "name": "Biatorbágy",
    "lat": "47.4706",
    "lng": "18.81892"
  },
  {
    "country": "HU",
    "name": "Berzence",
    "lat": "46.20907",
    "lng": "17.1481"
  },
  {
    "country": "HU",
    "name": "Berhida",
    "lat": "47.11131",
    "lng": "18.12948"
  },
  {
    "country": "HU",
    "name": "Beremend",
    "lat": "45.79108",
    "lng": "18.43263"
  },
  {
    "country": "HU",
    "name": "Bercel",
    "lat": "47.87057",
    "lng": "19.40715"
  },
  {
    "country": "HU",
    "name": "Beled",
    "lat": "47.46594",
    "lng": "17.09294"
  },
  {
    "country": "HU",
    "name": "Becsehely",
    "lat": "46.44755",
    "lng": "16.7771"
  },
  {
    "country": "HU",
    "name": "Bátya",
    "lat": "46.488",
    "lng": "18.95419"
  },
  {
    "country": "HU",
    "name": "Bátonyterenye",
    "lat": "47.96962",
    "lng": "19.84076"
  },
  {
    "country": "HU",
    "name": "Bátaszék",
    "lat": "46.19373",
    "lng": "18.72307"
  },
  {
    "country": "HU",
    "name": "Báta",
    "lat": "46.12864",
    "lng": "18.77027"
  },
  {
    "country": "HU",
    "name": "Barcs",
    "lat": "45.96",
    "lng": "17.45861"
  },
  {
    "country": "HU",
    "name": "Baracska",
    "lat": "47.28225",
    "lng": "18.75853"
  },
  {
    "country": "HU",
    "name": "Baracs",
    "lat": "46.88202",
    "lng": "18.90658"
  },
  {
    "country": "HU",
    "name": "Ballószög",
    "lat": "46.86216",
    "lng": "19.57092"
  },
  {
    "country": "HU",
    "name": "Balatonszárszó",
    "lat": "46.82946",
    "lng": "17.82426"
  },
  {
    "country": "HU",
    "name": "Balatonszabadi",
    "lat": "46.89397",
    "lng": "18.13737"
  },
  {
    "country": "HU",
    "name": "Balatonlelle",
    "lat": "46.78318",
    "lng": "17.69498"
  },
  {
    "country": "HU",
    "name": "Balatonkenese",
    "lat": "47.04019",
    "lng": "18.10671"
  },
  {
    "country": "HU",
    "name": "Balatonfüred",
    "lat": "46.96188",
    "lng": "17.87187"
  },
  {
    "country": "HU",
    "name": "Balatonföldvár",
    "lat": "46.85255",
    "lng": "17.88123"
  },
  {
    "country": "HU",
    "name": "Balatonfenyves",
    "lat": "46.71542",
    "lng": "17.49223"
  },
  {
    "country": "HU",
    "name": "Balatonboglár",
    "lat": "46.77525",
    "lng": "17.64415"
  },
  {
    "country": "HU",
    "name": "Balatonberény",
    "lat": "46.70701",
    "lng": "17.32013"
  },
  {
    "country": "HU",
    "name": "Balatonalmádi",
    "lat": "47.03526",
    "lng": "18.02076"
  },
  {
    "country": "HU",
    "name": "Balassagyarmat",
    "lat": "48.07296",
    "lng": "19.29614"
  },
  {
    "country": "HU",
    "name": "Bakonyszentlászló",
    "lat": "47.38901",
    "lng": "17.80321"
  },
  {
    "country": "HU",
    "name": "Bakonycsernye",
    "lat": "47.32395",
    "lng": "18.07509"
  },
  {
    "country": "HU",
    "name": "Bajna",
    "lat": "47.654",
    "lng": "18.5972"
  },
  {
    "country": "HU",
    "name": "Baja",
    "lat": "46.17496",
    "lng": "18.95639"
  },
  {
    "country": "HU",
    "name": "Baj",
    "lat": "47.64593",
    "lng": "18.3641"
  },
  {
    "country": "HU",
    "name": "Bag",
    "lat": "47.63333",
    "lng": "19.48333"
  },
  {
    "country": "HU",
    "name": "Badacsonytomaj",
    "lat": "46.80711",
    "lng": "17.51385"
  },
  {
    "country": "HU",
    "name": "Bácsbokod",
    "lat": "46.125",
    "lng": "19.15621"
  },
  {
    "country": "HU",
    "name": "Bácsalmás",
    "lat": "46.12648",
    "lng": "19.3326"
  },
  {
    "country": "HU",
    "name": "Bábolna",
    "lat": "47.64361",
    "lng": "17.97798"
  },
  {
    "country": "HU",
    "name": "Babócsa",
    "lat": "46.04155",
    "lng": "17.34332"
  },
  {
    "country": "HU",
    "name": "Ásványráró",
    "lat": "47.82733",
    "lng": "17.49418"
  },
  {
    "country": "HU",
    "name": "Ásotthalom",
    "lat": "46.19875",
    "lng": "19.78334"
  },
  {
    "country": "HU",
    "name": "Apostag",
    "lat": "46.88208",
    "lng": "18.9621"
  },
  {
    "country": "HU",
    "name": "Apc",
    "lat": "47.79419",
    "lng": "19.69429"
  },
  {
    "country": "HU",
    "name": "Alsónémedi",
    "lat": "47.31524",
    "lng": "19.15843"
  },
  {
    "country": "HU",
    "name": "Almásfüzitő",
    "lat": "47.72752",
    "lng": "18.26153"
  },
  {
    "country": "HU",
    "name": "Albertirsa",
    "lat": "47.24315",
    "lng": "19.61686"
  },
  {
    "country": "HU",
    "name": "Alap",
    "lat": "46.79915",
    "lng": "18.68938"
  },
  {
    "country": "HU",
    "name": "Akasztó",
    "lat": "46.69167",
    "lng": "19.20423"
  },
  {
    "country": "HU",
    "name": "Ajka",
    "lat": "47.10196",
    "lng": "17.55892"
  },
  {
    "country": "HU",
    "name": "Ágfalva",
    "lat": "47.68991",
    "lng": "16.51658"
  },
  {
    "country": "HU",
    "name": "Ágasegyháza",
    "lat": "46.84025",
    "lng": "19.45208"
  },
  {
    "country": "HU",
    "name": "Adony",
    "lat": "47.1194",
    "lng": "18.86493"
  },
  {
    "country": "HU",
    "name": "Ádánd",
    "lat": "46.85931",
    "lng": "18.16442"
  },
  {
    "country": "HU",
    "name": "Adács",
    "lat": "47.6921",
    "lng": "19.97696"
  },
  {
    "country": "HU",
    "name": "Acsa",
    "lat": "47.79425",
    "lng": "19.38795"
  },
  {
    "country": "HU",
    "name": "Ács",
    "lat": "47.71231",
    "lng": "18.01131"
  },
  {
    "country": "HU",
    "name": "Abda",
    "lat": "47.69464",
    "lng": "17.54489"
  },
  {
    "country": "HU",
    "name": "Aba",
    "lat": "47.02907",
    "lng": "18.52172"
  },
  {
    "country": "HU",
    "name": "Tiszaalpár",
    "lat": "46.81279",
    "lng": "19.99841"
  },
  {
    "country": "HU",
    "name": "Budapest XII. kerület",
    "lat": "47.49192",
    "lng": "19.01493"
  },
  {
    "country": "HU",
    "name": "Budapest XI. kerület",
    "lat": "47.47603",
    "lng": "19.03605"
  },
  {
    "country": "HU",
    "name": "Budapest VIII. kerület",
    "lat": "47.48919",
    "lng": "19.07012"
  },
  {
    "country": "HU",
    "name": "Budapest VI. kerület",
    "lat": "47.50369",
    "lng": "19.06583"
  },
  {
    "country": "HU",
    "name": "Budapest XIII. kerület",
    "lat": "47.52978",
    "lng": "19.08068"
  },
  {
    "country": "HU",
    "name": "Budapest IV. kerület",
    "lat": "47.56182",
    "lng": "19.08909"
  },
  {
    "country": "HU",
    "name": "Budapest XV. kerület",
    "lat": "47.56263",
    "lng": "19.11681"
  },
  {
    "country": "HU",
    "name": "Budapest XVI. kerület",
    "lat": "47.51482",
    "lng": "19.17028"
  },
  {
    "country": "HU",
    "name": "Budapest X. kerület",
    "lat": "47.4791",
    "lng": "19.15835"
  },
  {
    "country": "HU",
    "name": "Budapest XIX. kerület",
    "lat": "47.45293",
    "lng": "19.14943"
  },
  {
    "country": "HU",
    "name": "Budapest XVIII. kerület",
    "lat": "47.44417",
    "lng": "19.17595"
  },
  {
    "country": "HU",
    "name": "Budapest XXIII. kerület",
    "lat": "47.39788",
    "lng": "19.11492"
  },
  {
    "country": "HU",
    "name": "Budapest XXII. kerület",
    "lat": "47.42698",
    "lng": "19.04016"
  },
  {
    "country": "HU",
    "name": "Budapest XXI. kerület",
    "lat": "47.43047",
    "lng": "19.07098"
  },
  {
    "country": "HU",
    "name": "Budapest XX. kerület",
    "lat": "47.43674",
    "lng": "19.10093"
  },
  {
    "country": "HU",
    "name": "Budapest XVII. kerület",
    "lat": "47.47997",
    "lng": "19.25388"
  },
  {
    "country": "HU",
    "name": "Budapest III. kerület",
    "lat": "47.54157",
    "lng": "19.04501"
  },
  {
    "country": "HU",
    "name": "Budapest II. kerület",
    "lat": "47.51984",
    "lng": "19.02218"
  },
  {
    "country": "HU",
    "name": "Budapest I. kerület",
    "lat": "47.49705",
    "lng": "19.03961"
  },
  {
    "country": "HU",
    "name": "Algyő",
    "lat": "46.33472",
    "lng": "20.20849"
  },
  {
    "country": "HU",
    "name": "Szelevény",
    "lat": "46.80259",
    "lng": "20.20283"
  },
  {
    "country": "HU",
    "name": "Kismaros",
    "lat": "47.83742",
    "lng": "19.00463"
  },
  {
    "country": "HU",
    "name": "Héhalom",
    "lat": "47.78017",
    "lng": "19.58519"
  },
  {
    "country": "HU",
    "name": "Mosonszentmiklós",
    "lat": "47.72778",
    "lng": "17.42784"
  },
  {
    "country": "HU",
    "name": "Kerepes",
    "lat": "47.56008",
    "lng": "19.28289"
  },
  {
    "country": "HU",
    "name": "Tiszaszőlős",
    "lat": "47.55707",
    "lng": "20.71949"
  },
  {
    "country": "HU",
    "name": "Józsefváros",
    "lat": "47.48938",
    "lng": "19.07292"
  },
  {
    "country": "ID",
    "name": "Ujung Gading",
    "lat": "0.27293",
    "lng": "99.55762"
  },
  {
    "country": "ID",
    "name": "Ujungbatu",
    "lat": "1.04239",
    "lng": "99.93461"
  },
  {
    "country": "ID",
    "name": "Tualangcut",
    "lat": "4.4018",
    "lng": "98.0722"
  },
  {
    "country": "ID",
    "name": "Tongging",
    "lat": "2.8985",
    "lng": "98.5231"
  },
  {
    "country": "ID",
    "name": "Tomok Bolon",
    "lat": "2.6521",
    "lng": "98.8608"
  },
  {
    "country": "ID",
    "name": "Tiku",
    "lat": "-0.3958",
    "lng": "99.92307"
  },
  {
    "country": "ID",
    "name": "Teluk Nibung",
    "lat": "3.001",
    "lng": "99.8164"
  },
  {
    "country": "ID",
    "name": "Teluk Dalam",
    "lat": "0.5729",
    "lng": "97.8034"
  },
  {
    "country": "ID",
    "name": "Tebingtinggi",
    "lat": "3.3285",
    "lng": "99.1625"
  },
  {
    "country": "ID",
    "name": "Tarutung",
    "lat": "2.01467",
    "lng": "98.96548"
  },
  {
    "country": "ID",
    "name": "Tanjungtiram",
    "lat": "4.0613",
    "lng": "98.3699"
  },
  {
    "country": "ID",
    "name": "Tanjungbalai",
    "lat": "2.96667",
    "lng": "99.8"
  },
  {
    "country": "ID",
    "name": "Tangse",
    "lat": "5.0136",
    "lng": "95.9153"
  },
  {
    "country": "ID",
    "name": "Talu",
    "lat": "0.23006",
    "lng": "99.98123"
  },
  {
    "country": "ID",
    "name": "Takengon",
    "lat": "4.6212",
    "lng": "96.8467"
  },
  {
    "country": "ID",
    "name": "Susoh",
    "lat": "3.72394",
    "lng": "96.82159"
  },
  {
    "country": "ID",
    "name": "Sunggal",
    "lat": "3.5765",
    "lng": "98.6151"
  },
  {
    "country": "ID",
    "name": "Sei Rampah",
    "lat": "3.4845",
    "lng": "99.1366"
  },
  {
    "country": "ID",
    "name": "Stabat",
    "lat": "3.73335",
    "lng": "98.45025"
  },
  {
    "country": "ID",
    "name": "Sondi",
    "lat": "2.9735",
    "lng": "98.8617"
  },
  {
    "country": "ID",
    "name": "Sipirok",
    "lat": "1.60248",
    "lng": "99.27377"
  },
  {
    "country": "ID",
    "name": "Sipiongot",
    "lat": "1.83501",
    "lng": "99.66266"
  },
  {
    "country": "ID",
    "name": "Sipagimbar",
    "lat": "1.83072",
    "lng": "99.37185"
  },
  {
    "country": "ID",
    "name": "Singkil",
    "lat": "2.2874",
    "lng": "97.7884"
  },
  {
    "country": "ID",
    "name": "Sinabang",
    "lat": "2.4803",
    "lng": "96.3801"
  },
  {
    "country": "ID",
    "name": "Simpang Empat",
    "lat": "0.09703",
    "lng": "99.82339"
  },
  {
    "country": "ID",
    "name": "Sigli",
    "lat": "5.3848",
    "lng": "95.9609"
  },
  {
    "country": "ID",
    "name": "Sidikalang",
    "lat": "2.74899",
    "lng": "98.3127"
  },
  {
    "country": "ID",
    "name": "Sibuhuan",
    "lat": "1.05387",
    "lng": "99.73018"
  },
  {
    "country": "ID",
    "name": "Siborong-Borong",
    "lat": "2.21251",
    "lng": "98.97291"
  },
  {
    "country": "ID",
    "name": "Sibolga",
    "lat": "1.74016",
    "lng": "98.78117"
  },
  {
    "country": "ID",
    "name": "Sibigo",
    "lat": "2.8385",
    "lng": "95.9131"
  },
  {
    "country": "ID",
    "name": "Siabu",
    "lat": "1.01552",
    "lng": "99.49452"
  },
  {
    "country": "ID",
    "name": "Seulimeum",
    "lat": "5.3618",
    "lng": "95.5765"
  },
  {
    "country": "ID",
    "name": "Serawai",
    "lat": "4.3542",
    "lng": "98.1868"
  },
  {
    "country": "ID",
    "name": "Saribudolok",
    "lat": "2.9392",
    "lng": "98.6107"
  },
  {
    "country": "ID",
    "name": "Salak",
    "lat": "2.5566",
    "lng": "98.3235"
  },
  {
    "country": "ID",
    "name": "Sabang",
    "lat": "5.88969",
    "lng": "95.31644"
  },
  {
    "country": "ID",
    "name": "Rikitgaib",
    "lat": "4.1447",
    "lng": "97.0572"
  },
  {
    "country": "ID",
    "name": "Reuleuet",
    "lat": "5.21667",
    "lng": "96.28333"
  },
  {
    "country": "ID",
    "name": "Rantauprapat",
    "lat": "2.1",
    "lng": "99.83333"
  },
  {
    "country": "ID",
    "name": "Parapat",
    "lat": "2.663",
    "lng": "98.9349"
  },
  {
    "country": "ID",
    "name": "Pintupadang",
    "lat": "1.2402",
    "lng": "99.345"
  },
  {
    "country": "ID",
    "name": "Peureulak",
    "lat": "4.8098",
    "lng": "97.8902"
  },
  {
    "country": "ID",
    "name": "Percut",
    "lat": "3.6253",
    "lng": "98.864"
  },
  {
    "country": "ID",
    "name": "Perbaungan",
    "lat": "3.5679",
    "lng": "98.956"
  },
  {
    "country": "ID",
    "name": "Penaron",
    "lat": "4.6407",
    "lng": "97.6842"
  },
  {
    "country": "ID",
    "name": "Pematangsiantar",
    "lat": "2.9595",
    "lng": "99.0687"
  },
  {
    "country": "ID",
    "name": "Pematang Raya",
    "lat": "2.9658",
    "lng": "98.8473"
  },
  {
    "country": "ID",
    "name": "Parmonangan",
    "lat": "2.1046",
    "lng": "98.7637"
  },
  {
    "country": "ID",
    "name": "Parlilitan",
    "lat": "2.324",
    "lng": "98.4571"
  },
  {
    "country": "ID",
    "name": "Panyambungan",
    "lat": "0.8651",
    "lng": "99.5528"
  },
  {
    "country": "ID",
    "name": "Pangururan",
    "lat": "2.6081",
    "lng": "98.6961"
  },
  {
    "country": "ID",
    "name": "Pangkalan Brandan",
    "lat": "4.0238",
    "lng": "98.2782"
  },
  {
    "country": "ID",
    "name": "Pakkat",
    "lat": "2.1524",
    "lng": "98.4745"
  },
  {
    "country": "ID",
    "name": "Padangtiji",
    "lat": "5.3742",
    "lng": "95.8445"
  },
  {
    "country": "ID",
    "name": "Padangsidempuan",
    "lat": "1.37952",
    "lng": "99.27146"
  },
  {
    "country": "ID",
    "name": "Natal",
    "lat": "0.5632",
    "lng": "99.1099"
  },
  {
    "country": "ID",
    "name": "Nainggolan",
    "lat": "2.4361",
    "lng": "98.8852"
  },
  {
    "country": "ID",
    "name": "Muara Soma",
    "lat": "0.68842",
    "lng": "99.36194"
  },
  {
    "country": "ID",
    "name": "Muara Sipongi",
    "lat": "0.56926",
    "lng": "100.01266"
  },
  {
    "country": "ID",
    "name": "Sikabaluan",
    "lat": "-1.11961",
    "lng": "98.99217"
  },
  {
    "country": "ID",
    "name": "Muara Siberut",
    "lat": "-1.59787",
    "lng": "99.21097"
  },
  {
    "country": "ID",
    "name": "Muara",
    "lat": "2.33722",
    "lng": "98.90539"
  },
  {
    "country": "ID",
    "name": "Montasik",
    "lat": "5.50266",
    "lng": "95.42306"
  },
  {
    "country": "ID",
    "name": "Mogang",
    "lat": "2.4697",
    "lng": "98.8043"
  },
  {
    "country": "ID",
    "name": "Meureubo",
    "lat": "4.14",
    "lng": "96.1623"
  },
  {
    "country": "ID",
    "name": "Meulaboh",
    "lat": "4.14402",
    "lng": "96.12664"
  },
  {
    "country": "ID",
    "name": "Medan",
    "lat": "3.58333",
    "lng": "98.66667"
  },
  {
    "country": "ID",
    "name": "Lubuk Pakam",
    "lat": "3.5592",
    "lng": "98.8733"
  },
  {
    "country": "ID",
    "name": "Lintongnihuta",
    "lat": "2.276",
    "lng": "98.866"
  },
  {
    "country": "ID",
    "name": "Limapuluh",
    "lat": "3.1689",
    "lng": "99.4175"
  },
  {
    "country": "ID",
    "name": "Lhoong",
    "lat": "5.26667",
    "lng": "95.25"
  },
  {
    "country": "ID",
    "name": "Lhokseumawe",
    "lat": "5.1801",
    "lng": "97.1507"
  },
  {
    "country": "ID",
    "name": "Lhoknga",
    "lat": "5.47691",
    "lng": "95.24538"
  },
  {
    "country": "ID",
    "name": "Lhokkruet",
    "lat": "4.8797",
    "lng": "95.401"
  },
  {
    "country": "ID",
    "name": "Laweueng",
    "lat": "5.5151",
    "lng": "95.8465"
  },
  {
    "country": "ID",
    "name": "Langsa",
    "lat": "4.4683",
    "lng": "97.9683"
  },
  {
    "country": "ID",
    "name": "Langgapayung",
    "lat": "1.72693",
    "lng": "99.96285"
  },
  {
    "country": "ID",
    "name": "Lampuyang",
    "lat": "5.6701",
    "lng": "95.1345"
  },
  {
    "country": "ID",
    "name": "Lamno",
    "lat": "5.0902",
    "lng": "95.3727"
  },
  {
    "country": "ID",
    "name": "Labuhan Deli",
    "lat": "3.7278",
    "lng": "98.6738"
  },
  {
    "country": "ID",
    "name": "Kuala Bhee",
    "lat": "4.3855",
    "lng": "96.0471"
  },
  {
    "country": "ID",
    "name": "Kruengraya",
    "lat": "5.5895",
    "lng": "95.5145"
  },
  {
    "country": "ID",
    "name": "Krueng Luak",
    "lat": "2.8583",
    "lng": "97.7578"
  },
  {
    "country": "ID",
    "name": "Kisaran",
    "lat": "2.9845",
    "lng": "99.6158"
  },
  {
    "country": "ID",
    "name": "Kabanjahe",
    "lat": "3.1001",
    "lng": "98.4908"
  },
  {
    "country": "ID",
    "name": "Isak",
    "lat": "4.4599",
    "lng": "96.8822"
  },
  {
    "country": "ID",
    "name": "Kotanopan",
    "lat": "0.66758",
    "lng": "99.70908"
  },
  {
    "country": "ID",
    "name": "Gunung Tua",
    "lat": "1.51274",
    "lng": "99.62628"
  },
  {
    "country": "ID",
    "name": "Gunungsitoli",
    "lat": "1.2888",
    "lng": "97.6143"
  },
  {
    "country": "ID",
    "name": "Gosong Telaga",
    "lat": "2.2786",
    "lng": "97.9268"
  },
  {
    "country": "ID",
    "name": "Dolok Sanggul",
    "lat": "2.2588",
    "lng": "98.7501"
  },
  {
    "country": "ID",
    "name": "Deli Tua",
    "lat": "3.5078",
    "lng": "98.6839"
  },
  {
    "country": "ID",
    "name": "Celala",
    "lat": "4.5955",
    "lng": "96.692"
  },
  {
    "country": "ID",
    "name": "Calang",
    "lat": "4.6306",
    "lng": "95.5754"
  },
  {
    "country": "ID",
    "name": "Blangpidie",
    "lat": "3.73956",
    "lng": "96.83608"
  },
  {
    "country": "ID",
    "name": "Blangkejeren",
    "lat": "3.9971",
    "lng": "97.3384"
  },
  {
    "country": "ID",
    "name": "Bireun",
    "lat": "5.203",
    "lng": "96.7009"
  },
  {
    "country": "ID",
    "name": "Binjai",
    "lat": "3.6001",
    "lng": "98.4854"
  },
  {
    "country": "ID",
    "name": "Binanga",
    "lat": "1.41006",
    "lng": "99.77602"
  },
  {
    "country": "ID",
    "name": "Berastagi",
    "lat": "3.19468",
    "lng": "98.50889"
  },
  {
    "country": "ID",
    "name": "Belawan",
    "lat": "3.7755",
    "lng": "98.6832"
  },
  {
    "country": "ID",
    "name": "Bayeuen",
    "lat": "4.5902",
    "lng": "97.9087"
  },
  {
    "country": "ID",
    "name": "Batangtoru",
    "lat": "1.48253",
    "lng": "99.06569"
  },
  {
    "country": "ID",
    "name": "Barus",
    "lat": "2.0106",
    "lng": "98.3982"
  },
  {
    "country": "ID",
    "name": "Bandar",
    "lat": "2.05",
    "lng": "99.75"
  },
  {
    "country": "ID",
    "name": "Banda Aceh",
    "lat": "5.54167",
    "lng": "95.33333"
  },
  {
    "country": "ID",
    "name": "Balige",
    "lat": "2.3328",
    "lng": "99.0657"
  },
  {
    "country": "ID",
    "name": "Bakungan",
    "lat": "2.92397",
    "lng": "97.48311"
  },
  {
    "country": "ID",
    "name": "Asan Kumbang",
    "lat": "5.30424",
    "lng": "96.02744"
  },
  {
    "country": "ID",
    "name": "Ambarita",
    "lat": "2.6814",
    "lng": "98.8311"
  },
  {
    "country": "ID",
    "name": "Air Bangis",
    "lat": "0.2018",
    "lng": "99.37985"
  },
  {
    "country": "ID",
    "name": "Terangun",
    "lat": "4.0772",
    "lng": "97.0666"
  },
  {
    "country": "ID",
    "name": "Kenyaran",
    "lat": "4.1544",
    "lng": "97.1951"
  },
  {
    "country": "ID",
    "name": "Pining",
    "lat": "4.1064",
    "lng": "97.5886"
  },
  {
    "country": "ID",
    "name": "Yosowilangun",
    "lat": "-8.2391",
    "lng": "113.3136"
  },
  {
    "country": "ID",
    "name": "Yogyakarta",
    "lat": "-7.80139",
    "lng": "110.36472"
  },
  {
    "country": "ID",
    "name": "Wuluhan",
    "lat": "-8.3376",
    "lng": "113.5503"
  },
  {
    "country": "ID",
    "name": "Wotu",
    "lat": "-2.5906",
    "lng": "120.804"
  },
  {
    "country": "ID",
    "name": "Wori",
    "lat": "1.59714",
    "lng": "124.85246"
  },
  {
    "country": "ID",
    "name": "Wonosobo",
    "lat": "-7.35889",
    "lng": "109.90306"
  },
  {
    "country": "ID",
    "name": "Wonosari",
    "lat": "-7.96556",
    "lng": "110.60361"
  },
  {
    "country": "ID",
    "name": "Wonorejo",
    "lat": "-2.4937",
    "lng": "120.8126"
  },
  {
    "country": "ID",
    "name": "Wonopringgo",
    "lat": "-6.98333",
    "lng": "109.61667"
  },
  {
    "country": "ID",
    "name": "Wonogiri",
    "lat": "-7.81444",
    "lng": "110.92056"
  },
  {
    "country": "ID",
    "name": "Wongsorejo",
    "lat": "-7.9908",
    "lng": "114.4009"
  },
  {
    "country": "ID",
    "name": "Wolowaru",
    "lat": "-8.7835",
    "lng": "121.886"
  },
  {
    "country": "ID",
    "name": "Wlingi",
    "lat": "-8.0776",
    "lng": "112.3311"
  },
  {
    "country": "ID",
    "name": "Witihama",
    "lat": "-8.2996",
    "lng": "123.2627"
  },
  {
    "country": "ID",
    "name": "Wiradesa",
    "lat": "-6.8922",
    "lng": "109.619"
  },
  {
    "country": "ID",
    "name": "Weru",
    "lat": "-6.711",
    "lng": "108.5037"
  },
  {
    "country": "ID",
    "name": "Werinama",
    "lat": "-3.5029",
    "lng": "130.1105"
  },
  {
    "country": "ID",
    "name": "Weleri",
    "lat": "-6.9713",
    "lng": "110.0666"
  },
  {
    "country": "ID",
    "name": "Welahan",
    "lat": "-6.8",
    "lng": "110.71667"
  },
  {
    "country": "ID",
    "name": "Wedi",
    "lat": "-7.74306",
    "lng": "110.57944"
  },
  {
    "country": "ID",
    "name": "Wedarijaksa",
    "lat": "-6.68155",
    "lng": "111.07161"
  },
  {
    "country": "ID",
    "name": "Weda",
    "lat": "0.32952",
    "lng": "127.87389"
  },
  {
    "country": "ID",
    "name": "Wates",
    "lat": "-7.85722",
    "lng": "110.15694"
  },
  {
    "country": "ID",
    "name": "Watansoppeng",
    "lat": "-4.3522",
    "lng": "119.8841"
  },
  {
    "country": "ID",
    "name": "Watampone",
    "lat": "-4.5386",
    "lng": "120.3279"
  },
  {
    "country": "ID",
    "name": "Waru",
    "lat": "-6.9421",
    "lng": "113.5499"
  },
  {
    "country": "ID",
    "name": "Waren",
    "lat": "-2.2645",
    "lng": "136.3342"
  },
  {
    "country": "ID",
    "name": "Wardo",
    "lat": "-1.0623",
    "lng": "135.8416"
  },
  {
    "country": "ID",
    "name": "Wanurian",
    "lat": "-1.2463",
    "lng": "131.5665"
  },
  {
    "country": "ID",
    "name": "Wangon",
    "lat": "-7.51611",
    "lng": "109.05389"
  },
  {
    "country": "ID",
    "name": "Wanci",
    "lat": "-5.3271",
    "lng": "123.5388"
  },
  {
    "country": "ID",
    "name": "Wanareja",
    "lat": "-7.3332",
    "lng": "108.6876"
  },
  {
    "country": "ID",
    "name": "Wanaraja",
    "lat": "-7.1749",
    "lng": "107.9808"
  },
  {
    "country": "ID",
    "name": "Wamena",
    "lat": "-4.09512",
    "lng": "138.94492"
  },
  {
    "country": "ID",
    "name": "Wajak",
    "lat": "-8.102",
    "lng": "112.7312"
  },
  {
    "country": "ID",
    "name": "Waiwerang",
    "lat": "-8.3884",
    "lng": "123.1648"
  },
  {
    "country": "ID",
    "name": "Waisai",
    "lat": "-0.2379",
    "lng": "130.5072"
  },
  {
    "country": "ID",
    "name": "Waigete",
    "lat": "-8.6127",
    "lng": "122.4198"
  },
  {
    "country": "ID",
    "name": "Waipukang",
    "lat": "-8.3207",
    "lng": "123.4638"
  },
  {
    "country": "ID",
    "name": "Waingapu",
    "lat": "-9.6567",
    "lng": "120.2641"
  },
  {
    "country": "ID",
    "name": "Waimangura",
    "lat": "-9.5098",
    "lng": "119.2377"
  },
  {
    "country": "ID",
    "name": "Waikabubak",
    "lat": "-9.6475",
    "lng": "119.3889"
  },
  {
    "country": "ID",
    "name": "Waigama",
    "lat": "-1.8364",
    "lng": "129.8316"
  },
  {
    "country": "ID",
    "name": "Waibakul",
    "lat": "-9.63556",
    "lng": "119.41333"
  },
  {
    "country": "ID",
    "name": "Wahai",
    "lat": "-2.79529",
    "lng": "129.5382"
  },
  {
    "country": "ID",
    "name": "Utan",
    "lat": "-8.4129",
    "lng": "117.1332"
  },
  {
    "country": "ID",
    "name": "Uta",
    "lat": "-4.5536",
    "lng": "136.0339"
  },
  {
    "country": "ID",
    "name": "Ungaran",
    "lat": "-7.13972",
    "lng": "110.405"
  },
  {
    "country": "ID",
    "name": "Ketapang",
    "lat": "-4.71335",
    "lng": "104.79954"
  },
  {
    "country": "ID",
    "name": "Kolaka",
    "lat": "-4.0597",
    "lng": "121.60556"
  },
  {
    "country": "ID",
    "name": "Ulu",
    "lat": "2.70363",
    "lng": "125.39375"
  },
  {
    "country": "ID",
    "name": "Ujungpangkah",
    "lat": "-6.917",
    "lng": "112.5551"
  },
  {
    "country": "ID",
    "name": "Makassar",
    "lat": "-5.14861",
    "lng": "119.43194"
  },
  {
    "country": "ID",
    "name": "Ujoh Bilang",
    "lat": "0.55",
    "lng": "115.25"
  },
  {
    "country": "ID",
    "name": "Ubud",
    "lat": "-8.5098",
    "lng": "115.2654"
  },
  {
    "country": "ID",
    "name": "Turen",
    "lat": "-8.17295",
    "lng": "112.6861"
  },
  {
    "country": "ID",
    "name": "Tunjungan",
    "lat": "-6.921",
    "lng": "111.3698"
  },
  {
    "country": "ID",
    "name": "Tumpang",
    "lat": "-8.0061",
    "lng": "112.7639"
  },
  {
    "country": "ID",
    "name": "Tulungagung",
    "lat": "-8.0657",
    "lng": "111.9025"
  },
  {
    "country": "ID",
    "name": "Tulangan Utara",
    "lat": "-7.4737",
    "lng": "112.6505"
  },
  {
    "country": "ID",
    "name": "Tuban",
    "lat": "-6.8976",
    "lng": "112.0649"
  },
  {
    "country": "ID",
    "name": "Tual",
    "lat": "-5.62878",
    "lng": "132.75229"
  },
  {
    "country": "ID",
    "name": "Trucuk",
    "lat": "-7.71833",
    "lng": "110.65889"
  },
  {
    "country": "ID",
    "name": "Trenggalek",
    "lat": "-8.0764",
    "lng": "111.70641"
  },
  {
    "country": "ID",
    "name": "Terawas",
    "lat": "-3.0526",
    "lng": "102.8149"
  },
  {
    "country": "ID",
    "name": "Tongutisungi",
    "lat": "1.49813",
    "lng": "127.55571"
  },
  {
    "country": "ID",
    "name": "Tangga",
    "lat": "-8.656",
    "lng": "118.6937"
  },
  {
    "country": "ID",
    "name": "Tondano",
    "lat": "1.3054",
    "lng": "124.91261"
  },
  {
    "country": "ID",
    "name": "Tomohon",
    "lat": "1.31678",
    "lng": "124.80379"
  },
  {
    "country": "ID",
    "name": "Tombatu",
    "lat": "1.04168",
    "lng": "124.68362"
  },
  {
    "country": "ID",
    "name": "Tolitoli",
    "lat": "1.0392",
    "lng": "120.8169"
  },
  {
    "country": "ID",
    "name": "Toho",
    "lat": "0.41795",
    "lng": "109.22001"
  },
  {
    "country": "ID",
    "name": "Tobelo",
    "lat": "1.72837",
    "lng": "128.00948"
  },
  {
    "country": "ID",
    "name": "Tiom",
    "lat": "-3.92361",
    "lng": "138.45472"
  },
  {
    "country": "ID",
    "name": "Tinabogan",
    "lat": "0.7823",
    "lng": "120.5264"
  },
  {
    "country": "ID",
    "name": "Tilamuta",
    "lat": "0.5273",
    "lng": "122.3463"
  },
  {
    "country": "ID",
    "name": "Tigi",
    "lat": "-3.96667",
    "lng": "136.26667"
  },
  {
    "country": "ID",
    "name": "Tideng Pale",
    "lat": "3.60815",
    "lng": "116.90668"
  },
  {
    "country": "ID",
    "name": "Ternate",
    "lat": "0.79065",
    "lng": "127.38424"
  },
  {
    "country": "ID",
    "name": "Terbanggi Besar",
    "lat": "-4.87898",
    "lng": "105.21818"
  },
  {
    "country": "ID",
    "name": "Tepas",
    "lat": "-8.71667",
    "lng": "116.91667"
  },
  {
    "country": "ID",
    "name": "Tentena",
    "lat": "-1.7562",
    "lng": "120.648"
  },
  {
    "country": "ID",
    "name": "Tenga",
    "lat": "1.16146",
    "lng": "124.43929"
  },
  {
    "country": "ID",
    "name": "Teminabuan",
    "lat": "-1.4416",
    "lng": "132.01428"
  },
  {
    "country": "ID",
    "name": "Tembilahan",
    "lat": "-0.3227",
    "lng": "103.1603"
  },
  {
    "country": "ID",
    "name": "Temanggung",
    "lat": "-7.31917",
    "lng": "110.19278"
  },
  {
    "country": "ID",
    "name": "Telukpakedai",
    "lat": "-0.26493",
    "lng": "109.12069"
  },
  {
    "country": "ID",
    "name": "Telukdalam",
    "lat": "0.53275",
    "lng": "103.26645"
  },
  {
    "country": "ID",
    "name": "Tekung",
    "lat": "-8.1736",
    "lng": "113.2796"
  },
  {
    "country": "ID",
    "name": "Tehoru",
    "lat": "-3.4432",
    "lng": "129.5434"
  },
  {
    "country": "ID",
    "name": "Tegalalang",
    "lat": "-8.4366",
    "lng": "115.2792"
  },
  {
    "country": "ID",
    "name": "Tegal",
    "lat": "-6.8694",
    "lng": "109.1402"
  },
  {
    "country": "ID",
    "name": "Tebing Tinggi",
    "lat": "-3.5842",
    "lng": "103.0772"
  },
  {
    "country": "ID",
    "name": "Tayu",
    "lat": "-6.5397",
    "lng": "111.0518"
  },
  {
    "country": "ID",
    "name": "Tayan",
    "lat": "-0.03365",
    "lng": "110.10184"
  },
  {
    "country": "ID",
    "name": "Tatelu",
    "lat": "1.5307",
    "lng": "124.94765"
  },
  {
    "country": "ID",
    "name": "Tasikmalaya",
    "lat": "-7.3274",
    "lng": "108.2207"
  },
  {
    "country": "ID",
    "name": "Tarub",
    "lat": "-6.93333",
    "lng": "109.16667"
  },
  {
    "country": "ID",
    "name": "Tarogong",
    "lat": "-7.1902",
    "lng": "107.8874"
  },
  {
    "country": "ID",
    "name": "Tarempa",
    "lat": "3.21583",
    "lng": "106.21722"
  },
  {
    "country": "ID",
    "name": "Tarakan",
    "lat": "3.31332",
    "lng": "117.59152"
  },
  {
    "country": "ID",
    "name": "Taraju",
    "lat": "-7.458",
    "lng": "107.9812"
  },
  {
    "country": "ID",
    "name": "Tapalang",
    "lat": "-2.8637",
    "lng": "118.8672"
  },
  {
    "country": "ID",
    "name": "Tanjung Selor",
    "lat": "2.8375",
    "lng": "117.36528"
  },
  {
    "country": "ID",
    "name": "Tanjungsakti",
    "lat": "-4.16762",
    "lng": "103.0687"
  },
  {
    "country": "ID",
    "name": "Tanjungraja",
    "lat": "-3.33725",
    "lng": "104.77452"
  },
  {
    "country": "ID",
    "name": "Tanjung Pinang",
    "lat": "0.91667",
    "lng": "104.45833"
  },
  {
    "country": "ID",
    "name": "Tanjungpati",
    "lat": "-0.16046",
    "lng": "100.67997"
  },
  {
    "country": "ID",
    "name": "Tanjung Pandan",
    "lat": "-2.73353",
    "lng": "107.63477"
  },
  {
    "country": "ID",
    "name": "Tanjung Lubuk",
    "lat": "-3.52678",
    "lng": "104.75858"
  },
  {
    "country": "ID",
    "name": "Bandar Lampung",
    "lat": "-5.42917",
    "lng": "105.26111"
  },
  {
    "country": "ID",
    "name": "Tanjunggadang",
    "lat": "-0.7783",
    "lng": "101.1982"
  },
  {
    "country": "ID",
    "name": "Tanjunggadang",
    "lat": "-0.30126",
    "lng": "100.73841"
  },
  {
    "country": "ID",
    "name": "Tanjungbumi",
    "lat": "-6.8912",
    "lng": "113.0799"
  },
  {
    "country": "ID",
    "name": "Tanjungbatu",
    "lat": "-3.0002",
    "lng": "116.2227"
  },
  {
    "country": "ID",
    "name": "Tanjungbatu",
    "lat": "0.65936",
    "lng": "103.46195"
  },
  {
    "country": "ID",
    "name": "Tanjungampalu",
    "lat": "-0.6221",
    "lng": "100.82507"
  },
  {
    "country": "ID",
    "name": "Tanjungagung",
    "lat": "-3.93728",
    "lng": "103.80465"
  },
  {
    "country": "ID",
    "name": "Tanjung",
    "lat": "-8.356",
    "lng": "116.1565"
  },
  {
    "country": "ID",
    "name": "Tanjung",
    "lat": "4.01527",
    "lng": "108.34345"
  },
  {
    "country": "ID",
    "name": "Tanjung",
    "lat": "-2.1709",
    "lng": "115.4077"
  },
  {
    "country": "ID",
    "name": "Taniwel",
    "lat": "-2.85245",
    "lng": "128.4772"
  },
  {
    "country": "ID",
    "name": "Tongkiling",
    "lat": "-2.1357",
    "lng": "113.8755"
  },
  {
    "country": "ID",
    "name": "Tanggulangin",
    "lat": "-7.49958",
    "lng": "112.69992"
  },
  {
    "country": "ID",
    "name": "Tanggul",
    "lat": "-8.1645",
    "lng": "113.4525"
  },
  {
    "country": "ID",
    "name": "Tanggeung",
    "lat": "-7.2677",
    "lng": "107.1236"
  },
  {
    "country": "ID",
    "name": "Tangerang",
    "lat": "-6.17806",
    "lng": "106.63"
  },
  {
    "country": "ID",
    "name": "Tanahwangko",
    "lat": "1.39368",
    "lng": "124.68227"
  },
  {
    "country": "ID",
    "name": "Tana Paser",
    "lat": "-1.9051",
    "lng": "116.1913"
  },
  {
    "country": "ID",
    "name": "Tamiang Layang",
    "lat": "-2.1236",
    "lng": "115.1958"
  },
  {
    "country": "ID",
    "name": "Tamberu",
    "lat": "-6.8981",
    "lng": "113.4843"
  },
  {
    "country": "ID",
    "name": "Tambaksari",
    "lat": "-7.2489",
    "lng": "108.535"
  },
  {
    "country": "ID",
    "name": "Tamako",
    "lat": "3.44589",
    "lng": "125.52696"
  },
  {
    "country": "ID",
    "name": "Talun",
    "lat": "-8.0906",
    "lng": "112.285"
  },
  {
    "country": "ID",
    "name": "Teluk Kuantan",
    "lat": "-0.5283",
    "lng": "101.581"
  },
  {
    "country": "ID",
    "name": "Taliwang",
    "lat": "-8.7449",
    "lng": "116.8532"
  },
  {
    "country": "ID",
    "name": "Talise",
    "lat": "1.83344",
    "lng": "125.06949"
  },
  {
    "country": "ID",
    "name": "Talawi",
    "lat": "-0.59745",
    "lng": "100.73979"
  },
  {
    "country": "ID",
    "name": "Talang Ubi",
    "lat": "-3.2656",
    "lng": "103.8253"
  },
  {
    "country": "ID",
    "name": "Talangbetutu",
    "lat": "-2.8817",
    "lng": "104.6939"
  },
  {
    "country": "ID",
    "name": "Takokak",
    "lat": "-7.0513",
    "lng": "107.0036"
  },
  {
    "country": "ID",
    "name": "Takalar",
    "lat": "-5.4258",
    "lng": "119.4384"
  },
  {
    "country": "ID",
    "name": "Tajinan",
    "lat": "-8.0497",
    "lng": "112.6824"
  },
  {
    "country": "ID",
    "name": "Tais",
    "lat": "-4.07543",
    "lng": "102.57739"
  },
  {
    "country": "ID",
    "name": "Tagolu",
    "lat": "-1.4393",
    "lng": "120.7731"
  },
  {
    "country": "ID",
    "name": "Taccipi",
    "lat": "-4.5066",
    "lng": "120.1842"
  },
  {
    "country": "ID",
    "name": "Tabing",
    "lat": "-0.87203",
    "lng": "100.34279"
  },
  {
    "country": "ID",
    "name": "Tabanan",
    "lat": "-8.5413",
    "lng": "115.12522"
  },
  {
    "country": "ID",
    "name": "Susupu",
    "lat": "1.15125",
    "lng": "127.43243"
  },
  {
    "country": "ID",
    "name": "Lasusua",
    "lat": "-3.5105",
    "lng": "120.8844"
  },
  {
    "country": "ID",
    "name": "Surulangun Rawas",
    "lat": "-2.6227",
    "lng": "102.7634"
  },
  {
    "country": "ID",
    "name": "Surian",
    "lat": "-1.25587",
    "lng": "100.88129"
  },
  {
    "country": "ID",
    "name": "Surakarta",
    "lat": "-7.55611",
    "lng": "110.83167"
  },
  {
    "country": "ID",
    "name": "Surade",
    "lat": "-7.342",
    "lng": "106.5616"
  },
  {
    "country": "ID",
    "name": "Surabaya",
    "lat": "-7.24917",
    "lng": "112.75083"
  },
  {
    "country": "ID",
    "name": "Surabaya",
    "lat": "-4.67122",
    "lng": "105.72571"
  },
  {
    "country": "ID",
    "name": "Suban Jeriji",
    "lat": "-3.74637",
    "lng": "103.96405"
  },
  {
    "country": "ID",
    "name": "Sungsang",
    "lat": "-2.3629",
    "lng": "104.9038"
  },
  {
    "country": "ID",
    "name": "Sungguminasa",
    "lat": "-5.1971",
    "lng": "119.451"
  },
  {
    "country": "ID",
    "name": "Sungaikakap",
    "lat": "-0.05193",
    "lng": "109.20741"
  },
  {
    "country": "ID",
    "name": "Sungaisalak",
    "lat": "-0.4381",
    "lng": "103.0075"
  },
  {
    "country": "ID",
    "name": "Sungairotan",
    "lat": "-3.10245",
    "lng": "104.27802"
  },
  {
    "country": "ID",
    "name": "Sungairaya",
    "lat": "-2.8566",
    "lng": "115.2474"
  },
  {
    "country": "ID",
    "name": "Sungai Raya",
    "lat": "0.7",
    "lng": "108.9"
  },
  {
    "country": "ID",
    "name": "Sungai Pinyuh",
    "lat": "0.2832",
    "lng": "109.07859"
  },
  {
    "country": "ID",
    "name": "Sungai Penuh",
    "lat": "-2.0561",
    "lng": "101.3913"
  },
  {
    "country": "ID",
    "name": "Sungailimau",
    "lat": "-0.51638",
    "lng": "100.06171"
  },
  {
    "country": "ID",
    "name": "Sungailiat",
    "lat": "-1.85442",
    "lng": "106.12215"
  },
  {
    "country": "ID",
    "name": "Sungaikupang",
    "lat": "-3.0438",
    "lng": "115.9918"
  },
  {
    "country": "ID",
    "name": "Sungaigerong",
    "lat": "-2.9817",
    "lng": "104.8483"
  },
  {
    "country": "ID",
    "name": "Sungaiduri",
    "lat": "0.5664",
    "lng": "108.92891"
  },
  {
    "country": "ID",
    "name": "Sungaibali",
    "lat": "-3.4027",
    "lng": "116.4044"
  },
  {
    "country": "ID",
    "name": "Semurup",
    "lat": "-1.9917",
    "lng": "101.369"
  },
  {
    "country": "ID",
    "name": "Sumpur Kudus",
    "lat": "-0.4418",
    "lng": "100.9088"
  },
  {
    "country": "ID",
    "name": "Sumenep",
    "lat": "-7.01667",
    "lng": "113.86667"
  },
  {
    "country": "ID",
    "name": "Sumedang Utara",
    "lat": "-6.85",
    "lng": "107.91667"
  },
  {
    "country": "ID",
    "name": "Sumedang",
    "lat": "-6.85861",
    "lng": "107.91639"
  },
  {
    "country": "ID",
    "name": "Sumberpucung",
    "lat": "-8.15856",
    "lng": "112.48292"
  },
  {
    "country": "ID",
    "name": "Sumbermanjing Wetan",
    "lat": "-8.2807",
    "lng": "112.6896"
  },
  {
    "country": "ID",
    "name": "Sumberjati",
    "lat": "-8.1873",
    "lng": "113.8799"
  },
  {
    "country": "ID",
    "name": "Sumberjambe",
    "lat": "-8.0699",
    "lng": "113.9002"
  },
  {
    "country": "ID",
    "name": "Sumberbaru",
    "lat": "-8.1177",
    "lng": "113.3887"
  },
  {
    "country": "ID",
    "name": "Sumberanyar",
    "lat": "-7.7824",
    "lng": "114.2997"
  },
  {
    "country": "ID",
    "name": "Sumber",
    "lat": "-6.7978",
    "lng": "111.2572"
  },
  {
    "country": "ID",
    "name": "Sumber",
    "lat": "-6.76028",
    "lng": "108.48306"
  },
  {
    "country": "ID",
    "name": "Sumbawa Besar",
    "lat": "-8.49317",
    "lng": "117.42024"
  },
  {
    "country": "ID",
    "name": "Sulitair",
    "lat": "-0.61258",
    "lng": "100.64788"
  },
  {
    "country": "ID",
    "name": "Sulang Tengah",
    "lat": "-6.8065",
    "lng": "111.3806"
  },
  {
    "country": "ID",
    "name": "Sukowono",
    "lat": "-8.0576",
    "lng": "113.8342"
  },
  {
    "country": "ID",
    "name": "Sukoharjo",
    "lat": "-7.6725",
    "lng": "110.83806"
  },
  {
    "country": "ID",
    "name": "Sukawening",
    "lat": "-7.1568",
    "lng": "108.0065"
  },
  {
    "country": "ID",
    "name": "Sukasari",
    "lat": "-7.0757",
    "lng": "107.8947"
  },
  {
    "country": "ID",
    "name": "Sukasada",
    "lat": "-8.1395",
    "lng": "115.1031"
  },
  {
    "country": "ID",
    "name": "Sokaraja",
    "lat": "-7.45806",
    "lng": "109.28806"
  },
  {
    "country": "ID",
    "name": "Sukaraja",
    "lat": "-7.4519",
    "lng": "108.1944"
  },
  {
    "country": "ID",
    "name": "Sukanagara",
    "lat": "-7.098",
    "lng": "107.1309"
  },
  {
    "country": "ID",
    "name": "Sukadana",
    "lat": "-5.06446",
    "lng": "105.54869"
  },
  {
    "country": "ID",
    "name": "Sukadana",
    "lat": "-1.25",
    "lng": "109.95"
  },
  {
    "country": "ID",
    "name": "Sukabumi",
    "lat": "-6.91806",
    "lng": "106.92667"
  },
  {
    "country": "ID",
    "name": "Subang",
    "lat": "-7.1277",
    "lng": "108.5283"
  },
  {
    "country": "ID",
    "name": "Subang",
    "lat": "-6.57",
    "lng": "107.75667"
  },
  {
    "country": "ID",
    "name": "Subaim",
    "lat": "1.12034",
    "lng": "128.13301"
  },
  {
    "country": "ID",
    "name": "Stagen",
    "lat": "-3.3049",
    "lng": "116.1779"
  },
  {
    "country": "ID",
    "name": "Srono",
    "lat": "-8.40003",
    "lng": "114.26661"
  },
  {
    "country": "ID",
    "name": "Srandakan",
    "lat": "-7.93861",
    "lng": "110.25056"
  },
  {
    "country": "ID",
    "name": "Sragen",
    "lat": "-7.42639",
    "lng": "111.02222"
  },
  {
    "country": "ID",
    "name": "Sorong",
    "lat": "-0.87956",
    "lng": "131.26104"
  },
  {
    "country": "ID",
    "name": "Insrom",
    "lat": "-1.14473",
    "lng": "136.03134"
  },
  {
    "country": "ID",
    "name": "Sorendiweri",
    "lat": "-0.73389",
    "lng": "135.73611"
  },
  {
    "country": "ID",
    "name": "Soreang",
    "lat": "-7.03306",
    "lng": "107.51833"
  },
  {
    "country": "ID",
    "name": "Sonder",
    "lat": "1.25474",
    "lng": "124.77945"
  },
  {
    "country": "ID",
    "name": "Somba",
    "lat": "-3.3772",
    "lng": "118.8475"
  },
  {
    "country": "ID",
    "name": "Solok",
    "lat": "-0.8006",
    "lng": "100.6571"
  },
  {
    "country": "ID",
    "name": "Sokobanah",
    "lat": "-6.89",
    "lng": "113.4347"
  },
  {
    "country": "ID",
    "name": "Soko",
    "lat": "-7.48315",
    "lng": "112.42704"
  },
  {
    "country": "ID",
    "name": "Sofifi",
    "lat": "0.73729",
    "lng": "127.5588"
  },
  {
    "country": "ID",
    "name": "Soe",
    "lat": "-9.86071",
    "lng": "124.28395"
  },
  {
    "country": "ID",
    "name": "Sodong Hilir",
    "lat": "-7.4894",
    "lng": "108.0514"
  },
  {
    "country": "ID",
    "name": "Sluke",
    "lat": "-6.63252",
    "lng": "111.49946"
  },
  {
    "country": "ID",
    "name": "Sleman",
    "lat": "-7.71556",
    "lng": "110.35556"
  },
  {
    "country": "ID",
    "name": "Slawi",
    "lat": "-6.9816",
    "lng": "109.1407"
  },
  {
    "country": "ID",
    "name": "Siwa",
    "lat": "-3.6999",
    "lng": "120.4156"
  },
  {
    "country": "ID",
    "name": "Situbondo",
    "lat": "-7.70623",
    "lng": "114.00976"
  },
  {
    "country": "ID",
    "name": "Sintang",
    "lat": "0.06667",
    "lng": "111.5"
  },
  {
    "country": "ID",
    "name": "Sinjai",
    "lat": "-5.1241",
    "lng": "120.253"
  },
  {
    "country": "ID",
    "name": "Singosari",
    "lat": "-7.8924",
    "lng": "112.6658"
  },
  {
    "country": "ID",
    "name": "Singojuruh",
    "lat": "-8.31667",
    "lng": "114.23333"
  },
  {
    "country": "ID",
    "name": "Singkawang",
    "lat": "0.90925",
    "lng": "108.98463"
  },
  {
    "country": "ID",
    "name": "Singkarak",
    "lat": "-0.69089",
    "lng": "100.60335"
  },
  {
    "country": "ID",
    "name": "Sengkang",
    "lat": "-4.1279",
    "lng": "120.0297"
  },
  {
    "country": "ID",
    "name": "Singaraja",
    "lat": "-8.112",
    "lng": "115.08818"
  },
  {
    "country": "ID",
    "name": "Singaparna",
    "lat": "-7.3515",
    "lng": "108.111"
  },
  {
    "country": "ID",
    "name": "Sindangbarang",
    "lat": "-7.4516",
    "lng": "107.1353"
  },
  {
    "country": "ID",
    "name": "Simpur",
    "lat": "-2.8281",
    "lng": "115.2666"
  },
  {
    "country": "ID",
    "name": "Simpangempat",
    "lat": "-3.2785",
    "lng": "115.0293"
  },
  {
    "country": "ID",
    "name": "Simpang",
    "lat": "-4.44867",
    "lng": "104.1922"
  },
  {
    "country": "ID",
    "name": "Simpang",
    "lat": "-1.26424",
    "lng": "104.09701"
  },
  {
    "country": "ID",
    "name": "Sila",
    "lat": "-8.5025",
    "lng": "118.62"
  },
  {
    "country": "ID",
    "name": "Sijunjung",
    "lat": "-0.7005",
    "lng": "100.9774"
  },
  {
    "country": "ID",
    "name": "Sidoarjo",
    "lat": "-7.4478",
    "lng": "112.7183"
  },
  {
    "country": "ID",
    "name": "Sidareja",
    "lat": "-7.4846",
    "lng": "108.7923"
  },
  {
    "country": "ID",
    "name": "Siak Sri Indrapura",
    "lat": "0.79317",
    "lng": "102.0511"
  },
  {
    "country": "ID",
    "name": "Sewon",
    "lat": "-7.87639",
    "lng": "110.35889"
  },
  {
    "country": "ID",
    "name": "Seteluk",
    "lat": "-8.62549",
    "lng": "116.86674"
  },
  {
    "country": "ID",
    "name": "Sesayap",
    "lat": "3.58525",
    "lng": "117.00765"
  },
  {
    "country": "ID",
    "name": "Serui",
    "lat": "-1.8802",
    "lng": "136.2426"
  },
  {
    "country": "ID",
    "name": "Serpong",
    "lat": "-6.31694",
    "lng": "106.66417"
  },
  {
    "country": "ID",
    "name": "Serasan",
    "lat": "2.51111",
    "lng": "109.03111"
  },
  {
    "country": "ID",
    "name": "Serang",
    "lat": "-6.11528",
    "lng": "106.15417"
  },
  {
    "country": "ID",
    "name": "Sepatan",
    "lat": "-6.11889",
    "lng": "106.575"
  },
  {
    "country": "ID",
    "name": "Senori",
    "lat": "-7.0157",
    "lng": "111.7244"
  },
  {
    "country": "ID",
    "name": "Sengeti",
    "lat": "-1.4772",
    "lng": "103.50765"
  },
  {
    "country": "ID",
    "name": "Sangatta",
    "lat": "0.5049",
    "lng": "117.5279"
  },
  {
    "country": "ID",
    "name": "Senduro",
    "lat": "-8.0936",
    "lng": "113.0891"
  },
  {
    "country": "ID",
    "name": "Semuda",
    "lat": "-2.8617",
    "lng": "112.9732"
  },
  {
    "country": "ID",
    "name": "Semongkat",
    "lat": "-8.5721",
    "lng": "117.3193"
  },
  {
    "country": "ID",
    "name": "Semilat",
    "lat": "-2.3077",
    "lng": "112.2118"
  },
  {
    "country": "ID",
    "name": "Semboro Lor",
    "lat": "-8.1901",
    "lng": "113.4445"
  },
  {
    "country": "ID",
    "name": "Semarang",
    "lat": "-6.99306",
    "lng": "110.42083"
  },
  {
    "country": "ID",
    "name": "Semamung",
    "lat": "-8.6515",
    "lng": "117.4288"
  },
  {
    "country": "ID",
    "name": "Selorejo",
    "lat": "-8.1392",
    "lng": "112.4257"
  },
  {
    "country": "ID",
    "name": "Selong",
    "lat": "-8.6503",
    "lng": "116.5318"
  },
  {
    "country": "ID",
    "name": "Selogiri",
    "lat": "-7.78333",
    "lng": "110.86667"
  },
  {
    "country": "ID",
    "name": "Selat Panjang",
    "lat": "0.99408",
    "lng": "102.70817"
  },
  {
    "country": "ID",
    "name": "Selajambe",
    "lat": "-7.1181",
    "lng": "108.4625"
  },
  {
    "country": "ID",
    "name": "Sekupang",
    "lat": "1.12723",
    "lng": "103.92672"
  },
  {
    "country": "ID",
    "name": "Sekongkang Bawah",
    "lat": "-8.9659",
    "lng": "116.74917"
  },
  {
    "country": "ID",
    "name": "Sekayu",
    "lat": "-2.8819",
    "lng": "103.8344"
  },
  {
    "country": "ID",
    "name": "Sekernan",
    "lat": "-1.52342",
    "lng": "103.56752"
  },
  {
    "country": "ID",
    "name": "Sekampung",
    "lat": "-5.13326",
    "lng": "105.43595"
  },
  {
    "country": "ID",
    "name": "Sekadau",
    "lat": "0.01667",
    "lng": "110.9"
  },
  {
    "country": "ID",
    "name": "Seget",
    "lat": "-1.41179",
    "lng": "130.97478"
  },
  {
    "country": "ID",
    "name": "Sedinginan",
    "lat": "1.55381",
    "lng": "101.0152"
  },
  {
    "country": "ID",
    "name": "Sidayu",
    "lat": "-6.9993",
    "lng": "112.5636"
  },
  {
    "country": "ID",
    "name": "Sedanau",
    "lat": "3.79377",
    "lng": "108.02929"
  },
  {
    "country": "ID",
    "name": "Sedan",
    "lat": "-6.7668",
    "lng": "111.5744"
  },
  {
    "country": "ID",
    "name": "Sebulu",
    "lat": "-0.27393",
    "lng": "116.99835"
  },
  {
    "country": "ID",
    "name": "Sebuku",
    "lat": "4.00232",
    "lng": "117.03456"
  },
  {
    "country": "ID",
    "name": "Sawangan",
    "lat": "-6.40278",
    "lng": "106.77444"
  },
  {
    "country": "ID",
    "name": "Sawang",
    "lat": "0.7368",
    "lng": "103.35635"
  },
  {
    "country": "ID",
    "name": "Saukorem",
    "lat": "-0.565",
    "lng": "133.1527"
  },
  {
    "country": "ID",
    "name": "Satui",
    "lat": "-3.7818",
    "lng": "115.4575"
  },
  {
    "country": "ID",
    "name": "Saruaso",
    "lat": "-0.4831",
    "lng": "100.63765"
  },
  {
    "country": "ID",
    "name": "Sarolangun",
    "lat": "-2.3121",
    "lng": "102.7271"
  },
  {
    "country": "ID",
    "name": "Sarmi",
    "lat": "-1.85302",
    "lng": "138.75093"
  },
  {
    "country": "ID",
    "name": "Sarilamak",
    "lat": "-0.1503",
    "lng": "100.664"
  },
  {
    "country": "ID",
    "name": "Sepulu",
    "lat": "-6.8976",
    "lng": "112.9593"
  },
  {
    "country": "ID",
    "name": "Sapeken",
    "lat": "-7.00468",
    "lng": "115.70619"
  },
  {
    "country": "ID",
    "name": "Sape",
    "lat": "-8.56667",
    "lng": "118.98333"
  },
  {
    "country": "ID",
    "name": "Sapat",
    "lat": "-0.3235",
    "lng": "103.3101"
  },
  {
    "country": "ID",
    "name": "Saparua",
    "lat": "-3.573",
    "lng": "128.65242"
  },
  {
    "country": "ID",
    "name": "Saonek",
    "lat": "-0.4379",
    "lng": "130.7559"
  },
  {
    "country": "ID",
    "name": "Sausapor",
    "lat": "-0.49985",
    "lng": "132.08588"
  },
  {
    "country": "ID",
    "name": "Sangkulirang",
    "lat": "0.977",
    "lng": "117.9803"
  },
  {
    "country": "ID",
    "name": "Sanggau",
    "lat": "0.13333",
    "lng": "110.6"
  },
  {
    "country": "ID",
    "name": "Kore",
    "lat": "-8.37599",
    "lng": "118.29876"
  },
  {
    "country": "ID",
    "name": "Sangasangadalam",
    "lat": "-0.6624",
    "lng": "117.2365"
  },
  {
    "country": "ID",
    "name": "Sanana",
    "lat": "-2.05853",
    "lng": "125.97786"
  },
  {
    "country": "ID",
    "name": "Sampit",
    "lat": "-2.5315",
    "lng": "112.9496"
  },
  {
    "country": "ID",
    "name": "Sampang",
    "lat": "-7.56333",
    "lng": "109.19667"
  },
  {
    "country": "ID",
    "name": "Sampang",
    "lat": "-7.1872",
    "lng": "113.2394"
  },
  {
    "country": "ID",
    "name": "Sampalan",
    "lat": "-8.6736",
    "lng": "115.5586"
  },
  {
    "country": "ID",
    "name": "Samboja",
    "lat": "-1.03333",
    "lng": "117.03333"
  },
  {
    "country": "ID",
    "name": "Sumberbaba",
    "lat": "-1.8188",
    "lng": "136.7576"
  },
  {
    "country": "ID",
    "name": "Sambas",
    "lat": "1.33333",
    "lng": "109.25"
  },
  {
    "country": "ID",
    "name": "Samarinda",
    "lat": "-0.49167",
    "lng": "117.14583"
  },
  {
    "country": "ID",
    "name": "Tanjungsamalantakan",
    "lat": "-2.5818",
    "lng": "116.4099"
  },
  {
    "country": "ID",
    "name": "Salopa",
    "lat": "-7.5162",
    "lng": "108.2722"
  },
  {
    "country": "ID",
    "name": "Salinbatu",
    "lat": "2.94051",
    "lng": "117.34343"
  },
  {
    "country": "ID",
    "name": "Salem",
    "lat": "-7.1825",
    "lng": "108.8059"
  },
  {
    "country": "ID",
    "name": "Sale",
    "lat": "-6.8619",
    "lng": "111.6043"
  },
  {
    "country": "ID",
    "name": "Salawu",
    "lat": "-7.3755",
    "lng": "108.0325"
  },
  {
    "country": "ID",
    "name": "Salatiga",
    "lat": "-7.33194",
    "lng": "110.49278"
  },
  {
    "country": "ID",
    "name": "Salakan",
    "lat": "-1.3085",
    "lng": "123.2909"
  },
  {
    "country": "ID",
    "name": "Sakra",
    "lat": "-8.6831",
    "lng": "116.462"
  },
  {
    "country": "ID",
    "name": "Saketi",
    "lat": "-6.401",
    "lng": "105.992"
  },
  {
    "country": "ID",
    "name": "Sagaranten",
    "lat": "-7.2184",
    "lng": "106.8851"
  },
  {
    "country": "ID",
    "name": "Sadananya",
    "lat": "-7.2741",
    "lng": "108.3149"
  },
  {
    "country": "ID",
    "name": "Sabang Barat",
    "lat": "3.00722",
    "lng": "107.75361"
  },
  {
    "country": "ID",
    "name": "Ruteng",
    "lat": "-8.61139",
    "lng": "120.46444"
  },
  {
    "country": "ID",
    "name": "Rumbia",
    "lat": "-4.62767",
    "lng": "122.00472"
  },
  {
    "country": "ID",
    "name": "Rubaru",
    "lat": "-6.9581",
    "lng": "113.753"
  },
  {
    "country": "ID",
    "name": "Rokan",
    "lat": "0.5698",
    "lng": "100.4075"
  },
  {
    "country": "ID",
    "name": "Robatal",
    "lat": "-7.0009",
    "lng": "113.28"
  },
  {
    "country": "ID",
    "name": "Riung",
    "lat": "-8.4213",
    "lng": "121.0256"
  },
  {
    "country": "ID",
    "name": "Rengat",
    "lat": "-0.37546",
    "lng": "102.5481"
  },
  {
    "country": "ID",
    "name": "Rengasdengklok",
    "lat": "-6.15917",
    "lng": "107.29806"
  },
  {
    "country": "ID",
    "name": "Rembangan",
    "lat": "-6.7036",
    "lng": "111.3416"
  },
  {
    "country": "ID",
    "name": "Rawalo",
    "lat": "-7.53694",
    "lng": "109.17917"
  },
  {
    "country": "ID",
    "name": "Ratahan",
    "lat": "1.0549",
    "lng": "124.8012"
  },
  {
    "country": "ID",
    "name": "Rasiei",
    "lat": "-2.817",
    "lng": "134.5292"
  },
  {
    "country": "ID",
    "name": "Rappang",
    "lat": "-3.8445",
    "lng": "119.8173"
  },
  {
    "country": "ID",
    "name": "Rantepao",
    "lat": "-2.9701",
    "lng": "119.8978"
  },
  {
    "country": "ID",
    "name": "Rantaupulut",
    "lat": "-2.0093",
    "lng": "112.1956"
  },
  {
    "country": "ID",
    "name": "Rantaupangiang",
    "lat": "-2.4962",
    "lng": "102.2505"
  },
  {
    "country": "ID",
    "name": "Rantaupanjang",
    "lat": "-1.8446",
    "lng": "102.3081"
  },
  {
    "country": "ID",
    "name": "Rantau",
    "lat": "-2.9334",
    "lng": "115.1621"
  },
  {
    "country": "ID",
    "name": "Ransiki",
    "lat": "-1.5083",
    "lng": "134.1708"
  },
  {
    "country": "ID",
    "name": "Rangkasbitung",
    "lat": "-6.3591",
    "lng": "106.2494"
  },
  {
    "country": "ID",
    "name": "Randudongkal",
    "lat": "-7.0981",
    "lng": "109.3243"
  },
  {
    "country": "ID",
    "name": "Randuagung",
    "lat": "-8.072",
    "lng": "113.3032"
  },
  {
    "country": "ID",
    "name": "Rancah",
    "lat": "-7.1969",
    "lng": "108.5041"
  },
  {
    "country": "ID",
    "name": "Ranai",
    "lat": "3.9384",
    "lng": "108.38401"
  },
  {
    "country": "ID",
    "name": "Rambipuji",
    "lat": "-8.209",
    "lng": "113.6092"
  },
  {
    "country": "ID",
    "name": "Rajapolah",
    "lat": "-7.221",
    "lng": "108.1896"
  },
  {
    "country": "ID",
    "name": "Rajadesa",
    "lat": "-7.1836",
    "lng": "108.4341"
  },
  {
    "country": "ID",
    "name": "Rainis",
    "lat": "4.23282",
    "lng": "126.86129"
  },
  {
    "country": "ID",
    "name": "Raha",
    "lat": "-4.838",
    "lng": "122.7209"
  },
  {
    "country": "ID",
    "name": "Raba",
    "lat": "-8.4613",
    "lng": "118.747"
  },
  {
    "country": "ID",
    "name": "Putussibau",
    "lat": "0.83333",
    "lng": "112.93333"
  },
  {
    "country": "ID",
    "name": "Purworejo",
    "lat": "-7.71139",
    "lng": "110.01028"
  },
  {
    "country": "ID",
    "name": "Purwokerto",
    "lat": "-7.42139",
    "lng": "109.23444"
  },
  {
    "country": "ID",
    "name": "Purwoharjo",
    "lat": "-8.501",
    "lng": "114.222"
  },
  {
    "country": "ID",
    "name": "Purwodadi",
    "lat": "-7.0868",
    "lng": "110.9158"
  },
  {
    "country": "ID",
    "name": "Purwakarta",
    "lat": "-6.55694",
    "lng": "107.44333"
  },
  {
    "country": "ID",
    "name": "Puruk Cahu",
    "lat": "-0.58333",
    "lng": "114.58333"
  },
  {
    "country": "ID",
    "name": "Purbalingga",
    "lat": "-7.38806",
    "lng": "109.36389"
  },
  {
    "country": "ID",
    "name": "Pundong",
    "lat": "-7.95222",
    "lng": "110.34861"
  },
  {
    "country": "ID",
    "name": "Pule",
    "lat": "-8.1238",
    "lng": "111.5614"
  },
  {
    "country": "ID",
    "name": "Pulaupinang",
    "lat": "-3.89106",
    "lng": "103.52023"
  },
  {
    "country": "ID",
    "name": "Pulaukijang",
    "lat": "-0.6868",
    "lng": "103.1841"
  },
  {
    "country": "ID",
    "name": "Pulauberingin",
    "lat": "-4.49982",
    "lng": "103.63662"
  },
  {
    "country": "ID",
    "name": "Pulang Pisau",
    "lat": "-2.7671",
    "lng": "114.2406"
  },
  {
    "country": "ID",
    "name": "Puger",
    "lat": "-8.3702",
    "lng": "113.4752"
  },
  {
    "country": "ID",
    "name": "Probolinggo",
    "lat": "-7.7543",
    "lng": "113.2159"
  },
  {
    "country": "ID",
    "name": "Pringsewu",
    "lat": "-5.35822",
    "lng": "104.97441"
  },
  {
    "country": "ID",
    "name": "Prigen",
    "lat": "-7.68333",
    "lng": "112.61667"
  },
  {
    "country": "ID",
    "name": "Praya",
    "lat": "-8.70536",
    "lng": "116.27036"
  },
  {
    "country": "ID",
    "name": "Candi Prambanan",
    "lat": "-7.75",
    "lng": "110.49417"
  },
  {
    "country": "ID",
    "name": "Pota",
    "lat": "-8.3414",
    "lng": "120.7607"
  },
  {
    "country": "ID",
    "name": "Poso",
    "lat": "-1.3959",
    "lng": "120.7524"
  },
  {
    "country": "ID",
    "name": "Pontianak",
    "lat": "-0.03194",
    "lng": "109.325"
  },
  {
    "country": "ID",
    "name": "Ponorogo",
    "lat": "-7.8685",
    "lng": "111.462"
  },
  {
    "country": "ID",
    "name": "Polewali",
    "lat": "-3.4324",
    "lng": "119.3435"
  },
  {
    "country": "ID",
    "name": "Poigar",
    "lat": "1.02082",
    "lng": "124.30894"
  },
  {
    "country": "ID",
    "name": "Plumbon",
    "lat": "-6.705",
    "lng": "108.47278"
  },
  {
    "country": "ID",
    "name": "Plampang",
    "lat": "-8.7974",
    "lng": "117.7791"
  },
  {
    "country": "ID",
    "name": "Piru",
    "lat": "-3.0618",
    "lng": "128.1945"
  },
  {
    "country": "ID",
    "name": "Pinrang",
    "lat": "-3.78611",
    "lng": "119.65222"
  },
  {
    "country": "ID",
    "name": "Pineleng",
    "lat": "1.42422",
    "lng": "124.83865"
  },
  {
    "country": "ID",
    "name": "Pimpi",
    "lat": "0.8825",
    "lng": "123.5502"
  },
  {
    "country": "ID",
    "name": "Patimuan",
    "lat": "-7.59825",
    "lng": "108.75511"
  },
  {
    "country": "ID",
    "name": "Petakbehandang",
    "lat": "-2.0775",
    "lng": "113.4364"
  },
  {
    "country": "ID",
    "name": "Peranap",
    "lat": "-0.5449",
    "lng": "101.9837"
  },
  {
    "country": "ID",
    "name": "Prabumulih",
    "lat": "-3.43447",
    "lng": "104.23056"
  },
  {
    "country": "ID",
    "name": "Peninjawan",
    "lat": "-3.86945",
    "lng": "104.38233"
  },
  {
    "country": "ID",
    "name": "Pangaron",
    "lat": "-3.3101",
    "lng": "115.1961"
  },
  {
    "country": "ID",
    "name": "Pengandonan",
    "lat": "-4.05421",
    "lng": "103.87668"
  },
  {
    "country": "ID",
    "name": "Pendolo",
    "lat": "-2.0746",
    "lng": "120.6851"
  },
  {
    "country": "ID",
    "name": "Pembuanghulu",
    "lat": "-2.5094",
    "lng": "112.1515"
  },
  {
    "country": "ID",
    "name": "Pemangkat",
    "lat": "1.16667",
    "lng": "108.96667"
  },
  {
    "country": "ID",
    "name": "Pemalang",
    "lat": "-6.89193",
    "lng": "109.38263"
  },
  {
    "country": "ID",
    "name": "Pelau",
    "lat": "-3.5204",
    "lng": "128.4681"
  },
  {
    "country": "ID",
    "name": "Pelaihari",
    "lat": "-3.7987",
    "lng": "114.7788"
  },
  {
    "country": "ID",
    "name": "Pelabuhanratu",
    "lat": "-6.9875",
    "lng": "106.55139"
  },
  {
    "country": "ID",
    "name": "Pelabuhan Dagang",
    "lat": "-1.1463",
    "lng": "103.08494"
  },
  {
    "country": "ID",
    "name": "Pekanbaru",
    "lat": "0.51667",
    "lng": "101.44167"
  },
  {
    "country": "ID",
    "name": "Pekalongan",
    "lat": "-6.8886",
    "lng": "109.6753"
  },
  {
    "country": "ID",
    "name": "Pedamaran",
    "lat": "-3.4884",
    "lng": "104.8376"
  },
  {
    "country": "ID",
    "name": "Pecangaan",
    "lat": "-6.6978",
    "lng": "110.7107"
  },
  {
    "country": "ID",
    "name": "Payunga",
    "lat": "0.5632",
    "lng": "122.9519"
  },
  {
    "country": "ID",
    "name": "Payakumbuh",
    "lat": "-0.2159",
    "lng": "100.6334"
  },
  {
    "country": "ID",
    "name": "Pemenang",
    "lat": "-8.40401",
    "lng": "116.10255"
  },
  {
    "country": "ID",
    "name": "Pauh",
    "lat": "-2.1386",
    "lng": "102.8186"
  },
  {
    "country": "ID",
    "name": "Pototano",
    "lat": "-8.4126",
    "lng": "117.4811"
  },
  {
    "country": "ID",
    "name": "Pati",
    "lat": "-6.7559",
    "lng": "111.038"
  },
  {
    "country": "ID",
    "name": "Pasuruan",
    "lat": "-7.6453",
    "lng": "112.9075"
  },
  {
    "country": "ID",
    "name": "Pasongsongan",
    "lat": "-6.889",
    "lng": "113.657"
  },
  {
    "country": "ID",
    "name": "Passo",
    "lat": "-3.63011",
    "lng": "128.25237"
  },
  {
    "country": "ID",
    "name": "Pasir Pengaraian",
    "lat": "0.86459",
    "lng": "100.29547"
  },
  {
    "country": "ID",
    "name": "Pasirian",
    "lat": "-8.2137",
    "lng": "113.1146"
  },
  {
    "country": "ID",
    "name": "Pasean",
    "lat": "-6.8932",
    "lng": "113.5805"
  },
  {
    "country": "ID",
    "name": "Passi",
    "lat": "0.7655",
    "lng": "124.2982"
  },
  {
    "country": "ID",
    "name": "Paseh",
    "lat": "-7.1026",
    "lng": "107.7641"
  },
  {
    "country": "ID",
    "name": "Pasar Wajo",
    "lat": "-5.4957",
    "lng": "122.8447"
  },
  {
    "country": "ID",
    "name": "Pasarkuok",
    "lat": "-1.4414",
    "lng": "100.622"
  },
  {
    "country": "ID",
    "name": "Pasarkemis",
    "lat": "-6.17028",
    "lng": "106.53028"
  },
  {
    "country": "ID",
    "name": "Pasarbaru",
    "lat": "-1.3051",
    "lng": "100.50995"
  },
  {
    "country": "ID",
    "name": "Parung",
    "lat": "-6.42139",
    "lng": "106.73306"
  },
  {
    "country": "ID",
    "name": "Parit Malintang",
    "lat": "-0.62046",
    "lng": "100.27885"
  },
  {
    "country": "ID",
    "name": "Paringin",
    "lat": "-2.3357",
    "lng": "115.4749"
  },
  {
    "country": "ID",
    "name": "Parigi",
    "lat": "-7.7015",
    "lng": "108.496"
  },
  {
    "country": "ID",
    "name": "Parigi",
    "lat": "-0.8156",
    "lng": "120.1768"
  },
  {
    "country": "ID",
    "name": "Pariaman",
    "lat": "-0.61898",
    "lng": "100.11997"
  },
  {
    "country": "ID",
    "name": "Parepare",
    "lat": "-4.0135",
    "lng": "119.6255"
  },
  {
    "country": "ID",
    "name": "Pare",
    "lat": "-7.7679",
    "lng": "112.198"
  },
  {
    "country": "ID",
    "name": "Panti",
    "lat": "0.3623",
    "lng": "100.0552"
  },
  {
    "country": "ID",
    "name": "Pantaihambawang",
    "lat": "-2.64659",
    "lng": "115.33087"
  },
  {
    "country": "ID",
    "name": "Pantai",
    "lat": "-3.1313",
    "lng": "116.1353"
  },
  {
    "country": "ID",
    "name": "Panji",
    "lat": "-7.72528",
    "lng": "114.09954"
  },
  {
    "country": "ID",
    "name": "Panjang",
    "lat": "-5.4759",
    "lng": "105.31982"
  },
  {
    "country": "ID",
    "name": "Panjalu",
    "lat": "-7.1313",
    "lng": "108.2661"
  },
  {
    "country": "ID",
    "name": "Pangkalpinang",
    "lat": "-2.12914",
    "lng": "106.11377"
  },
  {
    "country": "ID",
    "name": "Pangkalan Kasai",
    "lat": "-0.5892",
    "lng": "102.39"
  },
  {
    "country": "ID",
    "name": "Pangkalanbuun",
    "lat": "-2.6832",
    "lng": "111.6259"
  },
  {
    "country": "ID",
    "name": "Pangkalanbunut",
    "lat": "0.2981",
    "lng": "102.1461"
  },
  {
    "country": "ID",
    "name": "Pangkalan Balai",
    "lat": "-2.8812",
    "lng": "104.3943"
  },
  {
    "country": "ID",
    "name": "Pangkajene",
    "lat": "-4.8372",
    "lng": "119.5472"
  },
  {
    "country": "ID",
    "name": "Panggungrejo",
    "lat": "-8.2512",
    "lng": "112.2787"
  },
  {
    "country": "ID",
    "name": "Panggul",
    "lat": "-8.2492",
    "lng": "111.4554"
  },
  {
    "country": "ID",
    "name": "Pandeglang",
    "lat": "-6.3084",
    "lng": "106.1067"
  },
  {
    "country": "ID",
    "name": "Pandaan",
    "lat": "-7.65268",
    "lng": "112.6875"
  },
  {
    "country": "ID",
    "name": "Pandak",
    "lat": "-7.91306",
    "lng": "110.29361"
  },
  {
    "country": "ID",
    "name": "Pancur",
    "lat": "-6.7215",
    "lng": "111.4684"
  },
  {
    "country": "ID",
    "name": "Panawangan",
    "lat": "-7.118",
    "lng": "108.3816"
  },
  {
    "country": "ID",
    "name": "Panarukan",
    "lat": "-7.70181",
    "lng": "113.91844"
  },
  {
    "country": "ID",
    "name": "Panaragan",
    "lat": "-4.47784",
    "lng": "105.08142"
  },
  {
    "country": "ID",
    "name": "Penajam",
    "lat": "-1.24919",
    "lng": "116.76968"
  },
  {
    "country": "ID",
    "name": "Pamulang",
    "lat": "-6.34278",
    "lng": "106.73833"
  },
  {
    "country": "ID",
    "name": "Pompanua",
    "lat": "-4.2254",
    "lng": "120.1484"
  },
  {
    "country": "ID",
    "name": "Pamotan",
    "lat": "-6.7609",
    "lng": "111.4898"
  },
  {
    "country": "ID",
    "name": "Pameungpeuk",
    "lat": "-7.6413",
    "lng": "107.7332"
  },
  {
    "country": "ID",
    "name": "Pameungpeuk",
    "lat": "-7.01833",
    "lng": "107.60389"
  },
  {
    "country": "ID",
    "name": "Pamekasan",
    "lat": "-7.1568",
    "lng": "113.4746"
  },
  {
    "country": "ID",
    "name": "Pamarican",
    "lat": "-7.4576",
    "lng": "108.524"
  },
  {
    "country": "ID",
    "name": "Pamanukan",
    "lat": "-6.28417",
    "lng": "107.81056"
  },
  {
    "country": "ID",
    "name": "Palu",
    "lat": "-0.90833",
    "lng": "119.87083"
  },
  {
    "country": "ID",
    "name": "Palopo",
    "lat": "-2.9925",
    "lng": "120.19694"
  },
  {
    "country": "ID",
    "name": "Palimanan",
    "lat": "-6.70694",
    "lng": "108.42417"
  },
  {
    "country": "ID",
    "name": "Palembaian",
    "lat": "-0.18333",
    "lng": "100.23333"
  },
  {
    "country": "ID",
    "name": "Palembang",
    "lat": "-2.91673",
    "lng": "104.7458"
  },
  {
    "country": "ID",
    "name": "Palattae",
    "lat": "-4.9711",
    "lng": "120.1127"
  },
  {
    "country": "ID",
    "name": "Palangkaraya",
    "lat": "-2.20833",
    "lng": "113.91667"
  },
  {
    "country": "ID",
    "name": "Palakka",
    "lat": "-4.5313",
    "lng": "120.2892"
  },
  {
    "country": "ID",
    "name": "Pakuan Agung",
    "lat": "-4.66481",
    "lng": "104.96293"
  },
  {
    "country": "ID",
    "name": "Kuaro",
    "lat": "-1.8198",
    "lng": "116.0797"
  },
  {
    "country": "ID",
    "name": "Pakong",
    "lat": "-7.0311",
    "lng": "113.5496"
  },
  {
    "country": "ID",
    "name": "Pakisaji",
    "lat": "-8.0665",
    "lng": "112.5981"
  },
  {
    "country": "ID",
    "name": "Pakenjeng",
    "lat": "-7.41181",
    "lng": "107.69049"
  },
  {
    "country": "ID",
    "name": "Pakel",
    "lat": "-8.1543",
    "lng": "111.8264"
  },
  {
    "country": "ID",
    "name": "Painan",
    "lat": "-1.35172",
    "lng": "100.57383"
  },
  {
    "country": "ID",
    "name": "Pagerageung",
    "lat": "-7.1124",
    "lng": "108.1668"
  },
  {
    "country": "ID",
    "name": "Pagelaran",
    "lat": "-6.433",
    "lng": "105.8572"
  },
  {
    "country": "ID",
    "name": "Pagatan",
    "lat": "-3.6075",
    "lng": "115.9381"
  },
  {
    "country": "ID",
    "name": "Pagatan",
    "lat": "-3.1701",
    "lng": "113.2881"
  },
  {
    "country": "ID",
    "name": "Pagat",
    "lat": "-2.6243",
    "lng": "115.4338"
  },
  {
    "country": "ID",
    "name": "Pagar Alam",
    "lat": "-4.02506",
    "lng": "103.24694"
  },
  {
    "country": "ID",
    "name": "Pagak",
    "lat": "-8.2258",
    "lng": "112.5276"
  },
  {
    "country": "ID",
    "name": "Paga",
    "lat": "-8.7766",
    "lng": "122.0455"
  },
  {
    "country": "ID",
    "name": "Pademawu",
    "lat": "-7.1862",
    "lng": "113.52571"
  },
  {
    "country": "ID",
    "name": "Padarincang",
    "lat": "-6.214",
    "lng": "105.9512"
  },
  {
    "country": "ID",
    "name": "Padangulaktanding",
    "lat": "-3.3749",
    "lng": "102.7996"
  },
  {
    "country": "ID",
    "name": "Padangtikar",
    "lat": "-0.6913",
    "lng": "109.26327"
  },
  {
    "country": "ID",
    "name": "Padangguci",
    "lat": "-4.58891",
    "lng": "103.14425"
  },
  {
    "country": "ID",
    "name": "Padangcermin",
    "lat": "-5.60075",
    "lng": "105.1387"
  },
  {
    "country": "ID",
    "name": "Padangbatung",
    "lat": "-2.838",
    "lng": "115.2912"
  },
  {
    "country": "ID",
    "name": "Padang",
    "lat": "-0.94924",
    "lng": "100.35427"
  },
  {
    "country": "ID",
    "name": "Padaherang",
    "lat": "-7.5499",
    "lng": "108.6956"
  },
  {
    "country": "ID",
    "name": "Pacitan",
    "lat": "-8.19389",
    "lng": "111.10333"
  },
  {
    "country": "ID",
    "name": "Paciran",
    "lat": "-6.87666",
    "lng": "112.37606"
  },
  {
    "country": "ID",
    "name": "Pabuaran",
    "lat": "-6.2043",
    "lng": "106.0711"
  },
  {
    "country": "ID",
    "name": "Oransbari",
    "lat": "-1.3442",
    "lng": "134.2587"
  },
  {
    "country": "ID",
    "name": "Ondong Siau",
    "lat": "2.7473",
    "lng": "125.3611"
  },
  {
    "country": "ID",
    "name": "Obano",
    "lat": "-3.9259",
    "lng": "136.2259"
  },
  {
    "country": "ID",
    "name": "Nyalindung",
    "lat": "-7.0426",
    "lng": "106.9442"
  },
  {
    "country": "ID",
    "name": "Noemuti",
    "lat": "-9.568",
    "lng": "124.495"
  },
  {
    "country": "ID",
    "name": "Nipah Panjang",
    "lat": "-1.07518",
    "lng": "104.19438"
  },
  {
    "country": "ID",
    "name": "Nikiniki",
    "lat": "-9.81361",
    "lng": "124.47649"
  },
  {
    "country": "ID",
    "name": "Ngunut",
    "lat": "-8.1058",
    "lng": "112.01591"
  },
  {
    "country": "ID",
    "name": "Ngrayun",
    "lat": "-8.0723",
    "lng": "111.4489"
  },
  {
    "country": "ID",
    "name": "Ngoro",
    "lat": "-7.68386",
    "lng": "112.25804"
  },
  {
    "country": "ID",
    "name": "Ngawi",
    "lat": "-7.4038",
    "lng": "111.4461"
  },
  {
    "country": "ID",
    "name": "Ngawen",
    "lat": "-7.0032",
    "lng": "111.3129"
  },
  {
    "country": "ID",
    "name": "Ngantru",
    "lat": "-8.0101",
    "lng": "111.9254"
  },
  {
    "country": "ID",
    "name": "Nganjuk",
    "lat": "-7.6051",
    "lng": "111.9035"
  },
  {
    "country": "ID",
    "name": "Ngabang",
    "lat": "0.38333",
    "lng": "109.95"
  },
  {
    "country": "ID",
    "name": "Negararatu",
    "lat": "-4.65603",
    "lng": "104.73576"
  },
  {
    "country": "ID",
    "name": "Negara",
    "lat": "-8.35694",
    "lng": "114.61694"
  },
  {
    "country": "ID",
    "name": "Natar",
    "lat": "-5.30897",
    "lng": "105.19251"
  },
  {
    "country": "ID",
    "name": "Narmada",
    "lat": "-8.5912",
    "lng": "116.202"
  },
  {
    "country": "ID",
    "name": "Naringgul",
    "lat": "-7.3344",
    "lng": "107.3282"
  },
  {
    "country": "ID",
    "name": "Nangaroro",
    "lat": "-8.7872",
    "lng": "121.3923"
  },
  {
    "country": "ID",
    "name": "Nangah Pinoh",
    "lat": "-0.33333",
    "lng": "111.73333"
  },
  {
    "country": "ID",
    "name": "Nanga Bulik",
    "lat": "-2.1624",
    "lng": "111.4885"
  },
  {
    "country": "ID",
    "name": "Namrole",
    "lat": "-3.84548",
    "lng": "126.72619"
  },
  {
    "country": "ID",
    "name": "Namlea",
    "lat": "-3.26194",
    "lng": "127.09292"
  },
  {
    "country": "ID",
    "name": "Nabire",
    "lat": "-3.35989",
    "lng": "135.50074"
  },
  {
    "country": "ID",
    "name": "Muraloka",
    "lat": "-8.77213",
    "lng": "116.87932"
  },
  {
    "country": "ID",
    "name": "Muntok",
    "lat": "-2.06719",
    "lng": "105.16228"
  },
  {
    "country": "ID",
    "name": "Muntilan",
    "lat": "-7.58111",
    "lng": "110.29278"
  },
  {
    "country": "ID",
    "name": "Munjungan",
    "lat": "-8.3031",
    "lng": "111.5786"
  },
  {
    "country": "ID",
    "name": "Munduk",
    "lat": "-8.26866",
    "lng": "115.07947"
  },
  {
    "country": "ID",
    "name": "Muncar",
    "lat": "-8.43333",
    "lng": "114.33333"
  },
  {
    "country": "ID",
    "name": "Muncang",
    "lat": "-6.5443",
    "lng": "106.2911"
  },
  {
    "country": "ID",
    "name": "Mulia",
    "lat": "-3.71472",
    "lng": "137.98528"
  },
  {
    "country": "ID",
    "name": "Mukomuko",
    "lat": "-2.5689",
    "lng": "101.1118"
  },
  {
    "country": "ID",
    "name": "Mujur",
    "lat": "-8.7617",
    "lng": "116.3548"
  },
  {
    "country": "ID",
    "name": "Muarauya",
    "lat": "-1.8875",
    "lng": "115.595"
  },
  {
    "country": "ID",
    "name": "Muara Teweh",
    "lat": "-0.94734",
    "lng": "114.8962"
  },
  {
    "country": "ID",
    "name": "Muara Tembesi",
    "lat": "-1.7109",
    "lng": "103.1182"
  },
  {
    "country": "ID",
    "name": "Muara Tebo",
    "lat": "-1.476",
    "lng": "102.4435"
  },
  {
    "country": "ID",
    "name": "Muarasiau",
    "lat": "-2.273",
    "lng": "102.0998"
  },
  {
    "country": "ID",
    "name": "Muara Sabak",
    "lat": "-1.13612",
    "lng": "103.84987"
  },
  {
    "country": "ID",
    "name": "Muararupit",
    "lat": "-2.7236",
    "lng": "102.9108"
  },
  {
    "country": "ID",
    "name": "Muarapinang",
    "lat": "-3.8503",
    "lng": "103.0533"
  },
  {
    "country": "ID",
    "name": "Muaralimun",
    "lat": "-2.3967",
    "lng": "102.6389"
  },
  {
    "country": "ID",
    "name": "Muaralembu",
    "lat": "-0.3808",
    "lng": "101.3395"
  },
  {
    "country": "ID",
    "name": "Muaralakitan",
    "lat": "-2.8594",
    "lng": "103.3039"
  },
  {
    "country": "ID",
    "name": "Muaralabuh",
    "lat": "-1.4621",
    "lng": "101.023"
  },
  {
    "country": "ID",
    "name": "Muarakuang",
    "lat": "-3.66648",
    "lng": "104.56717"
  },
  {
    "country": "ID",
    "name": "Muarakomam",
    "lat": "-1.6785",
    "lng": "115.8129"
  },
  {
    "country": "ID",
    "name": "Muara Enim",
    "lat": "-3.6486",
    "lng": "103.771"
  },
  {
    "country": "ID",
    "name": "Muara Dua",
    "lat": "-4.53178",
    "lng": "104.07397"
  },
  {
    "country": "ID",
    "name": "Muara Bungo",
    "lat": "-1.49018",
    "lng": "102.1149"
  },
  {
    "country": "ID",
    "name": "Muara Bulian",
    "lat": "-1.71327",
    "lng": "103.25902"
  },
  {
    "country": "ID",
    "name": "Muara Beliti",
    "lat": "-3.2486",
    "lng": "103.0335"
  },
  {
    "country": "ID",
    "name": "Muarabadak",
    "lat": "-0.35085",
    "lng": "117.43523"
  },
  {
    "country": "ID",
    "name": "Muaro",
    "lat": "-0.66387",
    "lng": "100.95818"
  },
  {
    "country": "ID",
    "name": "Mranggen",
    "lat": "-7.0268",
    "lng": "110.5158"
  },
  {
    "country": "ID",
    "name": "Moro",
    "lat": "0.75417",
    "lng": "103.70833"
  },
  {
    "country": "ID",
    "name": "Munse",
    "lat": "-4.0967",
    "lng": "123.2519"
  },
  {
    "country": "ID",
    "name": "Molobulahe",
    "lat": "0.6326",
    "lng": "122.5748"
  },
  {
    "country": "ID",
    "name": "Molibagu",
    "lat": "0.3862",
    "lng": "123.9824"
  },
  {
    "country": "ID",
    "name": "Mojosari",
    "lat": "-7.5194",
    "lng": "112.5597"
  },
  {
    "country": "ID",
    "name": "Mojokerto",
    "lat": "-7.4664",
    "lng": "112.4338"
  },
  {
    "country": "ID",
    "name": "Mojoagung",
    "lat": "-7.56667",
    "lng": "112.35"
  },
  {
    "country": "ID",
    "name": "Mlonggo",
    "lat": "-6.53333",
    "lng": "110.7"
  },
  {
    "country": "ID",
    "name": "Metro",
    "lat": "-5.11306",
    "lng": "105.30667"
  },
  {
    "country": "ID",
    "name": "Mertoyudan",
    "lat": "-7.52",
    "lng": "110.22639"
  },
  {
    "country": "ID",
    "name": "Mersam",
    "lat": "-1.69823",
    "lng": "102.9976"
  },
  {
    "country": "ID",
    "name": "Merakurak",
    "lat": "-6.8783",
    "lng": "111.9863"
  },
  {
    "country": "ID",
    "name": "Mensalong",
    "lat": "3.75883",
    "lng": "116.74532"
  },
  {
    "country": "ID",
    "name": "Menjalin",
    "lat": "0.46935",
    "lng": "109.33828"
  },
  {
    "country": "ID",
    "name": "Mengkalip",
    "lat": "-2.1488",
    "lng": "114.8819"
  },
  {
    "country": "ID",
    "name": "Menggala",
    "lat": "-4.47131",
    "lng": "105.25214"
  },
  {
    "country": "ID",
    "name": "Menes",
    "lat": "-6.37553",
    "lng": "105.91872"
  },
  {
    "country": "ID",
    "name": "Mempawah",
    "lat": "0.37102",
    "lng": "108.97013"
  },
  {
    "country": "ID",
    "name": "Meliau",
    "lat": "-0.12533",
    "lng": "110.28962"
  },
  {
    "country": "ID",
    "name": "Melati",
    "lat": "-7.73333",
    "lng": "110.36667"
  },
  {
    "country": "ID",
    "name": "Mega",
    "lat": "-0.66392",
    "lng": "131.90487"
  },
  {
    "country": "ID",
    "name": "Borong",
    "lat": "-8.8125",
    "lng": "120.60972"
  },
  {
    "country": "ID",
    "name": "Mayang",
    "lat": "-8.1762",
    "lng": "113.7958"
  },
  {
    "country": "ID",
    "name": "Mauponggo",
    "lat": "-8.8892",
    "lng": "121.2112"
  },
  {
    "country": "ID",
    "name": "Maumere",
    "lat": "-8.6199",
    "lng": "122.2111"
  },
  {
    "country": "ID",
    "name": "Matur",
    "lat": "-0.27877",
    "lng": "100.28802"
  },
  {
    "country": "ID",
    "name": "Mataram",
    "lat": "-8.58333",
    "lng": "116.11667"
  },
  {
    "country": "ID",
    "name": "Masmambang",
    "lat": "-4.16418",
    "lng": "102.70045"
  },
  {
    "country": "ID",
    "name": "Masbagik",
    "lat": "-8.622",
    "lng": "116.4773"
  },
  {
    "country": "ID",
    "name": "Masat",
    "lat": "-4.38057",
    "lng": "102.95437"
  },
  {
    "country": "ID",
    "name": "Masamba",
    "lat": "-2.5537",
    "lng": "120.3279"
  },
  {
    "country": "ID",
    "name": "Martapura",
    "lat": "-4.31885",
    "lng": "104.34715"
  },
  {
    "country": "ID",
    "name": "Martapura",
    "lat": "-3.4109",
    "lng": "114.8642"
  },
  {
    "country": "ID",
    "name": "Maros",
    "lat": "-5.006",
    "lng": "119.5727"
  },
  {
    "country": "ID",
    "name": "Buakayu",
    "lat": "-3.1995",
    "lng": "119.7232"
  },
  {
    "country": "ID",
    "name": "Marisa",
    "lat": "0.4655",
    "lng": "121.9386"
  },
  {
    "country": "ID",
    "name": "Maria",
    "lat": "-8.52388",
    "lng": "118.84294"
  },
  {
    "country": "ID",
    "name": "Margasari",
    "lat": "-7.1",
    "lng": "109.01667"
  },
  {
    "country": "ID",
    "name": "Margahayukencana",
    "lat": "-6.97083",
    "lng": "107.5675"
  },
  {
    "country": "ID",
    "name": "Marabahan",
    "lat": "-3.0136",
    "lng": "114.7687"
  },
  {
    "country": "ID",
    "name": "Manonjaya",
    "lat": "-7.3509",
    "lng": "108.3087"
  },
  {
    "country": "ID",
    "name": "Manokwari",
    "lat": "-0.86291",
    "lng": "134.06402"
  },
  {
    "country": "ID",
    "name": "Manna",
    "lat": "-4.4651",
    "lng": "102.90386"
  },
  {
    "country": "ID",
    "name": "Manismata",
    "lat": "-2.46667",
    "lng": "111.03333"
  },
  {
    "country": "ID",
    "name": "Maninjau",
    "lat": "-0.30059",
    "lng": "100.22671"
  },
  {
    "country": "ID",
    "name": "Mangkutana",
    "lat": "-2.4894",
    "lng": "120.812"
  },
  {
    "country": "ID",
    "name": "Manggar",
    "lat": "-2.88333",
    "lng": "108.26667"
  },
  {
    "country": "ID",
    "name": "Mangarang",
    "lat": "3.81284",
    "lng": "126.75135"
  },
  {
    "country": "ID",
    "name": "Mangaran",
    "lat": "-7.6668",
    "lng": "114.0406"
  },
  {
    "country": "ID",
    "name": "Manganitu",
    "lat": "3.57622",
    "lng": "125.51849"
  },
  {
    "country": "ID",
    "name": "Mandor",
    "lat": "0.32243",
    "lng": "109.33795"
  },
  {
    "country": "ID",
    "name": "Manding",
    "lat": "-6.953",
    "lng": "113.8717"
  },
  {
    "country": "ID",
    "name": "Mandalawangi",
    "lat": "-6.3102",
    "lng": "105.9886"
  },
  {
    "country": "ID",
    "name": "Mendaha",
    "lat": "-1.0163",
    "lng": "103.59331"
  },
  {
    "country": "ID",
    "name": "Khairiahmandah",
    "lat": "0.02107",
    "lng": "103.49757"
  },
  {
    "country": "ID",
    "name": "Manalu",
    "lat": "3.51225",
    "lng": "125.62302"
  },
  {
    "country": "ID",
    "name": "Manado",
    "lat": "1.48218",
    "lng": "124.84892"
  },
  {
    "country": "ID",
    "name": "Mamuju",
    "lat": "-2.68056",
    "lng": "118.88611"
  },
  {
    "country": "ID",
    "name": "Mambi",
    "lat": "-2.9505",
    "lng": "119.1747"
  },
  {
    "country": "ID",
    "name": "Mamasa",
    "lat": "-2.942",
    "lng": "119.3776"
  },
  {
    "country": "ID",
    "name": "Malinau",
    "lat": "3.58855",
    "lng": "116.62391"
  },
  {
    "country": "ID",
    "name": "Malili",
    "lat": "-2.6351",
    "lng": "121.0948"
  },
  {
    "country": "ID",
    "name": "Malangbong",
    "lat": "-7.0603",
    "lng": "108.0876"
  },
  {
    "country": "ID",
    "name": "Malang",
    "lat": "-7.9797",
    "lng": "112.6304"
  },
  {
    "country": "ID",
    "name": "Makbon",
    "lat": "-0.74753",
    "lng": "131.53875"
  },
  {
    "country": "ID",
    "name": "Makale",
    "lat": "-3.1019",
    "lng": "119.8539"
  },
  {
    "country": "ID",
    "name": "Majene",
    "lat": "-3.5403",
    "lng": "118.9707"
  },
  {
    "country": "ID",
    "name": "Majenang",
    "lat": "-7.2975",
    "lng": "108.7642"
  },
  {
    "country": "ID",
    "name": "Majalengka",
    "lat": "-6.83611",
    "lng": "108.22778"
  },
  {
    "country": "ID",
    "name": "Magetan",
    "lat": "-7.65667",
    "lng": "111.33139"
  },
  {
    "country": "ID",
    "name": "Magelang",
    "lat": "-7.47056",
    "lng": "110.21778"
  },
  {
    "country": "ID",
    "name": "Mafa",
    "lat": "0.04705",
    "lng": "127.89037"
  },
  {
    "country": "ID",
    "name": "Maesan",
    "lat": "-8.0233",
    "lng": "113.7779"
  },
  {
    "country": "ID",
    "name": "Madiun",
    "lat": "-7.6298",
    "lng": "111.5239"
  },
  {
    "country": "ID",
    "name": "Maba",
    "lat": "0.7007",
    "lng": "128.29197"
  },
  {
    "country": "ID",
    "name": "Luwuk",
    "lat": "-0.9516",
    "lng": "122.7875"
  },
  {
    "country": "ID",
    "name": "Luragung",
    "lat": "-7.0172",
    "lng": "108.6381"
  },
  {
    "country": "ID",
    "name": "Lumajang",
    "lat": "-8.1335",
    "lng": "113.2248"
  },
  {
    "country": "ID",
    "name": "Lubuk Sikaping",
    "lat": "0.14411",
    "lng": "100.1657"
  },
  {
    "country": "ID",
    "name": "Lubuklinggau",
    "lat": "-3.2945",
    "lng": "102.8614"
  },
  {
    "country": "ID",
    "name": "Lubukjambi",
    "lat": "-0.6517",
    "lng": "101.4681"
  },
  {
    "country": "ID",
    "name": "Lubukgadang",
    "lat": "-1.5251",
    "lng": "101.2734"
  },
  {
    "country": "ID",
    "name": "Lubuk Basung",
    "lat": "-0.32545",
    "lng": "100.06462"
  },
  {
    "country": "ID",
    "name": "Lubukbergalung",
    "lat": "-0.96076",
    "lng": "100.40011"
  },
  {
    "country": "ID",
    "name": "Lubukalung",
    "lat": "-0.68321",
    "lng": "100.31856"
  },
  {
    "country": "ID",
    "name": "Long Pujungan",
    "lat": "2.58769",
    "lng": "115.79478"
  },
  {
    "country": "ID",
    "name": "Longnawang",
    "lat": "1.78931",
    "lng": "114.9013"
  },
  {
    "country": "ID",
    "name": "Longkali",
    "lat": "-1.5218",
    "lng": "116.3205"
  },
  {
    "country": "ID",
    "name": "Longikis",
    "lat": "-1.5834",
    "lng": "116.2061"
  },
  {
    "country": "ID",
    "name": "Labuan Lombok",
    "lat": "-8.5",
    "lng": "116.66667"
  },
  {
    "country": "ID",
    "name": "Lolak",
    "lat": "0.8755",
    "lng": "124.0098"
  },
  {
    "country": "ID",
    "name": "Lodoyo",
    "lat": "-8.1613",
    "lng": "112.2173"
  },
  {
    "country": "ID",
    "name": "Loakulu",
    "lat": "-0.51489",
    "lng": "117.01567"
  },
  {
    "country": "ID",
    "name": "Loa Janan",
    "lat": "-0.58295",
    "lng": "117.09503"
  },
  {
    "country": "ID",
    "name": "Liwa",
    "lat": "-5.03554",
    "lng": "104.07595"
  },
  {
    "country": "ID",
    "name": "Lirung",
    "lat": "3.94481",
    "lng": "126.67265"
  },
  {
    "country": "ID",
    "name": "Limboto",
    "lat": "0.627",
    "lng": "122.9778"
  },
  {
    "country": "ID",
    "name": "Likupang",
    "lat": "1.6722",
    "lng": "125.06104"
  },
  {
    "country": "ID",
    "name": "Lewoleba",
    "lat": "-8.3723",
    "lng": "123.418"
  },
  {
    "country": "ID",
    "name": "Lewolaga",
    "lat": "-8.4196",
    "lng": "122.8094"
  },
  {
    "country": "ID",
    "name": "Leuwidamar",
    "lat": "-6.5125",
    "lng": "106.1934"
  },
  {
    "country": "ID",
    "name": "Letung",
    "lat": "2.98861",
    "lng": "105.70694"
  },
  {
    "country": "ID",
    "name": "Lengkong",
    "lat": "-7.1315",
    "lng": "106.6926"
  },
  {
    "country": "ID",
    "name": "Lenangguar",
    "lat": "-8.7356",
    "lng": "117.3653"
  },
  {
    "country": "ID",
    "name": "Lemito",
    "lat": "0.5424",
    "lng": "121.5713"
  },
  {
    "country": "ID",
    "name": "Lembar",
    "lat": "-8.7264",
    "lng": "116.0744"
  },
  {
    "country": "ID",
    "name": "Lembang",
    "lat": "-6.81167",
    "lng": "107.6175"
  },
  {
    "country": "ID",
    "name": "Lemahputih",
    "lat": "-7.0099",
    "lng": "108.1698"
  },
  {
    "country": "ID",
    "name": "Lelogama",
    "lat": "-9.7114",
    "lng": "123.954"
  },
  {
    "country": "ID",
    "name": "Leles",
    "lat": "-7.1099",
    "lng": "107.8986"
  },
  {
    "country": "ID",
    "name": "Lela",
    "lat": "-8.7289",
    "lng": "122.1726"
  },
  {
    "country": "ID",
    "name": "Leksula",
    "lat": "-3.7731",
    "lng": "126.538"
  },
  {
    "country": "ID",
    "name": "Lekebai",
    "lat": "-8.712",
    "lng": "122.0762"
  },
  {
    "country": "ID",
    "name": "Ledokombo",
    "lat": "-8.1346",
    "lng": "113.8752"
  },
  {
    "country": "ID",
    "name": "Lebakwangi",
    "lat": "-7.0173",
    "lng": "108.6016"
  },
  {
    "country": "ID",
    "name": "Lebaksiu",
    "lat": "-7.0496",
    "lng": "109.1441"
  },
  {
    "country": "ID",
    "name": "Lawang",
    "lat": "-7.8353",
    "lng": "112.6947"
  },
  {
    "country": "ID",
    "name": "Lasem",
    "lat": "-6.6922",
    "lng": "111.4527"
  },
  {
    "country": "ID",
    "name": "Lasehao",
    "lat": "-5.0068",
    "lng": "122.4943"
  },
  {
    "country": "ID",
    "name": "Larompong",
    "lat": "-3.515",
    "lng": "120.3704"
  },
  {
    "country": "ID",
    "name": "Larantuka",
    "lat": "-8.3468",
    "lng": "122.9771"
  },
  {
    "country": "ID",
    "name": "Lampihung",
    "lat": "-2.3809",
    "lng": "115.5277"
  },
  {
    "country": "ID",
    "name": "Langgur",
    "lat": "-5.66689",
    "lng": "132.73762"
  },
  {
    "country": "ID",
    "name": "Langnga",
    "lat": "-3.8459",
    "lng": "119.5222"
  },
  {
    "country": "ID",
    "name": "Langara",
    "lat": "-4.0248",
    "lng": "122.9906"
  },
  {
    "country": "ID",
    "name": "Lamongan",
    "lat": "-7.11667",
    "lng": "112.41667"
  },
  {
    "country": "ID",
    "name": "Laiwui",
    "lat": "-1.35177",
    "lng": "127.66929"
  },
  {
    "country": "ID",
    "name": "Lais",
    "lat": "-3.5294",
    "lng": "102.0497"
  },
  {
    "country": "ID",
    "name": "Laikit, Laikit II (Dimembe)",
    "lat": "1.48833",
    "lng": "124.97444"
  },
  {
    "country": "ID",
    "name": "Lahat",
    "lat": "-3.78514",
    "lng": "103.54279"
  },
  {
    "country": "ID",
    "name": "Labuhanmaringgai",
    "lat": "-5.35074",
    "lng": "105.80993"
  },
  {
    "country": "ID",
    "name": "Labuan Bajo",
    "lat": "-8.4964",
    "lng": "119.8877"
  },
  {
    "country": "ID",
    "name": "Labuan",
    "lat": "-6.3784",
    "lng": "105.83"
  },
  {
    "country": "ID",
    "name": "Labuha",
    "lat": "-0.62546",
    "lng": "127.47808"
  },
  {
    "country": "ID",
    "name": "Kwantisore",
    "lat": "-3.2651",
    "lng": "134.9065"
  },
  {
    "country": "ID",
    "name": "Kutoarjo",
    "lat": "-7.71694",
    "lng": "109.91278"
  },
  {
    "country": "ID",
    "name": "Kuta",
    "lat": "-8.72332",
    "lng": "115.17234"
  },
  {
    "country": "ID",
    "name": "Pangkalan Kerinci",
    "lat": "0.39611",
    "lng": "101.85722"
  },
  {
    "country": "ID",
    "name": "Kuningan",
    "lat": "-6.97583",
    "lng": "108.48306"
  },
  {
    "country": "ID",
    "name": "Kumurkek",
    "lat": "-1.25667",
    "lng": "132.49972"
  },
  {
    "country": "ID",
    "name": "Kumai",
    "lat": "-2.7398",
    "lng": "111.72558"
  },
  {
    "country": "ID",
    "name": "Kuma",
    "lat": "3.57467",
    "lng": "125.57746"
  },
  {
    "country": "ID",
    "name": "Kudus",
    "lat": "-6.8048",
    "lng": "110.8405"
  },
  {
    "country": "ID",
    "name": "Kubu",
    "lat": "-8.2524",
    "lng": "115.5666"
  },
  {
    "country": "ID",
    "name": "Kubu",
    "lat": "-0.48576",
    "lng": "109.35513"
  },
  {
    "country": "ID",
    "name": "Kwandang",
    "lat": "0.8348",
    "lng": "122.915"
  },
  {
    "country": "ID",
    "name": "Kuala Tungkal",
    "lat": "-0.81623",
    "lng": "103.46111"
  },
  {
    "country": "ID",
    "name": "Kualakapuas",
    "lat": "-3.00913",
    "lng": "114.38759"
  },
  {
    "country": "ID",
    "name": "Krui",
    "lat": "-5.18251",
    "lng": "103.93746"
  },
  {
    "country": "ID",
    "name": "Kroya",
    "lat": "-7.63306",
    "lng": "109.24611"
  },
  {
    "country": "ID",
    "name": "Krian",
    "lat": "-7.4104",
    "lng": "112.5792"
  },
  {
    "country": "ID",
    "name": "Kresek",
    "lat": "-6.13139",
    "lng": "106.37972"
  },
  {
    "country": "ID",
    "name": "Kraksaan",
    "lat": "-7.75845",
    "lng": "113.39624"
  },
  {
    "country": "ID",
    "name": "Kragan",
    "lat": "-6.6897",
    "lng": "111.6125"
  },
  {
    "country": "ID",
    "name": "Kotawaringin",
    "lat": "-2.4729",
    "lng": "111.4731"
  },
  {
    "country": "ID",
    "name": "Kotatengah",
    "lat": "1.08738",
    "lng": "100.55458"
  },
  {
    "country": "ID",
    "name": "Kota Pinang",
    "lat": "1.89076",
    "lng": "100.09211"
  },
  {
    "country": "ID",
    "name": "Daik Lingga",
    "lat": "-0.21451",
    "lng": "104.61824"
  },
  {
    "country": "ID",
    "name": "Kotabunan",
    "lat": "0.81217",
    "lng": "124.65546"
  },
  {
    "country": "ID",
    "name": "Kotabumi",
    "lat": "-4.82505",
    "lng": "104.8817"
  },
  {
    "country": "ID",
    "name": "Kotabesi",
    "lat": "-2.3715",
    "lng": "113.0025"
  },
  {
    "country": "ID",
    "name": "Kotabaru Hilir",
    "lat": "-3.24267",
    "lng": "116.22514"
  },
  {
    "country": "ID",
    "name": "Kotabaru",
    "lat": "-1.10155",
    "lng": "101.76031"
  },
  {
    "country": "ID",
    "name": "Kotaagung",
    "lat": "-5.49415",
    "lng": "104.62201"
  },
  {
    "country": "ID",
    "name": "Kotaagung",
    "lat": "-4.06853",
    "lng": "103.43164"
  },
  {
    "country": "ID",
    "name": "Korem",
    "lat": "-0.90004",
    "lng": "136.04082"
  },
  {
    "country": "ID",
    "name": "Korido",
    "lat": "-0.8747",
    "lng": "135.6344"
  },
  {
    "country": "ID",
    "name": "Kopang Satu",
    "lat": "-8.6335",
    "lng": "116.3517"
  },
  {
    "country": "ID",
    "name": "Komodo",
    "lat": "-8.5895",
    "lng": "119.4913"
  },
  {
    "country": "ID",
    "name": "Kolonodale",
    "lat": "-1.9825",
    "lng": "121.3364"
  },
  {
    "country": "ID",
    "name": "Kokas",
    "lat": "-2.70306",
    "lng": "132.43806"
  },
  {
    "country": "ID",
    "name": "Kokar",
    "lat": "-8.1629",
    "lng": "124.4473"
  },
  {
    "country": "ID",
    "name": "Koba",
    "lat": "-2.49313",
    "lng": "106.4081"
  },
  {
    "country": "ID",
    "name": "Klungkung",
    "lat": "-8.53333",
    "lng": "115.4"
  },
  {
    "country": "ID",
    "name": "Kelua",
    "lat": "-2.2048",
    "lng": "115.3993"
  },
  {
    "country": "ID",
    "name": "Klaten",
    "lat": "-7.70583",
    "lng": "110.60639"
  },
  {
    "country": "ID",
    "name": "Klangenan",
    "lat": "-6.70944",
    "lng": "108.44"
  },
  {
    "country": "ID",
    "name": "Klampis",
    "lat": "-6.8938",
    "lng": "112.9041"
  },
  {
    "country": "ID",
    "name": "Kiruru",
    "lat": "-3.9389",
    "lng": "134.9696"
  },
  {
    "country": "ID",
    "name": "Kimaam",
    "lat": "-7.98507",
    "lng": "138.84689"
  },
  {
    "country": "ID",
    "name": "Kijang",
    "lat": "0.9",
    "lng": "104.63333"
  },
  {
    "country": "ID",
    "name": "Ketahun",
    "lat": "-3.3897",
    "lng": "101.8352"
  },
  {
    "country": "ID",
    "name": "Ketapang",
    "lat": "-6.8958",
    "lng": "113.2806"
  },
  {
    "country": "ID",
    "name": "Ketapang",
    "lat": "-1.83862",
    "lng": "109.97728"
  },
  {
    "country": "ID",
    "name": "Ketanggungan",
    "lat": "-6.9383",
    "lng": "108.891"
  },
  {
    "country": "ID",
    "name": "Kesugihan",
    "lat": "-7.6175",
    "lng": "109.12139"
  },
  {
    "country": "ID",
    "name": "Kesamben",
    "lat": "-8.1462",
    "lng": "112.3658"
  },
  {
    "country": "ID",
    "name": "Kertosono",
    "lat": "-7.58333",
    "lng": "112.1"
  },
  {
    "country": "ID",
    "name": "Kerek",
    "lat": "-6.8951",
    "lng": "111.8866"
  },
  {
    "country": "ID",
    "name": "Kerang",
    "lat": "-2.2333",
    "lng": "116.0718"
  },
  {
    "country": "ID",
    "name": "Kepoh",
    "lat": "-2.94454",
    "lng": "106.55743"
  },
  {
    "country": "ID",
    "name": "Kepi",
    "lat": "-6.52461",
    "lng": "139.32224"
  },
  {
    "country": "ID",
    "name": "Kepanjen",
    "lat": "-8.1303",
    "lng": "112.5727"
  },
  {
    "country": "ID",
    "name": "Kendari",
    "lat": "-3.9778",
    "lng": "122.51507"
  },
  {
    "country": "ID",
    "name": "Kendal",
    "lat": "-6.9213",
    "lng": "110.2022"
  },
  {
    "country": "ID",
    "name": "Kencong",
    "lat": "-8.28333",
    "lng": "113.36667"
  },
  {
    "country": "ID",
    "name": "Kenali",
    "lat": "-4.99157",
    "lng": "104.1929"
  },
  {
    "country": "ID",
    "name": "Kema",
    "lat": "1.36574",
    "lng": "125.07484"
  },
  {
    "country": "ID",
    "name": "Kelapa",
    "lat": "-1.87757",
    "lng": "105.67661"
  },
  {
    "country": "ID",
    "name": "Kefamenanu",
    "lat": "-9.44667",
    "lng": "124.47806"
  },
  {
    "country": "ID",
    "name": "Kedungwuni",
    "lat": "-6.97038",
    "lng": "109.64794"
  },
  {
    "country": "ID",
    "name": "Kedungwaru",
    "lat": "-8.06667",
    "lng": "111.91667"
  },
  {
    "country": "ID",
    "name": "Kediri",
    "lat": "-8.6343",
    "lng": "116.1515"
  },
  {
    "country": "ID",
    "name": "Kediri",
    "lat": "-7.81667",
    "lng": "112.01667"
  },
  {
    "country": "ID",
    "name": "Kedaton",
    "lat": "-5.38354",
    "lng": "105.2596"
  },
  {
    "country": "ID",
    "name": "Kebumen",
    "lat": "-7.66861",
    "lng": "109.65361"
  },
  {
    "country": "ID",
    "name": "Kebonarun",
    "lat": "-7.70028",
    "lng": "110.56306"
  },
  {
    "country": "ID",
    "name": "Kebomas",
    "lat": "-7.16667",
    "lng": "112.6333"
  },
  {
    "country": "ID",
    "name": "Padangtepung",
    "lat": "-3.7538",
    "lng": "102.7945"
  },
  {
    "country": "ID",
    "name": "Kayu Agung",
    "lat": "-3.392",
    "lng": "104.8306"
  },
  {
    "country": "ID",
    "name": "Kawangu",
    "lat": "-9.6728",
    "lng": "120.3409"
  },
  {
    "country": "ID",
    "name": "Kawangkoan",
    "lat": "1.20525",
    "lng": "124.78218"
  },
  {
    "country": "ID",
    "name": "Kawalu",
    "lat": "-7.3817",
    "lng": "108.2082"
  },
  {
    "country": "ID",
    "name": "Kawali",
    "lat": "-7.1854",
    "lng": "108.3704"
  },
  {
    "country": "ID",
    "name": "Katabu",
    "lat": "-4.9333",
    "lng": "122.5167"
  },
  {
    "country": "ID",
    "name": "Kasui",
    "lat": "-4.71572",
    "lng": "104.4498"
  },
  {
    "country": "ID",
    "name": "Kasonawejo",
    "lat": "-2.2818",
    "lng": "138.0348"
  },
  {
    "country": "ID",
    "name": "Kasiguncu",
    "lat": "-1.42114",
    "lng": "120.6554"
  },
  {
    "country": "ID",
    "name": "Kasarangan",
    "lat": "-2.62636",
    "lng": "115.29739"
  },
  {
    "country": "ID",
    "name": "Karawang",
    "lat": "-6.30333",
    "lng": "107.30556"
  },
  {
    "country": "ID",
    "name": "Karangsembung",
    "lat": "-6.8487",
    "lng": "108.6422"
  },
  {
    "country": "ID",
    "name": "Karangrejo",
    "lat": "-8.003",
    "lng": "111.9092"
  },
  {
    "country": "ID",
    "name": "Karangpawitan",
    "lat": "-7.2061",
    "lng": "107.9456"
  },
  {
    "country": "ID",
    "name": "Karangnunggal",
    "lat": "-7.6278",
    "lng": "108.1341"
  },
  {
    "country": "ID",
    "name": "Karangintan",
    "lat": "-3.4116",
    "lng": "115.0134"
  },
  {
    "country": "ID",
    "name": "Karanggeneng",
    "lat": "-6.9897",
    "lng": "112.3738"
  },
  {
    "country": "ID",
    "name": "Amlapura",
    "lat": "-8.45",
    "lng": "115.61667"
  },
  {
    "country": "ID",
    "name": "Karangarjo",
    "lat": "-8.3125",
    "lng": "114.0483"
  },
  {
    "country": "ID",
    "name": "Karanganyar",
    "lat": "-7.59833",
    "lng": "110.94444"
  },
  {
    "country": "ID",
    "name": "Karanganom",
    "lat": "-7.64889",
    "lng": "110.625"
  },
  {
    "country": "ID",
    "name": "Karangan",
    "lat": "-8.0876",
    "lng": "111.6592"
  },
  {
    "country": "ID",
    "name": "Karangan",
    "lat": "0.55986",
    "lng": "109.37566"
  },
  {
    "country": "ID",
    "name": "Karangampel",
    "lat": "-6.46222",
    "lng": "108.45194"
  },
  {
    "country": "ID",
    "name": "Kapongan",
    "lat": "-7.6907",
    "lng": "114.0619"
  },
  {
    "country": "ID",
    "name": "Kapan",
    "lat": "-9.7348",
    "lng": "124.2739"
  },
  {
    "country": "ID",
    "name": "Kepahiang",
    "lat": "-3.6455",
    "lng": "102.5712"
  },
  {
    "country": "ID",
    "name": "Kandangan",
    "lat": "-2.7837",
    "lng": "115.2772"
  },
  {
    "country": "ID",
    "name": "Malaju",
    "lat": "-8.3104",
    "lng": "118.394"
  },
  {
    "country": "ID",
    "name": "Kelarik",
    "lat": "4.00833",
    "lng": "107.99861"
  },
  {
    "country": "ID",
    "name": "Hampang",
    "lat": "-2.918",
    "lng": "115.8373"
  },
  {
    "country": "ID",
    "name": "Kampak",
    "lat": "-8.1748",
    "lng": "111.6613"
  },
  {
    "country": "ID",
    "name": "Kameri",
    "lat": "-0.9821",
    "lng": "134.8046"
  },
  {
    "country": "ID",
    "name": "Kambang",
    "lat": "-1.6904",
    "lng": "100.7209"
  },
  {
    "country": "ID",
    "name": "Kamal",
    "lat": "-7.16778",
    "lng": "112.71917"
  },
  {
    "country": "ID",
    "name": "Cibaregbeg",
    "lat": "-7.67916",
    "lng": "107.80295"
  },
  {
    "country": "ID",
    "name": "Kalipucang",
    "lat": "-7.6433",
    "lng": "108.7526"
  },
  {
    "country": "ID",
    "name": "Kalipang",
    "lat": "-6.7241",
    "lng": "111.6536"
  },
  {
    "country": "ID",
    "name": "Kaliori",
    "lat": "-6.7019",
    "lng": "111.2475"
  },
  {
    "country": "ID",
    "name": "Kalidawir",
    "lat": "-8.1808",
    "lng": "111.9723"
  },
  {
    "country": "ID",
    "name": "Kalibunder",
    "lat": "-7.2627",
    "lng": "106.7222"
  },
  {
    "country": "ID",
    "name": "Kalianget",
    "lat": "-7.0537",
    "lng": "113.94244"
  },
  {
    "country": "ID",
    "name": "Kalianda",
    "lat": "-5.73805",
    "lng": "105.5916"
  },
  {
    "country": "ID",
    "name": "Kalangbret",
    "lat": "-8.0527",
    "lng": "111.8653"
  },
  {
    "country": "ID",
    "name": "Kalabahi",
    "lat": "-8.2151",
    "lng": "124.5458"
  },
  {
    "country": "ID",
    "name": "Kajen",
    "lat": "-7.0324",
    "lng": "109.5773"
  },
  {
    "country": "ID",
    "name": "Kairatu",
    "lat": "-3.35167",
    "lng": "128.36853"
  },
  {
    "country": "ID",
    "name": "Kaimana",
    "lat": "-3.6635",
    "lng": "133.7649"
  },
  {
    "country": "ID",
    "name": "Kadupandak",
    "lat": "-7.2611",
    "lng": "107.0472"
  },
  {
    "country": "ID",
    "name": "Kadugedong",
    "lat": "-6.3639",
    "lng": "106.1"
  },
  {
    "country": "ID",
    "name": "Kadugede",
    "lat": "-7.0043",
    "lng": "108.4543"
  },
  {
    "country": "ID",
    "name": "Kabir",
    "lat": "-8.2545",
    "lng": "124.2145"
  },
  {
    "country": "ID",
    "name": "Kabare",
    "lat": "-0.0149",
    "lng": "130.8322"
  },
  {
    "country": "ID",
    "name": "Juwana",
    "lat": "-6.715",
    "lng": "111.1514"
  },
  {
    "country": "ID",
    "name": "Dungkek",
    "lat": "-6.9779",
    "lng": "114.0948"
  },
  {
    "country": "ID",
    "name": "Jorong",
    "lat": "-3.986",
    "lng": "114.9518"
  },
  {
    "country": "ID",
    "name": "Jombang",
    "lat": "-7.54595",
    "lng": "112.23307"
  },
  {
    "country": "ID",
    "name": "Jojogan",
    "lat": "-6.9709",
    "lng": "111.7881"
  },
  {
    "country": "ID",
    "name": "Jogonalan",
    "lat": "-7.70361",
    "lng": "110.53611"
  },
  {
    "country": "ID",
    "name": "Jimbaran",
    "lat": "-8.79093",
    "lng": "115.16006"
  },
  {
    "country": "ID",
    "name": "Jepon",
    "lat": "-6.9726",
    "lng": "111.4795"
  },
  {
    "country": "ID",
    "name": "Jepara",
    "lat": "-6.5924",
    "lng": "110.671"
  },
  {
    "country": "ID",
    "name": "Jepara",
    "lat": "-5.16948",
    "lng": "105.70441"
  },
  {
    "country": "ID",
    "name": "Jenggawah",
    "lat": "-8.2661",
    "lng": "113.6479"
  },
  {
    "country": "ID",
    "name": "Jeneponto",
    "lat": "-5.6765",
    "lng": "119.7484"
  },
  {
    "country": "ID",
    "name": "Jember",
    "lat": "-8.17211",
    "lng": "113.69953"
  },
  {
    "country": "ID",
    "name": "Jelbuk",
    "lat": "-8.0839",
    "lng": "113.7592"
  },
  {
    "country": "ID",
    "name": "Jekulo",
    "lat": "-6.8057",
    "lng": "110.9262"
  },
  {
    "country": "ID",
    "name": "Jebus",
    "lat": "-1.74302",
    "lng": "105.45527"
  },
  {
    "country": "ID",
    "name": "Jatiwangi",
    "lat": "-6.73361",
    "lng": "108.26278"
  },
  {
    "country": "ID",
    "name": "Jatiroto",
    "lat": "-8.1218",
    "lng": "113.3637"
  },
  {
    "country": "ID",
    "name": "Jatiroto",
    "lat": "-7.88333",
    "lng": "111.11667"
  },
  {
    "country": "ID",
    "name": "Jatirogo",
    "lat": "-6.8858",
    "lng": "111.6592"
  },
  {
    "country": "ID",
    "name": "Jatinagara",
    "lat": "-7.1735",
    "lng": "108.4028"
  },
  {
    "country": "ID",
    "name": "Jatibarang",
    "lat": "-6.47472",
    "lng": "108.31528"
  },
  {
    "country": "ID",
    "name": "Jaten",
    "lat": "-7.57722",
    "lng": "110.8975"
  },
  {
    "country": "ID",
    "name": "Japah",
    "lat": "-6.9423",
    "lng": "111.2903"
  },
  {
    "country": "ID",
    "name": "Jangkat",
    "lat": "-2.5072",
    "lng": "102.054"
  },
  {
    "country": "ID",
    "name": "Jampang Tengah",
    "lat": "-7.0568",
    "lng": "106.8014"
  },
  {
    "country": "ID",
    "name": "Jampang Kulon",
    "lat": "-7.2579",
    "lng": "106.6256"
  },
  {
    "country": "ID",
    "name": "Jambula",
    "lat": "0.75776",
    "lng": "127.31828"
  },
  {
    "country": "ID",
    "name": "Jambi City",
    "lat": "-1.6",
    "lng": "103.61667"
  },
  {
    "country": "ID",
    "name": "Jalang",
    "lat": "-4.0383",
    "lng": "120.3216"
  },
  {
    "country": "ID",
    "name": "Jakenan",
    "lat": "-6.762",
    "lng": "111.1643"
  },
  {
    "country": "ID",
    "name": "Jakarta",
    "lat": "-6.21462",
    "lng": "106.84513"
  },
  {
    "country": "ID",
    "name": "Jailolo",
    "lat": "1.06504",
    "lng": "127.46786"
  },
  {
    "country": "ID",
    "name": "Jabung",
    "lat": "-5.46314",
    "lng": "105.66752"
  },
  {
    "country": "ID",
    "name": "Isimu",
    "lat": "0.6446",
    "lng": "122.8614"
  },
  {
    "country": "ID",
    "name": "Ipuh",
    "lat": "-3.0067",
    "lng": "101.4836"
  },
  {
    "country": "ID",
    "name": "Indramayu",
    "lat": "-6.32639",
    "lng": "108.32"
  },
  {
    "country": "ID",
    "name": "Indralaya",
    "lat": "-3.25249",
    "lng": "104.67555"
  },
  {
    "country": "ID",
    "name": "Inanwatan",
    "lat": "-2.12705",
    "lng": "132.16527"
  },
  {
    "country": "ID",
    "name": "Alung",
    "lat": "-2.5161",
    "lng": "115.4275"
  },
  {
    "country": "ID",
    "name": "Hila",
    "lat": "-3.58689",
    "lng": "128.08798"
  },
  {
    "country": "ID",
    "name": "Gajrug",
    "lat": "-6.5271",
    "lng": "106.3798"
  },
  {
    "country": "ID",
    "name": "Haruyan",
    "lat": "-2.69169",
    "lng": "115.34992"
  },
  {
    "country": "ID",
    "name": "Haruai",
    "lat": "-2.0154",
    "lng": "115.5072"
  },
  {
    "country": "ID",
    "name": "Hadakewa",
    "lat": "-8.3698",
    "lng": "123.5473"
  },
  {
    "country": "ID",
    "name": "Gunungwungkal",
    "lat": "-6.5662",
    "lng": "110.9891"
  },
  {
    "country": "ID",
    "name": "Gunung Sugih",
    "lat": "-4.9753",
    "lng": "105.21396"
  },
  {
    "country": "ID",
    "name": "Gunungmenang",
    "lat": "-3.1799",
    "lng": "104.03347"
  },
  {
    "country": "ID",
    "name": "Gunungmegang Dalam",
    "lat": "-3.44968",
    "lng": "103.8699"
  },
  {
    "country": "ID",
    "name": "Gunungkencana",
    "lat": "-6.5721",
    "lng": "106.0742"
  },
  {
    "country": "ID",
    "name": "Gunungbatubesar",
    "lat": "-2.6211",
    "lng": "116.2931"
  },
  {
    "country": "ID",
    "name": "Gunem",
    "lat": "-6.807",
    "lng": "111.4656"
  },
  {
    "country": "ID",
    "name": "Gulukguluk",
    "lat": "-7.0546",
    "lng": "113.6754"
  },
  {
    "country": "ID",
    "name": "Grogol",
    "lat": "-7.60111",
    "lng": "110.81861"
  },
  {
    "country": "ID",
    "name": "Gresik",
    "lat": "-7.15389",
    "lng": "112.65611"
  },
  {
    "country": "ID",
    "name": "Gorontalo",
    "lat": "0.5375",
    "lng": "123.0625"
  },
  {
    "country": "ID",
    "name": "Gongdanglegi Kulon",
    "lat": "-8.17529",
    "lng": "112.63594"
  },
  {
    "country": "ID",
    "name": "Gondang",
    "lat": "-8.0734",
    "lng": "111.8472"
  },
  {
    "country": "ID",
    "name": "Gombong",
    "lat": "-7.60722",
    "lng": "109.51417"
  },
  {
    "country": "ID",
    "name": "Godo",
    "lat": "-8.56114",
    "lng": "118.66647"
  },
  {
    "country": "ID",
    "name": "Godean",
    "lat": "-7.76972",
    "lng": "110.29389"
  },
  {
    "country": "ID",
    "name": "Gianyar",
    "lat": "-8.5435",
    "lng": "115.3272"
  },
  {
    "country": "ID",
    "name": "Geser",
    "lat": "-3.8732",
    "lng": "130.9254"
  },
  {
    "country": "ID",
    "name": "Gerung",
    "lat": "-8.683",
    "lng": "116.1253"
  },
  {
    "country": "ID",
    "name": "Genteng",
    "lat": "-8.36667",
    "lng": "114.15"
  },
  {
    "country": "ID",
    "name": "Glumbang",
    "lat": "-3.23949",
    "lng": "104.43725"
  },
  {
    "country": "ID",
    "name": "Gedong Tataan",
    "lat": "-5.3827",
    "lng": "105.0955"
  },
  {
    "country": "ID",
    "name": "Gedangan",
    "lat": "-7.39083",
    "lng": "112.72667"
  },
  {
    "country": "ID",
    "name": "Gebog",
    "lat": "-6.735",
    "lng": "110.8444"
  },
  {
    "country": "ID",
    "name": "Gayam",
    "lat": "-7.1636",
    "lng": "114.331"
  },
  {
    "country": "ID",
    "name": "Garut",
    "lat": "-7.2024",
    "lng": "107.8878"
  },
  {
    "country": "ID",
    "name": "Garawangi",
    "lat": "-6.9987",
    "lng": "108.5389"
  },
  {
    "country": "ID",
    "name": "Gapura",
    "lat": "-6.99667",
    "lng": "113.95575"
  },
  {
    "country": "ID",
    "name": "Gandusari",
    "lat": "-8.1296",
    "lng": "111.7044"
  },
  {
    "country": "ID",
    "name": "Gandusari",
    "lat": "-8.0457",
    "lng": "112.303"
  },
  {
    "country": "ID",
    "name": "Gandrungmangu",
    "lat": "-7.52036",
    "lng": "108.85351"
  },
  {
    "country": "ID",
    "name": "Ganding",
    "lat": "-7.0387",
    "lng": "113.6887"
  },
  {
    "country": "ID",
    "name": "Gampengrejo",
    "lat": "-7.76667",
    "lng": "112.01667"
  },
  {
    "country": "ID",
    "name": "Gampang",
    "lat": "-6.956",
    "lng": "112.2986"
  },
  {
    "country": "ID",
    "name": "Gambiran Satu",
    "lat": "-8.3939",
    "lng": "114.1464"
  },
  {
    "country": "ID",
    "name": "Galunggalung",
    "lat": "-3.489",
    "lng": "118.896"
  },
  {
    "country": "ID",
    "name": "Kalumpang",
    "lat": "-2.4781",
    "lng": "119.4859"
  },
  {
    "country": "ID",
    "name": "Galis",
    "lat": "-7.15624",
    "lng": "113.55373"
  },
  {
    "country": "ID",
    "name": "Galesong",
    "lat": "-5.3166",
    "lng": "119.3661"
  },
  {
    "country": "ID",
    "name": "Fakfak",
    "lat": "-2.92481",
    "lng": "132.29813"
  },
  {
    "country": "ID",
    "name": "Essang",
    "lat": "4.45501",
    "lng": "126.73859"
  },
  {
    "country": "ID",
    "name": "Enrekang",
    "lat": "-3.56508",
    "lng": "119.77025"
  },
  {
    "country": "ID",
    "name": "Enok",
    "lat": "-0.5149",
    "lng": "103.1985"
  },
  {
    "country": "ID",
    "name": "Enemawira",
    "lat": "3.6565",
    "lng": "125.5612"
  },
  {
    "country": "ID",
    "name": "Ende",
    "lat": "-8.8432",
    "lng": "121.6623"
  },
  {
    "country": "ID",
    "name": "Enarotali",
    "lat": "-3.93032",
    "lng": "136.37651"
  },
  {
    "country": "ID",
    "name": "Elopada",
    "lat": "-9.5686",
    "lng": "119.3172"
  },
  {
    "country": "ID",
    "name": "Duri",
    "lat": "1.27607",
    "lng": "101.19457"
  },
  {
    "country": "ID",
    "name": "Durenan",
    "lat": "-8.1203",
    "lng": "111.7986"
  },
  {
    "country": "ID",
    "name": "Dumoga",
    "lat": "0.6096",
    "lng": "124.0826"
  },
  {
    "country": "ID",
    "name": "Dumai",
    "lat": "1.66711",
    "lng": "101.44316"
  },
  {
    "country": "ID",
    "name": "Dukuhturi",
    "lat": "-6.9",
    "lng": "109.08333"
  },
  {
    "country": "ID",
    "name": "Dukuhseti",
    "lat": "-6.4705",
    "lng": "111.0358"
  },
  {
    "country": "ID",
    "name": "Driyorejo",
    "lat": "-7.3659",
    "lng": "112.6219"
  },
  {
    "country": "ID",
    "name": "Kempo",
    "lat": "-8.54286",
    "lng": "118.24821"
  },
  {
    "country": "ID",
    "name": "Donomulyo",
    "lat": "-8.2867",
    "lng": "112.427"
  },
  {
    "country": "ID",
    "name": "Dongko",
    "lat": "-8.1882",
    "lng": "111.5746"
  },
  {
    "country": "ID",
    "name": "Donggala",
    "lat": "-0.6723",
    "lng": "119.7402"
  },
  {
    "country": "ID",
    "name": "Dompu",
    "lat": "-8.5365",
    "lng": "118.4634"
  },
  {
    "country": "ID",
    "name": "Dofa",
    "lat": "-1.7952",
    "lng": "125.3649"
  },
  {
    "country": "ID",
    "name": "Dobo",
    "lat": "-5.76092",
    "lng": "134.23405"
  },
  {
    "country": "ID",
    "name": "Diwek",
    "lat": "-7.57897",
    "lng": "112.23109"
  },
  {
    "country": "ID",
    "name": "Depok",
    "lat": "-7.7625",
    "lng": "110.43167"
  },
  {
    "country": "ID",
    "name": "Depok",
    "lat": "-6.4",
    "lng": "106.81861"
  },
  {
    "country": "ID",
    "name": "Denpasar",
    "lat": "-8.65",
    "lng": "115.21667"
  },
  {
    "country": "ID",
    "name": "Demak",
    "lat": "-6.8909",
    "lng": "110.6396"
  },
  {
    "country": "ID",
    "name": "Delanggu",
    "lat": "-7.61667",
    "lng": "110.68333"
  },
  {
    "country": "ID",
    "name": "Dayeuhluhur",
    "lat": "-7.2594",
    "lng": "108.6108"
  },
  {
    "country": "ID",
    "name": "Dasuk",
    "lat": "-6.9015",
    "lng": "113.8139"
  },
  {
    "country": "ID",
    "name": "Daruba",
    "lat": "2.05049",
    "lng": "128.29398"
  },
  {
    "country": "ID",
    "name": "Darma",
    "lat": "-7.0045",
    "lng": "108.4035"
  },
  {
    "country": "ID",
    "name": "Dampit",
    "lat": "-8.21162",
    "lng": "112.74934"
  },
  {
    "country": "ID",
    "name": "Dalududalu",
    "lat": "1.08142",
    "lng": "100.24475"
  },
  {
    "country": "ID",
    "name": "Dabra",
    "lat": "-3.2453",
    "lng": "138.5878"
  },
  {
    "country": "ID",
    "name": "Curup",
    "lat": "-3.4703",
    "lng": "102.5207"
  },
  {
    "country": "ID",
    "name": "Curug",
    "lat": "-6.26583",
    "lng": "106.55639"
  },
  {
    "country": "ID",
    "name": "Comal",
    "lat": "-6.9053",
    "lng": "109.5347"
  },
  {
    "country": "ID",
    "name": "Colomadu",
    "lat": "-7.53333",
    "lng": "110.75"
  },
  {
    "country": "ID",
    "name": "Ciwaru",
    "lat": "-7.0777",
    "lng": "108.6278"
  },
  {
    "country": "ID",
    "name": "Citeureup",
    "lat": "-6.48556",
    "lng": "106.88194"
  },
  {
    "country": "ID",
    "name": "Cisompet",
    "lat": "-7.55179",
    "lng": "107.8103"
  },
  {
    "country": "ID",
    "name": "Cisolok",
    "lat": "-6.9482",
    "lng": "106.4498"
  },
  {
    "country": "ID",
    "name": "Cisewu",
    "lat": "-7.3758",
    "lng": "107.4975"
  },
  {
    "country": "ID",
    "name": "Cisayong",
    "lat": "-7.2575",
    "lng": "108.14947"
  },
  {
    "country": "ID",
    "name": "Cisaga",
    "lat": "-7.3461",
    "lng": "108.5163"
  },
  {
    "country": "ID",
    "name": "Ciruas",
    "lat": "-6.125",
    "lng": "106.23278"
  },
  {
    "country": "ID",
    "name": "Cirebon",
    "lat": "-6.7063",
    "lng": "108.557"
  },
  {
    "country": "ID",
    "name": "Ciracap",
    "lat": "-7.3312",
    "lng": "106.5215"
  },
  {
    "country": "ID",
    "name": "Ciputat",
    "lat": "-6.2375",
    "lng": "106.69556"
  },
  {
    "country": "ID",
    "name": "Cipatujah",
    "lat": "-7.733",
    "lng": "108.0204"
  },
  {
    "country": "ID",
    "name": "Cipari",
    "lat": "-7.4391",
    "lng": "108.7635"
  },
  {
    "country": "ID",
    "name": "Ciomas",
    "lat": "-6.2173",
    "lng": "106.044"
  },
  {
    "country": "ID",
    "name": "Cimerak",
    "lat": "-7.7507",
    "lng": "108.4399"
  },
  {
    "country": "ID",
    "name": "Cimaragas",
    "lat": "-7.372",
    "lng": "108.4629"
  },
  {
    "country": "ID",
    "name": "Cimanggu",
    "lat": "-7.3524",
    "lng": "108.8402"
  },
  {
    "country": "ID",
    "name": "Cimahi",
    "lat": "-6.87222",
    "lng": "107.5425"
  },
  {
    "country": "ID",
    "name": "Cileunyi",
    "lat": "-6.93889",
    "lng": "107.75278"
  },
  {
    "country": "ID",
    "name": "Cileungsir",
    "lat": "-6.39472",
    "lng": "106.95917"
  },
  {
    "country": "ID",
    "name": "Cilegong",
    "lat": "-6.5485",
    "lng": "105.9988"
  },
  {
    "country": "ID",
    "name": "Cilawu",
    "lat": "-7.2779",
    "lng": "107.9203"
  },
  {
    "country": "ID",
    "name": "Cilacap",
    "lat": "-7.72639",
    "lng": "109.00944"
  },
  {
    "country": "ID",
    "name": "Cikoneng",
    "lat": "-7.3118",
    "lng": "108.271"
  },
  {
    "country": "ID",
    "name": "Cikijing",
    "lat": "-7.0163",
    "lng": "108.3665"
  },
  {
    "country": "ID",
    "name": "Cikeusik",
    "lat": "-6.7282",
    "lng": "105.872"
  },
  {
    "country": "ID",
    "name": "Cikelet",
    "lat": "-7.6117",
    "lng": "107.6771"
  },
  {
    "country": "ID",
    "name": "Cikatomas",
    "lat": "-7.6209",
    "lng": "108.2583"
  },
  {
    "country": "ID",
    "name": "Cikarang",
    "lat": "-6.26111",
    "lng": "107.15278"
  },
  {
    "country": "ID",
    "name": "Cikampek",
    "lat": "-6.41972",
    "lng": "107.45583"
  },
  {
    "country": "ID",
    "name": "Cikalong",
    "lat": "-7.7623",
    "lng": "108.1727"
  },
  {
    "country": "ID",
    "name": "Cikajang",
    "lat": "-7.3578",
    "lng": "107.8086"
  },
  {
    "country": "ID",
    "name": "Cijulang",
    "lat": "-7.7273",
    "lng": "108.4733"
  },
  {
    "country": "ID",
    "name": "Cijeungjing",
    "lat": "-7.3323",
    "lng": "108.4145"
  },
  {
    "country": "ID",
    "name": "Cihaurbeuti",
    "lat": "-7.2234",
    "lng": "108.2011"
  },
  {
    "country": "ID",
    "name": "Ciemas",
    "lat": "-7.2333",
    "lng": "106.5198"
  },
  {
    "country": "ID",
    "name": "Cicurug",
    "lat": "-6.78139",
    "lng": "106.7825"
  },
  {
    "country": "ID",
    "name": "Cibinong",
    "lat": "-6.48167",
    "lng": "106.85417"
  },
  {
    "country": "ID",
    "name": "Cibingbin",
    "lat": "-7.0611",
    "lng": "108.7619"
  },
  {
    "country": "ID",
    "name": "Cibeureum",
    "lat": "-7.3552",
    "lng": "108.2693"
  },
  {
    "country": "ID",
    "name": "Cibalong",
    "lat": "-7.5148",
    "lng": "108.1812"
  },
  {
    "country": "ID",
    "name": "Cibaliung",
    "lat": "-6.705",
    "lng": "105.716"
  },
  {
    "country": "ID",
    "name": "Cianjur",
    "lat": "-6.82222",
    "lng": "107.13944"
  },
  {
    "country": "ID",
    "name": "Ciamis",
    "lat": "-7.3257",
    "lng": "108.3534"
  },
  {
    "country": "ID",
    "name": "Cermee",
    "lat": "-7.7772",
    "lng": "114.0487"
  },
  {
    "country": "ID",
    "name": "Cerenti",
    "lat": "-0.5086",
    "lng": "101.8689"
  },
  {
    "country": "ID",
    "name": "Cepu",
    "lat": "-7.1475",
    "lng": "111.5906"
  },
  {
    "country": "ID",
    "name": "Ceper",
    "lat": "-7.67417",
    "lng": "110.67889"
  },
  {
    "country": "ID",
    "name": "Cempaka",
    "lat": "-3.73235",
    "lng": "104.66759"
  },
  {
    "country": "ID",
    "name": "Caruban",
    "lat": "-7.5447",
    "lng": "111.6566"
  },
  {
    "country": "ID",
    "name": "Caringin",
    "lat": "-6.70611",
    "lng": "106.82139"
  },
  {
    "country": "ID",
    "name": "Campurdarat",
    "lat": "-8.1652",
    "lng": "111.8535"
  },
  {
    "country": "ID",
    "name": "Campor",
    "lat": "-6.9729",
    "lng": "112.8851"
  },
  {
    "country": "ID",
    "name": "Ciampea",
    "lat": "-6.55472",
    "lng": "106.70083"
  },
  {
    "country": "ID",
    "name": "Camming",
    "lat": "-4.8118",
    "lng": "120.0771"
  },
  {
    "country": "ID",
    "name": "Cakke",
    "lat": "-3.4101",
    "lng": "119.7985"
  },
  {
    "country": "ID",
    "name": "Buol",
    "lat": "1.1584",
    "lng": "121.4361"
  },
  {
    "country": "ID",
    "name": "Buntok",
    "lat": "-1.72139",
    "lng": "114.8397"
  },
  {
    "country": "ID",
    "name": "Buniseuri",
    "lat": "-7.2425",
    "lng": "108.3778"
  },
  {
    "country": "ID",
    "name": "Bungku",
    "lat": "-2.5471",
    "lng": "121.972"
  },
  {
    "country": "ID",
    "name": "Bungkal",
    "lat": "-8.0079",
    "lng": "111.4541"
  },
  {
    "country": "ID",
    "name": "Bungbulang",
    "lat": "-7.4568",
    "lng": "107.5991"
  },
  {
    "country": "ID",
    "name": "Bunga Mas",
    "lat": "-3.7011",
    "lng": "103.3686"
  },
  {
    "country": "ID",
    "name": "Bulukumba",
    "lat": "-5.55",
    "lng": "120.18333"
  },
  {
    "country": "ID",
    "name": "Bulu",
    "lat": "-6.8587",
    "lng": "111.4056"
  },
  {
    "country": "ID",
    "name": "Bulakamba",
    "lat": "-6.8748",
    "lng": "108.9559"
  },
  {
    "country": "ID",
    "name": "Bula",
    "lat": "-3.1112",
    "lng": "130.4954"
  },
  {
    "country": "ID",
    "name": "Bukittinggi",
    "lat": "-0.30907",
    "lng": "100.37055"
  },
  {
    "country": "ID",
    "name": "Bukitkemuning",
    "lat": "-4.85962",
    "lng": "104.57373"
  },
  {
    "country": "ID",
    "name": "Buduran",
    "lat": "-7.4281",
    "lng": "112.7234"
  },
  {
    "country": "ID",
    "name": "Buaran",
    "lat": "-7.05",
    "lng": "109.55"
  },
  {
    "country": "ID",
    "name": "Brondong",
    "lat": "-6.877",
    "lng": "112.2915"
  },
  {
    "country": "ID",
    "name": "Brebes",
    "lat": "-6.8691",
    "lng": "109.0378"
  },
  {
    "country": "ID",
    "name": "Brakas",
    "lat": "-7.1521",
    "lng": "114.6143"
  },
  {
    "country": "ID",
    "name": "Boyolangu",
    "lat": "-8.1181",
    "lng": "111.8935"
  },
  {
    "country": "ID",
    "name": "Boyolali",
    "lat": "-7.53306",
    "lng": "110.59583"
  },
  {
    "country": "ID",
    "name": "Bosnik",
    "lat": "-1.1572",
    "lng": "136.2283"
  },
  {
    "country": "ID",
    "name": "Boroko",
    "lat": "0.9083",
    "lng": "123.2679"
  },
  {
    "country": "ID",
    "name": "Bontang",
    "lat": "0.1324",
    "lng": "117.4854"
  },
  {
    "country": "ID",
    "name": "Bunobogu",
    "lat": "1.0407",
    "lng": "121.6126"
  },
  {
    "country": "ID",
    "name": "Bonjol",
    "lat": "-0.01785",
    "lng": "100.22748"
  },
  {
    "country": "ID",
    "name": "Bonebone",
    "lat": "-2.6005",
    "lng": "120.5195"
  },
  {
    "country": "ID",
    "name": "Bondowoso",
    "lat": "-7.91346",
    "lng": "113.82145"
  },
  {
    "country": "ID",
    "name": "Bondokodi",
    "lat": "-9.5943",
    "lng": "118.9934"
  },
  {
    "country": "ID",
    "name": "Bolaang",
    "lat": "0.9411",
    "lng": "124.1556"
  },
  {
    "country": "ID",
    "name": "Bolangitang",
    "lat": "0.9068",
    "lng": "123.3067"
  },
  {
    "country": "ID",
    "name": "Bola",
    "lat": "-8.7419",
    "lng": "122.2958"
  },
  {
    "country": "ID",
    "name": "Bikondini",
    "lat": "-3.65836",
    "lng": "138.57468"
  },
  {
    "country": "ID",
    "name": "Bokat",
    "lat": "1.0871",
    "lng": "121.505"
  },
  {
    "country": "ID",
    "name": "Bojongmanik Girang",
    "lat": "-6.5843",
    "lng": "106.1662"
  },
  {
    "country": "ID",
    "name": "Bojonegoro",
    "lat": "-7.1502",
    "lng": "111.8817"
  },
  {
    "country": "ID",
    "name": "Bojonegara",
    "lat": "-5.97",
    "lng": "106.0955"
  },
  {
    "country": "ID",
    "name": "Bogorejo",
    "lat": "-6.9404",
    "lng": "111.5186"
  },
  {
    "country": "ID",
    "name": "Bogor",
    "lat": "-6.59444",
    "lng": "106.78917"
  },
  {
    "country": "ID",
    "name": "Bobong",
    "lat": "-1.94625",
    "lng": "124.38394"
  },
  {
    "country": "ID",
    "name": "Boawae",
    "lat": "-8.7639",
    "lng": "121.1694"
  },
  {
    "country": "ID",
    "name": "Baluburlimbangan",
    "lat": "-7.0357",
    "lng": "107.9829"
  },
  {
    "country": "ID",
    "name": "Blora",
    "lat": "-6.9698",
    "lng": "111.4186"
  },
  {
    "country": "ID",
    "name": "Blitar",
    "lat": "-8.0983",
    "lng": "112.1681"
  },
  {
    "country": "ID",
    "name": "Baranusa",
    "lat": "-8.3622",
    "lng": "124.0888"
  },
  {
    "country": "ID",
    "name": "Bitung",
    "lat": "1.45697",
    "lng": "125.1895"
  },
  {
    "country": "ID",
    "name": "Bitung",
    "lat": "1.20746",
    "lng": "124.5958"
  },
  {
    "country": "ID",
    "name": "Birayang",
    "lat": "-2.5328",
    "lng": "115.4549"
  },
  {
    "country": "ID",
    "name": "Binuang",
    "lat": "-3.0707",
    "lng": "115.1638"
  },
  {
    "country": "ID",
    "name": "Bintuni",
    "lat": "-2.1084",
    "lng": "133.537"
  },
  {
    "country": "ID",
    "name": "Bintuhan",
    "lat": "-4.79371",
    "lng": "103.34836"
  },
  {
    "country": "ID",
    "name": "Bingintelok",
    "lat": "-2.6232",
    "lng": "103.1173"
  },
  {
    "country": "ID",
    "name": "Binangun",
    "lat": "-8.2343",
    "lng": "112.336"
  },
  {
    "country": "ID",
    "name": "Bima",
    "lat": "-8.46006",
    "lng": "118.72667"
  },
  {
    "country": "ID",
    "name": "Bilungala",
    "lat": "0.3815",
    "lng": "123.2135"
  },
  {
    "country": "ID",
    "name": "Biha",
    "lat": "-5.3296",
    "lng": "104.0295"
  },
  {
    "country": "ID",
    "name": "Biak",
    "lat": "-1.1767",
    "lng": "136.082"
  },
  {
    "country": "ID",
    "name": "Betaf",
    "lat": "-2.11422",
    "lng": "139.25282"
  },
  {
    "country": "ID",
    "name": "Besuki Satu",
    "lat": "-8.2088",
    "lng": "111.7755"
  },
  {
    "country": "ID",
    "name": "Besuki",
    "lat": "-7.73379",
    "lng": "113.69785"
  },
  {
    "country": "ID",
    "name": "Beo",
    "lat": "4.22867",
    "lng": "126.79872"
  },
  {
    "country": "ID",
    "name": "Benteng",
    "lat": "-6.1184",
    "lng": "120.4605"
  },
  {
    "country": "ID",
    "name": "Bengkulu",
    "lat": "-3.80044",
    "lng": "102.26554"
  },
  {
    "country": "ID",
    "name": "Bengkayang",
    "lat": "0.83194",
    "lng": "109.43589"
  },
  {
    "country": "ID",
    "name": "Bengkalis",
    "lat": "1.46667",
    "lng": "102.13333"
  },
  {
    "country": "ID",
    "name": "Belopa",
    "lat": "-3.3849",
    "lng": "120.3676"
  },
  {
    "country": "ID",
    "name": "Belimbing",
    "lat": "-2.9823",
    "lng": "115.3502"
  },
  {
    "country": "ID",
    "name": "Blambangan Umpu",
    "lat": "-4.50263",
    "lng": "104.51926"
  },
  {
    "country": "ID",
    "name": "Mentarang",
    "lat": "3.60626",
    "lng": "116.16786"
  },
  {
    "country": "ID",
    "name": "Belakangpadang",
    "lat": "1.14964",
    "lng": "103.89164"
  },
  {
    "country": "ID",
    "name": "Bekasi",
    "lat": "-6.2349",
    "lng": "106.9896"
  },
  {
    "country": "ID",
    "name": "Bejubang Dua",
    "lat": "-1.7923",
    "lng": "103.3167"
  },
  {
    "country": "ID",
    "name": "Bebandem",
    "lat": "-8.4403",
    "lng": "115.5602"
  },
  {
    "country": "ID",
    "name": "Bayunglincir",
    "lat": "-2.0549",
    "lng": "103.6834"
  },
  {
    "country": "ID",
    "name": "Bayongbong",
    "lat": "-7.2716",
    "lng": "107.8197"
  },
  {
    "country": "ID",
    "name": "Batusangkar",
    "lat": "-0.4606",
    "lng": "100.6107"
  },
  {
    "country": "ID",
    "name": "Baturaja",
    "lat": "-4.12891",
    "lng": "104.16695"
  },
  {
    "country": "ID",
    "name": "Baturaden",
    "lat": "-7.3",
    "lng": "109.21667"
  },
  {
    "country": "ID",
    "name": "Batuputih",
    "lat": "-6.9161",
    "lng": "113.9177"
  },
  {
    "country": "ID",
    "name": "Batu Panjang",
    "lat": "1.71206",
    "lng": "101.51427"
  },
  {
    "country": "ID",
    "name": "Batumandi",
    "lat": "-2.4218",
    "lng": "115.4409"
  },
  {
    "country": "ID",
    "name": "Batulicin",
    "lat": "-3.42022",
    "lng": "116.00611"
  },
  {
    "country": "ID",
    "name": "Batubantar",
    "lat": "-6.3501",
    "lng": "106.0444"
  },
  {
    "country": "ID",
    "name": "Batu",
    "lat": "-7.87",
    "lng": "112.52833"
  },
  {
    "country": "ID",
    "name": "Batibati",
    "lat": "-3.6184",
    "lng": "114.7166"
  },
  {
    "country": "ID",
    "name": "Batangan",
    "lat": "-6.7094",
    "lng": "111.2295"
  },
  {
    "country": "ID",
    "name": "Batauga",
    "lat": "-5.5882",
    "lng": "122.5964"
  },
  {
    "country": "ID",
    "name": "Batang",
    "lat": "-6.4846",
    "lng": "110.7083"
  },
  {
    "country": "ID",
    "name": "Baso",
    "lat": "-0.28067",
    "lng": "100.45362"
  },
  {
    "country": "ID",
    "name": "Baserah",
    "lat": "-0.4462",
    "lng": "101.7436"
  },
  {
    "country": "ID",
    "name": "Barru",
    "lat": "-4.412",
    "lng": "119.618"
  },
  {
    "country": "ID",
    "name": "Barapas",
    "lat": "-2.199",
    "lng": "137.0013"
  },
  {
    "country": "ID",
    "name": "Barabai",
    "lat": "-2.58333",
    "lng": "115.38333"
  },
  {
    "country": "ID",
    "name": "Banyuwangi",
    "lat": "-8.2325",
    "lng": "114.35755"
  },
  {
    "country": "ID",
    "name": "Banyuresmi",
    "lat": "-7.1605",
    "lng": "107.9517"
  },
  {
    "country": "ID",
    "name": "Banyumas",
    "lat": "-7.51417",
    "lng": "109.29417"
  },
  {
    "country": "ID",
    "name": "Banyuates",
    "lat": "-6.8967",
    "lng": "113.1554"
  },
  {
    "country": "ID",
    "name": "Bantur",
    "lat": "-8.314",
    "lng": "112.5807"
  },
  {
    "country": "ID",
    "name": "Bantul",
    "lat": "-7.88806",
    "lng": "110.32889"
  },
  {
    "country": "ID",
    "name": "Bantaeng",
    "lat": "-5.5475",
    "lng": "119.9509"
  },
  {
    "country": "ID",
    "name": "Banjarwangi",
    "lat": "-7.4398",
    "lng": "107.9026"
  },
  {
    "country": "ID",
    "name": "Banjarsari",
    "lat": "-7.4819",
    "lng": "108.5998"
  },
  {
    "country": "ID",
    "name": "Banjarejo",
    "lat": "-7.0344",
    "lng": "111.3441"
  },
  {
    "country": "ID",
    "name": "Banjarnegara",
    "lat": "-7.39611",
    "lng": "109.69611"
  },
  {
    "country": "ID",
    "name": "Banjarmasin",
    "lat": "-3.31987",
    "lng": "114.59075"
  },
  {
    "country": "ID",
    "name": "Banjaran",
    "lat": "-7.04528",
    "lng": "107.58778"
  },
  {
    "country": "ID",
    "name": "Banjar",
    "lat": "-8.19",
    "lng": "114.9675"
  },
  {
    "country": "ID",
    "name": "Banjar",
    "lat": "-7.3688",
    "lng": "108.5329"
  },
  {
    "country": "ID",
    "name": "Banjar",
    "lat": "-7.1955",
    "lng": "107.4313"
  },
  {
    "country": "ID",
    "name": "Bangli",
    "lat": "-8.4542",
    "lng": "115.3545"
  },
  {
    "country": "ID",
    "name": "Bangko",
    "lat": "-2.0796",
    "lng": "102.2573"
  },
  {
    "country": "ID",
    "name": "Bangkinang",
    "lat": "0.33833",
    "lng": "101.02361"
  },
  {
    "country": "ID",
    "name": "Bangkalan",
    "lat": "-7.0455",
    "lng": "112.7351"
  },
  {
    "country": "ID",
    "name": "Bangilan",
    "lat": "-6.97",
    "lng": "111.7141"
  },
  {
    "country": "ID",
    "name": "Bangil",
    "lat": "-7.59939",
    "lng": "112.8186"
  },
  {
    "country": "ID",
    "name": "Banggai",
    "lat": "-1.5887",
    "lng": "123.4992"
  },
  {
    "country": "ID",
    "name": "Bandung",
    "lat": "-8.1676",
    "lng": "111.7844"
  },
  {
    "country": "ID",
    "name": "Bandung",
    "lat": "-6.92222",
    "lng": "107.60694"
  },
  {
    "country": "ID",
    "name": "Banding Agung",
    "lat": "-4.80947",
    "lng": "103.92443"
  },
  {
    "country": "ID",
    "name": "Elat",
    "lat": "-5.6578",
    "lng": "132.9709"
  },
  {
    "country": "ID",
    "name": "Bancar",
    "lat": "-6.7827",
    "lng": "111.7808"
  },
  {
    "country": "ID",
    "name": "Bambanglipuro",
    "lat": "-7.95",
    "lng": "110.28333"
  },
  {
    "country": "ID",
    "name": "Balung",
    "lat": "-8.2727",
    "lng": "113.5388"
  },
  {
    "country": "ID",
    "name": "Balung",
    "lat": "-7.73333",
    "lng": "113.91667"
  },
  {
    "country": "ID",
    "name": "Balong",
    "lat": "-6.8381",
    "lng": "111.1714"
  },
  {
    "country": "ID",
    "name": "Balikpapan",
    "lat": "-1.26753",
    "lng": "116.82887"
  },
  {
    "country": "ID",
    "name": "Balauring",
    "lat": "-8.2336",
    "lng": "123.706"
  },
  {
    "country": "ID",
    "name": "Balapulang",
    "lat": "-7.04858",
    "lng": "109.10056"
  },
  {
    "country": "ID",
    "name": "Balaipungut",
    "lat": "1.05949",
    "lng": "101.29054"
  },
  {
    "country": "ID",
    "name": "Balaiberkuak",
    "lat": "-0.52609",
    "lng": "110.36637"
  },
  {
    "country": "ID",
    "name": "Baki",
    "lat": "-7.61278",
    "lng": "110.78389"
  },
  {
    "country": "ID",
    "name": "Bajo",
    "lat": "-3.3788",
    "lng": "120.3102"
  },
  {
    "country": "ID",
    "name": "Bajawa",
    "lat": "-8.7848",
    "lng": "120.9744"
  },
  {
    "country": "ID",
    "name": "Bagansiapiapi",
    "lat": "2.15668",
    "lng": "100.80763"
  },
  {
    "country": "ID",
    "name": "Baekrajan",
    "lat": "-6.7674",
    "lng": "110.8541"
  },
  {
    "country": "ID",
    "name": "Bade",
    "lat": "-7.16667",
    "lng": "139.58333"
  },
  {
    "country": "ID",
    "name": "Babo",
    "lat": "-2.5383",
    "lng": "133.4199"
  },
  {
    "country": "ID",
    "name": "Babirik",
    "lat": "-2.5409",
    "lng": "115.1588"
  },
  {
    "country": "ID",
    "name": "Babat",
    "lat": "-7.11282",
    "lng": "112.16354"
  },
  {
    "country": "ID",
    "name": "Babat",
    "lat": "-2.7381",
    "lng": "103.6401"
  },
  {
    "country": "ID",
    "name": "Babana",
    "lat": "-2.0779",
    "lng": "119.1986"
  },
  {
    "country": "ID",
    "name": "Ayamaru",
    "lat": "-1.27448",
    "lng": "132.19334"
  },
  {
    "country": "ID",
    "name": "Aitinyo",
    "lat": "-1.3119",
    "lng": "132.3447"
  },
  {
    "country": "ID",
    "name": "Atap",
    "lat": "3.85714",
    "lng": "117.04654"
  },
  {
    "country": "ID",
    "name": "Atambua",
    "lat": "-9.10611",
    "lng": "124.8925"
  },
  {
    "country": "ID",
    "name": "Astanajapura",
    "lat": "-6.8017",
    "lng": "108.6311"
  },
  {
    "country": "ID",
    "name": "Asera",
    "lat": "-3.4746",
    "lng": "122.0669"
  },
  {
    "country": "ID",
    "name": "Asembagus",
    "lat": "-7.7507",
    "lng": "114.2101"
  },
  {
    "country": "ID",
    "name": "Arosbaya",
    "lat": "-6.9442",
    "lng": "112.839"
  },
  {
    "country": "ID",
    "name": "Armopa",
    "lat": "-2.3409",
    "lng": "139.6335"
  },
  {
    "country": "ID",
    "name": "Arjawinangun",
    "lat": "-6.64528",
    "lng": "108.41028"
  },
  {
    "country": "ID",
    "name": "Arjasa",
    "lat": "-6.8596",
    "lng": "115.2852"
  },
  {
    "country": "ID",
    "name": "Argamakmur",
    "lat": "-3.4232",
    "lng": "102.1891"
  },
  {
    "country": "ID",
    "name": "Ansus",
    "lat": "-1.7256",
    "lng": "135.8115"
  },
  {
    "country": "ID",
    "name": "Ankola",
    "lat": "-7.3071",
    "lng": "107.1272"
  },
  {
    "country": "ID",
    "name": "Anggana",
    "lat": "-0.5705",
    "lng": "117.2844"
  },
  {
    "country": "ID",
    "name": "Andoolo",
    "lat": "-4.3273",
    "lng": "122.2522"
  },
  {
    "country": "ID",
    "name": "Amuntai",
    "lat": "-2.41773",
    "lng": "115.24941"
  },
  {
    "country": "ID",
    "name": "Ampana",
    "lat": "-0.86901",
    "lng": "121.58367"
  },
  {
    "country": "ID",
    "name": "Ambuten",
    "lat": "-6.8885",
    "lng": "113.7392"
  },
  {
    "country": "ID",
    "name": "Ambon",
    "lat": "-3.69583",
    "lng": "128.18333"
  },
  {
    "country": "ID",
    "name": "Ambarawa",
    "lat": "-7.26333",
    "lng": "110.3975"
  },
  {
    "country": "ID",
    "name": "Amahai",
    "lat": "-3.33984",
    "lng": "128.91975"
  },
  {
    "country": "ID",
    "name": "Aluhaluh",
    "lat": "-3.4991",
    "lng": "114.5443"
  },
  {
    "country": "ID",
    "name": "Alahanpanjang",
    "lat": "-1.07491",
    "lng": "100.79354"
  },
  {
    "country": "ID",
    "name": "Alabio",
    "lat": "-2.4542",
    "lng": "115.2445"
  },
  {
    "country": "ID",
    "name": "Airmolek",
    "lat": "-0.37001",
    "lng": "102.29221"
  },
  {
    "country": "ID",
    "name": "Airmadidi",
    "lat": "1.42804",
    "lng": "124.97774"
  },
  {
    "country": "ID",
    "name": "Aimere",
    "lat": "-8.8431",
    "lng": "120.8579"
  },
  {
    "country": "ID",
    "name": "Agats",
    "lat": "-5.54505",
    "lng": "138.13522"
  },
  {
    "country": "ID",
    "name": "Airbuaya",
    "lat": "-3.103",
    "lng": "126.4207"
  },
  {
    "country": "ID",
    "name": "Aenganyar",
    "lat": "-7.1905",
    "lng": "113.8969"
  },
  {
    "country": "ID",
    "name": "Adiwerna",
    "lat": "-6.9375",
    "lng": "109.1325"
  },
  {
    "country": "ID",
    "name": "Adipala",
    "lat": "-7.65972",
    "lng": "109.15"
  },
  {
    "country": "ID",
    "name": "Lupak",
    "lat": "-3.3823",
    "lng": "114.268"
  },
  {
    "country": "ID",
    "name": "Tabunganen",
    "lat": "-3.4103",
    "lng": "114.4829"
  },
  {
    "country": "ID",
    "name": "Belawang",
    "lat": "-3.0715",
    "lng": "114.6604"
  },
  {
    "country": "ID",
    "name": "Tulehu",
    "lat": "-3.58803",
    "lng": "128.32728"
  },
  {
    "country": "ID",
    "name": "Meral",
    "lat": "0.99487",
    "lng": "103.39365"
  },
  {
    "country": "ID",
    "name": "Gununganyar",
    "lat": "-7.3409",
    "lng": "112.7821"
  },
  {
    "country": "ID",
    "name": "Betun",
    "lat": "-9.56722",
    "lng": "124.9075"
  },
  {
    "country": "ID",
    "name": "Naisano Dua",
    "lat": "-9.59806",
    "lng": "123.77028"
  },
  {
    "country": "ID",
    "name": "Sasi",
    "lat": "-9.49917",
    "lng": "124.49278"
  },
  {
    "country": "ID",
    "name": "Bangunrejo",
    "lat": "-5.1403",
    "lng": "105.0372"
  },
  {
    "country": "ID",
    "name": "Punggur",
    "lat": "-5.04146",
    "lng": "105.27734"
  },
  {
    "country": "ID",
    "name": "Pekalongan",
    "lat": "-5.08277",
    "lng": "105.35885"
  },
  {
    "country": "ID",
    "name": "Batanghari",
    "lat": "-5.14095",
    "lng": "105.3752"
  },
  {
    "country": "ID",
    "name": "Sokarame",
    "lat": "-7.084",
    "lng": "114.2856"
  },
  {
    "country": "ID",
    "name": "Padalarang",
    "lat": "-6.83778",
    "lng": "107.47278"
  },
  {
    "country": "ID",
    "name": "Ciranjang-hilir",
    "lat": "-6.82",
    "lng": "107.25722"
  },
  {
    "country": "ID",
    "name": "Ngamprah",
    "lat": "-6.80361",
    "lng": "107.27528"
  },
  {
    "country": "ID",
    "name": "Gunung Kendil",
    "lat": "-7.33167",
    "lng": "110.40417"
  },
  {
    "country": "ID",
    "name": "Kali",
    "lat": "1.1627",
    "lng": "121.4278"
  },
  {
    "country": "ID",
    "name": "Lamadong",
    "lat": "1.1175",
    "lng": "121.4142"
  },
  {
    "country": "ID",
    "name": "Kauditan",
    "lat": "1.39132",
    "lng": "125.03436"
  },
  {
    "country": "ID",
    "name": "Ogotua",
    "lat": "0.9596",
    "lng": "120.2642"
  },
  {
    "country": "ID",
    "name": "Sidomulyo",
    "lat": "0.6496",
    "lng": "122.6152"
  },
  {
    "country": "ID",
    "name": "Tompasobaru",
    "lat": "0.9202",
    "lng": "124.4689"
  },
  {
    "country": "ID",
    "name": "Tobadak",
    "lat": "-2.08944",
    "lng": "119.34722"
  },
  {
    "country": "ID",
    "name": "Rantepang",
    "lat": "-2.9252",
    "lng": "119.9413"
  },
  {
    "country": "ID",
    "name": "Rindingallo",
    "lat": "-2.8979",
    "lng": "119.8138"
  },
  {
    "country": "ID",
    "name": "Sukamaju",
    "lat": "-2.6098",
    "lng": "120.4664"
  },
  {
    "country": "ID",
    "name": "Lamasi",
    "lat": "-2.8166",
    "lng": "120.1763"
  },
  {
    "country": "ID",
    "name": "Walenrang",
    "lat": "-2.8417",
    "lng": "120.1222"
  },
  {
    "country": "ID",
    "name": "Malunda",
    "lat": "-3.013",
    "lng": "118.8559"
  },
  {
    "country": "ID",
    "name": "Lampa",
    "lat": "-3.6634",
    "lng": "119.5334"
  },
  {
    "country": "ID",
    "name": "Majennang",
    "lat": "-3.9728",
    "lng": "119.6091"
  },
  {
    "country": "ID",
    "name": "Uluale",
    "lat": "-3.9072",
    "lng": "119.7441"
  },
  {
    "country": "ID",
    "name": "Amparita",
    "lat": "-3.9937",
    "lng": "119.8122"
  },
  {
    "country": "ID",
    "name": "Sidenreng",
    "lat": "-3.92753",
    "lng": "119.7993"
  },
  {
    "country": "ID",
    "name": "Baranti",
    "lat": "-3.8398",
    "lng": "119.7838"
  },
  {
    "country": "ID",
    "name": "Teppo",
    "lat": "-3.7065",
    "lng": "119.67"
  },
  {
    "country": "ID",
    "name": "Baraka",
    "lat": "-3.4079",
    "lng": "119.8559"
  },
  {
    "country": "ID",
    "name": "Getengan",
    "lat": "-3.1813",
    "lng": "119.8839"
  },
  {
    "country": "ID",
    "name": "Beringinjaya",
    "lat": "-3.0072",
    "lng": "120.2057"
  },
  {
    "country": "ID",
    "name": "Beuma",
    "lat": "-3.2115",
    "lng": "120.0527"
  },
  {
    "country": "ID",
    "name": "Padangsappa",
    "lat": "-3.2347",
    "lng": "120.3005"
  },
  {
    "country": "ID",
    "name": "Lempokasi",
    "lat": "-3.4557",
    "lng": "120.3661"
  },
  {
    "country": "ID",
    "name": "Unaaha",
    "lat": "-3.8539",
    "lng": "122.042"
  },
  {
    "country": "ID",
    "name": "Tancung",
    "lat": "-4.0525",
    "lng": "120.0288"
  },
  {
    "country": "ID",
    "name": "Maroanging",
    "lat": "-4.1961",
    "lng": "120.0984"
  },
  {
    "country": "ID",
    "name": "Kotabaru",
    "lat": "-4.2137",
    "lng": "120.0096"
  },
  {
    "country": "ID",
    "name": "Matango",
    "lat": "-4.6619",
    "lng": "120.014"
  },
  {
    "country": "ID",
    "name": "Apala",
    "lat": "-4.6125",
    "lng": "120.3136"
  },
  {
    "country": "ID",
    "name": "Kadai",
    "lat": "-4.8083",
    "lng": "120.3423"
  },
  {
    "country": "ID",
    "name": "Bulubulu",
    "lat": "-4.9127",
    "lng": "120.2817"
  },
  {
    "country": "ID",
    "name": "Bilalang",
    "lat": "0.77292",
    "lng": "124.30103"
  },
  {
    "country": "ID",
    "name": "Modayag",
    "lat": "0.7105",
    "lng": "124.3838"
  },
  {
    "country": "ID",
    "name": "Batuputih",
    "lat": "-2.9582",
    "lng": "120.181"
  },
  {
    "country": "ID",
    "name": "Gubengairlangga",
    "lat": "-7.2729",
    "lng": "112.7573"
  },
  {
    "country": "ID",
    "name": "Cikupa",
    "lat": "-6.23639",
    "lng": "106.50833"
  },
  {
    "country": "ID",
    "name": "Teluknaga",
    "lat": "-6.09889",
    "lng": "106.63806"
  },
  {
    "country": "ID",
    "name": "Gamping Lor",
    "lat": "-7.79556",
    "lng": "110.32639"
  },
  {
    "country": "ID",
    "name": "Kasihan",
    "lat": "-7.82694",
    "lng": "110.32917"
  },
  {
    "country": "ID",
    "name": "Ngemplak",
    "lat": "-7.54972",
    "lng": "110.71639"
  },
  {
    "country": "ID",
    "name": "Kartasura",
    "lat": "-7.55194",
    "lng": "110.73778"
  },
  {
    "country": "ID",
    "name": "Gatak",
    "lat": "-7.59083",
    "lng": "110.70444"
  },
  {
    "country": "ID",
    "name": "Olafulihaa",
    "lat": "-10.631",
    "lng": "123.2347"
  },
  {
    "country": "ID",
    "name": "Seba",
    "lat": "-10.4933",
    "lng": "121.8393"
  },
  {
    "country": "ID",
    "name": "Oelamasi",
    "lat": "-10.0642",
    "lng": "123.8787"
  },
  {
    "country": "ID",
    "name": "Oekabiti",
    "lat": "-10.2152",
    "lng": "123.8253"
  },
  {
    "country": "ID",
    "name": "Kupang",
    "lat": "-10.17083",
    "lng": "123.60694"
  },
  {
    "country": "ID",
    "name": "Kelapalima",
    "lat": "-10.1499",
    "lng": "123.6194"
  },
  {
    "country": "ID",
    "name": "Kananggar",
    "lat": "-10.0432",
    "lng": "120.3622"
  },
  {
    "country": "ID",
    "name": "Eahun",
    "lat": "-10.6146",
    "lng": "123.3852"
  },
  {
    "country": "ID",
    "name": "Camplong",
    "lat": "-10.0376",
    "lng": "123.9234"
  },
  {
    "country": "ID",
    "name": "Babau",
    "lat": "-10.1054",
    "lng": "123.7863"
  },
  {
    "country": "ID",
    "name": "Baa",
    "lat": "-10.7263",
    "lng": "123.0492"
  },
  {
    "country": "ID",
    "name": "Waris",
    "lat": "-3.11667",
    "lng": "140.88333"
  },
  {
    "country": "ID",
    "name": "Ubrub",
    "lat": "-3.7131",
    "lng": "140.8795"
  },
  {
    "country": "ID",
    "name": "Tanah Merah",
    "lat": "-6.09756",
    "lng": "140.30649"
  },
  {
    "country": "ID",
    "name": "Sentani",
    "lat": "-2.5691",
    "lng": "140.5127"
  },
  {
    "country": "ID",
    "name": "Sengge",
    "lat": "-3.4475",
    "lng": "140.7751"
  },
  {
    "country": "ID",
    "name": "Jayapura",
    "lat": "-2.53371",
    "lng": "140.71813"
  },
  {
    "country": "ID",
    "name": "Genyem",
    "lat": "-2.5791",
    "lng": "140.1495"
  },
  {
    "country": "ID",
    "name": "Depapre",
    "lat": "-2.4869",
    "lng": "140.3711"
  },
  {
    "country": "ID",
    "name": "Demta",
    "lat": "-2.3589",
    "lng": "140.1473"
  },
  {
    "country": "ID",
    "name": "Arso",
    "lat": "-2.9028",
    "lng": "140.7657"
  },
  {
    "country": "ID",
    "name": "Abepura",
    "lat": "-2.5964",
    "lng": "140.6324"
  },
  {
    "country": "ID",
    "name": "Mungkid",
    "lat": "-7.5925",
    "lng": "110.21889"
  },
  {
    "country": "ID",
    "name": "Gambarsari",
    "lat": "-7.53139",
    "lng": "109.20139"
  },
  {
    "country": "ID",
    "name": "Klapagada",
    "lat": "-7.62333",
    "lng": "109.14861"
  },
  {
    "country": "ID",
    "name": "Rejanegara",
    "lat": "-7.68528",
    "lng": "109.03833"
  },
  {
    "country": "ID",
    "name": "Karangbadar Kidul",
    "lat": "-7.70556",
    "lng": "109.03083"
  },
  {
    "country": "ID",
    "name": "Gili Air",
    "lat": "-8.35783",
    "lng": "116.0824"
  },
  {
    "country": "ID",
    "name": "Senggigi",
    "lat": "-8.4919",
    "lng": "116.0424"
  },
  {
    "country": "ID",
    "name": "Lueng Putu",
    "lat": "5.2571",
    "lng": "96.0565"
  },
  {
    "country": "ID",
    "name": "Kuala Tuha",
    "lat": "4.05927",
    "lng": "96.24452"
  },
  {
    "country": "ID",
    "name": "Kebayakan",
    "lat": "4.6408",
    "lng": "96.8538"
  },
  {
    "country": "ID",
    "name": "Simpang Tiga Redelong",
    "lat": "4.722",
    "lng": "96.8743"
  },
  {
    "country": "ID",
    "name": "Pandan",
    "lat": "1.6838",
    "lng": "98.822"
  },
  {
    "country": "ID",
    "name": "Tangantangancut",
    "lat": "3.6876",
    "lng": "96.8896"
  },
  {
    "country": "ID",
    "name": "Jambi Baru",
    "lat": "2.7787",
    "lng": "97.8887"
  },
  {
    "country": "ID",
    "name": "Drien Rampak",
    "lat": "4.3105",
    "lng": "95.958"
  },
  {
    "country": "ID",
    "name": "Angkup",
    "lat": "4.6216",
    "lng": "96.7228"
  },
  {
    "country": "ID",
    "name": "Aek Kanopan",
    "lat": "2.5704",
    "lng": "99.6534"
  },
  {
    "country": "ID",
    "name": "Onolimbu",
    "lat": "0.99459",
    "lng": "97.49746"
  },
  {
    "country": "ID",
    "name": "Kaburon",
    "lat": "-6.2875",
    "lng": "106.1267"
  },
  {
    "country": "ID",
    "name": "Curug",
    "lat": "-5.9813",
    "lng": "106.0193"
  },
  {
    "country": "ID",
    "name": "Bahoi",
    "lat": "2.36191",
    "lng": "125.37335"
  },
  {
    "country": "ID",
    "name": "Tutuyan",
    "lat": "0.7654",
    "lng": "124.6144"
  },
  {
    "country": "ID",
    "name": "Lolayan",
    "lat": "0.646",
    "lng": "124.3074"
  },
  {
    "country": "ID",
    "name": "Poigar",
    "lat": "0.9957",
    "lng": "124.2827"
  },
  {
    "country": "ID",
    "name": "Tanggunggunung",
    "lat": "-8.2185",
    "lng": "111.8757"
  },
  {
    "country": "ID",
    "name": "Kromengan",
    "lat": "-8.1296",
    "lng": "112.4911"
  },
  {
    "country": "ID",
    "name": "Menden",
    "lat": "-7.2467",
    "lng": "111.4548"
  },
  {
    "country": "ID",
    "name": "Ngraho",
    "lat": "-7.1707",
    "lng": "111.4972"
  },
  {
    "country": "ID",
    "name": "Pengkok",
    "lat": "-7.1667",
    "lng": "111.6099"
  },
  {
    "country": "ID",
    "name": "Sambopinggir",
    "lat": "-7.0225",
    "lng": "112.4793"
  },
  {
    "country": "ID",
    "name": "Pule",
    "lat": "-8.0482",
    "lng": "113.1404"
  },
  {
    "country": "ID",
    "name": "Darungan Lor",
    "lat": "-8.0438",
    "lng": "113.2345"
  },
  {
    "country": "ID",
    "name": "Pohgending Kawan",
    "lat": "-8.4359",
    "lng": "115.1426"
  },
  {
    "country": "ID",
    "name": "Basa",
    "lat": "-8.4741",
    "lng": "115.1685"
  },
  {
    "country": "ID",
    "name": "Amahusu",
    "lat": "-3.72525",
    "lng": "128.1471"
  },
  {
    "country": "ID",
    "name": "Watulumbung",
    "lat": "-7.0052",
    "lng": "111.512"
  },
  {
    "country": "ID",
    "name": "Banjar Wangsian",
    "lat": "-8.49497",
    "lng": "115.42342"
  },
  {
    "country": "ID",
    "name": "Wonotirto",
    "lat": "-8.2245",
    "lng": "112.154"
  },
  {
    "country": "ID",
    "name": "Sukorambi",
    "lat": "-8.1571",
    "lng": "113.6652"
  },
  {
    "country": "ID",
    "name": "Patrang",
    "lat": "-8.1446",
    "lng": "113.7196"
  },
  {
    "country": "ID",
    "name": "Kloncing",
    "lat": "-8.1848",
    "lng": "113.727"
  },
  {
    "country": "ID",
    "name": "Durenan",
    "lat": "-8.2441",
    "lng": "113.6536"
  },
  {
    "country": "ID",
    "name": "Pacarkeling",
    "lat": "-7.258",
    "lng": "112.7581"
  },
  {
    "country": "ID",
    "name": "Semarapura",
    "lat": "-8.5346",
    "lng": "115.4022"
  },
  {
    "country": "ID",
    "name": "Songgon",
    "lat": "-8.2351",
    "lng": "114.20438"
  },
  {
    "country": "ID",
    "name": "Tirtopuro",
    "lat": "-8.1805",
    "lng": "114.357"
  },
  {
    "country": "ID",
    "name": "Olehsari",
    "lat": "-8.2158",
    "lng": "114.3193"
  },
  {
    "country": "ID",
    "name": "Krajan Satu",
    "lat": "-8.2072",
    "lng": "114.3563"
  },
  {
    "country": "ID",
    "name": "Seririt",
    "lat": "-8.1928",
    "lng": "114.9388"
  },
  {
    "country": "ID",
    "name": "Sukamulia",
    "lat": "-8.6286",
    "lng": "116.5125"
  },
  {
    "country": "ID",
    "name": "Aikmel",
    "lat": "-8.5678",
    "lng": "116.5305"
  },
  {
    "country": "ID",
    "name": "Abang",
    "lat": "-8.3866",
    "lng": "115.6013"
  },
  {
    "country": "ID",
    "name": "Subagan",
    "lat": "-8.4503",
    "lng": "115.6065"
  },
  {
    "country": "ID",
    "name": "Pauhambar",
    "lat": "-0.65536",
    "lng": "100.21279"
  },
  {
    "country": "ID",
    "name": "Lubukalung",
    "lat": "-0.68624",
    "lng": "100.28613"
  },
  {
    "country": "ID",
    "name": "Sungaisarik",
    "lat": "-0.57358",
    "lng": "100.22464"
  },
  {
    "country": "ID",
    "name": "Kampungladang",
    "lat": "-0.54192",
    "lng": "100.17043"
  },
  {
    "country": "ID",
    "name": "Kotatua",
    "lat": "-0.34514",
    "lng": "100.36241"
  },
  {
    "country": "ID",
    "name": "Guguk",
    "lat": "-0.1389",
    "lng": "100.5526"
  },
  {
    "country": "ID",
    "name": "Salimpaung",
    "lat": "-0.3523",
    "lng": "100.54884"
  },
  {
    "country": "ID",
    "name": "Sungayang",
    "lat": "-0.40756",
    "lng": "100.59718"
  },
  {
    "country": "ID",
    "name": "Simabur",
    "lat": "-0.46448",
    "lng": "100.52817"
  },
  {
    "country": "ID",
    "name": "Rambatan",
    "lat": "-0.49214",
    "lng": "100.54544"
  },
  {
    "country": "ID",
    "name": "Gunung Talang",
    "lat": "-0.90566",
    "lng": "100.62709"
  },
  {
    "country": "ID",
    "name": "Kumanis",
    "lat": "-0.5497",
    "lng": "100.831"
  },
  {
    "country": "ID",
    "name": "Tanjungampalu",
    "lat": "-0.63865",
    "lng": "100.8281"
  },
  {
    "country": "ID",
    "name": "Kototujuh",
    "lat": "-0.6361",
    "lng": "100.889"
  },
  {
    "country": "ID",
    "name": "Sirukam",
    "lat": "-0.88711",
    "lng": "100.7595"
  },
  {
    "country": "ID",
    "name": "Tanjung Mas",
    "lat": "-0.497",
    "lng": "100.773"
  },
  {
    "country": "ID",
    "name": "Nusa Dua",
    "lat": "-8.80047",
    "lng": "115.23341"
  },
  {
    "country": "ID",
    "name": "Legian",
    "lat": "-8.70415",
    "lng": "115.17028"
  },
  {
    "country": "ID",
    "name": "Banjar Mandung",
    "lat": "-8.5179",
    "lng": "115.0919"
  },
  {
    "country": "ID",
    "name": "Tambolaka",
    "lat": "-9.4283",
    "lng": "119.238"
  },
  {
    "country": "ID",
    "name": "Ndona",
    "lat": "-8.8338",
    "lng": "121.6862"
  },
  {
    "country": "ID",
    "name": "Wolowona",
    "lat": "-8.8322",
    "lng": "121.6765"
  },
  {
    "country": "ID",
    "name": "Maurole",
    "lat": "-8.511",
    "lng": "121.8023"
  },
  {
    "country": "ID",
    "name": "Mantang",
    "lat": "-8.6155",
    "lng": "116.3137"
  },
  {
    "country": "ID",
    "name": "Sumberrejo",
    "lat": "-8.1868",
    "lng": "113.0718"
  },
  {
    "country": "ID",
    "name": "Rowokangkung",
    "lat": "-8.1945",
    "lng": "113.3297"
  },
  {
    "country": "ID",
    "name": "Sebaren",
    "lat": "-8.2371",
    "lng": "113.3493"
  },
  {
    "country": "ID",
    "name": "Kebonsari",
    "lat": "-8.21098",
    "lng": "113.1702"
  },
  {
    "country": "ID",
    "name": "Kebonan",
    "lat": "-8.2162",
    "lng": "113.2283"
  },
  {
    "country": "ID",
    "name": "Sulahan",
    "lat": "-8.421",
    "lng": "115.3479"
  },
  {
    "country": "ID",
    "name": "Karang Daye",
    "lat": "-8.7448",
    "lng": "116.2413"
  },
  {
    "country": "ID",
    "name": "Kotabaru",
    "lat": "-8.5104",
    "lng": "121.9911"
  },
  {
    "country": "ID",
    "name": "Naru",
    "lat": "-8.572",
    "lng": "118.9929"
  },
  {
    "country": "ID",
    "name": "Donggo",
    "lat": "-8.4247",
    "lng": "118.5952"
  },
  {
    "country": "ID",
    "name": "Tawali",
    "lat": "-8.3407",
    "lng": "118.9145"
  },
  {
    "country": "ID",
    "name": "Tangratte",
    "lat": "-3.0497",
    "lng": "119.7643"
  },
  {
    "country": "ID",
    "name": "Totumbang",
    "lat": "-3.0779",
    "lng": "119.9211"
  },
  {
    "country": "ID",
    "name": "Nggongi",
    "lat": "-10.1944",
    "lng": "120.2336"
  },
  {
    "country": "ID",
    "name": "Malahar",
    "lat": "-9.9492",
    "lng": "120.0719"
  },
  {
    "country": "ID",
    "name": "Tempurejo",
    "lat": "-8.2994",
    "lng": "113.6793"
  },
  {
    "country": "ID",
    "name": "Kalianyar Selatan",
    "lat": "-8.0152",
    "lng": "113.8291"
  },
  {
    "country": "ID",
    "name": "Busungbiu",
    "lat": "-8.2565",
    "lng": "114.9672"
  },
  {
    "country": "ID",
    "name": "Sikur",
    "lat": "-8.6331",
    "lng": "116.4463"
  },
  {
    "country": "ID",
    "name": "Terara",
    "lat": "-8.6409",
    "lng": "116.411"
  },
  {
    "country": "ID",
    "name": "Janapria",
    "lat": "-8.6952",
    "lng": "116.4015"
  },
  {
    "country": "ID",
    "name": "Kabukarudi",
    "lat": "-9.7246",
    "lng": "119.3596"
  },
  {
    "country": "ID",
    "name": "Allu",
    "lat": "-3.4247",
    "lng": "118.9912"
  },
  {
    "country": "ID",
    "name": "Petoosang",
    "lat": "-3.4277",
    "lng": "118.9906"
  },
  {
    "country": "ID",
    "name": "Iteng",
    "lat": "-8.812",
    "lng": "120.4219"
  },
  {
    "country": "ID",
    "name": "Detung",
    "lat": "-8.664",
    "lng": "122.2157"
  },
  {
    "country": "ID",
    "name": "Onan Ganjang Satu",
    "lat": "2.1589",
    "lng": "98.63044"
  },
  {
    "country": "ID",
    "name": "Anyar",
    "lat": "-8.2301",
    "lng": "116.425"
  },
  {
    "country": "ID",
    "name": "Kotawaikabubak",
    "lat": "-9.6376",
    "lng": "119.4229"
  },
  {
    "country": "ID",
    "name": "Welamosa",
    "lat": "-8.6058",
    "lng": "121.71763"
  },
  {
    "country": "ID",
    "name": "Aelande",
    "lat": "-8.59565",
    "lng": "121.7252"
  },
  {
    "country": "ID",
    "name": "Ritapiret",
    "lat": "-8.6718",
    "lng": "122.1746"
  },
  {
    "country": "ID",
    "name": "Talibura",
    "lat": "-8.5246",
    "lng": "122.5255"
  },
  {
    "country": "ID",
    "name": "Boru",
    "lat": "-8.5252",
    "lng": "122.7108"
  },
  {
    "country": "ID",
    "name": "Dajan Tangluk",
    "lat": "-8.6458",
    "lng": "115.2389"
  },
  {
    "country": "ID",
    "name": "Karyadharma",
    "lat": "-8.7037",
    "lng": "115.2187"
  },
  {
    "country": "ID",
    "name": "Jabajero",
    "lat": "-8.72767",
    "lng": "115.17502"
  },
  {
    "country": "ID",
    "name": "Cempa Pasar",
    "lat": "-3.7486",
    "lng": "119.5842"
  },
  {
    "country": "ID",
    "name": "Pringgabaya",
    "lat": "-8.557",
    "lng": "116.6319"
  },
  {
    "country": "ID",
    "name": "Pekutatan",
    "lat": "-8.4207",
    "lng": "114.8228"
  },
  {
    "country": "ID",
    "name": "Lokokrangan",
    "lat": "-8.255",
    "lng": "116.2591"
  },
  {
    "country": "ID",
    "name": "Manola",
    "lat": "-9.5639",
    "lng": "119.2014"
  },
  {
    "country": "ID",
    "name": "Werang",
    "lat": "-8.6488",
    "lng": "120.0106"
  },
  {
    "country": "ID",
    "name": "Waelengga",
    "lat": "-8.8261",
    "lng": "120.8073"
  },
  {
    "country": "ID",
    "name": "Mataloko",
    "lat": "-8.8206",
    "lng": "121.063"
  },
  {
    "country": "ID",
    "name": "Toroloji",
    "lat": "-8.3582",
    "lng": "120.1693"
  },
  {
    "country": "ID",
    "name": "Sambelia",
    "lat": "-8.3791",
    "lng": "116.6869"
  },
  {
    "country": "ID",
    "name": "Bentengjawa",
    "lat": "-8.4569",
    "lng": "120.5722"
  },
  {
    "country": "ID",
    "name": "Waipare",
    "lat": "-8.6374",
    "lng": "122.2787"
  },
  {
    "country": "ID",
    "name": "Tamanan",
    "lat": "-8.0722",
    "lng": "111.9026"
  },
  {
    "country": "ID",
    "name": "Harapankarya",
    "lat": "-3.9893",
    "lng": "119.6438"
  },
  {
    "country": "ID",
    "name": "Belajen",
    "lat": "-3.3235",
    "lng": "119.8236"
  },
  {
    "country": "ID",
    "name": "Kamalaputi",
    "lat": "-9.6484",
    "lng": "120.2634"
  },
  {
    "country": "ID",
    "name": "Soa",
    "lat": "-8.6981",
    "lng": "121.0361"
  },
  {
    "country": "ID",
    "name": "Mbay",
    "lat": "-8.5613",
    "lng": "121.2717"
  },
  {
    "country": "ID",
    "name": "Senggapi",
    "lat": "-8.298",
    "lng": "120.4623"
  },
  {
    "country": "ID",
    "name": "Detusoko",
    "lat": "-8.7166",
    "lng": "121.7609"
  },
  {
    "country": "ID",
    "name": "Bandaragung",
    "lat": "-5.29229",
    "lng": "105.69255"
  },
  {
    "country": "ID",
    "name": "Gadingrejo",
    "lat": "-5.37233",
    "lng": "105.06163"
  },
  {
    "country": "ID",
    "name": "Palas",
    "lat": "-5.65191",
    "lng": "105.68011"
  },
  {
    "country": "ID",
    "name": "Sidorejo",
    "lat": "-5.58471",
    "lng": "105.52364"
  },
  {
    "country": "ID",
    "name": "Pasuruan",
    "lat": "-5.7463",
    "lng": "105.67707"
  },
  {
    "country": "ID",
    "name": "Penengahan",
    "lat": "-5.7706",
    "lng": "105.6969"
  },
  {
    "country": "ID",
    "name": "Kedondong",
    "lat": "-5.46284",
    "lng": "105.0009"
  },
  {
    "country": "ID",
    "name": "Mulyosari",
    "lat": "-7.50735",
    "lng": "108.78593"
  },
  {
    "country": "ID",
    "name": "Harian",
    "lat": "2.5561",
    "lng": "98.6625"
  },
  {
    "country": "ID",
    "name": "Tuktuk Sonak",
    "lat": "2.6689",
    "lng": "98.8576"
  },
  {
    "country": "ID",
    "name": "Tigarunggu",
    "lat": "2.8965",
    "lng": "98.7226"
  },
  {
    "country": "ID",
    "name": "Sipintuangin",
    "lat": "2.8133",
    "lng": "98.7904"
  },
  {
    "country": "ID",
    "name": "Sarimatondang",
    "lat": "2.8641",
    "lng": "98.9155"
  },
  {
    "country": "ID",
    "name": "Pane Tongah",
    "lat": "2.9059",
    "lng": "98.9723"
  },
  {
    "country": "ID",
    "name": "Cigeulis",
    "lat": "-6.5876",
    "lng": "105.6924"
  },
  {
    "country": "ID",
    "name": "Warungbanten",
    "lat": "-6.8327",
    "lng": "106.3293"
  },
  {
    "country": "ID",
    "name": "Polos",
    "lat": "-6.7001",
    "lng": "105.6493"
  },
  {
    "country": "ID",
    "name": "Pasanggrahan",
    "lat": "-6.6052",
    "lng": "105.9045"
  },
  {
    "country": "ID",
    "name": "Panimbang",
    "lat": "-6.4943",
    "lng": "105.7961"
  },
  {
    "country": "ID",
    "name": "Sukacai",
    "lat": "-6.3487",
    "lng": "105.8667"
  },
  {
    "country": "ID",
    "name": "Gardutanjak",
    "lat": "-6.3133",
    "lng": "106.1013"
  },
  {
    "country": "ID",
    "name": "Kopibera",
    "lat": "-6.1548",
    "lng": "105.8734"
  },
  {
    "country": "ID",
    "name": "Sukamaju",
    "lat": "-6.7053",
    "lng": "106.0701"
  },
  {
    "country": "ID",
    "name": "Sajir",
    "lat": "-6.5068",
    "lng": "106.0858"
  },
  {
    "country": "ID",
    "name": "Pasirgeleng",
    "lat": "-6.80253",
    "lng": "106.01285"
  },
  {
    "country": "ID",
    "name": "Gili Trawangan",
    "lat": "-8.34897",
    "lng": "116.037"
  },
  {
    "country": "ID",
    "name": "Sumandang",
    "lat": "-6.5068",
    "lng": "106.329"
  },
  {
    "country": "ID",
    "name": "Buniasih",
    "lat": "-7.4229",
    "lng": "106.7226"
  },
  {
    "country": "ID",
    "name": "Cisiih",
    "lat": "-6.90665",
    "lng": "106.19112"
  },
  {
    "country": "ID",
    "name": "Ciwaru",
    "lat": "-6.93272",
    "lng": "106.24502"
  },
  {
    "country": "ID",
    "name": "Sinarjaya",
    "lat": "-7.3047",
    "lng": "106.8353"
  },
  {
    "country": "ID",
    "name": "Sukarama",
    "lat": "-7.3738",
    "lng": "106.9822"
  },
  {
    "country": "ID",
    "name": "Kertajadi",
    "lat": "-7.4876",
    "lng": "107.3466"
  },
  {
    "country": "ID",
    "name": "Puncaktugu",
    "lat": "-7.2053",
    "lng": "106.8337"
  },
  {
    "country": "ID",
    "name": "Sindangratu",
    "lat": "-7.4651",
    "lng": "107.6718"
  },
  {
    "country": "ID",
    "name": "Cibungur",
    "lat": "-7.2913",
    "lng": "107.5324"
  },
  {
    "country": "ID",
    "name": "Sukoharjo Satu",
    "lat": "-5.30094",
    "lng": "104.98329"
  },
  {
    "country": "ID",
    "name": "Kuripan",
    "lat": "-5.03546",
    "lng": "103.7642"
  },
  {
    "country": "ID",
    "name": "Kalirejo",
    "lat": "-5.22582",
    "lng": "104.96131"
  },
  {
    "country": "ID",
    "name": "Pulaupanggung",
    "lat": "-5.31812",
    "lng": "104.74152"
  },
  {
    "country": "ID",
    "name": "Kota Ternate",
    "lat": "0.78333",
    "lng": "127.36667"
  },
  {
    "country": "ID",
    "name": "Gudang",
    "lat": "-7.307",
    "lng": "107.7967"
  },
  {
    "country": "ID",
    "name": "Kebonkai",
    "lat": "-7.5025",
    "lng": "107.967"
  },
  {
    "country": "ID",
    "name": "Parabon",
    "lat": "-7.5351",
    "lng": "107.9207"
  },
  {
    "country": "ID",
    "name": "Cibitung",
    "lat": "-7.4831",
    "lng": "107.9233"
  },
  {
    "country": "ID",
    "name": "Pakuwon",
    "lat": "-7.2155",
    "lng": "107.9036"
  },
  {
    "country": "ID",
    "name": "Bunisari",
    "lat": "-7.0724",
    "lng": "107.9614"
  },
  {
    "country": "ID",
    "name": "Pasirluhur",
    "lat": "-7.104",
    "lng": "107.9546"
  },
  {
    "country": "ID",
    "name": "Gununglimbangan",
    "lat": "-7.1016",
    "lng": "107.9841"
  },
  {
    "country": "ID",
    "name": "Simpang",
    "lat": "-7.6231",
    "lng": "108.1064"
  },
  {
    "country": "ID",
    "name": "Tanjungjaya",
    "lat": "-7.3882",
    "lng": "108.1215"
  },
  {
    "country": "ID",
    "name": "Jayapura",
    "lat": "-7.352",
    "lng": "108.0322"
  },
  {
    "country": "ID",
    "name": "Arjasari",
    "lat": "-7.3367",
    "lng": "108.1011"
  },
  {
    "country": "ID",
    "name": "Sukamaju Kidul",
    "lat": "-7.2831",
    "lng": "108.1867"
  },
  {
    "country": "ID",
    "name": "Argasari",
    "lat": "-7.3247",
    "lng": "108.2057"
  },
  {
    "country": "ID",
    "name": "Nagarasari",
    "lat": "-7.3003",
    "lng": "108.2213"
  },
  {
    "country": "ID",
    "name": "Kahuripan",
    "lat": "-7.3471",
    "lng": "108.2281"
  },
  {
    "country": "ID",
    "name": "Sindangtamu",
    "lat": "-7.1429",
    "lng": "108.1483"
  },
  {
    "country": "ID",
    "name": "Sukaraja",
    "lat": "-7.1466",
    "lng": "108.214"
  },
  {
    "country": "ID",
    "name": "Jamanis",
    "lat": "-7.1894",
    "lng": "108.1836"
  },
  {
    "country": "ID",
    "name": "Cibongas",
    "lat": "-7.6593",
    "lng": "108.2721"
  },
  {
    "country": "ID",
    "name": "Ciriri",
    "lat": "-7.4087",
    "lng": "108.3595"
  },
  {
    "country": "ID",
    "name": "Cibitung",
    "lat": "-7.3335",
    "lng": "108.3629"
  },
  {
    "country": "ID",
    "name": "Cigugur",
    "lat": "-7.6347",
    "lng": "108.4203"
  },
  {
    "country": "ID",
    "name": "Limusnunggal",
    "lat": "-7.5039",
    "lng": "108.4022"
  },
  {
    "country": "ID",
    "name": "Sukadana",
    "lat": "-7.2655",
    "lng": "108.4403"
  },
  {
    "country": "ID",
    "name": "Hegarsari",
    "lat": "-7.3859",
    "lng": "108.5394"
  },
  {
    "country": "ID",
    "name": "Ngulakan",
    "lat": "-6.7761",
    "lng": "111.2248"
  },
  {
    "country": "ID",
    "name": "Bantengan",
    "lat": "-6.6597",
    "lng": "111.0634"
  },
  {
    "country": "ID",
    "name": "Cipadung Timur",
    "lat": "-7.3594",
    "lng": "108.5414"
  },
  {
    "country": "ID",
    "name": "Rembang",
    "lat": "-6.707",
    "lng": "111.3498"
  },
  {
    "country": "ID",
    "name": "Sidowayah Kidul",
    "lat": "-6.7202",
    "lng": "111.347"
  },
  {
    "country": "ID",
    "name": "Pananjung",
    "lat": "-7.6826",
    "lng": "108.6503"
  },
  {
    "country": "ID",
    "name": "Bangkle",
    "lat": "-6.9706",
    "lng": "111.4307"
  },
  {
    "country": "ID",
    "name": "Sinargalih",
    "lat": "-7.3574",
    "lng": "108.6382"
  },
  {
    "country": "ID",
    "name": "Jetis",
    "lat": "-6.9122",
    "lng": "111.6263"
  },
  {
    "country": "ID",
    "name": "Jamong",
    "lat": "-6.8016",
    "lng": "111.8552"
  },
  {
    "country": "ID",
    "name": "Latsari",
    "lat": "-6.8928",
    "lng": "112.0461"
  },
  {
    "country": "ID",
    "name": "Gedongombo",
    "lat": "-6.9094",
    "lng": "112.0647"
  },
  {
    "country": "ID",
    "name": "Bejagung Kidul",
    "lat": "-6.9205",
    "lng": "112.0636"
  },
  {
    "country": "ID",
    "name": "Bakung",
    "lat": "-8.2588",
    "lng": "112.0726"
  },
  {
    "country": "ID",
    "name": "Wates",
    "lat": "-8.2538",
    "lng": "112.3763"
  },
  {
    "country": "ID",
    "name": "Banjaranyar",
    "lat": "-6.9013",
    "lng": "112.1538"
  },
  {
    "country": "ID",
    "name": "Solokuro",
    "lat": "-6.9334",
    "lng": "112.3561"
  },
  {
    "country": "ID",
    "name": "Prupuh",
    "lat": "-6.9127",
    "lng": "112.4578"
  },
  {
    "country": "ID",
    "name": "Gupakan",
    "lat": "-6.9997",
    "lng": "112.5089"
  },
  {
    "country": "ID",
    "name": "Sukorejo",
    "lat": "-8.2471",
    "lng": "111.3803"
  },
  {
    "country": "ID",
    "name": "Gedangan",
    "lat": "-8.2949",
    "lng": "112.6517"
  },
  {
    "country": "ID",
    "name": "Tempursari",
    "lat": "-8.2864",
    "lng": "112.9791"
  },
  {
    "country": "ID",
    "name": "Dawang",
    "lat": "-8.0353",
    "lng": "111.4145"
  },
  {
    "country": "ID",
    "name": "Kebonsari",
    "lat": "-8.2641",
    "lng": "113.4477"
  },
  {
    "country": "ID",
    "name": "Krajan A Wonorejo",
    "lat": "-8.2864",
    "lng": "113.3819"
  },
  {
    "country": "ID",
    "name": "Kebonan",
    "lat": "-8.3122",
    "lng": "113.4079"
  },
  {
    "country": "ID",
    "name": "Sumberan",
    "lat": "-8.3426",
    "lng": "113.606"
  },
  {
    "country": "ID",
    "name": "Bangsalsari",
    "lat": "-8.2029",
    "lng": "113.5346"
  },
  {
    "country": "ID",
    "name": "City of Balikpapan",
    "lat": "-1.24204",
    "lng": "116.89419"
  },
  {
    "country": "ID",
    "name": "Pasirpanjang",
    "lat": "1.12595",
    "lng": "103.35005"
  },
  {
    "country": "ID",
    "name": "Tebing",
    "lat": "1.03211",
    "lng": "103.42071"
  },
  {
    "country": "ID",
    "name": "Sekotong Tengah",
    "lat": "-8.7782",
    "lng": "116.0485"
  },
  {
    "country": "ID",
    "name": "Tlogowungu",
    "lat": "-6.70685",
    "lng": "111.01411"
  },
  {
    "country": "ID",
    "name": "Lakbok",
    "lat": "-7.404",
    "lng": "108.6573"
  },
  {
    "country": "ID",
    "name": "Dibee",
    "lat": "-6.9996",
    "lng": "112.3896"
  },
  {
    "country": "ID",
    "name": "Glagahwero",
    "lat": "-8.177",
    "lng": "113.6188"
  },
  {
    "country": "ID",
    "name": "Siliragung",
    "lat": "-8.5574",
    "lng": "114.112"
  },
  {
    "country": "ID",
    "name": "Prigi",
    "lat": "-8.2721",
    "lng": "111.7151"
  },
  {
    "country": "ID",
    "name": "Sumbergedong",
    "lat": "-8.0525",
    "lng": "111.7078"
  },
  {
    "country": "ID",
    "name": "Bendo",
    "lat": "-8.0946",
    "lng": "111.744"
  },
  {
    "country": "ID",
    "name": "Larangan",
    "lat": "-7.12875",
    "lng": "113.54702"
  },
  {
    "country": "ID",
    "name": "Woja",
    "lat": "-8.6366",
    "lng": "118.3542"
  },
  {
    "country": "ID",
    "name": "Pakel",
    "lat": "-8.0018",
    "lng": "111.9063"
  },
  {
    "country": "ID",
    "name": "Pucanglaban",
    "lat": "-8.2626",
    "lng": "112.0153"
  },
  {
    "country": "ID",
    "name": "Muaradua",
    "lat": "-4.11768",
    "lng": "103.6121"
  },
  {
    "country": "ID",
    "name": "Bara Datu",
    "lat": "-4.74423",
    "lng": "104.4964"
  },
  {
    "country": "ID",
    "name": "Oganlima",
    "lat": "-4.86736",
    "lng": "104.70308"
  },
  {
    "country": "ID",
    "name": "Umbulan Kapiak",
    "lat": "-4.83438",
    "lng": "104.52867"
  },
  {
    "country": "ID",
    "name": "Ledeunu",
    "lat": "-10.6058",
    "lng": "121.6106"
  },
  {
    "country": "ID",
    "name": "Loboae",
    "lat": "-10.5048",
    "lng": "121.828"
  },
  {
    "country": "ID",
    "name": "Bolou",
    "lat": "-10.4979",
    "lng": "121.9733"
  },
  {
    "country": "ID",
    "name": "Pragaan",
    "lat": "-7.1109",
    "lng": "113.66"
  },
  {
    "country": "ID",
    "name": "Batutua",
    "lat": "-10.8593",
    "lng": "122.9843"
  },
  {
    "country": "ID",
    "name": "Busalangga",
    "lat": "-10.804",
    "lng": "123.0035"
  },
  {
    "country": "ID",
    "name": "Likioen",
    "lat": "-10.7484",
    "lng": "123.0446"
  },
  {
    "country": "ID",
    "name": "Momanalu",
    "lat": "-10.6631",
    "lng": "123.1415"
  },
  {
    "country": "ID",
    "name": "Talango",
    "lat": "-7.063",
    "lng": "113.9507"
  },
  {
    "country": "ID",
    "name": "Batakte",
    "lat": "-10.2559",
    "lng": "123.5566"
  },
  {
    "country": "ID",
    "name": "Uitao",
    "lat": "-10.1907",
    "lng": "123.4073"
  },
  {
    "country": "ID",
    "name": "Oebobo",
    "lat": "-10.1678",
    "lng": "123.5992"
  },
  {
    "country": "ID",
    "name": "Tarus",
    "lat": "-10.1329",
    "lng": "123.6878"
  },
  {
    "country": "ID",
    "name": "Takari",
    "lat": "-9.9727",
    "lng": "124.0469"
  },
  {
    "country": "ID",
    "name": "Neonmat",
    "lat": "-9.8757",
    "lng": "124.3317"
  },
  {
    "country": "ID",
    "name": "Siso",
    "lat": "-9.8719",
    "lng": "124.2209"
  },
  {
    "country": "ID",
    "name": "Oekamusa",
    "lat": "-9.8747",
    "lng": "124.3064"
  },
  {
    "country": "ID",
    "name": "Polen",
    "lat": "-9.687",
    "lng": "124.4804"
  },
  {
    "country": "ID",
    "name": "Oeekam",
    "lat": "-9.7087",
    "lng": "124.5886"
  },
  {
    "country": "ID",
    "name": "Eban",
    "lat": "-9.5541",
    "lng": "124.3242"
  },
  {
    "country": "ID",
    "name": "Panite",
    "lat": "-10.0703",
    "lng": "124.2284"
  },
  {
    "country": "ID",
    "name": "Kuanfatu",
    "lat": "-10.0236",
    "lng": "124.448"
  },
  {
    "country": "ID",
    "name": "Kie",
    "lat": "-9.8448",
    "lng": "124.5481"
  },
  {
    "country": "ID",
    "name": "Oinlasi",
    "lat": "-9.8499",
    "lng": "124.5744"
  },
  {
    "country": "ID",
    "name": "Ayotupas",
    "lat": "-9.6971",
    "lng": "124.7076"
  },
  {
    "country": "ID",
    "name": "Biudukfoho",
    "lat": "-9.6066",
    "lng": "124.7395"
  },
  {
    "country": "ID",
    "name": "Maritaing",
    "lat": "-8.2907",
    "lng": "125.1242"
  },
  {
    "country": "ID",
    "name": "Kemang",
    "lat": "-8.1658",
    "lng": "124.7548"
  },
  {
    "country": "ID",
    "name": "Mainang",
    "lat": "-8.2831",
    "lng": "124.6254"
  },
  {
    "country": "ID",
    "name": "Apui",
    "lat": "-8.2732",
    "lng": "124.7231"
  },
  {
    "country": "ID",
    "name": "Moru",
    "lat": "-8.2568",
    "lng": "124.5155"
  },
  {
    "country": "ID",
    "name": "Kampungraja",
    "lat": "-8.216",
    "lng": "124.5175"
  },
  {
    "country": "ID",
    "name": "Wairiang",
    "lat": "-8.1921",
    "lng": "123.8187"
  },
  {
    "country": "ID",
    "name": "Watugolok",
    "lat": "-8.4382",
    "lng": "123.4734"
  },
  {
    "country": "ID",
    "name": "Waiwadan",
    "lat": "-8.2763",
    "lng": "123.0928"
  },
  {
    "country": "ID",
    "name": "Senadan",
    "lat": "-8.3855",
    "lng": "123.2579"
  },
  {
    "country": "ID",
    "name": "Loang",
    "lat": "-8.471",
    "lng": "123.2849"
  },
  {
    "country": "ID",
    "name": "Klubagolit",
    "lat": "-8.298",
    "lng": "123.2284"
  },
  {
    "country": "ID",
    "name": "Baniona",
    "lat": "-8.4",
    "lng": "123.0848"
  },
  {
    "country": "ID",
    "name": "Menanga",
    "lat": "-8.436",
    "lng": "123.0868"
  },
  {
    "country": "ID",
    "name": "Ritaebang",
    "lat": "-8.5308",
    "lng": "122.8836"
  },
  {
    "country": "ID",
    "name": "Data Dian",
    "lat": "2.01651",
    "lng": "115.25869"
  },
  {
    "country": "ID",
    "name": "Samalantan",
    "lat": "0.7927",
    "lng": "109.19669"
  },
  {
    "country": "ID",
    "name": "Rundeng",
    "lat": "2.68554",
    "lng": "97.83494"
  },
  {
    "country": "ID",
    "name": "Rantau Prapat",
    "lat": "2.3321",
    "lng": "100.05205"
  },
  {
    "country": "ID",
    "name": "Waiklibang",
    "lat": "-8.1745",
    "lng": "122.8955"
  },
  {
    "country": "ID",
    "name": "Uwa",
    "lat": "-8.297",
    "lng": "121.7258"
  },
  {
    "country": "ID",
    "name": "Rambangaru",
    "lat": "-9.4499",
    "lng": "120.0524"
  },
  {
    "country": "ID",
    "name": "Ngalu",
    "lat": "-10.1453",
    "lng": "120.7084"
  },
  {
    "country": "ID",
    "name": "Pekan Bahapal",
    "lat": "3.11313",
    "lng": "99.17352"
  },
  {
    "country": "ID",
    "name": "Mandarahan",
    "lat": "-1.7961",
    "lng": "100.8295"
  },
  {
    "country": "ID",
    "name": "Rantauambacang",
    "lat": "-1.3978",
    "lng": "101.9202"
  },
  {
    "country": "ID",
    "name": "Siulakderasmudik",
    "lat": "-1.9067",
    "lng": "101.2303"
  },
  {
    "country": "ID",
    "name": "Senayan",
    "lat": "-8.6127",
    "lng": "116.8505"
  },
  {
    "country": "ID",
    "name": "Tanjung Lubuk",
    "lat": "-3.3599",
    "lng": "104.8429"
  },
  {
    "country": "ID",
    "name": "Negeriagung",
    "lat": "-3.7673",
    "lng": "103.6516"
  },
  {
    "country": "ID",
    "name": "Waghete",
    "lat": "-4.03901",
    "lng": "136.27489"
  },
  {
    "country": "ID",
    "name": "Eci",
    "lat": "-6.12382",
    "lng": "139.15365"
  },
  {
    "country": "ID",
    "name": "Getentiri",
    "lat": "-6.58887",
    "lng": "140.34613"
  },
  {
    "country": "ID",
    "name": "Muting",
    "lat": "-7.30759",
    "lng": "140.55782"
  },
  {
    "country": "ID",
    "name": "Mindiptana",
    "lat": "-5.86386",
    "lng": "140.69253"
  },
  {
    "country": "ID",
    "name": "Warmare",
    "lat": "-1.1143",
    "lng": "133.9361"
  },
  {
    "country": "ID",
    "name": "Kebar",
    "lat": "-0.8474",
    "lng": "133.1457"
  },
  {
    "country": "ID",
    "name": "Bomomani",
    "lat": "-4.0659",
    "lng": "135.8182"
  },
  {
    "country": "ID",
    "name": "Merdey",
    "lat": "-1.6623",
    "lng": "133.3485"
  },
  {
    "country": "ID",
    "name": "Bofuer",
    "lat": "-3.0114",
    "lng": "133.7626"
  },
  {
    "country": "ID",
    "name": "Topo",
    "lat": "-3.5403",
    "lng": "135.5375"
  },
  {
    "country": "ID",
    "name": "Homeyo",
    "lat": "-3.663",
    "lng": "136.4692"
  },
  {
    "country": "ID",
    "name": "Kumopa",
    "lat": "-3.8216",
    "lng": "136.5092"
  },
  {
    "country": "ID",
    "name": "Moanemani",
    "lat": "-3.9679",
    "lng": "136.1116"
  },
  {
    "country": "ID",
    "name": "Bilogai",
    "lat": "-3.7181",
    "lng": "136.6683"
  },
  {
    "country": "ID",
    "name": "Beoga",
    "lat": "-3.8395",
    "lng": "137.1667"
  },
  {
    "country": "ID",
    "name": "Trimuris",
    "lat": "-1.9582",
    "lng": "137.8366"
  },
  {
    "country": "ID",
    "name": "Arbais",
    "lat": "-1.7393",
    "lng": "138.4043"
  },
  {
    "country": "ID",
    "name": "Samanente",
    "lat": "-2.1992",
    "lng": "138.8803"
  },
  {
    "country": "ID",
    "name": "Guay",
    "lat": "-2.5033",
    "lng": "139.8099"
  },
  {
    "country": "ID",
    "name": "Banda",
    "lat": "-3.1796",
    "lng": "140.9419"
  },
  {
    "country": "ID",
    "name": "Wurigelebur",
    "lat": "-3.7627",
    "lng": "138.8085"
  },
  {
    "country": "ID",
    "name": "Karubaga",
    "lat": "-3.6994",
    "lng": "138.4579"
  },
  {
    "country": "ID",
    "name": "Sawoi",
    "lat": "-2.6246",
    "lng": "140.3356"
  },
  {
    "country": "ID",
    "name": "Sumberan",
    "lat": "-8.4003",
    "lng": "114.2681"
  },
  {
    "country": "ID",
    "name": "Kota Agung",
    "lat": "-5.50257",
    "lng": "104.64538"
  },
  {
    "country": "ID",
    "name": "Pulosari",
    "lat": "-7.0091",
    "lng": "108.0174"
  },
  {
    "country": "ID",
    "name": "Gondang",
    "lat": "-8.0462",
    "lng": "111.6566"
  },
  {
    "country": "ID",
    "name": "Kokop",
    "lat": "-6.9425",
    "lng": "113.0303"
  },
  {
    "country": "ID",
    "name": "Bontang Baru",
    "lat": "0.1194",
    "lng": "117.4866"
  },
  {
    "country": "ID",
    "name": "Larantuka",
    "lat": "-8.3272",
    "lng": "123.0023"
  },
  {
    "country": "ID",
    "name": "Wasior",
    "lat": "-2.6423",
    "lng": "134.4883"
  },
  {
    "country": "ID",
    "name": "Pulau Punjung",
    "lat": "-0.959",
    "lng": "101.5002"
  },
  {
    "country": "ID",
    "name": "Teluk Pinang",
    "lat": "-0.18198",
    "lng": "103.35893"
  },
  {
    "country": "ID",
    "name": "Suak Bakung",
    "lat": "3.0056",
    "lng": "97.36455"
  },
  {
    "country": "ID",
    "name": "Paya Dapur",
    "lat": "3.20984",
    "lng": "97.41768"
  },
  {
    "country": "ID",
    "name": "Labuhan Bajau",
    "lat": "2.40119",
    "lng": "96.45516"
  },
  {
    "country": "ID",
    "name": "Luan Balu",
    "lat": "2.52582",
    "lng": "96.33172"
  },
  {
    "country": "ID",
    "name": "Lauke",
    "lat": "2.584",
    "lng": "96.04142"
  },
  {
    "country": "ID",
    "name": "Kuala Baru",
    "lat": "2.24731",
    "lng": "97.78697"
  },
  {
    "country": "ID",
    "name": "Rimo",
    "lat": "2.35944",
    "lng": "97.96083"
  },
  {
    "country": "ID",
    "name": "Danauparis",
    "lat": "2.41096",
    "lng": "98.08537"
  },
  {
    "country": "ID",
    "name": "Pulo Batal",
    "lat": "2.22532",
    "lng": "97.23413"
  },
  {
    "country": "ID",
    "name": "Pulopaya",
    "lat": "2.87349",
    "lng": "97.65178"
  },
  {
    "country": "ID",
    "name": "Pulo Ie",
    "lat": "3.28192",
    "lng": "97.35545"
  },
  {
    "country": "ID",
    "name": "Terbangan",
    "lat": "3.21546",
    "lng": "97.27163"
  },
  {
    "country": "ID",
    "name": "Tapaktuan",
    "lat": "3.28625",
    "lng": "97.16045"
  },
  {
    "country": "ID",
    "name": "Samadua",
    "lat": "3.3356",
    "lng": "97.13078"
  },
  {
    "country": "ID",
    "name": "Sawang",
    "lat": "3.40342",
    "lng": "97.1011"
  },
  {
    "country": "ID",
    "name": "Meukek",
    "lat": "3.47608",
    "lng": "97.06235"
  },
  {
    "country": "ID",
    "name": "Peuleumat",
    "lat": "3.52725",
    "lng": "97.03086"
  },
  {
    "country": "ID",
    "name": "Kota Trieng",
    "lat": "3.5984",
    "lng": "96.96243"
  },
  {
    "country": "ID",
    "name": "Mersak",
    "lat": "3.51416",
    "lng": "97.38209"
  },
  {
    "country": "ID",
    "name": "Seupakat",
    "lat": "3.64333",
    "lng": "97.46279"
  },
  {
    "country": "ID",
    "name": "Tanah Merah",
    "lat": "3.63221",
    "lng": "97.70234"
  },
  {
    "country": "ID",
    "name": "Kutacane",
    "lat": "3.52211",
    "lng": "97.79625"
  },
  {
    "country": "ID",
    "name": "Bambol",
    "lat": "3.44991",
    "lng": "97.87972"
  },
  {
    "country": "ID",
    "name": "Lawesigalagala Timur",
    "lat": "3.33222",
    "lng": "97.94212"
  },
  {
    "country": "ID",
    "name": "Ngkan",
    "lat": "3.40173",
    "lng": "97.66872"
  },
  {
    "country": "ID",
    "name": "Idi Rayeuk",
    "lat": "4.93037",
    "lng": "97.79129"
  },
  {
    "country": "ID",
    "name": "Idi Cut",
    "lat": "4.97797",
    "lng": "97.73198"
  },
  {
    "country": "ID",
    "name": "Bagok",
    "lat": "4.94707",
    "lng": "97.66519"
  },
  {
    "country": "ID",
    "name": "Beusa Seberang",
    "lat": "4.8738",
    "lng": "97.85708"
  },
  {
    "country": "ID",
    "name": "Sungai Raya",
    "lat": "4.76116",
    "lng": "97.91165"
  },
  {
    "country": "ID",
    "name": "Rantau Panjang",
    "lat": "4.72711",
    "lng": "97.75724"
  },
  {
    "country": "ID",
    "name": "Buket Teukuh",
    "lat": "4.80879",
    "lng": "97.65893"
  },
  {
    "country": "ID",
    "name": "Seuneubok Bayu",
    "lat": "4.87794",
    "lng": "97.57483"
  },
  {
    "country": "ID",
    "name": "Simpang Ulim",
    "lat": "5.12223",
    "lng": "97.5623"
  },
  {
    "country": "ID",
    "name": "Kota Binjai",
    "lat": "5.0469",
    "lng": "97.60903"
  },
  {
    "country": "ID",
    "name": "Luthu",
    "lat": "5.31351",
    "lng": "95.40294"
  },
  {
    "country": "ID",
    "name": "Indrapuri",
    "lat": "5.47704",
    "lng": "95.41736"
  },
  {
    "country": "ID",
    "name": "Angan",
    "lat": "5.60572",
    "lng": "95.39144"
  },
  {
    "country": "ID",
    "name": "Lampuuk",
    "lat": "5.57098",
    "lng": "95.38954"
  },
  {
    "country": "ID",
    "name": "Sibreh",
    "lat": "5.51863",
    "lng": "95.37336"
  },
  {
    "country": "ID",
    "name": "Mata Ie",
    "lat": "5.5278",
    "lng": "95.33473"
  },
  {
    "country": "ID",
    "name": "Keumala",
    "lat": "5.2493",
    "lng": "95.92382"
  },
  {
    "country": "ID",
    "name": "Geuleumpangminyeuk",
    "lat": "5.25",
    "lng": "96.02904"
  },
  {
    "country": "ID",
    "name": "Rusip",
    "lat": "4.66808",
    "lng": "96.60995"
  },
  {
    "country": "ID",
    "name": "Kute Panang",
    "lat": "4.65107",
    "lng": "96.73443"
  },
  {
    "country": "ID",
    "name": "Kemil",
    "lat": "4.62079",
    "lng": "96.75686"
  },
  {
    "country": "ID",
    "name": "Pegasing",
    "lat": "4.57669",
    "lng": "96.77592"
  },
  {
    "country": "ID",
    "name": "Kuala Bintang",
    "lat": "4.575",
    "lng": "96.96282"
  },
  {
    "country": "ID",
    "name": "Jagongjeget",
    "lat": "4.38727",
    "lng": "96.79298"
  },
  {
    "country": "ID",
    "name": "Banda Layung",
    "lat": "4.24161",
    "lng": "96.09695"
  },
  {
    "country": "ID",
    "name": "Keudee Aron",
    "lat": "4.2145",
    "lng": "96.17878"
  },
  {
    "country": "ID",
    "name": "Pantai Ceuremen",
    "lat": "4.36901",
    "lng": "96.19555"
  },
  {
    "country": "ID",
    "name": "Uleeglee",
    "lat": "5.19066",
    "lng": "96.34875"
  },
  {
    "country": "ID",
    "name": "Jumpangdua",
    "lat": "5.19669",
    "lng": "96.78445"
  },
  {
    "country": "ID",
    "name": "Cot Baroh",
    "lat": "5.21554",
    "lng": "96.84084"
  },
  {
    "country": "ID",
    "name": "Adil Makmur",
    "lat": "5.19843",
    "lng": "96.87015"
  },
  {
    "country": "ID",
    "name": "Juli",
    "lat": "5.10782",
    "lng": "96.71058"
  },
  {
    "country": "ID",
    "name": "Alue Glumpang",
    "lat": "5.07942",
    "lng": "96.76486"
  },
  {
    "country": "ID",
    "name": "Blang Ara",
    "lat": "4.28175",
    "lng": "96.37087"
  },
  {
    "country": "ID",
    "name": "Beutong Ateuh",
    "lat": "4.25129",
    "lng": "96.43726"
  },
  {
    "country": "ID",
    "name": "Alue Bilie",
    "lat": "4.00526",
    "lng": "96.56028"
  },
  {
    "country": "ID",
    "name": "Suka Makmue",
    "lat": "4.00312",
    "lng": "96.61762"
  },
  {
    "country": "ID",
    "name": "Blang Mane",
    "lat": "5.0174",
    "lng": "96.77214"
  },
  {
    "country": "ID",
    "name": "Kalde Panga",
    "lat": "4.5557",
    "lng": "95.71508"
  },
  {
    "country": "ID",
    "name": "Lageun",
    "lat": "4.69361",
    "lng": "95.53032"
  },
  {
    "country": "ID",
    "name": "Blang Dalam",
    "lat": "4.89615",
    "lng": "95.61974"
  },
  {
    "country": "ID",
    "name": "Kajeung",
    "lat": "4.51385",
    "lng": "96.13244"
  },
  {
    "country": "ID",
    "name": "Peukanbada",
    "lat": "5.53606",
    "lng": "95.2284"
  },
  {
    "country": "ID",
    "name": "Jantho",
    "lat": "5.3334",
    "lng": "95.61336"
  },
  {
    "country": "ID",
    "name": "Geumpang",
    "lat": "4.82876",
    "lng": "96.16073"
  },
  {
    "country": "ID",
    "name": "Mane",
    "lat": "4.93789",
    "lng": "96.0063"
  },
  {
    "country": "ID",
    "name": "Tiro",
    "lat": "5.19196",
    "lng": "95.93666"
  },
  {
    "country": "ID",
    "name": "Lampoih",
    "lat": "5.3178",
    "lng": "95.98628"
  },
  {
    "country": "ID",
    "name": "Caloue",
    "lat": "5.31494",
    "lng": "95.9706"
  },
  {
    "country": "ID",
    "name": "Matangkuli",
    "lat": "5.03198",
    "lng": "97.28351"
  },
  {
    "country": "ID",
    "name": "Matangpayang",
    "lat": "5.12577",
    "lng": "97.24949"
  },
  {
    "country": "ID",
    "name": "Seunudon",
    "lat": "5.20864",
    "lng": "97.44889"
  },
  {
    "country": "ID",
    "name": "Bulahblangaro",
    "lat": "5.08626",
    "lng": "96.85273"
  },
  {
    "country": "ID",
    "name": "Blang Ara",
    "lat": "5.11088",
    "lng": "97.02958"
  },
  {
    "country": "ID",
    "name": "Babah Rot",
    "lat": "3.9288",
    "lng": "96.68902"
  },
  {
    "country": "ID",
    "name": "Suek",
    "lat": "3.77495",
    "lng": "96.81779"
  },
  {
    "country": "ID",
    "name": "Kutapanjang",
    "lat": "4.03753",
    "lng": "97.2371"
  },
  {
    "country": "ID",
    "name": "Sangir",
    "lat": "3.88622",
    "lng": "97.52787"
  },
  {
    "country": "ID",
    "name": "Sungai Iyu",
    "lat": "4.40515",
    "lng": "98.13249"
  },
  {
    "country": "ID",
    "name": "Karangbaru",
    "lat": "4.30563",
    "lng": "98.02709"
  },
  {
    "country": "ID",
    "name": "Sungi Liput",
    "lat": "4.20737",
    "lng": "98.01275"
  },
  {
    "country": "ID",
    "name": "Tenggulun",
    "lat": "3.99131",
    "lng": "98.00705"
  },
  {
    "country": "ID",
    "name": "Pulau Tiga",
    "lat": "4.12685",
    "lng": "97.8776"
  },
  {
    "country": "ID",
    "name": "Simpang Teritit",
    "lat": "4.69707",
    "lng": "96.8567"
  },
  {
    "country": "ID",
    "name": "Ulee Gle",
    "lat": "5.20314",
    "lng": "96.3269"
  },
  {
    "country": "ID",
    "name": "Trienggadeng",
    "lat": "5.2402",
    "lng": "96.2018"
  },
  {
    "country": "ID",
    "name": "Pante Raja",
    "lat": "5.24525",
    "lng": "96.14624"
  },
  {
    "country": "ID",
    "name": "Lambaro",
    "lat": "5.55579",
    "lng": "95.34385"
  },
  {
    "country": "ID",
    "name": "Pasir Panjang",
    "lat": "2.67455",
    "lng": "98.00057"
  },
  {
    "country": "ID",
    "name": "Lawepakam",
    "lat": "3.30436",
    "lng": "97.96793"
  },
  {
    "country": "ID",
    "name": "Kuala Baru Sungai",
    "lat": "2.40779",
    "lng": "97.74047"
  },
  {
    "country": "ID",
    "name": "South Tangerang",
    "lat": "-6.28862",
    "lng": "106.71789"
  },
  {
    "country": "ID",
    "name": "Kotabahagia",
    "lat": "3.819",
    "lng": "96.7658"
  },
  {
    "country": "ID",
    "name": "Blangpulo",
    "lat": "5.2068",
    "lng": "97.07743"
  },
  {
    "country": "ID",
    "name": "Sarulla",
    "lat": "1.78596",
    "lng": "99.11375"
  },
  {
    "country": "ID",
    "name": "Long Peso",
    "lat": "2.69028",
    "lng": "116.7849"
  },
  {
    "country": "ID",
    "name": "Long Beluah",
    "lat": "2.75992",
    "lng": "117.08905"
  },
  {
    "country": "ID",
    "name": "Long Bang",
    "lat": "2.84792",
    "lng": "116.90454"
  },
  {
    "country": "ID",
    "name": "Sungai Nyamuk",
    "lat": "4.14383",
    "lng": "117.91087"
  },
  {
    "country": "ID",
    "name": "Binalawan",
    "lat": "4.09197",
    "lng": "117.77322"
  },
  {
    "country": "ID",
    "name": "Long Layu",
    "lat": "3.61023",
    "lng": "115.69993"
  },
  {
    "country": "ID",
    "name": "Sungaiboh",
    "lat": "1.63863",
    "lng": "115.23319"
  },
  {
    "country": "ID",
    "name": "Long Loreh",
    "lat": "3.1679",
    "lng": "116.47027"
  },
  {
    "country": "ID",
    "name": "Sekatak Bengara",
    "lat": "3.08757",
    "lng": "117.21345"
  },
  {
    "country": "ID",
    "name": "Tanjung Palas",
    "lat": "2.82988",
    "lng": "117.34255"
  },
  {
    "country": "ID",
    "name": "Kerangagung",
    "lat": "3.00123",
    "lng": "117.21714"
  },
  {
    "country": "ID",
    "name": "Kayan Hulu",
    "lat": "3.82572",
    "lng": "115.86671"
  },
  {
    "country": "ID",
    "name": "Pasarujungbatu",
    "lat": "1.03596",
    "lng": "99.9484"
  },
  {
    "country": "ID",
    "name": "Panyabungan",
    "lat": "1.93206",
    "lng": "99.69113"
  },
  {
    "country": "ID",
    "name": "Sipoholon",
    "lat": "2.0649",
    "lng": "98.9465"
  },
  {
    "country": "ID",
    "name": "Sampuran",
    "lat": "2.00848",
    "lng": "98.96658"
  },
  {
    "country": "ID",
    "name": "Sukarama",
    "lat": "2.6465",
    "lng": "98.3015"
  },
  {
    "country": "ID",
    "name": "Sumbul",
    "lat": "2.741",
    "lng": "98.3975"
  },
  {
    "country": "ID",
    "name": "Pulautemiang",
    "lat": "-1.22495",
    "lng": "102.24228"
  },
  {
    "country": "ID",
    "name": "Handilenam",
    "lat": "-0.8244",
    "lng": "117.2488"
  },
  {
    "country": "ID",
    "name": "Palaran",
    "lat": "-0.57119",
    "lng": "117.19568"
  },
  {
    "country": "ID",
    "name": "Batusopang",
    "lat": "-1.8236",
    "lng": "115.9126"
  },
  {
    "country": "ID",
    "name": "Awayan",
    "lat": "-2.4622",
    "lng": "115.6538"
  },
  {
    "country": "ID",
    "name": "Matangai",
    "lat": "-2.5825",
    "lng": "114.3728"
  },
  {
    "country": "ID",
    "name": "Jenamas",
    "lat": "-2.4464",
    "lng": "114.908"
  },
  {
    "country": "ID",
    "name": "Danaupanggang",
    "lat": "-2.4082",
    "lng": "115.0398"
  },
  {
    "country": "ID",
    "name": "Telagaselaba",
    "lat": "-2.3829",
    "lng": "115.3144"
  },
  {
    "country": "ID",
    "name": "Sungaiturak",
    "lat": "-2.3535",
    "lng": "115.3866"
  },
  {
    "country": "ID",
    "name": "Pasararba",
    "lat": "-2.2591",
    "lng": "115.3166"
  },
  {
    "country": "ID",
    "name": "Tanta",
    "lat": "-2.2285",
    "lng": "115.4522"
  },
  {
    "country": "ID",
    "name": "Tambarangan",
    "lat": "-3.0039",
    "lng": "115.1321"
  },
  {
    "country": "ID",
    "name": "Tapintengah",
    "lat": "-2.9564",
    "lng": "115.0372"
  },
  {
    "country": "ID",
    "name": "Margasari",
    "lat": "-2.8558",
    "lng": "115.0367"
  },
  {
    "country": "ID",
    "name": "Margasarihilir",
    "lat": "-2.8266",
    "lng": "115.0066"
  },
  {
    "country": "ID",
    "name": "Angkimang",
    "lat": "-2.7344",
    "lng": "115.3101"
  },
  {
    "country": "ID",
    "name": "Pasingkan",
    "lat": "-2.686",
    "lng": "115.2105"
  },
  {
    "country": "ID",
    "name": "Pendawanbaru",
    "lat": "-2.5303",
    "lng": "115.2418"
  },
  {
    "country": "ID",
    "name": "Sungaitatas",
    "lat": "-2.8353",
    "lng": "114.4887"
  },
  {
    "country": "ID",
    "name": "Bantul",
    "lat": "-3.0432",
    "lng": "114.7614"
  },
  {
    "country": "ID",
    "name": "Barimba",
    "lat": "-2.9418",
    "lng": "114.4427"
  },
  {
    "country": "ID",
    "name": "Anjirserapat",
    "lat": "-3.0391",
    "lng": "114.3845"
  },
  {
    "country": "ID",
    "name": "Basarang",
    "lat": "-2.9637",
    "lng": "114.2994"
  },
  {
    "country": "ID",
    "name": "Anjirmuara",
    "lat": "-3.1973",
    "lng": "114.5667"
  },
  {
    "country": "ID",
    "name": "Sungaigampa",
    "lat": "-3.0849",
    "lng": "114.6996"
  },
  {
    "country": "ID",
    "name": "Sungaipuntik",
    "lat": "-3.169",
    "lng": "114.683"
  },
  {
    "country": "ID",
    "name": "Sungaitabuk",
    "lat": "-3.2473",
    "lng": "114.7709"
  },
  {
    "country": "ID",
    "name": "Gambut",
    "lat": "-3.3961",
    "lng": "114.6752"
  },
  {
    "country": "ID",
    "name": "Astambul",
    "lat": "-3.3696",
    "lng": "114.9143"
  },
  {
    "country": "ID",
    "name": "Sungairaya",
    "lat": "-3.2864",
    "lng": "115.0561"
  },
  {
    "country": "ID",
    "name": "Kurau",
    "lat": "-3.5658",
    "lng": "114.5795"
  },
  {
    "country": "ID",
    "name": "Bakau",
    "lat": "-2.4105",
    "lng": "116.2387"
  },
  {
    "country": "ID",
    "name": "Pudi",
    "lat": "-2.8878",
    "lng": "116.3435"
  },
  {
    "country": "ID",
    "name": "Putatbasiun",
    "lat": "-2.4206",
    "lng": "115.5294"
  },
  {
    "country": "ID",
    "name": "Mungkuruyam",
    "lat": "-2.2668",
    "lng": "115.5759"
  },
  {
    "country": "ID",
    "name": "Halong",
    "lat": "-2.258",
    "lng": "115.6511"
  },
  {
    "country": "ID",
    "name": "Manunggulama",
    "lat": "-2.5142",
    "lng": "116.1656"
  },
  {
    "country": "ID",
    "name": "Binawara",
    "lat": "-3.4853",
    "lng": "115.7946"
  },
  {
    "country": "ID",
    "name": "Lontar",
    "lat": "-3.9751",
    "lng": "116.0698"
  },
  {
    "country": "ID",
    "name": "Allealle",
    "lat": "-3.9116",
    "lng": "116.3038"
  },
  {
    "country": "ID",
    "name": "Telagalangsat",
    "lat": "-2.7908",
    "lng": "115.5643"
  },
  {
    "country": "ID",
    "name": "Juai",
    "lat": "-2.3044",
    "lng": "115.5622"
  },
  {
    "country": "ID",
    "name": "Mapurujaya",
    "lat": "-4.6752",
    "lng": "136.8297"
  },
  {
    "country": "ID",
    "name": "Woha",
    "lat": "-8.61802",
    "lng": "118.64788"
  },
  {
    "country": "ID",
    "name": "Kuala Pembuang",
    "lat": "-3.39228",
    "lng": "112.55049"
  },
  {
    "country": "ID",
    "name": "Doom",
    "lat": "-0.88718",
    "lng": "131.23644"
  },
  {
    "country": "ID",
    "name": "Aifat",
    "lat": "-1.1664",
    "lng": "132.5015"
  },
  {
    "country": "ID",
    "name": "Masohi",
    "lat": "-3.29833",
    "lng": "128.96882"
  },
  {
    "country": "ID",
    "name": "Waipia",
    "lat": "-3.1878",
    "lng": "128.903"
  },
  {
    "country": "ID",
    "name": "Petani",
    "lat": "0.32884",
    "lng": "128.6527"
  },
  {
    "country": "ID",
    "name": "Buli",
    "lat": "0.68518",
    "lng": "128.2909"
  },
  {
    "country": "ID",
    "name": "Basiong",
    "lat": "0.77294",
    "lng": "127.37484"
  },
  {
    "country": "ID",
    "name": "Malifud",
    "lat": "0.36381",
    "lng": "127.42279"
  },
  {
    "country": "ID",
    "name": "Guruafin",
    "lat": "0.10144",
    "lng": "127.43402"
  },
  {
    "country": "ID",
    "name": "Dufa-Dufa",
    "lat": "-0.46182",
    "lng": "127.15"
  },
  {
    "country": "ID",
    "name": "Tungoo",
    "lat": "0.74692",
    "lng": "124.26106"
  },
  {
    "country": "ID",
    "name": "Teritip",
    "lat": "-1.83347",
    "lng": "105.36985"
  },
  {
    "country": "ID",
    "name": "Terentang",
    "lat": "-0.38233",
    "lng": "109.62098"
  },
  {
    "country": "ID",
    "name": "Batuampar",
    "lat": "-0.7385",
    "lng": "109.52454"
  },
  {
    "country": "ID",
    "name": "Kenyau",
    "lat": "-0.89477",
    "lng": "110.50382"
  },
  {
    "country": "ID",
    "name": "Pontianak Barat",
    "lat": "-0.01894",
    "lng": "109.31868"
  },
  {
    "country": "ID",
    "name": "Barikin",
    "lat": "-2.67986",
    "lng": "115.32503"
  },
  {
    "country": "ID",
    "name": "Loklaga",
    "lat": "-2.71244",
    "lng": "115.3728"
  },
  {
    "country": "ID",
    "name": "Senayang",
    "lat": "0.0375",
    "lng": "104.65444"
  },
  {
    "country": "ID",
    "name": "Matak",
    "lat": "3.34806",
    "lng": "106.29139"
  },
  {
    "country": "ID",
    "name": "Sabang Mawang Barat",
    "lat": "3.63306",
    "lng": "108.11333"
  },
  {
    "country": "ID",
    "name": "Cemaga",
    "lat": "3.78333",
    "lng": "108.36528"
  },
  {
    "country": "ID",
    "name": "Harapan Jaya",
    "lat": "3.87472",
    "lng": "108.30306"
  },
  {
    "country": "ID",
    "name": "Mangupura",
    "lat": "-8.54389",
    "lng": "115.17"
  },
  {
    "country": "ID",
    "name": "Tigaraksa",
    "lat": "-6.22806",
    "lng": "106.51389"
  },
  {
    "country": "ID",
    "name": "Tubei",
    "lat": "-3.11917",
    "lng": "102.2"
  },
  {
    "country": "ID",
    "name": "Karang Tinggi",
    "lat": "-3.75",
    "lng": "102.4225"
  },
  {
    "country": "ID",
    "name": "Pulau Pramuka",
    "lat": "-5.74583",
    "lng": "106.61389"
  },
  {
    "country": "ID",
    "name": "Suwawa",
    "lat": "0.5325",
    "lng": "123.14694"
  },
  {
    "country": "ID",
    "name": "Siulak",
    "lat": "-1.94667",
    "lng": "101.33417"
  },
  {
    "country": "ID",
    "name": "Batang",
    "lat": "-6.90778",
    "lng": "109.73028"
  },
  {
    "country": "ID",
    "name": "Ngasem",
    "lat": "-7.80583",
    "lng": "112.04083"
  },
  {
    "country": "ID",
    "name": "Sungai Raya",
    "lat": "-0.12694",
    "lng": "109.40389"
  },
  {
    "country": "ID",
    "name": "Sendawar",
    "lat": "-0.23639",
    "lng": "115.69472"
  },
  {
    "country": "ID",
    "name": "Bandar Seri Bentan",
    "lat": "1.05417",
    "lng": "104.48"
  },
  {
    "country": "ID",
    "name": "Wiralaga Mulya",
    "lat": "-3.84278",
    "lng": "105.49389"
  },
  {
    "country": "ID",
    "name": "Tiakur",
    "lat": "-8.15",
    "lng": "127.795"
  },
  {
    "country": "ID",
    "name": "Kigamani",
    "lat": "-3.96139",
    "lng": "135.94361"
  },
  {
    "country": "ID",
    "name": "Sugapa",
    "lat": "-3.74306",
    "lng": "137.05"
  },
  {
    "country": "ID",
    "name": "Burmeso",
    "lat": "-2.32611",
    "lng": "138.04139"
  },
  {
    "country": "ID",
    "name": "Kobakma",
    "lat": "-3.66417",
    "lng": "139.065"
  },
  {
    "country": "ID",
    "name": "Kenyam",
    "lat": "-4.59972",
    "lng": "138.38417"
  },
  {
    "country": "ID",
    "name": "Oksibil",
    "lat": "-4.90417",
    "lng": "140.62972"
  },
  {
    "country": "ID",
    "name": "Ilaga",
    "lat": "-3.95",
    "lng": "137.4"
  },
  {
    "country": "ID",
    "name": "Botawa",
    "lat": "-2.21",
    "lng": "136.44722"
  },
  {
    "country": "ID",
    "name": "Sumohai",
    "lat": "-4.68944",
    "lng": "139.35472"
  },
  {
    "country": "ID",
    "name": "Elelim",
    "lat": "-3.759",
    "lng": "139.7075"
  },
  {
    "country": "ID",
    "name": "Ullong",
    "lat": "-1.37083",
    "lng": "133.91306"
  },
  {
    "country": "ID",
    "name": "Aimas",
    "lat": "-0.95698",
    "lng": "131.33535"
  },
  {
    "country": "ID",
    "name": "Fef",
    "lat": "-0.80889",
    "lng": "132.43222"
  },
  {
    "country": "ID",
    "name": "Sigi Biromaru",
    "lat": "-0.94982",
    "lng": "119.91805"
  },
  {
    "country": "ID",
    "name": "Buranga",
    "lat": "-4.80098",
    "lng": "122.98308"
  },
  {
    "country": "ID",
    "name": "Laworo",
    "lat": "-4.78333",
    "lng": "122.52472"
  },
  {
    "country": "ID",
    "name": "Tuapejat",
    "lat": "-2.02833",
    "lng": "99.58944"
  },
  {
    "country": "ID",
    "name": "Arosuka",
    "lat": "-0.95221",
    "lng": "100.621"
  },
  {
    "country": "ID",
    "name": "Padang Aro",
    "lat": "-1.52722",
    "lng": "101.26361"
  },
  {
    "country": "ID",
    "name": "Lotu",
    "lat": "1.4299",
    "lng": "97.35365"
  },
  {
    "country": "ID",
    "name": "Labungkari",
    "lat": "-5.26318",
    "lng": "122.55104"
  },
  {
    "country": "ID",
    "name": "Jembrana Subdistrict",
    "lat": "-8.31492",
    "lng": "114.57586"
  },
  {
    "country": "ID",
    "name": "Seminyak town",
    "lat": "-8.68883",
    "lng": "115.15998"
  },
  {
    "country": "ID",
    "name": "Amlapura city",
    "lat": "-8.44869",
    "lng": "115.60621"
  },
  {
    "country": "IE",
    "name": "Buncrana",
    "lat": "55.13333",
    "lng": "-7.45"
  },
  {
    "country": "IE",
    "name": "Youghal",
    "lat": "51.95",
    "lng": "-7.85056"
  },
  {
    "country": "IE",
    "name": "Wicklow",
    "lat": "52.975",
    "lng": "-6.04944"
  },
  {
    "country": "IE",
    "name": "Whitegate",
    "lat": "51.83056",
    "lng": "-8.22972"
  },
  {
    "country": "IE",
    "name": "Loch Garman",
    "lat": "52.33417",
    "lng": "-6.4575"
  },
  {
    "country": "IE",
    "name": "Westport",
    "lat": "53.8",
    "lng": "-9.51667"
  },
  {
    "country": "IE",
    "name": "Watergrasshill",
    "lat": "52.01139",
    "lng": "-8.34417"
  },
  {
    "country": "IE",
    "name": "Waterford",
    "lat": "52.25833",
    "lng": "-7.11194"
  },
  {
    "country": "IE",
    "name": "Virginia",
    "lat": "53.83389",
    "lng": "-7.07556"
  },
  {
    "country": "IE",
    "name": "Tullyallen",
    "lat": "53.73611",
    "lng": "-6.42278"
  },
  {
    "country": "IE",
    "name": "Tullow",
    "lat": "52.80028",
    "lng": "-6.73694"
  },
  {
    "country": "IE",
    "name": "Tullamore",
    "lat": "53.27389",
    "lng": "-7.48889"
  },
  {
    "country": "IE",
    "name": "Tuam",
    "lat": "53.51667",
    "lng": "-8.85"
  },
  {
    "country": "IE",
    "name": "Trim",
    "lat": "53.555",
    "lng": "-6.79167"
  },
  {
    "country": "IE",
    "name": "Trá Mhór",
    "lat": "52.16235",
    "lng": "-7.15244"
  },
  {
    "country": "IE",
    "name": "Tralee",
    "lat": "52.27042",
    "lng": "-9.70264"
  },
  {
    "country": "IE",
    "name": "Tower",
    "lat": "51.92599",
    "lng": "-8.60747"
  },
  {
    "country": "IE",
    "name": "Tobercurry",
    "lat": "54.05",
    "lng": "-8.73333"
  },
  {
    "country": "IE",
    "name": "Tipperary",
    "lat": "52.47333",
    "lng": "-8.15583"
  },
  {
    "country": "IE",
    "name": "Thurles",
    "lat": "52.68194",
    "lng": "-7.80222"
  },
  {
    "country": "IE",
    "name": "Thomastown",
    "lat": "52.52667",
    "lng": "-7.13722"
  },
  {
    "country": "IE",
    "name": "Termonfeckin",
    "lat": "53.76333",
    "lng": "-6.26778"
  },
  {
    "country": "IE",
    "name": "Terenure",
    "lat": "53.30972",
    "lng": "-6.28528"
  },
  {
    "country": "IE",
    "name": "Templemore",
    "lat": "52.79472",
    "lng": "-7.83389"
  },
  {
    "country": "IE",
    "name": "Tallaght",
    "lat": "53.2859",
    "lng": "-6.37344"
  },
  {
    "country": "IE",
    "name": "Swords",
    "lat": "53.45972",
    "lng": "-6.21806"
  },
  {
    "country": "IE",
    "name": "Swinford",
    "lat": "53.95",
    "lng": "-8.95"
  },
  {
    "country": "IE",
    "name": "Sutton",
    "lat": "53.38947",
    "lng": "-6.11059"
  },
  {
    "country": "IE",
    "name": "Stradbally",
    "lat": "53.01556",
    "lng": "-7.15278"
  },
  {
    "country": "IE",
    "name": "Stamullin",
    "lat": "53.62889",
    "lng": "-6.26833"
  },
  {
    "country": "IE",
    "name": "Sligo",
    "lat": "54.26969",
    "lng": "-8.46943"
  },
  {
    "country": "IE",
    "name": "Slane",
    "lat": "53.71",
    "lng": "-6.54333"
  },
  {
    "country": "IE",
    "name": "Skibbereen",
    "lat": "51.55",
    "lng": "-9.26667"
  },
  {
    "country": "IE",
    "name": "Skerries",
    "lat": "53.58278",
    "lng": "-6.10833"
  },
  {
    "country": "IE",
    "name": "Sixmilebridge",
    "lat": "52.74139",
    "lng": "-8.77417"
  },
  {
    "country": "IE",
    "name": "Shankill",
    "lat": "53.22611",
    "lng": "-6.12444"
  },
  {
    "country": "IE",
    "name": "Sandymount",
    "lat": "53.335",
    "lng": "-6.21139"
  },
  {
    "country": "IE",
    "name": "Sallins",
    "lat": "53.24889",
    "lng": "-6.66611"
  },
  {
    "country": "IE",
    "name": "Saggart",
    "lat": "53.28028",
    "lng": "-6.44444"
  },
  {
    "country": "IE",
    "name": "An Ros",
    "lat": "53.52424",
    "lng": "-6.10497"
  },
  {
    "country": "IE",
    "name": "Rosslare",
    "lat": "52.27583",
    "lng": "-6.38444"
  },
  {
    "country": "IE",
    "name": "Roscrea",
    "lat": "52.95111",
    "lng": "-7.80167"
  },
  {
    "country": "IE",
    "name": "Roscommon",
    "lat": "53.63333",
    "lng": "-8.18333"
  },
  {
    "country": "IE",
    "name": "Rochfortbridge",
    "lat": "53.41417",
    "lng": "-7.29611"
  },
  {
    "country": "IE",
    "name": "Ringsend",
    "lat": "53.34194",
    "lng": "-6.22639"
  },
  {
    "country": "IE",
    "name": "Ratoath",
    "lat": "53.50806",
    "lng": "-6.4625"
  },
  {
    "country": "IE",
    "name": "Rathwire",
    "lat": "53.50767",
    "lng": "-7.1351"
  },
  {
    "country": "IE",
    "name": "Rathnew",
    "lat": "52.99056",
    "lng": "-6.08528"
  },
  {
    "country": "IE",
    "name": "Rathmines",
    "lat": "53.32028",
    "lng": "-6.26333"
  },
  {
    "country": "IE",
    "name": "Ramelton",
    "lat": "55.03673",
    "lng": "-7.64923"
  },
  {
    "country": "IE",
    "name": "Rathkeale",
    "lat": "52.52444",
    "lng": "-8.93806"
  },
  {
    "country": "IE",
    "name": "Rathdrum",
    "lat": "52.92639",
    "lng": "-6.23556"
  },
  {
    "country": "IE",
    "name": "Rathdowney",
    "lat": "52.85472",
    "lng": "-7.58028"
  },
  {
    "country": "IE",
    "name": "Rathcormac",
    "lat": "52.07694",
    "lng": "-8.28194"
  },
  {
    "country": "IE",
    "name": "Rathcoole",
    "lat": "53.28278",
    "lng": "-6.47278"
  },
  {
    "country": "IE",
    "name": "Rathangan",
    "lat": "53.22139",
    "lng": "-6.995"
  },
  {
    "country": "IE",
    "name": "Raphoe",
    "lat": "54.87472",
    "lng": "-7.59833"
  },
  {
    "country": "IE",
    "name": "Raheny",
    "lat": "53.38681",
    "lng": "-6.18067"
  },
  {
    "country": "IE",
    "name": "Prosperous",
    "lat": "53.29028",
    "lng": "-6.75389"
  },
  {
    "country": "IE",
    "name": "Portumna",
    "lat": "53.08917",
    "lng": "-8.21889"
  },
  {
    "country": "IE",
    "name": "Portmarnock",
    "lat": "53.42306",
    "lng": "-6.1375"
  },
  {
    "country": "IE",
    "name": "Portlaw",
    "lat": "52.28833",
    "lng": "-7.32056"
  },
  {
    "country": "IE",
    "name": "Portlaoise",
    "lat": "53.03441",
    "lng": "-7.29979"
  },
  {
    "country": "IE",
    "name": "Portarlington",
    "lat": "53.16222",
    "lng": "-7.19111"
  },
  {
    "country": "IE",
    "name": "Piltown",
    "lat": "52.35333",
    "lng": "-7.34028"
  },
  {
    "country": "IE",
    "name": "Daingean",
    "lat": "53.29611",
    "lng": "-7.28944"
  },
  {
    "country": "IE",
    "name": "Passage West",
    "lat": "51.87389",
    "lng": "-8.34444"
  },
  {
    "country": "IE",
    "name": "Oughterard",
    "lat": "53.41667",
    "lng": "-9.33333"
  },
  {
    "country": "IE",
    "name": "Oranmore",
    "lat": "53.26833",
    "lng": "-8.92"
  },
  {
    "country": "IE",
    "name": "Old Kilcullen",
    "lat": "53.10639",
    "lng": "-6.76528"
  },
  {
    "country": "IE",
    "name": "Oldcastle",
    "lat": "53.76648",
    "lng": "-7.16284"
  },
  {
    "country": "IE",
    "name": "Newtown Trim",
    "lat": "53.55611",
    "lng": "-6.77"
  },
  {
    "country": "IE",
    "name": "Newtown Cunningham",
    "lat": "54.99639",
    "lng": "-7.51917"
  },
  {
    "country": "IE",
    "name": "New Ross",
    "lat": "52.39667",
    "lng": "-6.93667"
  },
  {
    "country": "IE",
    "name": "Newport",
    "lat": "52.71111",
    "lng": "-8.40972"
  },
  {
    "country": "IE",
    "name": "Newmarket on Fergus",
    "lat": "52.76",
    "lng": "-8.89556"
  },
  {
    "country": "IE",
    "name": "Newcastle",
    "lat": "53.30111",
    "lng": "-6.50222"
  },
  {
    "country": "IE",
    "name": "Newcastle West",
    "lat": "52.44917",
    "lng": "-9.06111"
  },
  {
    "country": "IE",
    "name": "Droichead Nua",
    "lat": "53.18194",
    "lng": "-6.79667"
  },
  {
    "country": "IE",
    "name": "Nenagh",
    "lat": "52.86194",
    "lng": "-8.19667"
  },
  {
    "country": "IE",
    "name": "Navan",
    "lat": "53.65278",
    "lng": "-6.68139"
  },
  {
    "country": "IE",
    "name": "Naas",
    "lat": "53.21583",
    "lng": "-6.66694"
  },
  {
    "country": "IE",
    "name": "An Muileann gCearr",
    "lat": "53.53333",
    "lng": "-7.35"
  },
  {
    "country": "IE",
    "name": "Mullagh",
    "lat": "53.81306",
    "lng": "-6.95139"
  },
  {
    "country": "IE",
    "name": "Muff",
    "lat": "55.06667",
    "lng": "-7.26667"
  },
  {
    "country": "IE",
    "name": "Moycullen",
    "lat": "53.33783",
    "lng": "-9.18002"
  },
  {
    "country": "IE",
    "name": "Moville",
    "lat": "55.19153",
    "lng": "-7.03873"
  },
  {
    "country": "IE",
    "name": "Mountrath",
    "lat": "52.99889",
    "lng": "-7.47278"
  },
  {
    "country": "IE",
    "name": "Mountmellick",
    "lat": "53.11361",
    "lng": "-7.32"
  },
  {
    "country": "IE",
    "name": "Moroe",
    "lat": "52.65111",
    "lng": "-8.39611"
  },
  {
    "country": "IE",
    "name": "Moone",
    "lat": "52.97556",
    "lng": "-6.815"
  },
  {
    "country": "IE",
    "name": "Mooncoin",
    "lat": "52.28944",
    "lng": "-7.24833"
  },
  {
    "country": "IE",
    "name": "Monkstown",
    "lat": "53.29308",
    "lng": "-6.15312"
  },
  {
    "country": "IE",
    "name": "Monasterevin",
    "lat": "53.14056",
    "lng": "-7.06639"
  },
  {
    "country": "IE",
    "name": "Monaghan",
    "lat": "54.25",
    "lng": "-6.96667"
  },
  {
    "country": "IE",
    "name": "Moate",
    "lat": "53.55",
    "lng": "-7.71667"
  },
  {
    "country": "IE",
    "name": "Mitchelstown",
    "lat": "52.26583",
    "lng": "-8.26806"
  },
  {
    "country": "IE",
    "name": "Millstreet",
    "lat": "52.05935",
    "lng": "-9.06031"
  },
  {
    "country": "IE",
    "name": "Midleton",
    "lat": "51.91526",
    "lng": "-8.18052"
  },
  {
    "country": "IE",
    "name": "Mount Merrion",
    "lat": "53.30008",
    "lng": "-6.21504"
  },
  {
    "country": "IE",
    "name": "Maynooth",
    "lat": "53.385",
    "lng": "-6.59361"
  },
  {
    "country": "IE",
    "name": "Marino",
    "lat": "53.37022",
    "lng": "-6.23646"
  },
  {
    "country": "IE",
    "name": "Manorhamilton",
    "lat": "54.30639",
    "lng": "-8.17611"
  },
  {
    "country": "IE",
    "name": "Mallow",
    "lat": "52.13333",
    "lng": "-8.63333"
  },
  {
    "country": "IE",
    "name": "Malahide",
    "lat": "53.45083",
    "lng": "-6.15444"
  },
  {
    "country": "IE",
    "name": "Macroom",
    "lat": "51.90663",
    "lng": "-8.96968"
  },
  {
    "country": "IE",
    "name": "Lusk",
    "lat": "53.52743",
    "lng": "-6.16423"
  },
  {
    "country": "IE",
    "name": "Lucan",
    "lat": "53.35736",
    "lng": "-6.44859"
  },
  {
    "country": "IE",
    "name": "Loughrea",
    "lat": "53.19694",
    "lng": "-8.56694"
  },
  {
    "country": "IE",
    "name": "Loughlinstown",
    "lat": "53.24389",
    "lng": "-6.13306"
  },
  {
    "country": "IE",
    "name": "Longwood",
    "lat": "53.45389",
    "lng": "-6.92194"
  },
  {
    "country": "IE",
    "name": "Longford",
    "lat": "53.72536",
    "lng": "-7.79823"
  },
  {
    "country": "IE",
    "name": "Listowel",
    "lat": "52.44639",
    "lng": "-9.485"
  },
  {
    "country": "IE",
    "name": "Luimneach",
    "lat": "52.66472",
    "lng": "-8.62306"
  },
  {
    "country": "IE",
    "name": "Leifear",
    "lat": "54.83194",
    "lng": "-7.48361"
  },
  {
    "country": "IE",
    "name": "Letterkenny",
    "lat": "54.95",
    "lng": "-7.73333"
  },
  {
    "country": "IE",
    "name": "Leixlip",
    "lat": "53.36583",
    "lng": "-6.49556"
  },
  {
    "country": "IE",
    "name": "Laytown",
    "lat": "53.68194",
    "lng": "-6.23917"
  },
  {
    "country": "IE",
    "name": "Strandhill",
    "lat": "54.27194",
    "lng": "-8.59333"
  },
  {
    "country": "IE",
    "name": "Lanesborough",
    "lat": "53.66667",
    "lng": "-7.98333"
  },
  {
    "country": "IE",
    "name": "Kinsale",
    "lat": "51.7075",
    "lng": "-8.53056"
  },
  {
    "country": "IE",
    "name": "Kinnegad",
    "lat": "53.45222",
    "lng": "-7.09972"
  },
  {
    "country": "IE",
    "name": "Kinlough",
    "lat": "54.45",
    "lng": "-8.28333"
  },
  {
    "country": "IE",
    "name": "Kingscourt",
    "lat": "53.90806",
    "lng": "-6.80556"
  },
  {
    "country": "IE",
    "name": "Kiltamagh",
    "lat": "53.85",
    "lng": "-9"
  },
  {
    "country": "IE",
    "name": "Kilrush",
    "lat": "52.63972",
    "lng": "-9.48333"
  },
  {
    "country": "IE",
    "name": "Kilmallock",
    "lat": "52.4",
    "lng": "-8.57722"
  },
  {
    "country": "IE",
    "name": "Killybegs",
    "lat": "54.63333",
    "lng": "-8.45"
  },
  {
    "country": "IE",
    "name": "Killumney",
    "lat": "51.87243",
    "lng": "-8.64781"
  },
  {
    "country": "IE",
    "name": "Killorglin",
    "lat": "52.1",
    "lng": "-9.78333"
  },
  {
    "country": "IE",
    "name": "Cill Airne",
    "lat": "52.05",
    "lng": "-9.51667"
  },
  {
    "country": "IE",
    "name": "Killaloe",
    "lat": "52.80667",
    "lng": "-8.44361"
  },
  {
    "country": "IE",
    "name": "Kilkenny",
    "lat": "52.65417",
    "lng": "-7.25222"
  },
  {
    "country": "IE",
    "name": "Kildare",
    "lat": "53.15611",
    "lng": "-6.91444"
  },
  {
    "country": "IE",
    "name": "Kilcullen",
    "lat": "53.13028",
    "lng": "-6.74444"
  },
  {
    "country": "IE",
    "name": "Kilcoole",
    "lat": "53.10278",
    "lng": "-6.065"
  },
  {
    "country": "IE",
    "name": "Kilcock",
    "lat": "53.40222",
    "lng": "-6.67083"
  },
  {
    "country": "IE",
    "name": "Kilbeggan",
    "lat": "53.36944",
    "lng": "-7.50333"
  },
  {
    "country": "IE",
    "name": "Kenmare",
    "lat": "51.88333",
    "lng": "-9.58333"
  },
  {
    "country": "IE",
    "name": "Kells",
    "lat": "53.72639",
    "lng": "-6.87917"
  },
  {
    "country": "IE",
    "name": "Kanturk",
    "lat": "52.16667",
    "lng": "-8.9"
  },
  {
    "country": "IE",
    "name": "Johnstown",
    "lat": "53.23833",
    "lng": "-6.62222"
  },
  {
    "country": "IE",
    "name": "Inishcrone",
    "lat": "54.21591",
    "lng": "-9.09197"
  },
  {
    "country": "IE",
    "name": "Howth",
    "lat": "53.38778",
    "lng": "-6.06528"
  },
  {
    "country": "IE",
    "name": "Gweedore",
    "lat": "55.05028",
    "lng": "-8.23194"
  },
  {
    "country": "IE",
    "name": "Greystones",
    "lat": "53.14083",
    "lng": "-6.06306"
  },
  {
    "country": "IE",
    "name": "Granard",
    "lat": "53.77928",
    "lng": "-7.49429"
  },
  {
    "country": "IE",
    "name": "Graiguenamanagh",
    "lat": "52.54028",
    "lng": "-6.95472"
  },
  {
    "country": "IE",
    "name": "Gort",
    "lat": "53.06639",
    "lng": "-8.81667"
  },
  {
    "country": "IE",
    "name": "Gorey",
    "lat": "52.67472",
    "lng": "-6.2925"
  },
  {
    "country": "IE",
    "name": "Glasnevin",
    "lat": "53.38028",
    "lng": "-6.26417"
  },
  {
    "country": "IE",
    "name": "Gaillimh",
    "lat": "53.27194",
    "lng": "-9.04889"
  },
  {
    "country": "IE",
    "name": "Foxford",
    "lat": "53.9807",
    "lng": "-9.11551"
  },
  {
    "country": "IE",
    "name": "Finglas",
    "lat": "53.38917",
    "lng": "-6.29694"
  },
  {
    "country": "IE",
    "name": "Fethard",
    "lat": "52.46722",
    "lng": "-7.69111"
  },
  {
    "country": "IE",
    "name": "Ferns",
    "lat": "52.58833",
    "lng": "-6.49972"
  },
  {
    "country": "IE",
    "name": "Fermoy",
    "lat": "52.13583",
    "lng": "-8.27583"
  },
  {
    "country": "IE",
    "name": "Ferbane",
    "lat": "53.26944",
    "lng": "-7.82694"
  },
  {
    "country": "IE",
    "name": "Enniskerry",
    "lat": "53.1925",
    "lng": "-6.16917"
  },
  {
    "country": "IE",
    "name": "Enniscorthy",
    "lat": "52.50083",
    "lng": "-6.55778"
  },
  {
    "country": "IE",
    "name": "Ennis",
    "lat": "52.84361",
    "lng": "-8.98639"
  },
  {
    "country": "IE",
    "name": "Enfield",
    "lat": "53.41419",
    "lng": "-6.83229"
  },
  {
    "country": "IE",
    "name": "Edgeworthstown",
    "lat": "53.7",
    "lng": "-7.61667"
  },
  {
    "country": "IE",
    "name": "Edenderry",
    "lat": "53.34528",
    "lng": "-7.04972"
  },
  {
    "country": "IE",
    "name": "Dunshaughlin",
    "lat": "53.5125",
    "lng": "-6.54"
  },
  {
    "country": "IE",
    "name": "Dunmore East",
    "lat": "52.15108",
    "lng": "-6.99872"
  },
  {
    "country": "IE",
    "name": "Dunmanway",
    "lat": "51.71667",
    "lng": "-9.11667"
  },
  {
    "country": "IE",
    "name": "Dunlewy",
    "lat": "55.01667",
    "lng": "-8.1"
  },
  {
    "country": "IE",
    "name": "Dunleer",
    "lat": "53.835",
    "lng": "-6.39611"
  },
  {
    "country": "IE",
    "name": "Dún Laoghaire",
    "lat": "53.29395",
    "lng": "-6.13586"
  },
  {
    "country": "IE",
    "name": "Dungloe",
    "lat": "54.95111",
    "lng": "-8.35917"
  },
  {
    "country": "IE",
    "name": "Dungarvan",
    "lat": "52.08806",
    "lng": "-7.62528"
  },
  {
    "country": "IE",
    "name": "Dundrum",
    "lat": "53.29067",
    "lng": "-6.25714"
  },
  {
    "country": "IE",
    "name": "Dundalk",
    "lat": "54",
    "lng": "-6.41667"
  },
  {
    "country": "IE",
    "name": "Dunboyne",
    "lat": "53.41901",
    "lng": "-6.47375"
  },
  {
    "country": "IE",
    "name": "Duleek",
    "lat": "53.65667",
    "lng": "-6.41917"
  },
  {
    "country": "IE",
    "name": "Dublin",
    "lat": "53.33306",
    "lng": "-6.24889"
  },
  {
    "country": "IE",
    "name": "Dromiskin",
    "lat": "53.92538",
    "lng": "-6.40292"
  },
  {
    "country": "IE",
    "name": "Drogheda",
    "lat": "53.71889",
    "lng": "-6.34778"
  },
  {
    "country": "IE",
    "name": "Donnybrook",
    "lat": "53.31375",
    "lng": "-6.22274"
  },
  {
    "country": "IE",
    "name": "Donegal",
    "lat": "54.65378",
    "lng": "-8.11134"
  },
  {
    "country": "IE",
    "name": "Donabate",
    "lat": "53.48722",
    "lng": "-6.15194"
  },
  {
    "country": "IE",
    "name": "Dollymount",
    "lat": "53.36489",
    "lng": "-6.18032"
  },
  {
    "country": "IE",
    "name": "Dingle",
    "lat": "52.14083",
    "lng": "-10.26889"
  },
  {
    "country": "IE",
    "name": "Derrybeg",
    "lat": "55.08333",
    "lng": "-8.28944"
  },
  {
    "country": "IE",
    "name": "Derry",
    "lat": "51.58666",
    "lng": "-9.05026"
  },
  {
    "country": "IE",
    "name": "Derrinturn",
    "lat": "53.34167",
    "lng": "-6.94111"
  },
  {
    "country": "IE",
    "name": "Dalkey",
    "lat": "53.27833",
    "lng": "-6.10028"
  },
  {
    "country": "IE",
    "name": "Crumlin",
    "lat": "53.32417",
    "lng": "-6.32861"
  },
  {
    "country": "IE",
    "name": "Crossmolina",
    "lat": "54.1",
    "lng": "-9.31667"
  },
  {
    "country": "IE",
    "name": "Crosshaven",
    "lat": "51.79833",
    "lng": "-8.30083"
  },
  {
    "country": "IE",
    "name": "Croom",
    "lat": "52.51944",
    "lng": "-8.71778"
  },
  {
    "country": "IE",
    "name": "Courtown",
    "lat": "52.64424",
    "lng": "-6.22899"
  },
  {
    "country": "IE",
    "name": "Cork",
    "lat": "51.89797",
    "lng": "-8.47061"
  },
  {
    "country": "IE",
    "name": "Cootehill",
    "lat": "54.0725",
    "lng": "-7.08194"
  },
  {
    "country": "IE",
    "name": "Convoy",
    "lat": "54.86083",
    "lng": "-7.66556"
  },
  {
    "country": "IE",
    "name": "Collooney",
    "lat": "54.18333",
    "lng": "-8.5"
  },
  {
    "country": "IE",
    "name": "Cobh",
    "lat": "51.85046",
    "lng": "-8.2948"
  },
  {
    "country": "IE",
    "name": "Cloyne",
    "lat": "51.86278",
    "lng": "-8.12444"
  },
  {
    "country": "IE",
    "name": "Cluain Meala",
    "lat": "52.355",
    "lng": "-7.70389"
  },
  {
    "country": "IE",
    "name": "Clones",
    "lat": "54.18333",
    "lng": "-7.23333"
  },
  {
    "country": "IE",
    "name": "Clondalkin",
    "lat": "53.32444",
    "lng": "-6.39722"
  },
  {
    "country": "IE",
    "name": "Clonakilty",
    "lat": "51.62306",
    "lng": "-8.87056"
  },
  {
    "country": "IE",
    "name": "Clogherhead",
    "lat": "53.79361",
    "lng": "-6.2375"
  },
  {
    "country": "IE",
    "name": "Clifden",
    "lat": "53.48907",
    "lng": "-10.0191"
  },
  {
    "country": "IE",
    "name": "Claremorris",
    "lat": "53.71667",
    "lng": "-9"
  },
  {
    "country": "IE",
    "name": "Claregalway",
    "lat": "53.33861",
    "lng": "-8.945"
  },
  {
    "country": "IE",
    "name": "Clara",
    "lat": "53.3425",
    "lng": "-7.61389"
  },
  {
    "country": "IE",
    "name": "Clane",
    "lat": "53.29139",
    "lng": "-6.68917"
  },
  {
    "country": "IE",
    "name": "Cherryville",
    "lat": "53.15694",
    "lng": "-6.96667"
  },
  {
    "country": "IE",
    "name": "Ráth Luirc",
    "lat": "52.35",
    "lng": "-8.68333"
  },
  {
    "country": "IE",
    "name": "Chapelizod",
    "lat": "53.34889",
    "lng": "-6.34667"
  },
  {
    "country": "IE",
    "name": "Celbridge",
    "lat": "53.33861",
    "lng": "-6.54361"
  },
  {
    "country": "IE",
    "name": "Cavan",
    "lat": "53.99083",
    "lng": "-7.36056"
  },
  {
    "country": "IE",
    "name": "Castlerea",
    "lat": "53.76667",
    "lng": "-8.5"
  },
  {
    "country": "IE",
    "name": "Castlepollard",
    "lat": "53.67935",
    "lng": "-7.29736"
  },
  {
    "country": "IE",
    "name": "Castlemartyr",
    "lat": "51.91028",
    "lng": "-8.05389"
  },
  {
    "country": "IE",
    "name": "Castleknock",
    "lat": "53.37483",
    "lng": "-6.36336"
  },
  {
    "country": "IE",
    "name": "Castleisland",
    "lat": "52.23333",
    "lng": "-9.46667"
  },
  {
    "country": "IE",
    "name": "Castledermot",
    "lat": "52.90889",
    "lng": "-6.84222"
  },
  {
    "country": "IE",
    "name": "Castlecomer",
    "lat": "52.80611",
    "lng": "-7.21056"
  },
  {
    "country": "IE",
    "name": "Castlebridge",
    "lat": "52.38639",
    "lng": "-6.44944"
  },
  {
    "country": "IE",
    "name": "Castleblayney",
    "lat": "54.11667",
    "lng": "-6.73333"
  },
  {
    "country": "IE",
    "name": "Castlebellingham",
    "lat": "53.90083",
    "lng": "-6.39028"
  },
  {
    "country": "IE",
    "name": "Castlebar",
    "lat": "53.85",
    "lng": "-9.3"
  },
  {
    "country": "IE",
    "name": "Cashel",
    "lat": "52.51583",
    "lng": "-7.88556"
  },
  {
    "country": "IE",
    "name": "Carrigtwohill",
    "lat": "51.90833",
    "lng": "-8.26333"
  },
  {
    "country": "IE",
    "name": "Carrigaline",
    "lat": "51.81167",
    "lng": "-8.39861"
  },
  {
    "country": "IE",
    "name": "Carrick-on-Suir",
    "lat": "52.34917",
    "lng": "-7.41306"
  },
  {
    "country": "IE",
    "name": "Carrick-on-Shannon",
    "lat": "53.94694",
    "lng": "-8.09"
  },
  {
    "country": "IE",
    "name": "Carrickmacross",
    "lat": "53.97278",
    "lng": "-6.71889"
  },
  {
    "country": "IE",
    "name": "Carnew",
    "lat": "52.70806",
    "lng": "-6.49444"
  },
  {
    "country": "IE",
    "name": "Carndonagh",
    "lat": "55.25",
    "lng": "-7.26667"
  },
  {
    "country": "IE",
    "name": "Carlow",
    "lat": "52.84083",
    "lng": "-6.92611"
  },
  {
    "country": "IE",
    "name": "Carlingford",
    "lat": "54.04",
    "lng": "-6.18833"
  },
  {
    "country": "IE",
    "name": "Callan",
    "lat": "52.545",
    "lng": "-7.39111"
  },
  {
    "country": "IE",
    "name": "Cahersiveen",
    "lat": "51.94861",
    "lng": "-10.22222"
  },
  {
    "country": "IE",
    "name": "Caherconlish",
    "lat": "52.59361",
    "lng": "-8.47028"
  },
  {
    "country": "IE",
    "name": "Cahir",
    "lat": "52.37694",
    "lng": "-7.92167"
  },
  {
    "country": "IE",
    "name": "Cabinteely",
    "lat": "53.26973",
    "lng": "-6.16058"
  },
  {
    "country": "IE",
    "name": "Bundoran",
    "lat": "54.47782",
    "lng": "-8.28094"
  },
  {
    "country": "IE",
    "name": "Bunclody",
    "lat": "52.6553",
    "lng": "-6.65359"
  },
  {
    "country": "IE",
    "name": "Bray",
    "lat": "53.20278",
    "lng": "-6.09833"
  },
  {
    "country": "IE",
    "name": "Boyle",
    "lat": "53.96667",
    "lng": "-8.3"
  },
  {
    "country": "IE",
    "name": "Blessington",
    "lat": "53.17",
    "lng": "-6.5325"
  },
  {
    "country": "IE",
    "name": "Blarney",
    "lat": "51.93333",
    "lng": "-8.56667"
  },
  {
    "country": "IE",
    "name": "Blanchardstown",
    "lat": "53.38806",
    "lng": "-6.37556"
  },
  {
    "country": "IE",
    "name": "Blackrock",
    "lat": "53.96405",
    "lng": "-6.36514"
  },
  {
    "country": "IE",
    "name": "Blackrock",
    "lat": "53.3015",
    "lng": "-6.1778"
  },
  {
    "country": "IE",
    "name": "Birr",
    "lat": "53.09139",
    "lng": "-7.91333"
  },
  {
    "country": "IE",
    "name": "Belturbet",
    "lat": "54.1",
    "lng": "-7.45"
  },
  {
    "country": "IE",
    "name": "Belmullet",
    "lat": "54.225",
    "lng": "-9.99083"
  },
  {
    "country": "IE",
    "name": "Bearna",
    "lat": "53.25194",
    "lng": "-9.14972"
  },
  {
    "country": "IE",
    "name": "Bantry",
    "lat": "51.68333",
    "lng": "-9.45"
  },
  {
    "country": "IE",
    "name": "Bandon",
    "lat": "51.74694",
    "lng": "-8.7425"
  },
  {
    "country": "IE",
    "name": "Banagher",
    "lat": "53.18861",
    "lng": "-7.98667"
  },
  {
    "country": "IE",
    "name": "Baltinglass",
    "lat": "52.93722",
    "lng": "-6.70917"
  },
  {
    "country": "IE",
    "name": "Balrothery",
    "lat": "53.58828",
    "lng": "-6.18728"
  },
  {
    "country": "IE",
    "name": "Ballyshannon",
    "lat": "54.5",
    "lng": "-8.18333"
  },
  {
    "country": "IE",
    "name": "Ballyragget",
    "lat": "52.78889",
    "lng": "-7.33028"
  },
  {
    "country": "IE",
    "name": "Ballymote",
    "lat": "54.08333",
    "lng": "-8.51667"
  },
  {
    "country": "IE",
    "name": "Ballymahon",
    "lat": "53.56667",
    "lng": "-7.76667"
  },
  {
    "country": "IE",
    "name": "Ballyjamesduff",
    "lat": "53.86528",
    "lng": "-7.20278"
  },
  {
    "country": "IE",
    "name": "Ballyhaunis",
    "lat": "53.76667",
    "lng": "-8.76667"
  },
  {
    "country": "IE",
    "name": "Ballyconnell",
    "lat": "54.11667",
    "lng": "-7.58333"
  },
  {
    "country": "IE",
    "name": "Ballybunnion",
    "lat": "52.51108",
    "lng": "-9.67097"
  },
  {
    "country": "IE",
    "name": "Ballybofey",
    "lat": "54.8",
    "lng": "-7.78333"
  },
  {
    "country": "IE",
    "name": "Ballyboden",
    "lat": "53.28056",
    "lng": "-6.31639"
  },
  {
    "country": "IE",
    "name": "Ballivor",
    "lat": "53.53167",
    "lng": "-6.96111"
  },
  {
    "country": "IE",
    "name": "Ballinrobe",
    "lat": "53.63333",
    "lng": "-9.23333"
  },
  {
    "country": "IE",
    "name": "Ballinasloe",
    "lat": "53.3275",
    "lng": "-8.21944"
  },
  {
    "country": "IE",
    "name": "Ballina",
    "lat": "54.11667",
    "lng": "-9.16667"
  },
  {
    "country": "IE",
    "name": "Ballina",
    "lat": "52.80778",
    "lng": "-8.43556"
  },
  {
    "country": "IE",
    "name": "Ballaghaderreen",
    "lat": "53.9",
    "lng": "-8.58333"
  },
  {
    "country": "IE",
    "name": "Baldoyle",
    "lat": "53.39972",
    "lng": "-6.12583"
  },
  {
    "country": "IE",
    "name": "Balbriggan",
    "lat": "53.60846",
    "lng": "-6.1831"
  },
  {
    "country": "IE",
    "name": "Bailieborough",
    "lat": "53.91667",
    "lng": "-6.96667"
  },
  {
    "country": "IE",
    "name": "Bagenalstown",
    "lat": "52.70031",
    "lng": "-6.96181"
  },
  {
    "country": "IE",
    "name": "Aughrim",
    "lat": "52.85333",
    "lng": "-6.3275"
  },
  {
    "country": "IE",
    "name": "Athy",
    "lat": "52.99139",
    "lng": "-6.98028"
  },
  {
    "country": "IE",
    "name": "Athlone",
    "lat": "53.43333",
    "lng": "-7.95"
  },
  {
    "country": "IE",
    "name": "Athgarvan",
    "lat": "53.15229",
    "lng": "-6.78173"
  },
  {
    "country": "IE",
    "name": "Athenry",
    "lat": "53.29639",
    "lng": "-8.74306"
  },
  {
    "country": "IE",
    "name": "Athboy",
    "lat": "53.62327",
    "lng": "-6.91434"
  },
  {
    "country": "IE",
    "name": "Askeaton",
    "lat": "52.59972",
    "lng": "-8.97556"
  },
  {
    "country": "IE",
    "name": "Ashbourne",
    "lat": "53.51163",
    "lng": "-6.39821"
  },
  {
    "country": "IE",
    "name": "Arklow",
    "lat": "52.79306",
    "lng": "-6.14139"
  },
  {
    "country": "IE",
    "name": "Ardnacrusha",
    "lat": "52.70908",
    "lng": "-8.61431"
  },
  {
    "country": "IE",
    "name": "Ardee",
    "lat": "53.85972",
    "lng": "-6.54056"
  },
  {
    "country": "IE",
    "name": "Aghada",
    "lat": "51.83917",
    "lng": "-8.21222"
  },
  {
    "country": "IE",
    "name": "Adare",
    "lat": "52.56194",
    "lng": "-8.79556"
  },
  {
    "country": "IE",
    "name": "Abbeyleix",
    "lat": "52.91331",
    "lng": "-7.34456"
  },
  {
    "country": "IE",
    "name": "Abbeyfeale",
    "lat": "52.38139",
    "lng": "-9.3025"
  },
  {
    "country": "IE",
    "name": "Castletown",
    "lat": "52.72306",
    "lng": "-6.18944"
  },
  {
    "country": "IE",
    "name": "Portraine",
    "lat": "53.49667",
    "lng": "-6.11111"
  },
  {
    "country": "IE",
    "name": "Ballygerry",
    "lat": "52.24917",
    "lng": "-6.35739"
  },
  {
    "country": "IE",
    "name": "Ballinroad",
    "lat": "52.51789",
    "lng": "-6.40619"
  },
  {
    "country": "IE",
    "name": "Annacotty",
    "lat": "52.66768",
    "lng": "-8.53121"
  },
  {
    "country": "IE",
    "name": "Castleconnell",
    "lat": "52.71389",
    "lng": "-8.49944"
  },
  {
    "country": "IE",
    "name": "Nenagh Bridge",
    "lat": "52.88167",
    "lng": "-8.19583"
  },
  {
    "country": "IE",
    "name": "Shannon",
    "lat": "52.70389",
    "lng": "-8.86417"
  },
  {
    "country": "IE",
    "name": "Moate",
    "lat": "53.39389",
    "lng": "-7.71722"
  },
  {
    "country": "IE",
    "name": "Kill",
    "lat": "53.25139",
    "lng": "-6.59167"
  },
  {
    "country": "IE",
    "name": "Ashford",
    "lat": "53.00833",
    "lng": "-6.11139"
  },
  {
    "country": "IE",
    "name": "Kilpedder",
    "lat": "53.10917",
    "lng": "-6.10667"
  },
  {
    "country": "IE",
    "name": "Valleymount",
    "lat": "53.10389",
    "lng": "-6.55361"
  },
  {
    "country": "IE",
    "name": "Kilmacanoge",
    "lat": "53.16722",
    "lng": "-6.13361"
  },
  {
    "country": "IE",
    "name": "Eadestown",
    "lat": "53.20278",
    "lng": "-6.57806"
  },
  {
    "country": "IE",
    "name": "Little Bray",
    "lat": "53.20444",
    "lng": "-6.12083"
  },
  {
    "country": "IE",
    "name": "Firhouse",
    "lat": "53.28167",
    "lng": "-6.33917"
  },
  {
    "country": "IE",
    "name": "Sandyford",
    "lat": "53.2747",
    "lng": "-6.2253"
  },
  {
    "country": "IE",
    "name": "Foxrock",
    "lat": "53.26667",
    "lng": "-6.17417"
  },
  {
    "country": "IE",
    "name": "Sallynoggin",
    "lat": "53.27917",
    "lng": "-6.14058"
  },
  {
    "country": "IE",
    "name": "Rathgar",
    "lat": "53.31457",
    "lng": "-6.275"
  },
  {
    "country": "IE",
    "name": "Artane",
    "lat": "53.38712",
    "lng": "-6.2138"
  },
  {
    "country": "IE",
    "name": "Beaumont",
    "lat": "53.39139",
    "lng": "-6.24056"
  },
  {
    "country": "IE",
    "name": "Drumcondra",
    "lat": "53.37058",
    "lng": "-6.25298"
  },
  {
    "country": "IE",
    "name": "Ballymun",
    "lat": "53.39807",
    "lng": "-6.26693"
  },
  {
    "country": "IE",
    "name": "Cabra",
    "lat": "53.36694",
    "lng": "-6.29444"
  },
  {
    "country": "IE",
    "name": "Hartstown",
    "lat": "53.39306",
    "lng": "-6.42694"
  },
  {
    "country": "IE",
    "name": "Ballyfermot",
    "lat": "53.34528",
    "lng": "-6.35889"
  },
  {
    "country": "IE",
    "name": "Templeogue",
    "lat": "53.29528",
    "lng": "-6.30889"
  },
  {
    "country": "IE",
    "name": "Oldbawn",
    "lat": "53.27556",
    "lng": "-6.3675"
  },
  {
    "country": "IE",
    "name": "Cherry Orchard",
    "lat": "53.33605",
    "lng": "-6.37799"
  },
  {
    "country": "IE",
    "name": "Rialto",
    "lat": "53.33625",
    "lng": "-6.29718"
  },
  {
    "country": "IE",
    "name": "Milltown",
    "lat": "53.31301",
    "lng": "-6.2453"
  },
  {
    "country": "IE",
    "name": "Clonskeagh",
    "lat": "53.31467",
    "lng": "-6.23148"
  },
  {
    "country": "IE",
    "name": "Booterstown",
    "lat": "53.30447",
    "lng": "-6.19985"
  },
  {
    "country": "IE",
    "name": "Ballinteer",
    "lat": "53.27409",
    "lng": "-6.25397"
  },
  {
    "country": "IE",
    "name": "Greenhills",
    "lat": "53.33467",
    "lng": "-6.30302"
  },
  {
    "country": "IE",
    "name": "Coolock",
    "lat": "53.3887",
    "lng": "-6.19998"
  },
  {
    "country": "IE",
    "name": "Bonnybrook",
    "lat": "53.39835",
    "lng": "-6.20749"
  },
  {
    "country": "IE",
    "name": "Donaghmede",
    "lat": "53.39845",
    "lng": "-6.16179"
  },
  {
    "country": "IE",
    "name": "Darndale",
    "lat": "53.39948",
    "lng": "-6.18886"
  },
  {
    "country": "IE",
    "name": "Donnycarney",
    "lat": "53.3735",
    "lng": "-6.20976"
  },
  {
    "country": "IE",
    "name": "Bayside",
    "lat": "53.38895",
    "lng": "-6.14041"
  },
  {
    "country": "IE",
    "name": "Charlesland",
    "lat": "53.12771",
    "lng": "-6.06347"
  },
  {
    "country": "IE",
    "name": "Moyross",
    "lat": "52.68198",
    "lng": "-8.63955"
  },
  {
    "country": "IE",
    "name": "Ballisodare",
    "lat": "54.2111",
    "lng": "-8.50865"
  },
  {
    "country": "IE",
    "name": "Ballylinan",
    "lat": "52.94497",
    "lng": "-7.04073"
  },
  {
    "country": "IE",
    "name": "Fairview",
    "lat": "53.36597",
    "lng": "-6.23985"
  },
  {
    "country": "IE",
    "name": "Knocklyon",
    "lat": "53.2803",
    "lng": "-6.3313"
  },
  {
    "country": "IE",
    "name": "Palmerstown",
    "lat": "53.35019",
    "lng": "-6.37778"
  },
  {
    "country": "IE",
    "name": "Jobstown",
    "lat": "53.27866",
    "lng": "-6.40803"
  },
  {
    "country": "IE",
    "name": "Killester",
    "lat": "53.37322",
    "lng": "-6.20431"
  },
  {
    "country": "IE",
    "name": "Confey",
    "lat": "53.37923",
    "lng": "-6.49052"
  },
  {
    "country": "IE",
    "name": "Kentstown",
    "lat": "53.62754",
    "lng": "-6.52674"
  },
  {
    "country": "IE",
    "name": "Kilquade",
    "lat": "53.09743",
    "lng": "-6.08411"
  },
  {
    "country": "IE",
    "name": "Newtownmountkennedy",
    "lat": "53.09052",
    "lng": "-6.11149"
  },
  {
    "country": "IE",
    "name": "Balally",
    "lat": "53.27504",
    "lng": "-6.23594"
  },
  {
    "country": "IE",
    "name": "Kinsealy-Drinan",
    "lat": "53.44395",
    "lng": "-6.20334"
  },
  {
    "country": "IE",
    "name": "Courtbrack",
    "lat": "51.96677",
    "lng": "-8.64611"
  },
  {
    "country": "IE",
    "name": "Ballybofey-Stranorlar",
    "lat": "54.80165",
    "lng": "-7.77437"
  },
  {
    "country": "IL",
    "name": "Jerusalem",
    "lat": "31.76904",
    "lng": "35.21633"
  },
  {
    "country": "IL",
    "name": "Har Adar",
    "lat": "31.82754",
    "lng": "35.13093"
  },
  {
    "country": "IL",
    "name": "Modi‘in Makkabbim Re‘ut",
    "lat": "31.89385",
    "lng": "35.01504"
  },
  {
    "country": "IL",
    "name": "Ẕur Moshe",
    "lat": "32.29819",
    "lng": "34.91313"
  },
  {
    "country": "IL",
    "name": "Ẕur Hadassa",
    "lat": "31.71912",
    "lng": "35.09708"
  },
  {
    "country": "IL",
    "name": "Safed",
    "lat": "32.96465",
    "lng": "35.496"
  },
  {
    "country": "IL",
    "name": "Yeroẖam",
    "lat": "30.98822",
    "lng": "34.93176"
  },
  {
    "country": "IL",
    "name": "Yehud",
    "lat": "32.03317",
    "lng": "34.89091"
  },
  {
    "country": "IL",
    "name": "Yavne’el",
    "lat": "32.70619",
    "lng": "35.50435"
  },
  {
    "country": "IL",
    "name": "Yavné",
    "lat": "31.87808",
    "lng": "34.73983"
  },
  {
    "country": "IL",
    "name": "Jaffa",
    "lat": "32.05043",
    "lng": "34.75224"
  },
  {
    "country": "IL",
    "name": "‘Uzeir",
    "lat": "32.79212",
    "lng": "35.32984"
  },
  {
    "country": "IL",
    "name": "Umm el Faḥm",
    "lat": "32.51725",
    "lng": "35.15349"
  },
  {
    "country": "IL",
    "name": "Tirat Karmel",
    "lat": "32.76021",
    "lng": "34.97183"
  },
  {
    "country": "IL",
    "name": "Timrat",
    "lat": "32.70302",
    "lng": "35.22359"
  },
  {
    "country": "IL",
    "name": "Tiberias",
    "lat": "32.79221",
    "lng": "35.53124"
  },
  {
    "country": "IL",
    "name": "Tel Mond",
    "lat": "32.24995",
    "lng": "34.91737"
  },
  {
    "country": "IL",
    "name": "Tel Aviv",
    "lat": "32.08088",
    "lng": "34.78057"
  },
  {
    "country": "IL",
    "name": "maalot Tarshīhā",
    "lat": "33.01667",
    "lng": "35.26667"
  },
  {
    "country": "IL",
    "name": "Tamra",
    "lat": "32.85301",
    "lng": "35.1987"
  },
  {
    "country": "IL",
    "name": "Sūlam",
    "lat": "32.60606",
    "lng": "35.33408"
  },
  {
    "country": "IL",
    "name": "Shelomi",
    "lat": "33.07216",
    "lng": "35.14452"
  },
  {
    "country": "IL",
    "name": "Sederot",
    "lat": "31.525",
    "lng": "34.59693"
  },
  {
    "country": "IL",
    "name": "Savyon",
    "lat": "32.04966",
    "lng": "34.8777"
  },
  {
    "country": "IL",
    "name": "Sakhnīn",
    "lat": "32.86422",
    "lng": "35.29707"
  },
  {
    "country": "IL",
    "name": "Sājūr",
    "lat": "32.94266",
    "lng": "35.34136"
  },
  {
    "country": "IL",
    "name": "Rosh Pinna",
    "lat": "32.96894",
    "lng": "35.54258"
  },
  {
    "country": "IL",
    "name": "Rosh Ha‘Ayin",
    "lat": "32.09556",
    "lng": "34.95664"
  },
  {
    "country": "IL",
    "name": "Rishon LeẔiyyon",
    "lat": "31.97102",
    "lng": "34.78939"
  },
  {
    "country": "IL",
    "name": "Rekhasim",
    "lat": "32.74907",
    "lng": "35.09901"
  },
  {
    "country": "IL",
    "name": "Reẖovot",
    "lat": "31.89421",
    "lng": "34.81199"
  },
  {
    "country": "IL",
    "name": "Ramla",
    "lat": "31.92923",
    "lng": "34.86563"
  },
  {
    "country": "IL",
    "name": "Ramat Yishay",
    "lat": "32.70444",
    "lng": "35.1707"
  },
  {
    "country": "IL",
    "name": "Ramat HaSharon",
    "lat": "32.14613",
    "lng": "34.8394"
  },
  {
    "country": "IL",
    "name": "Ramat Gan",
    "lat": "32.08227",
    "lng": "34.81065"
  },
  {
    "country": "IL",
    "name": "Ra'anana",
    "lat": "32.1836",
    "lng": "34.87386"
  },
  {
    "country": "IL",
    "name": "Qiryat Yam",
    "lat": "32.84966",
    "lng": "35.06973"
  },
  {
    "country": "IL",
    "name": "Qiryat Shemona",
    "lat": "33.20733",
    "lng": "35.57212"
  },
  {
    "country": "IL",
    "name": "Qiryat Moẕqin",
    "lat": "32.83706",
    "lng": "35.0776"
  },
  {
    "country": "IL",
    "name": "Qiryat Gat",
    "lat": "31.60998",
    "lng": "34.76422"
  },
  {
    "country": "IL",
    "name": "Qiryat Bialik",
    "lat": "32.8275",
    "lng": "35.08583"
  },
  {
    "country": "IL",
    "name": "Qiryat Ata",
    "lat": "32.81149",
    "lng": "35.11323"
  },
  {
    "country": "IL",
    "name": "Qalansuwa",
    "lat": "32.28493",
    "lng": "34.98106"
  },
  {
    "country": "IL",
    "name": "Petaẖ Tiqwa",
    "lat": "32.08707",
    "lng": "34.88747"
  },
  {
    "country": "IL",
    "name": "Pardesiyya",
    "lat": "32.30577",
    "lng": "34.90911"
  },
  {
    "country": "IL",
    "name": "Or Yehuda",
    "lat": "32.02923",
    "lng": "34.85788"
  },
  {
    "country": "IL",
    "name": "Ofaqim",
    "lat": "31.3141",
    "lng": "34.62025"
  },
  {
    "country": "IL",
    "name": "Nordiyya",
    "lat": "32.3147",
    "lng": "34.89617"
  },
  {
    "country": "IL",
    "name": "Netivot",
    "lat": "31.42305",
    "lng": "34.58911"
  },
  {
    "country": "IL",
    "name": "Netanya",
    "lat": "32.33291",
    "lng": "34.85992"
  },
  {
    "country": "IL",
    "name": "Ness Ziona",
    "lat": "31.92933",
    "lng": "34.79868"
  },
  {
    "country": "IL",
    "name": "Nesher",
    "lat": "32.76622",
    "lng": "35.04425"
  },
  {
    "country": "IL",
    "name": "Nein",
    "lat": "32.63063",
    "lng": "35.34885"
  },
  {
    "country": "IL",
    "name": "Neẖalim",
    "lat": "32.06012",
    "lng": "34.91069"
  },
  {
    "country": "IL",
    "name": "Nazareth",
    "lat": "32.69925",
    "lng": "35.30483"
  },
  {
    "country": "IL",
    "name": "Naḥf",
    "lat": "32.93444",
    "lng": "35.31679"
  },
  {
    "country": "IL",
    "name": "Nahariyya",
    "lat": "33.00892",
    "lng": "35.09814"
  },
  {
    "country": "IL",
    "name": "Mitzpe Ramon",
    "lat": "30.60944",
    "lng": "34.80111"
  },
  {
    "country": "IL",
    "name": "Mi‘ilyā",
    "lat": "33.02781",
    "lng": "35.25658"
  },
  {
    "country": "IL",
    "name": "Migdal Ha‘Emeq",
    "lat": "32.67597",
    "lng": "35.23986"
  },
  {
    "country": "IL",
    "name": "Mevasseret Ẕiyyon",
    "lat": "31.80186",
    "lng": "35.15072"
  },
  {
    "country": "IL",
    "name": "Metulla",
    "lat": "33.27918",
    "lng": "35.5795"
  },
  {
    "country": "IL",
    "name": "Mazkeret Batya",
    "lat": "31.85357",
    "lng": "34.84646"
  },
  {
    "country": "IL",
    "name": "Maghār",
    "lat": "32.88984",
    "lng": "35.40703"
  },
  {
    "country": "IL",
    "name": "Lod",
    "lat": "31.9467",
    "lng": "34.8903"
  },
  {
    "country": "IL",
    "name": "Kefar Yona",
    "lat": "32.31669",
    "lng": "34.93507"
  },
  {
    "country": "IL",
    "name": "Kefar Tavor",
    "lat": "32.68655",
    "lng": "35.42118"
  },
  {
    "country": "IL",
    "name": "Kefar Shemaryahu",
    "lat": "32.18529",
    "lng": "34.82082"
  },
  {
    "country": "IL",
    "name": "Kfar Saba",
    "lat": "32.175",
    "lng": "34.90694"
  },
  {
    "country": "IL",
    "name": "Kefar Rosh HaNiqra",
    "lat": "33.08607",
    "lng": "35.11348"
  },
  {
    "country": "IL",
    "name": "Kefar H̱abad",
    "lat": "31.98793",
    "lng": "34.8516"
  },
  {
    "country": "IL",
    "name": "Kaukab Abū el Hījā",
    "lat": "32.83155",
    "lng": "35.24848"
  },
  {
    "country": "IL",
    "name": "Karmi’el",
    "lat": "32.91708",
    "lng": "35.30501"
  },
  {
    "country": "IL",
    "name": "Kfar Yasif",
    "lat": "32.95451",
    "lng": "35.1623"
  },
  {
    "country": "IL",
    "name": "Kafr Qāsim",
    "lat": "32.11406",
    "lng": "34.97624"
  },
  {
    "country": "IL",
    "name": "Kafr Miṣr",
    "lat": "32.64521",
    "lng": "35.42147"
  },
  {
    "country": "IL",
    "name": "Kafr Mandā",
    "lat": "32.81034",
    "lng": "35.26009"
  },
  {
    "country": "IL",
    "name": "Kafr Kannā",
    "lat": "32.7466",
    "lng": "35.34242"
  },
  {
    "country": "IL",
    "name": "Kafr Kammā",
    "lat": "32.72129",
    "lng": "35.44122"
  },
  {
    "country": "IL",
    "name": "Kābūl",
    "lat": "32.86856",
    "lng": "35.21171"
  },
  {
    "country": "IL",
    "name": "Judeida Makr",
    "lat": "32.9282",
    "lng": "35.15705"
  },
  {
    "country": "IL",
    "name": "Jīsh",
    "lat": "33.02216",
    "lng": "35.44694"
  },
  {
    "country": "IL",
    "name": "Jaljūlya",
    "lat": "32.1547",
    "lng": "34.95372"
  },
  {
    "country": "IL",
    "name": "Iksāl",
    "lat": "32.68164",
    "lng": "35.32365"
  },
  {
    "country": "IL",
    "name": "Ibṭīn",
    "lat": "32.7615",
    "lng": "35.11402"
  },
  {
    "country": "IL",
    "name": "Ḥurfeish",
    "lat": "33.01711",
    "lng": "35.34835"
  },
  {
    "country": "IL",
    "name": "H̱olon",
    "lat": "32.01034",
    "lng": "34.77918"
  },
  {
    "country": "IL",
    "name": "Hod HaSharon",
    "lat": "32.15934",
    "lng": "34.8932"
  },
  {
    "country": "IL",
    "name": "Herzliya",
    "lat": "32.16627",
    "lng": "34.82536"
  },
  {
    "country": "IL",
    "name": "Haifa",
    "lat": "32.81841",
    "lng": "34.9885"
  },
  {
    "country": "IL",
    "name": "Hadera",
    "lat": "32.44192",
    "lng": "34.9039"
  },
  {
    "country": "IL",
    "name": "Giv'at Shmuel",
    "lat": "32.07817",
    "lng": "34.84858"
  },
  {
    "country": "IL",
    "name": "Givatayim",
    "lat": "32.07225",
    "lng": "34.81253"
  },
  {
    "country": "IL",
    "name": "Gedera",
    "lat": "31.81456",
    "lng": "34.77998"
  },
  {
    "country": "IL",
    "name": "Gan Yavne",
    "lat": "31.78737",
    "lng": "34.70659"
  },
  {
    "country": "IL",
    "name": "Ganei Tikva",
    "lat": "32.05971",
    "lng": "34.8732"
  },
  {
    "country": "IL",
    "name": "Pasuta",
    "lat": "33.04895",
    "lng": "35.30893"
  },
  {
    "country": "IL",
    "name": "Even Yehuda",
    "lat": "32.26959",
    "lng": "34.88759"
  },
  {
    "country": "IL",
    "name": "Tirah",
    "lat": "32.2341",
    "lng": "34.95023"
  },
  {
    "country": "IL",
    "name": "Eṭ Ṭaiyiba",
    "lat": "32.26616",
    "lng": "35.00893"
  },
  {
    "country": "IL",
    "name": "Esh Sheikh Dannūn",
    "lat": "32.9941",
    "lng": "35.14805"
  },
  {
    "country": "IL",
    "name": "Er Reina",
    "lat": "32.72339",
    "lng": "35.31622"
  },
  {
    "country": "IL",
    "name": "‘En Boqeq",
    "lat": "31.19941",
    "lng": "35.36253"
  },
  {
    "country": "IL",
    "name": "Elyakhin",
    "lat": "32.40793",
    "lng": "34.92433"
  },
  {
    "country": "IL",
    "name": "El Mazra‘a",
    "lat": "32.98338",
    "lng": "35.09837"
  },
  {
    "country": "IL",
    "name": "El Fureidīs",
    "lat": "32.59812",
    "lng": "34.95153"
  },
  {
    "country": "IL",
    "name": "Eilat",
    "lat": "29.55805",
    "lng": "34.94821"
  },
  {
    "country": "IL",
    "name": "‘Eilabun",
    "lat": "32.83693",
    "lng": "35.40029"
  },
  {
    "country": "IL",
    "name": "Dimona",
    "lat": "31.07079",
    "lng": "35.03269"
  },
  {
    "country": "IL",
    "name": "Deir Ḥannā",
    "lat": "32.86196",
    "lng": "35.36365"
  },
  {
    "country": "IL",
    "name": "Daliyat al Karmel",
    "lat": "32.69383",
    "lng": "35.04686"
  },
  {
    "country": "IL",
    "name": "Dabbūrīya",
    "lat": "32.69256",
    "lng": "35.37123"
  },
  {
    "country": "IL",
    "name": "Buqei‘a",
    "lat": "32.97747",
    "lng": "35.33345"
  },
  {
    "country": "IL",
    "name": "Bu‘eina",
    "lat": "32.80636",
    "lng": "35.36486"
  },
  {
    "country": "IL",
    "name": "Bīr el Maksūr",
    "lat": "32.77732",
    "lng": "35.22069"
  },
  {
    "country": "IL",
    "name": "Bet Yiẕẖaq",
    "lat": "32.32751",
    "lng": "34.88878"
  },
  {
    "country": "IL",
    "name": "Bet Shemesh",
    "lat": "31.73072",
    "lng": "34.99293"
  },
  {
    "country": "IL",
    "name": "Bet She’an",
    "lat": "32.49728",
    "lng": "35.49632"
  },
  {
    "country": "IL",
    "name": "Bet Dagan",
    "lat": "32.00191",
    "lng": "34.82977"
  },
  {
    "country": "IL",
    "name": "Bnei Brak",
    "lat": "32.08074",
    "lng": "34.8338"
  },
  {
    "country": "IL",
    "name": "Bnei Ayish",
    "lat": "31.78333",
    "lng": "34.75"
  },
  {
    "country": "IL",
    "name": "Beit Jann",
    "lat": "32.96464",
    "lng": "35.38152"
  },
  {
    "country": "IL",
    "name": "Beersheba",
    "lat": "31.25181",
    "lng": "34.7913"
  },
  {
    "country": "IL",
    "name": "Bat Yam",
    "lat": "32.02379",
    "lng": "34.75185"
  },
  {
    "country": "IL",
    "name": "Basmat Ṭab‘ūn",
    "lat": "32.73898",
    "lng": "35.15716"
  },
  {
    "country": "IL",
    "name": "Azor",
    "lat": "32.0243",
    "lng": "34.80632"
  },
  {
    "country": "IL",
    "name": "Atlit",
    "lat": "32.68889",
    "lng": "34.94236"
  },
  {
    "country": "IL",
    "name": "Ashkelon",
    "lat": "31.66926",
    "lng": "34.57149"
  },
  {
    "country": "IL",
    "name": "Ashdod",
    "lat": "31.79213",
    "lng": "34.64966"
  },
  {
    "country": "IL",
    "name": "Arad",
    "lat": "31.25882",
    "lng": "35.21282"
  },
  {
    "country": "IL",
    "name": "Acre",
    "lat": "32.92814",
    "lng": "35.07647"
  },
  {
    "country": "IL",
    "name": "Afula",
    "lat": "32.60907",
    "lng": "35.2892"
  },
  {
    "country": "IL",
    "name": "Abū Ghaush",
    "lat": "31.80592",
    "lng": "35.1093"
  },
  {
    "country": "IL",
    "name": "Shibli",
    "lat": "32.69464",
    "lng": "35.39252"
  },
  {
    "country": "IL",
    "name": "Rumat Heib",
    "lat": "32.77802",
    "lng": "35.30571"
  },
  {
    "country": "IL",
    "name": "Sallama",
    "lat": "32.89443",
    "lng": "35.36931"
  },
  {
    "country": "IL",
    "name": "Kefar Weradim",
    "lat": "32.99385",
    "lng": "35.27793"
  },
  {
    "country": "IL",
    "name": "Lehavim",
    "lat": "31.37284",
    "lng": "34.81619"
  },
  {
    "country": "IL",
    "name": "Midreshet Ben-Gurion",
    "lat": "30.85154",
    "lng": "34.7834"
  },
  {
    "country": "IL",
    "name": "Cesarea",
    "lat": "32.51888",
    "lng": "34.90459"
  },
  {
    "country": "IL",
    "name": "West Jerusalem",
    "lat": "31.78199",
    "lng": "35.21961"
  },
  {
    "country": "IL",
    "name": "Rahat",
    "lat": "31.39547",
    "lng": "34.75699"
  },
  {
    "country": "IL",
    "name": "Modiin Ilit",
    "lat": "31.93221",
    "lng": "35.04416"
  },
  {
    "country": "IL",
    "name": "Nof Ayalon",
    "lat": "31.87111",
    "lng": "34.99081"
  },
  {
    "country": "IL",
    "name": "Hashmonaim",
    "lat": "31.92973",
    "lng": "35.0215"
  },
  {
    "country": "IL",
    "name": "Lapid",
    "lat": "31.91764",
    "lng": "35.03222"
  },
  {
    "country": "IL",
    "name": "Kfar NaOranim",
    "lat": "31.91982",
    "lng": "35.03669"
  },
  {
    "country": "IL",
    "name": "Mevo horon",
    "lat": "31.84876",
    "lng": "35.03583"
  },
  {
    "country": "IL",
    "name": "Beit Horon",
    "lat": "31.87581",
    "lng": "35.12999"
  },
  {
    "country": "IL",
    "name": "Na'ale",
    "lat": "31.96236",
    "lng": "35.06553"
  },
  {
    "country": "IL",
    "name": "Giv'on HaHadasha",
    "lat": "31.84927",
    "lng": "35.16106"
  },
  {
    "country": "IL",
    "name": "Talmon",
    "lat": "31.93927",
    "lng": "35.13539"
  },
  {
    "country": "IL",
    "name": "Dolev",
    "lat": "31.92609",
    "lng": "35.13393"
  },
  {
    "country": "IL",
    "name": "Ariel",
    "lat": "32.1065",
    "lng": "35.18449"
  },
  {
    "country": "IL",
    "name": "Nirit",
    "lat": "32.14677",
    "lng": "34.98622"
  },
  {
    "country": "IL",
    "name": "Revava",
    "lat": "32.11926",
    "lng": "35.12896"
  },
  {
    "country": "IL",
    "name": "Shoham",
    "lat": "31.99866",
    "lng": "34.94559"
  },
  {
    "country": "IL",
    "name": "Herzliya Pituah",
    "lat": "32.17409",
    "lng": "34.8028"
  },
  {
    "country": "IL",
    "name": "Yehud-Monosson",
    "lat": "32.0284",
    "lng": "34.8796"
  },
  {
    "country": "IL",
    "name": "Kiryat Ono",
    "lat": "32.05503",
    "lng": "34.85789"
  },
  {
    "country": "IM",
    "name": "Santon",
    "lat": "54.11667",
    "lng": "-4.58333"
  },
  {
    "country": "IM",
    "name": "Ramsey",
    "lat": "54.32273",
    "lng": "-4.38526"
  },
  {
    "country": "IM",
    "name": "Port Saint Mary",
    "lat": "54.07405",
    "lng": "-4.73858"
  },
  {
    "country": "IM",
    "name": "Port Erin",
    "lat": "54.08487",
    "lng": "-4.75099"
  },
  {
    "country": "IM",
    "name": "Peel",
    "lat": "54.22209",
    "lng": "-4.69099"
  },
  {
    "country": "IM",
    "name": "Patrick",
    "lat": "54.20447",
    "lng": "-4.69417"
  },
  {
    "country": "IM",
    "name": "Onchan",
    "lat": "54.17329",
    "lng": "-4.45324"
  },
  {
    "country": "IM",
    "name": "Maughold",
    "lat": "54.29877",
    "lng": "-4.31844"
  },
  {
    "country": "IM",
    "name": "Lezayre",
    "lat": "54.31667",
    "lng": "-4.41667"
  },
  {
    "country": "IM",
    "name": "Laxey",
    "lat": "54.23017",
    "lng": "-4.39985"
  },
  {
    "country": "IM",
    "name": "Kirkmichael",
    "lat": "54.28562",
    "lng": "-4.58748"
  },
  {
    "country": "IM",
    "name": "Kirk Braddan",
    "lat": "54.16667",
    "lng": "-4.51667"
  },
  {
    "country": "IM",
    "name": "Jurby",
    "lat": "54.35941",
    "lng": "-4.52199"
  },
  {
    "country": "IM",
    "name": "Douglas",
    "lat": "54.15",
    "lng": "-4.48333"
  },
  {
    "country": "IM",
    "name": "Crosby",
    "lat": "54.18333",
    "lng": "-4.56667"
  },
  {
    "country": "IM",
    "name": "Castletown",
    "lat": "54.07445",
    "lng": "-4.65365"
  },
  {
    "country": "IM",
    "name": "Bride",
    "lat": "54.38256",
    "lng": "-4.38921"
  },
  {
    "country": "IM",
    "name": "Ballasalla",
    "lat": "54.0959",
    "lng": "-4.62962"
  },
  {
    "country": "IM",
    "name": "Ballabeg",
    "lat": "54.1",
    "lng": "-4.68333"
  },
  {
    "country": "IM",
    "name": "Andreas",
    "lat": "54.36667",
    "lng": "-4.43333"
  },
  {
    "country": "IM",
    "name": "Ballaugh",
    "lat": "54.31193",
    "lng": "-4.54456"
  },
  {
    "country": "IN",
    "name": "Thang",
    "lat": "34.9274",
    "lng": "76.79336"
  },
  {
    "country": "IN",
    "name": "Pūnch",
    "lat": "33.77033",
    "lng": "74.09254"
  },
  {
    "country": "IN",
    "name": "Keelakarai",
    "lat": "9.23183",
    "lng": "78.78545"
  },
  {
    "country": "IN",
    "name": "Zunheboto",
    "lat": "25.96667",
    "lng": "94.51667"
  },
  {
    "country": "IN",
    "name": "Ziro",
    "lat": "27.59497",
    "lng": "93.83854"
  },
  {
    "country": "IN",
    "name": "Zamānia",
    "lat": "25.41961",
    "lng": "83.55786"
  },
  {
    "country": "IN",
    "name": "Zaidpur",
    "lat": "26.83093",
    "lng": "81.32929"
  },
  {
    "country": "IN",
    "name": "Zahirābād",
    "lat": "17.68138",
    "lng": "77.60743"
  },
  {
    "country": "IN",
    "name": "Zafarābād",
    "lat": "25.69867",
    "lng": "82.73354"
  },
  {
    "country": "IN",
    "name": "Yol",
    "lat": "32.16423",
    "lng": "76.19622"
  },
  {
    "country": "IN",
    "name": "Yeola",
    "lat": "20.0424",
    "lng": "74.48944"
  },
  {
    "country": "IN",
    "name": "Yellāpur",
    "lat": "14.9637",
    "lng": "74.70929"
  },
  {
    "country": "IN",
    "name": "Yellandu",
    "lat": "17.59064",
    "lng": "80.32146"
  },
  {
    "country": "IN",
    "name": "Yelbarga",
    "lat": "15.61545",
    "lng": "76.01184"
  },
  {
    "country": "IN",
    "name": "Yelandūr",
    "lat": "12.04629",
    "lng": "77.03034"
  },
  {
    "country": "IN",
    "name": "Yelahanka",
    "lat": "13.10073",
    "lng": "77.59632"
  },
  {
    "country": "IN",
    "name": "Yavatmāl",
    "lat": "20.39324",
    "lng": "78.13201"
  },
  {
    "country": "IN",
    "name": "Yāval",
    "lat": "21.16772",
    "lng": "75.69762"
  },
  {
    "country": "IN",
    "name": "Yārāda",
    "lat": "17.65872",
    "lng": "83.27419"
  },
  {
    "country": "IN",
    "name": "Yanam",
    "lat": "16.73308",
    "lng": "82.21364"
  },
  {
    "country": "IN",
    "name": "Yamunānagar",
    "lat": "30.12796",
    "lng": "77.28371"
  },
  {
    "country": "IN",
    "name": "Yairipok",
    "lat": "24.67792",
    "lng": "94.04767"
  },
  {
    "country": "IN",
    "name": "Yādgīr",
    "lat": "16.77007",
    "lng": "77.13755"
  },
  {
    "country": "IN",
    "name": "Wokha",
    "lat": "26.09717",
    "lng": "94.25817"
  },
  {
    "country": "IN",
    "name": "Wer",
    "lat": "27.0186",
    "lng": "77.17636"
  },
  {
    "country": "IN",
    "name": "Wellington",
    "lat": "11.36552",
    "lng": "76.78442"
  },
  {
    "country": "IN",
    "name": "Wazīrganj",
    "lat": "28.21145",
    "lng": "79.05665"
  },
  {
    "country": "IN",
    "name": "Wāshīm",
    "lat": "20.11128",
    "lng": "77.133"
  },
  {
    "country": "IN",
    "name": "Warud",
    "lat": "21.47101",
    "lng": "78.26965"
  },
  {
    "country": "IN",
    "name": "Warora",
    "lat": "20.22885",
    "lng": "79.00277"
  },
  {
    "country": "IN",
    "name": "Wāris Alīganj",
    "lat": "25.0172",
    "lng": "85.64047"
  },
  {
    "country": "IN",
    "name": "Wardha",
    "lat": "20.73933",
    "lng": "78.59784"
  },
  {
    "country": "IN",
    "name": "Wārāseonī",
    "lat": "21.76184",
    "lng": "80.04301"
  },
  {
    "country": "IN",
    "name": "Warangal",
    "lat": "18",
    "lng": "79.58333"
  },
  {
    "country": "IN",
    "name": "Wanparti",
    "lat": "16.36738",
    "lng": "78.06889"
  },
  {
    "country": "IN",
    "name": "Wānkāner",
    "lat": "22.61198",
    "lng": "70.94379"
  },
  {
    "country": "IN",
    "name": "Wani",
    "lat": "20.05507",
    "lng": "78.95313"
  },
  {
    "country": "IN",
    "name": "Wāngjing",
    "lat": "24.58921",
    "lng": "94.06386"
  },
  {
    "country": "IN",
    "name": "Walajapet",
    "lat": "12.9251",
    "lng": "79.36626"
  },
  {
    "country": "IN",
    "name": "Wallajahbad",
    "lat": "12.79041",
    "lng": "79.82358"
  },
  {
    "country": "IN",
    "name": "Wai",
    "lat": "17.95276",
    "lng": "73.89058"
  },
  {
    "country": "IN",
    "name": "Waghāi",
    "lat": "20.77048",
    "lng": "73.50074"
  },
  {
    "country": "IN",
    "name": "Wādi",
    "lat": "17.05183",
    "lng": "76.99048"
  },
  {
    "country": "IN",
    "name": "Wadgaon",
    "lat": "18.7392",
    "lng": "73.63945"
  },
  {
    "country": "IN",
    "name": "Vyāra",
    "lat": "21.11079",
    "lng": "73.39365"
  },
  {
    "country": "IN",
    "name": "Vuyyūru",
    "lat": "16.36307",
    "lng": "80.84406"
  },
  {
    "country": "IN",
    "name": "Vrindāvan",
    "lat": "27.58105",
    "lng": "77.69662"
  },
  {
    "country": "IN",
    "name": "Vriddhāchalam",
    "lat": "11.5183",
    "lng": "79.32411"
  },
  {
    "country": "IN",
    "name": "Vizianagaram",
    "lat": "18.11692",
    "lng": "83.41148"
  },
  {
    "country": "IN",
    "name": "Vite",
    "lat": "17.27343",
    "lng": "74.53792"
  },
  {
    "country": "IN",
    "name": "Visnagar",
    "lat": "23.69855",
    "lng": "72.5521"
  },
  {
    "country": "IN",
    "name": "Visakhapatnam",
    "lat": "17.68009",
    "lng": "83.20161"
  },
  {
    "country": "IN",
    "name": "Vīsāvadar",
    "lat": "21.33954",
    "lng": "70.74966"
  },
  {
    "country": "IN",
    "name": "Virudunagar",
    "lat": "9.58509",
    "lng": "77.95787"
  },
  {
    "country": "IN",
    "name": "Virpur",
    "lat": "23.1892",
    "lng": "73.47987"
  },
  {
    "country": "IN",
    "name": "Vadakku Viravanallur",
    "lat": "8.69786",
    "lng": "77.51916"
  },
  {
    "country": "IN",
    "name": "Vīrarājendrapet",
    "lat": "12.19644",
    "lng": "75.80512"
  },
  {
    "country": "IN",
    "name": "Virār",
    "lat": "19.45591",
    "lng": "72.81136"
  },
  {
    "country": "IN",
    "name": "Vīraganūr",
    "lat": "11.47613",
    "lng": "78.73553"
  },
  {
    "country": "IN",
    "name": "Vinukonda",
    "lat": "16.0531",
    "lng": "79.73964"
  },
  {
    "country": "IN",
    "name": "Vinchia",
    "lat": "22.21027",
    "lng": "71.37967"
  },
  {
    "country": "IN",
    "name": "Villupuram",
    "lat": "11.93975",
    "lng": "79.49244"
  },
  {
    "country": "IN",
    "name": "Vilattikulam",
    "lat": "9.13227",
    "lng": "78.16635"
  },
  {
    "country": "IN",
    "name": "Vikravāndi",
    "lat": "12.0369",
    "lng": "79.54595"
  },
  {
    "country": "IN",
    "name": "Vikārābād",
    "lat": "17.3381",
    "lng": "77.90441"
  },
  {
    "country": "IN",
    "name": "Vijayawada",
    "lat": "16.50745",
    "lng": "80.6466"
  },
  {
    "country": "IN",
    "name": "Vijayapuri",
    "lat": "11.2453",
    "lng": "77.50066"
  },
  {
    "country": "IN",
    "name": "Vijāpur",
    "lat": "23.5623",
    "lng": "72.74848"
  },
  {
    "country": "IN",
    "name": "Vidisha",
    "lat": "23.52604",
    "lng": "77.81092"
  },
  {
    "country": "IN",
    "name": "Vettūr",
    "lat": "8.71742",
    "lng": "76.72582"
  },
  {
    "country": "IN",
    "name": "Vettavalam",
    "lat": "12.10769",
    "lng": "79.24516"
  },
  {
    "country": "IN",
    "name": "Vettaikkaranpudur",
    "lat": "10.56207",
    "lng": "76.91305"
  },
  {
    "country": "IN",
    "name": "Vetapālem",
    "lat": "15.78502",
    "lng": "80.30663"
  },
  {
    "country": "IN",
    "name": "Verāval",
    "lat": "20.9077",
    "lng": "70.36786"
  },
  {
    "country": "IN",
    "name": "Vepagunta",
    "lat": "17.77844",
    "lng": "83.21577"
  },
  {
    "country": "IN",
    "name": "Venkatagiri",
    "lat": "13.96005",
    "lng": "79.58032"
  },
  {
    "country": "IN",
    "name": "Vengurla",
    "lat": "15.86125",
    "lng": "73.63182"
  },
  {
    "country": "IN",
    "name": "Vemalwāda",
    "lat": "18.46523",
    "lng": "78.86894"
  },
  {
    "country": "IN",
    "name": "Velur",
    "lat": "11.10825",
    "lng": "78.00113"
  },
  {
    "country": "IN",
    "name": "Vellore",
    "lat": "12.9184",
    "lng": "79.13255"
  },
  {
    "country": "IN",
    "name": "Velankanni",
    "lat": "10.68333",
    "lng": "79.83333"
  },
  {
    "country": "IN",
    "name": "Vejalpur",
    "lat": "22.69021",
    "lng": "73.56299"
  },
  {
    "country": "IN",
    "name": "Vedasandūr",
    "lat": "10.53102",
    "lng": "77.95019"
  },
  {
    "country": "IN",
    "name": "Vedaraniyam",
    "lat": "10.37208",
    "lng": "79.85095"
  },
  {
    "country": "IN",
    "name": "Vayalār",
    "lat": "9.71158",
    "lng": "76.33888"
  },
  {
    "country": "IN",
    "name": "Vattalkundu",
    "lat": "10.16069",
    "lng": "77.75883"
  },
  {
    "country": "IN",
    "name": "Vāsudevanallūr",
    "lat": "9.24171",
    "lng": "77.41177"
  },
  {
    "country": "IN",
    "name": "Vasind",
    "lat": "19.40844",
    "lng": "73.26285"
  },
  {
    "country": "IN",
    "name": "Vasco da Gama",
    "lat": "15.39585",
    "lng": "73.81568"
  },
  {
    "country": "IN",
    "name": "Vasa",
    "lat": "22.66079",
    "lng": "72.75519"
  },
  {
    "country": "IN",
    "name": "Vartej",
    "lat": "21.73947",
    "lng": "72.06553"
  },
  {
    "country": "IN",
    "name": "Varkala",
    "lat": "8.7333",
    "lng": "76.7167"
  },
  {
    "country": "IN",
    "name": "Varca",
    "lat": "15.23237",
    "lng": "73.94311"
  },
  {
    "country": "IN",
    "name": "Varangaon",
    "lat": "21.01767",
    "lng": "75.91042"
  },
  {
    "country": "IN",
    "name": "Varanasi",
    "lat": "25.31668",
    "lng": "83.01041"
  },
  {
    "country": "IN",
    "name": "Vānsada",
    "lat": "20.75817",
    "lng": "73.36389"
  },
  {
    "country": "IN",
    "name": "Vaniyambadi",
    "lat": "12.68162",
    "lng": "78.62014"
  },
  {
    "country": "IN",
    "name": "Vandavāsi",
    "lat": "12.50429",
    "lng": "79.60556"
  },
  {
    "country": "IN",
    "name": "Vandalūr",
    "lat": "12.8924",
    "lng": "80.08079"
  },
  {
    "country": "IN",
    "name": "Valsād",
    "lat": "20.61013",
    "lng": "72.93428"
  },
  {
    "country": "IN",
    "name": "Valpoy",
    "lat": "15.53239",
    "lng": "74.13671"
  },
  {
    "country": "IN",
    "name": "Valparai",
    "lat": "10.32691",
    "lng": "76.95116"
  },
  {
    "country": "IN",
    "name": "Vallam",
    "lat": "10.71988",
    "lng": "79.05981"
  },
  {
    "country": "IN",
    "name": "Vallabh Vidyanagar",
    "lat": "22.53333",
    "lng": "72.9"
  },
  {
    "country": "IN",
    "name": "Valavanur",
    "lat": "11.92094",
    "lng": "79.58239"
  },
  {
    "country": "IN",
    "name": "Azhikkal",
    "lat": "11.91524",
    "lng": "75.34761"
  },
  {
    "country": "IN",
    "name": "Valangaiman",
    "lat": "10.89012",
    "lng": "79.39322"
  },
  {
    "country": "IN",
    "name": "Valabhīpur",
    "lat": "21.88868",
    "lng": "71.87935"
  },
  {
    "country": "IN",
    "name": "Vaikam",
    "lat": "9.74858",
    "lng": "76.39637"
  },
  {
    "country": "IN",
    "name": "Vaijāpur",
    "lat": "19.92672",
    "lng": "74.7275"
  },
  {
    "country": "IN",
    "name": "Vāghodia",
    "lat": "22.30505",
    "lng": "73.40016"
  },
  {
    "country": "IN",
    "name": "Vadodara",
    "lat": "22.29941",
    "lng": "73.20812"
  },
  {
    "country": "IN",
    "name": "Vadnagar",
    "lat": "23.78593",
    "lng": "72.63893"
  },
  {
    "country": "IN",
    "name": "Vadlapūdi",
    "lat": "14.31119",
    "lng": "79.8043"
  },
  {
    "country": "IN",
    "name": "Vādippatti",
    "lat": "10.08481",
    "lng": "77.96113"
  },
  {
    "country": "IN",
    "name": "Vadamadurai",
    "lat": "10.44081",
    "lng": "78.09784"
  },
  {
    "country": "IN",
    "name": "Vadakku Valliyūr",
    "lat": "8.38286",
    "lng": "77.61221"
  },
  {
    "country": "IN",
    "name": "Vāda",
    "lat": "19.65347",
    "lng": "73.14811"
  },
  {
    "country": "IN",
    "name": "Ūttukkuli",
    "lat": "11.16892",
    "lng": "77.45431"
  },
  {
    "country": "IN",
    "name": "Uttiramerūr",
    "lat": "12.61433",
    "lng": "79.75748"
  },
  {
    "country": "IN",
    "name": "Uttarkāshi",
    "lat": "30.72986",
    "lng": "78.44342"
  },
  {
    "country": "IN",
    "name": "Uttamapālaiyam",
    "lat": "9.80701",
    "lng": "77.32718"
  },
  {
    "country": "IN",
    "name": "Utraula",
    "lat": "27.31933",
    "lng": "82.41872"
  },
  {
    "country": "IN",
    "name": "Utrān",
    "lat": "21.23333",
    "lng": "72.86667"
  },
  {
    "country": "IN",
    "name": "Usilampatti",
    "lat": "9.96936",
    "lng": "77.78621"
  },
  {
    "country": "IN",
    "name": "Usehat",
    "lat": "27.79796",
    "lng": "79.23763"
  },
  {
    "country": "IN",
    "name": "Uri",
    "lat": "34.08064",
    "lng": "74.05088"
  },
  {
    "country": "IN",
    "name": "Uravakonda",
    "lat": "14.94348",
    "lng": "77.25494"
  },
  {
    "country": "IN",
    "name": "Uran",
    "lat": "18.87813",
    "lng": "72.93924"
  },
  {
    "country": "IN",
    "name": "Uppiliyapuram",
    "lat": "11.26356",
    "lng": "78.5139"
  },
  {
    "country": "IN",
    "name": "Upleta",
    "lat": "21.74015",
    "lng": "70.28256"
  },
  {
    "country": "IN",
    "name": "Uppal Kalan",
    "lat": "17.40577",
    "lng": "78.55911"
  },
  {
    "country": "IN",
    "name": "Unnāo",
    "lat": "26.54706",
    "lng": "80.48781"
  },
  {
    "country": "IN",
    "name": "Unjha",
    "lat": "23.80366",
    "lng": "72.39101"
  },
  {
    "country": "IN",
    "name": "Uniāra",
    "lat": "26.15336",
    "lng": "75.21523"
  },
  {
    "country": "IN",
    "name": "Unhel",
    "lat": "23.33794",
    "lng": "75.55931"
  },
  {
    "country": "IN",
    "name": "Una",
    "lat": "31.46493",
    "lng": "76.26914"
  },
  {
    "country": "IN",
    "name": "Una",
    "lat": "20.82318",
    "lng": "71.03795"
  },
  {
    "country": "IN",
    "name": "Ūn",
    "lat": "29.58479",
    "lng": "77.2554"
  },
  {
    "country": "IN",
    "name": "Un",
    "lat": "23.88745",
    "lng": "71.76975"
  },
  {
    "country": "IN",
    "name": "Umri",
    "lat": "26.51056",
    "lng": "78.93667"
  },
  {
    "country": "IN",
    "name": "Umreth",
    "lat": "22.69881",
    "lng": "73.11561"
  },
  {
    "country": "IN",
    "name": "Umred",
    "lat": "20.85396",
    "lng": "79.32466"
  },
  {
    "country": "IN",
    "name": "Umrāla",
    "lat": "21.84353",
    "lng": "71.80305"
  },
  {
    "country": "IN",
    "name": "Umarkot",
    "lat": "19.66529",
    "lng": "82.20629"
  },
  {
    "country": "IN",
    "name": "Umarkhed",
    "lat": "19.60144",
    "lng": "77.68878"
  },
  {
    "country": "IN",
    "name": "Umaria",
    "lat": "23.52473",
    "lng": "80.83716"
  },
  {
    "country": "IN",
    "name": "Umarga",
    "lat": "17.83841",
    "lng": "76.62331"
  },
  {
    "country": "IN",
    "name": "Ullal",
    "lat": "12.80569",
    "lng": "74.86058"
  },
  {
    "country": "IN",
    "name": "Ulhasnagar",
    "lat": "19.21667",
    "lng": "73.15"
  },
  {
    "country": "IN",
    "name": "Ukwā",
    "lat": "21.97102",
    "lng": "80.46625"
  },
  {
    "country": "IN",
    "name": "Uklāna",
    "lat": "29.51124",
    "lng": "75.87823"
  },
  {
    "country": "IN",
    "name": "Ujjain",
    "lat": "23.18239",
    "lng": "75.77643"
  },
  {
    "country": "IN",
    "name": "Ujhāni",
    "lat": "28.00311",
    "lng": "79.00821"
  },
  {
    "country": "IN",
    "name": "Ugu",
    "lat": "26.79681",
    "lng": "80.32093"
  },
  {
    "country": "IN",
    "name": "Udumalaippettai",
    "lat": "10.58806",
    "lng": "77.24779"
  },
  {
    "country": "IN",
    "name": "Udpura",
    "lat": "24.73355",
    "lng": "75.97514"
  },
  {
    "country": "IN",
    "name": "Udupi",
    "lat": "13.33467",
    "lng": "74.74617"
  },
  {
    "country": "IN",
    "name": "Udhampur",
    "lat": "32.92431",
    "lng": "75.13573"
  },
  {
    "country": "IN",
    "name": "Udgīr",
    "lat": "18.39258",
    "lng": "77.11756"
  },
  {
    "country": "IN",
    "name": "Udangudi",
    "lat": "8.42918",
    "lng": "78.02968"
  },
  {
    "country": "IN",
    "name": "Udalguri",
    "lat": "26.75367",
    "lng": "92.10215"
  },
  {
    "country": "IN",
    "name": "Udaipura",
    "lat": "23.07434",
    "lng": "78.51108"
  },
  {
    "country": "IN",
    "name": "Udaipur",
    "lat": "27.72297",
    "lng": "75.47178"
  },
  {
    "country": "IN",
    "name": "Udaipur",
    "lat": "24.58584",
    "lng": "73.71346"
  },
  {
    "country": "IN",
    "name": "Udaipur",
    "lat": "23.53333",
    "lng": "91.48333"
  },
  {
    "country": "IN",
    "name": "Udayagiri",
    "lat": "20.12416",
    "lng": "84.36869"
  },
  {
    "country": "IN",
    "name": "Ooty",
    "lat": "11.4134",
    "lng": "76.69521"
  },
  {
    "country": "IN",
    "name": "Bara Uchāna",
    "lat": "29.46747",
    "lng": "76.17798"
  },
  {
    "country": "IN",
    "name": "Turuvekere",
    "lat": "13.16374",
    "lng": "76.66641"
  },
  {
    "country": "IN",
    "name": "Turaiyūr",
    "lat": "11.14968",
    "lng": "78.5987"
  },
  {
    "country": "IN",
    "name": "Tura",
    "lat": "25.51421",
    "lng": "90.20239"
  },
  {
    "country": "IN",
    "name": "Tuni",
    "lat": "17.35905",
    "lng": "82.54607"
  },
  {
    "country": "IN",
    "name": "Tūndla",
    "lat": "27.2146",
    "lng": "78.23683"
  },
  {
    "country": "IN",
    "name": "Tumsar",
    "lat": "21.38333",
    "lng": "79.73333"
  },
  {
    "country": "IN",
    "name": "Tumkūr",
    "lat": "13.34136",
    "lng": "77.1022"
  },
  {
    "country": "IN",
    "name": "Tulsīpur",
    "lat": "27.5337",
    "lng": "82.41653"
  },
  {
    "country": "IN",
    "name": "Tuljāpur",
    "lat": "18.00804",
    "lng": "76.07011"
  },
  {
    "country": "IN",
    "name": "Tufānganj",
    "lat": "26.31688",
    "lng": "89.66549"
  },
  {
    "country": "IN",
    "name": "Tuensang",
    "lat": "26.26704",
    "lng": "94.82415"
  },
  {
    "country": "IN",
    "name": "Tsrār Sharīf",
    "lat": "33.86319",
    "lng": "74.76524"
  },
  {
    "country": "IN",
    "name": "Thiruvananthapuram",
    "lat": "8.4855",
    "lng": "76.94924"
  },
  {
    "country": "IN",
    "name": "Trimbak",
    "lat": "19.93268",
    "lng": "73.52907"
  },
  {
    "country": "IN",
    "name": "Trichūr",
    "lat": "10.51667",
    "lng": "76.21667"
  },
  {
    "country": "IN",
    "name": "Trāl",
    "lat": "33.92708",
    "lng": "75.11585"
  },
  {
    "country": "IN",
    "name": "Toshām",
    "lat": "28.86993",
    "lng": "75.9165"
  },
  {
    "country": "IN",
    "name": "Tori-Fatehpur",
    "lat": "25.45505",
    "lng": "79.11428"
  },
  {
    "country": "IN",
    "name": "Topchānchi",
    "lat": "23.90381",
    "lng": "86.19792"
  },
  {
    "country": "IN",
    "name": "Tonk",
    "lat": "26.16638",
    "lng": "75.78824"
  },
  {
    "country": "IN",
    "name": "Tondi",
    "lat": "9.74173",
    "lng": "79.01774"
  },
  {
    "country": "IN",
    "name": "Tohāna",
    "lat": "29.71332",
    "lng": "75.90441"
  },
  {
    "country": "IN",
    "name": "Todaraisingh",
    "lat": "26.02401",
    "lng": "75.48182"
  },
  {
    "country": "IN",
    "name": "Todabhim",
    "lat": "26.91667",
    "lng": "76.81667"
  },
  {
    "country": "IN",
    "name": "Titron",
    "lat": "29.66824",
    "lng": "77.32391"
  },
  {
    "country": "IN",
    "name": "Titlāgarh",
    "lat": "20.28961",
    "lng": "83.15233"
  },
  {
    "country": "IN",
    "name": "Titāgarh",
    "lat": "22.74252",
    "lng": "88.37326"
  },
  {
    "country": "IN",
    "name": "Titābar",
    "lat": "26.6014",
    "lng": "94.20386"
  },
  {
    "country": "IN",
    "name": "Tisaiyanvilai",
    "lat": "8.33702",
    "lng": "77.86776"
  },
  {
    "country": "IN",
    "name": "Tiruvottiyūr",
    "lat": "13.15823",
    "lng": "80.30181"
  },
  {
    "country": "IN",
    "name": "Thiruvidaimaruthur",
    "lat": "10.99857",
    "lng": "79.45227"
  },
  {
    "country": "IN",
    "name": "Cheyyar",
    "lat": "12.66052",
    "lng": "79.54308"
  },
  {
    "country": "IN",
    "name": "Tiruvannāmalai",
    "lat": "12.22662",
    "lng": "79.07461"
  },
  {
    "country": "IN",
    "name": "Tiruvallur",
    "lat": "13.14376",
    "lng": "79.90889"
  },
  {
    "country": "IN",
    "name": "Tiruvalla",
    "lat": "9.3816",
    "lng": "76.57489"
  },
  {
    "country": "IN",
    "name": "Thiruthani",
    "lat": "13.17594",
    "lng": "79.61637"
  },
  {
    "country": "IN",
    "name": "Tiruttangal",
    "lat": "9.48333",
    "lng": "77.83333"
  },
  {
    "country": "IN",
    "name": "Tirur",
    "lat": "10.91368",
    "lng": "75.92118"
  },
  {
    "country": "IN",
    "name": "Tiruppuvanam",
    "lat": "9.82564",
    "lng": "78.25795"
  },
  {
    "country": "IN",
    "name": "Tiruppur",
    "lat": "11.11541",
    "lng": "77.35456"
  },
  {
    "country": "IN",
    "name": "Tirupparangunram",
    "lat": "9.88151",
    "lng": "78.07306"
  },
  {
    "country": "IN",
    "name": "Tiruppālaikudi",
    "lat": "9.54606",
    "lng": "78.91721"
  },
  {
    "country": "IN",
    "name": "Tirupati",
    "lat": "13.63551",
    "lng": "79.41989"
  },
  {
    "country": "IN",
    "name": "Tirunelveli",
    "lat": "8.72742",
    "lng": "77.6838"
  },
  {
    "country": "IN",
    "name": "Tirumullaivāsal",
    "lat": "11.23996",
    "lng": "79.83705"
  },
  {
    "country": "IN",
    "name": "Tirumala",
    "lat": "13.68333",
    "lng": "79.35"
  },
  {
    "country": "IN",
    "name": "Tirumakūdal Narsipur",
    "lat": "12.21207",
    "lng": "76.9018"
  },
  {
    "country": "IN",
    "name": "Tirukkoyilur",
    "lat": "11.9662",
    "lng": "79.20259"
  },
  {
    "country": "IN",
    "name": "Thirukattupalli",
    "lat": "10.84431",
    "lng": "78.95647"
  },
  {
    "country": "IN",
    "name": "Tiruchengode",
    "lat": "11.38016",
    "lng": "77.89444"
  },
  {
    "country": "IN",
    "name": "Tiruchirappalli",
    "lat": "10.8155",
    "lng": "78.69651"
  },
  {
    "country": "IN",
    "name": "Tiruchchendur",
    "lat": "8.49725",
    "lng": "78.11906"
  },
  {
    "country": "IN",
    "name": "Tīrthahalli",
    "lat": "13.68835",
    "lng": "75.24548"
  },
  {
    "country": "IN",
    "name": "Tirodi",
    "lat": "21.68522",
    "lng": "79.71906"
  },
  {
    "country": "IN",
    "name": "Tīra Sujānpur",
    "lat": "31.83364",
    "lng": "76.50539"
  },
  {
    "country": "IN",
    "name": "Tiptūr",
    "lat": "13.2563",
    "lng": "76.47768"
  },
  {
    "country": "IN",
    "name": "Tinsukia",
    "lat": "27.48905",
    "lng": "95.35992"
  },
  {
    "country": "IN",
    "name": "Tinnanūr",
    "lat": "13.11448",
    "lng": "80.02713"
  },
  {
    "country": "IN",
    "name": "Tindwāri",
    "lat": "25.61739",
    "lng": "80.52718"
  },
  {
    "country": "IN",
    "name": "Tindivanam",
    "lat": "12.234",
    "lng": "79.65551"
  },
  {
    "country": "IN",
    "name": "Tilhar",
    "lat": "27.96282",
    "lng": "79.73827"
  },
  {
    "country": "IN",
    "name": "Tīkri",
    "lat": "29.2291",
    "lng": "77.35479"
  },
  {
    "country": "IN",
    "name": "Tīkamgarh",
    "lat": "24.74327",
    "lng": "78.83061"
  },
  {
    "country": "IN",
    "name": "Tikaitnagar",
    "lat": "26.94612",
    "lng": "81.56583"
  },
  {
    "country": "IN",
    "name": "Tijāra",
    "lat": "27.93411",
    "lng": "76.85541"
  },
  {
    "country": "IN",
    "name": "Thoubāl",
    "lat": "24.63881",
    "lng": "93.99639"
  },
  {
    "country": "IN",
    "name": "Thiruvarur",
    "lat": "10.77269",
    "lng": "79.6368"
  },
  {
    "country": "IN",
    "name": "Thiruvaiyaru",
    "lat": "10.88405",
    "lng": "79.10362"
  },
  {
    "country": "IN",
    "name": "Theog",
    "lat": "31.12155",
    "lng": "77.35838"
  },
  {
    "country": "IN",
    "name": "Thenzawl",
    "lat": "23.31667",
    "lng": "92.75"
  },
  {
    "country": "IN",
    "name": "Thāsra",
    "lat": "22.79831",
    "lng": "73.21174"
  },
  {
    "country": "IN",
    "name": "Tharād",
    "lat": "24.39597",
    "lng": "71.62577"
  },
  {
    "country": "IN",
    "name": "Thanniyam",
    "lat": "10.41667",
    "lng": "76.13333"
  },
  {
    "country": "IN",
    "name": "Thanna Mandi",
    "lat": "33.54204",
    "lng": "74.381"
  },
  {
    "country": "IN",
    "name": "Tanjore",
    "lat": "10.78523",
    "lng": "79.13909"
  },
  {
    "country": "IN",
    "name": "Thānesar",
    "lat": "29.97323",
    "lng": "76.83214"
  },
  {
    "country": "IN",
    "name": "Thāne",
    "lat": "19.19704",
    "lng": "72.96355"
  },
  {
    "country": "IN",
    "name": "Thandla",
    "lat": "23.00959",
    "lng": "74.57747"
  },
  {
    "country": "IN",
    "name": "Thāna Bhawan",
    "lat": "29.58605",
    "lng": "77.41811"
  },
  {
    "country": "IN",
    "name": "Thān",
    "lat": "22.57422",
    "lng": "71.19942"
  },
  {
    "country": "IN",
    "name": "Thākurganj",
    "lat": "26.42742",
    "lng": "88.13112"
  },
  {
    "country": "IN",
    "name": "Thakurdwara",
    "lat": "29.19203",
    "lng": "78.86145"
  },
  {
    "country": "IN",
    "name": "Tezu",
    "lat": "27.91256",
    "lng": "96.12882"
  },
  {
    "country": "IN",
    "name": "Tezpur",
    "lat": "26.63333",
    "lng": "92.8"
  },
  {
    "country": "IN",
    "name": "Terdāl",
    "lat": "16.49379",
    "lng": "75.04667"
  },
  {
    "country": "IN",
    "name": "Teonthar",
    "lat": "24.98207",
    "lng": "81.64194"
  },
  {
    "country": "IN",
    "name": "Thenkasi",
    "lat": "8.96003",
    "lng": "77.31525"
  },
  {
    "country": "IN",
    "name": "Teni",
    "lat": "10.01115",
    "lng": "77.47772"
  },
  {
    "country": "IN",
    "name": "Tendūkheda",
    "lat": "23.3962",
    "lng": "79.53947"
  },
  {
    "country": "IN",
    "name": "Tellicherry",
    "lat": "11.74811",
    "lng": "75.4929"
  },
  {
    "country": "IN",
    "name": "Telhāra",
    "lat": "21.02694",
    "lng": "76.83889"
  },
  {
    "country": "IN",
    "name": "Tekkali",
    "lat": "18.6057",
    "lng": "84.23546"
  },
  {
    "country": "IN",
    "name": "Tekkalakote",
    "lat": "15.53444",
    "lng": "76.87703"
  },
  {
    "country": "IN",
    "name": "Tekāri",
    "lat": "24.94253",
    "lng": "84.84265"
  },
  {
    "country": "IN",
    "name": "Tekanpur",
    "lat": "25.99401",
    "lng": "78.28322"
  },
  {
    "country": "IN",
    "name": "Tehri",
    "lat": "30.39086",
    "lng": "78.4803"
  },
  {
    "country": "IN",
    "name": "Teghra",
    "lat": "25.49043",
    "lng": "85.94001"
  },
  {
    "country": "IN",
    "name": "Tawang",
    "lat": "27.57417",
    "lng": "91.92437"
  },
  {
    "country": "IN",
    "name": "Tāttayyangārpettai",
    "lat": "11.12417",
    "lng": "78.44916"
  },
  {
    "country": "IN",
    "name": "Tāsgaon",
    "lat": "17.037",
    "lng": "74.60171"
  },
  {
    "country": "IN",
    "name": "Tarn Tāran",
    "lat": "31.45191",
    "lng": "74.92777"
  },
  {
    "country": "IN",
    "name": "Tarikere",
    "lat": "13.70954",
    "lng": "75.81382"
  },
  {
    "country": "IN",
    "name": "Tārāpur",
    "lat": "19.86499",
    "lng": "72.68426"
  },
  {
    "country": "IN",
    "name": "Tharangambadi",
    "lat": "11.02764",
    "lng": "79.85425"
  },
  {
    "country": "IN",
    "name": "Tārānagar",
    "lat": "28.6686",
    "lng": "75.03207"
  },
  {
    "country": "IN",
    "name": "Tarāna",
    "lat": "23.33383",
    "lng": "76.04253"
  },
  {
    "country": "IN",
    "name": "Tāramangalam",
    "lat": "11.69403",
    "lng": "77.97035"
  },
  {
    "country": "IN",
    "name": "Tarakeswar",
    "lat": "22.88605",
    "lng": "88.01363"
  },
  {
    "country": "IN",
    "name": "Tarabha",
    "lat": "20.73252",
    "lng": "83.67443"
  },
  {
    "country": "IN",
    "name": "Tāoru",
    "lat": "28.21173",
    "lng": "76.94984"
  },
  {
    "country": "IN",
    "name": "Tanuku",
    "lat": "16.75438",
    "lng": "81.68143"
  },
  {
    "country": "IN",
    "name": "Tankāra",
    "lat": "22.65622",
    "lng": "70.74945"
  },
  {
    "country": "IN",
    "name": "Tāndūr",
    "lat": "17.24849",
    "lng": "77.57698"
  },
  {
    "country": "IN",
    "name": "Tānda",
    "lat": "28.97621",
    "lng": "78.94187"
  },
  {
    "country": "IN",
    "name": "Tāndā",
    "lat": "26.54953",
    "lng": "82.65841"
  },
  {
    "country": "IN",
    "name": "Tanakpur",
    "lat": "29.074",
    "lng": "80.11139"
  },
  {
    "country": "IN",
    "name": "Tamlūk",
    "lat": "22.30083",
    "lng": "87.92593"
  },
  {
    "country": "IN",
    "name": "Tambaram",
    "lat": "12.9246",
    "lng": "80.12707"
  },
  {
    "country": "IN",
    "name": "Talwāra",
    "lat": "31.9376",
    "lng": "75.88657"
  },
  {
    "country": "IN",
    "name": "Talwandi Bhai",
    "lat": "30.85584",
    "lng": "74.92979"
  },
  {
    "country": "IN",
    "name": "Taloda",
    "lat": "21.56128",
    "lng": "74.21238"
  },
  {
    "country": "IN",
    "name": "Talipparamba",
    "lat": "12.04161",
    "lng": "75.35927"
  },
  {
    "country": "IN",
    "name": "Tālīkota",
    "lat": "16.47311",
    "lng": "76.31085"
  },
  {
    "country": "IN",
    "name": "Tālgrām",
    "lat": "27.04753",
    "lng": "79.64811"
  },
  {
    "country": "IN",
    "name": "Talen",
    "lat": "23.56949",
    "lng": "76.72821"
  },
  {
    "country": "IN",
    "name": "Taleigao",
    "lat": "15.46915",
    "lng": "73.83285"
  },
  {
    "country": "IN",
    "name": "Talegaon Dābhāde",
    "lat": "18.73502",
    "lng": "73.67561"
  },
  {
    "country": "IN",
    "name": "Tālcher",
    "lat": "20.94927",
    "lng": "85.23354"
  },
  {
    "country": "IN",
    "name": "Tālbahat",
    "lat": "25.04357",
    "lng": "78.43441"
  },
  {
    "country": "IN",
    "name": "Talāja",
    "lat": "21.3527",
    "lng": "72.03524"
  },
  {
    "country": "IN",
    "name": "Tāl",
    "lat": "23.71979",
    "lng": "75.38514"
  },
  {
    "country": "IN",
    "name": "Tāki",
    "lat": "22.58867",
    "lng": "88.93253"
  },
  {
    "country": "IN",
    "name": "Takhatpur",
    "lat": "22.12915",
    "lng": "81.86959"
  },
  {
    "country": "IN",
    "name": "Takhatgarh",
    "lat": "25.32235",
    "lng": "73.00487"
  },
  {
    "country": "IN",
    "name": "Tājpur",
    "lat": "29.16242",
    "lng": "78.48458"
  },
  {
    "country": "IN",
    "name": "Tādpatri",
    "lat": "14.90832",
    "lng": "78.01031"
  },
  {
    "country": "IN",
    "name": "Tādepallegūdem",
    "lat": "16.81467",
    "lng": "81.52717"
  },
  {
    "country": "IN",
    "name": "Tādepalle",
    "lat": "16.48333",
    "lng": "80.6"
  },
  {
    "country": "IN",
    "name": "Swāmimalai",
    "lat": "10.95747",
    "lng": "79.32931"
  },
  {
    "country": "IN",
    "name": "Susner",
    "lat": "23.94667",
    "lng": "76.08825"
  },
  {
    "country": "IN",
    "name": "Suriāpet",
    "lat": "17.14054",
    "lng": "79.62045"
  },
  {
    "country": "IN",
    "name": "Suriānwān",
    "lat": "25.46387",
    "lng": "82.41922"
  },
  {
    "country": "IN",
    "name": "Surgāna",
    "lat": "20.55956",
    "lng": "73.63747"
  },
  {
    "country": "IN",
    "name": "Surendranagar",
    "lat": "22.72706",
    "lng": "71.64856"
  },
  {
    "country": "IN",
    "name": "Sūratgarh",
    "lat": "29.3215",
    "lng": "73.89979"
  },
  {
    "country": "IN",
    "name": "Sūrat",
    "lat": "21.19594",
    "lng": "72.83023"
  },
  {
    "country": "IN",
    "name": "Sūrandai",
    "lat": "8.97574",
    "lng": "77.41923"
  },
  {
    "country": "IN",
    "name": "Surajpur",
    "lat": "23.21347",
    "lng": "82.86836"
  },
  {
    "country": "IN",
    "name": "Sūrajgarh",
    "lat": "28.31005",
    "lng": "75.73271"
  },
  {
    "country": "IN",
    "name": "Supaul",
    "lat": "26.11527",
    "lng": "86.59509"
  },
  {
    "country": "IN",
    "name": "Suntikoppa",
    "lat": "12.45594",
    "lng": "75.8297"
  },
  {
    "country": "IN",
    "name": "Sunel",
    "lat": "24.37065",
    "lng": "75.95708"
  },
  {
    "country": "IN",
    "name": "Sundarnagar",
    "lat": "31.53523",
    "lng": "76.905"
  },
  {
    "country": "IN",
    "name": "Sundargarh",
    "lat": "22.11667",
    "lng": "84.03333"
  },
  {
    "country": "IN",
    "name": "Sunām",
    "lat": "30.12883",
    "lng": "75.79943"
  },
  {
    "country": "IN",
    "name": "Sumbal",
    "lat": "34.23072",
    "lng": "74.6472"
  },
  {
    "country": "IN",
    "name": "Sulya",
    "lat": "12.561",
    "lng": "75.38741"
  },
  {
    "country": "IN",
    "name": "Sūlūru",
    "lat": "13.7",
    "lng": "80.01667"
  },
  {
    "country": "IN",
    "name": "Sulur",
    "lat": "11.02427",
    "lng": "77.12565"
  },
  {
    "country": "IN",
    "name": "Sultanpur",
    "lat": "31.21468",
    "lng": "75.19602"
  },
  {
    "country": "IN",
    "name": "Sultānpur",
    "lat": "29.75534",
    "lng": "78.11034"
  },
  {
    "country": "IN",
    "name": "Sultānpur",
    "lat": "26.25788",
    "lng": "82.07269"
  },
  {
    "country": "IN",
    "name": "Sultānpur",
    "lat": "23.13812",
    "lng": "77.93404"
  },
  {
    "country": "IN",
    "name": "Sukma",
    "lat": "18.39014",
    "lng": "81.65941"
  },
  {
    "country": "IN",
    "name": "Suket",
    "lat": "24.64609",
    "lng": "76.0417"
  },
  {
    "country": "IN",
    "name": "Sūjāngarh",
    "lat": "27.7",
    "lng": "74.46667"
  },
  {
    "country": "IN",
    "name": "Suchindram",
    "lat": "8.15442",
    "lng": "77.46704"
  },
  {
    "country": "IN",
    "name": "Suār",
    "lat": "29.02841",
    "lng": "79.05654"
  },
  {
    "country": "IN",
    "name": "Srivilliputhur",
    "lat": "9.51272",
    "lng": "77.63369"
  },
  {
    "country": "IN",
    "name": "Srīvardhan",
    "lat": "18.04592",
    "lng": "73.01552"
  },
  {
    "country": "IN",
    "name": "Srivaikuntam",
    "lat": "8.62931",
    "lng": "77.91281"
  },
  {
    "country": "IN",
    "name": "Srīsailain",
    "lat": "16.07217",
    "lng": "78.86816"
  },
  {
    "country": "IN",
    "name": "Srīrāmnagar",
    "lat": "17.26652",
    "lng": "78.25544"
  },
  {
    "country": "IN",
    "name": "Srīperumbūdūr",
    "lat": "12.96763",
    "lng": "79.94197"
  },
  {
    "country": "IN",
    "name": "Srīnivāspur",
    "lat": "13.33914",
    "lng": "78.21175"
  },
  {
    "country": "IN",
    "name": "Sringeri",
    "lat": "13.41698",
    "lng": "75.25271"
  },
  {
    "country": "IN",
    "name": "Srinagar",
    "lat": "34.08565",
    "lng": "74.80555"
  },
  {
    "country": "IN",
    "name": "Srīnagar",
    "lat": "30.22243",
    "lng": "78.78341"
  },
  {
    "country": "IN",
    "name": "Srīmushnam",
    "lat": "11.40118",
    "lng": "79.40384"
  },
  {
    "country": "IN",
    "name": "Sri Mādhopur",
    "lat": "27.46599",
    "lng": "75.59736"
  },
  {
    "country": "IN",
    "name": "Karanpur",
    "lat": "29.84042",
    "lng": "73.45519"
  },
  {
    "country": "IN",
    "name": "Chicacole",
    "lat": "18.2989",
    "lng": "83.89751"
  },
  {
    "country": "IN",
    "name": "Sri Dūngargarh",
    "lat": "28.09617",
    "lng": "74.00868"
  },
  {
    "country": "IN",
    "name": "Soygaon",
    "lat": "20.59606",
    "lng": "75.61765"
  },
  {
    "country": "IN",
    "name": "Soron",
    "lat": "27.89055",
    "lng": "78.74621"
  },
  {
    "country": "IN",
    "name": "Soro",
    "lat": "21.27851",
    "lng": "86.68833"
  },
  {
    "country": "IN",
    "name": "Sorbhog",
    "lat": "26.48612",
    "lng": "90.8859"
  },
  {
    "country": "IN",
    "name": "Sorada",
    "lat": "19.76082",
    "lng": "84.42997"
  },
  {
    "country": "IN",
    "name": "Sorab",
    "lat": "14.38144",
    "lng": "75.09183"
  },
  {
    "country": "IN",
    "name": "Sopur",
    "lat": "34.28671",
    "lng": "74.47228"
  },
  {
    "country": "IN",
    "name": "Sonīpat",
    "lat": "28.99478",
    "lng": "77.01937"
  },
  {
    "country": "IN",
    "name": "Songadh",
    "lat": "21.16966",
    "lng": "73.56357"
  },
  {
    "country": "IN",
    "name": "Sonepur",
    "lat": "20.83333",
    "lng": "83.91667"
  },
  {
    "country": "IN",
    "name": "Sonegaon",
    "lat": "20.62915",
    "lng": "78.69207"
  },
  {
    "country": "IN",
    "name": "Sonāri",
    "lat": "27.02462",
    "lng": "95.01629"
  },
  {
    "country": "IN",
    "name": "Sonāmura",
    "lat": "23.47547",
    "lng": "91.2659"
  },
  {
    "country": "IN",
    "name": "Sonāmukhi",
    "lat": "23.30521",
    "lng": "87.41336"
  },
  {
    "country": "IN",
    "name": "Somvārpet",
    "lat": "12.59698",
    "lng": "75.84957"
  },
  {
    "country": "IN",
    "name": "Sompeta",
    "lat": "18.94419",
    "lng": "84.58449"
  },
  {
    "country": "IN",
    "name": "Someshwar",
    "lat": "13.49112",
    "lng": "75.06646"
  },
  {
    "country": "IN",
    "name": "Solim",
    "lat": "15.61521",
    "lng": "73.7674"
  },
  {
    "country": "IN",
    "name": "Solan",
    "lat": "30.90908",
    "lng": "77.10869"
  },
  {
    "country": "IN",
    "name": "Sojītra",
    "lat": "22.53884",
    "lng": "72.71984"
  },
  {
    "country": "IN",
    "name": "Sojat",
    "lat": "25.92493",
    "lng": "73.66633"
  },
  {
    "country": "IN",
    "name": "Sohna",
    "lat": "28.24737",
    "lng": "77.06544"
  },
  {
    "country": "IN",
    "name": "Sohāgpur",
    "lat": "22.70055",
    "lng": "78.19522"
  },
  {
    "country": "IN",
    "name": "Sohāgi",
    "lat": "24.98181",
    "lng": "81.69558"
  },
  {
    "country": "IN",
    "name": "Sodpur",
    "lat": "22.70428",
    "lng": "88.39166"
  },
  {
    "country": "IN",
    "name": "Soalkuchi",
    "lat": "26.16806",
    "lng": "91.57111"
  },
  {
    "country": "IN",
    "name": "Siwāna",
    "lat": "25.65154",
    "lng": "72.42243"
  },
  {
    "country": "IN",
    "name": "Siwān",
    "lat": "26.22096",
    "lng": "84.35609"
  },
  {
    "country": "IN",
    "name": "Sivakasi",
    "lat": "9.44999",
    "lng": "77.79797"
  },
  {
    "country": "IN",
    "name": "Sivagiri",
    "lat": "11.12026",
    "lng": "77.78811"
  },
  {
    "country": "IN",
    "name": "Sivagiri",
    "lat": "9.34461",
    "lng": "77.42911"
  },
  {
    "country": "IN",
    "name": "Sivaganga",
    "lat": "9.84701",
    "lng": "78.48358"
  },
  {
    "country": "IN",
    "name": "Siuri",
    "lat": "23.90806",
    "lng": "87.52773"
  },
  {
    "country": "IN",
    "name": "Sitārganj",
    "lat": "28.9293",
    "lng": "79.70436"
  },
  {
    "country": "IN",
    "name": "Sītāpur",
    "lat": "27.56192",
    "lng": "80.68265"
  },
  {
    "country": "IN",
    "name": "Sītāmau",
    "lat": "24.01473",
    "lng": "75.35324"
  },
  {
    "country": "IN",
    "name": "Sītāmarhi",
    "lat": "26.59357",
    "lng": "85.4906"
  },
  {
    "country": "IN",
    "name": "Siswā Bāzār",
    "lat": "27.14652",
    "lng": "83.75803"
  },
  {
    "country": "IN",
    "name": "Sisauli",
    "lat": "29.41386",
    "lng": "77.4689"
  },
  {
    "country": "IN",
    "name": "Sirūr",
    "lat": "18.8276",
    "lng": "74.37475"
  },
  {
    "country": "IN",
    "name": "Sirumugai",
    "lat": "11.32137",
    "lng": "77.00521"
  },
  {
    "country": "IN",
    "name": "Siruguppa",
    "lat": "15.63",
    "lng": "76.89217"
  },
  {
    "country": "IN",
    "name": "Sirsilla",
    "lat": "18.38865",
    "lng": "78.81048"
  },
  {
    "country": "IN",
    "name": "Sirsi",
    "lat": "28.63916",
    "lng": "78.64303"
  },
  {
    "country": "IN",
    "name": "Sirsi",
    "lat": "14.62072",
    "lng": "74.83554"
  },
  {
    "country": "IN",
    "name": "Sirsāganj",
    "lat": "27.05715",
    "lng": "78.68661"
  },
  {
    "country": "IN",
    "name": "Sirsa",
    "lat": "29.53489",
    "lng": "75.02898"
  },
  {
    "country": "IN",
    "name": "Sirsā",
    "lat": "25.2634",
    "lng": "82.0919"
  },
  {
    "country": "IN",
    "name": "Sirpur",
    "lat": "19.47953",
    "lng": "79.57558"
  },
  {
    "country": "IN",
    "name": "Sironj",
    "lat": "24.10313",
    "lng": "77.69055"
  },
  {
    "country": "IN",
    "name": "Sirohi",
    "lat": "24.88838",
    "lng": "72.84794"
  },
  {
    "country": "IN",
    "name": "Sirmaur",
    "lat": "24.83648",
    "lng": "81.36448"
  },
  {
    "country": "IN",
    "name": "Sīrkāzhi",
    "lat": "11.23725",
    "lng": "79.73585"
  },
  {
    "country": "IN",
    "name": "Sirhind",
    "lat": "30.64321",
    "lng": "76.38421"
  },
  {
    "country": "IN",
    "name": "Sirāthu",
    "lat": "25.64292",
    "lng": "81.31855"
  },
  {
    "country": "IN",
    "name": "Sīra",
    "lat": "13.74155",
    "lng": "76.9043"
  },
  {
    "country": "IN",
    "name": "Sinor",
    "lat": "21.91117",
    "lng": "73.33974"
  },
  {
    "country": "IN",
    "name": "Sinnar",
    "lat": "19.84505",
    "lng": "73.99866"
  },
  {
    "country": "IN",
    "name": "Sini",
    "lat": "22.79325",
    "lng": "85.94543"
  },
  {
    "country": "IN",
    "name": "Singur",
    "lat": "22.80917",
    "lng": "88.22944"
  },
  {
    "country": "IN",
    "name": "Singtam",
    "lat": "27.23467",
    "lng": "88.50168"
  },
  {
    "country": "IN",
    "name": "Singoli",
    "lat": "24.96667",
    "lng": "75.3"
  },
  {
    "country": "IN",
    "name": "Singarāyakonda",
    "lat": "15.23046",
    "lng": "80.02794"
  },
  {
    "country": "IN",
    "name": "Singapperumālkovil",
    "lat": "12.75947",
    "lng": "80.0075"
  },
  {
    "country": "IN",
    "name": "Singānallūr",
    "lat": "10.99898",
    "lng": "77.03238"
  },
  {
    "country": "IN",
    "name": "Sindi",
    "lat": "20.80509",
    "lng": "78.88752"
  },
  {
    "country": "IN",
    "name": "Sindhnūr",
    "lat": "15.76983",
    "lng": "76.75581"
  },
  {
    "country": "IN",
    "name": "Sindgi",
    "lat": "16.91883",
    "lng": "76.23368"
  },
  {
    "country": "IN",
    "name": "Shimla",
    "lat": "31.10442",
    "lng": "77.16662"
  },
  {
    "country": "IN",
    "name": "Simga",
    "lat": "21.6281",
    "lng": "81.70376"
  },
  {
    "country": "IN",
    "name": "Simdega",
    "lat": "22.61523",
    "lng": "84.50208"
  },
  {
    "country": "IN",
    "name": "Simaria",
    "lat": "24.79497",
    "lng": "81.152"
  },
  {
    "country": "IN",
    "name": "Silvassa",
    "lat": "20.27386",
    "lng": "72.99673"
  },
  {
    "country": "IN",
    "name": "Sillod",
    "lat": "20.30303",
    "lng": "75.65284"
  },
  {
    "country": "IN",
    "name": "Silchar",
    "lat": "24.82733",
    "lng": "92.79787"
  },
  {
    "country": "IN",
    "name": "Silao",
    "lat": "25.08358",
    "lng": "85.42804"
  },
  {
    "country": "IN",
    "name": "Sīkar",
    "lat": "27.61206",
    "lng": "75.13996"
  },
  {
    "country": "IN",
    "name": "Sikandra Rao",
    "lat": "27.68859",
    "lng": "78.37985"
  },
  {
    "country": "IN",
    "name": "Sikandra",
    "lat": "26.36722",
    "lng": "79.6298"
  },
  {
    "country": "IN",
    "name": "Sikandarpur",
    "lat": "26.04327",
    "lng": "84.05298"
  },
  {
    "country": "IN",
    "name": "Sikandarābād",
    "lat": "28.45226",
    "lng": "77.70004"
  },
  {
    "country": "IN",
    "name": "Sikka",
    "lat": "22.43218",
    "lng": "69.84158"
  },
  {
    "country": "IN",
    "name": "Sijua",
    "lat": "23.77617",
    "lng": "86.33028"
  },
  {
    "country": "IN",
    "name": "Sihorā",
    "lat": "23.4871",
    "lng": "80.10404"
  },
  {
    "country": "IN",
    "name": "Sihor",
    "lat": "21.71134",
    "lng": "71.96179"
  },
  {
    "country": "IN",
    "name": "Sidlaghatta",
    "lat": "13.38896",
    "lng": "77.86444"
  },
  {
    "country": "IN",
    "name": "Sidhpura",
    "lat": "27.63312",
    "lng": "78.86918"
  },
  {
    "country": "IN",
    "name": "Sidhi",
    "lat": "24.4038",
    "lng": "81.87954"
  },
  {
    "country": "IN",
    "name": "Sidhaulī",
    "lat": "27.28202",
    "lng": "80.8345"
  },
  {
    "country": "IN",
    "name": "Siddipet",
    "lat": "18.10483",
    "lng": "78.84858"
  },
  {
    "country": "IN",
    "name": "Siddhapur",
    "lat": "23.91783",
    "lng": "72.37212"
  },
  {
    "country": "IN",
    "name": "Siddāpur",
    "lat": "14.34322",
    "lng": "74.894"
  },
  {
    "country": "IN",
    "name": "Sibsāgar",
    "lat": "26.98427",
    "lng": "94.63784"
  },
  {
    "country": "IN",
    "name": "Shyamnagar",
    "lat": "22.83333",
    "lng": "88.36667"
  },
  {
    "country": "IN",
    "name": "Shupīyan",
    "lat": "33.71723",
    "lng": "74.83413"
  },
  {
    "country": "IN",
    "name": "Shujālpur",
    "lat": "23.40673",
    "lng": "76.7098"
  },
  {
    "country": "IN",
    "name": "Shrīrangapattana",
    "lat": "12.42264",
    "lng": "76.68439"
  },
  {
    "country": "IN",
    "name": "Shrīrāmpur",
    "lat": "22.75278",
    "lng": "88.34222"
  },
  {
    "country": "IN",
    "name": "Shrīgonda",
    "lat": "18.61527",
    "lng": "74.69895"
  },
  {
    "country": "IN",
    "name": "Srāvana Belgola",
    "lat": "12.85737",
    "lng": "76.48886"
  },
  {
    "country": "IN",
    "name": "Shorāpur",
    "lat": "16.521",
    "lng": "76.75738"
  },
  {
    "country": "IN",
    "name": "Shōranūr",
    "lat": "10.76181",
    "lng": "76.27078"
  },
  {
    "country": "IN",
    "name": "Sholinghur",
    "lat": "13.1181",
    "lng": "79.42025"
  },
  {
    "country": "IN",
    "name": "Solāpur",
    "lat": "17.67152",
    "lng": "75.91044"
  },
  {
    "country": "IN",
    "name": "Shivrājpur",
    "lat": "22.42319",
    "lng": "73.60865"
  },
  {
    "country": "IN",
    "name": "Shivpuri",
    "lat": "25.42378",
    "lng": "77.66223"
  },
  {
    "country": "IN",
    "name": "Shīshgarh",
    "lat": "28.72928",
    "lng": "79.31469"
  },
  {
    "country": "IN",
    "name": "Shirwal",
    "lat": "18.15059",
    "lng": "73.97788"
  },
  {
    "country": "IN",
    "name": "Shirpur",
    "lat": "21.34821",
    "lng": "74.88035"
  },
  {
    "country": "IN",
    "name": "Shirhatti",
    "lat": "15.23352",
    "lng": "75.57996"
  },
  {
    "country": "IN",
    "name": "Shirgaon",
    "lat": "19.69589",
    "lng": "72.71527"
  },
  {
    "country": "IN",
    "name": "Shirdi",
    "lat": "19.76616",
    "lng": "74.47738"
  },
  {
    "country": "IN",
    "name": "Shimoga",
    "lat": "13.93157",
    "lng": "75.56791"
  },
  {
    "country": "IN",
    "name": "Shillong",
    "lat": "25.56892",
    "lng": "91.88313"
  },
  {
    "country": "IN",
    "name": "Shiliguri",
    "lat": "26.71004",
    "lng": "88.42851"
  },
  {
    "country": "IN",
    "name": "Shikohābād",
    "lat": "27.108",
    "lng": "78.58661"
  },
  {
    "country": "IN",
    "name": "Shikārpūr",
    "lat": "28.28072",
    "lng": "78.01411"
  },
  {
    "country": "IN",
    "name": "Shikārpur",
    "lat": "14.2698",
    "lng": "75.35643"
  },
  {
    "country": "IN",
    "name": "Shiggaon",
    "lat": "14.99053",
    "lng": "75.22499"
  },
  {
    "country": "IN",
    "name": "Shertallai",
    "lat": "9.68581",
    "lng": "76.33996"
  },
  {
    "country": "IN",
    "name": "Sherkot",
    "lat": "29.32704",
    "lng": "78.57429"
  },
  {
    "country": "IN",
    "name": "Sherghāti",
    "lat": "24.5595",
    "lng": "84.79162"
  },
  {
    "country": "IN",
    "name": "Shergarh",
    "lat": "28.65128",
    "lng": "79.36815"
  },
  {
    "country": "IN",
    "name": "Sheopur",
    "lat": "25.66472",
    "lng": "76.69616"
  },
  {
    "country": "IN",
    "name": "Sheohar",
    "lat": "26.51393",
    "lng": "85.29341"
  },
  {
    "country": "IN",
    "name": "Sheoganj",
    "lat": "25.13915",
    "lng": "73.06784"
  },
  {
    "country": "IN",
    "name": "Shegaon",
    "lat": "20.7932",
    "lng": "76.69921"
  },
  {
    "country": "IN",
    "name": "Shāntipur",
    "lat": "23.24723",
    "lng": "88.43302"
  },
  {
    "country": "IN",
    "name": "Shankargarh",
    "lat": "25.182",
    "lng": "81.61769"
  },
  {
    "country": "IN",
    "name": "Shamsābād",
    "lat": "27.5371",
    "lng": "79.43796"
  },
  {
    "country": "IN",
    "name": "Shamsābād",
    "lat": "27.01718",
    "lng": "78.12358"
  },
  {
    "country": "IN",
    "name": "Shāmli",
    "lat": "29.4497",
    "lng": "77.30959"
  },
  {
    "country": "IN",
    "name": "Shāmgarh",
    "lat": "24.18817",
    "lng": "75.63903"
  },
  {
    "country": "IN",
    "name": "Shām Churāsi",
    "lat": "31.50028",
    "lng": "75.74917"
  },
  {
    "country": "IN",
    "name": "Shājāpur",
    "lat": "23.42637",
    "lng": "76.27775"
  },
  {
    "country": "IN",
    "name": "Sheikhpura",
    "lat": "25.13994",
    "lng": "85.84096"
  },
  {
    "country": "IN",
    "name": "Shāhpura",
    "lat": "27.3912",
    "lng": "75.95956"
  },
  {
    "country": "IN",
    "name": "Shāhpura",
    "lat": "25.62094",
    "lng": "74.92487"
  },
  {
    "country": "IN",
    "name": "Shāhpura",
    "lat": "23.13663",
    "lng": "79.66402"
  },
  {
    "country": "IN",
    "name": "Shāhpur",
    "lat": "29.3501",
    "lng": "77.5516"
  },
  {
    "country": "IN",
    "name": "Shāhpur",
    "lat": "25.60293",
    "lng": "84.40412"
  },
  {
    "country": "IN",
    "name": "Shāhpur",
    "lat": "23.89371",
    "lng": "79.05074"
  },
  {
    "country": "IN",
    "name": "Shāhpur",
    "lat": "23.02446",
    "lng": "81.0038"
  },
  {
    "country": "IN",
    "name": "Shāhpur",
    "lat": "22.19526",
    "lng": "77.90682"
  },
  {
    "country": "IN",
    "name": "Shāhpur",
    "lat": "22.15611",
    "lng": "70.77068"
  },
  {
    "country": "IN",
    "name": "Shāhpur",
    "lat": "21.23742",
    "lng": "76.22558"
  },
  {
    "country": "IN",
    "name": "Shāhpur",
    "lat": "16.69605",
    "lng": "76.8422"
  },
  {
    "country": "IN",
    "name": "Shāhkot",
    "lat": "31.08173",
    "lng": "75.33708"
  },
  {
    "country": "IN",
    "name": "Shāhjānpur",
    "lat": "27.88165",
    "lng": "79.90918"
  },
  {
    "country": "IN",
    "name": "Shāhi",
    "lat": "28.55023",
    "lng": "79.31761"
  },
  {
    "country": "IN",
    "name": "Shāhgarh",
    "lat": "24.31365",
    "lng": "79.11806"
  },
  {
    "country": "IN",
    "name": "Shāhganj",
    "lat": "26.04965",
    "lng": "82.68423"
  },
  {
    "country": "IN",
    "name": "Shahdol",
    "lat": "23.29356",
    "lng": "81.3619"
  },
  {
    "country": "IN",
    "name": "Shāhāpur",
    "lat": "19.45231",
    "lng": "73.32572"
  },
  {
    "country": "IN",
    "name": "Shāhāda",
    "lat": "21.54538",
    "lng": "74.47106"
  },
  {
    "country": "IN",
    "name": "Shāhābād",
    "lat": "30.16776",
    "lng": "76.87046"
  },
  {
    "country": "IN",
    "name": "Shāhābād",
    "lat": "28.56681",
    "lng": "79.00956"
  },
  {
    "country": "IN",
    "name": "Shāhābād",
    "lat": "27.6431",
    "lng": "79.9402"
  },
  {
    "country": "IN",
    "name": "Shāhābād",
    "lat": "17.1307",
    "lng": "76.94361"
  },
  {
    "country": "IN",
    "name": "Serula",
    "lat": "15.54774",
    "lng": "73.84329"
  },
  {
    "country": "IN",
    "name": "Serchhīp",
    "lat": "23.29312",
    "lng": "92.84679"
  },
  {
    "country": "IN",
    "name": "Seram",
    "lat": "17.17859",
    "lng": "77.28998"
  },
  {
    "country": "IN",
    "name": "Seorīnārāyan",
    "lat": "21.72055",
    "lng": "82.59344"
  },
  {
    "country": "IN",
    "name": "Seoni Mālwa",
    "lat": "22.45046",
    "lng": "77.4665"
  },
  {
    "country": "IN",
    "name": "Seoni",
    "lat": "31.24188",
    "lng": "77.12362"
  },
  {
    "country": "IN",
    "name": "Seoni",
    "lat": "22.08503",
    "lng": "79.55037"
  },
  {
    "country": "IN",
    "name": "Seondha",
    "lat": "26.15422",
    "lng": "78.7812"
  },
  {
    "country": "IN",
    "name": "Seohāra",
    "lat": "29.20904",
    "lng": "78.58837"
  },
  {
    "country": "IN",
    "name": "Sendhwa",
    "lat": "21.68562",
    "lng": "75.09622"
  },
  {
    "country": "IN",
    "name": "Sehore",
    "lat": "23.2",
    "lng": "77.08333"
  },
  {
    "country": "IN",
    "name": "Secunderabad",
    "lat": "17.50427",
    "lng": "78.54263"
  },
  {
    "country": "IN",
    "name": "Sāyla",
    "lat": "22.54925",
    "lng": "71.48324"
  },
  {
    "country": "IN",
    "name": "Sāyalkudi",
    "lat": "9.16925",
    "lng": "78.44702"
  },
  {
    "country": "IN",
    "name": "Sawāi Mādhopur",
    "lat": "26.02301",
    "lng": "76.34408"
  },
  {
    "country": "IN",
    "name": "Sāvda",
    "lat": "21.15054",
    "lng": "75.88938"
  },
  {
    "country": "IN",
    "name": "Savanūr",
    "lat": "14.97335",
    "lng": "75.33724"
  },
  {
    "country": "IN",
    "name": "Sāvantvādi",
    "lat": "15.90413",
    "lng": "73.82191"
  },
  {
    "country": "IN",
    "name": "Sausar",
    "lat": "21.65576",
    "lng": "78.79669"
  },
  {
    "country": "IN",
    "name": "Saurikh",
    "lat": "27.03051",
    "lng": "79.48813"
  },
  {
    "country": "IN",
    "name": "Saundatti",
    "lat": "15.76615",
    "lng": "75.11778"
  },
  {
    "country": "IN",
    "name": "Sathyamangalam",
    "lat": "11.50526",
    "lng": "77.23826"
  },
  {
    "country": "IN",
    "name": "Satwās",
    "lat": "22.53628",
    "lng": "76.68452"
  },
  {
    "country": "IN",
    "name": "Sattur",
    "lat": "9.35592",
    "lng": "77.92457"
  },
  {
    "country": "IN",
    "name": "Sattenapalle",
    "lat": "16.39381",
    "lng": "80.15221"
  },
  {
    "country": "IN",
    "name": "Sathankulam",
    "lat": "8.44164",
    "lng": "77.91349"
  },
  {
    "country": "IN",
    "name": "Satrikh",
    "lat": "26.86045",
    "lng": "81.19567"
  },
  {
    "country": "IN",
    "name": "Satna",
    "lat": "24.57726",
    "lng": "80.82719"
  },
  {
    "country": "IN",
    "name": "Satara",
    "lat": "17.68589",
    "lng": "73.99333"
  },
  {
    "country": "IN",
    "name": "Satānā",
    "lat": "20.59483",
    "lng": "74.20301"
  },
  {
    "country": "IN",
    "name": "Sāsvad",
    "lat": "18.34351",
    "lng": "74.03102"
  },
  {
    "country": "IN",
    "name": "Sāsni",
    "lat": "27.70287",
    "lng": "78.08278"
  },
  {
    "country": "IN",
    "name": "Sarwār",
    "lat": "26.06272",
    "lng": "75.01104"
  },
  {
    "country": "IN",
    "name": "Sāruberā",
    "lat": "23.81813",
    "lng": "85.99628"
  },
  {
    "country": "IN",
    "name": "Sarkhej",
    "lat": "22.98297",
    "lng": "72.50196"
  },
  {
    "country": "IN",
    "name": "Sarka Ghāt",
    "lat": "31.69887",
    "lng": "76.73529"
  },
  {
    "country": "IN",
    "name": "Sarīla",
    "lat": "25.77579",
    "lng": "79.67535"
  },
  {
    "country": "IN",
    "name": "Sargūr",
    "lat": "11.99971",
    "lng": "76.39611"
  },
  {
    "country": "IN",
    "name": "Sardulgarh",
    "lat": "29.69224",
    "lng": "75.23608"
  },
  {
    "country": "IN",
    "name": "Sardhana",
    "lat": "29.14551",
    "lng": "77.61433"
  },
  {
    "country": "IN",
    "name": "Sardārshahr",
    "lat": "28.44062",
    "lng": "74.491"
  },
  {
    "country": "IN",
    "name": "Sarauli",
    "lat": "28.49404",
    "lng": "79.09177"
  },
  {
    "country": "IN",
    "name": "Sārangpur",
    "lat": "23.56651",
    "lng": "76.47306"
  },
  {
    "country": "IN",
    "name": "Sārangarh",
    "lat": "21.58614",
    "lng": "83.0785"
  },
  {
    "country": "IN",
    "name": "Saraipali",
    "lat": "21.3153",
    "lng": "83.00629"
  },
  {
    "country": "IN",
    "name": "Sarāi Mīr",
    "lat": "26.02705",
    "lng": "82.91843"
  },
  {
    "country": "IN",
    "name": "Saraikela",
    "lat": "22.69963",
    "lng": "85.93126"
  },
  {
    "country": "IN",
    "name": "Sarai Ekdil",
    "lat": "26.74442",
    "lng": "79.09353"
  },
  {
    "country": "IN",
    "name": "Sarāi Ākil",
    "lat": "25.3789",
    "lng": "81.51035"
  },
  {
    "country": "IN",
    "name": "Sarāhan",
    "lat": "31.50988",
    "lng": "77.79395"
  },
  {
    "country": "IN",
    "name": "Sapatgrām",
    "lat": "26.33732",
    "lng": "90.1236"
  },
  {
    "country": "IN",
    "name": "Saoner",
    "lat": "21.3851",
    "lng": "78.92155"
  },
  {
    "country": "IN",
    "name": "Sānwer",
    "lat": "22.97415",
    "lng": "75.8271"
  },
  {
    "country": "IN",
    "name": "Sanvordem",
    "lat": "15.26269",
    "lng": "74.11965"
  },
  {
    "country": "IN",
    "name": "Santoshpur",
    "lat": "22.52038",
    "lng": "88.26973"
  },
  {
    "country": "IN",
    "name": "Santokhgarh",
    "lat": "31.35205",
    "lng": "76.31775"
  },
  {
    "country": "IN",
    "name": "Sanquelim",
    "lat": "15.56422",
    "lng": "74.00799"
  },
  {
    "country": "IN",
    "name": "Sānkrāil",
    "lat": "22.54997",
    "lng": "88.22515"
  },
  {
    "country": "IN",
    "name": "Sankheda",
    "lat": "22.17021",
    "lng": "73.5782"
  },
  {
    "country": "IN",
    "name": "Sankeshwar",
    "lat": "16.25649",
    "lng": "74.48195"
  },
  {
    "country": "IN",
    "name": "Sanivārsante",
    "lat": "12.72824",
    "lng": "75.88669"
  },
  {
    "country": "IN",
    "name": "Sanguem",
    "lat": "15.22901",
    "lng": "74.15149"
  },
  {
    "country": "IN",
    "name": "Sangrūr",
    "lat": "30.24506",
    "lng": "75.84488"
  },
  {
    "country": "IN",
    "name": "Sāngola",
    "lat": "17.43948",
    "lng": "75.19379"
  },
  {
    "country": "IN",
    "name": "Sangod",
    "lat": "24.92707",
    "lng": "76.28649"
  },
  {
    "country": "IN",
    "name": "Sāngli",
    "lat": "16.85438",
    "lng": "74.56417"
  },
  {
    "country": "IN",
    "name": "Sangariā",
    "lat": "29.79886",
    "lng": "74.46683"
  },
  {
    "country": "IN",
    "name": "Sangāreddi",
    "lat": "17.62477",
    "lng": "78.08669"
  },
  {
    "country": "IN",
    "name": "Sangamner",
    "lat": "19.56784",
    "lng": "74.21154"
  },
  {
    "country": "IN",
    "name": "Sandūr",
    "lat": "15.08613",
    "lng": "76.54692"
  },
  {
    "country": "IN",
    "name": "Sandīla",
    "lat": "27.06989",
    "lng": "80.51497"
  },
  {
    "country": "IN",
    "name": "Sāndi",
    "lat": "27.28867",
    "lng": "79.9519"
  },
  {
    "country": "IN",
    "name": "Sancoale",
    "lat": "15.37794",
    "lng": "73.90352"
  },
  {
    "country": "IN",
    "name": "Sānchor",
    "lat": "24.75361",
    "lng": "71.7728"
  },
  {
    "country": "IN",
    "name": "Sānchi",
    "lat": "23.48646",
    "lng": "77.7378"
  },
  {
    "country": "IN",
    "name": "Sanāwad",
    "lat": "22.17391",
    "lng": "76.06993"
  },
  {
    "country": "IN",
    "name": "Sanaur",
    "lat": "30.30182",
    "lng": "76.45786"
  },
  {
    "country": "IN",
    "name": "Sānand",
    "lat": "22.99227",
    "lng": "72.38177"
  },
  {
    "country": "IN",
    "name": "Samthar",
    "lat": "25.84348",
    "lng": "78.90683"
  },
  {
    "country": "IN",
    "name": "Samrāla",
    "lat": "30.83601",
    "lng": "76.19324"
  },
  {
    "country": "IN",
    "name": "Samdari",
    "lat": "25.81299",
    "lng": "72.57879"
  },
  {
    "country": "IN",
    "name": "Sāmbhar",
    "lat": "26.90806",
    "lng": "75.19137"
  },
  {
    "country": "IN",
    "name": "Sambhal",
    "lat": "28.58498",
    "lng": "78.56959"
  },
  {
    "country": "IN",
    "name": "Sambalpur",
    "lat": "21.46527",
    "lng": "83.97573"
  },
  {
    "country": "IN",
    "name": "Sāmba",
    "lat": "32.56245",
    "lng": "75.11993"
  },
  {
    "country": "IN",
    "name": "Samāstipur",
    "lat": "25.86222",
    "lng": "85.77953"
  },
  {
    "country": "IN",
    "name": "Sāmalkot",
    "lat": "17.05675",
    "lng": "82.17639"
  },
  {
    "country": "IN",
    "name": "Samālkha",
    "lat": "29.23552",
    "lng": "77.01273"
  },
  {
    "country": "IN",
    "name": "Sālūr",
    "lat": "18.51716",
    "lng": "83.20548"
  },
  {
    "country": "IN",
    "name": "Sālūmbar",
    "lat": "24.13524",
    "lng": "74.04442"
  },
  {
    "country": "IN",
    "name": "Salon",
    "lat": "26.02857",
    "lng": "81.45403"
  },
  {
    "country": "IN",
    "name": "Saligao",
    "lat": "15.55359",
    "lng": "73.79036"
  },
  {
    "country": "IN",
    "name": "Salem",
    "lat": "11.65376",
    "lng": "78.15538"
  },
  {
    "country": "IN",
    "name": "Salāya",
    "lat": "22.31038",
    "lng": "69.60376"
  },
  {
    "country": "IN",
    "name": "Saktī",
    "lat": "22.02662",
    "lng": "82.96091"
  },
  {
    "country": "IN",
    "name": "Sakleshpur",
    "lat": "12.94119",
    "lng": "75.78467"
  },
  {
    "country": "IN",
    "name": "Sakīt",
    "lat": "27.43463",
    "lng": "78.77903"
  },
  {
    "country": "IN",
    "name": "Sāitlaw",
    "lat": "23.97187",
    "lng": "92.57454"
  },
  {
    "country": "IN",
    "name": "Sairang",
    "lat": "23.81034",
    "lng": "92.65226"
  },
  {
    "country": "IN",
    "name": "Saint Thomas Mount",
    "lat": "13.00334",
    "lng": "80.19614"
  },
  {
    "country": "IN",
    "name": "Sainthia",
    "lat": "23.94826",
    "lng": "87.68045"
  },
  {
    "country": "IN",
    "name": "Selu",
    "lat": "19.45512",
    "lng": "76.44073"
  },
  {
    "country": "IN",
    "name": "Sailāna",
    "lat": "23.46219",
    "lng": "74.92318"
  },
  {
    "country": "IN",
    "name": "Saiha",
    "lat": "22.49183",
    "lng": "92.98143"
  },
  {
    "country": "IN",
    "name": "Saidpur",
    "lat": "28.61089",
    "lng": "77.90896"
  },
  {
    "country": "IN",
    "name": "Saidpur",
    "lat": "25.53749",
    "lng": "83.22378"
  },
  {
    "country": "IN",
    "name": "Sāhibganj",
    "lat": "25.24425",
    "lng": "87.63481"
  },
  {
    "country": "IN",
    "name": "Sahāwar",
    "lat": "27.79603",
    "lng": "78.83373"
  },
  {
    "country": "IN",
    "name": "Sahaswān",
    "lat": "28.07227",
    "lng": "78.75082"
  },
  {
    "country": "IN",
    "name": "Sahaspur",
    "lat": "29.12125",
    "lng": "78.62273"
  },
  {
    "country": "IN",
    "name": "Saharsa",
    "lat": "25.87498",
    "lng": "86.59611"
  },
  {
    "country": "IN",
    "name": "Sahāranpur",
    "lat": "29.9679",
    "lng": "77.54522"
  },
  {
    "country": "IN",
    "name": "Sagauli",
    "lat": "26.7639",
    "lng": "84.74341"
  },
  {
    "country": "IN",
    "name": "Saugor",
    "lat": "23.83877",
    "lng": "78.73874"
  },
  {
    "country": "IN",
    "name": "Sāgar",
    "lat": "14.16498",
    "lng": "75.02901"
  },
  {
    "country": "IN",
    "name": "Safīpur",
    "lat": "26.73783",
    "lng": "80.3435"
  },
  {
    "country": "IN",
    "name": "Safidon",
    "lat": "29.40596",
    "lng": "76.67042"
  },
  {
    "country": "IN",
    "name": "Sādri",
    "lat": "25.18555",
    "lng": "73.45288"
  },
  {
    "country": "IN",
    "name": "Sādāt",
    "lat": "25.67117",
    "lng": "83.30269"
  },
  {
    "country": "IN",
    "name": "Sadāseopet",
    "lat": "17.61925",
    "lng": "77.95263"
  },
  {
    "country": "IN",
    "name": "Sadalgi",
    "lat": "16.5587",
    "lng": "74.53211"
  },
  {
    "country": "IN",
    "name": "Sadābād",
    "lat": "27.43818",
    "lng": "78.03758"
  },
  {
    "country": "IN",
    "name": "Sachīn",
    "lat": "21.08718",
    "lng": "72.88153"
  },
  {
    "country": "IN",
    "name": "Sabrūm",
    "lat": "23.00153",
    "lng": "91.72427"
  },
  {
    "country": "IN",
    "name": "Sabāthu",
    "lat": "30.97494",
    "lng": "76.99137"
  },
  {
    "country": "IN",
    "name": "Sabalgarh",
    "lat": "26.24918",
    "lng": "77.40786"
  },
  {
    "country": "IN",
    "name": "Rusera",
    "lat": "25.75355",
    "lng": "86.02597"
  },
  {
    "country": "IN",
    "name": "Rura",
    "lat": "26.49001",
    "lng": "79.90108"
  },
  {
    "country": "IN",
    "name": "Ropar",
    "lat": "30.96896",
    "lng": "76.52695"
  },
  {
    "country": "IN",
    "name": "Rudraprayāg",
    "lat": "30.28467",
    "lng": "78.98354"
  },
  {
    "country": "IN",
    "name": "Rūdarpur",
    "lat": "26.44467",
    "lng": "83.61302"
  },
  {
    "country": "IN",
    "name": "Roorkee",
    "lat": "29.86632",
    "lng": "77.89118"
  },
  {
    "country": "IN",
    "name": "Ron",
    "lat": "15.69935",
    "lng": "75.73408"
  },
  {
    "country": "IN",
    "name": "Rohtak",
    "lat": "28.89447",
    "lng": "76.58917"
  },
  {
    "country": "IN",
    "name": "Rohru",
    "lat": "31.20269",
    "lng": "77.75484"
  },
  {
    "country": "IN",
    "name": "Roha",
    "lat": "23.19646",
    "lng": "69.27076"
  },
  {
    "country": "IN",
    "name": "Roha",
    "lat": "18.43687",
    "lng": "73.11964"
  },
  {
    "country": "IN",
    "name": "Robertsonpet",
    "lat": "12.95629",
    "lng": "78.27539"
  },
  {
    "country": "IN",
    "name": "Robertsganj",
    "lat": "24.6886",
    "lng": "83.06784"
  },
  {
    "country": "IN",
    "name": "Risod",
    "lat": "19.97671",
    "lng": "76.78799"
  },
  {
    "country": "IN",
    "name": "Rishra",
    "lat": "22.72394",
    "lng": "88.34563"
  },
  {
    "country": "IN",
    "name": "Rishīkesh",
    "lat": "30.10778",
    "lng": "78.29255"
  },
  {
    "country": "IN",
    "name": "Rīngas",
    "lat": "27.3636",
    "lng": "75.56838"
  },
  {
    "country": "IN",
    "name": "Richha",
    "lat": "28.69467",
    "lng": "79.52284"
  },
  {
    "country": "IN",
    "name": "Riāsi",
    "lat": "33.08115",
    "lng": "74.83242"
  },
  {
    "country": "IN",
    "name": "Rewāri",
    "lat": "28.199",
    "lng": "76.6183"
  },
  {
    "country": "IN",
    "name": "Rewa",
    "lat": "24.53256",
    "lng": "81.29234"
  },
  {
    "country": "IN",
    "name": "Revelganj",
    "lat": "25.78976",
    "lng": "84.63596"
  },
  {
    "country": "IN",
    "name": "Revadanda",
    "lat": "18.55363",
    "lng": "72.92559"
  },
  {
    "country": "IN",
    "name": "Repalle",
    "lat": "16.0184",
    "lng": "80.82958"
  },
  {
    "country": "IN",
    "name": "Reoti",
    "lat": "25.85091",
    "lng": "84.3778"
  },
  {
    "country": "IN",
    "name": "Renukūt",
    "lat": "24.21641",
    "lng": "83.0358"
  },
  {
    "country": "IN",
    "name": "Renigunta",
    "lat": "13.65143",
    "lng": "79.51256"
  },
  {
    "country": "IN",
    "name": "Rengāli",
    "lat": "21.64602",
    "lng": "84.05311"
  },
  {
    "country": "IN",
    "name": "Remuna",
    "lat": "21.52798",
    "lng": "86.87156"
  },
  {
    "country": "IN",
    "name": "Rehti",
    "lat": "22.73781",
    "lng": "77.43399"
  },
  {
    "country": "IN",
    "name": "Rehli",
    "lat": "23.63722",
    "lng": "79.06275"
  },
  {
    "country": "IN",
    "name": "Rāzole",
    "lat": "16.47608",
    "lng": "81.83912"
  },
  {
    "country": "IN",
    "name": "Rāzām",
    "lat": "18.44909",
    "lng": "83.65957"
  },
  {
    "country": "IN",
    "name": "Rāybāg",
    "lat": "16.49178",
    "lng": "74.77391"
  },
  {
    "country": "IN",
    "name": "Rāyadrug",
    "lat": "14.69971",
    "lng": "76.85241"
  },
  {
    "country": "IN",
    "name": "Rāyachoti",
    "lat": "14.05723",
    "lng": "78.75056"
  },
  {
    "country": "IN",
    "name": "Rāya",
    "lat": "27.55607",
    "lng": "77.78972"
  },
  {
    "country": "IN",
    "name": "Rāy",
    "lat": "23.6843",
    "lng": "85.05457"
  },
  {
    "country": "IN",
    "name": "Raxaul",
    "lat": "26.97982",
    "lng": "84.85065"
  },
  {
    "country": "IN",
    "name": "Rāwatsār",
    "lat": "29.26724",
    "lng": "74.40288"
  },
  {
    "country": "IN",
    "name": "Rāwatbhāta",
    "lat": "24.92981",
    "lng": "75.59209"
  },
  {
    "country": "IN",
    "name": "Rāver",
    "lat": "21.24757",
    "lng": "76.03509"
  },
  {
    "country": "IN",
    "name": "Raurkela",
    "lat": "22.22496",
    "lng": "84.86414"
  },
  {
    "country": "IN",
    "name": "Ratnagiri",
    "lat": "16.99154",
    "lng": "73.31022"
  },
  {
    "country": "IN",
    "name": "Ratlām",
    "lat": "23.33033",
    "lng": "75.04032"
  },
  {
    "country": "IN",
    "name": "Ratia",
    "lat": "29.69029",
    "lng": "75.57688"
  },
  {
    "country": "IN",
    "name": "Rāth",
    "lat": "25.59474",
    "lng": "79.5666"
  },
  {
    "country": "IN",
    "name": "Ratanpur",
    "lat": "22.2866",
    "lng": "82.16823"
  },
  {
    "country": "IN",
    "name": "Ratangarh",
    "lat": "28.08137",
    "lng": "74.61854"
  },
  {
    "country": "IN",
    "name": "Ratangarh",
    "lat": "24.81667",
    "lng": "75.11667"
  },
  {
    "country": "IN",
    "name": "Rasūlābād",
    "lat": "26.74491",
    "lng": "80.49012"
  },
  {
    "country": "IN",
    "name": "Rasrā",
    "lat": "25.8576",
    "lng": "83.85487"
  },
  {
    "country": "IN",
    "name": "Rasipuram",
    "lat": "11.46009",
    "lng": "78.18635"
  },
  {
    "country": "IN",
    "name": "Rāpar",
    "lat": "23.57267",
    "lng": "70.64718"
  },
  {
    "country": "IN",
    "name": "Rānīr Bāzār",
    "lat": "23.83463",
    "lng": "91.36614"
  },
  {
    "country": "IN",
    "name": "Rānīpur",
    "lat": "25.25034",
    "lng": "79.06204"
  },
  {
    "country": "IN",
    "name": "Rānikhet",
    "lat": "29.64082",
    "lng": "79.43229"
  },
  {
    "country": "IN",
    "name": "Rānīganj",
    "lat": "23.6164",
    "lng": "87.13061"
  },
  {
    "country": "IN",
    "name": "Rānībennur",
    "lat": "14.62239",
    "lng": "75.62951"
  },
  {
    "country": "IN",
    "name": "Rānia",
    "lat": "29.52454",
    "lng": "74.83689"
  },
  {
    "country": "IN",
    "name": "Rāni",
    "lat": "25.35031",
    "lng": "73.30885"
  },
  {
    "country": "IN",
    "name": "Rangpo",
    "lat": "27.17733",
    "lng": "88.53358"
  },
  {
    "country": "IN",
    "name": "Rangia",
    "lat": "26.44931",
    "lng": "91.61356"
  },
  {
    "country": "IN",
    "name": "Rangāpāra",
    "lat": "26.83772",
    "lng": "92.66876"
  },
  {
    "country": "IN",
    "name": "Ranchi",
    "lat": "23.34316",
    "lng": "85.3094"
  },
  {
    "country": "IN",
    "name": "Rānāvāv",
    "lat": "21.68734",
    "lng": "69.74485"
  },
  {
    "country": "IN",
    "name": "Rānāpur",
    "lat": "22.64704",
    "lng": "74.52118"
  },
  {
    "country": "IN",
    "name": "Rānāghāt",
    "lat": "23.17623",
    "lng": "88.56667"
  },
  {
    "country": "IN",
    "name": "Rāmtek",
    "lat": "21.39562",
    "lng": "79.32725"
  },
  {
    "country": "IN",
    "name": "Rampur Hat",
    "lat": "24.17737",
    "lng": "87.78275"
  },
  {
    "country": "IN",
    "name": "Rāmpura",
    "lat": "30.256",
    "lng": "75.24116"
  },
  {
    "country": "IN",
    "name": "Rāmpura",
    "lat": "26.34967",
    "lng": "79.18234"
  },
  {
    "country": "IN",
    "name": "Rāmpura",
    "lat": "24.467",
    "lng": "75.43996"
  },
  {
    "country": "IN",
    "name": "Rāmpur",
    "lat": "31.44943",
    "lng": "77.63087"
  },
  {
    "country": "IN",
    "name": "Rāmpur",
    "lat": "29.8062",
    "lng": "77.45251"
  },
  {
    "country": "IN",
    "name": "Rāmpur",
    "lat": "28.81014",
    "lng": "79.02699"
  },
  {
    "country": "IN",
    "name": "Rāmnagar",
    "lat": "32.80728",
    "lng": "75.31119"
  },
  {
    "country": "IN",
    "name": "Rāmnagar",
    "lat": "29.3925",
    "lng": "79.1283"
  },
  {
    "country": "IN",
    "name": "Rāmnagar",
    "lat": "27.16371",
    "lng": "84.32342"
  },
  {
    "country": "IN",
    "name": "Rāmnagar",
    "lat": "27.08499",
    "lng": "81.40575"
  },
  {
    "country": "IN",
    "name": "Rāmnagar",
    "lat": "25.26907",
    "lng": "83.02971"
  },
  {
    "country": "IN",
    "name": "Rāmkola",
    "lat": "26.90172",
    "lng": "83.83758"
  },
  {
    "country": "IN",
    "name": "Rāmjībanpur",
    "lat": "22.82815",
    "lng": "87.60888"
  },
  {
    "country": "IN",
    "name": "Rāmgundam",
    "lat": "18.80084",
    "lng": "79.45206"
  },
  {
    "country": "IN",
    "name": "Rāmgarh",
    "lat": "33.40379",
    "lng": "74.22388"
  },
  {
    "country": "IN",
    "name": "Rāmgarh",
    "lat": "27.25097",
    "lng": "75.17893"
  },
  {
    "country": "IN",
    "name": "Rāmgarh",
    "lat": "23.6303",
    "lng": "85.52156"
  },
  {
    "country": "IN",
    "name": "Rāmganj Mandi",
    "lat": "24.64648",
    "lng": "75.94325"
  },
  {
    "country": "IN",
    "name": "Rameswaram",
    "lat": "9.2885",
    "lng": "79.31271"
  },
  {
    "country": "IN",
    "name": "Rām Dās",
    "lat": "31.96739",
    "lng": "74.9087"
  },
  {
    "country": "IN",
    "name": "Rambha",
    "lat": "19.51667",
    "lng": "85.1"
  },
  {
    "country": "IN",
    "name": "Rāmban",
    "lat": "33.24278",
    "lng": "75.23513"
  },
  {
    "country": "IN",
    "name": "Rāmāpuram",
    "lat": "15.28749",
    "lng": "77.86722"
  },
  {
    "country": "IN",
    "name": "Rāmāpuram",
    "lat": "13.10091",
    "lng": "79.1841"
  },
  {
    "country": "IN",
    "name": "Rāmānuj Ganj",
    "lat": "23.80637",
    "lng": "83.69981"
  },
  {
    "country": "IN",
    "name": "Ramanathapuram",
    "lat": "9.37158",
    "lng": "78.83077"
  },
  {
    "country": "IN",
    "name": "Closepet",
    "lat": "12.72181",
    "lng": "77.28149"
  },
  {
    "country": "IN",
    "name": "Rāmamangalam",
    "lat": "9.93333",
    "lng": "76.5"
  },
  {
    "country": "IN",
    "name": "Rāmachandrapuram",
    "lat": "16.83636",
    "lng": "82.02871"
  },
  {
    "country": "IN",
    "name": "Rājūra",
    "lat": "19.77947",
    "lng": "79.36459"
  },
  {
    "country": "IN",
    "name": "Rājur",
    "lat": "20.11087",
    "lng": "78.89311"
  },
  {
    "country": "IN",
    "name": "Rājula",
    "lat": "21.03854",
    "lng": "71.44345"
  },
  {
    "country": "IN",
    "name": "Rājsamand",
    "lat": "25.07145",
    "lng": "73.8798"
  },
  {
    "country": "IN",
    "name": "Rājpura",
    "lat": "30.47856",
    "lng": "76.59284"
  },
  {
    "country": "IN",
    "name": "Rajpur",
    "lat": "22.30393",
    "lng": "74.35568"
  },
  {
    "country": "IN",
    "name": "Rajpur",
    "lat": "21.94022",
    "lng": "75.13608"
  },
  {
    "country": "IN",
    "name": "Rājpīpla",
    "lat": "21.86667",
    "lng": "73.5"
  },
  {
    "country": "IN",
    "name": "Rāj-Nāndgaon",
    "lat": "21.09687",
    "lng": "81.0289"
  },
  {
    "country": "IN",
    "name": "Rājnagar",
    "lat": "24.88929",
    "lng": "79.91178"
  },
  {
    "country": "IN",
    "name": "Rājmahal",
    "lat": "25.05303",
    "lng": "87.83048"
  },
  {
    "country": "IN",
    "name": "Rājkot",
    "lat": "22.29161",
    "lng": "70.79322"
  },
  {
    "country": "IN",
    "name": "Rājgurunagar",
    "lat": "18.86667",
    "lng": "73.9"
  },
  {
    "country": "IN",
    "name": "Rājgīr",
    "lat": "25.02828",
    "lng": "85.42079"
  },
  {
    "country": "IN",
    "name": "Rājgarh",
    "lat": "30.85142",
    "lng": "77.30066"
  },
  {
    "country": "IN",
    "name": "Rājgarh",
    "lat": "28.64201",
    "lng": "75.38612"
  },
  {
    "country": "IN",
    "name": "Rājgarh",
    "lat": "27.23731",
    "lng": "76.62243"
  },
  {
    "country": "IN",
    "name": "Rājgarh",
    "lat": "24.00826",
    "lng": "76.7325"
  },
  {
    "country": "IN",
    "name": "Rājgarh",
    "lat": "22.67821",
    "lng": "74.94483"
  },
  {
    "country": "IN",
    "name": "Rajaori",
    "lat": "33.37526",
    "lng": "74.3092"
  },
  {
    "country": "IN",
    "name": "Rāja Sānsi",
    "lat": "31.72021",
    "lng": "74.8008"
  },
  {
    "country": "IN",
    "name": "Rājāpur",
    "lat": "25.38725",
    "lng": "81.15125"
  },
  {
    "country": "IN",
    "name": "Rājāpur",
    "lat": "16.65679",
    "lng": "73.51701"
  },
  {
    "country": "IN",
    "name": "Rajapalaiyam",
    "lat": "9.45296",
    "lng": "77.55335"
  },
  {
    "country": "IN",
    "name": "Rāzampeta",
    "lat": "14.19544",
    "lng": "79.15896"
  },
  {
    "country": "IN",
    "name": "Rājaldesar",
    "lat": "28.02849",
    "lng": "74.47442"
  },
  {
    "country": "IN",
    "name": "Rājākhera",
    "lat": "26.89802",
    "lng": "78.171"
  },
  {
    "country": "IN",
    "name": "Rājahmundry",
    "lat": "17.00517",
    "lng": "81.77784"
  },
  {
    "country": "IN",
    "name": "Rāīwāla Bara",
    "lat": "30.01864",
    "lng": "78.2293"
  },
  {
    "country": "IN",
    "name": "Rāisinghnagar",
    "lat": "29.53583",
    "lng": "73.44917"
  },
  {
    "country": "IN",
    "name": "Raisen",
    "lat": "23.33033",
    "lng": "77.7811"
  },
  {
    "country": "IN",
    "name": "Rāipur",
    "lat": "30.31097",
    "lng": "78.08979"
  },
  {
    "country": "IN",
    "name": "Raipur",
    "lat": "26.04259",
    "lng": "74.02373"
  },
  {
    "country": "IN",
    "name": "Raipur",
    "lat": "21.23333",
    "lng": "81.63333"
  },
  {
    "country": "IN",
    "name": "Rāikot",
    "lat": "30.65",
    "lng": "75.6"
  },
  {
    "country": "IN",
    "name": "Raigarh",
    "lat": "21.89764",
    "lng": "83.3966"
  },
  {
    "country": "IN",
    "name": "Rāiganj",
    "lat": "25.61281",
    "lng": "88.12449"
  },
  {
    "country": "IN",
    "name": "Rāichūr",
    "lat": "16.20546",
    "lng": "77.35567"
  },
  {
    "country": "IN",
    "name": "Raia",
    "lat": "15.30499",
    "lng": "73.97096"
  },
  {
    "country": "IN",
    "name": "Rāhuri",
    "lat": "19.39069",
    "lng": "74.64979"
  },
  {
    "country": "IN",
    "name": "Rāhon",
    "lat": "31.05275",
    "lng": "76.11907"
  },
  {
    "country": "IN",
    "name": "Rahimatpur",
    "lat": "17.5921",
    "lng": "74.19966"
  },
  {
    "country": "IN",
    "name": "Rāhatgarh",
    "lat": "23.78968",
    "lng": "78.39473"
  },
  {
    "country": "IN",
    "name": "Rahā",
    "lat": "26.23333",
    "lng": "92.51667"
  },
  {
    "country": "IN",
    "name": "Raghunāthpur",
    "lat": "25.64492",
    "lng": "87.91762"
  },
  {
    "country": "IN",
    "name": "Raghunathpur",
    "lat": "23.53878",
    "lng": "86.6735"
  },
  {
    "country": "IN",
    "name": "Rāghogarh",
    "lat": "24.44318",
    "lng": "77.19768"
  },
  {
    "country": "IN",
    "name": "Rafiganj",
    "lat": "24.81757",
    "lng": "84.63445"
  },
  {
    "country": "IN",
    "name": "Raebareli",
    "lat": "26.2309",
    "lng": "81.23315"
  },
  {
    "country": "IN",
    "name": "Rādhanpur",
    "lat": "23.83238",
    "lng": "71.6047"
  },
  {
    "country": "IN",
    "name": "Rādhākund",
    "lat": "27.52432",
    "lng": "77.49101"
  },
  {
    "country": "IN",
    "name": "Radaur",
    "lat": "30.02706",
    "lng": "77.15177"
  },
  {
    "country": "IN",
    "name": "Rabūpura",
    "lat": "28.25153",
    "lng": "77.60253"
  },
  {
    "country": "IN",
    "name": "Rabkavi",
    "lat": "16.47567",
    "lng": "75.1106"
  },
  {
    "country": "IN",
    "name": "Kollam",
    "lat": "8.88113",
    "lng": "76.58469"
  },
  {
    "country": "IN",
    "name": "Queula",
    "lat": "15.39011",
    "lng": "73.98557"
  },
  {
    "country": "IN",
    "name": "Quepem",
    "lat": "15.2128",
    "lng": "74.0772"
  },
  {
    "country": "IN",
    "name": "Qāzigund",
    "lat": "33.63828",
    "lng": "75.14261"
  },
  {
    "country": "IN",
    "name": "Kasba",
    "lat": "25.85643",
    "lng": "87.53836"
  },
  {
    "country": "IN",
    "name": "Qādiān",
    "lat": "31.82198",
    "lng": "75.37663"
  },
  {
    "country": "IN",
    "name": "Puttūr",
    "lat": "13.44189",
    "lng": "79.55314"
  },
  {
    "country": "IN",
    "name": "Puttūr",
    "lat": "12.75975",
    "lng": "75.20169"
  },
  {
    "country": "IN",
    "name": "Pushkar",
    "lat": "26.49022",
    "lng": "74.55211"
  },
  {
    "country": "IN",
    "name": "Pusad",
    "lat": "19.91274",
    "lng": "77.57838"
  },
  {
    "country": "IN",
    "name": "Purwā",
    "lat": "26.45756",
    "lng": "80.77403"
  },
  {
    "country": "IN",
    "name": "Purushottampur",
    "lat": "19.52024",
    "lng": "84.88514"
  },
  {
    "country": "IN",
    "name": "Puruliya",
    "lat": "23.33062",
    "lng": "86.36303"
  },
  {
    "country": "IN",
    "name": "Purnia",
    "lat": "25.77895",
    "lng": "87.47422"
  },
  {
    "country": "IN",
    "name": "Pūrna",
    "lat": "19.1817",
    "lng": "77.02566"
  },
  {
    "country": "IN",
    "name": "Puri",
    "lat": "19.79825",
    "lng": "85.82494"
  },
  {
    "country": "IN",
    "name": "Pūranpur",
    "lat": "28.51283",
    "lng": "80.14829"
  },
  {
    "country": "IN",
    "name": "Pupri",
    "lat": "26.47079",
    "lng": "85.70311"
  },
  {
    "country": "IN",
    "name": "Punjai Puliyampatti",
    "lat": "11.35163",
    "lng": "77.16671"
  },
  {
    "country": "IN",
    "name": "Punganūru",
    "lat": "13.36672",
    "lng": "78.57186"
  },
  {
    "country": "IN",
    "name": "Pune",
    "lat": "18.51957",
    "lng": "73.85535"
  },
  {
    "country": "IN",
    "name": "Pūndri",
    "lat": "29.76096",
    "lng": "76.56034"
  },
  {
    "country": "IN",
    "name": "Punāsa",
    "lat": "22.23507",
    "lng": "76.39335"
  },
  {
    "country": "IN",
    "name": "Punalūr",
    "lat": "9.01956",
    "lng": "76.92261"
  },
  {
    "country": "IN",
    "name": "Pūnāhāna",
    "lat": "27.86371",
    "lng": "77.20432"
  },
  {
    "country": "IN",
    "name": "Pulwama",
    "lat": "33.87405",
    "lng": "74.89955"
  },
  {
    "country": "IN",
    "name": "Pullambādi",
    "lat": "10.9411",
    "lng": "78.91041"
  },
  {
    "country": "IN",
    "name": "Puliyūr",
    "lat": "10.63375",
    "lng": "78.84139"
  },
  {
    "country": "IN",
    "name": "Puliyangudi",
    "lat": "9.17489",
    "lng": "77.39799"
  },
  {
    "country": "IN",
    "name": "Pulivendla",
    "lat": "14.42139",
    "lng": "78.22502"
  },
  {
    "country": "IN",
    "name": "Pulgaon",
    "lat": "20.72204",
    "lng": "78.32056"
  },
  {
    "country": "IN",
    "name": "Pukhrāyān",
    "lat": "26.22375",
    "lng": "79.83739"
  },
  {
    "country": "IN",
    "name": "Puduvāyal",
    "lat": "13.33015",
    "lng": "80.14577"
  },
  {
    "country": "IN",
    "name": "Pudūr",
    "lat": "12.99801",
    "lng": "79.14352"
  },
  {
    "country": "IN",
    "name": "Pudūr",
    "lat": "9.29169",
    "lng": "78.13848"
  },
  {
    "country": "IN",
    "name": "Puduppatti",
    "lat": "11.15217",
    "lng": "78.21205"
  },
  {
    "country": "IN",
    "name": "Pudukkottai",
    "lat": "10.38128",
    "lng": "78.82141"
  },
  {
    "country": "IN",
    "name": "Proddatūr",
    "lat": "14.7502",
    "lng": "78.54813"
  },
  {
    "country": "IN",
    "name": "Pratāpgarh",
    "lat": "25.89509",
    "lng": "81.9424"
  },
  {
    "country": "IN",
    "name": "Pratāpgarh",
    "lat": "24.03215",
    "lng": "74.78162"
  },
  {
    "country": "IN",
    "name": "Port Blair",
    "lat": "11.66613",
    "lng": "92.74635"
  },
  {
    "country": "IN",
    "name": "Porsa",
    "lat": "26.67444",
    "lng": "78.37081"
  },
  {
    "country": "IN",
    "name": "Porbandar",
    "lat": "21.64219",
    "lng": "69.60929"
  },
  {
    "country": "IN",
    "name": "Poonamalle",
    "lat": "13.04888",
    "lng": "80.11488"
  },
  {
    "country": "IN",
    "name": "Ponnūru",
    "lat": "16.06547",
    "lng": "80.55203"
  },
  {
    "country": "IN",
    "name": "Ponneri",
    "lat": "13.33868",
    "lng": "80.19487"
  },
  {
    "country": "IN",
    "name": "Ponnāni",
    "lat": "10.76695",
    "lng": "75.92523"
  },
  {
    "country": "IN",
    "name": "Ponnampet",
    "lat": "12.14473",
    "lng": "75.94514"
  },
  {
    "country": "IN",
    "name": "Ponnamarāvati",
    "lat": "10.28032",
    "lng": "78.53601"
  },
  {
    "country": "IN",
    "name": "Puducherry",
    "lat": "11.93381",
    "lng": "79.82979"
  },
  {
    "country": "IN",
    "name": "Ponda",
    "lat": "15.40341",
    "lng": "74.01519"
  },
  {
    "country": "IN",
    "name": "Polūr",
    "lat": "12.51217",
    "lng": "79.12405"
  },
  {
    "country": "IN",
    "name": "Pollachi",
    "lat": "10.65825",
    "lng": "77.0085"
  },
  {
    "country": "IN",
    "name": "Polavaram",
    "lat": "17.24754",
    "lng": "81.64372"
  },
  {
    "country": "IN",
    "name": "Polasara",
    "lat": "19.69386",
    "lng": "84.81401"
  },
  {
    "country": "IN",
    "name": "Pokaran",
    "lat": "26.92007",
    "lng": "71.91631"
  },
  {
    "country": "IN",
    "name": "Pithorāgarh",
    "lat": "29.58349",
    "lng": "80.20947"
  },
  {
    "country": "IN",
    "name": "Pithora",
    "lat": "21.25021",
    "lng": "82.51707"
  },
  {
    "country": "IN",
    "name": "Pithāpuram",
    "lat": "17.1168",
    "lng": "82.25284"
  },
  {
    "country": "IN",
    "name": "Piro",
    "lat": "25.33218",
    "lng": "84.40454"
  },
  {
    "country": "IN",
    "name": "Piriyāpatna",
    "lat": "12.33497",
    "lng": "76.10073"
  },
  {
    "country": "IN",
    "name": "Pirāwa",
    "lat": "24.15506",
    "lng": "76.02728"
  },
  {
    "country": "IN",
    "name": "Piravam",
    "lat": "9.86667",
    "lng": "76.5"
  },
  {
    "country": "IN",
    "name": "Pīpri",
    "lat": "19.79371",
    "lng": "75.53519"
  },
  {
    "country": "IN",
    "name": "Pipraich",
    "lat": "26.82745",
    "lng": "83.52632"
  },
  {
    "country": "IN",
    "name": "Pippara",
    "lat": "16.71667",
    "lng": "81.55"
  },
  {
    "country": "IN",
    "name": "Piploda",
    "lat": "23.35",
    "lng": "75.43333"
  },
  {
    "country": "IN",
    "name": "Pipili",
    "lat": "20.11357",
    "lng": "85.83147"
  },
  {
    "country": "IN",
    "name": "Pīpār",
    "lat": "26.38441",
    "lng": "73.54394"
  },
  {
    "country": "IN",
    "name": "Pīpalkoti",
    "lat": "30.42553",
    "lng": "79.43066"
  },
  {
    "country": "IN",
    "name": "Pinjaur",
    "lat": "30.79873",
    "lng": "76.91822"
  },
  {
    "country": "IN",
    "name": "Pindwāra",
    "lat": "24.79749",
    "lng": "73.05505"
  },
  {
    "country": "IN",
    "name": "Pināhat",
    "lat": "26.88487",
    "lng": "78.37647"
  },
  {
    "country": "IN",
    "name": "Pimpri",
    "lat": "18.62292",
    "lng": "73.80696"
  },
  {
    "country": "IN",
    "name": "Pilkhua",
    "lat": "28.71271",
    "lng": "77.656"
  },
  {
    "country": "IN",
    "name": "Pīlibhīt",
    "lat": "28.63124",
    "lng": "79.80436"
  },
  {
    "country": "IN",
    "name": "Pilibangan",
    "lat": "29.44964",
    "lng": "74.10093"
  },
  {
    "country": "IN",
    "name": "Pilāni",
    "lat": "28.36725",
    "lng": "75.60352"
  },
  {
    "country": "IN",
    "name": "Pihānī",
    "lat": "27.61987",
    "lng": "80.20343"
  },
  {
    "country": "IN",
    "name": "Phūlpur",
    "lat": "26.07779",
    "lng": "82.87608"
  },
  {
    "country": "IN",
    "name": "Phulpur",
    "lat": "25.54895",
    "lng": "82.0895"
  },
  {
    "country": "IN",
    "name": "Phulera",
    "lat": "26.87401",
    "lng": "75.24171"
  },
  {
    "country": "IN",
    "name": "Phulbāni",
    "lat": "20.48101",
    "lng": "84.23063"
  },
  {
    "country": "IN",
    "name": "Phirangipuram",
    "lat": "16.29078",
    "lng": "80.26233"
  },
  {
    "country": "IN",
    "name": "Phillaur",
    "lat": "31.01887",
    "lng": "75.79111"
  },
  {
    "country": "IN",
    "name": "Phek",
    "lat": "25.66667",
    "lng": "94.5"
  },
  {
    "country": "IN",
    "name": "Pharihā",
    "lat": "27.32166",
    "lng": "78.47267"
  },
  {
    "country": "IN",
    "name": "Phaphūnd",
    "lat": "26.59888",
    "lng": "79.46437"
  },
  {
    "country": "IN",
    "name": "Phaltan",
    "lat": "17.99113",
    "lng": "74.43177"
  },
  {
    "country": "IN",
    "name": "Phalodi",
    "lat": "27.13102",
    "lng": "72.36826"
  },
  {
    "country": "IN",
    "name": "Phalauda",
    "lat": "29.18824",
    "lng": "77.82996"
  },
  {
    "country": "IN",
    "name": "Phagwāra",
    "lat": "31.22452",
    "lng": "75.77387"
  },
  {
    "country": "IN",
    "name": "Petlāwad",
    "lat": "23.01102",
    "lng": "74.79772"
  },
  {
    "country": "IN",
    "name": "Petlād",
    "lat": "22.47681",
    "lng": "72.79995"
  },
  {
    "country": "IN",
    "name": "Perūr",
    "lat": "10.97519",
    "lng": "76.91292"
  },
  {
    "country": "IN",
    "name": "Perundurai",
    "lat": "11.27564",
    "lng": "77.58794"
  },
  {
    "country": "IN",
    "name": "Perumpāvūr",
    "lat": "10.11544",
    "lng": "76.47611"
  },
  {
    "country": "IN",
    "name": "Pernem",
    "lat": "15.723",
    "lng": "73.79511"
  },
  {
    "country": "IN",
    "name": "Periyapatti",
    "lat": "10.75812",
    "lng": "77.27087"
  },
  {
    "country": "IN",
    "name": "Periyanegamam",
    "lat": "10.74317",
    "lng": "77.10296"
  },
  {
    "country": "IN",
    "name": "Periyanayakkanpalaiyam",
    "lat": "11.15255",
    "lng": "76.95159"
  },
  {
    "country": "IN",
    "name": "Periyakulam",
    "lat": "10.12268",
    "lng": "77.54372"
  },
  {
    "country": "IN",
    "name": "Perya",
    "lat": "11.83334",
    "lng": "75.85408"
  },
  {
    "country": "IN",
    "name": "Peravurani",
    "lat": "10.29035",
    "lng": "79.20156"
  },
  {
    "country": "IN",
    "name": "Peranāmpattu",
    "lat": "12.9343",
    "lng": "78.7189"
  },
  {
    "country": "IN",
    "name": "Peranamallūr",
    "lat": "12.57052",
    "lng": "79.43332"
  },
  {
    "country": "IN",
    "name": "Perambalur",
    "lat": "11.23333",
    "lng": "78.88333"
  },
  {
    "country": "IN",
    "name": "Peraiyur",
    "lat": "9.73579",
    "lng": "77.78955"
  },
  {
    "country": "IN",
    "name": "Penukonda",
    "lat": "14.08286",
    "lng": "77.59473"
  },
  {
    "country": "IN",
    "name": "Penugonda",
    "lat": "16.65363",
    "lng": "81.7455"
  },
  {
    "country": "IN",
    "name": "Pennāthur",
    "lat": "12.24681",
    "lng": "79.22592"
  },
  {
    "country": "IN",
    "name": "Pennāgaram",
    "lat": "12.13433",
    "lng": "77.89525"
  },
  {
    "country": "IN",
    "name": "Pennādam",
    "lat": "11.40389",
    "lng": "79.24156"
  },
  {
    "country": "IN",
    "name": "Pendra",
    "lat": "22.77548",
    "lng": "81.95968"
  },
  {
    "country": "IN",
    "name": "Pen",
    "lat": "18.73734",
    "lng": "73.09603"
  },
  {
    "country": "IN",
    "name": "Pehowa",
    "lat": "29.97897",
    "lng": "76.58249"
  },
  {
    "country": "IN",
    "name": "Peddāpuram",
    "lat": "17.07701",
    "lng": "82.13836"
  },
  {
    "country": "IN",
    "name": "Peddapalli",
    "lat": "18.61357",
    "lng": "79.37442"
  },
  {
    "country": "IN",
    "name": "Pedana",
    "lat": "16.25582",
    "lng": "81.14378"
  },
  {
    "country": "IN",
    "name": "Payyannūr",
    "lat": "12.0935",
    "lng": "75.20249"
  },
  {
    "country": "IN",
    "name": "Pawāyan",
    "lat": "28.06626",
    "lng": "80.10305"
  },
  {
    "country": "IN",
    "name": "Pawai",
    "lat": "24.26635",
    "lng": "80.16196"
  },
  {
    "country": "IN",
    "name": "Pāvugada",
    "lat": "14.09953",
    "lng": "77.28018"
  },
  {
    "country": "IN",
    "name": "Pauri",
    "lat": "30.15286",
    "lng": "78.7771"
  },
  {
    "country": "IN",
    "name": "Pawni",
    "lat": "20.79229",
    "lng": "79.63644"
  },
  {
    "country": "IN",
    "name": "Pātūr",
    "lat": "20.46093",
    "lng": "76.93725"
  },
  {
    "country": "IN",
    "name": "Pātuli",
    "lat": "23.55286",
    "lng": "88.26473"
  },
  {
    "country": "IN",
    "name": "Pattukkottai",
    "lat": "10.42358",
    "lng": "79.31949"
  },
  {
    "country": "IN",
    "name": "Patti",
    "lat": "31.28092",
    "lng": "74.85849"
  },
  {
    "country": "IN",
    "name": "Patti",
    "lat": "25.9215",
    "lng": "82.20048"
  },
  {
    "country": "IN",
    "name": "Pattan",
    "lat": "34.16125",
    "lng": "74.55634"
  },
  {
    "country": "IN",
    "name": "Pātrasāer",
    "lat": "23.19697",
    "lng": "87.53319"
  },
  {
    "country": "IN",
    "name": "Patnāgarh",
    "lat": "20.70833",
    "lng": "83.13263"
  },
  {
    "country": "IN",
    "name": "Patna",
    "lat": "25.59408",
    "lng": "85.13563"
  },
  {
    "country": "IN",
    "name": "Patiāli",
    "lat": "27.69086",
    "lng": "78.99823"
  },
  {
    "country": "IN",
    "name": "Patiāla",
    "lat": "30.33625",
    "lng": "76.3922"
  },
  {
    "country": "IN",
    "name": "Pāthri",
    "lat": "19.2588",
    "lng": "76.43412"
  },
  {
    "country": "IN",
    "name": "Patharia",
    "lat": "23.89921",
    "lng": "79.19393"
  },
  {
    "country": "IN",
    "name": "Pāthardih",
    "lat": "23.6658",
    "lng": "86.43166"
  },
  {
    "country": "IN",
    "name": "Pāthardi",
    "lat": "19.17279",
    "lng": "75.17425"
  },
  {
    "country": "IN",
    "name": "Pathānkot",
    "lat": "32.27484",
    "lng": "75.65287"
  },
  {
    "country": "IN",
    "name": "Pathanāmthitta",
    "lat": "9.26667",
    "lng": "76.78333"
  },
  {
    "country": "IN",
    "name": "Pathalgaon",
    "lat": "22.55656",
    "lng": "83.46355"
  },
  {
    "country": "IN",
    "name": "Pataudi",
    "lat": "28.32547",
    "lng": "76.77858"
  },
  {
    "country": "IN",
    "name": "Patancheru",
    "lat": "17.53334",
    "lng": "78.2645"
  },
  {
    "country": "IN",
    "name": "Pātan",
    "lat": "23.8507",
    "lng": "72.12963"
  },
  {
    "country": "IN",
    "name": "Pātan",
    "lat": "23.28636",
    "lng": "79.68962"
  },
  {
    "country": "IN",
    "name": "Pātan",
    "lat": "21.03333",
    "lng": "81.53333"
  },
  {
    "country": "IN",
    "name": "Pātan",
    "lat": "17.37513",
    "lng": "73.90143"
  },
  {
    "country": "IN",
    "name": "Patāmundai",
    "lat": "20.57806",
    "lng": "86.56063"
  },
  {
    "country": "IN",
    "name": "Pāsighāt",
    "lat": "28.06631",
    "lng": "95.32678"
  },
  {
    "country": "IN",
    "name": "Pasān",
    "lat": "22.84412",
    "lng": "82.19823"
  },
  {
    "country": "IN",
    "name": "Parvatsar",
    "lat": "26.88604",
    "lng": "74.76602"
  },
  {
    "country": "IN",
    "name": "Pārvatipuram",
    "lat": "18.78392",
    "lng": "83.42569"
  },
  {
    "country": "IN",
    "name": "Partūr",
    "lat": "19.59925",
    "lng": "76.21541"
  },
  {
    "country": "IN",
    "name": "Partāpur",
    "lat": "23.59276",
    "lng": "74.17396"
  },
  {
    "country": "IN",
    "name": "Parshādepur",
    "lat": "26.07354",
    "lng": "81.49207"
  },
  {
    "country": "IN",
    "name": "Parola",
    "lat": "20.88098",
    "lng": "75.11937"
  },
  {
    "country": "IN",
    "name": "Parol",
    "lat": "32.34598",
    "lng": "75.43441"
  },
  {
    "country": "IN",
    "name": "Parnera",
    "lat": "20.56101",
    "lng": "72.94846"
  },
  {
    "country": "IN",
    "name": "Parli Vaijnāth",
    "lat": "18.85057",
    "lng": "76.53163"
  },
  {
    "country": "IN",
    "name": "Parlākimidi",
    "lat": "18.78113",
    "lng": "84.08836"
  },
  {
    "country": "IN",
    "name": "Pariyāpuram",
    "lat": "11.01667",
    "lng": "75.86667"
  },
  {
    "country": "IN",
    "name": "Parīchhatgarh",
    "lat": "28.97841",
    "lng": "77.93422"
  },
  {
    "country": "IN",
    "name": "Pārīchha",
    "lat": "25.50789",
    "lng": "78.75954"
  },
  {
    "country": "IN",
    "name": "Pārdi",
    "lat": "20.5087",
    "lng": "72.94569"
  },
  {
    "country": "IN",
    "name": "Parbhani",
    "lat": "19.26855",
    "lng": "76.77081"
  },
  {
    "country": "IN",
    "name": "Paravūr Tekkumbhāgam",
    "lat": "8.7947",
    "lng": "76.66798"
  },
  {
    "country": "IN",
    "name": "Parāsia",
    "lat": "22.1913",
    "lng": "78.75904"
  },
  {
    "country": "IN",
    "name": "Paramagudi",
    "lat": "9.54633",
    "lng": "78.5907"
  },
  {
    "country": "IN",
    "name": "Parādīp Garh",
    "lat": "20.31641",
    "lng": "86.6085"
  },
  {
    "country": "IN",
    "name": "Pāppinisshēri",
    "lat": "11.95655",
    "lng": "75.34034"
  },
  {
    "country": "IN",
    "name": "Pāppārappatti",
    "lat": "12.22086",
    "lng": "78.0592"
  },
  {
    "country": "IN",
    "name": "Pāpireddippatti",
    "lat": "11.91774",
    "lng": "78.36865"
  },
  {
    "country": "IN",
    "name": "Papanasam",
    "lat": "10.92687",
    "lng": "79.27056"
  },
  {
    "country": "IN",
    "name": "Pāonta Sāhib",
    "lat": "30.43666",
    "lng": "77.62462"
  },
  {
    "country": "IN",
    "name": "Panvel",
    "lat": "18.98878",
    "lng": "73.11013"
  },
  {
    "country": "IN",
    "name": "Pānsemāl",
    "lat": "21.65981",
    "lng": "74.69937"
  },
  {
    "country": "IN",
    "name": "Panruti",
    "lat": "11.77662",
    "lng": "79.55269"
  },
  {
    "country": "IN",
    "name": "Panna",
    "lat": "24.72094",
    "lng": "80.18772"
  },
  {
    "country": "IN",
    "name": "Ponmana",
    "lat": "9.00798",
    "lng": "76.52023"
  },
  {
    "country": "IN",
    "name": "Pānīpat",
    "lat": "29.38747",
    "lng": "76.96825"
  },
  {
    "country": "IN",
    "name": "Pānihāti",
    "lat": "22.69089",
    "lng": "88.37404"
  },
  {
    "country": "IN",
    "name": "Panhāla",
    "lat": "16.8121",
    "lng": "74.11007"
  },
  {
    "country": "IN",
    "name": "Pāngāla",
    "lat": "13.25",
    "lng": "74.75"
  },
  {
    "country": "IN",
    "name": "Pandua",
    "lat": "23.07492",
    "lng": "88.28637"
  },
  {
    "country": "IN",
    "name": "Pāndoh",
    "lat": "31.66902",
    "lng": "77.05359"
  },
  {
    "country": "IN",
    "name": "Pāndhurnā",
    "lat": "21.59556",
    "lng": "78.52628"
  },
  {
    "country": "IN",
    "name": "Pandharpur",
    "lat": "17.67924",
    "lng": "75.33098"
  },
  {
    "country": "IN",
    "name": "Pandhāna",
    "lat": "21.69816",
    "lng": "76.22487"
  },
  {
    "country": "IN",
    "name": "French Rocks",
    "lat": "12.50094",
    "lng": "76.67416"
  },
  {
    "country": "IN",
    "name": "Pāndātarai",
    "lat": "22.18714",
    "lng": "81.32815"
  },
  {
    "country": "IN",
    "name": "Pandaria",
    "lat": "22.22495",
    "lng": "81.40994"
  },
  {
    "country": "IN",
    "name": "Pānchgani",
    "lat": "17.92449",
    "lng": "73.8008"
  },
  {
    "country": "IN",
    "name": "Panara",
    "lat": "22.20568",
    "lng": "78.55093"
  },
  {
    "country": "IN",
    "name": "Panamaram",
    "lat": "11.74014",
    "lng": "76.07369"
  },
  {
    "country": "IN",
    "name": "Panaji",
    "lat": "15.49574",
    "lng": "73.82624"
  },
  {
    "country": "IN",
    "name": "Panāgar",
    "lat": "23.28539",
    "lng": "79.99509"
  },
  {
    "country": "IN",
    "name": "Palwal",
    "lat": "28.14469",
    "lng": "77.32546"
  },
  {
    "country": "IN",
    "name": "Pāloncha",
    "lat": "17.60184",
    "lng": "80.70509"
  },
  {
    "country": "IN",
    "name": "Palani",
    "lat": "10.45034",
    "lng": "77.5209"
  },
  {
    "country": "IN",
    "name": "Palmaner",
    "lat": "13.2",
    "lng": "78.74725"
  },
  {
    "country": "IN",
    "name": "Pallippatti",
    "lat": "11.9399",
    "lng": "78.40161"
  },
  {
    "country": "IN",
    "name": "Pallipattu",
    "lat": "13.3386",
    "lng": "79.44489"
  },
  {
    "country": "IN",
    "name": "Pallikondai",
    "lat": "12.90518",
    "lng": "78.9427"
  },
  {
    "country": "IN",
    "name": "Pallevāda",
    "lat": "16.5779",
    "lng": "81.29463"
  },
  {
    "country": "IN",
    "name": "Palle",
    "lat": "15.46667",
    "lng": "74.08333"
  },
  {
    "country": "IN",
    "name": "Pallāvaram",
    "lat": "12.96796",
    "lng": "80.15025"
  },
  {
    "country": "IN",
    "name": "Pallattūr",
    "lat": "10.14609",
    "lng": "78.80309"
  },
  {
    "country": "IN",
    "name": "Pallappatti",
    "lat": "10.72057",
    "lng": "77.87951"
  },
  {
    "country": "IN",
    "name": "Palladam",
    "lat": "10.99175",
    "lng": "77.28633"
  },
  {
    "country": "IN",
    "name": "Pālkonda",
    "lat": "18.60374",
    "lng": "83.75568"
  },
  {
    "country": "IN",
    "name": "Pāliyād",
    "lat": "22.25757",
    "lng": "71.56024"
  },
  {
    "country": "IN",
    "name": "Pālitāna",
    "lat": "21.52519",
    "lng": "71.82309"
  },
  {
    "country": "IN",
    "name": "Paliā Kalān",
    "lat": "28.43205",
    "lng": "80.58137"
  },
  {
    "country": "IN",
    "name": "Pāli",
    "lat": "25.77276",
    "lng": "73.32335"
  },
  {
    "country": "IN",
    "name": "Pāli",
    "lat": "24.49188",
    "lng": "78.41617"
  },
  {
    "country": "IN",
    "name": "Pāli",
    "lat": "23.36453",
    "lng": "81.04374"
  },
  {
    "country": "IN",
    "name": "Pālghāt",
    "lat": "10.77319",
    "lng": "76.65366"
  },
  {
    "country": "IN",
    "name": "Pālghar",
    "lat": "19.69693",
    "lng": "72.76543"
  },
  {
    "country": "IN",
    "name": "Palera",
    "lat": "25.02013",
    "lng": "79.22818"
  },
  {
    "country": "IN",
    "name": "Palāsbāri",
    "lat": "26.12388",
    "lng": "91.53974"
  },
  {
    "country": "IN",
    "name": "Palāsa",
    "lat": "18.77257",
    "lng": "84.41012"
  },
  {
    "country": "IN",
    "name": "Pālanpur",
    "lat": "24.17128",
    "lng": "72.43827"
  },
  {
    "country": "IN",
    "name": "Pālampur",
    "lat": "32.11453",
    "lng": "76.55681"
  },
  {
    "country": "IN",
    "name": "Pālamedu",
    "lat": "10.10501",
    "lng": "78.11336"
  },
  {
    "country": "IN",
    "name": "Pālakollu",
    "lat": "16.5167",
    "lng": "81.73"
  },
  {
    "country": "IN",
    "name": "Pālakkodu",
    "lat": "12.30696",
    "lng": "78.07022"
  },
  {
    "country": "IN",
    "name": "Pakur",
    "lat": "24.63925",
    "lng": "87.84239"
  },
  {
    "country": "IN",
    "name": "Pākāla",
    "lat": "13.44903",
    "lng": "79.11493"
  },
  {
    "country": "IN",
    "name": "Paithan",
    "lat": "19.47506",
    "lng": "75.38558"
  },
  {
    "country": "IN",
    "name": "Pahāsu",
    "lat": "28.1722",
    "lng": "78.06376"
  },
  {
    "country": "IN",
    "name": "Pahlgām",
    "lat": "34.01592",
    "lng": "75.31899"
  },
  {
    "country": "IN",
    "name": "Padrauna",
    "lat": "26.90403",
    "lng": "83.98087"
  },
  {
    "country": "IN",
    "name": "Padra",
    "lat": "22.2398",
    "lng": "73.08451"
  },
  {
    "country": "IN",
    "name": "Padmanābhapuram",
    "lat": "8.24462",
    "lng": "77.32581"
  },
  {
    "country": "IN",
    "name": "Paddhari",
    "lat": "22.43654",
    "lng": "70.60162"
  },
  {
    "country": "IN",
    "name": "Padampur",
    "lat": "29.70885",
    "lng": "73.62539"
  },
  {
    "country": "IN",
    "name": "Padampur",
    "lat": "20.99932",
    "lng": "83.06325"
  },
  {
    "country": "IN",
    "name": "Padam",
    "lat": "33.46659",
    "lng": "76.88488"
  },
  {
    "country": "IN",
    "name": "Pachperwa",
    "lat": "27.51234",
    "lng": "82.64297"
  },
  {
    "country": "IN",
    "name": "Pāchora",
    "lat": "20.66727",
    "lng": "75.35305"
  },
  {
    "country": "IN",
    "name": "Pachmarhi",
    "lat": "22.46791",
    "lng": "78.43312"
  },
  {
    "country": "IN",
    "name": "Ottappālam",
    "lat": "10.7735",
    "lng": "76.37758"
  },
  {
    "country": "IN",
    "name": "Osmanabad",
    "lat": "18.18158",
    "lng": "76.03889"
  },
  {
    "country": "IN",
    "name": "Orchha",
    "lat": "25.35192",
    "lng": "78.64033"
  },
  {
    "country": "IN",
    "name": "Oran",
    "lat": "25.36882",
    "lng": "80.7423"
  },
  {
    "country": "IN",
    "name": "Orai",
    "lat": "25.99023",
    "lng": "79.45334"
  },
  {
    "country": "IN",
    "name": "Ongole",
    "lat": "15.50357",
    "lng": "80.04454"
  },
  {
    "country": "IN",
    "name": "Omalur",
    "lat": "11.74099",
    "lng": "78.04559"
  },
  {
    "country": "IN",
    "name": "Olpād",
    "lat": "21.33649",
    "lng": "72.75161"
  },
  {
    "country": "IN",
    "name": "Okha",
    "lat": "22.46756",
    "lng": "69.07002"
  },
  {
    "country": "IN",
    "name": "Ozar",
    "lat": "20.09473",
    "lng": "73.92816"
  },
  {
    "country": "IN",
    "name": "Odugattūr",
    "lat": "12.76793",
    "lng": "78.88304"
  },
  {
    "country": "IN",
    "name": "Odlābāri",
    "lat": "26.83644",
    "lng": "88.62943"
  },
  {
    "country": "IN",
    "name": "Obra",
    "lat": "24.41863",
    "lng": "82.98797"
  },
  {
    "country": "IN",
    "name": "Nyāmti",
    "lat": "14.14869",
    "lng": "75.57641"
  },
  {
    "country": "IN",
    "name": "Nūzvīd",
    "lat": "16.78854",
    "lng": "80.84593"
  },
  {
    "country": "IN",
    "name": "Nūrpur Kalān",
    "lat": "31.16667",
    "lng": "76.48333"
  },
  {
    "country": "IN",
    "name": "Nūrpur",
    "lat": "29.14956",
    "lng": "78.4084"
  },
  {
    "country": "IN",
    "name": "Nūrmahal",
    "lat": "31.09662",
    "lng": "75.59386"
  },
  {
    "country": "IN",
    "name": "Numāligarh",
    "lat": "26.62249",
    "lng": "93.72225"
  },
  {
    "country": "IN",
    "name": "Nūh",
    "lat": "28.10296",
    "lng": "77.00144"
  },
  {
    "country": "IN",
    "name": "Nowrangapur",
    "lat": "19.23114",
    "lng": "82.54826"
  },
  {
    "country": "IN",
    "name": "North Vanlaiphai",
    "lat": "23.13227",
    "lng": "93.06532"
  },
  {
    "country": "IN",
    "name": "North Lakhimpur",
    "lat": "27.23517",
    "lng": "94.10357"
  },
  {
    "country": "IN",
    "name": "North Guwāhāti",
    "lat": "26.19749",
    "lng": "91.7202"
  },
  {
    "country": "IN",
    "name": "Nongstoin",
    "lat": "25.51704",
    "lng": "91.26484"
  },
  {
    "country": "IN",
    "name": "Nongpoh",
    "lat": "25.9023",
    "lng": "91.87694"
  },
  {
    "country": "IN",
    "name": "Nokha",
    "lat": "27.56155",
    "lng": "73.47141"
  },
  {
    "country": "IN",
    "name": "Nohar",
    "lat": "29.18292",
    "lng": "74.77064"
  },
  {
    "country": "IN",
    "name": "Noāmundi",
    "lat": "22.16094",
    "lng": "85.50416"
  },
  {
    "country": "IN",
    "name": "Nizāmābād",
    "lat": "26.05295",
    "lng": "83.05787"
  },
  {
    "country": "IN",
    "name": "Nizāmābād",
    "lat": "18.67154",
    "lng": "78.0988"
  },
  {
    "country": "IN",
    "name": "Niwāri",
    "lat": "28.87611",
    "lng": "77.5382"
  },
  {
    "country": "IN",
    "name": "Nirsā",
    "lat": "23.78438",
    "lng": "86.70692"
  },
  {
    "country": "IN",
    "name": "Nirmāli",
    "lat": "26.31397",
    "lng": "86.58537"
  },
  {
    "country": "IN",
    "name": "Nirmal",
    "lat": "19.09685",
    "lng": "78.34407"
  },
  {
    "country": "IN",
    "name": "Nipāni",
    "lat": "16.399",
    "lng": "74.38285"
  },
  {
    "country": "IN",
    "name": "Neem ka Thana",
    "lat": "27.73976",
    "lng": "75.78652"
  },
  {
    "country": "IN",
    "name": "Nīmbāhera",
    "lat": "24.62166",
    "lng": "74.67999"
  },
  {
    "country": "IN",
    "name": "Nimāparha",
    "lat": "20.05756",
    "lng": "86.00436"
  },
  {
    "country": "IN",
    "name": "Nīmāj",
    "lat": "26.14995",
    "lng": "74.00094"
  },
  {
    "country": "IN",
    "name": "Nīlokheri",
    "lat": "29.83671",
    "lng": "76.93191"
  },
  {
    "country": "IN",
    "name": "Nīlēshwar",
    "lat": "12.25953",
    "lng": "75.1352"
  },
  {
    "country": "IN",
    "name": "Nilanga",
    "lat": "18.11675",
    "lng": "76.75279"
  },
  {
    "country": "IN",
    "name": "Nilakottai",
    "lat": "10.165",
    "lng": "77.85024"
  },
  {
    "country": "IN",
    "name": "Nīlgiri",
    "lat": "21.46235",
    "lng": "86.76794"
  },
  {
    "country": "IN",
    "name": "Nihtaur",
    "lat": "29.32416",
    "lng": "78.38724"
  },
  {
    "country": "IN",
    "name": "Needamangalam",
    "lat": "10.77378",
    "lng": "79.41875"
  },
  {
    "country": "IN",
    "name": "Nidadavole",
    "lat": "16.90572",
    "lng": "81.67222"
  },
  {
    "country": "IN",
    "name": "Nichlaul",
    "lat": "27.31247",
    "lng": "83.7253"
  },
  {
    "country": "IN",
    "name": "Neyyāttinkara",
    "lat": "8.39854",
    "lng": "77.08586"
  },
  {
    "country": "IN",
    "name": "New Delhi",
    "lat": "28.63576",
    "lng": "77.22445"
  },
  {
    "country": "IN",
    "name": "Neturhāt",
    "lat": "23.47457",
    "lng": "84.2678"
  },
  {
    "country": "IN",
    "name": "Neral",
    "lat": "19.02475",
    "lng": "73.31688"
  },
  {
    "country": "IN",
    "name": "Nepānagar",
    "lat": "21.4538",
    "lng": "76.39335"
  },
  {
    "country": "IN",
    "name": "Nellore",
    "lat": "14.44992",
    "lng": "79.98697"
  },
  {
    "country": "IN",
    "name": "Nellikkuppam",
    "lat": "11.77554",
    "lng": "79.67016"
  },
  {
    "country": "IN",
    "name": "Nelamangala",
    "lat": "13.09978",
    "lng": "77.39364"
  },
  {
    "country": "IN",
    "name": "Nedumangād",
    "lat": "8.60267",
    "lng": "77.00139"
  },
  {
    "country": "IN",
    "name": "Nāzirā",
    "lat": "26.91649",
    "lng": "94.73611"
  },
  {
    "country": "IN",
    "name": "Nāyudupet",
    "lat": "13.90742",
    "lng": "79.89465"
  },
  {
    "country": "IN",
    "name": "Nayāgarh",
    "lat": "20.12882",
    "lng": "85.09626"
  },
  {
    "country": "IN",
    "name": "Naya Bāzār",
    "lat": "27.13082",
    "lng": "88.23972"
  },
  {
    "country": "IN",
    "name": "Nawanshahr",
    "lat": "31.1245",
    "lng": "76.11613"
  },
  {
    "country": "IN",
    "name": "Nawānshahr",
    "lat": "32.76505",
    "lng": "74.52772"
  },
  {
    "country": "IN",
    "name": "Nawalgarh",
    "lat": "27.85161",
    "lng": "75.27384"
  },
  {
    "country": "IN",
    "name": "Niwai",
    "lat": "26.36073",
    "lng": "75.91836"
  },
  {
    "country": "IN",
    "name": "Nawāda",
    "lat": "24.8867",
    "lng": "85.54364"
  },
  {
    "country": "IN",
    "name": "Nawābganj",
    "lat": "26.49716",
    "lng": "80.30934"
  },
  {
    "country": "IN",
    "name": "Nawābganj",
    "lat": "28.54103",
    "lng": "79.63462"
  },
  {
    "country": "IN",
    "name": "Nawābganj",
    "lat": "26.93129",
    "lng": "81.19841"
  },
  {
    "country": "IN",
    "name": "Nawābganj",
    "lat": "26.86396",
    "lng": "82.14103"
  },
  {
    "country": "IN",
    "name": "Nāwa",
    "lat": "27.0195",
    "lng": "75.00226"
  },
  {
    "country": "IN",
    "name": "Navelim",
    "lat": "15.53333",
    "lng": "73.98333"
  },
  {
    "country": "IN",
    "name": "Navalgund",
    "lat": "15.55877",
    "lng": "75.35305"
  },
  {
    "country": "IN",
    "name": "Navadwīp",
    "lat": "23.4067",
    "lng": "88.36861"
  },
  {
    "country": "IN",
    "name": "Nautanwa",
    "lat": "27.42752",
    "lng": "83.41789"
  },
  {
    "country": "IN",
    "name": "Naugachhia",
    "lat": "25.38807",
    "lng": "87.09906"
  },
  {
    "country": "IN",
    "name": "Nāttarasankottai",
    "lat": "9.86905",
    "lng": "78.55305"
  },
  {
    "country": "IN",
    "name": "Nattam",
    "lat": "10.22776",
    "lng": "78.22969"
  },
  {
    "country": "IN",
    "name": "Nāthdwāra",
    "lat": "24.93805",
    "lng": "73.82392"
  },
  {
    "country": "IN",
    "name": "Nasrullāhganj",
    "lat": "22.6837",
    "lng": "77.27069"
  },
  {
    "country": "IN",
    "name": "Nāsriganj",
    "lat": "25.0514",
    "lng": "84.32839"
  },
  {
    "country": "IN",
    "name": "Nāspur",
    "lat": "18.84577",
    "lng": "79.46165"
  },
  {
    "country": "IN",
    "name": "Nasīrābād",
    "lat": "26.30473",
    "lng": "74.73364"
  },
  {
    "country": "IN",
    "name": "Nashik",
    "lat": "19.99727",
    "lng": "73.79096"
  },
  {
    "country": "IN",
    "name": "Narwar",
    "lat": "25.6439",
    "lng": "77.9129"
  },
  {
    "country": "IN",
    "name": "Narwāna",
    "lat": "29.59903",
    "lng": "76.11927"
  },
  {
    "country": "IN",
    "name": "Narsīpatnam",
    "lat": "17.66709",
    "lng": "82.61245"
  },
  {
    "country": "IN",
    "name": "Nārsingi",
    "lat": "18.04468",
    "lng": "78.42516"
  },
  {
    "country": "IN",
    "name": "Narsinghgarh",
    "lat": "23.70758",
    "lng": "77.09319"
  },
  {
    "country": "IN",
    "name": "Narsimhapur",
    "lat": "22.94936",
    "lng": "79.18357"
  },
  {
    "country": "IN",
    "name": "Naroda",
    "lat": "23.07041",
    "lng": "72.65702"
  },
  {
    "country": "IN",
    "name": "Nārnaund",
    "lat": "29.22047",
    "lng": "76.14278"
  },
  {
    "country": "IN",
    "name": "Nārnaul",
    "lat": "28.04444",
    "lng": "76.10833"
  },
  {
    "country": "IN",
    "name": "Narharpur",
    "lat": "20.44892",
    "lng": "81.62004"
  },
  {
    "country": "IN",
    "name": "Nargund",
    "lat": "15.72299",
    "lng": "75.38666"
  },
  {
    "country": "IN",
    "name": "Narendranagar",
    "lat": "30.16173",
    "lng": "78.28712"
  },
  {
    "country": "IN",
    "name": "Naregal",
    "lat": "15.57316",
    "lng": "75.80805"
  },
  {
    "country": "IN",
    "name": "Nārāyanpet",
    "lat": "16.74799",
    "lng": "77.4954"
  },
  {
    "country": "IN",
    "name": "Narāyangarh",
    "lat": "30.47798",
    "lng": "77.12804"
  },
  {
    "country": "IN",
    "name": "Nārāyangarh",
    "lat": "24.27083",
    "lng": "75.05007"
  },
  {
    "country": "IN",
    "name": "Nārāyanavanam",
    "lat": "13.42565",
    "lng": "79.58881"
  },
  {
    "country": "IN",
    "name": "Nāravārikuppam",
    "lat": "13.19133",
    "lng": "80.18473"
  },
  {
    "country": "IN",
    "name": "Naraura",
    "lat": "28.20147",
    "lng": "78.38723"
  },
  {
    "country": "IN",
    "name": "Narauli",
    "lat": "28.48547",
    "lng": "78.71484"
  },
  {
    "country": "IN",
    "name": "Narasingāpuram",
    "lat": "13.60759",
    "lng": "79.31652"
  },
  {
    "country": "IN",
    "name": "Narasimharājapura",
    "lat": "13.61075",
    "lng": "75.512"
  },
  {
    "country": "IN",
    "name": "Narasaraopet",
    "lat": "16.23488",
    "lng": "80.04927"
  },
  {
    "country": "IN",
    "name": "Narasapur",
    "lat": "16.43425",
    "lng": "81.69845"
  },
  {
    "country": "IN",
    "name": "Narasannapeta",
    "lat": "18.41428",
    "lng": "84.04463"
  },
  {
    "country": "IN",
    "name": "Naraini",
    "lat": "25.19033",
    "lng": "80.475"
  },
  {
    "country": "IN",
    "name": "Naraina",
    "lat": "26.79069",
    "lng": "75.20608"
  },
  {
    "country": "IN",
    "name": "Napāsar",
    "lat": "27.96059",
    "lng": "73.55913"
  },
  {
    "country": "IN",
    "name": "Nānpāra",
    "lat": "27.86459",
    "lng": "81.50036"
  },
  {
    "country": "IN",
    "name": "Nannilam",
    "lat": "10.87933",
    "lng": "79.61062"
  },
  {
    "country": "IN",
    "name": "Nanjangūd",
    "lat": "12.11764",
    "lng": "76.68397"
  },
  {
    "country": "IN",
    "name": "Nanguneri",
    "lat": "8.49326",
    "lng": "77.65806"
  },
  {
    "country": "IN",
    "name": "Nāngloi Jāt",
    "lat": "28.67957",
    "lng": "77.06799"
  },
  {
    "country": "IN",
    "name": "Nangavalli",
    "lat": "11.76189",
    "lng": "77.89093"
  },
  {
    "country": "IN",
    "name": "Nangal",
    "lat": "31.38966",
    "lng": "76.37574"
  },
  {
    "country": "IN",
    "name": "Nandyāl",
    "lat": "15.47799",
    "lng": "78.4836"
  },
  {
    "country": "IN",
    "name": "Nandurbar",
    "lat": "21.36671",
    "lng": "74.24051"
  },
  {
    "country": "IN",
    "name": "Nāndūra Buzurg",
    "lat": "20.83417",
    "lng": "76.45924"
  },
  {
    "country": "IN",
    "name": "Nandikotkūr",
    "lat": "15.85668",
    "lng": "78.26569"
  },
  {
    "country": "IN",
    "name": "Nandigāma",
    "lat": "16.7717",
    "lng": "80.28596"
  },
  {
    "country": "IN",
    "name": "Nandgaon",
    "lat": "27.71102",
    "lng": "77.38653"
  },
  {
    "country": "IN",
    "name": "Nāndgaon",
    "lat": "20.3068",
    "lng": "74.65501"
  },
  {
    "country": "IN",
    "name": "Nanded",
    "lat": "19.16023",
    "lng": "77.31497"
  },
  {
    "country": "IN",
    "name": "Nanauta",
    "lat": "29.71215",
    "lng": "77.41728"
  },
  {
    "country": "IN",
    "name": "Nāmrup",
    "lat": "27.19395",
    "lng": "95.31929"
  },
  {
    "country": "IN",
    "name": "Namli",
    "lat": "23.46115",
    "lng": "75.06036"
  },
  {
    "country": "IN",
    "name": "Namchi",
    "lat": "27.16494",
    "lng": "88.3638"
  },
  {
    "country": "IN",
    "name": "Nambutalai",
    "lat": "9.72766",
    "lng": "79.00707"
  },
  {
    "country": "IN",
    "name": "Nambiyūr",
    "lat": "11.35811",
    "lng": "77.32115"
  },
  {
    "country": "IN",
    "name": "Nāmakkal",
    "lat": "11.22126",
    "lng": "78.16524"
  },
  {
    "country": "IN",
    "name": "Nāmagiripettai",
    "lat": "11.45513",
    "lng": "78.26818"
  },
  {
    "country": "IN",
    "name": "Naliya",
    "lat": "23.26058",
    "lng": "68.82655"
  },
  {
    "country": "IN",
    "name": "Nalhāti",
    "lat": "24.29704",
    "lng": "87.82899"
  },
  {
    "country": "IN",
    "name": "Nalgonda",
    "lat": "17.05439",
    "lng": "79.26707"
  },
  {
    "country": "IN",
    "name": "Naldurg",
    "lat": "17.81667",
    "lng": "76.28182"
  },
  {
    "country": "IN",
    "name": "Nālāgarh",
    "lat": "31.04168",
    "lng": "76.72285"
  },
  {
    "country": "IN",
    "name": "Nakūr",
    "lat": "29.91964",
    "lng": "77.30438"
  },
  {
    "country": "IN",
    "name": "Naksalbāri",
    "lat": "26.6827",
    "lng": "88.22001"
  },
  {
    "country": "IN",
    "name": "Nakodar",
    "lat": "31.12586",
    "lng": "75.47508"
  },
  {
    "country": "IN",
    "name": "Najībābād",
    "lat": "29.61194",
    "lng": "78.34274"
  },
  {
    "country": "IN",
    "name": "Nainwa",
    "lat": "25.77145",
    "lng": "75.84978"
  },
  {
    "country": "IN",
    "name": "Nainpur",
    "lat": "22.42996",
    "lng": "80.10561"
  },
  {
    "country": "IN",
    "name": "Naini Tāl",
    "lat": "29.39743",
    "lng": "79.44686"
  },
  {
    "country": "IN",
    "name": "Naihāti",
    "lat": "22.89396",
    "lng": "88.41521"
  },
  {
    "country": "IN",
    "name": "Naīgarhi",
    "lat": "24.78686",
    "lng": "81.77868"
  },
  {
    "country": "IN",
    "name": "Nahorkatiya",
    "lat": "27.28912",
    "lng": "95.3418"
  },
  {
    "country": "IN",
    "name": "Nāhan",
    "lat": "30.56029",
    "lng": "77.29426"
  },
  {
    "country": "IN",
    "name": "Nagrota",
    "lat": "32.0571",
    "lng": "76.09139"
  },
  {
    "country": "IN",
    "name": "Nagrām",
    "lat": "26.61872",
    "lng": "81.14043"
  },
  {
    "country": "IN",
    "name": "Nagpur",
    "lat": "21.14631",
    "lng": "79.08491"
  },
  {
    "country": "IN",
    "name": "Nāgothana",
    "lat": "18.54225",
    "lng": "73.13493"
  },
  {
    "country": "IN",
    "name": "Nāgod",
    "lat": "24.56924",
    "lng": "80.58809"
  },
  {
    "country": "IN",
    "name": "Nāgireddipalli",
    "lat": "14.27005",
    "lng": "79.10131"
  },
  {
    "country": "IN",
    "name": "Nagīna",
    "lat": "29.44433",
    "lng": "78.43646"
  },
  {
    "country": "IN",
    "name": "Nāgercoil",
    "lat": "8.17899",
    "lng": "77.43227"
  },
  {
    "country": "IN",
    "name": "Nagda",
    "lat": "23.45834",
    "lng": "75.41759"
  },
  {
    "country": "IN",
    "name": "Nāgaur",
    "lat": "27.20201",
    "lng": "73.73394"
  },
  {
    "country": "IN",
    "name": "Nāgar Karnūl",
    "lat": "16.4821",
    "lng": "78.32471"
  },
  {
    "country": "IN",
    "name": "Nagari",
    "lat": "13.32139",
    "lng": "79.58557"
  },
  {
    "country": "IN",
    "name": "Nagar",
    "lat": "32.13808",
    "lng": "77.17393"
  },
  {
    "country": "IN",
    "name": "Nagar",
    "lat": "27.42397",
    "lng": "77.09922"
  },
  {
    "country": "IN",
    "name": "Negapatam",
    "lat": "10.76377",
    "lng": "79.84313"
  },
  {
    "country": "IN",
    "name": "Nāgamangala",
    "lat": "12.81939",
    "lng": "76.75456"
  },
  {
    "country": "IN",
    "name": "Naduvattam",
    "lat": "11.48075",
    "lng": "76.54365"
  },
  {
    "country": "IN",
    "name": "Naduvannūr",
    "lat": "11.48772",
    "lng": "75.77511"
  },
  {
    "country": "IN",
    "name": "Nadīgaon",
    "lat": "26.10784",
    "lng": "79.02283"
  },
  {
    "country": "IN",
    "name": "Nadiād",
    "lat": "22.69385",
    "lng": "72.86157"
  },
  {
    "country": "IN",
    "name": "Nādbai",
    "lat": "27.22288",
    "lng": "77.19569"
  },
  {
    "country": "IN",
    "name": "Nādaun",
    "lat": "31.78303",
    "lng": "76.3431"
  },
  {
    "country": "IN",
    "name": "Nādāpuram",
    "lat": "11.68465",
    "lng": "75.65493"
  },
  {
    "country": "IN",
    "name": "Nabīnagar",
    "lat": "24.60681",
    "lng": "84.12624"
  },
  {
    "country": "IN",
    "name": "Nābha",
    "lat": "30.37577",
    "lng": "76.15292"
  },
  {
    "country": "IN",
    "name": "Mysore",
    "lat": "12.29791",
    "lng": "76.63925"
  },
  {
    "country": "IN",
    "name": "Muzaffarpur",
    "lat": "26.12259",
    "lng": "85.39055"
  },
  {
    "country": "IN",
    "name": "Muzaffarnagar",
    "lat": "29.47091",
    "lng": "77.70332"
  },
  {
    "country": "IN",
    "name": "Mūvattupula",
    "lat": "9.98493",
    "lng": "76.57728"
  },
  {
    "country": "IN",
    "name": "Muttupet",
    "lat": "10.39505",
    "lng": "79.49353"
  },
  {
    "country": "IN",
    "name": "Mustafābād",
    "lat": "30.2022",
    "lng": "77.14873"
  },
  {
    "country": "IN",
    "name": "Mussoorie",
    "lat": "30.45498",
    "lng": "78.07068"
  },
  {
    "country": "IN",
    "name": "Musiri",
    "lat": "10.95299",
    "lng": "78.44427"
  },
  {
    "country": "IN",
    "name": "Mushābani",
    "lat": "22.51135",
    "lng": "86.45713"
  },
  {
    "country": "IN",
    "name": "Musāfir-Khāna",
    "lat": "26.37837",
    "lng": "81.79607"
  },
  {
    "country": "IN",
    "name": "Murwāra",
    "lat": "23.83776",
    "lng": "80.39405"
  },
  {
    "country": "IN",
    "name": "Murud",
    "lat": "18.32817",
    "lng": "72.9621"
  },
  {
    "country": "IN",
    "name": "Murtajāpur",
    "lat": "20.73299",
    "lng": "77.36694"
  },
  {
    "country": "IN",
    "name": "Murshidābād",
    "lat": "24.1839",
    "lng": "88.27171"
  },
  {
    "country": "IN",
    "name": "Mursān",
    "lat": "27.57788",
    "lng": "77.94091"
  },
  {
    "country": "IN",
    "name": "Murlīganj",
    "lat": "25.8969",
    "lng": "86.99577"
  },
  {
    "country": "IN",
    "name": "Morinda",
    "lat": "30.79014",
    "lng": "76.49883"
  },
  {
    "country": "IN",
    "name": "Muri",
    "lat": "23.37074",
    "lng": "85.86236"
  },
  {
    "country": "IN",
    "name": "Murgūd",
    "lat": "16.39604",
    "lng": "74.19142"
  },
  {
    "country": "IN",
    "name": "Murbād",
    "lat": "19.25395",
    "lng": "73.38993"
  },
  {
    "country": "IN",
    "name": "Muragācha",
    "lat": "23.53631",
    "lng": "88.39425"
  },
  {
    "country": "IN",
    "name": "Murādnagar",
    "lat": "28.78069",
    "lng": "77.49865"
  },
  {
    "country": "IN",
    "name": "Munnar",
    "lat": "10.08818",
    "lng": "77.06239"
  },
  {
    "country": "IN",
    "name": "Munirābād",
    "lat": "15.30928",
    "lng": "76.3383"
  },
  {
    "country": "IN",
    "name": "Monghyr",
    "lat": "25.37459",
    "lng": "86.47455"
  },
  {
    "country": "IN",
    "name": "Mungeli",
    "lat": "22.06566",
    "lng": "81.68543"
  },
  {
    "country": "IN",
    "name": "Mungaoli",
    "lat": "24.40837",
    "lng": "78.09588"
  },
  {
    "country": "IN",
    "name": "Mūndwa",
    "lat": "27.0631",
    "lng": "73.82304"
  },
  {
    "country": "IN",
    "name": "Mundra",
    "lat": "22.83918",
    "lng": "69.7219"
  },
  {
    "country": "IN",
    "name": "Mundi",
    "lat": "22.06693",
    "lng": "76.49326"
  },
  {
    "country": "IN",
    "name": "Mundgod",
    "lat": "14.97144",
    "lng": "75.03658"
  },
  {
    "country": "IN",
    "name": "Mundargi",
    "lat": "15.20677",
    "lng": "75.8839"
  },
  {
    "country": "IN",
    "name": "Multai",
    "lat": "21.77463",
    "lng": "78.25756"
  },
  {
    "country": "IN",
    "name": "Mūlki",
    "lat": "13.09101",
    "lng": "74.79353"
  },
  {
    "country": "IN",
    "name": "Mulgund",
    "lat": "15.2807",
    "lng": "75.52132"
  },
  {
    "country": "IN",
    "name": "Mulbāgal",
    "lat": "13.16352",
    "lng": "78.39346"
  },
  {
    "country": "IN",
    "name": "Muluppilagadu",
    "lat": "11.79788",
    "lng": "75.45111"
  },
  {
    "country": "IN",
    "name": "Mūlanūr",
    "lat": "10.79426",
    "lng": "77.7115"
  },
  {
    "country": "IN",
    "name": "Mūl",
    "lat": "20.06987",
    "lng": "79.67826"
  },
  {
    "country": "IN",
    "name": "Muktsar",
    "lat": "30.47426",
    "lng": "74.5166"
  },
  {
    "country": "IN",
    "name": "Mukher",
    "lat": "18.70636",
    "lng": "77.36795"
  },
  {
    "country": "IN",
    "name": "Mukeriān",
    "lat": "31.95394",
    "lng": "75.61716"
  },
  {
    "country": "IN",
    "name": "Muhammadābād",
    "lat": "27.30895",
    "lng": "79.43252"
  },
  {
    "country": "IN",
    "name": "Muhammadābād",
    "lat": "26.03404",
    "lng": "83.38114"
  },
  {
    "country": "IN",
    "name": "Muhammadābād",
    "lat": "25.61907",
    "lng": "83.75576"
  },
  {
    "country": "IN",
    "name": "Mugma",
    "lat": "23.77015",
    "lng": "86.72746"
  },
  {
    "country": "IN",
    "name": "Mughal Sarāi",
    "lat": "25.28307",
    "lng": "83.11968"
  },
  {
    "country": "IN",
    "name": "Mudukulattūr",
    "lat": "9.34169",
    "lng": "78.51388"
  },
  {
    "country": "IN",
    "name": "Mudkhed",
    "lat": "19.15657",
    "lng": "77.50304"
  },
  {
    "country": "IN",
    "name": "Mudgere",
    "lat": "13.13353",
    "lng": "75.6416"
  },
  {
    "country": "IN",
    "name": "Mudhol",
    "lat": "16.33354",
    "lng": "75.28305"
  },
  {
    "country": "IN",
    "name": "Mudgal",
    "lat": "16.01191",
    "lng": "76.44203"
  },
  {
    "country": "IN",
    "name": "Muddebihāl",
    "lat": "16.33782",
    "lng": "76.13173"
  },
  {
    "country": "IN",
    "name": "Mūdbidri",
    "lat": "13.06653",
    "lng": "74.99525"
  },
  {
    "country": "IN",
    "name": "Mubārakpur",
    "lat": "26.08866",
    "lng": "83.29088"
  },
  {
    "country": "IN",
    "name": "Mowād",
    "lat": "21.46475",
    "lng": "78.45103"
  },
  {
    "country": "IN",
    "name": "Mothīhāri",
    "lat": "26.64862",
    "lng": "84.91656"
  },
  {
    "country": "IN",
    "name": "Moth",
    "lat": "25.72595",
    "lng": "78.95029"
  },
  {
    "country": "IN",
    "name": "Morwa",
    "lat": "22.90469",
    "lng": "73.83912"
  },
  {
    "country": "IN",
    "name": "Morsi",
    "lat": "21.3403",
    "lng": "78.01258"
  },
  {
    "country": "IN",
    "name": "Morjim",
    "lat": "15.63097",
    "lng": "73.73903"
  },
  {
    "country": "IN",
    "name": "Morena",
    "lat": "26.49892",
    "lng": "77.99534"
  },
  {
    "country": "IN",
    "name": "Morbi",
    "lat": "22.81731",
    "lng": "70.8377"
  },
  {
    "country": "IN",
    "name": "Morār",
    "lat": "26.2264",
    "lng": "78.22482"
  },
  {
    "country": "IN",
    "name": "Morānha",
    "lat": "27.18735",
    "lng": "94.91557"
  },
  {
    "country": "IN",
    "name": "Moram",
    "lat": "17.78812",
    "lng": "76.47077"
  },
  {
    "country": "IN",
    "name": "Morādābād",
    "lat": "28.83893",
    "lng": "78.77684"
  },
  {
    "country": "IN",
    "name": "Mon",
    "lat": "26.73583",
    "lng": "95.05841"
  },
  {
    "country": "IN",
    "name": "Mokokchūng",
    "lat": "26.3248",
    "lng": "94.51834"
  },
  {
    "country": "IN",
    "name": "Mokameh",
    "lat": "25.39662",
    "lng": "85.9219"
  },
  {
    "country": "IN",
    "name": "Moirāng",
    "lat": "24.4975",
    "lng": "93.77791"
  },
  {
    "country": "IN",
    "name": "Mohpa",
    "lat": "21.31012",
    "lng": "78.82969"
  },
  {
    "country": "IN",
    "name": "Mohiuddinnagar",
    "lat": "25.57374",
    "lng": "85.66944"
  },
  {
    "country": "IN",
    "name": "Mohgaon",
    "lat": "21.63941",
    "lng": "78.73638"
  },
  {
    "country": "IN",
    "name": "Mohanūr",
    "lat": "11.05936",
    "lng": "78.13965"
  },
  {
    "country": "IN",
    "name": "Mohanpur",
    "lat": "28.25261",
    "lng": "80.24498"
  },
  {
    "country": "IN",
    "name": "Mohān",
    "lat": "26.78008",
    "lng": "80.67497"
  },
  {
    "country": "IN",
    "name": "Moga",
    "lat": "30.81383",
    "lng": "75.16878"
  },
  {
    "country": "IN",
    "name": "Modāsa",
    "lat": "23.46253",
    "lng": "73.29857"
  },
  {
    "country": "IN",
    "name": "Meethari Marwar",
    "lat": "27.57615",
    "lng": "74.68661"
  },
  {
    "country": "IN",
    "name": "Misrikh",
    "lat": "27.43137",
    "lng": "80.53157"
  },
  {
    "country": "IN",
    "name": "Mirzāpur",
    "lat": "25.1449",
    "lng": "82.56534"
  },
  {
    "country": "IN",
    "name": "Mirik",
    "lat": "26.88817",
    "lng": "88.19007"
  },
  {
    "country": "IN",
    "name": "Miriālgūda",
    "lat": "16.8722",
    "lng": "79.56247"
  },
  {
    "country": "IN",
    "name": "Mīrganj",
    "lat": "28.54012",
    "lng": "79.20817"
  },
  {
    "country": "IN",
    "name": "Mīrānpur Katra",
    "lat": "28.02963",
    "lng": "79.66778"
  },
  {
    "country": "IN",
    "name": "Mīrānpur",
    "lat": "29.29026",
    "lng": "77.94939"
  },
  {
    "country": "IN",
    "name": "Mīnjūr",
    "lat": "13.27951",
    "lng": "80.25815"
  },
  {
    "country": "IN",
    "name": "Milak",
    "lat": "28.61031",
    "lng": "79.16997"
  },
  {
    "country": "IN",
    "name": "Mihona",
    "lat": "26.28373",
    "lng": "78.98048"
  },
  {
    "country": "IN",
    "name": "Mhāsvād",
    "lat": "17.63359",
    "lng": "74.78773"
  },
  {
    "country": "IN",
    "name": "Mhasla",
    "lat": "18.1334",
    "lng": "73.11162"
  },
  {
    "country": "IN",
    "name": "Mettur",
    "lat": "11.78796",
    "lng": "77.8008"
  },
  {
    "country": "IN",
    "name": "Mettupalayam",
    "lat": "11.29971",
    "lng": "76.93485"
  },
  {
    "country": "IN",
    "name": "Mettuppālaiyam",
    "lat": "11.16806",
    "lng": "78.44944"
  },
  {
    "country": "IN",
    "name": "Merta",
    "lat": "26.64859",
    "lng": "74.03414"
  },
  {
    "country": "IN",
    "name": "Mendarda",
    "lat": "21.32112",
    "lng": "70.44078"
  },
  {
    "country": "IN",
    "name": "Memāri",
    "lat": "23.17647",
    "lng": "88.09749"
  },
  {
    "country": "IN",
    "name": "Melur",
    "lat": "10.03241",
    "lng": "78.3393"
  },
  {
    "country": "IN",
    "name": "Melukote",
    "lat": "12.66258",
    "lng": "76.64861"
  },
  {
    "country": "IN",
    "name": "Mehndāwal",
    "lat": "26.97579",
    "lng": "83.10995"
  },
  {
    "country": "IN",
    "name": "Mehnagar",
    "lat": "25.87889",
    "lng": "83.11611"
  },
  {
    "country": "IN",
    "name": "Mehekar",
    "lat": "20.1505",
    "lng": "76.56841"
  },
  {
    "country": "IN",
    "name": "Meghraj",
    "lat": "23.49805",
    "lng": "73.51352"
  },
  {
    "country": "IN",
    "name": "Meerut",
    "lat": "28.98002",
    "lng": "77.70636"
  },
  {
    "country": "IN",
    "name": "Medinīpur",
    "lat": "22.42114",
    "lng": "87.32257"
  },
  {
    "country": "IN",
    "name": "Medchal",
    "lat": "17.62972",
    "lng": "78.48139"
  },
  {
    "country": "IN",
    "name": "Medak",
    "lat": "18.04531",
    "lng": "78.26078"
  },
  {
    "country": "IN",
    "name": "Mayiladuthurai",
    "lat": "11.10354",
    "lng": "79.655"
  },
  {
    "country": "IN",
    "name": "Mayāng Imphāl",
    "lat": "24.60998",
    "lng": "93.88873"
  },
  {
    "country": "IN",
    "name": "Māyakonda",
    "lat": "14.28894",
    "lng": "76.08305"
  },
  {
    "country": "IN",
    "name": "Mawāna",
    "lat": "29.10288",
    "lng": "77.92199"
  },
  {
    "country": "IN",
    "name": "Mavoor",
    "lat": "11.26667",
    "lng": "75.91667"
  },
  {
    "country": "IN",
    "name": "Māvelikara",
    "lat": "9.25929",
    "lng": "76.55642"
  },
  {
    "country": "IN",
    "name": "Maurānwān",
    "lat": "26.42876",
    "lng": "80.88008"
  },
  {
    "country": "IN",
    "name": "Maur",
    "lat": "30.08333",
    "lng": "75.25"
  },
  {
    "country": "IN",
    "name": "Mauganj",
    "lat": "24.66721",
    "lng": "81.87339"
  },
  {
    "country": "IN",
    "name": "Maudaha",
    "lat": "25.68312",
    "lng": "80.11419"
  },
  {
    "country": "IN",
    "name": "Mau Aimma",
    "lat": "25.69515",
    "lng": "81.92336"
  },
  {
    "country": "IN",
    "name": "Mau",
    "lat": "26.26584",
    "lng": "78.67108"
  },
  {
    "country": "IN",
    "name": "Mau",
    "lat": "25.94167",
    "lng": "83.56111"
  },
  {
    "country": "IN",
    "name": "Māttūr",
    "lat": "11.32147",
    "lng": "79.20245"
  },
  {
    "country": "IN",
    "name": "Mattanur",
    "lat": "11.93018",
    "lng": "75.57152"
  },
  {
    "country": "IN",
    "name": "Mathura",
    "lat": "27.5035",
    "lng": "77.67215"
  },
  {
    "country": "IN",
    "name": "Mātherān",
    "lat": "18.98281",
    "lng": "73.2652"
  },
  {
    "country": "IN",
    "name": "Mataundh",
    "lat": "25.43594",
    "lng": "80.15653"
  },
  {
    "country": "IN",
    "name": "Mātābhānga",
    "lat": "26.34197",
    "lng": "89.21555"
  },
  {
    "country": "IN",
    "name": "Masinigudi",
    "lat": "11.56831",
    "lng": "76.64087"
  },
  {
    "country": "IN",
    "name": "Masaurhi Buzurg",
    "lat": "25.35417",
    "lng": "85.03195"
  },
  {
    "country": "IN",
    "name": "Mormugao",
    "lat": "15.38914",
    "lng": "73.81491"
  },
  {
    "country": "IN",
    "name": "Mārkāpur",
    "lat": "15.73534",
    "lng": "79.26848"
  },
  {
    "country": "IN",
    "name": "Mariāni",
    "lat": "26.65725",
    "lng": "94.31529"
  },
  {
    "country": "IN",
    "name": "Mariāhu",
    "lat": "25.60404",
    "lng": "82.60379"
  },
  {
    "country": "IN",
    "name": "Marhaura",
    "lat": "25.97349",
    "lng": "84.86796"
  },
  {
    "country": "IN",
    "name": "Margherita",
    "lat": "27.28482",
    "lng": "95.66796"
  },
  {
    "country": "IN",
    "name": "Mārāndahalli",
    "lat": "12.38826",
    "lng": "78.00316"
  },
  {
    "country": "IN",
    "name": "Marakkanam",
    "lat": "12.19214",
    "lng": "79.94193"
  },
  {
    "country": "IN",
    "name": "Marayur",
    "lat": "10.27641",
    "lng": "77.16205"
  },
  {
    "country": "IN",
    "name": "Mārahra",
    "lat": "27.7368",
    "lng": "78.56891"
  },
  {
    "country": "IN",
    "name": "Māpuca",
    "lat": "15.59154",
    "lng": "73.80898"
  },
  {
    "country": "IN",
    "name": "Mānwat",
    "lat": "19.30133",
    "lng": "76.49735"
  },
  {
    "country": "IN",
    "name": "Mānvi",
    "lat": "15.99126",
    "lng": "77.05034"
  },
  {
    "country": "IN",
    "name": "Manthani",
    "lat": "18.65087",
    "lng": "79.66501"
  },
  {
    "country": "IN",
    "name": "Mansar",
    "lat": "21.39602",
    "lng": "79.2635"
  },
  {
    "country": "IN",
    "name": "Mānsa",
    "lat": "29.98844",
    "lng": "75.40167"
  },
  {
    "country": "IN",
    "name": "Mānsa",
    "lat": "23.42564",
    "lng": "72.65739"
  },
  {
    "country": "IN",
    "name": "Mānpur",
    "lat": "22.43151",
    "lng": "75.62107"
  },
  {
    "country": "IN",
    "name": "Manor",
    "lat": "19.7244",
    "lng": "72.90966"
  },
  {
    "country": "IN",
    "name": "Manohar Thāna",
    "lat": "24.24",
    "lng": "76.80182"
  },
  {
    "country": "IN",
    "name": "Manoharpur",
    "lat": "27.29769",
    "lng": "75.9495"
  },
  {
    "country": "IN",
    "name": "Manoharpur",
    "lat": "22.37456",
    "lng": "85.19234"
  },
  {
    "country": "IN",
    "name": "Mannargudi",
    "lat": "10.66626",
    "lng": "79.45064"
  },
  {
    "country": "IN",
    "name": "Mannārakkāt",
    "lat": "10.99223",
    "lng": "76.46418"
  },
  {
    "country": "IN",
    "name": "Manmād",
    "lat": "20.25334",
    "lng": "74.43755"
  },
  {
    "country": "IN",
    "name": "Mankāpur",
    "lat": "27.05189",
    "lng": "82.22961"
  },
  {
    "country": "IN",
    "name": "Mankāchar",
    "lat": "25.53347",
    "lng": "89.86373"
  },
  {
    "country": "IN",
    "name": "Mājalgaon",
    "lat": "19.15988",
    "lng": "76.20832"
  },
  {
    "country": "IN",
    "name": "Manjhanpur",
    "lat": "25.53046",
    "lng": "81.37566"
  },
  {
    "country": "IN",
    "name": "Manjēshvar",
    "lat": "12.71287",
    "lng": "74.88857"
  },
  {
    "country": "IN",
    "name": "Manjeri",
    "lat": "11.12018",
    "lng": "76.11996"
  },
  {
    "country": "IN",
    "name": "Manipala",
    "lat": "13.35",
    "lng": "74.78333"
  },
  {
    "country": "IN",
    "name": "Mānikpur",
    "lat": "25.06083",
    "lng": "81.09961"
  },
  {
    "country": "IN",
    "name": "Manihāri",
    "lat": "25.33891",
    "lng": "87.61998"
  },
  {
    "country": "IN",
    "name": "Maniar",
    "lat": "25.98546",
    "lng": "84.17233"
  },
  {
    "country": "IN",
    "name": "Mangrūl Pīr",
    "lat": "20.31379",
    "lng": "77.34178"
  },
  {
    "country": "IN",
    "name": "Māngrol",
    "lat": "25.33061",
    "lng": "76.50973"
  },
  {
    "country": "IN",
    "name": "Māngrol",
    "lat": "21.12268",
    "lng": "70.11484"
  },
  {
    "country": "IN",
    "name": "Manglaur",
    "lat": "29.79094",
    "lng": "77.87836"
  },
  {
    "country": "IN",
    "name": "Mangawān",
    "lat": "24.66754",
    "lng": "81.54644"
  },
  {
    "country": "IN",
    "name": "Mangan",
    "lat": "27.50965",
    "lng": "88.52206"
  },
  {
    "country": "IN",
    "name": "Mangalore",
    "lat": "12.91723",
    "lng": "74.85603"
  },
  {
    "country": "IN",
    "name": "Mangaldai",
    "lat": "26.44212",
    "lng": "92.03047"
  },
  {
    "country": "IN",
    "name": "Mangalam",
    "lat": "9.76473",
    "lng": "78.64037"
  },
  {
    "country": "IN",
    "name": "Mangalagiri",
    "lat": "16.43083",
    "lng": "80.56815"
  },
  {
    "country": "IN",
    "name": "Maner",
    "lat": "25.64602",
    "lng": "84.87291"
  },
  {
    "country": "IN",
    "name": "Mandya",
    "lat": "12.5223",
    "lng": "76.89746"
  },
  {
    "country": "IN",
    "name": "Māndvi",
    "lat": "22.83282",
    "lng": "69.35237"
  },
  {
    "country": "IN",
    "name": "Māndvi",
    "lat": "21.25526",
    "lng": "73.30412"
  },
  {
    "country": "IN",
    "name": "Mandsaur",
    "lat": "24.07184",
    "lng": "75.06986"
  },
  {
    "country": "IN",
    "name": "Māndleshwar",
    "lat": "22.17598",
    "lng": "75.65995"
  },
  {
    "country": "IN",
    "name": "Mandlā",
    "lat": "22.59879",
    "lng": "80.37115"
  },
  {
    "country": "IN",
    "name": "Mandi",
    "lat": "31.71194",
    "lng": "76.93273"
  },
  {
    "country": "IN",
    "name": "Mandholi Kalān",
    "lat": "28.7085",
    "lng": "75.68296"
  },
  {
    "country": "IN",
    "name": "Mandāwar",
    "lat": "29.48655",
    "lng": "78.12732"
  },
  {
    "country": "IN",
    "name": "Mandāwar",
    "lat": "27.86374",
    "lng": "76.54999"
  },
  {
    "country": "IN",
    "name": "Mandasa",
    "lat": "18.8683",
    "lng": "84.46296"
  },
  {
    "country": "IN",
    "name": "Mandapeta",
    "lat": "16.86254",
    "lng": "81.92921"
  },
  {
    "country": "IN",
    "name": "Mandapam",
    "lat": "9.27571",
    "lng": "79.12362"
  },
  {
    "country": "IN",
    "name": "Māndalgarh",
    "lat": "25.19407",
    "lng": "75.07215"
  },
  {
    "country": "IN",
    "name": "Māndal",
    "lat": "25.44126",
    "lng": "74.56979"
  },
  {
    "country": "IN",
    "name": "Māndal",
    "lat": "23.28865",
    "lng": "71.91854"
  },
  {
    "country": "IN",
    "name": "Mancherāl",
    "lat": "18.87074",
    "lng": "79.42863"
  },
  {
    "country": "IN",
    "name": "Manchar",
    "lat": "19.00436",
    "lng": "73.94346"
  },
  {
    "country": "IN",
    "name": "Manāwar",
    "lat": "22.23566",
    "lng": "75.08917"
  },
  {
    "country": "IN",
    "name": "Manavālakurichi",
    "lat": "8.14776",
    "lng": "77.30552"
  },
  {
    "country": "IN",
    "name": "Mānāvadar",
    "lat": "21.49813",
    "lng": "70.13775"
  },
  {
    "country": "IN",
    "name": "Manāsa",
    "lat": "24.47764",
    "lng": "75.14095"
  },
  {
    "country": "IN",
    "name": "Manapparai",
    "lat": "10.60772",
    "lng": "78.42582"
  },
  {
    "country": "IN",
    "name": "Manamadurai",
    "lat": "9.67318",
    "lng": "78.47096"
  },
  {
    "country": "IN",
    "name": "Manalūrpettai",
    "lat": "12.00788",
    "lng": "79.09184"
  },
  {
    "country": "IN",
    "name": "Manāli",
    "lat": "32.2574",
    "lng": "77.17481"
  },
  {
    "country": "IN",
    "name": "Manali",
    "lat": "13.16667",
    "lng": "80.26667"
  },
  {
    "country": "IN",
    "name": "Mamit",
    "lat": "23.92703",
    "lng": "92.48968"
  },
  {
    "country": "IN",
    "name": "Seven Pagodas",
    "lat": "12.62091",
    "lng": "80.19331"
  },
  {
    "country": "IN",
    "name": "Mālvan",
    "lat": "16.05981",
    "lng": "73.4629"
  },
  {
    "country": "IN",
    "name": "Mālūr",
    "lat": "13.00322",
    "lng": "77.93798"
  },
  {
    "country": "IN",
    "name": "Mālpura",
    "lat": "26.2838",
    "lng": "75.36458"
  },
  {
    "country": "IN",
    "name": "Mālpur",
    "lat": "23.36035",
    "lng": "73.46595"
  },
  {
    "country": "IN",
    "name": "Malpe",
    "lat": "13.34962",
    "lng": "74.70394"
  },
  {
    "country": "IN",
    "name": "Māllūr",
    "lat": "11.54424",
    "lng": "78.14078"
  },
  {
    "country": "IN",
    "name": "Mallasamudram",
    "lat": "11.49333",
    "lng": "78.03119"
  },
  {
    "country": "IN",
    "name": "Mallāpuram",
    "lat": "11.98231",
    "lng": "78.24796"
  },
  {
    "country": "IN",
    "name": "Malkera",
    "lat": "23.78213",
    "lng": "86.28767"
  },
  {
    "country": "IN",
    "name": "Malkāpur",
    "lat": "20.88555",
    "lng": "76.19932"
  },
  {
    "country": "IN",
    "name": "Malkāpur",
    "lat": "16.91999",
    "lng": "73.9347"
  },
  {
    "country": "IN",
    "name": "Malakanagiri",
    "lat": "18.36428",
    "lng": "81.888"
  },
  {
    "country": "IN",
    "name": "Malīhābād",
    "lat": "26.92223",
    "lng": "80.71078"
  },
  {
    "country": "IN",
    "name": "Malhārgarh",
    "lat": "24.28286",
    "lng": "74.99024"
  },
  {
    "country": "IN",
    "name": "Māler Kotla",
    "lat": "30.5309",
    "lng": "75.87949"
  },
  {
    "country": "IN",
    "name": "Mālegaon",
    "lat": "20.54966",
    "lng": "74.53462"
  },
  {
    "country": "IN",
    "name": "Malavalli",
    "lat": "12.38556",
    "lng": "77.06045"
  },
  {
    "country": "IN",
    "name": "Malaut",
    "lat": "30.21121",
    "lng": "74.4818"
  },
  {
    "country": "IN",
    "name": "Malappuram",
    "lat": "11.04199",
    "lng": "76.08154"
  },
  {
    "country": "IN",
    "name": "Mākum",
    "lat": "27.48652",
    "lng": "95.43646"
  },
  {
    "country": "IN",
    "name": "Maksi",
    "lat": "23.25999",
    "lng": "76.14567"
  },
  {
    "country": "IN",
    "name": "Makrāna",
    "lat": "27.04361",
    "lng": "74.72445"
  },
  {
    "country": "IN",
    "name": "Makhu",
    "lat": "31.10335",
    "lng": "74.99631"
  },
  {
    "country": "IN",
    "name": "Mākhjan",
    "lat": "17.2698",
    "lng": "73.50031"
  },
  {
    "country": "IN",
    "name": "Majītha",
    "lat": "31.75711",
    "lng": "74.95891"
  },
  {
    "country": "IN",
    "name": "Majholi",
    "lat": "23.50114",
    "lng": "79.92396"
  },
  {
    "country": "IN",
    "name": "Mairwa",
    "lat": "26.23218",
    "lng": "84.16349"
  },
  {
    "country": "IN",
    "name": "Mairang",
    "lat": "25.56165",
    "lng": "91.63602"
  },
  {
    "country": "IN",
    "name": "Mainpuri",
    "lat": "27.22857",
    "lng": "79.02882"
  },
  {
    "country": "IN",
    "name": "Maindargi",
    "lat": "17.45739",
    "lng": "76.2932"
  },
  {
    "country": "IN",
    "name": "Maināguri",
    "lat": "26.56263",
    "lng": "88.8204"
  },
  {
    "country": "IN",
    "name": "Mailāni",
    "lat": "28.29088",
    "lng": "80.3438"
  },
  {
    "country": "IN",
    "name": "Maihar",
    "lat": "24.26594",
    "lng": "80.76063"
  },
  {
    "country": "IN",
    "name": "Maibong",
    "lat": "25.30125",
    "lng": "93.13811"
  },
  {
    "country": "IN",
    "name": "Mahwah",
    "lat": "27.04594",
    "lng": "76.93152"
  },
  {
    "country": "IN",
    "name": "Mahur",
    "lat": "25.18305",
    "lng": "93.11342"
  },
  {
    "country": "IN",
    "name": "Mahudha",
    "lat": "22.82082",
    "lng": "72.94032"
  },
  {
    "country": "IN",
    "name": "Mahroni",
    "lat": "24.58624",
    "lng": "78.72771"
  },
  {
    "country": "IN",
    "name": "Maholi",
    "lat": "27.66368",
    "lng": "80.47371"
  },
  {
    "country": "IN",
    "name": "Mahobā",
    "lat": "25.2905",
    "lng": "79.87533"
  },
  {
    "country": "IN",
    "name": "Mahmudābād",
    "lat": "27.29191",
    "lng": "81.11775"
  },
  {
    "country": "IN",
    "name": "Mahīshādal",
    "lat": "22.18616",
    "lng": "87.98072"
  },
  {
    "country": "IN",
    "name": "Mahgawān",
    "lat": "26.49471",
    "lng": "78.61593"
  },
  {
    "country": "IN",
    "name": "Maheshwar",
    "lat": "22.17592",
    "lng": "75.58715"
  },
  {
    "country": "IN",
    "name": "Mahendragarh",
    "lat": "28.26935",
    "lng": "76.15253"
  },
  {
    "country": "IN",
    "name": "Mahemdāvād",
    "lat": "22.82359",
    "lng": "72.75551"
  },
  {
    "country": "IN",
    "name": "Mahē",
    "lat": "11.70172",
    "lng": "75.53474"
  },
  {
    "country": "IN",
    "name": "Mahbūbnagar",
    "lat": "16.74385",
    "lng": "77.98597"
  },
  {
    "country": "IN",
    "name": "Mahbūbābād",
    "lat": "17.59728",
    "lng": "80.00207"
  },
  {
    "country": "IN",
    "name": "Mahāsamund",
    "lat": "21.10743",
    "lng": "82.0948"
  },
  {
    "country": "IN",
    "name": "Mahārāganj",
    "lat": "27.14456",
    "lng": "83.56214"
  },
  {
    "country": "IN",
    "name": "Mahārājganj",
    "lat": "26.38126",
    "lng": "81.27436"
  },
  {
    "country": "IN",
    "name": "Bishunpur Urf Mahārājganj",
    "lat": "26.25914",
    "lng": "83.11643"
  },
  {
    "country": "IN",
    "name": "Mahārājgani",
    "lat": "26.11017",
    "lng": "84.50365"
  },
  {
    "country": "IN",
    "name": "Maham",
    "lat": "28.96912",
    "lng": "76.29495"
  },
  {
    "country": "IN",
    "name": "Mahālingpur",
    "lat": "16.3888",
    "lng": "75.10873"
  },
  {
    "country": "IN",
    "name": "Mahād",
    "lat": "18.08333",
    "lng": "73.41667"
  },
  {
    "country": "IN",
    "name": "Mahāban",
    "lat": "27.43262",
    "lng": "77.74338"
  },
  {
    "country": "IN",
    "name": "Mahābaleshwar",
    "lat": "17.56",
    "lng": "73.4"
  },
  {
    "country": "IN",
    "name": "Maghar",
    "lat": "26.75586",
    "lng": "83.12773"
  },
  {
    "country": "IN",
    "name": "Māgām",
    "lat": "34.09256",
    "lng": "74.59016"
  },
  {
    "country": "IN",
    "name": "Māgadi",
    "lat": "12.95706",
    "lng": "77.22374"
  },
  {
    "country": "IN",
    "name": "Madurāntakam",
    "lat": "12.51167",
    "lng": "79.88485"
  },
  {
    "country": "IN",
    "name": "Madurai",
    "lat": "9.91769",
    "lng": "78.11898"
  },
  {
    "country": "IN",
    "name": "Madukkūr",
    "lat": "10.48098",
    "lng": "79.39939"
  },
  {
    "country": "IN",
    "name": "Madukkarai",
    "lat": "10.90568",
    "lng": "76.96344"
  },
  {
    "country": "IN",
    "name": "Mādugula",
    "lat": "17.91589",
    "lng": "82.81578"
  },
  {
    "country": "IN",
    "name": "Chennai",
    "lat": "13.08784",
    "lng": "80.27847"
  },
  {
    "country": "IN",
    "name": "Madikeri",
    "lat": "12.42602",
    "lng": "75.7382"
  },
  {
    "country": "IN",
    "name": "Madhyamgram",
    "lat": "22.68944",
    "lng": "88.44594"
  },
  {
    "country": "IN",
    "name": "Madhupur",
    "lat": "24.27419",
    "lng": "86.63929"
  },
  {
    "country": "IN",
    "name": "Maddagiri",
    "lat": "13.66035",
    "lng": "77.21239"
  },
  {
    "country": "IN",
    "name": "Madhubani",
    "lat": "26.35367",
    "lng": "86.07169"
  },
  {
    "country": "IN",
    "name": "Mādhogarh",
    "lat": "26.27522",
    "lng": "79.1859"
  },
  {
    "country": "IN",
    "name": "Madhogarh",
    "lat": "24.56401",
    "lng": "80.91126"
  },
  {
    "country": "IN",
    "name": "Mādhoganj",
    "lat": "27.11807",
    "lng": "80.14058"
  },
  {
    "country": "IN",
    "name": "Madhipura",
    "lat": "25.92127",
    "lng": "86.79271"
  },
  {
    "country": "IN",
    "name": "Madgaon",
    "lat": "15.27501",
    "lng": "73.95786"
  },
  {
    "country": "IN",
    "name": "Maddūr",
    "lat": "12.58283",
    "lng": "77.04294"
  },
  {
    "country": "IN",
    "name": "Madanpur",
    "lat": "23.00589",
    "lng": "88.49168"
  },
  {
    "country": "IN",
    "name": "Madanapalle",
    "lat": "13.5503",
    "lng": "78.50288"
  },
  {
    "country": "IN",
    "name": "Machilīpatnam",
    "lat": "16.18747",
    "lng": "81.13888"
  },
  {
    "country": "IN",
    "name": "Machhlīshahr",
    "lat": "25.68564",
    "lng": "82.41106"
  },
  {
    "country": "IN",
    "name": "Māchhīwāra",
    "lat": "30.91557",
    "lng": "76.20016"
  },
  {
    "country": "IN",
    "name": "Mācherla",
    "lat": "16.47635",
    "lng": "79.43533"
  },
  {
    "country": "IN",
    "name": "Māchalpur",
    "lat": "24.12767",
    "lng": "76.31672"
  },
  {
    "country": "IN",
    "name": "Lunglei",
    "lat": "22.89247",
    "lng": "92.74218"
  },
  {
    "country": "IN",
    "name": "Lūnāvāda",
    "lat": "23.12841",
    "lng": "73.61043"
  },
  {
    "country": "IN",
    "name": "Ludhiāna",
    "lat": "30.91204",
    "lng": "75.85379"
  },
  {
    "country": "IN",
    "name": "Lucknow",
    "lat": "26.83928",
    "lng": "80.92313"
  },
  {
    "country": "IN",
    "name": "Luckeesarai",
    "lat": "25.1765",
    "lng": "86.0947"
  },
  {
    "country": "IN",
    "name": "Losal",
    "lat": "27.4",
    "lng": "74.91667"
  },
  {
    "country": "IN",
    "name": "Lormi",
    "lat": "22.27434",
    "lng": "81.70181"
  },
  {
    "country": "IN",
    "name": "Loni",
    "lat": "28.75143",
    "lng": "77.29023"
  },
  {
    "country": "IN",
    "name": "Londa",
    "lat": "15.46907",
    "lng": "74.51906"
  },
  {
    "country": "IN",
    "name": "Lonavla",
    "lat": "18.75275",
    "lng": "73.40575"
  },
  {
    "country": "IN",
    "name": "Lonār",
    "lat": "19.98533",
    "lng": "76.52046"
  },
  {
    "country": "IN",
    "name": "Lohogaon",
    "lat": "18.59921",
    "lng": "73.92701"
  },
  {
    "country": "IN",
    "name": "Lohāru",
    "lat": "28.42993",
    "lng": "75.80779"
  },
  {
    "country": "IN",
    "name": "Lohārdagā",
    "lat": "23.43305",
    "lng": "84.67992"
  },
  {
    "country": "IN",
    "name": "Lohaghāt",
    "lat": "29.40356",
    "lng": "80.08965"
  },
  {
    "country": "IN",
    "name": "Lodhīkheda",
    "lat": "21.58235",
    "lng": "78.85911"
  },
  {
    "country": "IN",
    "name": "Lingsugūr",
    "lat": "16.15876",
    "lng": "76.52174"
  },
  {
    "country": "IN",
    "name": "Limbdi",
    "lat": "22.56507",
    "lng": "71.81076"
  },
  {
    "country": "IN",
    "name": "Leteri",
    "lat": "24.05979",
    "lng": "77.40858"
  },
  {
    "country": "IN",
    "name": "Leh",
    "lat": "34.16504",
    "lng": "77.58402"
  },
  {
    "country": "IN",
    "name": "Lāwar Khās",
    "lat": "29.11091",
    "lng": "77.77767"
  },
  {
    "country": "IN",
    "name": "Laungowāl",
    "lat": "30.19393",
    "lng": "75.68089"
  },
  {
    "country": "IN",
    "name": "Latur",
    "lat": "18.39721",
    "lng": "76.56784"
  },
  {
    "country": "IN",
    "name": "Lāthi",
    "lat": "21.7231",
    "lng": "71.38843"
  },
  {
    "country": "IN",
    "name": "Lātehār",
    "lat": "23.74423",
    "lng": "84.49984"
  },
  {
    "country": "IN",
    "name": "Lāsalgaon",
    "lat": "20.1427",
    "lng": "74.23946"
  },
  {
    "country": "IN",
    "name": "Lar",
    "lat": "26.20394",
    "lng": "83.96906"
  },
  {
    "country": "IN",
    "name": "Lansdowne",
    "lat": "29.84183",
    "lng": "78.68014"
  },
  {
    "country": "IN",
    "name": "Lānja",
    "lat": "16.86086",
    "lng": "73.54993"
  },
  {
    "country": "IN",
    "name": "Lālsot",
    "lat": "26.55951",
    "lng": "76.32915"
  },
  {
    "country": "IN",
    "name": "Lālpur",
    "lat": "22.19073",
    "lng": "69.96351"
  },
  {
    "country": "IN",
    "name": "Lalitpur",
    "lat": "24.69007",
    "lng": "78.41915"
  },
  {
    "country": "IN",
    "name": "Lalgudi",
    "lat": "10.87419",
    "lng": "78.81935"
  },
  {
    "country": "IN",
    "name": "Lālgola",
    "lat": "24.42244",
    "lng": "88.25238"
  },
  {
    "country": "IN",
    "name": "Lālganj",
    "lat": "25.93182",
    "lng": "81.70478"
  },
  {
    "country": "IN",
    "name": "Lālganj",
    "lat": "25.86894",
    "lng": "85.17394"
  },
  {
    "country": "IN",
    "name": "Lālam",
    "lat": "9.71667",
    "lng": "76.7"
  },
  {
    "country": "IN",
    "name": "Lāla",
    "lat": "24.55418",
    "lng": "92.61592"
  },
  {
    "country": "IN",
    "name": "Lakshmeshwar",
    "lat": "15.12689",
    "lng": "75.46935"
  },
  {
    "country": "IN",
    "name": "Lakshettipet",
    "lat": "18.86667",
    "lng": "79.21667"
  },
  {
    "country": "IN",
    "name": "Laksar",
    "lat": "29.7587",
    "lng": "78.04148"
  },
  {
    "country": "IN",
    "name": "Lakhyabad",
    "lat": "23.66667",
    "lng": "86.66667"
  },
  {
    "country": "IN",
    "name": "Lakhtar",
    "lat": "22.85683",
    "lng": "71.78844"
  },
  {
    "country": "IN",
    "name": "Lakhnādon",
    "lat": "22.60049",
    "lng": "79.60094"
  },
  {
    "country": "IN",
    "name": "Lakhnā",
    "lat": "26.64822",
    "lng": "79.1477"
  },
  {
    "country": "IN",
    "name": "Lakhipur",
    "lat": "26.03001",
    "lng": "90.30611"
  },
  {
    "country": "IN",
    "name": "Lakhipur",
    "lat": "24.79281",
    "lng": "93.0091"
  },
  {
    "country": "IN",
    "name": "Lakhīmpur",
    "lat": "27.94822",
    "lng": "80.77935"
  },
  {
    "country": "IN",
    "name": "Lākheri",
    "lat": "25.67237",
    "lng": "76.17692"
  },
  {
    "country": "IN",
    "name": "Lāharpur",
    "lat": "27.70827",
    "lng": "80.90256"
  },
  {
    "country": "IN",
    "name": "Lahār",
    "lat": "26.19401",
    "lng": "78.94137"
  },
  {
    "country": "IN",
    "name": "Lādwa",
    "lat": "29.9935",
    "lng": "77.04563"
  },
  {
    "country": "IN",
    "name": "Lādnūn",
    "lat": "27.65312",
    "lng": "74.39993"
  },
  {
    "country": "IN",
    "name": "Lachhmangarh Sīkar",
    "lat": "27.82294",
    "lng": "75.02754"
  },
  {
    "country": "IN",
    "name": "Kyelang",
    "lat": "32.5717",
    "lng": "77.02448"
  },
  {
    "country": "IN",
    "name": "Kuzhithurai",
    "lat": "8.31792",
    "lng": "77.19192"
  },
  {
    "country": "IN",
    "name": "Koothanallur",
    "lat": "10.7199",
    "lng": "79.5157"
  },
  {
    "country": "IN",
    "name": "Kuttampuzha",
    "lat": "10.15033",
    "lng": "76.73544"
  },
  {
    "country": "IN",
    "name": "Kuttālam",
    "lat": "8.9303",
    "lng": "77.26951"
  },
  {
    "country": "IN",
    "name": "Kutiyāna",
    "lat": "21.6241",
    "lng": "69.98494"
  },
  {
    "country": "IN",
    "name": "Kutiatodu",
    "lat": "9.8",
    "lng": "76.33333"
  },
  {
    "country": "IN",
    "name": "Kushtagi",
    "lat": "15.75623",
    "lng": "76.19112"
  },
  {
    "country": "IN",
    "name": "Kushālnagar",
    "lat": "12.45795",
    "lng": "75.95904"
  },
  {
    "country": "IN",
    "name": "Kushālgarh",
    "lat": "23.19899",
    "lng": "74.45074"
  },
  {
    "country": "IN",
    "name": "Kurud",
    "lat": "20.83073",
    "lng": "81.72212"
  },
  {
    "country": "IN",
    "name": "Kurnool",
    "lat": "15.82887",
    "lng": "78.03602"
  },
  {
    "country": "IN",
    "name": "Kurinjippādi",
    "lat": "11.55028",
    "lng": "79.59066"
  },
  {
    "country": "IN",
    "name": "Kurgunta",
    "lat": "17.19321",
    "lng": "77.35772"
  },
  {
    "country": "IN",
    "name": "Kurduvādi",
    "lat": "18.09339",
    "lng": "75.41567"
  },
  {
    "country": "IN",
    "name": "Kurāra",
    "lat": "25.98046",
    "lng": "79.98984"
  },
  {
    "country": "IN",
    "name": "Kurandvād",
    "lat": "16.68317",
    "lng": "74.58892"
  },
  {
    "country": "IN",
    "name": "Kuppam",
    "lat": "12.74931",
    "lng": "78.34189"
  },
  {
    "country": "IN",
    "name": "Kunnattūr",
    "lat": "12.34782",
    "lng": "78.51046"
  },
  {
    "country": "IN",
    "name": "Kunnamkulam",
    "lat": "10.64667",
    "lng": "76.06695"
  },
  {
    "country": "IN",
    "name": "Kunnamangalam",
    "lat": "11.30459",
    "lng": "75.87772"
  },
  {
    "country": "IN",
    "name": "Kunigal",
    "lat": "13.02319",
    "lng": "77.02518"
  },
  {
    "country": "IN",
    "name": "Kundla",
    "lat": "21.34222",
    "lng": "71.30633"
  },
  {
    "country": "IN",
    "name": "Kundgol",
    "lat": "15.25612",
    "lng": "75.24735"
  },
  {
    "country": "IN",
    "name": "Kundarkhi",
    "lat": "28.68304",
    "lng": "78.78559"
  },
  {
    "country": "IN",
    "name": "Kunda",
    "lat": "25.71702",
    "lng": "81.51396"
  },
  {
    "country": "IN",
    "name": "Kumta",
    "lat": "14.42853",
    "lng": "74.4189"
  },
  {
    "country": "IN",
    "name": "Kumsi",
    "lat": "14.05455",
    "lng": "75.39992"
  },
  {
    "country": "IN",
    "name": "Kūmher",
    "lat": "27.31657",
    "lng": "77.37079"
  },
  {
    "country": "IN",
    "name": "Kumhāri",
    "lat": "21.26667",
    "lng": "81.51667"
  },
  {
    "country": "IN",
    "name": "Kumbhrāj",
    "lat": "24.37338",
    "lng": "77.04841"
  },
  {
    "country": "IN",
    "name": "Kumbakonam",
    "lat": "10.96209",
    "lng": "79.39124"
  },
  {
    "country": "IN",
    "name": "Kumaralingam",
    "lat": "10.48936",
    "lng": "77.3499"
  },
  {
    "country": "IN",
    "name": "Kulu",
    "lat": "31.95835",
    "lng": "77.10823"
  },
  {
    "country": "IN",
    "name": "Kulti",
    "lat": "23.73166",
    "lng": "86.84372"
  },
  {
    "country": "IN",
    "name": "Kulpahār",
    "lat": "25.32007",
    "lng": "79.63931"
  },
  {
    "country": "IN",
    "name": "Kulittalai",
    "lat": "10.93487",
    "lng": "78.41251"
  },
  {
    "country": "IN",
    "name": "Kulgam",
    "lat": "33.64456",
    "lng": "75.01923"
  },
  {
    "country": "IN",
    "name": "Kulattūr",
    "lat": "9.0032",
    "lng": "78.1928"
  },
  {
    "country": "IN",
    "name": "Kukshi",
    "lat": "22.20677",
    "lng": "74.75788"
  },
  {
    "country": "IN",
    "name": "Kūkatpalli",
    "lat": "17.48486",
    "lng": "78.41376"
  },
  {
    "country": "IN",
    "name": "Kuju",
    "lat": "23.72536",
    "lng": "85.51023"
  },
  {
    "country": "IN",
    "name": "Kūdligi",
    "lat": "14.905",
    "lng": "76.38527"
  },
  {
    "country": "IN",
    "name": "Kudāl",
    "lat": "16.01148",
    "lng": "73.68867"
  },
  {
    "country": "IN",
    "name": "Kudachi",
    "lat": "16.62784",
    "lng": "74.85408"
  },
  {
    "country": "IN",
    "name": "Kūd",
    "lat": "33.07246",
    "lng": "75.28727"
  },
  {
    "country": "IN",
    "name": "Kuchera",
    "lat": "26.98747",
    "lng": "73.97108"
  },
  {
    "country": "IN",
    "name": "Kuchāman",
    "lat": "27.14745",
    "lng": "74.85655"
  },
  {
    "country": "IN",
    "name": "Kuchaiburi",
    "lat": "22.26675",
    "lng": "86.17385"
  },
  {
    "country": "IN",
    "name": "Krishnarājpet",
    "lat": "12.66621",
    "lng": "76.4877"
  },
  {
    "country": "IN",
    "name": "Krishnanagar",
    "lat": "23.40576",
    "lng": "88.49073"
  },
  {
    "country": "IN",
    "name": "Krishnagiri",
    "lat": "12.51921",
    "lng": "78.21382"
  },
  {
    "country": "IN",
    "name": "Kozhikode",
    "lat": "11.24802",
    "lng": "75.7804"
  },
  {
    "country": "IN",
    "name": "Koynanagar",
    "lat": "17.4",
    "lng": "73.76667"
  },
  {
    "country": "IN",
    "name": "Kovvūr",
    "lat": "17.0162",
    "lng": "81.72934"
  },
  {
    "country": "IN",
    "name": "Kovūr",
    "lat": "14.5005",
    "lng": "79.98518"
  },
  {
    "country": "IN",
    "name": "Kovilpatti",
    "lat": "9.17167",
    "lng": "77.86989"
  },
  {
    "country": "IN",
    "name": "Kovalam",
    "lat": "8.36667",
    "lng": "76.99667"
  },
  {
    "country": "IN",
    "name": "Kotwa",
    "lat": "25.0308",
    "lng": "81.31908"
  },
  {
    "country": "IN",
    "name": "Kottūru",
    "lat": "14.82442",
    "lng": "76.22005"
  },
  {
    "country": "IN",
    "name": "Kottayam",
    "lat": "9.58692",
    "lng": "76.52132"
  },
  {
    "country": "IN",
    "name": "Kottapalli",
    "lat": "18.49543",
    "lng": "79.0943"
  },
  {
    "country": "IN",
    "name": "Kottaiyūr",
    "lat": "10.10956",
    "lng": "78.7956"
  },
  {
    "country": "IN",
    "name": "Kottagūdem",
    "lat": "17.55106",
    "lng": "80.61779"
  },
  {
    "country": "IN",
    "name": "Kotra",
    "lat": "25.8077",
    "lng": "79.30909"
  },
  {
    "country": "IN",
    "name": "Kotputli",
    "lat": "27.70207",
    "lng": "76.19911"
  },
  {
    "country": "IN",
    "name": "Kotma",
    "lat": "23.20383",
    "lng": "81.97904"
  },
  {
    "country": "IN",
    "name": "Kotla",
    "lat": "32.25",
    "lng": "76.03333"
  },
  {
    "country": "IN",
    "name": "Kotkhai",
    "lat": "31.11728",
    "lng": "77.53936"
  },
  {
    "country": "IN",
    "name": "Kot Īsa Khān",
    "lat": "30.94659",
    "lng": "75.1378"
  },
  {
    "country": "IN",
    "name": "Kothi",
    "lat": "24.7526",
    "lng": "80.77751"
  },
  {
    "country": "IN",
    "name": "Kothāpet",
    "lat": "19.35176",
    "lng": "79.48323"
  },
  {
    "country": "IN",
    "name": "Kotdwāra",
    "lat": "29.74612",
    "lng": "78.52219"
  },
  {
    "country": "IN",
    "name": "Kotār",
    "lat": "24.69802",
    "lng": "80.98073"
  },
  {
    "country": "IN",
    "name": "Kotapārh",
    "lat": "19.14256",
    "lng": "82.32536"
  },
  {
    "country": "IN",
    "name": "Kotamangalam",
    "lat": "10.06435",
    "lng": "76.62843"
  },
  {
    "country": "IN",
    "name": "Kotagiri",
    "lat": "11.42072",
    "lng": "76.86035"
  },
  {
    "country": "IN",
    "name": "Kota",
    "lat": "25.18254",
    "lng": "75.83907"
  },
  {
    "country": "IN",
    "name": "Kota",
    "lat": "24.44643",
    "lng": "83.13063"
  },
  {
    "country": "IN",
    "name": "Kotā",
    "lat": "22.29507",
    "lng": "82.02366"
  },
  {
    "country": "IN",
    "name": "Kosigi",
    "lat": "15.8551",
    "lng": "77.24463"
  },
  {
    "country": "IN",
    "name": "Kosi",
    "lat": "27.79449",
    "lng": "77.4368"
  },
  {
    "country": "IN",
    "name": "Kosamba",
    "lat": "21.46202",
    "lng": "72.95842"
  },
  {
    "country": "IN",
    "name": "Korwai",
    "lat": "24.11774",
    "lng": "78.04007"
  },
  {
    "country": "IN",
    "name": "Korukollu",
    "lat": "16.5",
    "lng": "81.25"
  },
  {
    "country": "IN",
    "name": "Koregaon",
    "lat": "18.64573",
    "lng": "74.05909"
  },
  {
    "country": "IN",
    "name": "Korba",
    "lat": "22.3458",
    "lng": "82.69633"
  },
  {
    "country": "IN",
    "name": "Koratla",
    "lat": "18.82154",
    "lng": "78.71186"
  },
  {
    "country": "IN",
    "name": "Koratagere",
    "lat": "13.522",
    "lng": "77.2373"
  },
  {
    "country": "IN",
    "name": "Korāput",
    "lat": "18.81199",
    "lng": "82.71048"
  },
  {
    "country": "IN",
    "name": "Korampallam",
    "lat": "8.77506",
    "lng": "78.09158"
  },
  {
    "country": "IN",
    "name": "Korādi",
    "lat": "21.24758",
    "lng": "79.10575"
  },
  {
    "country": "IN",
    "name": "Koradāchcheri",
    "lat": "10.77019",
    "lng": "79.49158"
  },
  {
    "country": "IN",
    "name": "Koppal",
    "lat": "15.34522",
    "lng": "76.15478"
  },
  {
    "country": "IN",
    "name": "Koppa",
    "lat": "13.53044",
    "lng": "75.36329"
  },
  {
    "country": "IN",
    "name": "Kopargaon",
    "lat": "19.88239",
    "lng": "74.47605"
  },
  {
    "country": "IN",
    "name": "Kopāganj",
    "lat": "26.01923",
    "lng": "83.5663"
  },
  {
    "country": "IN",
    "name": "Konnūr",
    "lat": "16.20138",
    "lng": "74.74886"
  },
  {
    "country": "IN",
    "name": "Konnagar",
    "lat": "22.70508",
    "lng": "88.34446"
  },
  {
    "country": "IN",
    "name": "Konganāpuram",
    "lat": "11.57105",
    "lng": "77.9004"
  },
  {
    "country": "IN",
    "name": "Kondapalle",
    "lat": "16.61989",
    "lng": "80.54244"
  },
  {
    "country": "IN",
    "name": "Kondalwādi",
    "lat": "18.80727",
    "lng": "77.77031"
  },
  {
    "country": "IN",
    "name": "Kondagaon",
    "lat": "19.59083",
    "lng": "81.664"
  },
  {
    "country": "IN",
    "name": "Konch",
    "lat": "25.99451",
    "lng": "79.15127"
  },
  {
    "country": "IN",
    "name": "Konārka",
    "lat": "19.89758",
    "lng": "86.11413"
  },
  {
    "country": "IN",
    "name": "Konanūr",
    "lat": "12.63016",
    "lng": "76.05037"
  },
  {
    "country": "IN",
    "name": "Kombai",
    "lat": "9.84745",
    "lng": "77.29603"
  },
  {
    "country": "IN",
    "name": "Kolasib",
    "lat": "24.22388",
    "lng": "92.67869"
  },
  {
    "country": "IN",
    "name": "Kollegāl",
    "lat": "12.15449",
    "lng": "77.11051"
  },
  {
    "country": "IN",
    "name": "Kolhāpur",
    "lat": "16.69563",
    "lng": "74.23167"
  },
  {
    "country": "IN",
    "name": "Kolāras",
    "lat": "25.21928",
    "lng": "77.61167"
  },
  {
    "country": "IN",
    "name": "Kolār",
    "lat": "13.13768",
    "lng": "78.12999"
  },
  {
    "country": "IN",
    "name": "Kolanukonda",
    "lat": "16.45392",
    "lng": "80.61046"
  },
  {
    "country": "IN",
    "name": "Colachel",
    "lat": "8.17938",
    "lng": "77.25818"
  },
  {
    "country": "IN",
    "name": "Kokrajhar",
    "lat": "26.40107",
    "lng": "90.27286"
  },
  {
    "country": "IN",
    "name": "Kohima",
    "lat": "25.67467",
    "lng": "94.11099"
  },
  {
    "country": "IN",
    "name": "Koelwār",
    "lat": "25.58055",
    "lng": "84.79751"
  },
  {
    "country": "IN",
    "name": "Kodungallūr",
    "lat": "10.23263",
    "lng": "76.19513"
  },
  {
    "country": "IN",
    "name": "Kodumudi",
    "lat": "11.07751",
    "lng": "77.88363"
  },
  {
    "country": "IN",
    "name": "Kodoli",
    "lat": "16.87639",
    "lng": "74.1909"
  },
  {
    "country": "IN",
    "name": "Kodlipet",
    "lat": "12.80087",
    "lng": "75.88662"
  },
  {
    "country": "IN",
    "name": "Kodīnar",
    "lat": "20.79393",
    "lng": "70.70216"
  },
  {
    "country": "IN",
    "name": "Kodigenahalli",
    "lat": "13.72136",
    "lng": "77.38629"
  },
  {
    "country": "IN",
    "name": "Kodarmā",
    "lat": "24.46753",
    "lng": "85.59397"
  },
  {
    "country": "IN",
    "name": "Kodār",
    "lat": "16.9985",
    "lng": "79.9656"
  },
  {
    "country": "IN",
    "name": "Kodala",
    "lat": "19.62425",
    "lng": "84.94075"
  },
  {
    "country": "IN",
    "name": "Kodaikānāl",
    "lat": "10.23925",
    "lng": "77.48932"
  },
  {
    "country": "IN",
    "name": "Kuchinda",
    "lat": "21.74356",
    "lng": "84.34848"
  },
  {
    "country": "IN",
    "name": "Koch Bihār",
    "lat": "26.32539",
    "lng": "89.44508"
  },
  {
    "country": "IN",
    "name": "Koāth",
    "lat": "25.32643",
    "lng": "84.25983"
  },
  {
    "country": "IN",
    "name": "Kizhake Chālakudi",
    "lat": "10.30067",
    "lng": "76.33763"
  },
  {
    "country": "IN",
    "name": "Kithor",
    "lat": "28.86684",
    "lng": "77.93861"
  },
  {
    "country": "IN",
    "name": "Kishtwār",
    "lat": "33.31346",
    "lng": "75.76726"
  },
  {
    "country": "IN",
    "name": "Kishni",
    "lat": "27.02487",
    "lng": "79.262"
  },
  {
    "country": "IN",
    "name": "Kishanpur",
    "lat": "25.64232",
    "lng": "81.0227"
  },
  {
    "country": "IN",
    "name": "Kishangarh",
    "lat": "27.81889",
    "lng": "76.72972"
  },
  {
    "country": "IN",
    "name": "Kishangarh",
    "lat": "26.59006",
    "lng": "74.85397"
  },
  {
    "country": "IN",
    "name": "Kishanganj",
    "lat": "26.10224",
    "lng": "87.95534"
  },
  {
    "country": "IN",
    "name": "Kiri Buru",
    "lat": "22.08333",
    "lng": "85.35"
  },
  {
    "country": "IN",
    "name": "Kīratpur",
    "lat": "29.50671",
    "lng": "78.20613"
  },
  {
    "country": "IN",
    "name": "Kiraoli",
    "lat": "27.13768",
    "lng": "77.78516"
  },
  {
    "country": "IN",
    "name": "Kīranūr",
    "lat": "10.59395",
    "lng": "77.50315"
  },
  {
    "country": "IN",
    "name": "Kīranūr",
    "lat": "10.56988",
    "lng": "78.78682"
  },
  {
    "country": "IN",
    "name": "Kirākat",
    "lat": "25.63745",
    "lng": "82.91596"
  },
  {
    "country": "IN",
    "name": "Kinwat",
    "lat": "19.62557",
    "lng": "78.1987"
  },
  {
    "country": "IN",
    "name": "Kilvelur",
    "lat": "10.76721",
    "lng": "79.74186"
  },
  {
    "country": "IN",
    "name": "Kichha",
    "lat": "28.91154",
    "lng": "79.52009"
  },
  {
    "country": "IN",
    "name": "Khūtār",
    "lat": "28.20307",
    "lng": "80.27046"
  },
  {
    "country": "IN",
    "name": "Khusropur",
    "lat": "25.48174",
    "lng": "85.38492"
  },
  {
    "country": "IN",
    "name": "Khurja",
    "lat": "28.25382",
    "lng": "77.85535"
  },
  {
    "country": "IN",
    "name": "Khurda",
    "lat": "20.18268",
    "lng": "85.61629"
  },
  {
    "country": "IN",
    "name": "Khurai",
    "lat": "24.04372",
    "lng": "78.33014"
  },
  {
    "country": "IN",
    "name": "Khunti",
    "lat": "23.07602",
    "lng": "85.27818"
  },
  {
    "country": "IN",
    "name": "Khuldābād",
    "lat": "20.00671",
    "lng": "75.19245"
  },
  {
    "country": "IN",
    "name": "Khujner",
    "lat": "23.78597",
    "lng": "76.61773"
  },
  {
    "country": "IN",
    "name": "Khudāganj",
    "lat": "28.14607",
    "lng": "79.71472"
  },
  {
    "country": "IN",
    "name": "Khowai",
    "lat": "24.07964",
    "lng": "91.59972"
  },
  {
    "country": "IN",
    "name": "Khopoli",
    "lat": "18.78562",
    "lng": "73.34589"
  },
  {
    "country": "IN",
    "name": "Khonsa",
    "lat": "27.01667",
    "lng": "95.56667"
  },
  {
    "country": "IN",
    "name": "Khirkiyān",
    "lat": "22.16732",
    "lng": "76.86137"
  },
  {
    "country": "IN",
    "name": "Khilchipur",
    "lat": "24.03943",
    "lng": "76.578"
  },
  {
    "country": "IN",
    "name": "Khetri",
    "lat": "28.00069",
    "lng": "75.78644"
  },
  {
    "country": "IN",
    "name": "Khetia",
    "lat": "21.67124",
    "lng": "74.58535"
  },
  {
    "country": "IN",
    "name": "Kheri",
    "lat": "27.90354",
    "lng": "80.79754"
  },
  {
    "country": "IN",
    "name": "Kherālu",
    "lat": "23.88534",
    "lng": "72.61869"
  },
  {
    "country": "IN",
    "name": "Khem Karan",
    "lat": "31.14443",
    "lng": "74.55938"
  },
  {
    "country": "IN",
    "name": "Khekra",
    "lat": "28.86586",
    "lng": "77.2841"
  },
  {
    "country": "IN",
    "name": "Khedbrahma",
    "lat": "24.0299",
    "lng": "73.04632"
  },
  {
    "country": "IN",
    "name": "Kheda",
    "lat": "22.75218",
    "lng": "72.68533"
  },
  {
    "country": "IN",
    "name": "Khed",
    "lat": "18.33811",
    "lng": "73.84677"
  },
  {
    "country": "IN",
    "name": "Khed",
    "lat": "17.71888",
    "lng": "73.39693"
  },
  {
    "country": "IN",
    "name": "Khawhai",
    "lat": "23.37807",
    "lng": "93.12797"
  },
  {
    "country": "IN",
    "name": "Khaur",
    "lat": "32.6027",
    "lng": "74.80918"
  },
  {
    "country": "IN",
    "name": "Khātra",
    "lat": "22.97617",
    "lng": "86.85462"
  },
  {
    "country": "IN",
    "name": "Khatīma",
    "lat": "28.92134",
    "lng": "79.97075"
  },
  {
    "country": "IN",
    "name": "Khātegaon",
    "lat": "22.59573",
    "lng": "76.9133"
  },
  {
    "country": "IN",
    "name": "Khatauli",
    "lat": "29.27844",
    "lng": "77.73302"
  },
  {
    "country": "IN",
    "name": "Khārupatia",
    "lat": "26.51839",
    "lng": "92.14722"
  },
  {
    "country": "IN",
    "name": "Kharsia",
    "lat": "21.98953",
    "lng": "83.10476"
  },
  {
    "country": "IN",
    "name": "Kharsāwān",
    "lat": "22.79093",
    "lng": "85.83102"
  },
  {
    "country": "IN",
    "name": "Kharod",
    "lat": "21.7442",
    "lng": "82.5788"
  },
  {
    "country": "IN",
    "name": "Kharkhauda",
    "lat": "28.8787",
    "lng": "76.91069"
  },
  {
    "country": "IN",
    "name": "Kharkhauda",
    "lat": "28.83644",
    "lng": "77.74159"
  },
  {
    "country": "IN",
    "name": "Kharhiāl",
    "lat": "20.28845",
    "lng": "82.7606"
  },
  {
    "country": "IN",
    "name": "Khargupur",
    "lat": "27.37611",
    "lng": "81.9882"
  },
  {
    "country": "IN",
    "name": "Khargone",
    "lat": "21.82292",
    "lng": "75.61394"
  },
  {
    "country": "IN",
    "name": "Khargāpur",
    "lat": "24.823",
    "lng": "79.144"
  },
  {
    "country": "IN",
    "name": "Kharela",
    "lat": "25.54277",
    "lng": "79.81235"
  },
  {
    "country": "IN",
    "name": "Khardah",
    "lat": "22.71861",
    "lng": "88.37806"
  },
  {
    "country": "IN",
    "name": "Kharar",
    "lat": "30.74632",
    "lng": "76.64689"
  },
  {
    "country": "IN",
    "name": "Kharar",
    "lat": "22.72211",
    "lng": "87.67824"
  },
  {
    "country": "IN",
    "name": "Kharakvasla",
    "lat": "18.43997",
    "lng": "73.77545"
  },
  {
    "country": "IN",
    "name": "Kharagpur",
    "lat": "25.12446",
    "lng": "86.55578"
  },
  {
    "country": "IN",
    "name": "Kharagpur",
    "lat": "22.33971",
    "lng": "87.32501"
  },
  {
    "country": "IN",
    "name": "Khāpa",
    "lat": "21.42243",
    "lng": "78.98168"
  },
  {
    "country": "IN",
    "name": "Khānpur",
    "lat": "28.53446",
    "lng": "78.06546"
  },
  {
    "country": "IN",
    "name": "Khānpur",
    "lat": "24.73241",
    "lng": "76.39601"
  },
  {
    "country": "IN",
    "name": "Khanna",
    "lat": "30.70547",
    "lng": "76.22196"
  },
  {
    "country": "IN",
    "name": "Khandwa",
    "lat": "21.82427",
    "lng": "76.35086"
  },
  {
    "country": "IN",
    "name": "Khandela",
    "lat": "27.60499",
    "lng": "75.502"
  },
  {
    "country": "IN",
    "name": "Khānāpur",
    "lat": "15.63969",
    "lng": "74.50847"
  },
  {
    "country": "IN",
    "name": "Khammam",
    "lat": "17.24767",
    "lng": "80.14368"
  },
  {
    "country": "IN",
    "name": "Khamharia",
    "lat": "20.976",
    "lng": "82.25116"
  },
  {
    "country": "IN",
    "name": "Khāmgaon",
    "lat": "20.70738",
    "lng": "76.56827"
  },
  {
    "country": "IN",
    "name": "Khambhāt",
    "lat": "22.31744",
    "lng": "72.61916"
  },
  {
    "country": "IN",
    "name": "Khambhāliya",
    "lat": "22.20685",
    "lng": "69.65031"
  },
  {
    "country": "IN",
    "name": "Khamaria",
    "lat": "23.22558",
    "lng": "79.88007"
  },
  {
    "country": "IN",
    "name": "Khamānon Kalān",
    "lat": "30.81725",
    "lng": "76.35478"
  },
  {
    "country": "IN",
    "name": "Khallikot",
    "lat": "19.60908",
    "lng": "85.08609"
  },
  {
    "country": "IN",
    "name": "Khalīlābād",
    "lat": "26.77268",
    "lng": "83.07179"
  },
  {
    "country": "IN",
    "name": "Khajuraho Group of Monuments",
    "lat": "24.84809",
    "lng": "79.93351"
  },
  {
    "country": "IN",
    "name": "Khairāgarh",
    "lat": "26.94269",
    "lng": "77.8189"
  },
  {
    "country": "IN",
    "name": "Khairāgarh",
    "lat": "21.41859",
    "lng": "80.97942"
  },
  {
    "country": "IN",
    "name": "Khairābād",
    "lat": "27.52698",
    "lng": "80.75461"
  },
  {
    "country": "IN",
    "name": "Khair",
    "lat": "27.94195",
    "lng": "77.84243"
  },
  {
    "country": "IN",
    "name": "Khailār",
    "lat": "25.34127",
    "lng": "78.53133"
  },
  {
    "country": "IN",
    "name": "Khagaul",
    "lat": "25.57898",
    "lng": "85.04564"
  },
  {
    "country": "IN",
    "name": "Khagaria",
    "lat": "25.5022",
    "lng": "86.46708"
  },
  {
    "country": "IN",
    "name": "Khāga",
    "lat": "25.77215",
    "lng": "81.10393"
  },
  {
    "country": "IN",
    "name": "Khadki",
    "lat": "18.5635",
    "lng": "73.85205"
  },
  {
    "country": "IN",
    "name": "Khada",
    "lat": "27.18333",
    "lng": "83.88333"
  },
  {
    "country": "IN",
    "name": "Khāchrod",
    "lat": "23.42322",
    "lng": "75.28185"
  },
  {
    "country": "IN",
    "name": "Kesinga",
    "lat": "20.18778",
    "lng": "83.21949"
  },
  {
    "country": "IN",
    "name": "Keshorai Pātan",
    "lat": "25.29275",
    "lng": "75.93948"
  },
  {
    "country": "IN",
    "name": "Keshod",
    "lat": "21.30328",
    "lng": "70.24861"
  },
  {
    "country": "IN",
    "name": "Kerūr",
    "lat": "16.01384",
    "lng": "75.54631"
  },
  {
    "country": "IN",
    "name": "Kenduadīh",
    "lat": "23.77574",
    "lng": "86.37609"
  },
  {
    "country": "IN",
    "name": "Kendrāparha",
    "lat": "20.50166",
    "lng": "86.42227"
  },
  {
    "country": "IN",
    "name": "Kenda",
    "lat": "23.1959",
    "lng": "86.51499"
  },
  {
    "country": "IN",
    "name": "Kemrī",
    "lat": "28.80673",
    "lng": "79.2048"
  },
  {
    "country": "IN",
    "name": "Kelamangalam",
    "lat": "12.60307",
    "lng": "77.85193"
  },
  {
    "country": "IN",
    "name": "Kekri",
    "lat": "25.97132",
    "lng": "75.14992"
  },
  {
    "country": "IN",
    "name": "Kayattār",
    "lat": "8.94834",
    "lng": "77.77424"
  },
  {
    "country": "IN",
    "name": "Kāyankulam",
    "lat": "9.18173",
    "lng": "76.50093"
  },
  {
    "country": "IN",
    "name": "Kayalpattinam",
    "lat": "8.57143",
    "lng": "78.11992"
  },
  {
    "country": "IN",
    "name": "Kawardha",
    "lat": "22.00853",
    "lng": "81.23148"
  },
  {
    "country": "IN",
    "name": "Kawānt",
    "lat": "22.09282",
    "lng": "74.05078"
  },
  {
    "country": "IN",
    "name": "Kāveripatnam",
    "lat": "12.42186",
    "lng": "78.2188"
  },
  {
    "country": "IN",
    "name": "Kavaratti",
    "lat": "10.56688",
    "lng": "72.64203"
  },
  {
    "country": "IN",
    "name": "Kavalūr",
    "lat": "15.28829",
    "lng": "75.9433"
  },
  {
    "country": "IN",
    "name": "Kāvali",
    "lat": "14.9163",
    "lng": "79.99449"
  },
  {
    "country": "IN",
    "name": "Kāttupputtūr",
    "lat": "10.99385",
    "lng": "78.21929"
  },
  {
    "country": "IN",
    "name": "Kattivākkam",
    "lat": "13.21667",
    "lng": "80.31667"
  },
  {
    "country": "IN",
    "name": "Kattanam",
    "lat": "9.17614",
    "lng": "76.56325"
  },
  {
    "country": "IN",
    "name": "Kātrās",
    "lat": "23.79752",
    "lng": "86.29834"
  },
  {
    "country": "IN",
    "name": "Katra",
    "lat": "32.99167",
    "lng": "74.93195"
  },
  {
    "country": "IN",
    "name": "Katra",
    "lat": "27.50871",
    "lng": "82.02636"
  },
  {
    "country": "IN",
    "name": "Katpur",
    "lat": "21.05869",
    "lng": "71.79457"
  },
  {
    "country": "IN",
    "name": "Kātpādi",
    "lat": "12.96951",
    "lng": "79.14552"
  },
  {
    "country": "IN",
    "name": "Kātoya",
    "lat": "23.64558",
    "lng": "88.13258"
  },
  {
    "country": "IN",
    "name": "Kātol",
    "lat": "21.27388",
    "lng": "78.5858"
  },
  {
    "country": "IN",
    "name": "Katihar",
    "lat": "25.53852",
    "lng": "87.57044"
  },
  {
    "country": "IN",
    "name": "Kāti",
    "lat": "17.96137",
    "lng": "75.88895"
  },
  {
    "country": "IN",
    "name": "Kathua",
    "lat": "32.36941",
    "lng": "75.52539"
  },
  {
    "country": "IN",
    "name": "Kāthor",
    "lat": "21.28854",
    "lng": "72.9407"
  },
  {
    "country": "IN",
    "name": "Katghora",
    "lat": "22.50247",
    "lng": "82.54279"
  },
  {
    "country": "IN",
    "name": "Katangi",
    "lat": "23.44124",
    "lng": "79.79621"
  },
  {
    "country": "IN",
    "name": "Katangi",
    "lat": "21.77369",
    "lng": "79.80513"
  },
  {
    "country": "IN",
    "name": "Kasrāwad",
    "lat": "22.12745",
    "lng": "75.61101"
  },
  {
    "country": "IN",
    "name": "Kashipur",
    "lat": "29.21399",
    "lng": "78.95693"
  },
  {
    "country": "IN",
    "name": "Kāsganj",
    "lat": "27.80882",
    "lng": "78.64579"
  },
  {
    "country": "IN",
    "name": "Kasauli",
    "lat": "30.89856",
    "lng": "76.96587"
  },
  {
    "country": "IN",
    "name": "Kāsaragod",
    "lat": "12.49838",
    "lng": "74.98959"
  },
  {
    "country": "IN",
    "name": "Karwar",
    "lat": "14.81361",
    "lng": "74.12972"
  },
  {
    "country": "IN",
    "name": "Karur",
    "lat": "10.95771",
    "lng": "78.08095"
  },
  {
    "country": "IN",
    "name": "Karumbākkam",
    "lat": "12.70203",
    "lng": "80.0911"
  },
  {
    "country": "IN",
    "name": "Kartārpur",
    "lat": "31.44268",
    "lng": "75.49847"
  },
  {
    "country": "IN",
    "name": "Kārsiyāng",
    "lat": "26.88251",
    "lng": "88.27729"
  },
  {
    "country": "IN",
    "name": "Karrāpur",
    "lat": "23.94891",
    "lng": "78.86584"
  },
  {
    "country": "IN",
    "name": "Karol Bāgh",
    "lat": "28.65136",
    "lng": "77.19072"
  },
  {
    "country": "IN",
    "name": "Karnāl",
    "lat": "29.69197",
    "lng": "76.98448"
  },
  {
    "country": "IN",
    "name": "Karmāla",
    "lat": "18.4077",
    "lng": "75.19386"
  },
  {
    "country": "IN",
    "name": "Kārkala",
    "lat": "13.21428",
    "lng": "74.99234"
  },
  {
    "country": "IN",
    "name": "Karjat",
    "lat": "18.9107",
    "lng": "73.32354"
  },
  {
    "country": "IN",
    "name": "Kariapatti",
    "lat": "9.67505",
    "lng": "78.09992"
  },
  {
    "country": "IN",
    "name": "Karīmpur",
    "lat": "23.97594",
    "lng": "88.61917"
  },
  {
    "country": "IN",
    "name": "Karīmnagar",
    "lat": "18.43915",
    "lng": "79.12856"
  },
  {
    "country": "IN",
    "name": "Karīmganj",
    "lat": "24.86919",
    "lng": "92.35543"
  },
  {
    "country": "IN",
    "name": "Karhal",
    "lat": "27.00089",
    "lng": "78.93935"
  },
  {
    "country": "IN",
    "name": "Kargil",
    "lat": "34.55765",
    "lng": "76.12622"
  },
  {
    "country": "IN",
    "name": "Karera",
    "lat": "25.45815",
    "lng": "78.13583"
  },
  {
    "country": "IN",
    "name": "Kareli",
    "lat": "22.91533",
    "lng": "79.06378"
  },
  {
    "country": "IN",
    "name": "Karauli",
    "lat": "26.49831",
    "lng": "77.02755"
  },
  {
    "country": "IN",
    "name": "Karārī",
    "lat": "25.45241",
    "lng": "81.42675"
  },
  {
    "country": "IN",
    "name": "Kāranja",
    "lat": "20.48273",
    "lng": "77.48857"
  },
  {
    "country": "IN",
    "name": "Karamsad",
    "lat": "22.54243",
    "lng": "72.90392"
  },
  {
    "country": "IN",
    "name": "Karambakkudi",
    "lat": "10.45866",
    "lng": "79.14101"
  },
  {
    "country": "IN",
    "name": "Kāramadai",
    "lat": "11.24058",
    "lng": "76.96009"
  },
  {
    "country": "IN",
    "name": "Kāraikkudi",
    "lat": "10.06615",
    "lng": "78.76784"
  },
  {
    "country": "IN",
    "name": "Kāraikāl",
    "lat": "10.91667",
    "lng": "79.83333"
  },
  {
    "country": "IN",
    "name": "Karād",
    "lat": "17.28937",
    "lng": "74.18183"
  },
  {
    "country": "IN",
    "name": "Kapūrthala",
    "lat": "31.38011",
    "lng": "75.38105"
  },
  {
    "country": "IN",
    "name": "Captainganj",
    "lat": "26.9264",
    "lng": "83.71334"
  },
  {
    "country": "IN",
    "name": "Kāpren",
    "lat": "25.40529",
    "lng": "76.07431"
  },
  {
    "country": "IN",
    "name": "Kapadvanj",
    "lat": "23.02302",
    "lng": "73.07113"
  },
  {
    "country": "IN",
    "name": "Kantilo",
    "lat": "20.36152",
    "lng": "85.19212"
  },
  {
    "country": "IN",
    "name": "Kānth",
    "lat": "29.05939",
    "lng": "78.62951"
  },
  {
    "country": "IN",
    "name": "Kantābānji",
    "lat": "20.46709",
    "lng": "82.92042"
  },
  {
    "country": "IN",
    "name": "Kānt",
    "lat": "27.81049",
    "lng": "79.79185"
  },
  {
    "country": "IN",
    "name": "Kanpur",
    "lat": "26.46523",
    "lng": "80.34975"
  },
  {
    "country": "IN",
    "name": "Kānor",
    "lat": "24.43437",
    "lng": "74.26546"
  },
  {
    "country": "IN",
    "name": "Kānodar",
    "lat": "24.08932",
    "lng": "72.39354"
  },
  {
    "country": "IN",
    "name": "Kannod",
    "lat": "22.66764",
    "lng": "76.74286"
  },
  {
    "country": "IN",
    "name": "Kanniyākumāri",
    "lat": "8.09008",
    "lng": "77.53841"
  },
  {
    "country": "IN",
    "name": "Kannavam",
    "lat": "11.8445",
    "lng": "75.66266"
  },
  {
    "country": "IN",
    "name": "Kannauj",
    "lat": "27.05524",
    "lng": "79.9188"
  },
  {
    "country": "IN",
    "name": "Kānnangād",
    "lat": "12.30814",
    "lng": "75.10632"
  },
  {
    "country": "IN",
    "name": "Kannad",
    "lat": "20.25684",
    "lng": "75.13786"
  },
  {
    "country": "IN",
    "name": "Kānkon",
    "lat": "15.02698",
    "lng": "74.04617"
  },
  {
    "country": "IN",
    "name": "Kankipādu",
    "lat": "16.4353",
    "lng": "80.76715"
  },
  {
    "country": "IN",
    "name": "Kānker",
    "lat": "20.27193",
    "lng": "81.49177"
  },
  {
    "country": "IN",
    "name": "Kānke",
    "lat": "23.43478",
    "lng": "85.32059"
  },
  {
    "country": "IN",
    "name": "Kankauli",
    "lat": "16.26609",
    "lng": "73.71217"
  },
  {
    "country": "IN",
    "name": "Kanigiri",
    "lat": "15.40555",
    "lng": "79.50694"
  },
  {
    "country": "IN",
    "name": "Kāngar",
    "lat": "32.09135",
    "lng": "76.26267"
  },
  {
    "country": "IN",
    "name": "Kāngpokpi",
    "lat": "25.15273",
    "lng": "93.97167"
  },
  {
    "country": "IN",
    "name": "Kangayam",
    "lat": "11.00599",
    "lng": "77.5609"
  },
  {
    "country": "IN",
    "name": "Kandukūr",
    "lat": "15.21542",
    "lng": "79.9039"
  },
  {
    "country": "IN",
    "name": "Kāndri",
    "lat": "21.4203",
    "lng": "79.27663"
  },
  {
    "country": "IN",
    "name": "Kāndra",
    "lat": "22.8517",
    "lng": "86.05192"
  },
  {
    "country": "IN",
    "name": "Kāndla",
    "lat": "23.03333",
    "lng": "70.21667"
  },
  {
    "country": "IN",
    "name": "Kāndi",
    "lat": "23.95946",
    "lng": "88.04018"
  },
  {
    "country": "IN",
    "name": "Kāndhla",
    "lat": "29.32104",
    "lng": "77.27101"
  },
  {
    "country": "IN",
    "name": "Kānchipuram",
    "lat": "12.83515",
    "lng": "79.70006"
  },
  {
    "country": "IN",
    "name": "Kānkānhalli",
    "lat": "12.54654",
    "lng": "77.42005"
  },
  {
    "country": "IN",
    "name": "Kanadukattan",
    "lat": "10.17209",
    "lng": "78.77935"
  },
  {
    "country": "IN",
    "name": "Kamuthi",
    "lat": "9.40732",
    "lng": "78.37337"
  },
  {
    "country": "IN",
    "name": "Kāmthi",
    "lat": "21.21615",
    "lng": "79.1973"
  },
  {
    "country": "IN",
    "name": "Kampli",
    "lat": "15.40626",
    "lng": "76.60013"
  },
  {
    "country": "IN",
    "name": "Kampil",
    "lat": "27.61268",
    "lng": "79.27687"
  },
  {
    "country": "IN",
    "name": "Cumbum",
    "lat": "9.73647",
    "lng": "77.2847"
  },
  {
    "country": "IN",
    "name": "Kāmārhāti",
    "lat": "22.67111",
    "lng": "88.37472"
  },
  {
    "country": "IN",
    "name": "Kāmāreddi",
    "lat": "18.32001",
    "lng": "78.34177"
  },
  {
    "country": "IN",
    "name": "Kāman",
    "lat": "27.65791",
    "lng": "77.26908"
  },
  {
    "country": "IN",
    "name": "Kamalpur",
    "lat": "24.19593",
    "lng": "91.83438"
  },
  {
    "country": "IN",
    "name": "Kamalganj",
    "lat": "27.26181",
    "lng": "79.63134"
  },
  {
    "country": "IN",
    "name": "Kāmalāpuram",
    "lat": "14.5983",
    "lng": "78.66948"
  },
  {
    "country": "IN",
    "name": "Kāmākhyānagar",
    "lat": "20.93385",
    "lng": "85.54489"
  },
  {
    "country": "IN",
    "name": "Kalyani",
    "lat": "22.98333",
    "lng": "88.48333"
  },
  {
    "country": "IN",
    "name": "Kalyān",
    "lat": "19.2437",
    "lng": "73.13554"
  },
  {
    "country": "IN",
    "name": "Kālundri",
    "lat": "18.9802",
    "lng": "73.12708"
  },
  {
    "country": "IN",
    "name": "Kalugumalai",
    "lat": "9.14941",
    "lng": "77.70569"
  },
  {
    "country": "IN",
    "name": "Kālpi",
    "lat": "26.11667",
    "lng": "79.73333"
  },
  {
    "country": "IN",
    "name": "Kalpatta",
    "lat": "11.60871",
    "lng": "76.08343"
  },
  {
    "country": "IN",
    "name": "Kālol",
    "lat": "22.60777",
    "lng": "73.46272"
  },
  {
    "country": "IN",
    "name": "Kālna",
    "lat": "23.21944",
    "lng": "88.36295"
  },
  {
    "country": "IN",
    "name": "Kalmeshwar",
    "lat": "21.23219",
    "lng": "78.91988"
  },
  {
    "country": "IN",
    "name": "Kallupatti",
    "lat": "9.71667",
    "lng": "77.86667"
  },
  {
    "country": "IN",
    "name": "Kallidaikurichi",
    "lat": "8.68591",
    "lng": "77.46592"
  },
  {
    "country": "IN",
    "name": "Kallakkurichchi",
    "lat": "11.7404",
    "lng": "78.959"
  },
  {
    "country": "IN",
    "name": "Kālka",
    "lat": "30.83982",
    "lng": "76.94065"
  },
  {
    "country": "IN",
    "name": "Kāliyāganj",
    "lat": "25.63442",
    "lng": "88.32665"
  },
  {
    "country": "IN",
    "name": "Kanīna Khās",
    "lat": "28.33093",
    "lng": "76.31099"
  },
  {
    "country": "IN",
    "name": "Kālīnagar",
    "lat": "28.62019",
    "lng": "80.08152"
  },
  {
    "country": "IN",
    "name": "Kālimpong",
    "lat": "27.07059",
    "lng": "88.47529"
  },
  {
    "country": "IN",
    "name": "Kālikāpur",
    "lat": "22.61662",
    "lng": "86.2881"
  },
  {
    "country": "IN",
    "name": "Kalghatgi",
    "lat": "15.18315",
    "lng": "74.97099"
  },
  {
    "country": "IN",
    "name": "Kalavai",
    "lat": "12.77029",
    "lng": "79.41999"
  },
  {
    "country": "IN",
    "name": "Kālāvad",
    "lat": "22.20789",
    "lng": "70.38343"
  },
  {
    "country": "IN",
    "name": "Kalas",
    "lat": "18.17241",
    "lng": "74.79045"
  },
  {
    "country": "IN",
    "name": "Kālānwāli",
    "lat": "29.83573",
    "lng": "74.9717"
  },
  {
    "country": "IN",
    "name": "Kalanaur",
    "lat": "32.01227",
    "lng": "75.15063"
  },
  {
    "country": "IN",
    "name": "Kalānaur",
    "lat": "28.82823",
    "lng": "76.3955"
  },
  {
    "country": "IN",
    "name": "Kalamnūri",
    "lat": "19.67386",
    "lng": "77.31149"
  },
  {
    "country": "IN",
    "name": "Kalamb",
    "lat": "19.04437",
    "lng": "73.95554"
  },
  {
    "country": "IN",
    "name": "Kalakkādu",
    "lat": "8.5138",
    "lng": "77.54944"
  },
  {
    "country": "IN",
    "name": "Kalaīkunda",
    "lat": "22.3393",
    "lng": "87.22637"
  },
  {
    "country": "IN",
    "name": "Kālāgarh Project Colony",
    "lat": "29.4778",
    "lng": "78.78449"
  },
  {
    "country": "IN",
    "name": "Kālādhūngi",
    "lat": "29.28351",
    "lng": "79.351"
  },
  {
    "country": "IN",
    "name": "Kakrāla",
    "lat": "27.89269",
    "lng": "79.1945"
  },
  {
    "country": "IN",
    "name": "Kākori",
    "lat": "26.868",
    "lng": "80.7857"
  },
  {
    "country": "IN",
    "name": "Kākināda",
    "lat": "16.96036",
    "lng": "82.23809"
  },
  {
    "country": "IN",
    "name": "Kakching",
    "lat": "24.4982",
    "lng": "93.98126"
  },
  {
    "country": "IN",
    "name": "Kaithal",
    "lat": "29.80153",
    "lng": "76.39959"
  },
  {
    "country": "IN",
    "name": "Kairāna",
    "lat": "29.39541",
    "lng": "77.2054"
  },
  {
    "country": "IN",
    "name": "Kaintragarh",
    "lat": "20.72115",
    "lng": "84.53514"
  },
  {
    "country": "IN",
    "name": "Kaimori",
    "lat": "23.38465",
    "lng": "79.7442"
  },
  {
    "country": "IN",
    "name": "Kaimganj",
    "lat": "27.55441",
    "lng": "79.33525"
  },
  {
    "country": "IN",
    "name": "Kailāshahar",
    "lat": "24.33199",
    "lng": "92.00391"
  },
  {
    "country": "IN",
    "name": "Kailāras",
    "lat": "26.30498",
    "lng": "77.616"
  },
  {
    "country": "IN",
    "name": "Kaikalūr",
    "lat": "16.55154",
    "lng": "81.214"
  },
  {
    "country": "IN",
    "name": "Kāgal",
    "lat": "16.57702",
    "lng": "74.31544"
  },
  {
    "country": "IN",
    "name": "Kadūr",
    "lat": "13.55285",
    "lng": "76.01164"
  },
  {
    "country": "IN",
    "name": "Kadod",
    "lat": "21.21717",
    "lng": "73.21972"
  },
  {
    "country": "IN",
    "name": "Kadiri",
    "lat": "14.11168",
    "lng": "78.15982"
  },
  {
    "country": "IN",
    "name": "Kādīpur",
    "lat": "26.16779",
    "lng": "82.37028"
  },
  {
    "country": "IN",
    "name": "Kadi",
    "lat": "23.29908",
    "lng": "72.33362"
  },
  {
    "country": "IN",
    "name": "Kadaura",
    "lat": "25.98537",
    "lng": "79.83842"
  },
  {
    "country": "IN",
    "name": "Kadambūr",
    "lat": "8.99739",
    "lng": "77.86191"
  },
  {
    "country": "IN",
    "name": "Kadayanallur",
    "lat": "9.07277",
    "lng": "77.34152"
  },
  {
    "country": "IN",
    "name": "Kānchrāpāra",
    "lat": "22.95998",
    "lng": "88.42849"
  },
  {
    "country": "IN",
    "name": "Kachhwa",
    "lat": "25.20615",
    "lng": "82.71442"
  },
  {
    "country": "IN",
    "name": "Kabrāi",
    "lat": "25.40281",
    "lng": "79.9997"
  },
  {
    "country": "IN",
    "name": "Jutogh",
    "lat": "31.1",
    "lng": "77.11667"
  },
  {
    "country": "IN",
    "name": "Junnar",
    "lat": "19.20815",
    "lng": "73.8752"
  },
  {
    "country": "IN",
    "name": "Jūnāgarh",
    "lat": "19.85993",
    "lng": "82.93385"
  },
  {
    "country": "IN",
    "name": "Jūnāgadh",
    "lat": "21.51966",
    "lng": "70.45981"
  },
  {
    "country": "IN",
    "name": "Jumri Tilaiyā",
    "lat": "24.4349",
    "lng": "85.52951"
  },
  {
    "country": "IN",
    "name": "Jalandhar",
    "lat": "31.32556",
    "lng": "75.57917"
  },
  {
    "country": "IN",
    "name": "Shādīpur Julāna",
    "lat": "29.12368",
    "lng": "76.40516"
  },
  {
    "country": "IN",
    "name": "Jugsālai",
    "lat": "22.77668",
    "lng": "86.18351"
  },
  {
    "country": "IN",
    "name": "Jubbal",
    "lat": "31.10923",
    "lng": "77.65085"
  },
  {
    "country": "IN",
    "name": "Jua",
    "lat": "15.5307",
    "lng": "73.95047"
  },
  {
    "country": "IN",
    "name": "Joshīmath",
    "lat": "30.55543",
    "lng": "79.56436"
  },
  {
    "country": "IN",
    "name": "Jorhāt",
    "lat": "26.75751",
    "lng": "94.20306"
  },
  {
    "country": "IN",
    "name": "Jora",
    "lat": "26.34209",
    "lng": "77.8092"
  },
  {
    "country": "IN",
    "name": "Jalārpet",
    "lat": "12.57025",
    "lng": "78.57318"
  },
  {
    "country": "IN",
    "name": "Jogindarnagar",
    "lat": "31.98727",
    "lng": "76.78906"
  },
  {
    "country": "IN",
    "name": "Jogīghopa",
    "lat": "26.22646",
    "lng": "90.57247"
  },
  {
    "country": "IN",
    "name": "Jogbani",
    "lat": "26.39905",
    "lng": "87.26525"
  },
  {
    "country": "IN",
    "name": "Jodiya Bandar",
    "lat": "22.71667",
    "lng": "70.28333"
  },
  {
    "country": "IN",
    "name": "Jodhpur",
    "lat": "26.26841",
    "lng": "73.00594"
  },
  {
    "country": "IN",
    "name": "Jodhpur",
    "lat": "21.90174",
    "lng": "70.0327"
  },
  {
    "country": "IN",
    "name": "Jobner",
    "lat": "26.97257",
    "lng": "75.38752"
  },
  {
    "country": "IN",
    "name": "Jobat",
    "lat": "22.41599",
    "lng": "74.56828"
  },
  {
    "country": "IN",
    "name": "Jīran",
    "lat": "24.30871",
    "lng": "74.89087"
  },
  {
    "country": "IN",
    "name": "Jintūr",
    "lat": "19.61186",
    "lng": "76.6874"
  },
  {
    "country": "IN",
    "name": "Jīnd",
    "lat": "29.31577",
    "lng": "76.31502"
  },
  {
    "country": "IN",
    "name": "Jhūsi",
    "lat": "25.43745",
    "lng": "81.9055"
  },
  {
    "country": "IN",
    "name": "Jhunjhunūn",
    "lat": "28.12559",
    "lng": "75.39797"
  },
  {
    "country": "IN",
    "name": "Jhinjhāna",
    "lat": "29.52118",
    "lng": "77.2247"
  },
  {
    "country": "IN",
    "name": "Jhīnjhak",
    "lat": "26.56093",
    "lng": "79.73423"
  },
  {
    "country": "IN",
    "name": "Jhārsugra",
    "lat": "21.8624",
    "lng": "84.01782"
  },
  {
    "country": "IN",
    "name": "Jharia",
    "lat": "23.74079",
    "lng": "86.41456"
  },
  {
    "country": "IN",
    "name": "Jhārgrām",
    "lat": "22.45384",
    "lng": "86.99497"
  },
  {
    "country": "IN",
    "name": "Jhānsi",
    "lat": "25.45887",
    "lng": "78.57994"
  },
  {
    "country": "IN",
    "name": "Jhanjhārpur",
    "lat": "26.26467",
    "lng": "86.27993"
  },
  {
    "country": "IN",
    "name": "Jhālu",
    "lat": "29.33609",
    "lng": "78.22608"
  },
  {
    "country": "IN",
    "name": "Jhālrapātan",
    "lat": "24.54205",
    "lng": "76.17242"
  },
  {
    "country": "IN",
    "name": "Jhalidā",
    "lat": "23.36545",
    "lng": "85.97643"
  },
  {
    "country": "IN",
    "name": "Jhālāwār",
    "lat": "24.59633",
    "lng": "76.16499"
  },
  {
    "country": "IN",
    "name": "Jhajjar",
    "lat": "28.6063",
    "lng": "76.6565"
  },
  {
    "country": "IN",
    "name": "Jhā-Jhā",
    "lat": "24.77107",
    "lng": "86.37888"
  },
  {
    "country": "IN",
    "name": "Jhābua",
    "lat": "22.76772",
    "lng": "74.59087"
  },
  {
    "country": "IN",
    "name": "Jewar",
    "lat": "28.122",
    "lng": "77.55734"
  },
  {
    "country": "IN",
    "name": "Jevargi",
    "lat": "17.01394",
    "lng": "76.77317"
  },
  {
    "country": "IN",
    "name": "Jetpur",
    "lat": "22.34472",
    "lng": "73.84093"
  },
  {
    "country": "IN",
    "name": "Jetpur",
    "lat": "21.75482",
    "lng": "70.62347"
  },
  {
    "country": "IN",
    "name": "Jetalsar",
    "lat": "21.70891",
    "lng": "70.57695"
  },
  {
    "country": "IN",
    "name": "Jejūri",
    "lat": "18.27658",
    "lng": "74.16008"
  },
  {
    "country": "IN",
    "name": "Jeypore",
    "lat": "18.8563",
    "lng": "82.5716"
  },
  {
    "country": "IN",
    "name": "Jaynagar",
    "lat": "26.59048",
    "lng": "86.13791"
  },
  {
    "country": "IN",
    "name": "Jaynagar-Majilpur",
    "lat": "22.17583",
    "lng": "88.41778"
  },
  {
    "country": "IN",
    "name": "Jayamkondacholapuram",
    "lat": "11.21266",
    "lng": "79.36369"
  },
  {
    "country": "IN",
    "name": "Jawhār",
    "lat": "19.91213",
    "lng": "73.22679"
  },
  {
    "country": "IN",
    "name": "Iāwar",
    "lat": "23.00943",
    "lng": "76.5007"
  },
  {
    "country": "IN",
    "name": "Jawāla Mukhi",
    "lat": "31.87456",
    "lng": "76.32013"
  },
  {
    "country": "IN",
    "name": "Jāwad",
    "lat": "24.59916",
    "lng": "74.86261"
  },
  {
    "country": "IN",
    "name": "Jaunpur",
    "lat": "25.75356",
    "lng": "82.68689"
  },
  {
    "country": "IN",
    "name": "Jatāra",
    "lat": "25.00964",
    "lng": "79.04869"
  },
  {
    "country": "IN",
    "name": "Jatani",
    "lat": "20.15975",
    "lng": "85.70742"
  },
  {
    "country": "IN",
    "name": "Jaswantnagar",
    "lat": "26.88271",
    "lng": "78.90256"
  },
  {
    "country": "IN",
    "name": "Jasrāna",
    "lat": "27.23587",
    "lng": "78.65244"
  },
  {
    "country": "IN",
    "name": "Jaspur",
    "lat": "29.27919",
    "lng": "78.82798"
  },
  {
    "country": "IN",
    "name": "Jasidih",
    "lat": "24.51379",
    "lng": "86.64576"
  },
  {
    "country": "IN",
    "name": "Jashpurnagar",
    "lat": "22.88783",
    "lng": "84.13864"
  },
  {
    "country": "IN",
    "name": "Jasdan",
    "lat": "22.03709",
    "lng": "71.20794"
  },
  {
    "country": "IN",
    "name": "Jarwal",
    "lat": "27.1629",
    "lng": "81.54179"
  },
  {
    "country": "IN",
    "name": "Jaorā",
    "lat": "23.63783",
    "lng": "75.12711"
  },
  {
    "country": "IN",
    "name": "Jānsath",
    "lat": "29.32502",
    "lng": "77.85044"
  },
  {
    "country": "IN",
    "name": "Jānjgīr",
    "lat": "22.00922",
    "lng": "82.5778"
  },
  {
    "country": "IN",
    "name": "Jangipur",
    "lat": "24.47001",
    "lng": "88.07659"
  },
  {
    "country": "IN",
    "name": "Jangaon",
    "lat": "17.72602",
    "lng": "79.15236"
  },
  {
    "country": "IN",
    "name": "Jandiāla Gurū",
    "lat": "31.56198",
    "lng": "75.0277"
  },
  {
    "country": "IN",
    "name": "Jandiāla",
    "lat": "31.1593",
    "lng": "75.61755"
  },
  {
    "country": "IN",
    "name": "Jāmuria",
    "lat": "23.70468",
    "lng": "87.07872"
  },
  {
    "country": "IN",
    "name": "Jamūī",
    "lat": "24.92606",
    "lng": "86.22531"
  },
  {
    "country": "IN",
    "name": "Jāmtāra",
    "lat": "23.963",
    "lng": "86.80285"
  },
  {
    "country": "IN",
    "name": "Jamshedpur",
    "lat": "22.80278",
    "lng": "86.18545"
  },
  {
    "country": "IN",
    "name": "Jamnagar",
    "lat": "22.47292",
    "lng": "70.06673"
  },
  {
    "country": "IN",
    "name": "Jammu",
    "lat": "32.73569",
    "lng": "74.86911"
  },
  {
    "country": "IN",
    "name": "Jammalamadugu",
    "lat": "14.84677",
    "lng": "78.38314"
  },
  {
    "country": "IN",
    "name": "Jamkhandi",
    "lat": "16.50461",
    "lng": "75.29146"
  },
  {
    "country": "IN",
    "name": "Jambusar",
    "lat": "22.05236",
    "lng": "72.80074"
  },
  {
    "country": "IN",
    "name": "Jamālpur",
    "lat": "25.31258",
    "lng": "86.48888"
  },
  {
    "country": "IN",
    "name": "Jāmai",
    "lat": "22.19644",
    "lng": "78.59191"
  },
  {
    "country": "IN",
    "name": "Jāmadoba",
    "lat": "23.71667",
    "lng": "86.4"
  },
  {
    "country": "IN",
    "name": "Jalpāiguri",
    "lat": "26.51667",
    "lng": "88.73333"
  },
  {
    "country": "IN",
    "name": "Jalor",
    "lat": "25.34558",
    "lng": "72.61559"
  },
  {
    "country": "IN",
    "name": "Jālna",
    "lat": "19.84102",
    "lng": "75.88636"
  },
  {
    "country": "IN",
    "name": "Jalgaon Jamod",
    "lat": "21.05194",
    "lng": "76.53464"
  },
  {
    "country": "IN",
    "name": "Jalgaon",
    "lat": "21.00292",
    "lng": "75.56602"
  },
  {
    "country": "IN",
    "name": "Jalgaon",
    "lat": "17.74026",
    "lng": "73.19087"
  },
  {
    "country": "IN",
    "name": "Jaleshwar",
    "lat": "21.80176",
    "lng": "87.2225"
  },
  {
    "country": "IN",
    "name": "Jalesar",
    "lat": "27.47315",
    "lng": "78.3031"
  },
  {
    "country": "IN",
    "name": "Jālaun",
    "lat": "26.1451",
    "lng": "79.3366"
  },
  {
    "country": "IN",
    "name": "Jalālpur",
    "lat": "26.31162",
    "lng": "82.73859"
  },
  {
    "country": "IN",
    "name": "Jalālpur",
    "lat": "20.94896",
    "lng": "72.89829"
  },
  {
    "country": "IN",
    "name": "Jalālī",
    "lat": "27.8668",
    "lng": "78.25267"
  },
  {
    "country": "IN",
    "name": "Jalālābād",
    "lat": "30.60622",
    "lng": "74.25727"
  },
  {
    "country": "IN",
    "name": "Jalālābad",
    "lat": "29.61853",
    "lng": "77.43908"
  },
  {
    "country": "IN",
    "name": "Jalālābād",
    "lat": "27.72625",
    "lng": "79.65523"
  },
  {
    "country": "IN",
    "name": "Jalakandapuram",
    "lat": "11.69779",
    "lng": "77.87298"
  },
  {
    "country": "IN",
    "name": "Jākhal",
    "lat": "29.79627",
    "lng": "75.82392"
  },
  {
    "country": "IN",
    "name": "Jājpur",
    "lat": "20.84852",
    "lng": "86.33729"
  },
  {
    "country": "IN",
    "name": "Jaito",
    "lat": "30.45126",
    "lng": "74.89189"
  },
  {
    "country": "IN",
    "name": "Jaithāri",
    "lat": "23.20856",
    "lng": "78.61487"
  },
  {
    "country": "IN",
    "name": "Jaitāran",
    "lat": "26.20446",
    "lng": "73.93676"
  },
  {
    "country": "IN",
    "name": "Jaisingpur",
    "lat": "16.77639",
    "lng": "74.55361"
  },
  {
    "country": "IN",
    "name": "Jaisinghnagar",
    "lat": "23.68582",
    "lng": "81.39085"
  },
  {
    "country": "IN",
    "name": "Jaisalmer",
    "lat": "26.91763",
    "lng": "70.90387"
  },
  {
    "country": "IN",
    "name": "Jais",
    "lat": "26.2649",
    "lng": "81.54855"
  },
  {
    "country": "IN",
    "name": "Jaipur",
    "lat": "26.91962",
    "lng": "75.78781"
  },
  {
    "country": "IN",
    "name": "Jainpur",
    "lat": "26.15389",
    "lng": "83.33505"
  },
  {
    "country": "IN",
    "name": "Jahāzpur",
    "lat": "25.61994",
    "lng": "75.27609"
  },
  {
    "country": "IN",
    "name": "Jahāngīrpur",
    "lat": "28.17919",
    "lng": "77.70501"
  },
  {
    "country": "IN",
    "name": "Jahāngīrābād",
    "lat": "28.40549",
    "lng": "78.10588"
  },
  {
    "country": "IN",
    "name": "Jahānābād",
    "lat": "28.63025",
    "lng": "79.71818"
  },
  {
    "country": "IN",
    "name": "Jahānābād",
    "lat": "25.21368",
    "lng": "84.9871"
  },
  {
    "country": "IN",
    "name": "Jagtiāl",
    "lat": "18.79473",
    "lng": "78.91661"
  },
  {
    "country": "IN",
    "name": "Jagraon",
    "lat": "30.78783",
    "lng": "75.47391"
  },
  {
    "country": "IN",
    "name": "Jagnair",
    "lat": "26.8636",
    "lng": "77.60231"
  },
  {
    "country": "IN",
    "name": "Jaggayyapeta",
    "lat": "16.8938",
    "lng": "80.09807"
  },
  {
    "country": "IN",
    "name": "Jagdīspur",
    "lat": "25.46811",
    "lng": "84.41939"
  },
  {
    "country": "IN",
    "name": "Jagdīshpur",
    "lat": "26.74967",
    "lng": "80.5451"
  },
  {
    "country": "IN",
    "name": "Jagdalpur",
    "lat": "19.08136",
    "lng": "82.02131"
  },
  {
    "country": "IN",
    "name": "Jagatsinghapur",
    "lat": "20.2557",
    "lng": "86.17112"
  },
  {
    "country": "IN",
    "name": "Jagannāthpur",
    "lat": "22.22115",
    "lng": "85.63917"
  },
  {
    "country": "IN",
    "name": "Jagalūr",
    "lat": "14.51957",
    "lng": "76.33915"
  },
  {
    "country": "IN",
    "name": "Jagādhri",
    "lat": "30.16719",
    "lng": "77.30367"
  },
  {
    "country": "IN",
    "name": "Jabalpur",
    "lat": "23.16697",
    "lng": "79.95006"
  },
  {
    "country": "IN",
    "name": "Itimādpur",
    "lat": "27.23541",
    "lng": "78.19829"
  },
  {
    "country": "IN",
    "name": "Itaunja",
    "lat": "27.08347",
    "lng": "80.89672"
  },
  {
    "country": "IN",
    "name": "Itārsi",
    "lat": "22.61477",
    "lng": "77.76222"
  },
  {
    "country": "IN",
    "name": "Itānagar",
    "lat": "27.08694",
    "lng": "93.60987"
  },
  {
    "country": "IN",
    "name": "Islāmpur",
    "lat": "26.26541",
    "lng": "88.18982"
  },
  {
    "country": "IN",
    "name": "Islāmpur",
    "lat": "25.14075",
    "lng": "85.20587"
  },
  {
    "country": "IN",
    "name": "Islāmnagar",
    "lat": "28.32896",
    "lng": "78.72524"
  },
  {
    "country": "IN",
    "name": "Isāgarh",
    "lat": "24.83906",
    "lng": "77.88274"
  },
  {
    "country": "IN",
    "name": "Irugūr",
    "lat": "11.01782",
    "lng": "77.06285"
  },
  {
    "country": "IN",
    "name": "Irinjālakuda",
    "lat": "10.34238",
    "lng": "76.21124"
  },
  {
    "country": "IN",
    "name": "Iringal",
    "lat": "11.55929",
    "lng": "75.61663"
  },
  {
    "country": "IN",
    "name": "Ingrāj Bāzār",
    "lat": "25.00447",
    "lng": "88.14573"
  },
  {
    "country": "IN",
    "name": "Indri",
    "lat": "29.87999",
    "lng": "77.05972"
  },
  {
    "country": "IN",
    "name": "Indore",
    "lat": "22.71792",
    "lng": "75.8333"
  },
  {
    "country": "IN",
    "name": "Indi",
    "lat": "17.17735",
    "lng": "75.9526"
  },
  {
    "country": "IN",
    "name": "Indergarh",
    "lat": "26.93521",
    "lng": "79.6712"
  },
  {
    "country": "IN",
    "name": "Indāpur",
    "lat": "18.3",
    "lng": "73.25"
  },
  {
    "country": "IN",
    "name": "Imphal",
    "lat": "24.80805",
    "lng": "93.9442"
  },
  {
    "country": "IN",
    "name": "Iluppūr",
    "lat": "10.51347",
    "lng": "78.62357"
  },
  {
    "country": "IN",
    "name": "Ilkal",
    "lat": "15.95923",
    "lng": "76.11351"
  },
  {
    "country": "IN",
    "name": "Ilampillai",
    "lat": "11.60659",
    "lng": "78.00676"
  },
  {
    "country": "IN",
    "name": "Iklehra",
    "lat": "23.14667",
    "lng": "76.39044"
  },
  {
    "country": "IN",
    "name": "Ikauna",
    "lat": "27.53097",
    "lng": "81.96917"
  },
  {
    "country": "IN",
    "name": "Iglās",
    "lat": "27.711",
    "lng": "77.93967"
  },
  {
    "country": "IN",
    "name": "Igatpuri",
    "lat": "19.69522",
    "lng": "73.5626"
  },
  {
    "country": "IN",
    "name": "Idukki",
    "lat": "9.85",
    "lng": "76.96667"
  },
  {
    "country": "IN",
    "name": "Idappadi",
    "lat": "11.58624",
    "lng": "77.83891"
  },
  {
    "country": "IN",
    "name": "Ichhāwar",
    "lat": "23.02816",
    "lng": "77.01729"
  },
  {
    "country": "IN",
    "name": "Ichchāpuram",
    "lat": "19.11393",
    "lng": "84.68721"
  },
  {
    "country": "IN",
    "name": "Ichalkaranji",
    "lat": "16.69117",
    "lng": "74.46054"
  },
  {
    "country": "IN",
    "name": "Hyderabad",
    "lat": "17.38405",
    "lng": "78.45636"
  },
  {
    "country": "IN",
    "name": "Hadagalli",
    "lat": "15.02048",
    "lng": "75.93185"
  },
  {
    "country": "IN",
    "name": "Husainābād",
    "lat": "24.52849",
    "lng": "84"
  },
  {
    "country": "IN",
    "name": "Hunsūr",
    "lat": "12.30359",
    "lng": "76.29275"
  },
  {
    "country": "IN",
    "name": "Hungund",
    "lat": "16.06213",
    "lng": "76.0586"
  },
  {
    "country": "IN",
    "name": "Hukeri",
    "lat": "16.23082",
    "lng": "74.60244"
  },
  {
    "country": "IN",
    "name": "Hugli",
    "lat": "22.90877",
    "lng": "88.39674"
  },
  {
    "country": "IN",
    "name": "Hubli",
    "lat": "15.34776",
    "lng": "75.13378"
  },
  {
    "country": "IN",
    "name": "Howli",
    "lat": "26.42237",
    "lng": "90.98004"
  },
  {
    "country": "IN",
    "name": "Hosūr",
    "lat": "12.73647",
    "lng": "77.83264"
  },
  {
    "country": "IN",
    "name": "Hospet",
    "lat": "15.26954",
    "lng": "76.3871"
  },
  {
    "country": "IN",
    "name": "Hoskote",
    "lat": "13.0707",
    "lng": "77.79814"
  },
  {
    "country": "IN",
    "name": "Hoshiārpur",
    "lat": "31.53723",
    "lng": "75.91269"
  },
  {
    "country": "IN",
    "name": "Hoshangābād",
    "lat": "22.74747",
    "lng": "77.72736"
  },
  {
    "country": "IN",
    "name": "Hosdurga",
    "lat": "13.79631",
    "lng": "76.28408"
  },
  {
    "country": "IN",
    "name": "Hosangadi",
    "lat": "13.69756",
    "lng": "74.95427"
  },
  {
    "country": "IN",
    "name": "Hosanagara",
    "lat": "13.91387",
    "lng": "75.06503"
  },
  {
    "country": "IN",
    "name": "Hosakote",
    "lat": "14.27603",
    "lng": "77.16827"
  },
  {
    "country": "IN",
    "name": "Honnāli",
    "lat": "14.23976",
    "lng": "75.64507"
  },
  {
    "country": "IN",
    "name": "Honāvar",
    "lat": "14.28088",
    "lng": "74.44497"
  },
  {
    "country": "IN",
    "name": "Homnābād",
    "lat": "17.77074",
    "lng": "77.12519"
  },
  {
    "country": "IN",
    "name": "Hole Narsipur",
    "lat": "12.78635",
    "lng": "76.24331"
  },
  {
    "country": "IN",
    "name": "Holalkere",
    "lat": "14.04295",
    "lng": "76.18496"
  },
  {
    "country": "IN",
    "name": "Hojāi",
    "lat": "26.00281",
    "lng": "92.85605"
  },
  {
    "country": "IN",
    "name": "Hodal",
    "lat": "27.89196",
    "lng": "77.36744"
  },
  {
    "country": "IN",
    "name": "Hisuā",
    "lat": "24.8336",
    "lng": "85.41729"
  },
  {
    "country": "IN",
    "name": "Hisar",
    "lat": "29.15394",
    "lng": "75.72294"
  },
  {
    "country": "IN",
    "name": "Hiriyūr",
    "lat": "13.94455",
    "lng": "76.61723"
  },
  {
    "country": "IN",
    "name": "Hirekerūr",
    "lat": "14.45506",
    "lng": "75.3952"
  },
  {
    "country": "IN",
    "name": "Hīrāpur Hamesha",
    "lat": "21.55546",
    "lng": "79.78581"
  },
  {
    "country": "IN",
    "name": "Hirānagar",
    "lat": "32.45493",
    "lng": "75.27187"
  },
  {
    "country": "IN",
    "name": "Hīrākud",
    "lat": "21.52502",
    "lng": "83.87275"
  },
  {
    "country": "IN",
    "name": "Hinjilikatu",
    "lat": "19.48166",
    "lng": "84.74489"
  },
  {
    "country": "IN",
    "name": "Hingoli",
    "lat": "19.71464",
    "lng": "77.14238"
  },
  {
    "country": "IN",
    "name": "Hinganghāt",
    "lat": "20.54875",
    "lng": "78.83978"
  },
  {
    "country": "IN",
    "name": "Hindupur",
    "lat": "13.82807",
    "lng": "77.49143"
  },
  {
    "country": "IN",
    "name": "Hindoria",
    "lat": "23.90345",
    "lng": "79.56861"
  },
  {
    "country": "IN",
    "name": "Hindaun",
    "lat": "26.73411",
    "lng": "77.03519"
  },
  {
    "country": "IN",
    "name": "Himatnagar",
    "lat": "23.59893",
    "lng": "72.96602"
  },
  {
    "country": "IN",
    "name": "Hilsa",
    "lat": "25.31642",
    "lng": "85.28234"
  },
  {
    "country": "IN",
    "name": "Hesla",
    "lat": "24.06313",
    "lng": "85.87905"
  },
  {
    "country": "IN",
    "name": "Harbatpur",
    "lat": "30.43863",
    "lng": "77.74058"
  },
  {
    "country": "IN",
    "name": "Heggadadevankote",
    "lat": "12.08809",
    "lng": "76.32957"
  },
  {
    "country": "IN",
    "name": "Hazāribāgh",
    "lat": "23.99241",
    "lng": "85.36162"
  },
  {
    "country": "IN",
    "name": "Hayuliang",
    "lat": "28.07301",
    "lng": "96.54305"
  },
  {
    "country": "IN",
    "name": "Hāveri",
    "lat": "14.79354",
    "lng": "75.40448"
  },
  {
    "country": "IN",
    "name": "Hatta",
    "lat": "24.13406",
    "lng": "79.60119"
  },
  {
    "country": "IN",
    "name": "Hātod",
    "lat": "22.79378",
    "lng": "75.73928"
  },
  {
    "country": "IN",
    "name": "Hāthras",
    "lat": "27.59551",
    "lng": "78.05201"
  },
  {
    "country": "IN",
    "name": "Hātā",
    "lat": "26.7412",
    "lng": "83.74526"
  },
  {
    "country": "IN",
    "name": "Hastināpur",
    "lat": "29.16042",
    "lng": "78.00762"
  },
  {
    "country": "IN",
    "name": "Hassan",
    "lat": "13.00715",
    "lng": "76.0962"
  },
  {
    "country": "IN",
    "name": "Hāsimāra",
    "lat": "26.7469",
    "lng": "89.35385"
  },
  {
    "country": "IN",
    "name": "Hasanpur",
    "lat": "28.72249",
    "lng": "78.28436"
  },
  {
    "country": "IN",
    "name": "Hasanpur",
    "lat": "27.96944",
    "lng": "77.49544"
  },
  {
    "country": "IN",
    "name": "Harūr",
    "lat": "12.05267",
    "lng": "78.48023"
  },
  {
    "country": "IN",
    "name": "Harsūd",
    "lat": "22.09947",
    "lng": "76.73423"
  },
  {
    "country": "IN",
    "name": "Harrai",
    "lat": "22.61428",
    "lng": "79.22207"
  },
  {
    "country": "IN",
    "name": "Harpanahalli",
    "lat": "14.78766",
    "lng": "75.98863"
  },
  {
    "country": "IN",
    "name": "Harpālpur",
    "lat": "25.28773",
    "lng": "79.33279"
  },
  {
    "country": "IN",
    "name": "Harnai",
    "lat": "17.8134",
    "lng": "73.09668"
  },
  {
    "country": "IN",
    "name": "Haringhāta",
    "lat": "22.96474",
    "lng": "88.57451"
  },
  {
    "country": "IN",
    "name": "Hārij",
    "lat": "23.69356",
    "lng": "71.907"
  },
  {
    "country": "IN",
    "name": "Harihar",
    "lat": "14.51288",
    "lng": "75.80716"
  },
  {
    "country": "IN",
    "name": "Haridwar",
    "lat": "29.94791",
    "lng": "78.16025"
  },
  {
    "country": "IN",
    "name": "Hariāna",
    "lat": "31.63512",
    "lng": "75.83887"
  },
  {
    "country": "IN",
    "name": "Harduāganj",
    "lat": "27.94361",
    "lng": "78.15789"
  },
  {
    "country": "IN",
    "name": "Hardoī",
    "lat": "27.39491",
    "lng": "80.13165"
  },
  {
    "country": "IN",
    "name": "Harda Khās",
    "lat": "22.34414",
    "lng": "77.09536"
  },
  {
    "country": "IN",
    "name": "Haraiya",
    "lat": "26.79477",
    "lng": "82.46436"
  },
  {
    "country": "IN",
    "name": "Hāpur",
    "lat": "28.72985",
    "lng": "77.78068"
  },
  {
    "country": "IN",
    "name": "Hāora",
    "lat": "22.57688",
    "lng": "88.31857"
  },
  {
    "country": "IN",
    "name": "Hanumāngarh",
    "lat": "29.58182",
    "lng": "74.32938"
  },
  {
    "country": "IN",
    "name": "Hansot",
    "lat": "21.58496",
    "lng": "72.80764"
  },
  {
    "country": "IN",
    "name": "Hānsi",
    "lat": "29.10239",
    "lng": "75.96253"
  },
  {
    "country": "IN",
    "name": "Hāngal",
    "lat": "14.76465",
    "lng": "75.1246"
  },
  {
    "country": "IN",
    "name": "Handiā",
    "lat": "25.36379",
    "lng": "82.18655"
  },
  {
    "country": "IN",
    "name": "Hampi",
    "lat": "15.3352",
    "lng": "76.4603"
  },
  {
    "country": "IN",
    "name": "Hamīrpur",
    "lat": "31.68411",
    "lng": "76.52506"
  },
  {
    "country": "IN",
    "name": "Hamīrpur",
    "lat": "25.9553",
    "lng": "80.14842"
  },
  {
    "country": "IN",
    "name": "Halvad",
    "lat": "23.01516",
    "lng": "71.18029"
  },
  {
    "country": "IN",
    "name": "Hālol",
    "lat": "22.50321",
    "lng": "73.47242"
  },
  {
    "country": "IN",
    "name": "Haliyal",
    "lat": "15.32864",
    "lng": "74.75638"
  },
  {
    "country": "IN",
    "name": "Hālīsahar",
    "lat": "22.93218",
    "lng": "88.41859"
  },
  {
    "country": "IN",
    "name": "Haldwani",
    "lat": "29.22254",
    "lng": "79.5286"
  },
  {
    "country": "IN",
    "name": "Haldībāri",
    "lat": "26.33887",
    "lng": "88.7822"
  },
  {
    "country": "IN",
    "name": "Haldaur",
    "lat": "29.28988",
    "lng": "78.28437"
  },
  {
    "country": "IN",
    "name": "Hājo",
    "lat": "26.2452",
    "lng": "91.52525"
  },
  {
    "country": "IN",
    "name": "Hājipur",
    "lat": "31.97714",
    "lng": "75.75438"
  },
  {
    "country": "IN",
    "name": "Hājīpur",
    "lat": "25.68544",
    "lng": "85.20981"
  },
  {
    "country": "IN",
    "name": "Hājan",
    "lat": "34.29895",
    "lng": "74.61681"
  },
  {
    "country": "IN",
    "name": "Hailākāndi",
    "lat": "24.68394",
    "lng": "92.56097"
  },
  {
    "country": "IN",
    "name": "Hāflong",
    "lat": "25.16478",
    "lng": "93.01744"
  },
  {
    "country": "IN",
    "name": "Hadgāon",
    "lat": "19.49552",
    "lng": "77.65863"
  },
  {
    "country": "IN",
    "name": "Hābra",
    "lat": "22.84202",
    "lng": "88.65606"
  },
  {
    "country": "IN",
    "name": "Gyānpur",
    "lat": "25.33268",
    "lng": "82.46637"
  },
  {
    "country": "IN",
    "name": "Gyalshing",
    "lat": "27.28952",
    "lng": "88.25764"
  },
  {
    "country": "IN",
    "name": "Gwalior",
    "lat": "26.22983",
    "lng": "78.17337"
  },
  {
    "country": "IN",
    "name": "Guskhara",
    "lat": "23.49276",
    "lng": "87.73484"
  },
  {
    "country": "IN",
    "name": "Guruvāyūr",
    "lat": "10.5943",
    "lng": "76.0411"
  },
  {
    "country": "IN",
    "name": "Guru Har Sahāi",
    "lat": "30.70862",
    "lng": "74.40407"
  },
  {
    "country": "IN",
    "name": "Gursarāi",
    "lat": "25.61677",
    "lng": "79.18053"
  },
  {
    "country": "IN",
    "name": "Gursahāiganj",
    "lat": "27.11518",
    "lng": "79.73174"
  },
  {
    "country": "IN",
    "name": "Gurmatkāl",
    "lat": "16.86773",
    "lng": "77.39088"
  },
  {
    "country": "IN",
    "name": "Gurh",
    "lat": "24.50265",
    "lng": "81.50037"
  },
  {
    "country": "IN",
    "name": "Gurgaon",
    "lat": "28.4601",
    "lng": "77.02635"
  },
  {
    "country": "IN",
    "name": "Gunupur",
    "lat": "19.0804",
    "lng": "83.80879"
  },
  {
    "country": "IN",
    "name": "Guntur",
    "lat": "16.29974",
    "lng": "80.45729"
  },
  {
    "country": "IN",
    "name": "Guntakal Junction",
    "lat": "15.17112",
    "lng": "77.36244"
  },
  {
    "country": "IN",
    "name": "Gunnaur",
    "lat": "28.23995",
    "lng": "78.43994"
  },
  {
    "country": "IN",
    "name": "Gundlupēt",
    "lat": "11.81004",
    "lng": "76.69027"
  },
  {
    "country": "IN",
    "name": "Guna",
    "lat": "24.64691",
    "lng": "77.3113"
  },
  {
    "country": "IN",
    "name": "Gummidipundi",
    "lat": "13.40765",
    "lng": "80.10879"
  },
  {
    "country": "IN",
    "name": "Gumlā",
    "lat": "23.04268",
    "lng": "84.54429"
  },
  {
    "country": "IN",
    "name": "Gumia",
    "lat": "23.7975",
    "lng": "85.82523"
  },
  {
    "country": "IN",
    "name": "Guledagudda",
    "lat": "16.05025",
    "lng": "75.78997"
  },
  {
    "country": "IN",
    "name": "Gulbarga",
    "lat": "17.33583",
    "lng": "76.83757"
  },
  {
    "country": "IN",
    "name": "Gulāothi",
    "lat": "28.58938",
    "lng": "77.79318"
  },
  {
    "country": "IN",
    "name": "Gulābpura",
    "lat": "25.90448",
    "lng": "74.66025"
  },
  {
    "country": "IN",
    "name": "Guirim",
    "lat": "15.57552",
    "lng": "73.80722"
  },
  {
    "country": "IN",
    "name": "Guhāgar",
    "lat": "17.48415",
    "lng": "73.19289"
  },
  {
    "country": "IN",
    "name": "Gūduvāncheri",
    "lat": "12.84519",
    "lng": "80.06055"
  },
  {
    "country": "IN",
    "name": "Gūdūr",
    "lat": "17.49174",
    "lng": "78.82302"
  },
  {
    "country": "IN",
    "name": "Gūdūr",
    "lat": "14.15093",
    "lng": "79.8521"
  },
  {
    "country": "IN",
    "name": "Gudlavalleru",
    "lat": "16.35",
    "lng": "81.05"
  },
  {
    "country": "IN",
    "name": "Gudiyatham",
    "lat": "12.94601",
    "lng": "78.87377"
  },
  {
    "country": "IN",
    "name": "Gudivāda",
    "lat": "16.43547",
    "lng": "80.99555"
  },
  {
    "country": "IN",
    "name": "Gudibanda",
    "lat": "13.67099",
    "lng": "77.70414"
  },
  {
    "country": "IN",
    "name": "Gudāri",
    "lat": "19.34762",
    "lng": "83.78128"
  },
  {
    "country": "IN",
    "name": "Gudalur",
    "lat": "9.67826",
    "lng": "77.24951"
  },
  {
    "country": "IN",
    "name": "Gubbi",
    "lat": "13.31216",
    "lng": "76.94102"
  },
  {
    "country": "IN",
    "name": "Gua",
    "lat": "22.21361",
    "lng": "85.38774"
  },
  {
    "country": "IN",
    "name": "Goyerkāta",
    "lat": "26.69984",
    "lng": "89.02565"
  },
  {
    "country": "IN",
    "name": "Govindgarh",
    "lat": "27.50423",
    "lng": "76.99938"
  },
  {
    "country": "IN",
    "name": "Govindgarh",
    "lat": "24.37845",
    "lng": "81.29644"
  },
  {
    "country": "IN",
    "name": "Govardhan",
    "lat": "27.49658",
    "lng": "77.46263"
  },
  {
    "country": "IN",
    "name": "Goshaingaon",
    "lat": "26.43946",
    "lng": "89.96307"
  },
  {
    "country": "IN",
    "name": "Goshāīnganj",
    "lat": "26.76793",
    "lng": "81.10752"
  },
  {
    "country": "IN",
    "name": "Goshāinganj",
    "lat": "26.57115",
    "lng": "82.38091"
  },
  {
    "country": "IN",
    "name": "Gosāba",
    "lat": "22.16547",
    "lng": "88.8007"
  },
  {
    "country": "IN",
    "name": "Gorūr",
    "lat": "12.82297",
    "lng": "76.06463"
  },
  {
    "country": "IN",
    "name": "Goregaon",
    "lat": "18.15483",
    "lng": "73.29147"
  },
  {
    "country": "IN",
    "name": "Gorantla",
    "lat": "13.98411",
    "lng": "77.77224"
  },
  {
    "country": "IN",
    "name": "Gorakhpur",
    "lat": "29.44768",
    "lng": "75.67206"
  },
  {
    "country": "IN",
    "name": "Gorakhpur",
    "lat": "26.76628",
    "lng": "83.36889"
  },
  {
    "country": "IN",
    "name": "Gopināthpur",
    "lat": "22.66301",
    "lng": "86.075"
  },
  {
    "country": "IN",
    "name": "Gobichettipalayam",
    "lat": "11.45496",
    "lng": "77.4422"
  },
  {
    "country": "IN",
    "name": "Gopāmau",
    "lat": "27.53468",
    "lng": "80.28507"
  },
  {
    "country": "IN",
    "name": "Gopālur",
    "lat": "16.6122",
    "lng": "77.80728"
  },
  {
    "country": "IN",
    "name": "Gopālpur",
    "lat": "19.25861",
    "lng": "84.90517"
  },
  {
    "country": "IN",
    "name": "Gopālganj",
    "lat": "26.46734",
    "lng": "84.44041"
  },
  {
    "country": "IN",
    "name": "Gondiā",
    "lat": "21.46026",
    "lng": "80.19205"
  },
  {
    "country": "IN",
    "name": "Gondal",
    "lat": "21.96074",
    "lng": "70.80255"
  },
  {
    "country": "IN",
    "name": "Gondā City",
    "lat": "27.13181",
    "lng": "81.95332"
  },
  {
    "country": "IN",
    "name": "Gomoh",
    "lat": "23.87355",
    "lng": "86.1516"
  },
  {
    "country": "IN",
    "name": "Golakganj",
    "lat": "26.10216",
    "lng": "89.82275"
  },
  {
    "country": "IN",
    "name": "Gola Gokarannāth",
    "lat": "28.07837",
    "lng": "80.47054"
  },
  {
    "country": "IN",
    "name": "Golāghāt",
    "lat": "26.51167",
    "lng": "93.95951"
  },
  {
    "country": "IN",
    "name": "Gola Bāzār",
    "lat": "26.3446",
    "lng": "83.35303"
  },
  {
    "country": "IN",
    "name": "Gokul",
    "lat": "27.43926",
    "lng": "77.72019"
  },
  {
    "country": "IN",
    "name": "Gokavaram",
    "lat": "17.25823",
    "lng": "81.84985"
  },
  {
    "country": "IN",
    "name": "Gokarna",
    "lat": "14.55",
    "lng": "74.31667"
  },
  {
    "country": "IN",
    "name": "Gokak",
    "lat": "16.16901",
    "lng": "74.82393"
  },
  {
    "country": "IN",
    "name": "Gohpur",
    "lat": "26.88184",
    "lng": "93.6156"
  },
  {
    "country": "IN",
    "name": "Gohānd",
    "lat": "25.69871",
    "lng": "79.54567"
  },
  {
    "country": "IN",
    "name": "Gohāna",
    "lat": "29.13777",
    "lng": "76.70247"
  },
  {
    "country": "IN",
    "name": "Gohadi",
    "lat": "26.43278",
    "lng": "78.44205"
  },
  {
    "country": "IN",
    "name": "Gogāpur",
    "lat": "23.55746",
    "lng": "75.51665"
  },
  {
    "country": "IN",
    "name": "Godhra",
    "lat": "22.77547",
    "lng": "73.61488"
  },
  {
    "country": "IN",
    "name": "Godda",
    "lat": "24.827",
    "lng": "87.2125"
  },
  {
    "country": "IN",
    "name": "Gobindpur",
    "lat": "23.83556",
    "lng": "86.51853"
  },
  {
    "country": "IN",
    "name": "Gobindpur",
    "lat": "22.63393",
    "lng": "86.07162"
  },
  {
    "country": "IN",
    "name": "Gobārdānga",
    "lat": "22.8774",
    "lng": "88.75479"
  },
  {
    "country": "IN",
    "name": "Goa Velha",
    "lat": "15.44384",
    "lng": "73.88572"
  },
  {
    "country": "IN",
    "name": "Goālpāra",
    "lat": "26.17668",
    "lng": "90.62634"
  },
  {
    "country": "IN",
    "name": "Gīrīdīh",
    "lat": "24.18622",
    "lng": "86.30875"
  },
  {
    "country": "IN",
    "name": "Gingee",
    "lat": "12.25282",
    "lng": "79.41727"
  },
  {
    "country": "IN",
    "name": "Giddarbāha",
    "lat": "30.19953",
    "lng": "74.66627"
  },
  {
    "country": "IN",
    "name": "Giddalūr",
    "lat": "15.37439",
    "lng": "78.92609"
  },
  {
    "country": "IN",
    "name": "Gīdam",
    "lat": "18.97431",
    "lng": "81.39894"
  },
  {
    "country": "IN",
    "name": "Ghugus",
    "lat": "19.9381",
    "lng": "79.11192"
  },
  {
    "country": "IN",
    "name": "Ghoti Budrukh",
    "lat": "19.71641",
    "lng": "73.62821"
  },
  {
    "country": "IN",
    "name": "Ghosī",
    "lat": "26.10587",
    "lng": "83.5393"
  },
  {
    "country": "IN",
    "name": "Ghorāwal",
    "lat": "24.75459",
    "lng": "82.77965"
  },
  {
    "country": "IN",
    "name": "Ghogha",
    "lat": "21.68813",
    "lng": "72.2763"
  },
  {
    "country": "IN",
    "name": "Ghoga",
    "lat": "25.21738",
    "lng": "87.1571"
  },
  {
    "country": "IN",
    "name": "Ghiror",
    "lat": "27.18912",
    "lng": "78.79312"
  },
  {
    "country": "IN",
    "name": "Ghazīpur",
    "lat": "25.58333",
    "lng": "83.58526"
  },
  {
    "country": "IN",
    "name": "Ghāziābād",
    "lat": "28.66535",
    "lng": "77.43915"
  },
  {
    "country": "IN",
    "name": "Ghātsīla",
    "lat": "22.58531",
    "lng": "86.47682"
  },
  {
    "country": "IN",
    "name": "Ghātanji",
    "lat": "20.14183",
    "lng": "78.31333"
  },
  {
    "country": "IN",
    "name": "Ghātampur",
    "lat": "26.15272",
    "lng": "80.16803"
  },
  {
    "country": "IN",
    "name": "Ghātāl",
    "lat": "22.66244",
    "lng": "87.73399"
  },
  {
    "country": "IN",
    "name": "Gharghoda",
    "lat": "22.17427",
    "lng": "83.3517"
  },
  {
    "country": "IN",
    "name": "Gharaunda",
    "lat": "29.53692",
    "lng": "76.97142"
  },
  {
    "country": "IN",
    "name": "Ghansor",
    "lat": "22.65976",
    "lng": "79.95013"
  },
  {
    "country": "IN",
    "name": "Ghanaur",
    "lat": "30.33092",
    "lng": "76.61203"
  },
  {
    "country": "IN",
    "name": "Ghumārwīn",
    "lat": "31.44166",
    "lng": "76.71509"
  },
  {
    "country": "IN",
    "name": "Gevrai",
    "lat": "19.26372",
    "lng": "75.75007"
  },
  {
    "country": "IN",
    "name": "George Town",
    "lat": "13.0926",
    "lng": "80.2801"
  },
  {
    "country": "IN",
    "name": "Gaya",
    "lat": "24.79686",
    "lng": "85.00385"
  },
  {
    "country": "IN",
    "name": "Gawān",
    "lat": "28.41969",
    "lng": "78.35186"
  },
  {
    "country": "IN",
    "name": "Gautampura",
    "lat": "22.98664",
    "lng": "75.51921"
  },
  {
    "country": "IN",
    "name": "Gauripur",
    "lat": "26.08334",
    "lng": "89.96118"
  },
  {
    "country": "IN",
    "name": "Goribidnūr",
    "lat": "13.61072",
    "lng": "77.51738"
  },
  {
    "country": "IN",
    "name": "Gaurela",
    "lat": "22.75449",
    "lng": "81.90107"
  },
  {
    "country": "IN",
    "name": "Guwahati",
    "lat": "26.1844",
    "lng": "91.7458"
  },
  {
    "country": "IN",
    "name": "Garhwa",
    "lat": "24.16002",
    "lng": "83.80755"
  },
  {
    "country": "IN",
    "name": "Garui",
    "lat": "22.63333",
    "lng": "88.4"
  },
  {
    "country": "IN",
    "name": "Gariadhar",
    "lat": "21.53889",
    "lng": "71.57737"
  },
  {
    "country": "IN",
    "name": "Gariāband",
    "lat": "20.63323",
    "lng": "82.06221"
  },
  {
    "country": "IN",
    "name": "Garhshankar",
    "lat": "31.21537",
    "lng": "76.14149"
  },
  {
    "country": "IN",
    "name": "Garhmuktesar",
    "lat": "28.78732",
    "lng": "78.10214"
  },
  {
    "country": "IN",
    "name": "Garhi Pūkhta",
    "lat": "29.5498",
    "lng": "77.30881"
  },
  {
    "country": "IN",
    "name": "Garhākota",
    "lat": "23.7791",
    "lng": "79.14321"
  },
  {
    "country": "IN",
    "name": "Garhdiwāla",
    "lat": "31.74147",
    "lng": "75.75567"
  },
  {
    "country": "IN",
    "name": "Garautha",
    "lat": "25.5719",
    "lng": "79.29764"
  },
  {
    "country": "IN",
    "name": "Gannavaram",
    "lat": "16.54092",
    "lng": "80.80213"
  },
  {
    "country": "IN",
    "name": "Ganj Murādābād",
    "lat": "26.95733",
    "lng": "80.184"
  },
  {
    "country": "IN",
    "name": "Ganjām",
    "lat": "19.38705",
    "lng": "85.05079"
  },
  {
    "country": "IN",
    "name": "Ganguvāda",
    "lat": "18.66667",
    "lng": "84.11667"
  },
  {
    "country": "IN",
    "name": "Gangtok",
    "lat": "27.32574",
    "lng": "88.61216"
  },
  {
    "country": "IN",
    "name": "Gangolli",
    "lat": "13.65024",
    "lng": "74.67072"
  },
  {
    "country": "IN",
    "name": "Gangoh",
    "lat": "29.78004",
    "lng": "77.26346"
  },
  {
    "country": "IN",
    "name": "Gangāwati",
    "lat": "15.4313",
    "lng": "76.52933"
  },
  {
    "country": "IN",
    "name": "Gangavalli",
    "lat": "11.49828",
    "lng": "78.64966"
  },
  {
    "country": "IN",
    "name": "Gangārāmpur",
    "lat": "25.40138",
    "lng": "88.52978"
  },
  {
    "country": "IN",
    "name": "Gangāpur",
    "lat": "26.47249",
    "lng": "76.71744"
  },
  {
    "country": "IN",
    "name": "Gangāpur",
    "lat": "25.21954",
    "lng": "74.26028"
  },
  {
    "country": "IN",
    "name": "Gangāpur",
    "lat": "19.69718",
    "lng": "75.01045"
  },
  {
    "country": "IN",
    "name": "Gangānagar",
    "lat": "29.92009",
    "lng": "73.87496"
  },
  {
    "country": "IN",
    "name": "Gangākher",
    "lat": "18.96962",
    "lng": "76.74946"
  },
  {
    "country": "IN",
    "name": "Gangaikondān",
    "lat": "8.85785",
    "lng": "77.78019"
  },
  {
    "country": "IN",
    "name": "Gāndhī Nagar",
    "lat": "13.00639",
    "lng": "80.25417"
  },
  {
    "country": "IN",
    "name": "Gandhinagar",
    "lat": "23.21667",
    "lng": "72.68333"
  },
  {
    "country": "IN",
    "name": "Gāndhīdhām",
    "lat": "23.08333",
    "lng": "70.13333"
  },
  {
    "country": "IN",
    "name": "Gandevi",
    "lat": "20.81214",
    "lng": "72.99811"
  },
  {
    "country": "IN",
    "name": "Gāndarbal",
    "lat": "34.22619",
    "lng": "74.77478"
  },
  {
    "country": "IN",
    "name": "Gandai",
    "lat": "21.66667",
    "lng": "81.10013"
  },
  {
    "country": "IN",
    "name": "Galiākot",
    "lat": "23.51995",
    "lng": "74.02028"
  },
  {
    "country": "IN",
    "name": "Gajraula",
    "lat": "28.8457",
    "lng": "78.2396"
  },
  {
    "country": "IN",
    "name": "Gajendragarh",
    "lat": "15.73628",
    "lng": "75.96976"
  },
  {
    "country": "IN",
    "name": "Gagret",
    "lat": "31.65846",
    "lng": "76.06144"
  },
  {
    "country": "IN",
    "name": "Gadwāl",
    "lat": "16.23504",
    "lng": "77.79556"
  },
  {
    "country": "IN",
    "name": "Gadhinglaj",
    "lat": "16.22291",
    "lng": "74.3501"
  },
  {
    "country": "IN",
    "name": "Gadhada",
    "lat": "21.96957",
    "lng": "71.57828"
  },
  {
    "country": "IN",
    "name": "Gādarwāra",
    "lat": "22.9235",
    "lng": "78.7849"
  },
  {
    "country": "IN",
    "name": "Gadag",
    "lat": "15.42977",
    "lng": "75.62971"
  },
  {
    "country": "IN",
    "name": "Fort Gloster",
    "lat": "22.50444",
    "lng": "88.18333"
  },
  {
    "country": "IN",
    "name": "Forbesganj",
    "lat": "26.30253",
    "lng": "87.26556"
  },
  {
    "country": "IN",
    "name": "Fīrozpur Jhirka",
    "lat": "27.78853",
    "lng": "76.94496"
  },
  {
    "country": "IN",
    "name": "Ferozepore",
    "lat": "30.92574",
    "lng": "74.61311"
  },
  {
    "country": "IN",
    "name": "Fīrozābād",
    "lat": "27.15092",
    "lng": "78.39781"
  },
  {
    "country": "IN",
    "name": "Ferokh",
    "lat": "11.17989",
    "lng": "75.84141"
  },
  {
    "country": "IN",
    "name": "Fāzilka",
    "lat": "30.40207",
    "lng": "74.02836"
  },
  {
    "country": "IN",
    "name": "Fatwa",
    "lat": "25.50958",
    "lng": "85.30504"
  },
  {
    "country": "IN",
    "name": "Fatehpur Sīkri",
    "lat": "27.0937",
    "lng": "77.66003"
  },
  {
    "country": "IN",
    "name": "Fatehpur Chaurāsi",
    "lat": "26.78925",
    "lng": "80.26547"
  },
  {
    "country": "IN",
    "name": "Fatehpur",
    "lat": "27.99486",
    "lng": "74.95628"
  },
  {
    "country": "IN",
    "name": "Fatehpur",
    "lat": "27.17281",
    "lng": "81.21061"
  },
  {
    "country": "IN",
    "name": "Fatehpur",
    "lat": "25.92774",
    "lng": "80.81266"
  },
  {
    "country": "IN",
    "name": "Fatehgarh Chūriān",
    "lat": "31.86431",
    "lng": "74.95665"
  },
  {
    "country": "IN",
    "name": "Fatehgarh",
    "lat": "27.36409",
    "lng": "79.63111"
  },
  {
    "country": "IN",
    "name": "Fatehganj West",
    "lat": "28.4662",
    "lng": "79.30657"
  },
  {
    "country": "IN",
    "name": "Fatehābād",
    "lat": "29.51525",
    "lng": "75.45554"
  },
  {
    "country": "IN",
    "name": "Fatehābād",
    "lat": "27.02645",
    "lng": "78.3027"
  },
  {
    "country": "IN",
    "name": "Farrukhnagar",
    "lat": "28.44745",
    "lng": "76.82391"
  },
  {
    "country": "IN",
    "name": "Farrukhnagar",
    "lat": "17.07787",
    "lng": "78.20339"
  },
  {
    "country": "IN",
    "name": "Farrukhābād",
    "lat": "27.39134",
    "lng": "79.5793"
  },
  {
    "country": "IN",
    "name": "Farīdpur",
    "lat": "28.20997",
    "lng": "79.54149"
  },
  {
    "country": "IN",
    "name": "Farīdnagar",
    "lat": "28.76923",
    "lng": "77.62934"
  },
  {
    "country": "IN",
    "name": "Farīdkot",
    "lat": "30.67399",
    "lng": "74.75579"
  },
  {
    "country": "IN",
    "name": "Faridabad",
    "lat": "28.41124",
    "lng": "77.31316"
  },
  {
    "country": "IN",
    "name": "Farakka",
    "lat": "24.81667",
    "lng": "87.9"
  },
  {
    "country": "IN",
    "name": "Farah",
    "lat": "27.32081",
    "lng": "77.76185"
  },
  {
    "country": "IN",
    "name": "Fālākāta",
    "lat": "26.51963",
    "lng": "89.20423"
  },
  {
    "country": "IN",
    "name": "Faizpur",
    "lat": "21.16766",
    "lng": "75.86006"
  },
  {
    "country": "IN",
    "name": "Fyzābād",
    "lat": "26.77549",
    "lng": "82.15018"
  },
  {
    "country": "IN",
    "name": "Ettaiyapuram",
    "lat": "9.14405",
    "lng": "77.99066"
  },
  {
    "country": "IN",
    "name": "Etikoppāka",
    "lat": "17.5",
    "lng": "82.73333"
  },
  {
    "country": "IN",
    "name": "Etāwah",
    "lat": "26.77615",
    "lng": "79.02133"
  },
  {
    "country": "IN",
    "name": "Erumaippatti",
    "lat": "11.14671",
    "lng": "78.28996"
  },
  {
    "country": "IN",
    "name": "Erraguntla",
    "lat": "14.63853",
    "lng": "78.53974"
  },
  {
    "country": "IN",
    "name": "Erode",
    "lat": "11.3428",
    "lng": "77.72741"
  },
  {
    "country": "IN",
    "name": "Erāttupetta",
    "lat": "9.68747",
    "lng": "76.77891"
  },
  {
    "country": "IN",
    "name": "Eraniel",
    "lat": "8.20589",
    "lng": "77.31726"
  },
  {
    "country": "IN",
    "name": "Erandol",
    "lat": "20.92206",
    "lng": "75.32641"
  },
  {
    "country": "IN",
    "name": "Eral",
    "lat": "8.62584",
    "lng": "78.02282"
  },
  {
    "country": "IN",
    "name": "Emmiganūr",
    "lat": "15.77203",
    "lng": "77.48345"
  },
  {
    "country": "IN",
    "name": "Ellore",
    "lat": "16.71311",
    "lng": "81.10437"
  },
  {
    "country": "IN",
    "name": "Elūr",
    "lat": "10.06667",
    "lng": "76.28333"
  },
  {
    "country": "IN",
    "name": "Elumalai",
    "lat": "9.86501",
    "lng": "77.69923"
  },
  {
    "country": "IN",
    "name": "Ellenabad",
    "lat": "29.45282",
    "lng": "74.66122"
  },
  {
    "country": "IN",
    "name": "Elāyirampannai",
    "lat": "9.27033",
    "lng": "77.82494"
  },
  {
    "country": "IN",
    "name": "Elamanchili",
    "lat": "17.54907",
    "lng": "82.85749"
  },
  {
    "country": "IN",
    "name": "Egra",
    "lat": "21.89947",
    "lng": "87.53794"
  },
  {
    "country": "IN",
    "name": "Dwārka",
    "lat": "22.23944",
    "lng": "68.96778"
  },
  {
    "country": "IN",
    "name": "Dwārāhāt",
    "lat": "29.77785",
    "lng": "79.42731"
  },
  {
    "country": "IN",
    "name": "Dūsi",
    "lat": "12.77574",
    "lng": "79.67892"
  },
  {
    "country": "IN",
    "name": "Durgapur",
    "lat": "23.51583",
    "lng": "87.30801"
  },
  {
    "country": "IN",
    "name": "Durgāpur",
    "lat": "20.0054",
    "lng": "79.30273"
  },
  {
    "country": "IN",
    "name": "Durg",
    "lat": "21.19147",
    "lng": "81.27619"
  },
  {
    "country": "IN",
    "name": "Dūngarpur",
    "lat": "23.84306",
    "lng": "73.71466"
  },
  {
    "country": "IN",
    "name": "Dungarpur",
    "lat": "21.28777",
    "lng": "71.7556"
  },
  {
    "country": "IN",
    "name": "Ganj Dundwāra",
    "lat": "27.73308",
    "lng": "78.94119"
  },
  {
    "country": "IN",
    "name": "Dumraon",
    "lat": "25.55265",
    "lng": "84.15149"
  },
  {
    "country": "IN",
    "name": "Dumra",
    "lat": "26.56708",
    "lng": "85.5204"
  },
  {
    "country": "IN",
    "name": "Dumka",
    "lat": "24.26778",
    "lng": "87.24855"
  },
  {
    "country": "IN",
    "name": "Dum Duma",
    "lat": "27.56884",
    "lng": "95.55664"
  },
  {
    "country": "IN",
    "name": "Dam Dam",
    "lat": "22.63341",
    "lng": "88.42286"
  },
  {
    "country": "IN",
    "name": "Duliāgaon",
    "lat": "27.37227",
    "lng": "95.30754"
  },
  {
    "country": "IN",
    "name": "Dugda",
    "lat": "23.74516",
    "lng": "86.17175"
  },
  {
    "country": "IN",
    "name": "Dūdhi",
    "lat": "24.21357",
    "lng": "83.24067"
  },
  {
    "country": "IN",
    "name": "Dudhani",
    "lat": "17.35792",
    "lng": "76.36688"
  },
  {
    "country": "IN",
    "name": "Dubrājpur",
    "lat": "23.7902",
    "lng": "87.37648"
  },
  {
    "country": "IN",
    "name": "Dostpur",
    "lat": "26.27486",
    "lng": "82.47091"
  },
  {
    "country": "IN",
    "name": "Dornakal",
    "lat": "17.44475",
    "lng": "80.14905"
  },
  {
    "country": "IN",
    "name": "Dorāha",
    "lat": "30.79953",
    "lng": "76.02355"
  },
  {
    "country": "IN",
    "name": "Dongargarh",
    "lat": "21.18893",
    "lng": "80.75459"
  },
  {
    "country": "IN",
    "name": "Dongargaon",
    "lat": "20.97172",
    "lng": "80.85077"
  },
  {
    "country": "IN",
    "name": "Dondaicha",
    "lat": "21.3236",
    "lng": "74.56804"
  },
  {
    "country": "IN",
    "name": "Dombivli",
    "lat": "19.21667",
    "lng": "73.08333"
  },
  {
    "country": "IN",
    "name": "Doiwāla",
    "lat": "30.17667",
    "lng": "78.11659"
  },
  {
    "country": "IN",
    "name": "Dohrighāt",
    "lat": "26.27217",
    "lng": "83.50916"
  },
  {
    "country": "IN",
    "name": "Dugadda",
    "lat": "29.80673",
    "lng": "78.61109"
  },
  {
    "country": "IN",
    "name": "Dod Ballāpur",
    "lat": "13.29452",
    "lng": "77.53777"
  },
  {
    "country": "IN",
    "name": "Doda",
    "lat": "33.14916",
    "lng": "75.54746"
  },
  {
    "country": "IN",
    "name": "Diu",
    "lat": "20.71405",
    "lng": "70.98224"
  },
  {
    "country": "IN",
    "name": "Dispur",
    "lat": "26.13564",
    "lng": "91.80069"
  },
  {
    "country": "IN",
    "name": "Dīsa",
    "lat": "24.25612",
    "lng": "72.17928"
  },
  {
    "country": "IN",
    "name": "Dirba",
    "lat": "30.07222",
    "lng": "75.99607"
  },
  {
    "country": "IN",
    "name": "Diphu",
    "lat": "25.84341",
    "lng": "93.43116"
  },
  {
    "country": "IN",
    "name": "Dīnhāta",
    "lat": "26.13526",
    "lng": "89.46129"
  },
  {
    "country": "IN",
    "name": "Dindori",
    "lat": "22.94141",
    "lng": "81.07975"
  },
  {
    "country": "IN",
    "name": "Dindigul",
    "lat": "10.36896",
    "lng": "77.98036"
  },
  {
    "country": "IN",
    "name": "Dīnānagar",
    "lat": "32.13664",
    "lng": "75.47291"
  },
  {
    "country": "IN",
    "name": "Dimāpur",
    "lat": "25.91174",
    "lng": "93.7217"
  },
  {
    "country": "IN",
    "name": "Diguvametta",
    "lat": "15.39507",
    "lng": "78.8293"
  },
  {
    "country": "IN",
    "name": "Digras",
    "lat": "20.1035",
    "lng": "77.71846"
  },
  {
    "country": "IN",
    "name": "Dīglūr",
    "lat": "18.54829",
    "lng": "77.57695"
  },
  {
    "country": "IN",
    "name": "Dighwāra",
    "lat": "25.74434",
    "lng": "85.01003"
  },
  {
    "country": "IN",
    "name": "Digha",
    "lat": "21.62776",
    "lng": "87.51965"
  },
  {
    "country": "IN",
    "name": "Digboi",
    "lat": "27.39321",
    "lng": "95.61839"
  },
  {
    "country": "IN",
    "name": "Digapahandi",
    "lat": "19.37275",
    "lng": "84.57184"
  },
  {
    "country": "IN",
    "name": "Dīg",
    "lat": "27.47188",
    "lng": "77.32564"
  },
  {
    "country": "IN",
    "name": "Dīdwāna",
    "lat": "27.40096",
    "lng": "74.57537"
  },
  {
    "country": "IN",
    "name": "Dicholi",
    "lat": "15.59319",
    "lng": "73.94571"
  },
  {
    "country": "IN",
    "name": "Dibrugarh",
    "lat": "27.47989",
    "lng": "94.90837"
  },
  {
    "country": "IN",
    "name": "Dibai",
    "lat": "28.20849",
    "lng": "78.26173"
  },
  {
    "country": "IN",
    "name": "Diamond Harbour",
    "lat": "22.19303",
    "lng": "88.18466"
  },
  {
    "country": "IN",
    "name": "Dhuwaran",
    "lat": "22.23779",
    "lng": "72.7591"
  },
  {
    "country": "IN",
    "name": "Dhūri",
    "lat": "30.36846",
    "lng": "75.86791"
  },
  {
    "country": "IN",
    "name": "Dhupgāri",
    "lat": "26.58904",
    "lng": "89.00732"
  },
  {
    "country": "IN",
    "name": "Dhuliān",
    "lat": "24.68127",
    "lng": "87.9535"
  },
  {
    "country": "IN",
    "name": "Dhūlia",
    "lat": "20.9013",
    "lng": "74.77737"
  },
  {
    "country": "IN",
    "name": "Dhuburi",
    "lat": "26.01856",
    "lng": "89.98564"
  },
  {
    "country": "IN",
    "name": "Dhrol",
    "lat": "22.567",
    "lng": "70.41769"
  },
  {
    "country": "IN",
    "name": "Dhrāngadhra",
    "lat": "22.99167",
    "lng": "71.46793"
  },
  {
    "country": "IN",
    "name": "Dhorāji",
    "lat": "21.73359",
    "lng": "70.45004"
  },
  {
    "country": "IN",
    "name": "Dhone",
    "lat": "15.3952",
    "lng": "77.8715"
  },
  {
    "country": "IN",
    "name": "Dholka",
    "lat": "22.72732",
    "lng": "72.44128"
  },
  {
    "country": "IN",
    "name": "Dhola",
    "lat": "21.88129",
    "lng": "71.77269"
  },
  {
    "country": "IN",
    "name": "Dhing",
    "lat": "26.46793",
    "lng": "92.47336"
  },
  {
    "country": "IN",
    "name": "Dhilwan",
    "lat": "31.51432",
    "lng": "75.34574"
  },
  {
    "country": "IN",
    "name": "Dhenkānāl",
    "lat": "20.65744",
    "lng": "85.59693"
  },
  {
    "country": "IN",
    "name": "Dhemāji",
    "lat": "27.48333",
    "lng": "94.58333"
  },
  {
    "country": "IN",
    "name": "Dhekiajuli",
    "lat": "26.70367",
    "lng": "92.47808"
  },
  {
    "country": "IN",
    "name": "Dhaurahra",
    "lat": "27.99814",
    "lng": "81.08975"
  },
  {
    "country": "IN",
    "name": "Dhaulpur",
    "lat": "26.69286",
    "lng": "77.87968"
  },
  {
    "country": "IN",
    "name": "Dhārūr",
    "lat": "18.82017",
    "lng": "76.10937"
  },
  {
    "country": "IN",
    "name": "Dhāruhera",
    "lat": "28.20553",
    "lng": "76.79691"
  },
  {
    "country": "IN",
    "name": "Dharamsala",
    "lat": "32.22006",
    "lng": "76.32013"
  },
  {
    "country": "IN",
    "name": "Dharmavaram",
    "lat": "14.41435",
    "lng": "77.72035"
  },
  {
    "country": "IN",
    "name": "Dharmapuri",
    "lat": "12.1277",
    "lng": "78.15794"
  },
  {
    "country": "IN",
    "name": "Dharmanagar",
    "lat": "24.36667",
    "lng": "92.16667"
  },
  {
    "country": "IN",
    "name": "Dharmadam",
    "lat": "11.77538",
    "lng": "75.46459"
  },
  {
    "country": "IN",
    "name": "Dharmābād",
    "lat": "18.89116",
    "lng": "77.8494"
  },
  {
    "country": "IN",
    "name": "Dhāriwāl",
    "lat": "31.95616",
    "lng": "75.32386"
  },
  {
    "country": "IN",
    "name": "Dhāri",
    "lat": "21.32855",
    "lng": "71.02645"
  },
  {
    "country": "IN",
    "name": "Dhārchula",
    "lat": "29.84707",
    "lng": "80.51951"
  },
  {
    "country": "IN",
    "name": "Dharapuram",
    "lat": "10.73828",
    "lng": "77.53223"
  },
  {
    "country": "IN",
    "name": "Dharangaon",
    "lat": "21.01187",
    "lng": "75.27407"
  },
  {
    "country": "IN",
    "name": "Dharampuri",
    "lat": "22.14951",
    "lng": "75.34439"
  },
  {
    "country": "IN",
    "name": "Dharampur",
    "lat": "20.53693",
    "lng": "73.17368"
  },
  {
    "country": "IN",
    "name": "Dhār",
    "lat": "22.59373",
    "lng": "75.29774"
  },
  {
    "country": "IN",
    "name": "Dhanwār",
    "lat": "24.41074",
    "lng": "85.98183"
  },
  {
    "country": "IN",
    "name": "Dhanera",
    "lat": "24.50967",
    "lng": "72.02343"
  },
  {
    "country": "IN",
    "name": "Dhandhuka",
    "lat": "22.38185",
    "lng": "71.98664"
  },
  {
    "country": "IN",
    "name": "Dhanbād",
    "lat": "23.80199",
    "lng": "86.44324"
  },
  {
    "country": "IN",
    "name": "Dhanaura",
    "lat": "28.95912",
    "lng": "78.25629"
  },
  {
    "country": "IN",
    "name": "Dhanaula",
    "lat": "30.28216",
    "lng": "75.57341"
  },
  {
    "country": "IN",
    "name": "Dhāna",
    "lat": "23.74697",
    "lng": "78.86234"
  },
  {
    "country": "IN",
    "name": "Dhamtari",
    "lat": "20.70718",
    "lng": "81.54874"
  },
  {
    "country": "IN",
    "name": "Dhāmpur",
    "lat": "29.30883",
    "lng": "78.51083"
  },
  {
    "country": "IN",
    "name": "Dhāmnod",
    "lat": "22.20928",
    "lng": "75.47057"
  },
  {
    "country": "IN",
    "name": "Dhali",
    "lat": "10.51049",
    "lng": "77.18806"
  },
  {
    "country": "IN",
    "name": "Dhāka",
    "lat": "26.67479",
    "lng": "85.16698"
  },
  {
    "country": "IN",
    "name": "Dewas",
    "lat": "22.96585",
    "lng": "76.05526"
  },
  {
    "country": "IN",
    "name": "Dewā",
    "lat": "27.03621",
    "lng": "81.16692"
  },
  {
    "country": "IN",
    "name": "Deoli",
    "lat": "25.75728",
    "lng": "75.37991"
  },
  {
    "country": "IN",
    "name": "Devgarh",
    "lat": "25.52533",
    "lng": "73.90812"
  },
  {
    "country": "IN",
    "name": "Devgadh Bāriya",
    "lat": "22.70517",
    "lng": "73.90882"
  },
  {
    "country": "IN",
    "name": "Devarkonda",
    "lat": "16.69186",
    "lng": "78.92073"
  },
  {
    "country": "IN",
    "name": "Devaprayāg",
    "lat": "30.14603",
    "lng": "78.60272"
  },
  {
    "country": "IN",
    "name": "Devanhalli",
    "lat": "13.24655",
    "lng": "77.71183"
  },
  {
    "country": "IN",
    "name": "Devakottai",
    "lat": "9.94704",
    "lng": "78.8233"
  },
  {
    "country": "IN",
    "name": "Devadānappatti",
    "lat": "10.14673",
    "lng": "77.6439"
  },
  {
    "country": "IN",
    "name": "Deūlgaon Rāja",
    "lat": "20.01757",
    "lng": "76.03755"
  },
  {
    "country": "IN",
    "name": "Desūr",
    "lat": "12.43727",
    "lng": "79.48145"
  },
  {
    "country": "IN",
    "name": "Deshnoke",
    "lat": "27.79836",
    "lng": "73.34297"
  },
  {
    "country": "IN",
    "name": "Dergaon",
    "lat": "26.7",
    "lng": "93.96667"
  },
  {
    "country": "IN",
    "name": "Dera Gopipur",
    "lat": "31.87919",
    "lng": "76.21871"
  },
  {
    "country": "IN",
    "name": "Derā Nānak",
    "lat": "32.03733",
    "lng": "75.02787"
  },
  {
    "country": "IN",
    "name": "Depālpur",
    "lat": "22.85095",
    "lng": "75.54224"
  },
  {
    "country": "IN",
    "name": "Deori Khās",
    "lat": "23.39017",
    "lng": "79.0163"
  },
  {
    "country": "IN",
    "name": "Deoria",
    "lat": "26.50167",
    "lng": "83.77936"
  },
  {
    "country": "IN",
    "name": "Deori",
    "lat": "21.45",
    "lng": "82.61667"
  },
  {
    "country": "IN",
    "name": "Deoraniān",
    "lat": "28.62989",
    "lng": "79.47648"
  },
  {
    "country": "IN",
    "name": "Deoli",
    "lat": "20.6492",
    "lng": "78.48023"
  },
  {
    "country": "IN",
    "name": "Deolāli",
    "lat": "19.94404",
    "lng": "73.83441"
  },
  {
    "country": "IN",
    "name": "Deogarh",
    "lat": "21.53827",
    "lng": "84.73337"
  },
  {
    "country": "IN",
    "name": "Deoband",
    "lat": "29.69505",
    "lng": "77.67964"
  },
  {
    "country": "IN",
    "name": "Denkanikota",
    "lat": "12.5301",
    "lng": "77.78887"
  },
  {
    "country": "IN",
    "name": "Delvāda",
    "lat": "20.77544",
    "lng": "71.04646"
  },
  {
    "country": "IN",
    "name": "Delhi",
    "lat": "28.65195",
    "lng": "77.23149"
  },
  {
    "country": "IN",
    "name": "Dehu",
    "lat": "18.71851",
    "lng": "73.76635"
  },
  {
    "country": "IN",
    "name": "Dehri",
    "lat": "24.90247",
    "lng": "84.18217"
  },
  {
    "country": "IN",
    "name": "Dehra Dūn",
    "lat": "30.32443",
    "lng": "78.03392"
  },
  {
    "country": "IN",
    "name": "Debīpur",
    "lat": "24.25029",
    "lng": "88.61824"
  },
  {
    "country": "IN",
    "name": "Dayāl Bāgh",
    "lat": "27.22122",
    "lng": "78.01095"
  },
  {
    "country": "IN",
    "name": "Davorlim",
    "lat": "15.27221",
    "lng": "73.99242"
  },
  {
    "country": "IN",
    "name": "Davangere",
    "lat": "14.46693",
    "lng": "75.92694"
  },
  {
    "country": "IN",
    "name": "Dausa",
    "lat": "26.89",
    "lng": "76.33584"
  },
  {
    "country": "IN",
    "name": "Daurāla",
    "lat": "29.11344",
    "lng": "77.70467"
  },
  {
    "country": "IN",
    "name": "Daund",
    "lat": "18.46515",
    "lng": "74.58375"
  },
  {
    "country": "IN",
    "name": "Daulatpur",
    "lat": "32.05622",
    "lng": "76.26101"
  },
  {
    "country": "IN",
    "name": "Daulatpur",
    "lat": "31.78871",
    "lng": "75.99154"
  },
  {
    "country": "IN",
    "name": "Daulatpur",
    "lat": "25.32605",
    "lng": "88.32989"
  },
  {
    "country": "IN",
    "name": "Daulatābād",
    "lat": "19.93611",
    "lng": "75.22148"
  },
  {
    "country": "IN",
    "name": "Daudnagar",
    "lat": "25.03473",
    "lng": "84.40095"
  },
  {
    "country": "IN",
    "name": "Dattāpur",
    "lat": "20.78075",
    "lng": "78.1407"
  },
  {
    "country": "IN",
    "name": "Datia",
    "lat": "25.67312",
    "lng": "78.45908"
  },
  {
    "country": "IN",
    "name": "Dātāganj",
    "lat": "28.0253",
    "lng": "79.40819"
  },
  {
    "country": "IN",
    "name": "Dasūya",
    "lat": "31.81679",
    "lng": "75.6531"
  },
  {
    "country": "IN",
    "name": "Dāsna",
    "lat": "28.67736",
    "lng": "77.52252"
  },
  {
    "country": "IN",
    "name": "Daryāpur",
    "lat": "20.92489",
    "lng": "77.32644"
  },
  {
    "country": "IN",
    "name": "Dārwha",
    "lat": "20.31017",
    "lng": "77.77257"
  },
  {
    "country": "IN",
    "name": "Darsi",
    "lat": "15.76978",
    "lng": "79.67939"
  },
  {
    "country": "IN",
    "name": "Darlawn",
    "lat": "24.01336",
    "lng": "92.92439"
  },
  {
    "country": "IN",
    "name": "Dārjiling",
    "lat": "27.03333",
    "lng": "88.26667"
  },
  {
    "country": "IN",
    "name": "Dariba",
    "lat": "24.94865",
    "lng": "74.1342"
  },
  {
    "country": "IN",
    "name": "Darbhanga",
    "lat": "26.15216",
    "lng": "85.89707"
  },
  {
    "country": "IN",
    "name": "Dankaur",
    "lat": "28.35121",
    "lng": "77.55508"
  },
  {
    "country": "IN",
    "name": "Dandeli",
    "lat": "15.26667",
    "lng": "74.61667"
  },
  {
    "country": "IN",
    "name": "Dinapore",
    "lat": "25.63705",
    "lng": "85.04794"
  },
  {
    "country": "IN",
    "name": "Damoh",
    "lat": "23.83312",
    "lng": "79.4419"
  },
  {
    "country": "IN",
    "name": "Dāmnagar",
    "lat": "21.69232",
    "lng": "71.51747"
  },
  {
    "country": "IN",
    "name": "Daman",
    "lat": "20.41431",
    "lng": "72.83236"
  },
  {
    "country": "IN",
    "name": "Daltonganj",
    "lat": "24.03971",
    "lng": "84.0658"
  },
  {
    "country": "IN",
    "name": "Dalsingh Sarai",
    "lat": "25.66795",
    "lng": "85.83636"
  },
  {
    "country": "IN",
    "name": "Dalmau",
    "lat": "26.06477",
    "lng": "81.0298"
  },
  {
    "country": "IN",
    "name": "Dalkola",
    "lat": "25.87577",
    "lng": "87.84009"
  },
  {
    "country": "IN",
    "name": "Dalhousie",
    "lat": "32.55219",
    "lng": "75.94663"
  },
  {
    "country": "IN",
    "name": "Dākor",
    "lat": "22.75268",
    "lng": "73.14967"
  },
  {
    "country": "IN",
    "name": "Daitari",
    "lat": "21.1",
    "lng": "85.75"
  },
  {
    "country": "IN",
    "name": "Dohad",
    "lat": "22.83283",
    "lng": "74.25986"
  },
  {
    "country": "IN",
    "name": "Dahegām",
    "lat": "23.16903",
    "lng": "72.82161"
  },
  {
    "country": "IN",
    "name": "Dāhānu",
    "lat": "19.96778",
    "lng": "72.71263"
  },
  {
    "country": "IN",
    "name": "Dagshai",
    "lat": "30.88431",
    "lng": "77.05228"
  },
  {
    "country": "IN",
    "name": "Dādri",
    "lat": "28.55257",
    "lng": "77.55403"
  },
  {
    "country": "IN",
    "name": "Dadra",
    "lat": "20.32504",
    "lng": "72.96618"
  },
  {
    "country": "IN",
    "name": "Dabwāli",
    "lat": "29.94906",
    "lng": "74.73832"
  },
  {
    "country": "IN",
    "name": "Dabra",
    "lat": "25.88572",
    "lng": "78.33221"
  },
  {
    "country": "IN",
    "name": "Daboh",
    "lat": "26.00239",
    "lng": "78.87658"
  },
  {
    "country": "IN",
    "name": "Dābhol",
    "lat": "17.58971",
    "lng": "73.18001"
  },
  {
    "country": "IN",
    "name": "Dabhoi",
    "lat": "22.18333",
    "lng": "73.43333"
  },
  {
    "country": "IN",
    "name": "Cuttack",
    "lat": "20.46497",
    "lng": "85.87927"
  },
  {
    "country": "IN",
    "name": "Curti",
    "lat": "15.41667",
    "lng": "74.01667"
  },
  {
    "country": "IN",
    "name": "Curchorem",
    "lat": "15.26349",
    "lng": "74.10875"
  },
  {
    "country": "IN",
    "name": "Cuncolim",
    "lat": "15.1773",
    "lng": "73.99392"
  },
  {
    "country": "IN",
    "name": "Cumbum",
    "lat": "15.58171",
    "lng": "79.11059"
  },
  {
    "country": "IN",
    "name": "Cuddapah",
    "lat": "14.47995",
    "lng": "78.82346"
  },
  {
    "country": "IN",
    "name": "Cuddalore",
    "lat": "11.75617",
    "lng": "79.76693"
  },
  {
    "country": "IN",
    "name": "Cortalim",
    "lat": "15.40247",
    "lng": "73.90881"
  },
  {
    "country": "IN",
    "name": "Coondapoor",
    "lat": "13.63126",
    "lng": "74.6902"
  },
  {
    "country": "IN",
    "name": "Colva",
    "lat": "15.27976",
    "lng": "73.92285"
  },
  {
    "country": "IN",
    "name": "Colovale",
    "lat": "15.63522",
    "lng": "73.82426"
  },
  {
    "country": "IN",
    "name": "Colonelganj",
    "lat": "27.13432",
    "lng": "81.69868"
  },
  {
    "country": "IN",
    "name": "Colgong",
    "lat": "25.26328",
    "lng": "87.23264"
  },
  {
    "country": "IN",
    "name": "Calangute",
    "lat": "15.5439",
    "lng": "73.7553"
  },
  {
    "country": "IN",
    "name": "Coimbatore",
    "lat": "11.00555",
    "lng": "76.96612"
  },
  {
    "country": "IN",
    "name": "Cochin",
    "lat": "9.93988",
    "lng": "76.26022"
  },
  {
    "country": "IN",
    "name": "Clement Town",
    "lat": "30.26361",
    "lng": "78.00862"
  },
  {
    "country": "IN",
    "name": "Chūru",
    "lat": "28.30415",
    "lng": "74.96718"
  },
  {
    "country": "IN",
    "name": "Churāchāndpur",
    "lat": "24.33353",
    "lng": "93.66999"
  },
  {
    "country": "IN",
    "name": "Chunār",
    "lat": "25.12776",
    "lng": "82.8821"
  },
  {
    "country": "IN",
    "name": "Vikāsnagar",
    "lat": "30.46944",
    "lng": "77.77275"
  },
  {
    "country": "IN",
    "name": "Chuāri Khās",
    "lat": "32.43058",
    "lng": "76.01428"
  },
  {
    "country": "IN",
    "name": "Chotila",
    "lat": "22.42347",
    "lng": "71.19641"
  },
  {
    "country": "IN",
    "name": "Chorhat",
    "lat": "24.42743",
    "lng": "81.66948"
  },
  {
    "country": "IN",
    "name": "Chopda",
    "lat": "21.24578",
    "lng": "75.29946"
  },
  {
    "country": "IN",
    "name": "Chopan",
    "lat": "24.51954",
    "lng": "83.02287"
  },
  {
    "country": "IN",
    "name": "Cholapuram",
    "lat": "9.35193",
    "lng": "77.56839"
  },
  {
    "country": "IN",
    "name": "Chodavaram",
    "lat": "17.82884",
    "lng": "82.93526"
  },
  {
    "country": "IN",
    "name": "Rampachodavaram",
    "lat": "17.44088",
    "lng": "81.77558"
  },
  {
    "country": "IN",
    "name": "Chittūr",
    "lat": "10.69967",
    "lng": "76.7471"
  },
  {
    "country": "IN",
    "name": "Chittoor",
    "lat": "13.21055",
    "lng": "79.0956"
  },
  {
    "country": "IN",
    "name": "Chittaurgarh",
    "lat": "24.88963",
    "lng": "74.62403"
  },
  {
    "country": "IN",
    "name": "Chittaranjan",
    "lat": "23.85681",
    "lng": "86.90324"
  },
  {
    "country": "IN",
    "name": "Chittarkonda",
    "lat": "18.12533",
    "lng": "82.1089"
  },
  {
    "country": "IN",
    "name": "Chitradurga",
    "lat": "14.22262",
    "lng": "76.40038"
  },
  {
    "country": "IN",
    "name": "Chītāpur",
    "lat": "17.12357",
    "lng": "77.0824"
  },
  {
    "country": "IN",
    "name": "Chiria",
    "lat": "22.31093",
    "lng": "85.27601"
  },
  {
    "country": "IN",
    "name": "Chirgaon",
    "lat": "25.57198",
    "lng": "78.81432"
  },
  {
    "country": "IN",
    "name": "Chidawa",
    "lat": "28.23937",
    "lng": "75.64035"
  },
  {
    "country": "IN",
    "name": "Chīrāla",
    "lat": "15.82385",
    "lng": "80.35219"
  },
  {
    "country": "IN",
    "name": "Chīpurupalle",
    "lat": "18.31142",
    "lng": "83.56846"
  },
  {
    "country": "IN",
    "name": "Chiplūn",
    "lat": "17.53339",
    "lng": "73.50935"
  },
  {
    "country": "IN",
    "name": "Chintāmani",
    "lat": "13.40051",
    "lng": "78.05172"
  },
  {
    "country": "IN",
    "name": "Chinna Salem",
    "lat": "11.63422",
    "lng": "78.87412"
  },
  {
    "country": "IN",
    "name": "Chinnamanūr",
    "lat": "9.83999",
    "lng": "77.38109"
  },
  {
    "country": "IN",
    "name": "Chincholi",
    "lat": "17.46508",
    "lng": "77.41874"
  },
  {
    "country": "IN",
    "name": "Chinchinim",
    "lat": "15.21447",
    "lng": "73.97555"
  },
  {
    "country": "IN",
    "name": "Chinchani",
    "lat": "19.87458",
    "lng": "72.6851"
  },
  {
    "country": "IN",
    "name": "Chillupār",
    "lat": "26.28221",
    "lng": "83.5064"
  },
  {
    "country": "IN",
    "name": "Chilakalūrupet",
    "lat": "16.08987",
    "lng": "80.16705"
  },
  {
    "country": "IN",
    "name": "Chikodi",
    "lat": "16.42898",
    "lng": "74.58591"
  },
  {
    "country": "IN",
    "name": "Chiknāyakanhalli",
    "lat": "13.41609",
    "lng": "76.62063"
  },
  {
    "country": "IN",
    "name": "Chikmagalūr",
    "lat": "13.32231",
    "lng": "75.774"
  },
  {
    "country": "IN",
    "name": "Chikitigarh",
    "lat": "19.20233",
    "lng": "84.6145"
  },
  {
    "country": "IN",
    "name": "Chikhli",
    "lat": "20.75751",
    "lng": "73.06268"
  },
  {
    "country": "IN",
    "name": "Chikhli",
    "lat": "20.35046",
    "lng": "76.25774"
  },
  {
    "country": "IN",
    "name": "Chik Ballāpur",
    "lat": "13.43512",
    "lng": "77.72787"
  },
  {
    "country": "IN",
    "name": "Chidambaram",
    "lat": "11.39933",
    "lng": "79.69144"
  },
  {
    "country": "IN",
    "name": "Chicholi",
    "lat": "21.46926",
    "lng": "79.70151"
  },
  {
    "country": "IN",
    "name": "Chichli",
    "lat": "22.83363",
    "lng": "78.82611"
  },
  {
    "country": "IN",
    "name": "Chicalim",
    "lat": "15.39835",
    "lng": "73.84216"
  },
  {
    "country": "IN",
    "name": "Chhuīkhadān",
    "lat": "21.52316",
    "lng": "80.99788"
  },
  {
    "country": "IN",
    "name": "Chhoti Sādri",
    "lat": "24.38145",
    "lng": "74.7012"
  },
  {
    "country": "IN",
    "name": "Chhota Udepur",
    "lat": "22.30401",
    "lng": "74.0158"
  },
  {
    "country": "IN",
    "name": "Chhindwāra",
    "lat": "22.05697",
    "lng": "78.93958"
  },
  {
    "country": "IN",
    "name": "Chhibrāmau",
    "lat": "27.14872",
    "lng": "79.50078"
  },
  {
    "country": "IN",
    "name": "Chhatarpur",
    "lat": "24.9177",
    "lng": "79.58871"
  },
  {
    "country": "IN",
    "name": "Chhātāpur",
    "lat": "26.21965",
    "lng": "87.00479"
  },
  {
    "country": "IN",
    "name": "Chhāta",
    "lat": "27.72374",
    "lng": "77.5081"
  },
  {
    "country": "IN",
    "name": "Chharra",
    "lat": "27.9247",
    "lng": "78.40102"
  },
  {
    "country": "IN",
    "name": "Chhaprauli",
    "lat": "29.20989",
    "lng": "77.17454"
  },
  {
    "country": "IN",
    "name": "Chāpra",
    "lat": "25.78031",
    "lng": "84.74709"
  },
  {
    "country": "IN",
    "name": "Chhāpar",
    "lat": "27.819",
    "lng": "74.43936"
  },
  {
    "country": "IN",
    "name": "Chhala",
    "lat": "23.30779",
    "lng": "72.77404"
  },
  {
    "country": "IN",
    "name": "Chhachhrauli",
    "lat": "30.24492",
    "lng": "77.36027"
  },
  {
    "country": "IN",
    "name": "Chhabra",
    "lat": "24.66472",
    "lng": "76.84379"
  },
  {
    "country": "IN",
    "name": "Cheyyur",
    "lat": "12.34948",
    "lng": "80.00304"
  },
  {
    "country": "IN",
    "name": "Chettipālaiyam",
    "lat": "10.91248",
    "lng": "77.03699"
  },
  {
    "country": "IN",
    "name": "Chetput",
    "lat": "13.07",
    "lng": "80.24083"
  },
  {
    "country": "IN",
    "name": "Cherrapunji",
    "lat": "25.30089",
    "lng": "91.69619"
  },
  {
    "country": "IN",
    "name": "Chennimalai",
    "lat": "11.16378",
    "lng": "77.60388"
  },
  {
    "country": "IN",
    "name": "Chengannūr",
    "lat": "9.31575",
    "lng": "76.61513"
  },
  {
    "country": "IN",
    "name": "Chengam",
    "lat": "12.30889",
    "lng": "78.79137"
  },
  {
    "country": "IN",
    "name": "Chingleput",
    "lat": "12.69184",
    "lng": "79.97661"
  },
  {
    "country": "IN",
    "name": "Chēlakara",
    "lat": "10.69289",
    "lng": "76.34387"
  },
  {
    "country": "IN",
    "name": "Chechat",
    "lat": "24.76667",
    "lng": "75.88333"
  },
  {
    "country": "IN",
    "name": "Chetwayi",
    "lat": "10.52885",
    "lng": "76.04793"
  },
  {
    "country": "IN",
    "name": "Chaupāl",
    "lat": "30.94647",
    "lng": "77.5884"
  },
  {
    "country": "IN",
    "name": "Chaksu",
    "lat": "26.6051",
    "lng": "75.94814"
  },
  {
    "country": "IN",
    "name": "Chatrapur",
    "lat": "19.35574",
    "lng": "84.98359"
  },
  {
    "country": "IN",
    "name": "Chatrā",
    "lat": "24.20645",
    "lng": "84.87085"
  },
  {
    "country": "IN",
    "name": "Chātakonda",
    "lat": "17.55303",
    "lng": "80.6477"
  },
  {
    "country": "IN",
    "name": "Chās",
    "lat": "23.63556",
    "lng": "86.16712"
  },
  {
    "country": "IN",
    "name": "Charthāwal",
    "lat": "29.54687",
    "lng": "77.59438"
  },
  {
    "country": "IN",
    "name": "Charkhi Dādri",
    "lat": "28.59166",
    "lng": "76.27161"
  },
  {
    "country": "IN",
    "name": "Charkhāri",
    "lat": "25.40304",
    "lng": "79.74877"
  },
  {
    "country": "IN",
    "name": "Chāpar",
    "lat": "26.27266",
    "lng": "90.44556"
  },
  {
    "country": "IN",
    "name": "Channarāyapatna",
    "lat": "12.90642",
    "lng": "76.38775"
  },
  {
    "country": "IN",
    "name": "Channapatna",
    "lat": "12.65143",
    "lng": "77.20672"
  },
  {
    "country": "IN",
    "name": "Channagiri",
    "lat": "14.02399",
    "lng": "75.92577"
  },
  {
    "country": "IN",
    "name": "Changanācheri",
    "lat": "9.44203",
    "lng": "76.53604"
  },
  {
    "country": "IN",
    "name": "Chāndor",
    "lat": "20.3306",
    "lng": "74.24467"
  },
  {
    "country": "IN",
    "name": "Chāndūr Bāzār",
    "lat": "21.23853",
    "lng": "77.74713"
  },
  {
    "country": "IN",
    "name": "Chāndūr",
    "lat": "20.81408",
    "lng": "77.98015"
  },
  {
    "country": "IN",
    "name": "Chāndur",
    "lat": "19.73444",
    "lng": "79.17167"
  },
  {
    "country": "IN",
    "name": "Chānda",
    "lat": "19.95076",
    "lng": "79.29523"
  },
  {
    "country": "IN",
    "name": "Chandrakona",
    "lat": "22.73333",
    "lng": "87.51667"
  },
  {
    "country": "IN",
    "name": "Chāndpur",
    "lat": "29.13489",
    "lng": "78.27187"
  },
  {
    "country": "IN",
    "name": "Chandla",
    "lat": "25.07148",
    "lng": "80.19294"
  },
  {
    "country": "IN",
    "name": "Chāndil",
    "lat": "22.95745",
    "lng": "86.05331"
  },
  {
    "country": "IN",
    "name": "Chandigarh",
    "lat": "30.73629",
    "lng": "76.7884"
  },
  {
    "country": "IN",
    "name": "Chandia",
    "lat": "23.65647",
    "lng": "80.70911"
  },
  {
    "country": "IN",
    "name": "Chanderi",
    "lat": "24.71312",
    "lng": "78.13809"
  },
  {
    "country": "IN",
    "name": "Chāndbāli",
    "lat": "20.77519",
    "lng": "86.74139"
  },
  {
    "country": "IN",
    "name": "Chanduasi",
    "lat": "28.45178",
    "lng": "78.78277"
  },
  {
    "country": "IN",
    "name": "Chandauli",
    "lat": "25.25803",
    "lng": "83.26825"
  },
  {
    "country": "IN",
    "name": "Chandannagar",
    "lat": "22.86225",
    "lng": "88.36796"
  },
  {
    "country": "IN",
    "name": "Chānasma",
    "lat": "23.71472",
    "lng": "72.11279"
  },
  {
    "country": "IN",
    "name": "Chamrajnagar",
    "lat": "11.92312",
    "lng": "76.93949"
  },
  {
    "country": "IN",
    "name": "Chāmpua",
    "lat": "22.06734",
    "lng": "85.66463"
  },
  {
    "country": "IN",
    "name": "Champawat",
    "lat": "29.33501",
    "lng": "80.07783"
  },
  {
    "country": "IN",
    "name": "Chāmpāhāti",
    "lat": "22.40026",
    "lng": "88.49209"
  },
  {
    "country": "IN",
    "name": "Chāmpa",
    "lat": "22.03532",
    "lng": "82.64234"
  },
  {
    "country": "IN",
    "name": "Chamba",
    "lat": "32.55531",
    "lng": "76.12647"
  },
  {
    "country": "IN",
    "name": "Challapalle",
    "lat": "16.11756",
    "lng": "80.93139"
  },
  {
    "country": "IN",
    "name": "Challakere",
    "lat": "14.318",
    "lng": "76.65165"
  },
  {
    "country": "IN",
    "name": "Chālisgaon",
    "lat": "20.45781",
    "lng": "75.01596"
  },
  {
    "country": "IN",
    "name": "Chalāla",
    "lat": "21.41073",
    "lng": "71.16621"
  },
  {
    "country": "IN",
    "name": "Chākuliā",
    "lat": "22.48301",
    "lng": "86.71793"
  },
  {
    "country": "IN",
    "name": "Chakrāta",
    "lat": "30.70369",
    "lng": "77.86386"
  },
  {
    "country": "IN",
    "name": "Chakradharpur",
    "lat": "22.67611",
    "lng": "85.62892"
  },
  {
    "country": "IN",
    "name": "Chaklāsi",
    "lat": "22.6532",
    "lng": "72.94497"
  },
  {
    "country": "IN",
    "name": "Chākia",
    "lat": "26.41598",
    "lng": "85.04665"
  },
  {
    "country": "IN",
    "name": "Chakia",
    "lat": "25.04891",
    "lng": "83.22155"
  },
  {
    "country": "IN",
    "name": "Chākan",
    "lat": "18.76059",
    "lng": "73.86351"
  },
  {
    "country": "IN",
    "name": "Chail",
    "lat": "25.42654",
    "lng": "81.63198"
  },
  {
    "country": "IN",
    "name": "Chāībāsa",
    "lat": "22.55038",
    "lng": "85.80249"
  },
  {
    "country": "IN",
    "name": "Chābua",
    "lat": "27.48253",
    "lng": "95.17451"
  },
  {
    "country": "IN",
    "name": "Cavelossim",
    "lat": "15.17255",
    "lng": "73.94194"
  },
  {
    "country": "IN",
    "name": "Carapur",
    "lat": "15.56588",
    "lng": "73.98713"
  },
  {
    "country": "IN",
    "name": "Canning",
    "lat": "22.31453",
    "lng": "88.66248"
  },
  {
    "country": "IN",
    "name": "Kannur",
    "lat": "11.86752",
    "lng": "75.35763"
  },
  {
    "country": "IN",
    "name": "Candolim",
    "lat": "15.51807",
    "lng": "73.76259"
  },
  {
    "country": "IN",
    "name": "Kolkata",
    "lat": "22.56263",
    "lng": "88.36304"
  },
  {
    "country": "IN",
    "name": "Byādgi",
    "lat": "14.67325",
    "lng": "75.4868"
  },
  {
    "country": "IN",
    "name": "Buxar",
    "lat": "25.57548",
    "lng": "83.98043"
  },
  {
    "country": "IN",
    "name": "Burla",
    "lat": "21.50976",
    "lng": "83.87259"
  },
  {
    "country": "IN",
    "name": "Būriya",
    "lat": "30.15911",
    "lng": "77.35814"
  },
  {
    "country": "IN",
    "name": "Burhar",
    "lat": "23.21494",
    "lng": "81.53204"
  },
  {
    "country": "IN",
    "name": "Burhānpur",
    "lat": "21.30868",
    "lng": "76.23026"
  },
  {
    "country": "IN",
    "name": "Būndu",
    "lat": "23.16095",
    "lng": "85.59007"
  },
  {
    "country": "IN",
    "name": "Būndi",
    "lat": "25.43855",
    "lng": "75.63735"
  },
  {
    "country": "IN",
    "name": "Buldāna",
    "lat": "20.52933",
    "lng": "76.18457"
  },
  {
    "country": "IN",
    "name": "Bulandshahr",
    "lat": "28.40392",
    "lng": "77.85773"
  },
  {
    "country": "IN",
    "name": "Buguda",
    "lat": "19.80806",
    "lng": "84.79084"
  },
  {
    "country": "IN",
    "name": "Budhlāda",
    "lat": "29.92799",
    "lng": "75.56205"
  },
  {
    "country": "IN",
    "name": "Budhāna",
    "lat": "29.28805",
    "lng": "77.47534"
  },
  {
    "country": "IN",
    "name": "Budaun",
    "lat": "28.03811",
    "lng": "79.12668"
  },
  {
    "country": "IN",
    "name": "Brājarājnagar",
    "lat": "21.81667",
    "lng": "83.91667"
  },
  {
    "country": "IN",
    "name": "Brahmapur",
    "lat": "19.31151",
    "lng": "84.7929"
  },
  {
    "country": "IN",
    "name": "Botād",
    "lat": "22.16917",
    "lng": "71.66671"
  },
  {
    "country": "IN",
    "name": "Borsad",
    "lat": "22.40788",
    "lng": "72.89817"
  },
  {
    "country": "IN",
    "name": "Borivli",
    "lat": "19.23496",
    "lng": "72.85976"
  },
  {
    "country": "IN",
    "name": "Bongaigaon",
    "lat": "26.47703",
    "lng": "90.55815"
  },
  {
    "country": "IN",
    "name": "Bomdila",
    "lat": "27.26475",
    "lng": "92.42472"
  },
  {
    "country": "IN",
    "name": "Mumbai",
    "lat": "19.07283",
    "lng": "72.88261"
  },
  {
    "country": "IN",
    "name": "Bolpur",
    "lat": "23.66278",
    "lng": "87.69695"
  },
  {
    "country": "IN",
    "name": "Bolānīkhodān",
    "lat": "22.11312",
    "lng": "85.33645"
  },
  {
    "country": "IN",
    "name": "Bokāro",
    "lat": "23.78707",
    "lng": "85.95644"
  },
  {
    "country": "IN",
    "name": "Bokākhāt",
    "lat": "26.64018",
    "lng": "93.60052"
  },
  {
    "country": "IN",
    "name": "Bokajān",
    "lat": "26.02131",
    "lng": "93.77945"
  },
  {
    "country": "IN",
    "name": "Boisar",
    "lat": "19.80362",
    "lng": "72.75598"
  },
  {
    "country": "IN",
    "name": "Bodri",
    "lat": "23.16524",
    "lng": "81.43262"
  },
  {
    "country": "IN",
    "name": "Bodināyakkanūr",
    "lat": "10.01171",
    "lng": "77.34976"
  },
  {
    "country": "IN",
    "name": "Buddh Gaya",
    "lat": "24.69808",
    "lng": "84.9869"
  },
  {
    "country": "IN",
    "name": "Bodhan",
    "lat": "18.66208",
    "lng": "77.88581"
  },
  {
    "country": "IN",
    "name": "Bobbili",
    "lat": "18.57366",
    "lng": "83.35925"
  },
  {
    "country": "IN",
    "name": "Bithūr",
    "lat": "26.60664",
    "lng": "80.27098"
  },
  {
    "country": "IN",
    "name": "Biswān",
    "lat": "27.49581",
    "lng": "80.99618"
  },
  {
    "country": "IN",
    "name": "Bissāu",
    "lat": "28.24737",
    "lng": "75.07666"
  },
  {
    "country": "IN",
    "name": "Bishnupur",
    "lat": "23.0738",
    "lng": "87.31991"
  },
  {
    "country": "IN",
    "name": "Bishnupur",
    "lat": "22.37777",
    "lng": "88.27411"
  },
  {
    "country": "IN",
    "name": "Bishnāh",
    "lat": "32.6106",
    "lng": "74.85557"
  },
  {
    "country": "IN",
    "name": "Bisenda Buzurg",
    "lat": "25.4035",
    "lng": "80.61889"
  },
  {
    "country": "IN",
    "name": "Bisauli",
    "lat": "28.30772",
    "lng": "78.93678"
  },
  {
    "country": "IN",
    "name": "Bīsalpur",
    "lat": "28.29253",
    "lng": "79.80472"
  },
  {
    "country": "IN",
    "name": "Birūr",
    "lat": "13.59723",
    "lng": "75.97167"
  },
  {
    "country": "IN",
    "name": "Bīrpur",
    "lat": "26.50823",
    "lng": "87.01194"
  },
  {
    "country": "IN",
    "name": "Birmitrapur",
    "lat": "22.4",
    "lng": "84.76667"
  },
  {
    "country": "IN",
    "name": "Birbhaddar",
    "lat": "30.0712",
    "lng": "78.28189"
  },
  {
    "country": "IN",
    "name": "Beed",
    "lat": "18.98921",
    "lng": "75.75634"
  },
  {
    "country": "IN",
    "name": "Binka",
    "lat": "21.02626",
    "lng": "83.81197"
  },
  {
    "country": "IN",
    "name": "Bindki",
    "lat": "26.03613",
    "lng": "80.57617"
  },
  {
    "country": "IN",
    "name": "Etāwa",
    "lat": "24.18351",
    "lng": "78.20289"
  },
  {
    "country": "IN",
    "name": "Bilthra",
    "lat": "26.12705",
    "lng": "83.89148"
  },
  {
    "country": "IN",
    "name": "Bilsi",
    "lat": "28.12941",
    "lng": "78.9109"
  },
  {
    "country": "IN",
    "name": "Bilsanda",
    "lat": "28.24341",
    "lng": "79.95135"
  },
  {
    "country": "IN",
    "name": "Biloli",
    "lat": "18.77385",
    "lng": "77.72463"
  },
  {
    "country": "IN",
    "name": "Bilkha",
    "lat": "21.4415",
    "lng": "70.60063"
  },
  {
    "country": "IN",
    "name": "Bilimora",
    "lat": "20.76957",
    "lng": "72.96134"
  },
  {
    "country": "IN",
    "name": "Bilhaur",
    "lat": "26.84345",
    "lng": "80.06388"
  },
  {
    "country": "IN",
    "name": "Bilgrām",
    "lat": "27.17509",
    "lng": "80.03201"
  },
  {
    "country": "IN",
    "name": "Bilgi",
    "lat": "16.34714",
    "lng": "75.61804"
  },
  {
    "country": "IN",
    "name": "Bilaspur",
    "lat": "31.33027",
    "lng": "76.75663"
  },
  {
    "country": "IN",
    "name": "Bilāspur",
    "lat": "30.3045",
    "lng": "77.30424"
  },
  {
    "country": "IN",
    "name": "Bīlāspur",
    "lat": "28.88655",
    "lng": "79.2703"
  },
  {
    "country": "IN",
    "name": "Bīlāspur",
    "lat": "28.39128",
    "lng": "77.62421"
  },
  {
    "country": "IN",
    "name": "Bilāspur",
    "lat": "22.08005",
    "lng": "82.15543"
  },
  {
    "country": "IN",
    "name": "Bilāsipāra",
    "lat": "26.23285",
    "lng": "90.2341"
  },
  {
    "country": "IN",
    "name": "Bilariāganj",
    "lat": "26.19593",
    "lng": "83.2269"
  },
  {
    "country": "IN",
    "name": "Bilāri",
    "lat": "28.62146",
    "lng": "78.80361"
  },
  {
    "country": "IN",
    "name": "Bilāra",
    "lat": "26.18067",
    "lng": "73.7055"
  },
  {
    "country": "IN",
    "name": "Bikramganj",
    "lat": "25.21073",
    "lng": "84.25508"
  },
  {
    "country": "IN",
    "name": "Bīkāpur",
    "lat": "26.59534",
    "lng": "82.13272"
  },
  {
    "country": "IN",
    "name": "Bīkaner",
    "lat": "28.01762",
    "lng": "73.31495"
  },
  {
    "country": "IN",
    "name": "Bijrauni",
    "lat": "24.93296",
    "lng": "77.64352"
  },
  {
    "country": "IN",
    "name": "Bijnor",
    "lat": "29.373",
    "lng": "78.13636"
  },
  {
    "country": "IN",
    "name": "Bijni",
    "lat": "26.49588",
    "lng": "90.70298"
  },
  {
    "country": "IN",
    "name": "Bijbehara",
    "lat": "33.79378",
    "lng": "75.107"
  },
  {
    "country": "IN",
    "name": "Bijāwar",
    "lat": "24.62351",
    "lng": "79.48994"
  },
  {
    "country": "IN",
    "name": "Bijapur",
    "lat": "16.82442",
    "lng": "75.71537"
  },
  {
    "country": "IN",
    "name": "Bihpuriāgaon",
    "lat": "27.01718",
    "lng": "93.91673"
  },
  {
    "country": "IN",
    "name": "Bihār Sharīf",
    "lat": "25.20084",
    "lng": "85.52389"
  },
  {
    "country": "IN",
    "name": "Bihārīganj",
    "lat": "25.73415",
    "lng": "86.98837"
  },
  {
    "country": "IN",
    "name": "Bīghāpur Khurd",
    "lat": "26.34734",
    "lng": "80.65698"
  },
  {
    "country": "IN",
    "name": "Bidhūna",
    "lat": "26.80172",
    "lng": "79.50829"
  },
  {
    "country": "IN",
    "name": "Bīdar",
    "lat": "17.91331",
    "lng": "77.53011"
  },
  {
    "country": "IN",
    "name": "Biaora",
    "lat": "23.9205",
    "lng": "76.91074"
  },
  {
    "country": "IN",
    "name": "Kīl Bhuvanagiri",
    "lat": "11.44216",
    "lng": "79.64763"
  },
  {
    "country": "IN",
    "name": "Bhusāval",
    "lat": "21.04365",
    "lng": "75.78506"
  },
  {
    "country": "IN",
    "name": "Bhuma",
    "lat": "27.78333",
    "lng": "74.93333"
  },
  {
    "country": "IN",
    "name": "Bhūm",
    "lat": "18.45908",
    "lng": "75.65877"
  },
  {
    "country": "IN",
    "name": "Bhuj",
    "lat": "23.25397",
    "lng": "69.66928"
  },
  {
    "country": "IN",
    "name": "Bhudgaon",
    "lat": "16.90742",
    "lng": "74.59954"
  },
  {
    "country": "IN",
    "name": "Bhubaneshwar",
    "lat": "20.27241",
    "lng": "85.83385"
  },
  {
    "country": "IN",
    "name": "Bhuban",
    "lat": "20.88197",
    "lng": "85.83334"
  },
  {
    "country": "IN",
    "name": "Bhowali",
    "lat": "29.38985",
    "lng": "79.50481"
  },
  {
    "country": "IN",
    "name": "Bhor",
    "lat": "18.14861",
    "lng": "73.84336"
  },
  {
    "country": "IN",
    "name": "Bhopal",
    "lat": "23.25469",
    "lng": "77.40289"
  },
  {
    "country": "IN",
    "name": "Bhongīr",
    "lat": "17.51544",
    "lng": "78.88563"
  },
  {
    "country": "IN",
    "name": "Bhongaon",
    "lat": "27.25515",
    "lng": "79.18118"
  },
  {
    "country": "IN",
    "name": "Bhulath Gharbi",
    "lat": "31.54279",
    "lng": "75.50755"
  },
  {
    "country": "IN",
    "name": "Bhojudih",
    "lat": "23.63962",
    "lng": "86.44105"
  },
  {
    "country": "IN",
    "name": "Bhogpur",
    "lat": "31.55442",
    "lng": "75.64271"
  },
  {
    "country": "IN",
    "name": "Bhiwāni",
    "lat": "28.79304",
    "lng": "76.13968"
  },
  {
    "country": "IN",
    "name": "Bhiwandi",
    "lat": "19.30023",
    "lng": "73.05881"
  },
  {
    "country": "IN",
    "name": "Bhitarwār",
    "lat": "25.79216",
    "lng": "78.11085"
  },
  {
    "country": "IN",
    "name": "Bhīnmāl",
    "lat": "24.99944",
    "lng": "72.27141"
  },
  {
    "country": "IN",
    "name": "Bhinga",
    "lat": "27.70283",
    "lng": "81.9343"
  },
  {
    "country": "IN",
    "name": "Bhindār",
    "lat": "24.50235",
    "lng": "74.18551"
  },
  {
    "country": "IN",
    "name": "Bhind",
    "lat": "26.56671",
    "lng": "78.78728"
  },
  {
    "country": "IN",
    "name": "Bhīmunipatnam",
    "lat": "17.89017",
    "lng": "83.45203"
  },
  {
    "country": "IN",
    "name": "Bhīm Tāl",
    "lat": "29.34447",
    "lng": "79.56336"
  },
  {
    "country": "IN",
    "name": "Bhīmavaram",
    "lat": "16.54078",
    "lng": "81.52322"
  },
  {
    "country": "IN",
    "name": "Bhīlwāra",
    "lat": "25.34707",
    "lng": "74.64081"
  },
  {
    "country": "IN",
    "name": "Bhilai",
    "lat": "21.20919",
    "lng": "81.4285"
  },
  {
    "country": "IN",
    "name": "Bhīkhi",
    "lat": "30.05918",
    "lng": "75.535"
  },
  {
    "country": "IN",
    "name": "Bhikangaon",
    "lat": "21.86764",
    "lng": "75.96391"
  },
  {
    "country": "IN",
    "name": "Bhigvan",
    "lat": "18.3007",
    "lng": "74.76701"
  },
  {
    "country": "IN",
    "name": "Bhāyāvadar",
    "lat": "21.85523",
    "lng": "70.24791"
  },
  {
    "country": "IN",
    "name": "Bhayandar",
    "lat": "19.30157",
    "lng": "72.85107"
  },
  {
    "country": "IN",
    "name": "Bhawānipatna",
    "lat": "19.90717",
    "lng": "83.16697"
  },
  {
    "country": "IN",
    "name": "Bhawānīgarh",
    "lat": "30.26685",
    "lng": "76.03854"
  },
  {
    "country": "IN",
    "name": "Bhawāniganj",
    "lat": "24.41582",
    "lng": "75.83552"
  },
  {
    "country": "IN",
    "name": "Bhavnagar",
    "lat": "21.76287",
    "lng": "72.15331"
  },
  {
    "country": "IN",
    "name": "Bhavāni",
    "lat": "11.44553",
    "lng": "77.68215"
  },
  {
    "country": "IN",
    "name": "Bhattiprolu",
    "lat": "16.1026",
    "lng": "80.78074"
  },
  {
    "country": "IN",
    "name": "Bhātpāra",
    "lat": "22.86643",
    "lng": "88.40113"
  },
  {
    "country": "IN",
    "name": "Bhatkal",
    "lat": "13.98534",
    "lng": "74.55531"
  },
  {
    "country": "IN",
    "name": "Bathinda",
    "lat": "30.20747",
    "lng": "74.93893"
  },
  {
    "country": "IN",
    "name": "Bhatgaon",
    "lat": "21.15",
    "lng": "81.7"
  },
  {
    "country": "IN",
    "name": "Bhātāpāra",
    "lat": "21.735",
    "lng": "81.94711"
  },
  {
    "country": "IN",
    "name": "Bhasāwar",
    "lat": "27.03895",
    "lng": "77.04849"
  },
  {
    "country": "IN",
    "name": "Bharwāri",
    "lat": "25.56078",
    "lng": "81.49164"
  },
  {
    "country": "IN",
    "name": "Bharūch",
    "lat": "21.69482",
    "lng": "72.9805"
  },
  {
    "country": "IN",
    "name": "Bharthana",
    "lat": "26.75231",
    "lng": "79.2218"
  },
  {
    "country": "IN",
    "name": "Bharatpur",
    "lat": "27.21731",
    "lng": "77.49009"
  },
  {
    "country": "IN",
    "name": "Bhānvad",
    "lat": "21.93053",
    "lng": "69.78081"
  },
  {
    "country": "IN",
    "name": "Bhānpurī",
    "lat": "21.0919",
    "lng": "80.93218"
  },
  {
    "country": "IN",
    "name": "Bhānpura",
    "lat": "24.513",
    "lng": "75.7469"
  },
  {
    "country": "IN",
    "name": "Bhanjanagar",
    "lat": "19.92719",
    "lng": "84.58201"
  },
  {
    "country": "IN",
    "name": "Bhānder",
    "lat": "25.73581",
    "lng": "78.74555"
  },
  {
    "country": "IN",
    "name": "Bhandāra",
    "lat": "21.16817",
    "lng": "79.64885"
  },
  {
    "country": "IN",
    "name": "Bhālki",
    "lat": "18.04348",
    "lng": "77.206"
  },
  {
    "country": "IN",
    "name": "Bhaisa",
    "lat": "19.11285",
    "lng": "77.96336"
  },
  {
    "country": "IN",
    "name": "Bhainsdehi",
    "lat": "21.64491",
    "lng": "77.63023"
  },
  {
    "country": "IN",
    "name": "Bhagwantnagar",
    "lat": "26.22383",
    "lng": "80.7575"
  },
  {
    "country": "IN",
    "name": "Bhāgalpur",
    "lat": "25.24446",
    "lng": "86.97183"
  },
  {
    "country": "IN",
    "name": "Bhadreswar",
    "lat": "22.82449",
    "lng": "88.33841"
  },
  {
    "country": "IN",
    "name": "Bhadrāvati",
    "lat": "13.84846",
    "lng": "75.70502"
  },
  {
    "country": "IN",
    "name": "Bhadrakh",
    "lat": "21.05447",
    "lng": "86.5156"
  },
  {
    "country": "IN",
    "name": "Bhadrāchalam",
    "lat": "17.66846",
    "lng": "80.88887"
  },
  {
    "country": "IN",
    "name": "Bhādra",
    "lat": "29.10298",
    "lng": "75.17138"
  },
  {
    "country": "IN",
    "name": "Bhadohi",
    "lat": "25.39526",
    "lng": "82.5703"
  },
  {
    "country": "IN",
    "name": "Bhadaur",
    "lat": "30.47651",
    "lng": "75.33049"
  },
  {
    "country": "IN",
    "name": "Bhādāsar",
    "lat": "28.31457",
    "lng": "74.28952"
  },
  {
    "country": "IN",
    "name": "Bhadarwāh",
    "lat": "32.97941",
    "lng": "75.71723"
  },
  {
    "country": "IN",
    "name": "Bhachāu",
    "lat": "23.29858",
    "lng": "70.34279"
  },
  {
    "country": "IN",
    "name": "Bhabhua",
    "lat": "25.04049",
    "lng": "83.60749"
  },
  {
    "country": "IN",
    "name": "Bhābhra",
    "lat": "22.53048",
    "lng": "74.32846"
  },
  {
    "country": "IN",
    "name": "Beypore",
    "lat": "11.17151",
    "lng": "75.80611"
  },
  {
    "country": "IN",
    "name": "Bewar",
    "lat": "27.21869",
    "lng": "79.29761"
  },
  {
    "country": "IN",
    "name": "Betūl Bazār",
    "lat": "21.85572",
    "lng": "77.92913"
  },
  {
    "country": "IN",
    "name": "Betūl",
    "lat": "21.90056",
    "lng": "77.90229"
  },
  {
    "country": "IN",
    "name": "Bettiah",
    "lat": "26.80229",
    "lng": "84.50311"
  },
  {
    "country": "IN",
    "name": "Betma",
    "lat": "22.68653",
    "lng": "75.61456"
  },
  {
    "country": "IN",
    "name": "Betamcherla",
    "lat": "15.45144",
    "lng": "78.14797"
  },
  {
    "country": "IN",
    "name": "Beswān",
    "lat": "27.63792",
    "lng": "77.88019"
  },
  {
    "country": "IN",
    "name": "Beri Khās",
    "lat": "28.70146",
    "lng": "76.57708"
  },
  {
    "country": "IN",
    "name": "Berasia",
    "lat": "23.63134",
    "lng": "77.43351"
  },
  {
    "country": "IN",
    "name": "Beohāri",
    "lat": "24.02423",
    "lng": "81.37831"
  },
  {
    "country": "IN",
    "name": "Benīganj",
    "lat": "27.29293",
    "lng": "80.44364"
  },
  {
    "country": "IN",
    "name": "Benaulim",
    "lat": "15.26435",
    "lng": "73.92812"
  },
  {
    "country": "IN",
    "name": "Bemetāra",
    "lat": "21.71556",
    "lng": "81.53423"
  },
  {
    "country": "IN",
    "name": "Belūr",
    "lat": "13.16558",
    "lng": "75.86519"
  },
  {
    "country": "IN",
    "name": "Belūr",
    "lat": "11.70752",
    "lng": "78.41437"
  },
  {
    "country": "IN",
    "name": "Beltangadi",
    "lat": "13.98333",
    "lng": "75.3"
  },
  {
    "country": "IN",
    "name": "Belsand",
    "lat": "26.44365",
    "lng": "85.40076"
  },
  {
    "country": "IN",
    "name": "Belonia",
    "lat": "23.25178",
    "lng": "91.45407"
  },
  {
    "country": "IN",
    "name": "Bellūru",
    "lat": "12.9814",
    "lng": "76.73308"
  },
  {
    "country": "IN",
    "name": "Bellary",
    "lat": "15.14205",
    "lng": "76.92398"
  },
  {
    "country": "IN",
    "name": "Beliātor",
    "lat": "23.32052",
    "lng": "87.22081"
  },
  {
    "country": "IN",
    "name": "Belgaum",
    "lat": "15.85212",
    "lng": "74.50447"
  },
  {
    "country": "IN",
    "name": "Beldānga",
    "lat": "23.93428",
    "lng": "88.26018"
  },
  {
    "country": "IN",
    "name": "Belaguntha",
    "lat": "19.88249",
    "lng": "84.63801"
  },
  {
    "country": "IN",
    "name": "Bela",
    "lat": "25.92058",
    "lng": "81.99629"
  },
  {
    "country": "IN",
    "name": "Behror",
    "lat": "27.88832",
    "lng": "76.28108"
  },
  {
    "country": "IN",
    "name": "Behat",
    "lat": "30.1718",
    "lng": "77.6139"
  },
  {
    "country": "IN",
    "name": "Begusarai",
    "lat": "25.41853",
    "lng": "86.13389"
  },
  {
    "country": "IN",
    "name": "Begūn",
    "lat": "24.98333",
    "lng": "75"
  },
  {
    "country": "IN",
    "name": "Begowāl",
    "lat": "31.61152",
    "lng": "75.52135"
  },
  {
    "country": "IN",
    "name": "Begamganj",
    "lat": "23.59917",
    "lng": "78.34064"
  },
  {
    "country": "IN",
    "name": "Bedi",
    "lat": "22.50143",
    "lng": "70.04363"
  },
  {
    "country": "IN",
    "name": "Beāwar",
    "lat": "26.10119",
    "lng": "74.32028"
  },
  {
    "country": "IN",
    "name": "Bāzpur",
    "lat": "29.15299",
    "lng": "79.10814"
  },
  {
    "country": "IN",
    "name": "Bayāna",
    "lat": "26.90791",
    "lng": "77.28985"
  },
  {
    "country": "IN",
    "name": "Bawāna",
    "lat": "28.7982",
    "lng": "77.03431"
  },
  {
    "country": "IN",
    "name": "Bāwal",
    "lat": "28.07184",
    "lng": "76.58312"
  },
  {
    "country": "IN",
    "name": "Baud",
    "lat": "20.83773",
    "lng": "84.32618"
  },
  {
    "country": "IN",
    "name": "Batoti",
    "lat": "33.11826",
    "lng": "75.30889"
  },
  {
    "country": "IN",
    "name": "Batāla",
    "lat": "31.80921",
    "lng": "75.20294"
  },
  {
    "country": "IN",
    "name": "Baswa",
    "lat": "27.14955",
    "lng": "76.58345"
  },
  {
    "country": "IN",
    "name": "Bāsugaon",
    "lat": "26.46742",
    "lng": "90.41951"
  },
  {
    "country": "IN",
    "name": "Bāsudebpur",
    "lat": "21.11974",
    "lng": "86.72896"
  },
  {
    "country": "IN",
    "name": "Bastī",
    "lat": "26.78817",
    "lng": "82.71617"
  },
  {
    "country": "IN",
    "name": "Bāsoda",
    "lat": "23.85153",
    "lng": "77.93652"
  },
  {
    "country": "IN",
    "name": "Basni",
    "lat": "27.17232",
    "lng": "73.64519"
  },
  {
    "country": "IN",
    "name": "Basna",
    "lat": "21.27885",
    "lng": "82.8267"
  },
  {
    "country": "IN",
    "name": "Basmat",
    "lat": "19.32872",
    "lng": "77.15746"
  },
  {
    "country": "IN",
    "name": "Basi",
    "lat": "30.6885",
    "lng": "76.40111"
  },
  {
    "country": "IN",
    "name": "Basi",
    "lat": "30.58813",
    "lng": "76.84498"
  },
  {
    "country": "IN",
    "name": "Basi",
    "lat": "26.8315",
    "lng": "76.04856"
  },
  {
    "country": "IN",
    "name": "Basavana Bāgevādi",
    "lat": "16.57278",
    "lng": "75.97252"
  },
  {
    "country": "IN",
    "name": "Basavakalyān",
    "lat": "17.87445",
    "lng": "76.94972"
  },
  {
    "country": "IN",
    "name": "Bāsār",
    "lat": "27.99008",
    "lng": "94.69451"
  },
  {
    "country": "IN",
    "name": "Barwāni",
    "lat": "22.03232",
    "lng": "74.89982"
  },
  {
    "country": "IN",
    "name": "Barwāla",
    "lat": "29.36747",
    "lng": "75.90809"
  },
  {
    "country": "IN",
    "name": "Barwādih",
    "lat": "23.8478",
    "lng": "84.11049"
  },
  {
    "country": "IN",
    "name": "Bāruni",
    "lat": "25.47509",
    "lng": "85.96813"
  },
  {
    "country": "IN",
    "name": "Bāruipur",
    "lat": "22.35253",
    "lng": "88.43882"
  },
  {
    "country": "IN",
    "name": "Bārsi",
    "lat": "18.23454",
    "lng": "75.69275"
  },
  {
    "country": "IN",
    "name": "Barsāna",
    "lat": "27.64802",
    "lng": "77.3764"
  },
  {
    "country": "IN",
    "name": "Barpeta",
    "lat": "26.32293",
    "lng": "91.00632"
  },
  {
    "country": "IN",
    "name": "Barpathār",
    "lat": "26.28709",
    "lng": "93.88844"
  },
  {
    "country": "IN",
    "name": "Barpāli",
    "lat": "21.19005",
    "lng": "83.58721"
  },
  {
    "country": "IN",
    "name": "Barnāla",
    "lat": "30.37451",
    "lng": "75.5487"
  },
  {
    "country": "IN",
    "name": "Bārmer",
    "lat": "25.74572",
    "lng": "71.39211"
  },
  {
    "country": "IN",
    "name": "Barkot",
    "lat": "30.80861",
    "lng": "78.20596"
  },
  {
    "country": "IN",
    "name": "Barki Saria",
    "lat": "24.17594",
    "lng": "85.88938"
  },
  {
    "country": "IN",
    "name": "Barkhera Kalān",
    "lat": "28.45209",
    "lng": "79.80655"
  },
  {
    "country": "IN",
    "name": "Barkā Kānā",
    "lat": "23.62118",
    "lng": "85.46748"
  },
  {
    "country": "IN",
    "name": "Barjora",
    "lat": "23.42754",
    "lng": "87.29037"
  },
  {
    "country": "IN",
    "name": "Barjala",
    "lat": "23.6182",
    "lng": "91.35596"
  },
  {
    "country": "IN",
    "name": "Bari Sādri",
    "lat": "24.41339",
    "lng": "74.47331"
  },
  {
    "country": "IN",
    "name": "Bariārpur",
    "lat": "25.28791",
    "lng": "86.57643"
  },
  {
    "country": "IN",
    "name": "Bāri",
    "lat": "26.64661",
    "lng": "77.61634"
  },
  {
    "country": "IN",
    "name": "Barhiya",
    "lat": "25.28814",
    "lng": "86.02055"
  },
  {
    "country": "IN",
    "name": "patamda",
    "lat": "24.3",
    "lng": "85.41667"
  },
  {
    "country": "IN",
    "name": "Barhi",
    "lat": "23.90326",
    "lng": "80.81516"
  },
  {
    "country": "IN",
    "name": "Bārh",
    "lat": "25.48339",
    "lng": "85.70928"
  },
  {
    "country": "IN",
    "name": "Bargi",
    "lat": "22.99138",
    "lng": "79.8755"
  },
  {
    "country": "IN",
    "name": "Barghāt",
    "lat": "22.03065",
    "lng": "79.7328"
  },
  {
    "country": "IN",
    "name": "Bargarh",
    "lat": "21.33348",
    "lng": "83.61905"
  },
  {
    "country": "IN",
    "name": "Barela",
    "lat": "23.09678",
    "lng": "80.05084"
  },
  {
    "country": "IN",
    "name": "Bareilly",
    "lat": "28.36678",
    "lng": "79.43167"
  },
  {
    "country": "IN",
    "name": "Bārdoli",
    "lat": "21.12297",
    "lng": "73.11151"
  },
  {
    "country": "IN",
    "name": "Barddhamān",
    "lat": "23.25572",
    "lng": "87.85691"
  },
  {
    "country": "IN",
    "name": "Bar Bigha",
    "lat": "25.21855",
    "lng": "85.7332"
  },
  {
    "country": "IN",
    "name": "Baraut",
    "lat": "29.10199",
    "lng": "77.26334"
  },
  {
    "country": "IN",
    "name": "Barauli",
    "lat": "26.38109",
    "lng": "84.58648"
  },
  {
    "country": "IN",
    "name": "Bārāsat",
    "lat": "22.72154",
    "lng": "88.48198"
  },
  {
    "country": "IN",
    "name": "Bārāsat",
    "lat": "22.22516",
    "lng": "88.45086"
  },
  {
    "country": "IN",
    "name": "Baranagar",
    "lat": "22.64132",
    "lng": "88.37727"
  },
  {
    "country": "IN",
    "name": "Bārān",
    "lat": "25.1",
    "lng": "76.51667"
  },
  {
    "country": "IN",
    "name": "Bāramūla",
    "lat": "34.209",
    "lng": "74.34285"
  },
  {
    "country": "IN",
    "name": "Bārāmati",
    "lat": "18.15174",
    "lng": "74.57767"
  },
  {
    "country": "IN",
    "name": "Bārākpur",
    "lat": "22.76602",
    "lng": "88.36336"
  },
  {
    "country": "IN",
    "name": "Barāgaon",
    "lat": "25.47554",
    "lng": "78.71224"
  },
  {
    "country": "IN",
    "name": "Barāgaon",
    "lat": "25.42936",
    "lng": "82.81709"
  },
  {
    "country": "IN",
    "name": "Bara Bazar",
    "lat": "22.56667",
    "lng": "88.35"
  },
  {
    "country": "IN",
    "name": "Bāpatla",
    "lat": "15.90422",
    "lng": "80.46743"
  },
  {
    "country": "IN",
    "name": "Banūr",
    "lat": "30.55407",
    "lng": "76.71948"
  },
  {
    "country": "IN",
    "name": "Bantvāl",
    "lat": "12.8905",
    "lng": "75.03489"
  },
  {
    "country": "IN",
    "name": "Bāntva",
    "lat": "21.48815",
    "lng": "70.07576"
  },
  {
    "country": "IN",
    "name": "Bānswāra",
    "lat": "23.54109",
    "lng": "74.4425"
  },
  {
    "country": "IN",
    "name": "Bānswāda",
    "lat": "18.37725",
    "lng": "77.88007"
  },
  {
    "country": "IN",
    "name": "Bānsi",
    "lat": "27.17749",
    "lng": "82.93442"
  },
  {
    "country": "IN",
    "name": "Bānsgāon",
    "lat": "26.55032",
    "lng": "83.34503"
  },
  {
    "country": "IN",
    "name": "Bānsdīh",
    "lat": "25.88377",
    "lng": "84.21827"
  },
  {
    "country": "IN",
    "name": "Bānsbāria",
    "lat": "22.95387",
    "lng": "88.40098"
  },
  {
    "country": "IN",
    "name": "Bānposh",
    "lat": "22.24834",
    "lng": "84.81044"
  },
  {
    "country": "IN",
    "name": "Bannūr",
    "lat": "12.33295",
    "lng": "76.86201"
  },
  {
    "country": "IN",
    "name": "Banmankhi",
    "lat": "25.88857",
    "lng": "87.19421"
  },
  {
    "country": "IN",
    "name": "Bānkura",
    "lat": "23.23241",
    "lng": "87.0716"
  },
  {
    "country": "IN",
    "name": "Bānki",
    "lat": "20.37912",
    "lng": "85.52953"
  },
  {
    "country": "IN",
    "name": "Bānka",
    "lat": "24.88091",
    "lng": "86.92257"
  },
  {
    "country": "IN",
    "name": "Banjār",
    "lat": "31.639",
    "lng": "77.34055"
  },
  {
    "country": "IN",
    "name": "Banihāl",
    "lat": "33.43647",
    "lng": "75.19684"
  },
  {
    "country": "IN",
    "name": "Bāngarmau",
    "lat": "26.8912",
    "lng": "80.21149"
  },
  {
    "country": "IN",
    "name": "Bowringpet",
    "lat": "12.99116",
    "lng": "78.17804"
  },
  {
    "country": "IN",
    "name": "Bangaon",
    "lat": "25.86728",
    "lng": "86.51152"
  },
  {
    "country": "IN",
    "name": "Bangaon",
    "lat": "23.04553",
    "lng": "88.83084"
  },
  {
    "country": "IN",
    "name": "Banganapalle",
    "lat": "15.31771",
    "lng": "78.22669"
  },
  {
    "country": "IN",
    "name": "Bengaluru",
    "lat": "12.97194",
    "lng": "77.59369"
  },
  {
    "country": "IN",
    "name": "Banga",
    "lat": "31.18874",
    "lng": "75.99495"
  },
  {
    "country": "IN",
    "name": "Bandora",
    "lat": "15.40823",
    "lng": "73.98129"
  },
  {
    "country": "IN",
    "name": "Bandipura",
    "lat": "34.41728",
    "lng": "74.64308"
  },
  {
    "country": "IN",
    "name": "Bāndīkūi",
    "lat": "27.05087",
    "lng": "76.57325"
  },
  {
    "country": "IN",
    "name": "Bānda",
    "lat": "25.47758",
    "lng": "80.33491"
  },
  {
    "country": "IN",
    "name": "Banda",
    "lat": "24.04488",
    "lng": "78.96094"
  },
  {
    "country": "IN",
    "name": "Bānāvar",
    "lat": "13.41029",
    "lng": "76.16314"
  },
  {
    "country": "IN",
    "name": "Banat",
    "lat": "29.46355",
    "lng": "77.35478"
  },
  {
    "country": "IN",
    "name": "Bānapur",
    "lat": "19.77889",
    "lng": "85.17033"
  },
  {
    "country": "IN",
    "name": "Bāmor Kalān",
    "lat": "24.89298",
    "lng": "78.15105"
  },
  {
    "country": "IN",
    "name": "Bamora",
    "lat": "24.05539",
    "lng": "78.08925"
  },
  {
    "country": "IN",
    "name": "Bamna",
    "lat": "23.09454",
    "lng": "74.76164"
  },
  {
    "country": "IN",
    "name": "Bamboo Flat",
    "lat": "11.7",
    "lng": "92.71667"
  },
  {
    "country": "IN",
    "name": "Bambolim",
    "lat": "15.46361",
    "lng": "73.8531"
  },
  {
    "country": "IN",
    "name": "Bālurghāt",
    "lat": "25.22099",
    "lng": "88.77732"
  },
  {
    "country": "IN",
    "name": "Bālugaon",
    "lat": "20.17838",
    "lng": "85.11327"
  },
  {
    "country": "IN",
    "name": "Balrāmpur",
    "lat": "27.42949",
    "lng": "82.18545"
  },
  {
    "country": "IN",
    "name": "Bālotra",
    "lat": "25.83242",
    "lng": "72.24"
  },
  {
    "country": "IN",
    "name": "Baloda Bāzār",
    "lat": "21.65678",
    "lng": "82.16062"
  },
  {
    "country": "IN",
    "name": "Baloda",
    "lat": "22.1389",
    "lng": "82.48171"
  },
  {
    "country": "IN",
    "name": "Balod",
    "lat": "20.73081",
    "lng": "81.20578"
  },
  {
    "country": "IN",
    "name": "Bāli",
    "lat": "22.64859",
    "lng": "88.34115"
  },
  {
    "country": "IN",
    "name": "Ballālpur",
    "lat": "19.84696",
    "lng": "79.34578"
  },
  {
    "country": "IN",
    "name": "Balimila",
    "lat": "18.25167",
    "lng": "82.10659"
  },
  {
    "country": "IN",
    "name": "Bāli Chak",
    "lat": "22.36482",
    "lng": "87.55304"
  },
  {
    "country": "IN",
    "name": "Bāli",
    "lat": "25.19725",
    "lng": "73.29117"
  },
  {
    "country": "IN",
    "name": "Balasore",
    "lat": "21.49266",
    "lng": "86.93348"
  },
  {
    "country": "IN",
    "name": "Baldeogarh",
    "lat": "24.75619",
    "lng": "79.06715"
  },
  {
    "country": "IN",
    "name": "Baldev",
    "lat": "27.40684",
    "lng": "77.82214"
  },
  {
    "country": "IN",
    "name": "Balarāmpur",
    "lat": "23.09714",
    "lng": "86.22292"
  },
  {
    "country": "IN",
    "name": "Bālāpur",
    "lat": "20.66612",
    "lng": "76.77386"
  },
  {
    "country": "IN",
    "name": "Balāngīr",
    "lat": "20.70419",
    "lng": "83.49029"
  },
  {
    "country": "IN",
    "name": "Bālāghāt",
    "lat": "21.8156",
    "lng": "80.18845"
  },
  {
    "country": "IN",
    "name": "Bālāchor",
    "lat": "31.06062",
    "lng": "76.30166"
  },
  {
    "country": "IN",
    "name": "Bakshwāho",
    "lat": "24.25106",
    "lng": "79.28618"
  },
  {
    "country": "IN",
    "name": "Bakreswar",
    "lat": "23.8832",
    "lng": "87.37265"
  },
  {
    "country": "IN",
    "name": "Bakloh",
    "lat": "32.47939",
    "lng": "75.91874"
  },
  {
    "country": "IN",
    "name": "Bakhtiyārpur",
    "lat": "25.46179",
    "lng": "85.53179"
  },
  {
    "country": "IN",
    "name": "Bakewar",
    "lat": "26.66226",
    "lng": "79.17625"
  },
  {
    "country": "IN",
    "name": "Bakāni",
    "lat": "24.28624",
    "lng": "76.23709"
  },
  {
    "country": "IN",
    "name": "Bājna",
    "lat": "27.89793",
    "lng": "77.67836"
  },
  {
    "country": "IN",
    "name": "Baj Baj",
    "lat": "22.47514",
    "lng": "88.17767"
  },
  {
    "country": "IN",
    "name": "Baisi",
    "lat": "25.86302",
    "lng": "87.74487"
  },
  {
    "country": "IN",
    "name": "Bairāgnia",
    "lat": "26.74063",
    "lng": "85.27323"
  },
  {
    "country": "IN",
    "name": "Byndoor",
    "lat": "13.86667",
    "lng": "74.63333"
  },
  {
    "country": "IN",
    "name": "Bail-Hongal",
    "lat": "15.8137",
    "lng": "74.85895"
  },
  {
    "country": "IN",
    "name": "Baikunthpur",
    "lat": "23.26206",
    "lng": "82.56051"
  },
  {
    "country": "IN",
    "name": "Baikunthpur",
    "lat": "24.72768",
    "lng": "81.40975"
  },
  {
    "country": "IN",
    "name": "Baihar",
    "lat": "22.10133",
    "lng": "80.54967"
  },
  {
    "country": "IN",
    "name": "Baidyabāti",
    "lat": "22.78498",
    "lng": "88.32586"
  },
  {
    "country": "IN",
    "name": "Bahua",
    "lat": "25.83942",
    "lng": "80.62255"
  },
  {
    "country": "IN",
    "name": "Bahsūma",
    "lat": "29.20063",
    "lng": "77.97221"
  },
  {
    "country": "IN",
    "name": "Bahraigh",
    "lat": "27.57429",
    "lng": "81.59474"
  },
  {
    "country": "IN",
    "name": "Bahjoi",
    "lat": "28.39502",
    "lng": "78.62659"
  },
  {
    "country": "IN",
    "name": "Baheri",
    "lat": "28.77416",
    "lng": "79.4974"
  },
  {
    "country": "IN",
    "name": "Baharampur",
    "lat": "24.10473",
    "lng": "88.25155"
  },
  {
    "country": "IN",
    "name": "Bahādurgarh",
    "lat": "28.69287",
    "lng": "76.93555"
  },
  {
    "country": "IN",
    "name": "Bahādurganj",
    "lat": "26.26172",
    "lng": "87.82443"
  },
  {
    "country": "IN",
    "name": "Bāh",
    "lat": "26.86912",
    "lng": "78.59385"
  },
  {
    "country": "IN",
    "name": "Bagulā",
    "lat": "23.33664",
    "lng": "88.64109"
  },
  {
    "country": "IN",
    "name": "Bagra",
    "lat": "23.73333",
    "lng": "86.31667"
  },
  {
    "country": "IN",
    "name": "Bāgli",
    "lat": "22.64124",
    "lng": "76.34877"
  },
  {
    "country": "IN",
    "name": "Bāghpat",
    "lat": "28.94485",
    "lng": "77.21865"
  },
  {
    "country": "IN",
    "name": "Bagdogra",
    "lat": "26.69929",
    "lng": "88.31177"
  },
  {
    "country": "IN",
    "name": "Bāgha Purāna",
    "lat": "30.68809",
    "lng": "75.09838"
  },
  {
    "country": "IN",
    "name": "Bāg",
    "lat": "22.35905",
    "lng": "74.79052"
  },
  {
    "country": "IN",
    "name": "Bāgeshwar",
    "lat": "29.83738",
    "lng": "79.77161"
  },
  {
    "country": "IN",
    "name": "Bāgepalli",
    "lat": "13.78338",
    "lng": "77.79667"
  },
  {
    "country": "IN",
    "name": "Bagasra",
    "lat": "21.48719",
    "lng": "70.95516"
  },
  {
    "country": "IN",
    "name": "Bagar",
    "lat": "28.18784",
    "lng": "75.50012"
  },
  {
    "country": "IN",
    "name": "Bagalkot",
    "lat": "16.18673",
    "lng": "75.69614"
  },
  {
    "country": "IN",
    "name": "Bagaha",
    "lat": "27.09918",
    "lng": "84.09003"
  },
  {
    "country": "IN",
    "name": "Bagaha",
    "lat": "24.52898",
    "lng": "85.06019"
  },
  {
    "country": "IN",
    "name": "Badvel",
    "lat": "14.7451",
    "lng": "79.06288"
  },
  {
    "country": "IN",
    "name": "Badūria",
    "lat": "22.74431",
    "lng": "88.78655"
  },
  {
    "country": "IN",
    "name": "Badnāwar",
    "lat": "23.02181",
    "lng": "75.23268"
  },
  {
    "country": "IN",
    "name": "Badlapur",
    "lat": "19.15516",
    "lng": "73.26553"
  },
  {
    "country": "IN",
    "name": "Badhni Kalān",
    "lat": "30.6813",
    "lng": "75.29087"
  },
  {
    "country": "IN",
    "name": "Badarwās",
    "lat": "24.97516",
    "lng": "77.5649"
  },
  {
    "country": "IN",
    "name": "Badarpur",
    "lat": "24.86852",
    "lng": "92.59606"
  },
  {
    "country": "IN",
    "name": "Bādāmi",
    "lat": "15.91495",
    "lng": "75.67683"
  },
  {
    "country": "IN",
    "name": "Badagara",
    "lat": "11.59776",
    "lng": "75.58142"
  },
  {
    "country": "IN",
    "name": "Bada Barabīl",
    "lat": "22.11186",
    "lng": "85.38684"
  },
  {
    "country": "IN",
    "name": "Bachhrāwān",
    "lat": "26.4709",
    "lng": "81.1158"
  },
  {
    "country": "IN",
    "name": "Bachhraon",
    "lat": "28.92694",
    "lng": "78.23456"
  },
  {
    "country": "IN",
    "name": "Babugarh",
    "lat": "28.72353",
    "lng": "77.84677"
  },
  {
    "country": "IN",
    "name": "Babrāla",
    "lat": "28.26419",
    "lng": "78.4056"
  },
  {
    "country": "IN",
    "name": "Bābra",
    "lat": "21.84577",
    "lng": "71.30544"
  },
  {
    "country": "IN",
    "name": "Babīna",
    "lat": "25.23947",
    "lng": "78.47028"
  },
  {
    "country": "IN",
    "name": "Baberu",
    "lat": "25.54711",
    "lng": "80.70443"
  },
  {
    "country": "IN",
    "name": "Bābai",
    "lat": "22.70256",
    "lng": "77.93494"
  },
  {
    "country": "IN",
    "name": "Azamgarh",
    "lat": "26.06832",
    "lng": "83.18358"
  },
  {
    "country": "IN",
    "name": "Ayyampettāi",
    "lat": "10.90141",
    "lng": "79.17984"
  },
  {
    "country": "IN",
    "name": "Ajodhya",
    "lat": "26.79909",
    "lng": "82.2047"
  },
  {
    "country": "IN",
    "name": "Ayakudi",
    "lat": "10.44992",
    "lng": "77.55198"
  },
  {
    "country": "IN",
    "name": "Awantipur",
    "lat": "33.91978",
    "lng": "75.01515"
  },
  {
    "country": "IN",
    "name": "Avanigadda",
    "lat": "16.02148",
    "lng": "80.91808"
  },
  {
    "country": "IN",
    "name": "Avinashi",
    "lat": "11.19297",
    "lng": "77.26865"
  },
  {
    "country": "IN",
    "name": "Āvadi",
    "lat": "13.1147",
    "lng": "80.10981"
  },
  {
    "country": "IN",
    "name": "Ausa",
    "lat": "18.24728",
    "lng": "76.4993"
  },
  {
    "country": "IN",
    "name": "Aurās",
    "lat": "26.91414",
    "lng": "80.50792"
  },
  {
    "country": "IN",
    "name": "Aurangābād",
    "lat": "24.75204",
    "lng": "84.3742"
  },
  {
    "country": "IN",
    "name": "Aurangabad",
    "lat": "19.87757",
    "lng": "75.34226"
  },
  {
    "country": "IN",
    "name": "Auraiya",
    "lat": "26.46517",
    "lng": "79.50918"
  },
  {
    "country": "IN",
    "name": "Aurād",
    "lat": "18.25397",
    "lng": "77.41761"
  },
  {
    "country": "IN",
    "name": "Attur",
    "lat": "11.59414",
    "lng": "78.60143"
  },
  {
    "country": "IN",
    "name": "Attingal",
    "lat": "8.69609",
    "lng": "76.81507"
  },
  {
    "country": "IN",
    "name": "Attili",
    "lat": "16.7",
    "lng": "81.6"
  },
  {
    "country": "IN",
    "name": "Āttayyāmpatti",
    "lat": "11.53272",
    "lng": "78.05363"
  },
  {
    "country": "IN",
    "name": "Atraulia",
    "lat": "26.3333",
    "lng": "82.94727"
  },
  {
    "country": "IN",
    "name": "Atraulī",
    "lat": "28.02964",
    "lng": "78.28571"
  },
  {
    "country": "IN",
    "name": "Atmakūr",
    "lat": "15.88109",
    "lng": "78.58704"
  },
  {
    "country": "IN",
    "name": "Adirampattinam",
    "lat": "10.34059",
    "lng": "79.37905"
  },
  {
    "country": "IN",
    "name": "Athni",
    "lat": "16.72613",
    "lng": "75.06421"
  },
  {
    "country": "IN",
    "name": "Āthagarh",
    "lat": "20.51999",
    "lng": "85.62965"
  },
  {
    "country": "IN",
    "name": "Ateli Mandi",
    "lat": "28.1008",
    "lng": "76.2598"
  },
  {
    "country": "IN",
    "name": "Atarra",
    "lat": "25.28618",
    "lng": "80.57155"
  },
  {
    "country": "IN",
    "name": "Āsind",
    "lat": "25.7342",
    "lng": "74.33278"
  },
  {
    "country": "IN",
    "name": "Āsika",
    "lat": "19.61114",
    "lng": "84.65998"
  },
  {
    "country": "IN",
    "name": "Asifābād",
    "lat": "19.35851",
    "lng": "79.28415"
  },
  {
    "country": "IN",
    "name": "Ashti",
    "lat": "19.37671",
    "lng": "76.2252"
  },
  {
    "country": "IN",
    "name": "Ashta",
    "lat": "23.01754",
    "lng": "76.72208"
  },
  {
    "country": "IN",
    "name": "Ashta",
    "lat": "16.94943",
    "lng": "74.40936"
  },
  {
    "country": "IN",
    "name": "Ashoknagar",
    "lat": "24.57578",
    "lng": "77.73123"
  },
  {
    "country": "IN",
    "name": "Asarganj",
    "lat": "25.15046",
    "lng": "86.68639"
  },
  {
    "country": "IN",
    "name": "Āsansol",
    "lat": "23.68333",
    "lng": "86.98333"
  },
  {
    "country": "IN",
    "name": "Āsandh",
    "lat": "29.52119",
    "lng": "76.60552"
  },
  {
    "country": "IN",
    "name": "Ārvi",
    "lat": "20.99585",
    "lng": "78.22914"
  },
  {
    "country": "IN",
    "name": "Aruppukkottai",
    "lat": "9.5096",
    "lng": "78.09588"
  },
  {
    "country": "IN",
    "name": "Arumuganeri",
    "lat": "8.5688",
    "lng": "78.09091"
  },
  {
    "country": "IN",
    "name": "Arumbāvūr",
    "lat": "11.38096",
    "lng": "78.72965"
  },
  {
    "country": "IN",
    "name": "Arukutti",
    "lat": "9.86667",
    "lng": "76.35"
  },
  {
    "country": "IN",
    "name": "Arsikere",
    "lat": "13.31446",
    "lng": "76.25704"
  },
  {
    "country": "IN",
    "name": "Āron",
    "lat": "24.38109",
    "lng": "77.41739"
  },
  {
    "country": "IN",
    "name": "Norīa",
    "lat": "32.52095",
    "lng": "74.79845"
  },
  {
    "country": "IN",
    "name": "Arki",
    "lat": "31.15196",
    "lng": "76.96675"
  },
  {
    "country": "IN",
    "name": "Arkalgūd",
    "lat": "12.76171",
    "lng": "76.06035"
  },
  {
    "country": "IN",
    "name": "Ariyalūr",
    "lat": "11.13849",
    "lng": "79.07556"
  },
  {
    "country": "IN",
    "name": "Arimalam",
    "lat": "10.25498",
    "lng": "78.88403"
  },
  {
    "country": "IN",
    "name": "Arcot",
    "lat": "12.90569",
    "lng": "79.31897"
  },
  {
    "country": "IN",
    "name": "Aruvankad",
    "lat": "11.36315",
    "lng": "76.7579"
  },
  {
    "country": "IN",
    "name": "Arāria",
    "lat": "26.14934",
    "lng": "87.51323"
  },
  {
    "country": "IN",
    "name": "Arantāngi",
    "lat": "10.17235",
    "lng": "78.99118"
  },
  {
    "country": "IN",
    "name": "Arni",
    "lat": "12.66771",
    "lng": "79.28529"
  },
  {
    "country": "IN",
    "name": "Ārangaon",
    "lat": "19.02681",
    "lng": "74.71487"
  },
  {
    "country": "IN",
    "name": "Arang",
    "lat": "21.19639",
    "lng": "81.96912"
  },
  {
    "country": "IN",
    "name": "Arambol",
    "lat": "15.68681",
    "lng": "73.70449"
  },
  {
    "country": "IN",
    "name": "Arāmbāgh",
    "lat": "22.88333",
    "lng": "87.78333"
  },
  {
    "country": "IN",
    "name": "Arakkonam",
    "lat": "13.08449",
    "lng": "79.67053"
  },
  {
    "country": "IN",
    "name": "Arrah",
    "lat": "25.55629",
    "lng": "84.66335"
  },
  {
    "country": "IN",
    "name": "Aonla",
    "lat": "28.27402",
    "lng": "79.16521"
  },
  {
    "country": "IN",
    "name": "Anūpshahr",
    "lat": "28.35748",
    "lng": "78.26914"
  },
  {
    "country": "IN",
    "name": "Anūppur",
    "lat": "23.10344",
    "lng": "81.69083"
  },
  {
    "country": "IN",
    "name": "Anūpgarh",
    "lat": "29.19111",
    "lng": "73.20861"
  },
  {
    "country": "IN",
    "name": "Antu",
    "lat": "26.05654",
    "lng": "81.90267"
  },
  {
    "country": "IN",
    "name": "Antri",
    "lat": "26.05804",
    "lng": "78.21027"
  },
  {
    "country": "IN",
    "name": "Anta",
    "lat": "25.15",
    "lng": "76.3"
  },
  {
    "country": "IN",
    "name": "Anshing",
    "lat": "20.0409",
    "lng": "77.31501"
  },
  {
    "country": "IN",
    "name": "Annur",
    "lat": "11.23616",
    "lng": "77.10514"
  },
  {
    "country": "IN",
    "name": "Annigeri",
    "lat": "15.42513",
    "lng": "75.4335"
  },
  {
    "country": "IN",
    "name": "Annavāsal",
    "lat": "10.4606",
    "lng": "78.70029"
  },
  {
    "country": "IN",
    "name": "Annāmalainagar",
    "lat": "11.4",
    "lng": "79.73333"
  },
  {
    "country": "IN",
    "name": "Ankola",
    "lat": "14.66049",
    "lng": "74.3047"
  },
  {
    "country": "IN",
    "name": "Ankleshwar",
    "lat": "21.63236",
    "lng": "72.99001"
  },
  {
    "country": "IN",
    "name": "Anjār",
    "lat": "23.11316",
    "lng": "70.02671"
  },
  {
    "country": "IN",
    "name": "Anjangaon",
    "lat": "21.16516",
    "lng": "77.3091"
  },
  {
    "country": "IN",
    "name": "Anjad",
    "lat": "22.04171",
    "lng": "75.05519"
  },
  {
    "country": "IN",
    "name": "Angul",
    "lat": "20.84089",
    "lng": "85.10192"
  },
  {
    "country": "IN",
    "name": "Angamāli",
    "lat": "10.19055",
    "lng": "76.38789"
  },
  {
    "country": "IN",
    "name": "Anekal",
    "lat": "12.7111",
    "lng": "77.69557"
  },
  {
    "country": "IN",
    "name": "Andol",
    "lat": "17.81458",
    "lng": "78.07713"
  },
  {
    "country": "IN",
    "name": "Anthiyur",
    "lat": "11.57506",
    "lng": "77.59043"
  },
  {
    "country": "IN",
    "name": "Āndippatti",
    "lat": "9.99797",
    "lng": "77.62097"
  },
  {
    "country": "IN",
    "name": "Anantnag",
    "lat": "33.73068",
    "lng": "75.15418"
  },
  {
    "country": "IN",
    "name": "Anantapur",
    "lat": "14.67784",
    "lng": "77.60813"
  },
  {
    "country": "IN",
    "name": "Anandpur",
    "lat": "31.23926",
    "lng": "76.50253"
  },
  {
    "country": "IN",
    "name": "Anandnagar",
    "lat": "27.10062",
    "lng": "83.27156"
  },
  {
    "country": "IN",
    "name": "Anand",
    "lat": "22.55251",
    "lng": "72.9552"
  },
  {
    "country": "IN",
    "name": "Anakāpalle",
    "lat": "17.69134",
    "lng": "83.00395"
  },
  {
    "country": "IN",
    "name": "Anamalais",
    "lat": "10.58303",
    "lng": "76.93441"
  },
  {
    "country": "IN",
    "name": "Amudālavalasa",
    "lat": "18.41025",
    "lng": "83.90295"
  },
  {
    "country": "IN",
    "name": "Āmta",
    "lat": "22.58344",
    "lng": "88.01039"
  },
  {
    "country": "IN",
    "name": "Amroli",
    "lat": "21.25084",
    "lng": "72.83878"
  },
  {
    "country": "IN",
    "name": "Amroha",
    "lat": "28.90314",
    "lng": "78.46984"
  },
  {
    "country": "IN",
    "name": "Amritsar",
    "lat": "31.62234",
    "lng": "74.87534"
  },
  {
    "country": "IN",
    "name": "Amreli",
    "lat": "21.59983",
    "lng": "71.21169"
  },
  {
    "country": "IN",
    "name": "Amrāvati",
    "lat": "20.93333",
    "lng": "77.75"
  },
  {
    "country": "IN",
    "name": "Amod",
    "lat": "21.99317",
    "lng": "72.87047"
  },
  {
    "country": "IN",
    "name": "Ammāpettai",
    "lat": "11.61975",
    "lng": "77.74264"
  },
  {
    "country": "IN",
    "name": "Ammāpettai",
    "lat": "10.79476",
    "lng": "79.31986"
  },
  {
    "country": "IN",
    "name": "Amloh",
    "lat": "30.60837",
    "lng": "76.23199"
  },
  {
    "country": "IN",
    "name": "Āmli",
    "lat": "20.28333",
    "lng": "73.01667"
  },
  {
    "country": "IN",
    "name": "Āmlāgora",
    "lat": "22.84616",
    "lng": "87.33559"
  },
  {
    "country": "IN",
    "name": "Amla",
    "lat": "21.92485",
    "lng": "78.12786"
  },
  {
    "country": "IN",
    "name": "Amguri",
    "lat": "26.81482",
    "lng": "94.52614"
  },
  {
    "country": "IN",
    "name": "Amethi",
    "lat": "28.01667",
    "lng": "81.05"
  },
  {
    "country": "IN",
    "name": "Amethī",
    "lat": "26.15696",
    "lng": "81.80519"
  },
  {
    "country": "IN",
    "name": "Amet",
    "lat": "25.30609",
    "lng": "73.9258"
  },
  {
    "country": "IN",
    "name": "Ambur",
    "lat": "12.79163",
    "lng": "78.71644"
  },
  {
    "country": "IN",
    "name": "Ambikāpur",
    "lat": "23.11892",
    "lng": "83.19537"
  },
  {
    "country": "IN",
    "name": "Ambattūr",
    "lat": "13.09818",
    "lng": "80.16152"
  },
  {
    "country": "IN",
    "name": "Ambasamudram",
    "lat": "8.71068",
    "lng": "77.4519"
  },
  {
    "country": "IN",
    "name": "Āmbāsa",
    "lat": "23.936",
    "lng": "91.85436"
  },
  {
    "country": "IN",
    "name": "Ambāla",
    "lat": "30.36099",
    "lng": "76.79782"
  },
  {
    "country": "IN",
    "name": "Ambājogāi",
    "lat": "18.73312",
    "lng": "76.38616"
  },
  {
    "country": "IN",
    "name": "Ambahta",
    "lat": "29.85706",
    "lng": "77.33583"
  },
  {
    "country": "IN",
    "name": "Ambāh",
    "lat": "26.70423",
    "lng": "78.22678"
  },
  {
    "country": "IN",
    "name": "Ambāgarh Chauki",
    "lat": "20.77644",
    "lng": "80.74608"
  },
  {
    "country": "IN",
    "name": "Ambad",
    "lat": "19.61301",
    "lng": "75.78906"
  },
  {
    "country": "IN",
    "name": "Amarwāra",
    "lat": "22.2978",
    "lng": "79.16943"
  },
  {
    "country": "IN",
    "name": "Amarpur",
    "lat": "25.03967",
    "lng": "86.90247"
  },
  {
    "country": "IN",
    "name": "Amarpur",
    "lat": "23.5257",
    "lng": "91.65879"
  },
  {
    "country": "IN",
    "name": "Amarpātan",
    "lat": "24.31371",
    "lng": "80.97703"
  },
  {
    "country": "IN",
    "name": "Amarnāth",
    "lat": "19.2",
    "lng": "73.16667"
  },
  {
    "country": "IN",
    "name": "Amarkantak",
    "lat": "22.67486",
    "lng": "81.75908"
  },
  {
    "country": "IN",
    "name": "Amānpur",
    "lat": "27.71222",
    "lng": "78.73788"
  },
  {
    "country": "IN",
    "name": "Amānganj",
    "lat": "24.42664",
    "lng": "80.03579"
  },
  {
    "country": "IN",
    "name": "Amalner",
    "lat": "21.03983",
    "lng": "75.05887"
  },
  {
    "country": "IN",
    "name": "Amalāpuram",
    "lat": "16.57868",
    "lng": "82.00609"
  },
  {
    "country": "IN",
    "name": "Alwaye",
    "lat": "10.10649",
    "lng": "76.35484"
  },
  {
    "country": "IN",
    "name": "Alwa Tirunagari",
    "lat": "8.60635",
    "lng": "77.93983"
  },
  {
    "country": "IN",
    "name": "Alwar",
    "lat": "27.56246",
    "lng": "76.625"
  },
  {
    "country": "IN",
    "name": "Alūr",
    "lat": "12.97805",
    "lng": "75.99094"
  },
  {
    "country": "IN",
    "name": "Alot",
    "lat": "23.76336",
    "lng": "75.55662"
  },
  {
    "country": "IN",
    "name": "Along",
    "lat": "28.16951",
    "lng": "94.8006"
  },
  {
    "country": "IN",
    "name": "Alnāvar",
    "lat": "15.42727",
    "lng": "74.74111"
  },
  {
    "country": "IN",
    "name": "Almora",
    "lat": "29.59713",
    "lng": "79.65911"
  },
  {
    "country": "IN",
    "name": "Alleppey",
    "lat": "9.49004",
    "lng": "76.3264"
  },
  {
    "country": "IN",
    "name": "Allāpalli",
    "lat": "19.43172",
    "lng": "80.06377"
  },
  {
    "country": "IN",
    "name": "Allāhganj",
    "lat": "27.5454",
    "lng": "79.68715"
  },
  {
    "country": "IN",
    "name": "Allahābād",
    "lat": "25.44478",
    "lng": "81.84322"
  },
  {
    "country": "IN",
    "name": "Alīpur Duār",
    "lat": "26.4835",
    "lng": "89.52286"
  },
  {
    "country": "IN",
    "name": "Alīpur",
    "lat": "28.79862",
    "lng": "77.13314"
  },
  {
    "country": "IN",
    "name": "Alīgarh",
    "lat": "27.88145",
    "lng": "78.07464"
  },
  {
    "country": "IN",
    "name": "Alīganj",
    "lat": "27.49358",
    "lng": "79.17127"
  },
  {
    "country": "IN",
    "name": "Alībāg",
    "lat": "18.64813",
    "lng": "72.87579"
  },
  {
    "country": "IN",
    "name": "Aldona",
    "lat": "15.59337",
    "lng": "73.87482"
  },
  {
    "country": "IN",
    "name": "Alāwalpur",
    "lat": "31.43161",
    "lng": "75.65614"
  },
  {
    "country": "IN",
    "name": "Ālappākkam",
    "lat": "11.59895",
    "lng": "79.71893"
  },
  {
    "country": "IN",
    "name": "Ālangulam",
    "lat": "8.86404",
    "lng": "77.49937"
  },
  {
    "country": "IN",
    "name": "Ālangudi",
    "lat": "10.3606",
    "lng": "78.98492"
  },
  {
    "country": "IN",
    "name": "Alangāyam",
    "lat": "12.62235",
    "lng": "78.75207"
  },
  {
    "country": "IN",
    "name": "Alangānallūr",
    "lat": "10.04697",
    "lng": "78.09033"
  },
  {
    "country": "IN",
    "name": "Alandur",
    "lat": "13.0025",
    "lng": "80.20611"
  },
  {
    "country": "IN",
    "name": "Alandi",
    "lat": "18.67756",
    "lng": "73.89868"
  },
  {
    "country": "IN",
    "name": "Aland",
    "lat": "17.56425",
    "lng": "76.56854"
  },
  {
    "country": "IN",
    "name": "Alampur",
    "lat": "26.02514",
    "lng": "78.79697"
  },
  {
    "country": "IN",
    "name": "Ālampur",
    "lat": "15.87987",
    "lng": "78.13352"
  },
  {
    "country": "IN",
    "name": "Alagāpuram",
    "lat": "11.88705",
    "lng": "78.91758"
  },
  {
    "country": "IN",
    "name": "Akot",
    "lat": "21.0963",
    "lng": "77.0588"
  },
  {
    "country": "IN",
    "name": "Akola",
    "lat": "20.70957",
    "lng": "76.9981"
  },
  {
    "country": "IN",
    "name": "Akodia",
    "lat": "23.38027",
    "lng": "76.59875"
  },
  {
    "country": "IN",
    "name": "Aklera",
    "lat": "24.41288",
    "lng": "76.56719"
  },
  {
    "country": "IN",
    "name": "Akivīdu",
    "lat": "16.58225",
    "lng": "81.38112"
  },
  {
    "country": "IN",
    "name": "Akhnūr",
    "lat": "32.86667",
    "lng": "74.73333"
  },
  {
    "country": "IN",
    "name": "Akbarpur",
    "lat": "26.42953",
    "lng": "82.53431"
  },
  {
    "country": "IN",
    "name": "Akbarpur",
    "lat": "26.38371",
    "lng": "79.94926"
  },
  {
    "country": "IN",
    "name": "Akaltara",
    "lat": "22.02463",
    "lng": "82.42641"
  },
  {
    "country": "IN",
    "name": "Akalkot",
    "lat": "17.52532",
    "lng": "76.20611"
  },
  {
    "country": "IN",
    "name": "Akālgarh",
    "lat": "29.82074",
    "lng": "75.89078"
  },
  {
    "country": "IN",
    "name": "Ajra",
    "lat": "16.11601",
    "lng": "74.21097"
  },
  {
    "country": "IN",
    "name": "Ajnāla",
    "lat": "31.84473",
    "lng": "74.76295"
  },
  {
    "country": "IN",
    "name": "Ajmer",
    "lat": "26.4521",
    "lng": "74.63867"
  },
  {
    "country": "IN",
    "name": "Ajjampur",
    "lat": "13.72794",
    "lng": "76.0068"
  },
  {
    "country": "IN",
    "name": "Ajaigarh",
    "lat": "24.89879",
    "lng": "80.25921"
  },
  {
    "country": "IN",
    "name": "Aizawl",
    "lat": "23.72894",
    "lng": "92.71791"
  },
  {
    "country": "IN",
    "name": "Ahwa",
    "lat": "20.75718",
    "lng": "73.68626"
  },
  {
    "country": "IN",
    "name": "Ahraura",
    "lat": "25.01579",
    "lng": "83.03294"
  },
  {
    "country": "IN",
    "name": "Ahmadpur",
    "lat": "23.83009",
    "lng": "87.68661"
  },
  {
    "country": "IN",
    "name": "Ahmadpur",
    "lat": "18.70622",
    "lng": "76.93731"
  },
  {
    "country": "IN",
    "name": "Ahmadnagar",
    "lat": "19.09457",
    "lng": "74.73843"
  },
  {
    "country": "IN",
    "name": "Ahmedabad",
    "lat": "23.02579",
    "lng": "72.58727"
  },
  {
    "country": "IN",
    "name": "Ahiri",
    "lat": "19.41386",
    "lng": "80.00359"
  },
  {
    "country": "IN",
    "name": "Agra",
    "lat": "27.18333",
    "lng": "78.01667"
  },
  {
    "country": "IN",
    "name": "Agartala",
    "lat": "23.83605",
    "lng": "91.27939"
  },
  {
    "country": "IN",
    "name": "Agar",
    "lat": "23.71177",
    "lng": "76.01571"
  },
  {
    "country": "IN",
    "name": "Afzalpur",
    "lat": "17.19986",
    "lng": "76.36018"
  },
  {
    "country": "IN",
    "name": "Afzalgarh",
    "lat": "29.3937",
    "lng": "78.67393"
  },
  {
    "country": "IN",
    "name": "Aduthurai",
    "lat": "11.01542",
    "lng": "79.48093"
  },
  {
    "country": "IN",
    "name": "Adūr",
    "lat": "9.15595",
    "lng": "76.73192"
  },
  {
    "country": "IN",
    "name": "Adra",
    "lat": "23.49668",
    "lng": "86.68363"
  },
  {
    "country": "IN",
    "name": "Ādoni",
    "lat": "15.62788",
    "lng": "77.27495"
  },
  {
    "country": "IN",
    "name": "Ādilābād",
    "lat": "19.67203",
    "lng": "78.5359"
  },
  {
    "country": "IN",
    "name": "Addanki",
    "lat": "15.81061",
    "lng": "79.97338"
  },
  {
    "country": "IN",
    "name": "Adalaj",
    "lat": "23.16453",
    "lng": "72.58107"
  },
  {
    "country": "IN",
    "name": "Achhnera",
    "lat": "27.17826",
    "lng": "77.75674"
  },
  {
    "country": "IN",
    "name": "Achalpur",
    "lat": "21.25665",
    "lng": "77.51006"
  },
  {
    "country": "IN",
    "name": "Ābu Road",
    "lat": "24.48012",
    "lng": "72.78186"
  },
  {
    "country": "IN",
    "name": "Ābu",
    "lat": "24.59365",
    "lng": "72.71756"
  },
  {
    "country": "IN",
    "name": "Abohar",
    "lat": "30.14453",
    "lng": "74.19552"
  },
  {
    "country": "IN",
    "name": "Abirāmam",
    "lat": "9.4423",
    "lng": "78.4399"
  },
  {
    "country": "IN",
    "name": "Abhayāpuri",
    "lat": "26.32255",
    "lng": "90.68526"
  },
  {
    "country": "IN",
    "name": "Contai",
    "lat": "21.77985",
    "lng": "87.74892"
  },
  {
    "country": "IN",
    "name": "Haldia",
    "lat": "22.06046",
    "lng": "88.10975"
  },
  {
    "country": "IN",
    "name": "Srirāmpur",
    "lat": "22.94849",
    "lng": "88.01954"
  },
  {
    "country": "IN",
    "name": "Haripur",
    "lat": "22.93611",
    "lng": "88.23194"
  },
  {
    "country": "IN",
    "name": "Kesabpur",
    "lat": "22.96833",
    "lng": "88.26278"
  },
  {
    "country": "IN",
    "name": "Rāmchandrapur",
    "lat": "22.89639",
    "lng": "88.47528"
  },
  {
    "country": "IN",
    "name": "Bāgnān",
    "lat": "22.93338",
    "lng": "88.13856"
  },
  {
    "country": "IN",
    "name": "Rāmnagar",
    "lat": "22.77778",
    "lng": "88.24639"
  },
  {
    "country": "IN",
    "name": "Sankarpur",
    "lat": "22.84839",
    "lng": "88.45126"
  },
  {
    "country": "IN",
    "name": "Begampur",
    "lat": "22.7307",
    "lng": "88.25764"
  },
  {
    "country": "IN",
    "name": "Parbatipur",
    "lat": "22.6625",
    "lng": "88.22222"
  },
  {
    "country": "IN",
    "name": "Bhandārdaha",
    "lat": "22.61476",
    "lng": "88.1919"
  },
  {
    "country": "IN",
    "name": "Dumjor",
    "lat": "22.61993",
    "lng": "88.24566"
  },
  {
    "country": "IN",
    "name": "Krishnapur",
    "lat": "22.67028",
    "lng": "88.26944"
  },
  {
    "country": "IN",
    "name": "Bankra",
    "lat": "22.60291",
    "lng": "88.27751"
  },
  {
    "country": "IN",
    "name": "Chakapara",
    "lat": "22.63222",
    "lng": "88.34861"
  },
  {
    "country": "IN",
    "name": "Mahiari",
    "lat": "22.58826",
    "lng": "88.23544"
  },
  {
    "country": "IN",
    "name": "Masila",
    "lat": "22.58083",
    "lng": "88.23278"
  },
  {
    "country": "IN",
    "name": "Dhulagari",
    "lat": "22.58213",
    "lng": "88.171"
  },
  {
    "country": "IN",
    "name": "Pānchla",
    "lat": "22.53665",
    "lng": "88.13785"
  },
  {
    "country": "IN",
    "name": "Sāhāpur",
    "lat": "22.52444",
    "lng": "88.16694"
  },
  {
    "country": "IN",
    "name": "Raghudebbati",
    "lat": "22.52556",
    "lng": "88.19583"
  },
  {
    "country": "IN",
    "name": "Gobindapur",
    "lat": "22.59306",
    "lng": "88.09139"
  },
  {
    "country": "IN",
    "name": "Nangi",
    "lat": "22.50833",
    "lng": "88.21528"
  },
  {
    "country": "IN",
    "name": "Pujali",
    "lat": "22.4711",
    "lng": "88.1453"
  },
  {
    "country": "IN",
    "name": "Amtala",
    "lat": "22.37046",
    "lng": "88.27864"
  },
  {
    "country": "IN",
    "name": "Bāwāli",
    "lat": "22.42563",
    "lng": "88.19336"
  },
  {
    "country": "IN",
    "name": "Balarāmpur",
    "lat": "22.33417",
    "lng": "88.29778"
  },
  {
    "country": "IN",
    "name": "Jāfarpur",
    "lat": "22.31878",
    "lng": "88.2305"
  },
  {
    "country": "IN",
    "name": "Serpur",
    "lat": "22.32344",
    "lng": "88.30775"
  },
  {
    "country": "IN",
    "name": "Monoharpur",
    "lat": "22.10833",
    "lng": "88.07889"
  },
  {
    "country": "IN",
    "name": "Solap",
    "lat": "22.12778",
    "lng": "88.15861"
  },
  {
    "country": "IN",
    "name": "Harindānga",
    "lat": "22.03833",
    "lng": "88.32139"
  },
  {
    "country": "IN",
    "name": "Gurdaha",
    "lat": "22.73472",
    "lng": "88.75944"
  },
  {
    "country": "IN",
    "name": "Ula",
    "lat": "22.7225",
    "lng": "88.55556"
  },
  {
    "country": "IN",
    "name": "Gopālpur",
    "lat": "22.61845",
    "lng": "88.75119"
  },
  {
    "country": "IN",
    "name": "Raypur",
    "lat": "22.41083",
    "lng": "88.50944"
  },
  {
    "country": "IN",
    "name": "Nabagrām",
    "lat": "22.28806",
    "lng": "88.50917"
  },
  {
    "country": "IN",
    "name": "Soyībug",
    "lat": "34.07677",
    "lng": "74.7057"
  },
  {
    "country": "IN",
    "name": "Jauriān",
    "lat": "32.83255",
    "lng": "74.57612"
  },
  {
    "country": "IN",
    "name": "Chīma",
    "lat": "30.6854",
    "lng": "76.08643"
  },
  {
    "country": "IN",
    "name": "Kheri Sāmpla",
    "lat": "28.7781",
    "lng": "76.7756"
  },
  {
    "country": "IN",
    "name": "Gho Brāhmanān de",
    "lat": "32.5559",
    "lng": "74.9539"
  },
  {
    "country": "IN",
    "name": "Chhutmalpur",
    "lat": "30.03209",
    "lng": "77.75329"
  },
  {
    "country": "IN",
    "name": "Borkhera",
    "lat": "25.52115",
    "lng": "75.64028"
  },
  {
    "country": "IN",
    "name": "Singāpur",
    "lat": "17.46982",
    "lng": "78.12574"
  },
  {
    "country": "IN",
    "name": "Bālāpur",
    "lat": "17.31018",
    "lng": "78.49969"
  },
  {
    "country": "IN",
    "name": "Ghatkesar",
    "lat": "17.45081",
    "lng": "78.68366"
  },
  {
    "country": "IN",
    "name": "Chandūr",
    "lat": "17.87455",
    "lng": "78.10017"
  },
  {
    "country": "IN",
    "name": "Vadigenhalli",
    "lat": "13.29724",
    "lng": "77.80184"
  },
  {
    "country": "IN",
    "name": "Adampur",
    "lat": "31.43224",
    "lng": "75.71484"
  },
  {
    "country": "IN",
    "name": "Chinnasekkadu",
    "lat": "13.16089",
    "lng": "80.25727"
  },
  {
    "country": "IN",
    "name": "Porur",
    "lat": "13.03565",
    "lng": "80.15821"
  },
  {
    "country": "IN",
    "name": "Manappakkam",
    "lat": "13.01083",
    "lng": "80.16861"
  },
  {
    "country": "IN",
    "name": "Madipakkam",
    "lat": "12.96226",
    "lng": "80.19864"
  },
  {
    "country": "IN",
    "name": "Perungudi",
    "lat": "12.96095",
    "lng": "80.24094"
  },
  {
    "country": "IN",
    "name": "Vengavasal",
    "lat": "12.89911",
    "lng": "80.169"
  },
  {
    "country": "IN",
    "name": "Nandambakkam",
    "lat": "12.97795",
    "lng": "80.06781"
  },
  {
    "country": "IN",
    "name": "Madambakkam",
    "lat": "12.8525",
    "lng": "80.04667"
  },
  {
    "country": "IN",
    "name": "Vellānūr",
    "lat": "13.15804",
    "lng": "80.10634"
  },
  {
    "country": "IN",
    "name": "Kupwāra",
    "lat": "34.03056",
    "lng": "74.26417"
  },
  {
    "country": "IN",
    "name": "Powai",
    "lat": "19.1164",
    "lng": "72.90471"
  },
  {
    "country": "IN",
    "name": "Navi Mumbai",
    "lat": "19.03681",
    "lng": "73.01582"
  },
  {
    "country": "IN",
    "name": "Auroville",
    "lat": "12.00549",
    "lng": "79.80885"
  },
  {
    "country": "IN",
    "name": "Puttaparthi",
    "lat": "14.1652",
    "lng": "77.8117"
  },
  {
    "country": "IN",
    "name": "Panchkula",
    "lat": "30.69461",
    "lng": "76.8504"
  },
  {
    "country": "IN",
    "name": "Canacona",
    "lat": "14.9959",
    "lng": "74.05056"
  },
  {
    "country": "IN",
    "name": "Abhaneri",
    "lat": "27.00743",
    "lng": "76.6076"
  },
  {
    "country": "IN",
    "name": "Chowari",
    "lat": "32.4319",
    "lng": "76.012"
  },
  {
    "country": "IN",
    "name": "Murudeshwara",
    "lat": "14.0943",
    "lng": "74.4845"
  },
  {
    "country": "IN",
    "name": "Shivaji Nagar",
    "lat": "18.53017",
    "lng": "73.85263"
  },
  {
    "country": "IN",
    "name": "Greater Noida",
    "lat": "28.49615",
    "lng": "77.53601"
  },
  {
    "country": "IN",
    "name": "Mohali",
    "lat": "30.67995",
    "lng": "76.72211"
  },
  {
    "country": "IN",
    "name": "Banbasa",
    "lat": "28.99132",
    "lng": "80.07608"
  },
  {
    "country": "IN",
    "name": "vadlamuru",
    "lat": "17.09545",
    "lng": "82.16565"
  },
  {
    "country": "IN",
    "name": "Pithampur",
    "lat": "22.60197",
    "lng": "75.69649"
  },
  {
    "country": "IN",
    "name": "Barbil",
    "lat": "22.10194",
    "lng": "85.37752"
  },
  {
    "country": "IN",
    "name": "Airoli",
    "lat": "19.15096",
    "lng": "72.99625"
  },
  {
    "country": "IN",
    "name": "Aluva",
    "lat": "10.10764",
    "lng": "76.35158"
  },
  {
    "country": "IN",
    "name": "Kotkapura",
    "lat": "30.5819",
    "lng": "74.83298"
  },
  {
    "country": "IN",
    "name": "Muvattupuzha",
    "lat": "9.97985",
    "lng": "76.57381"
  },
  {
    "country": "IN",
    "name": "Perumbavoor",
    "lat": "10.10695",
    "lng": "76.47366"
  },
  {
    "country": "IN",
    "name": "Vapi",
    "lat": "20.37175",
    "lng": "72.90493"
  },
  {
    "country": "IN",
    "name": "Baddi",
    "lat": "30.95783",
    "lng": "76.79136"
  },
  {
    "country": "IN",
    "name": "Noida",
    "lat": "28.58",
    "lng": "77.33"
  },
  {
    "country": "IN",
    "name": "Bhiwadi",
    "lat": "28.21024",
    "lng": "76.86056"
  },
  {
    "country": "IN",
    "name": "Parwanoo",
    "lat": "30.83716",
    "lng": "76.96143"
  },
  {
    "country": "IN",
    "name": "Jorethang",
    "lat": "27.10696",
    "lng": "88.32332"
  },
  {
    "country": "IN",
    "name": "Mandideep",
    "lat": "23.08166",
    "lng": "77.53328"
  },
  {
    "country": "IN",
    "name": "Singrauli",
    "lat": "24.19973",
    "lng": "82.67535"
  },
  {
    "country": "IN",
    "name": "Edakkulam",
    "lat": "10.6102",
    "lng": "76.18352"
  },
  {
    "country": "IN",
    "name": "Avanoor",
    "lat": "10.60826",
    "lng": "76.1762"
  },
  {
    "country": "IN",
    "name": "Baga",
    "lat": "15.56517",
    "lng": "73.75517"
  },
  {
    "country": "IN",
    "name": "Birpara",
    "lat": "26.70421",
    "lng": "89.14547"
  },
  {
    "country": "IN",
    "name": "Jaigaon",
    "lat": "26.84766",
    "lng": "89.37558"
  },
  {
    "country": "IN",
    "name": "Palackattumala",
    "lat": "9.74356",
    "lng": "76.6294"
  },
  {
    "country": "IN",
    "name": "Periyapattinam",
    "lat": "9.27263",
    "lng": "78.90232"
  },
  {
    "country": "IN",
    "name": "Pitampura",
    "lat": "28.68964",
    "lng": "77.13126"
  },
  {
    "country": "IN",
    "name": "Vagator",
    "lat": "15.59766",
    "lng": "73.74496"
  },
  {
    "country": "IN",
    "name": "Akkarampalle",
    "lat": "13.65",
    "lng": "79.42"
  },
  {
    "country": "IN",
    "name": "Bellampalli",
    "lat": "19.05577",
    "lng": "79.493"
  },
  {
    "country": "IN",
    "name": "Chemmumiahpet",
    "lat": "15.89794",
    "lng": "79.32129"
  },
  {
    "country": "IN",
    "name": "Gaddi Annaram",
    "lat": "17.36687",
    "lng": "78.5242"
  },
  {
    "country": "IN",
    "name": "Dasnapur",
    "lat": "19.65399",
    "lng": "78.51213"
  },
  {
    "country": "IN",
    "name": "Kanuru",
    "lat": "16.28584",
    "lng": "81.25464"
  },
  {
    "country": "IN",
    "name": "Lal Bahadur Nagar",
    "lat": "17.34769",
    "lng": "78.55757"
  },
  {
    "country": "IN",
    "name": "Malkajgiri",
    "lat": "17.44781",
    "lng": "78.52633"
  },
  {
    "country": "IN",
    "name": "Mandamarri",
    "lat": "18.96506",
    "lng": "79.47475"
  },
  {
    "country": "IN",
    "name": "Chinnachowk",
    "lat": "14.47516",
    "lng": "78.8354"
  },
  {
    "country": "IN",
    "name": "Kyathampalle",
    "lat": "19.66781",
    "lng": "78.5289"
  },
  {
    "country": "IN",
    "name": "Gajuwaka",
    "lat": "17.7",
    "lng": "83.21667"
  },
  {
    "country": "IN",
    "name": "Manuguru",
    "lat": "17.98102",
    "lng": "80.7547"
  },
  {
    "country": "IN",
    "name": "Kalyandurg",
    "lat": "14.54519",
    "lng": "77.10552"
  },
  {
    "country": "IN",
    "name": "Ponnur",
    "lat": "16.07114",
    "lng": "80.54944"
  },
  {
    "country": "IN",
    "name": "Quthbullapur",
    "lat": "17.50107",
    "lng": "78.45818"
  },
  {
    "country": "IN",
    "name": "Ramanayyapeta",
    "lat": "16.94516",
    "lng": "82.2385"
  },
  {
    "country": "IN",
    "name": "Palwancha",
    "lat": "17.58152",
    "lng": "80.67651"
  },
  {
    "country": "IN",
    "name": "Barpeta Road",
    "lat": "26.50284",
    "lng": "90.96937"
  },
  {
    "country": "IN",
    "name": "Sathupalli",
    "lat": "17.24968",
    "lng": "80.86899"
  },
  {
    "country": "IN",
    "name": "Yanamalakuduru",
    "lat": "16.48531",
    "lng": "80.66746"
  },
  {
    "country": "IN",
    "name": "Morigaon",
    "lat": "26.24908",
    "lng": "92.34764"
  },
  {
    "country": "IN",
    "name": "Naharlagun",
    "lat": "27.10467",
    "lng": "93.69518"
  },
  {
    "country": "IN",
    "name": "Serilingampalle",
    "lat": "17.49313",
    "lng": "78.30196"
  },
  {
    "country": "IN",
    "name": "Silapathar",
    "lat": "27.59441",
    "lng": "94.72402"
  },
  {
    "country": "IN",
    "name": "Sarupathar",
    "lat": "26.206",
    "lng": "96.81"
  },
  {
    "country": "IN",
    "name": "Lumding Railway Colony",
    "lat": "25.74903",
    "lng": "93.16998"
  },
  {
    "country": "IN",
    "name": "Aistala",
    "lat": "23.18",
    "lng": "88.58"
  },
  {
    "country": "IN",
    "name": "Ashoknagar Kalyangarh",
    "lat": "22.86416",
    "lng": "88.63701"
  },
  {
    "country": "IN",
    "name": "Bahula",
    "lat": "23.65176",
    "lng": "87.16475"
  },
  {
    "country": "IN",
    "name": "Pavuluru",
    "lat": "15.85292",
    "lng": "80.16468"
  },
  {
    "country": "IN",
    "name": "pedda nakkalapalem",
    "lat": "15.8668",
    "lng": "80.16202"
  },
  {
    "country": "IN",
    "name": "Jhulasan",
    "lat": "23.3286",
    "lng": "72.47314"
  },
  {
    "country": "IN",
    "name": "Bhawanipur",
    "lat": "26.45352",
    "lng": "87.02744"
  },
  {
    "country": "IN",
    "name": "Zira",
    "lat": "30.96853",
    "lng": "74.99106"
  },
  {
    "country": "IN",
    "name": "Williamnagar",
    "lat": "25.4955",
    "lng": "90.6168"
  },
  {
    "country": "IN",
    "name": "Nangilickondan",
    "lat": "12.25539",
    "lng": "79.47508"
  },
  {
    "country": "IN",
    "name": "Artist Village",
    "lat": "19.03227",
    "lng": "73.04276"
  },
  {
    "country": "IN",
    "name": "Ramagundam",
    "lat": "18.755",
    "lng": "79.474"
  },
  {
    "country": "IN",
    "name": "Govindapuram,Chilakaluripet,Guntur",
    "lat": "16.15477",
    "lng": "80.10279"
  },
  {
    "country": "IN",
    "name": "Cherpulassery",
    "lat": "10.87655",
    "lng": "76.30932"
  },
  {
    "country": "IN",
    "name": "Biswanath Chariali",
    "lat": "26.72577",
    "lng": "93.14659"
  },
  {
    "country": "IN",
    "name": "Kagaznāgār",
    "lat": "19.33159",
    "lng": "79.46605"
  },
  {
    "country": "IN",
    "name": "Kirandul",
    "lat": "18.63649",
    "lng": "81.25827"
  },
  {
    "country": "IN",
    "name": "Dayapar",
    "lat": "23.63371",
    "lng": "68.90192"
  },
  {
    "country": "IN",
    "name": "Paikpara",
    "lat": "24.77121",
    "lng": "87.92251"
  },
  {
    "country": "IN",
    "name": "Thoothukudi",
    "lat": "8.76735",
    "lng": "78.13425"
  },
  {
    "country": "IN",
    "name": "Kalimpong, Крукети",
    "lat": "27.05623",
    "lng": "88.46207"
  },
  {
    "country": "IN",
    "name": "Shiraguppi",
    "lat": "16.61875",
    "lng": "74.70907"
  },
  {
    "country": "IN",
    "name": "Gadag-Betageri",
    "lat": "15.4167",
    "lng": "75.6167"
  },
  {
    "country": "IN",
    "name": "Bishnupur",
    "lat": "24.62845",
    "lng": "93.76179"
  },
  {
    "country": "IN",
    "name": "V.S.K.Valasai (Dindigul-Dist.)",
    "lat": "10.31549",
    "lng": "78.15141"
  },
  {
    "country": "IN",
    "name": "Gangadharpur",
    "lat": "22.76",
    "lng": "88.22"
  },
  {
    "country": "IN",
    "name": "Neemuch",
    "lat": "24.47639",
    "lng": "74.86241"
  },
  {
    "country": "IN",
    "name": "Dasarahalli",
    "lat": "13.09904",
    "lng": "77.83204"
  },
  {
    "country": "IN",
    "name": "Neelankarai",
    "lat": "12.9495",
    "lng": "80.2592"
  },
  {
    "country": "IN",
    "name": "Injambakkam",
    "lat": "12.9162",
    "lng": "80.2488"
  },
  {
    "country": "IN",
    "name": "Palavakkam",
    "lat": "12.9535",
    "lng": "80.2572"
  },
  {
    "country": "IN",
    "name": "Kultali",
    "lat": "21.9",
    "lng": "88.4"
  },
  {
    "country": "IN",
    "name": "Mushalpur",
    "lat": "26.5792",
    "lng": "91.4261"
  },
  {
    "country": "IN",
    "name": "Shahbazpur",
    "lat": "26.30511",
    "lng": "87.28865"
  },
  {
    "country": "IN",
    "name": "Bhagirathpur",
    "lat": "26.2695",
    "lng": "86.06346"
  },
  {
    "country": "IN",
    "name": "Inda Chhoi",
    "lat": "29.64042",
    "lng": "75.79041"
  },
  {
    "country": "IN",
    "name": "Deoli",
    "lat": "28.50254",
    "lng": "77.23117"
  },
  {
    "country": "IN",
    "name": "Defence Colony",
    "lat": "28.57144",
    "lng": "77.23272"
  },
  {
    "country": "IN",
    "name": "Kumbalam",
    "lat": "9.9063",
    "lng": "76.31127"
  },
  {
    "country": "IN",
    "name": "Aroor",
    "lat": "9.8694",
    "lng": "76.30498"
  },
  {
    "country": "IN",
    "name": "Kadakkavoor",
    "lat": "8.67921",
    "lng": "76.76714"
  },
  {
    "country": "IN",
    "name": "Kalavoor",
    "lat": "9.57046",
    "lng": "76.32756"
  },
  {
    "country": "IN",
    "name": "Kalamassery",
    "lat": "10.0614",
    "lng": "76.32631"
  },
  {
    "country": "IN",
    "name": "Akasahebpet",
    "lat": "17.50455",
    "lng": "82.56597"
  },
  {
    "country": "IN",
    "name": "Cherthala",
    "lat": "9.68444",
    "lng": "76.33558"
  },
  {
    "country": "IN",
    "name": "Kunnumma",
    "lat": "9.35672",
    "lng": "76.41343"
  },
  {
    "country": "IN",
    "name": "Abrama",
    "lat": "20.85865",
    "lng": "72.90648"
  },
  {
    "country": "IN",
    "name": "Hawai",
    "lat": "27.88677",
    "lng": "96.8017"
  },
  {
    "country": "IN",
    "name": "Longleng",
    "lat": "26.48989",
    "lng": "94.81772"
  },
  {
    "country": "IN",
    "name": "Savarkundla",
    "lat": "21.33726",
    "lng": "71.3035"
  },
  {
    "country": "IN",
    "name": "Resubelpara",
    "lat": "25.90404",
    "lng": "90.60747"
  },
  {
    "country": "IN",
    "name": "Namsai",
    "lat": "27.66904",
    "lng": "95.86395"
  },
  {
    "country": "IN",
    "name": "Hatsingimari",
    "lat": "25.70986",
    "lng": "89.90078"
  },
  {
    "country": "IN",
    "name": "Malkapur",
    "lat": "17.26214",
    "lng": "74.17574"
  },
  {
    "country": "IN",
    "name": "Nagarukhra",
    "lat": "22.94099",
    "lng": "88.63701"
  },
  {
    "country": "IN",
    "name": "Garha Brahman",
    "lat": "23.86873",
    "lng": "77.35731"
  },
  {
    "country": "IN",
    "name": "Sector",
    "lat": "28.5708",
    "lng": "77.3261"
  },
  {
    "country": "IN",
    "name": "Jiribam",
    "lat": "24.80427",
    "lng": "93.12148"
  },
  {
    "country": "IN",
    "name": "Kamjong",
    "lat": "24.85846",
    "lng": "94.51549"
  },
  {
    "country": "IN",
    "name": "Pherzawl",
    "lat": "24.26227",
    "lng": "93.18873"
  },
  {
    "country": "IN",
    "name": "Chandel",
    "lat": "24.32987",
    "lng": "94.00379"
  },
  {
    "country": "IN",
    "name": "Tengnoupal",
    "lat": "24.3855",
    "lng": "94.1472"
  },
  {
    "country": "IN",
    "name": "Garamur",
    "lat": "26.94891",
    "lng": "94.17205"
  },
  {
    "country": "IN",
    "name": "Bishramganj",
    "lat": "23.60582",
    "lng": "91.34355"
  },
  {
    "country": "IN",
    "name": "Bhupalpally",
    "lat": "18.21314",
    "lng": "79.92729"
  },
  {
    "country": "IN",
    "name": "Ampati",
    "lat": "25.4623",
    "lng": "89.93325"
  },
  {
    "country": "IN",
    "name": "Khliehriat",
    "lat": "25.35776",
    "lng": "92.36643"
  },
  {
    "country": "IN",
    "name": "Shahdara",
    "lat": "28.60311",
    "lng": "77.13988"
  },
  {
    "country": "IN",
    "name": "Balrampur",
    "lat": "23.61219",
    "lng": "83.61115"
  },
  {
    "country": "IN",
    "name": "Hamren",
    "lat": "25.93354",
    "lng": "92.61656"
  },
  {
    "country": "IN",
    "name": "Sonari",
    "lat": "27.07344",
    "lng": "95.02753"
  },
  {
    "country": "IN",
    "name": "Pangin",
    "lat": "28.21022",
    "lng": "94.98873"
  },
  {
    "country": "IQ",
    "name": "Zāwītah",
    "lat": "36.90547",
    "lng": "43.14478"
  },
  {
    "country": "IQ",
    "name": "Zaxo",
    "lat": "37.14871",
    "lng": "42.68591"
  },
  {
    "country": "IQ",
    "name": "Umm Qaşr",
    "lat": "30.0362",
    "lng": "47.91951"
  },
  {
    "country": "IQ",
    "name": "Tozkhurmato",
    "lat": "34.88808",
    "lng": "44.63256"
  },
  {
    "country": "IQ",
    "name": "Tikrīt",
    "lat": "34.61581",
    "lng": "43.67861"
  },
  {
    "country": "IQ",
    "name": "Dāqūq",
    "lat": "35.13923",
    "lng": "44.44907"
  },
  {
    "country": "IQ",
    "name": "Tallkayf",
    "lat": "36.49118",
    "lng": "43.12114"
  },
  {
    "country": "IQ",
    "name": "Tall ‘Afar",
    "lat": "36.37913",
    "lng": "42.44806"
  },
  {
    "country": "IQ",
    "name": "Sūq ash Shuyūkh",
    "lat": "30.89086",
    "lng": "46.45425"
  },
  {
    "country": "IQ",
    "name": "Saymayl",
    "lat": "36.85823",
    "lng": "42.8482"
  },
  {
    "country": "IQ",
    "name": "Sīnah",
    "lat": "36.80851",
    "lng": "43.03935"
  },
  {
    "country": "IQ",
    "name": "‘Ayn Tamr",
    "lat": "32.56687",
    "lng": "43.48815"
  },
  {
    "country": "IQ",
    "name": "Ash Sharqāt",
    "lat": "35.51722",
    "lng": "43.22806"
  },
  {
    "country": "IQ",
    "name": "Shaqlāwah",
    "lat": "36.40422",
    "lng": "44.32563"
  },
  {
    "country": "IQ",
    "name": "Seyid Sadiq",
    "lat": "35.35278",
    "lng": "45.86682"
  },
  {
    "country": "IQ",
    "name": "Sāmarrā’",
    "lat": "34.1959",
    "lng": "43.88568"
  },
  {
    "country": "IQ",
    "name": "Nāḩīyat Saddat al Hindīyah",
    "lat": "32.71557",
    "lng": "44.27857"
  },
  {
    "country": "IQ",
    "name": "Ruwāndiz",
    "lat": "36.61207",
    "lng": "44.52372"
  },
  {
    "country": "IQ",
    "name": "Rāwah",
    "lat": "34.48229",
    "lng": "41.91898"
  },
  {
    "country": "IQ",
    "name": "Ṟaniye",
    "lat": "36.25511",
    "lng": "44.88239"
  },
  {
    "country": "IQ",
    "name": "Al Qā’im",
    "lat": "34.39251",
    "lng": "40.98945"
  },
  {
    "country": "IQ",
    "name": "Al-Hamdaniya",
    "lat": "36.27093",
    "lng": "43.37758"
  },
  {
    "country": "IQ",
    "name": "Qeredagh",
    "lat": "35.3071",
    "lng": "45.3906"
  },
  {
    "country": "IQ",
    "name": "Qal‘at Şāliḩ",
    "lat": "31.52802",
    "lng": "47.29362"
  },
  {
    "country": "IQ",
    "name": "Qeładizê",
    "lat": "36.18254",
    "lng": "45.13017"
  },
  {
    "country": "IQ",
    "name": "Mêrgasur",
    "lat": "36.84069",
    "lng": "44.30229"
  },
  {
    "country": "IQ",
    "name": "Mawet",
    "lat": "35.90123",
    "lng": "45.41422"
  },
  {
    "country": "IQ",
    "name": "Mandalī",
    "lat": "33.7481",
    "lng": "45.55503"
  },
  {
    "country": "IQ",
    "name": "Mexmur",
    "lat": "35.77622",
    "lng": "43.57974"
  },
  {
    "country": "IQ",
    "name": "Koysinceq",
    "lat": "36.08289",
    "lng": "44.62873"
  },
  {
    "country": "IQ",
    "name": "Kifrī",
    "lat": "34.68963",
    "lng": "44.96057"
  },
  {
    "country": "IQ",
    "name": "Khānaqīn",
    "lat": "34.3482",
    "lng": "45.39065"
  },
  {
    "country": "IQ",
    "name": "Kirkuk",
    "lat": "35.46806",
    "lng": "44.39222"
  },
  {
    "country": "IQ",
    "name": "Karbala",
    "lat": "32.61603",
    "lng": "44.02488"
  },
  {
    "country": "IQ",
    "name": "Ain Nuni",
    "lat": "37.22781",
    "lng": "43.43732"
  },
  {
    "country": "IQ",
    "name": "Kelar",
    "lat": "34.62805",
    "lng": "45.31852"
  },
  {
    "country": "IQ",
    "name": "Al ‘Abbāsī",
    "lat": "35.27517",
    "lng": "43.59593"
  },
  {
    "country": "IQ",
    "name": "Erbil",
    "lat": "36.18333",
    "lng": "44.01193"
  },
  {
    "country": "IQ",
    "name": "Hīt",
    "lat": "33.63664",
    "lng": "42.82768"
  },
  {
    "country": "IQ",
    "name": "Hīrān",
    "lat": "36.27757",
    "lng": "44.49334"
  },
  {
    "country": "IQ",
    "name": "Al Ḩaqlānīyah",
    "lat": "34.08599",
    "lng": "42.36174"
  },
  {
    "country": "IQ",
    "name": "Ḩalabjah",
    "lat": "35.17778",
    "lng": "45.98611"
  },
  {
    "country": "IQ",
    "name": "Ḩadīthah",
    "lat": "34.13661",
    "lng": "42.37727"
  },
  {
    "country": "IQ",
    "name": "Xebat",
    "lat": "36.27798",
    "lng": "43.67065"
  },
  {
    "country": "IQ",
    "name": "Dukan",
    "lat": "35.92922",
    "lng": "44.96282"
  },
  {
    "country": "IQ",
    "name": "Soran",
    "lat": "36.6532",
    "lng": "44.54407"
  },
  {
    "country": "IQ",
    "name": "Dihok",
    "lat": "36.86709",
    "lng": "42.98845"
  },
  {
    "country": "IQ",
    "name": "Dibis",
    "lat": "35.67482",
    "lng": "44.07067"
  },
  {
    "country": "IQ",
    "name": "Derkar",
    "lat": "37.19989",
    "lng": "42.82361"
  },
  {
    "country": "IQ",
    "name": "Chwarta",
    "lat": "35.72659",
    "lng": "45.57232"
  },
  {
    "country": "IQ",
    "name": "Jamjamāl",
    "lat": "35.53356",
    "lng": "44.8343"
  },
  {
    "country": "IQ",
    "name": "Al Jabāyish",
    "lat": "30.96588",
    "lng": "47.00196"
  },
  {
    "country": "IQ",
    "name": "Bayjī",
    "lat": "34.92915",
    "lng": "43.48878"
  },
  {
    "country": "IQ",
    "name": "Batufe",
    "lat": "37.17454",
    "lng": "43.01233"
  },
  {
    "country": "IQ",
    "name": "Baqubah",
    "lat": "33.75403",
    "lng": "44.60518"
  },
  {
    "country": "IQ",
    "name": "Baynjiwayn",
    "lat": "35.62329",
    "lng": "45.94714"
  },
  {
    "country": "IQ",
    "name": "Bāmarnī",
    "lat": "37.12163",
    "lng": "43.2709"
  },
  {
    "country": "IQ",
    "name": "Baladrūz",
    "lat": "33.69631",
    "lng": "45.07782"
  },
  {
    "country": "IQ",
    "name": "Balad",
    "lat": "34.01485",
    "lng": "44.14574"
  },
  {
    "country": "IQ",
    "name": "Beḧirke",
    "lat": "36.31556",
    "lng": "44.03533"
  },
  {
    "country": "IQ",
    "name": "Baghdad",
    "lat": "33.34058",
    "lng": "44.40088"
  },
  {
    "country": "IQ",
    "name": "Badrah",
    "lat": "33.11508",
    "lng": "45.93344"
  },
  {
    "country": "IQ",
    "name": "Az Zubayr",
    "lat": "30.39213",
    "lng": "47.70175"
  },
  {
    "country": "IQ",
    "name": "Ash Shaykhān",
    "lat": "36.69595",
    "lng": "43.35202"
  },
  {
    "country": "IQ",
    "name": "‘Aynkāwah",
    "lat": "36.2306",
    "lng": "43.99442"
  },
  {
    "country": "IQ",
    "name": "Aţ Ţārmīyah",
    "lat": "33.67444",
    "lng": "44.39583"
  },
  {
    "country": "IQ",
    "name": "Aş Şuwayrah",
    "lat": "32.92556",
    "lng": "44.77583"
  },
  {
    "country": "IQ",
    "name": "As Sulaymānīyah",
    "lat": "35.56496",
    "lng": "45.4329"
  },
  {
    "country": "IQ",
    "name": "As Samawah",
    "lat": "31.33198",
    "lng": "45.2944"
  },
  {
    "country": "IQ",
    "name": "As Salmān",
    "lat": "30.50464",
    "lng": "44.53943"
  },
  {
    "country": "IQ",
    "name": "Nāḩiyat ash Shināfīyah",
    "lat": "31.58376",
    "lng": "44.64675"
  },
  {
    "country": "IQ",
    "name": "Ash Shaţrah",
    "lat": "31.40906",
    "lng": "46.1727"
  },
  {
    "country": "IQ",
    "name": "Ash Shāmīyah",
    "lat": "31.96257",
    "lng": "44.60075"
  },
  {
    "country": "IQ",
    "name": "Ar Ruţbah",
    "lat": "33.03718",
    "lng": "40.28586"
  },
  {
    "country": "IQ",
    "name": "Ar Rumaythah",
    "lat": "31.52845",
    "lng": "45.20377"
  },
  {
    "country": "IQ",
    "name": "Ar Riyāḑ",
    "lat": "35.26964",
    "lng": "43.91067"
  },
  {
    "country": "IQ",
    "name": "Ar Rifā‘ī",
    "lat": "31.72079",
    "lng": "46.10778"
  },
  {
    "country": "IQ",
    "name": "Ramadi",
    "lat": "33.42056",
    "lng": "43.30778"
  },
  {
    "country": "IQ",
    "name": "‘Aqrah",
    "lat": "36.76038",
    "lng": "43.89428"
  },
  {
    "country": "IQ",
    "name": "An Nu‘mānīyah",
    "lat": "32.55621",
    "lng": "45.41293"
  },
  {
    "country": "IQ",
    "name": "Nasiriyah",
    "lat": "31.05799",
    "lng": "46.25726"
  },
  {
    "country": "IQ",
    "name": "Najaf",
    "lat": "32.02594",
    "lng": "44.34625"
  },
  {
    "country": "IQ",
    "name": "‘Anat al Qadīmah",
    "lat": "34.46934",
    "lng": "41.94223"
  },
  {
    "country": "IQ",
    "name": "Al Qurnah",
    "lat": "31.01547",
    "lng": "47.43362"
  },
  {
    "country": "IQ",
    "name": "Al Qayyārah",
    "lat": "35.79933",
    "lng": "43.29447"
  },
  {
    "country": "IQ",
    "name": "Imam Qasim",
    "lat": "32.29799",
    "lng": "44.68282"
  },
  {
    "country": "IQ",
    "name": "Al Musayyib",
    "lat": "32.77872",
    "lng": "44.29005"
  },
  {
    "country": "IQ",
    "name": "Al Mishkhāb",
    "lat": "31.80437",
    "lng": "44.4893"
  },
  {
    "country": "IQ",
    "name": "Al Miqdādīyah",
    "lat": "33.97861",
    "lng": "44.93694"
  },
  {
    "country": "IQ",
    "name": "Al Maymūnah",
    "lat": "31.679",
    "lng": "46.96948"
  },
  {
    "country": "IQ",
    "name": "Al Mawşil al Jadīdah",
    "lat": "36.33271",
    "lng": "43.10555"
  },
  {
    "country": "IQ",
    "name": "Mosul",
    "lat": "36.335",
    "lng": "43.11889"
  },
  {
    "country": "IQ",
    "name": "Al Maḩmūdīyah",
    "lat": "33.06221",
    "lng": "44.36564"
  },
  {
    "country": "IQ",
    "name": "Al Maḩāwīl",
    "lat": "32.66138",
    "lng": "44.40854"
  },
  {
    "country": "IQ",
    "name": "Al Madīnah",
    "lat": "30.96324",
    "lng": "47.26998"
  },
  {
    "country": "IQ",
    "name": "Al Kūt",
    "lat": "32.5128",
    "lng": "45.81817"
  },
  {
    "country": "IQ",
    "name": "Kufa",
    "lat": "32.05114",
    "lng": "44.44017"
  },
  {
    "country": "IQ",
    "name": "Al Khāliş",
    "lat": "33.85118",
    "lng": "44.52047"
  },
  {
    "country": "IQ",
    "name": "Khāliş",
    "lat": "33.80809",
    "lng": "44.53343"
  },
  {
    "country": "IQ",
    "name": "Al Kaḩlā’",
    "lat": "31.66789",
    "lng": "47.2945"
  },
  {
    "country": "IQ",
    "name": "‘Alī al Gharbī",
    "lat": "32.46186",
    "lng": "46.68794"
  },
  {
    "country": "IQ",
    "name": "Al Hindīyah",
    "lat": "32.54671",
    "lng": "44.22765"
  },
  {
    "country": "IQ",
    "name": "Al Ḩillah",
    "lat": "32.46367",
    "lng": "44.41963"
  },
  {
    "country": "IQ",
    "name": "Al Ḩayy",
    "lat": "32.17419",
    "lng": "46.04345"
  },
  {
    "country": "IQ",
    "name": "Al Hāshimīyah",
    "lat": "32.36351",
    "lng": "44.66011"
  },
  {
    "country": "IQ",
    "name": "Al Hārithah",
    "lat": "30.58481",
    "lng": "47.76114"
  },
  {
    "country": "IQ",
    "name": "Al Ḩamzah",
    "lat": "31.72444",
    "lng": "44.97694"
  },
  {
    "country": "IQ",
    "name": "Al Ḩaḑar",
    "lat": "35.5729",
    "lng": "42.73395"
  },
  {
    "country": "IQ",
    "name": "Nahiyat Ghammas",
    "lat": "31.74311",
    "lng": "44.6196"
  },
  {
    "country": "IQ",
    "name": "Nāḩiyat al Fuhūd",
    "lat": "30.96972",
    "lng": "46.72278"
  },
  {
    "country": "IQ",
    "name": "Al Fāw",
    "lat": "29.97421",
    "lng": "48.47309"
  },
  {
    "country": "IQ",
    "name": "Al Fallūjah",
    "lat": "33.34913",
    "lng": "43.78599"
  },
  {
    "country": "IQ",
    "name": "Al Ba‘āj",
    "lat": "36.0426",
    "lng": "41.71632"
  },
  {
    "country": "IQ",
    "name": "Basrah",
    "lat": "30.50852",
    "lng": "47.7804"
  },
  {
    "country": "IQ",
    "name": "Al ‘Azīzīyah",
    "lat": "32.90941",
    "lng": "45.06359"
  },
  {
    "country": "IQ",
    "name": "Al ‘Awjah",
    "lat": "34.53333",
    "lng": "43.73333"
  },
  {
    "country": "IQ",
    "name": "Al ‘Amārah",
    "lat": "31.83561",
    "lng": "47.14483"
  },
  {
    "country": "IQ",
    "name": "Al ‘Amādīyah",
    "lat": "37.09214",
    "lng": "43.48769"
  },
  {
    "country": "IQ",
    "name": "‘Afak",
    "lat": "32.0643",
    "lng": "45.24743"
  },
  {
    "country": "IQ",
    "name": "Ad Dujayl",
    "lat": "33.84667",
    "lng": "44.23444"
  },
  {
    "country": "IQ",
    "name": "Ad Dīwānīyah",
    "lat": "31.99289",
    "lng": "44.92552"
  },
  {
    "country": "IQ",
    "name": "Ad Dawr",
    "lat": "34.45597",
    "lng": "43.79341"
  },
  {
    "country": "IQ",
    "name": "Al Manādhirah",
    "lat": "31.90692",
    "lng": "44.48649"
  },
  {
    "country": "IQ",
    "name": "Abī al Khaşīb",
    "lat": "30.44636",
    "lng": "47.97813"
  },
  {
    "country": "IQ",
    "name": "Abū Ghurayb",
    "lat": "33.30563",
    "lng": "44.18477"
  },
  {
    "country": "IQ",
    "name": "Derbendîxan",
    "lat": "35.11207",
    "lng": "45.68663"
  },
  {
    "country": "IQ",
    "name": "Al Başrah al Qadīmah",
    "lat": "30.50316",
    "lng": "47.81507"
  },
  {
    "country": "IQ",
    "name": "Al Ḩawījah",
    "lat": "35.32592",
    "lng": "43.77267"
  },
  {
    "country": "IQ",
    "name": "Qushtepe",
    "lat": "36.00193",
    "lng": "44.03827"
  },
  {
    "country": "IQ",
    "name": "Dare Tû",
    "lat": "36.12062",
    "lng": "44.05972"
  },
  {
    "country": "IQ",
    "name": "Kasnazān",
    "lat": "36.20067",
    "lng": "44.13263"
  },
  {
    "country": "IQ",
    "name": "Choman",
    "lat": "36.63665",
    "lng": "44.8882"
  },
  {
    "country": "IQ",
    "name": "Sinjār",
    "lat": "36.3209",
    "lng": "41.87656"
  },
  {
    "country": "IQ",
    "name": "Halshaw",
    "lat": "36.20901",
    "lng": "45.25926"
  },
  {
    "country": "IQ",
    "name": "‘Anah",
    "lat": "34.36857",
    "lng": "41.98194"
  },
  {
    "country": "IQ",
    "name": "Ibrāhīm al Khalīl",
    "lat": "37.13963",
    "lng": "42.56995"
  },
  {
    "country": "IQ",
    "name": "Nāḩiyat Hīrān",
    "lat": "36.27899",
    "lng": "44.48815"
  },
  {
    "country": "IQ",
    "name": "Nāḩiyat Baḩār",
    "lat": "30.17649",
    "lng": "48.39775"
  },
  {
    "country": "IQ",
    "name": "Nāḩiyat ‘Atbah",
    "lat": "30.48117",
    "lng": "48.01424"
  },
  {
    "country": "IQ",
    "name": "Nāḩiyat Alī ash Sharqī",
    "lat": "32.12287",
    "lng": "46.74928"
  },
  {
    "country": "IQ",
    "name": "Hayraw",
    "lat": "36.12659",
    "lng": "45.28292"
  },
  {
    "country": "IQ",
    "name": "Zaxu",
    "lat": "37.14246",
    "lng": "42.68187"
  },
  {
    "country": "IQ",
    "name": "Ḩalabjah al Jadīdah",
    "lat": "35.31975",
    "lng": "45.68948"
  },
  {
    "country": "IR",
    "name": "Shahrak",
    "lat": "36.17449",
    "lng": "50.76908"
  },
  {
    "country": "IR",
    "name": "Alvand",
    "lat": "36.1893",
    "lng": "50.0643"
  },
  {
    "country": "IR",
    "name": "Āzādshahr",
    "lat": "34.79049",
    "lng": "48.57011"
  },
  {
    "country": "IR",
    "name": "Nīr",
    "lat": "38.0346",
    "lng": "47.9986"
  },
  {
    "country": "IR",
    "name": "Qarah Āghāj",
    "lat": "37.2187",
    "lng": "47.2167"
  },
  {
    "country": "IR",
    "name": "Bostānābād",
    "lat": "37.84633",
    "lng": "46.83542"
  },
  {
    "country": "IR",
    "name": "Kahrīz",
    "lat": "34.3838",
    "lng": "47.0553"
  },
  {
    "country": "IR",
    "name": "Nūrābād",
    "lat": "34.0734",
    "lng": "47.9725"
  },
  {
    "country": "IR",
    "name": "Javānrūd",
    "lat": "34.8067",
    "lng": "46.4913"
  },
  {
    "country": "IR",
    "name": "Bozghān",
    "lat": "36.28639",
    "lng": "58.58586"
  },
  {
    "country": "IR",
    "name": "Kalāt-e Nāderī",
    "lat": "36.99532",
    "lng": "59.76472"
  },
  {
    "country": "IR",
    "name": "Īstgāh-e Rāh Āhan-e Garmsār",
    "lat": "35.23455",
    "lng": "52.30942"
  },
  {
    "country": "IR",
    "name": "Qarchak",
    "lat": "35.42867",
    "lng": "51.57544"
  },
  {
    "country": "IR",
    "name": "Shahrak-e Emām Ḩasan",
    "lat": "35.48846",
    "lng": "51.34567"
  },
  {
    "country": "IR",
    "name": "Shahre Jadide Andisheh",
    "lat": "35.6803",
    "lng": "51.0193"
  },
  {
    "country": "IR",
    "name": "Omīdcheh",
    "lat": "38.28667",
    "lng": "48.14139"
  },
  {
    "country": "IR",
    "name": "Āq Qāyeh",
    "lat": "37.27472",
    "lng": "55.15889"
  },
  {
    "country": "IR",
    "name": "Gomīshān",
    "lat": "37.0718",
    "lng": "54.07654"
  },
  {
    "country": "IR",
    "name": "Pā’īn-e Bāzār-e Rūdbār",
    "lat": "36.8211",
    "lng": "49.4264"
  },
  {
    "country": "IR",
    "name": "Khorramdarreh",
    "lat": "36.20777",
    "lng": "49.19527"
  },
  {
    "country": "IR",
    "name": "Pādegān-e Manjīl",
    "lat": "36.7415",
    "lng": "49.4161"
  },
  {
    "country": "IR",
    "name": "Kavār",
    "lat": "29.205",
    "lng": "52.6899"
  },
  {
    "country": "IR",
    "name": "Yasuj",
    "lat": "30.66824",
    "lng": "51.58796"
  },
  {
    "country": "IR",
    "name": "Āzādshahr",
    "lat": "37.08641",
    "lng": "55.17222"
  },
  {
    "country": "IR",
    "name": "Ziabar (Gaskar)",
    "lat": "37.4261",
    "lng": "49.2459"
  },
  {
    "country": "IR",
    "name": "Zarrīnābād",
    "lat": "36.42622",
    "lng": "48.28158"
  },
  {
    "country": "IR",
    "name": "Zarand",
    "lat": "30.81271",
    "lng": "56.56399"
  },
  {
    "country": "IR",
    "name": "Zanjān",
    "lat": "36.67642",
    "lng": "48.49628"
  },
  {
    "country": "IR",
    "name": "Yazd",
    "lat": "31.89722",
    "lng": "54.3675"
  },
  {
    "country": "IR",
    "name": "Vasīān",
    "lat": "33.49083",
    "lng": "48.04917"
  },
  {
    "country": "IR",
    "name": "Varazqān",
    "lat": "38.67549",
    "lng": "46.11205"
  },
  {
    "country": "IR",
    "name": "Varāmīn",
    "lat": "35.3242",
    "lng": "51.6457"
  },
  {
    "country": "IR",
    "name": "Tūyserkān",
    "lat": "34.551",
    "lng": "48.44353"
  },
  {
    "country": "IR",
    "name": "Ţorqabeh",
    "lat": "36.3104",
    "lng": "59.3735"
  },
  {
    "country": "IR",
    "name": "Torbat-e Ḩeydarīyeh",
    "lat": "35.27401",
    "lng": "59.21949"
  },
  {
    "country": "IR",
    "name": "Tonekābon",
    "lat": "36.81626",
    "lng": "50.87376"
  },
  {
    "country": "IR",
    "name": "Tehran",
    "lat": "35.69439",
    "lng": "51.42151"
  },
  {
    "country": "IR",
    "name": "Hashtpar",
    "lat": "37.79658",
    "lng": "48.90521"
  },
  {
    "country": "IR",
    "name": "Ţāleb ābād",
    "lat": "35.5013",
    "lng": "51.53147"
  },
  {
    "country": "IR",
    "name": "Tākestān",
    "lat": "36.07057",
    "lng": "49.69571"
  },
  {
    "country": "IR",
    "name": "Takāb",
    "lat": "36.4009",
    "lng": "47.1133"
  },
  {
    "country": "IR",
    "name": "Tajrīsh",
    "lat": "35.8044",
    "lng": "51.4256"
  },
  {
    "country": "IR",
    "name": "Shahr-e Herāt",
    "lat": "30.05407",
    "lng": "54.37294"
  },
  {
    "country": "IR",
    "name": "Taft",
    "lat": "31.74384",
    "lng": "54.20278"
  },
  {
    "country": "IR",
    "name": "Tafresh",
    "lat": "34.69307",
    "lng": "50.01601"
  },
  {
    "country": "IR",
    "name": "Tabriz",
    "lat": "38.08",
    "lng": "46.2919"
  },
  {
    "country": "IR",
    "name": "Tabas",
    "lat": "33.59586",
    "lng": "56.92437"
  },
  {
    "country": "IR",
    "name": "Sūrīān",
    "lat": "30.4551",
    "lng": "53.651"
  },
  {
    "country": "IR",
    "name": "Sūrak",
    "lat": "36.59488",
    "lng": "53.20762"
  },
  {
    "country": "IR",
    "name": "Nūr",
    "lat": "36.57168",
    "lng": "52.0153"
  },
  {
    "country": "IR",
    "name": "Şowme‘eh Sarā",
    "lat": "37.30134",
    "lng": "49.31504"
  },
  {
    "country": "IR",
    "name": "Sorkheh",
    "lat": "35.4633",
    "lng": "53.214"
  },
  {
    "country": "IR",
    "name": "Sonqor",
    "lat": "34.78187",
    "lng": "47.59945"
  },
  {
    "country": "IR",
    "name": "Solţānābād",
    "lat": "36.40352",
    "lng": "58.03894"
  },
  {
    "country": "IR",
    "name": "Sirjan",
    "lat": "29.45137",
    "lng": "55.6809"
  },
  {
    "country": "IR",
    "name": "Sīāhkal",
    "lat": "37.15328",
    "lng": "49.87136"
  },
  {
    "country": "IR",
    "name": "Shūshtar",
    "lat": "32.04972",
    "lng": "48.84843"
  },
  {
    "country": "IR",
    "name": "Shūsh",
    "lat": "32.1942",
    "lng": "48.2436"
  },
  {
    "country": "IR",
    "name": "Shīrvān",
    "lat": "37.39669",
    "lng": "57.92952"
  },
  {
    "country": "IR",
    "name": "Shiraz",
    "lat": "29.61031",
    "lng": "52.53113"
  },
  {
    "country": "IR",
    "name": "Sharīfābād",
    "lat": "35.4275",
    "lng": "51.78528"
  },
  {
    "country": "IR",
    "name": "Shalamzār",
    "lat": "32.04539",
    "lng": "50.81714"
  },
  {
    "country": "IR",
    "name": "Shahr-e Kord",
    "lat": "32.32556",
    "lng": "50.86444"
  },
  {
    "country": "IR",
    "name": "Shahr-e Bābak",
    "lat": "30.1165",
    "lng": "55.1186"
  },
  {
    "country": "IR",
    "name": "Shaft",
    "lat": "37.1702",
    "lng": "49.3998"
  },
  {
    "country": "IR",
    "name": "Shādegān",
    "lat": "30.64924",
    "lng": "48.66497"
  },
  {
    "country": "IR",
    "name": "Shabestar",
    "lat": "38.1804",
    "lng": "45.7028"
  },
  {
    "country": "IR",
    "name": "Seyah Cheshmeh",
    "lat": "39.06508",
    "lng": "44.38416"
  },
  {
    "country": "IR",
    "name": "Semnān",
    "lat": "35.57691",
    "lng": "53.39205"
  },
  {
    "country": "IR",
    "name": "Semīrom",
    "lat": "31.41667",
    "lng": "51.56667"
  },
  {
    "country": "IR",
    "name": "sedeyen-e Yek",
    "lat": "31.36205",
    "lng": "48.81833"
  },
  {
    "country": "IR",
    "name": "Sāveh",
    "lat": "35.0213",
    "lng": "50.3566"
  },
  {
    "country": "IR",
    "name": "Sarvestān",
    "lat": "29.2735",
    "lng": "53.2203"
  },
  {
    "country": "IR",
    "name": "Sarvābād",
    "lat": "35.3126",
    "lng": "46.3669"
  },
  {
    "country": "IR",
    "name": "Sari",
    "lat": "36.56332",
    "lng": "53.06009"
  },
  {
    "country": "IR",
    "name": "Sardasht",
    "lat": "36.1552",
    "lng": "45.4788"
  },
  {
    "country": "IR",
    "name": "Sardasht",
    "lat": "26.4559",
    "lng": "57.9028"
  },
  {
    "country": "IR",
    "name": "Sarbīsheh",
    "lat": "32.57566",
    "lng": "59.79821"
  },
  {
    "country": "IR",
    "name": "Sarāyān",
    "lat": "33.86017",
    "lng": "58.52166"
  },
  {
    "country": "IR",
    "name": "Sarābleh",
    "lat": "33.76772",
    "lng": "46.56578"
  },
  {
    "country": "IR",
    "name": "Sarāb-e Dūreh",
    "lat": "33.5639",
    "lng": "48.0221"
  },
  {
    "country": "IR",
    "name": "Sarāb",
    "lat": "37.9408",
    "lng": "47.5367"
  },
  {
    "country": "IR",
    "name": "Saqqez",
    "lat": "36.24992",
    "lng": "46.2735"
  },
  {
    "country": "IR",
    "name": "Sanandaj",
    "lat": "35.31495",
    "lng": "46.99883"
  },
  {
    "country": "IR",
    "name": "Salmās",
    "lat": "38.1973",
    "lng": "44.7653"
  },
  {
    "country": "IR",
    "name": "Soleh Bon",
    "lat": "35.76841",
    "lng": "52.56091"
  },
  {
    "country": "IR",
    "name": "Rāmsar",
    "lat": "36.91796",
    "lng": "50.64802"
  },
  {
    "country": "IR",
    "name": "Shāhīn Dezh",
    "lat": "36.6793",
    "lng": "46.5669"
  },
  {
    "country": "IR",
    "name": "Şaḩneh",
    "lat": "34.4813",
    "lng": "47.6908"
  },
  {
    "country": "IR",
    "name": "Sabzevar",
    "lat": "36.2126",
    "lng": "57.68191"
  },
  {
    "country": "IR",
    "name": "Sa‘ādat Shahr",
    "lat": "30.07921",
    "lng": "53.13464"
  },
  {
    "country": "IR",
    "name": "Rūdsar",
    "lat": "37.13696",
    "lng": "50.29174"
  },
  {
    "country": "IR",
    "name": "Narmāshīr",
    "lat": "28.95216",
    "lng": "58.69773"
  },
  {
    "country": "IR",
    "name": "Roshtkhvār",
    "lat": "34.97512",
    "lng": "59.62482"
  },
  {
    "country": "IR",
    "name": "Robāţ Karīm",
    "lat": "35.4846",
    "lng": "51.0829"
  },
  {
    "country": "IR",
    "name": "Reẕvānshahr",
    "lat": "37.54976",
    "lng": "49.13703"
  },
  {
    "country": "IR",
    "name": "Razan",
    "lat": "35.38625",
    "lng": "49.0334"
  },
  {
    "country": "IR",
    "name": "Rāvar",
    "lat": "31.26562",
    "lng": "56.80545"
  },
  {
    "country": "IR",
    "name": "Ravānsar",
    "lat": "34.7153",
    "lng": "46.6533"
  },
  {
    "country": "IR",
    "name": "Rasht",
    "lat": "37.27611",
    "lng": "49.58862"
  },
  {
    "country": "IR",
    "name": "Rāmshīr",
    "lat": "30.89315",
    "lng": "49.40787"
  },
  {
    "country": "IR",
    "name": "Rāmīān",
    "lat": "37.01598",
    "lng": "55.14123"
  },
  {
    "country": "IR",
    "name": "Rāmhormoz",
    "lat": "31.27997",
    "lng": "49.60351"
  },
  {
    "country": "IR",
    "name": "Rafsanjān",
    "lat": "30.4067",
    "lng": "55.9939"
  },
  {
    "country": "IR",
    "name": "Rābor",
    "lat": "29.2912",
    "lng": "56.9131"
  },
  {
    "country": "IR",
    "name": "Qūchān",
    "lat": "37.106",
    "lng": "58.50955"
  },
  {
    "country": "IR",
    "name": "Qorveh",
    "lat": "35.1664",
    "lng": "47.80564"
  },
  {
    "country": "IR",
    "name": "Qom",
    "lat": "34.6401",
    "lng": "50.8764"
  },
  {
    "country": "IR",
    "name": "Qohūrd-e ‘Olyā",
    "lat": "35.43979",
    "lng": "48.07362"
  },
  {
    "country": "IR",
    "name": "Qīr",
    "lat": "28.4825",
    "lng": "53.0346"
  },
  {
    "country": "IR",
    "name": "Qeshm",
    "lat": "26.9492",
    "lng": "56.2691"
  },
  {
    "country": "IR",
    "name": "Qazvin",
    "lat": "36.26877",
    "lng": "50.0041"
  },
  {
    "country": "IR",
    "name": "Qaşr-e Shīrīn",
    "lat": "34.5156",
    "lng": "45.5791"
  },
  {
    "country": "IR",
    "name": "Qarnābād",
    "lat": "36.82203",
    "lng": "54.59222"
  },
  {
    "country": "IR",
    "name": "Qarah Ẕīā’ od Dīn",
    "lat": "38.8915",
    "lng": "45.0255"
  },
  {
    "country": "IR",
    "name": "Shahr-e Qods",
    "lat": "35.7214",
    "lng": "51.109"
  },
  {
    "country": "IR",
    "name": "Qal‘eh Ganj",
    "lat": "27.5236",
    "lng": "57.8811"
  },
  {
    "country": "IR",
    "name": "Rūdān",
    "lat": "27.44194",
    "lng": "57.19198"
  },
  {
    "country": "IR",
    "name": "Qal‘eh-ye Khvājeh",
    "lat": "32.20622",
    "lng": "49.44526"
  },
  {
    "country": "IR",
    "name": "Arakvāz-e Malekshāhī",
    "lat": "33.3828",
    "lng": "46.5983"
  },
  {
    "country": "IR",
    "name": "Farrokh Shahr",
    "lat": "32.27174",
    "lng": "50.98008"
  },
  {
    "country": "IR",
    "name": "Qā’en",
    "lat": "33.72654",
    "lng": "59.18439"
  },
  {
    "country": "IR",
    "name": "Sarpol-e Z̄ahāb",
    "lat": "34.46109",
    "lng": "45.86264"
  },
  {
    "country": "IR",
    "name": "Pol-e Sefīd",
    "lat": "36.11787",
    "lng": "53.05531"
  },
  {
    "country": "IR",
    "name": "Poldokhtar",
    "lat": "33.15249",
    "lng": "47.71014"
  },
  {
    "country": "IR",
    "name": "Poldasht",
    "lat": "39.348",
    "lng": "45.071"
  },
  {
    "country": "IR",
    "name": "Pīshvā",
    "lat": "35.308",
    "lng": "51.7267"
  },
  {
    "country": "IR",
    "name": "Piranshahr",
    "lat": "36.701",
    "lng": "45.1413"
  },
  {
    "country": "IR",
    "name": "Pāveh",
    "lat": "35.0434",
    "lng": "46.3565"
  },
  {
    "country": "IR",
    "name": "Pārsābād",
    "lat": "39.6482",
    "lng": "47.9174"
  },
  {
    "country": "IR",
    "name": "Oskū",
    "lat": "37.91504",
    "lng": "46.12258"
  },
  {
    "country": "IR",
    "name": "Oshnavīyeh",
    "lat": "37.0397",
    "lng": "45.0983"
  },
  {
    "country": "IR",
    "name": "Orūmīyeh",
    "lat": "37.55274",
    "lng": "45.07605"
  },
  {
    "country": "IR",
    "name": "Omīdīyeh",
    "lat": "30.76277",
    "lng": "49.70226"
  },
  {
    "country": "IR",
    "name": "Nūrābād",
    "lat": "30.11405",
    "lng": "51.52174"
  },
  {
    "country": "IR",
    "name": "Nowshahr",
    "lat": "36.64852",
    "lng": "51.49621"
  },
  {
    "country": "IR",
    "name": "Noşratābād",
    "lat": "29.9",
    "lng": "59.98333"
  },
  {
    "country": "IR",
    "name": "Neyshābūr",
    "lat": "36.21329",
    "lng": "58.79575"
  },
  {
    "country": "IR",
    "name": "Neyrīz",
    "lat": "29.1988",
    "lng": "54.3278"
  },
  {
    "country": "IR",
    "name": "Neqāb",
    "lat": "36.70792",
    "lng": "57.42146"
  },
  {
    "country": "IR",
    "name": "Nekā",
    "lat": "36.65079",
    "lng": "53.29905"
  },
  {
    "country": "IR",
    "name": "Naz̧arābād",
    "lat": "35.95411",
    "lng": "50.60607"
  },
  {
    "country": "IR",
    "name": "Naţanz",
    "lat": "33.51118",
    "lng": "51.91808"
  },
  {
    "country": "IR",
    "name": "Nashtārūd",
    "lat": "36.7509",
    "lng": "51.02362"
  },
  {
    "country": "IR",
    "name": "Naqadeh",
    "lat": "36.9553",
    "lng": "45.388"
  },
  {
    "country": "IR",
    "name": "Namīn",
    "lat": "38.4269",
    "lng": "48.4839"
  },
  {
    "country": "IR",
    "name": "Nā’īn",
    "lat": "32.86006",
    "lng": "53.08749"
  },
  {
    "country": "IR",
    "name": "Nahāvand",
    "lat": "34.19088",
    "lng": "48.37446"
  },
  {
    "country": "IR",
    "name": "Marāveh Tappeh",
    "lat": "37.9041",
    "lng": "55.95596"
  },
  {
    "country": "IR",
    "name": "Mollās̄ānī",
    "lat": "31.5847",
    "lng": "48.88587"
  },
  {
    "country": "IR",
    "name": "Mohr",
    "lat": "27.5552",
    "lng": "52.8836"
  },
  {
    "country": "IR",
    "name": "Moḩammadābād",
    "lat": "28.66877",
    "lng": "59.07341"
  },
  {
    "country": "IR",
    "name": "Mīnūdasht",
    "lat": "37.23015",
    "lng": "55.37211"
  },
  {
    "country": "IR",
    "name": "Mīnāb",
    "lat": "27.13104",
    "lng": "57.08716"
  },
  {
    "country": "IR",
    "name": "Mīāneh",
    "lat": "37.421",
    "lng": "47.715"
  },
  {
    "country": "IR",
    "name": "Mīāndoāb",
    "lat": "36.96667",
    "lng": "46.10961"
  },
  {
    "country": "IR",
    "name": "Meybod",
    "lat": "32.25014",
    "lng": "54.01658"
  },
  {
    "country": "IR",
    "name": "Meshgīn Shahr",
    "lat": "38.399",
    "lng": "47.682"
  },
  {
    "country": "IR",
    "name": "Mahrīz",
    "lat": "31.58428",
    "lng": "54.4428"
  },
  {
    "country": "IR",
    "name": "Mehrān",
    "lat": "33.1222",
    "lng": "46.1646"
  },
  {
    "country": "IR",
    "name": "Masjed Soleymān",
    "lat": "31.9364",
    "lng": "49.3039"
  },
  {
    "country": "IR",
    "name": "Maşīrī",
    "lat": "30.24584",
    "lng": "51.52233"
  },
  {
    "country": "IR",
    "name": "Bardsīr",
    "lat": "29.92266",
    "lng": "56.57433"
  },
  {
    "country": "IR",
    "name": "Mashhad",
    "lat": "36.31559",
    "lng": "59.56796"
  },
  {
    "country": "IR",
    "name": "Marvdasht",
    "lat": "29.8742",
    "lng": "52.8025"
  },
  {
    "country": "IR",
    "name": "Marīvān",
    "lat": "35.51829",
    "lng": "46.18298"
  },
  {
    "country": "IR",
    "name": "Marand",
    "lat": "38.4329",
    "lng": "45.7749"
  },
  {
    "country": "IR",
    "name": "Marāgheh",
    "lat": "37.39206",
    "lng": "46.23909"
  },
  {
    "country": "IR",
    "name": "Manūjān",
    "lat": "27.40698",
    "lng": "57.50128"
  },
  {
    "country": "IR",
    "name": "Malekān",
    "lat": "37.14258",
    "lng": "46.10345"
  },
  {
    "country": "IR",
    "name": "Malāyer",
    "lat": "34.30158",
    "lng": "48.82166"
  },
  {
    "country": "IR",
    "name": "Malārd",
    "lat": "35.6659",
    "lng": "50.9767"
  },
  {
    "country": "IR",
    "name": "Mākū",
    "lat": "39.29513",
    "lng": "44.49822"
  },
  {
    "country": "IR",
    "name": "Māhneshān",
    "lat": "36.7444",
    "lng": "47.6725"
  },
  {
    "country": "IR",
    "name": "Maḩmūdābād",
    "lat": "36.63191",
    "lng": "52.26286"
  },
  {
    "country": "IR",
    "name": "Maḩallāt",
    "lat": "33.91108",
    "lng": "50.45317"
  },
  {
    "country": "IR",
    "name": "Mahābād",
    "lat": "36.7631",
    "lng": "45.7222"
  },
  {
    "country": "IR",
    "name": "Lordegān",
    "lat": "31.51338",
    "lng": "50.82672"
  },
  {
    "country": "IR",
    "name": "Līkak",
    "lat": "30.8949",
    "lng": "50.0931"
  },
  {
    "country": "IR",
    "name": "Shahr-e Qadīm-e Lār",
    "lat": "27.68336",
    "lng": "54.34172"
  },
  {
    "country": "IR",
    "name": "Langarūd",
    "lat": "37.19548",
    "lng": "50.15263"
  },
  {
    "country": "IR",
    "name": "Lāmerd",
    "lat": "27.334",
    "lng": "53.179"
  },
  {
    "country": "IR",
    "name": "Dasht-e Lati",
    "lat": "32.32981",
    "lng": "49.09324"
  },
  {
    "country": "IR",
    "name": "Lāhījān",
    "lat": "37.20416",
    "lng": "50.00919"
  },
  {
    "country": "IR",
    "name": "Kūhdasht",
    "lat": "33.53335",
    "lng": "47.60999"
  },
  {
    "country": "IR",
    "name": "Kūhbanān",
    "lat": "31.41029",
    "lng": "56.28255"
  },
  {
    "country": "IR",
    "name": "Kord Kūy",
    "lat": "36.79307",
    "lng": "54.11214"
  },
  {
    "country": "IR",
    "name": "Komījān",
    "lat": "34.72142",
    "lng": "49.32653"
  },
  {
    "country": "IR",
    "name": "Kīsh",
    "lat": "26.55778",
    "lng": "54.01944"
  },
  {
    "country": "IR",
    "name": "Khowy",
    "lat": "38.5503",
    "lng": "44.9521"
  },
  {
    "country": "IR",
    "name": "Khowrmūj",
    "lat": "28.6543",
    "lng": "51.38"
  },
  {
    "country": "IR",
    "name": "Khūr",
    "lat": "33.77512",
    "lng": "55.08329"
  },
  {
    "country": "IR",
    "name": "Khvānsār",
    "lat": "33.22052",
    "lng": "50.31497"
  },
  {
    "country": "IR",
    "name": "Khorramshahr",
    "lat": "30.44079",
    "lng": "48.18428"
  },
  {
    "country": "IR",
    "name": "Khorramabad",
    "lat": "33.48778",
    "lng": "48.35583"
  },
  {
    "country": "IR",
    "name": "Khonj",
    "lat": "27.8913",
    "lng": "53.4344"
  },
  {
    "country": "IR",
    "name": "Khondāb",
    "lat": "34.3928",
    "lng": "49.1841"
  },
  {
    "country": "IR",
    "name": "Khomeyn",
    "lat": "33.64225",
    "lng": "50.0789"
  },
  {
    "country": "IR",
    "name": "Khomārlū",
    "lat": "39.1489",
    "lng": "47.0347"
  },
  {
    "country": "IR",
    "name": "Kherāmeh",
    "lat": "29.49896",
    "lng": "53.31199"
  },
  {
    "country": "IR",
    "name": "Khānī Yek",
    "lat": "29.89167",
    "lng": "51.68667"
  },
  {
    "country": "IR",
    "name": "Bandar-e Khamīr",
    "lat": "26.9521",
    "lng": "55.5851"
  },
  {
    "country": "IR",
    "name": "Khalkhāl",
    "lat": "37.61837",
    "lng": "48.52928"
  },
  {
    "country": "IR",
    "name": "Khalīlābād",
    "lat": "35.25395",
    "lng": "58.28566"
  },
  {
    "country": "IR",
    "name": "Kermanshah",
    "lat": "34.31417",
    "lng": "47.065"
  },
  {
    "country": "IR",
    "name": "Kerman",
    "lat": "30.28321",
    "lng": "57.07879"
  },
  {
    "country": "IR",
    "name": "Kerend-e Gharb",
    "lat": "34.2842",
    "lng": "46.2423"
  },
  {
    "country": "IR",
    "name": "Kāzerūn",
    "lat": "29.61949",
    "lng": "51.65415"
  },
  {
    "country": "IR",
    "name": "Kāshmar",
    "lat": "35.23831",
    "lng": "58.46558"
  },
  {
    "country": "IR",
    "name": "Karaj",
    "lat": "35.83266",
    "lng": "50.99155"
  },
  {
    "country": "IR",
    "name": "Kangāvar",
    "lat": "34.5043",
    "lng": "47.9653"
  },
  {
    "country": "IR",
    "name": "Kangān",
    "lat": "27.834",
    "lng": "52.0628"
  },
  {
    "country": "IR",
    "name": "Kāmyārān",
    "lat": "34.7956",
    "lng": "46.9355"
  },
  {
    "country": "IR",
    "name": "Kaleybar",
    "lat": "38.86509",
    "lng": "47.03909"
  },
  {
    "country": "IR",
    "name": "Kalāleh",
    "lat": "37.37899",
    "lng": "55.493"
  },
  {
    "country": "IR",
    "name": "Kabūdarāhang",
    "lat": "35.20924",
    "lng": "48.72341"
  },
  {
    "country": "IR",
    "name": "Eyvān",
    "lat": "33.8272",
    "lng": "46.3097"
  },
  {
    "country": "IR",
    "name": "Jūybār",
    "lat": "36.64115",
    "lng": "52.91244"
  },
  {
    "country": "IR",
    "name": "Joghtāy",
    "lat": "36.63619",
    "lng": "57.07284"
  },
  {
    "country": "IR",
    "name": "Khārk",
    "lat": "29.26139",
    "lng": "50.33056"
  },
  {
    "country": "IR",
    "name": "Javānrūd",
    "lat": "34.79611",
    "lng": "46.51722"
  },
  {
    "country": "IR",
    "name": "Jask",
    "lat": "25.64533",
    "lng": "57.77552"
  },
  {
    "country": "IR",
    "name": "Jongīyeh",
    "lat": "31.25583",
    "lng": "48.61667"
  },
  {
    "country": "IR",
    "name": "Jam",
    "lat": "27.82817",
    "lng": "52.32536"
  },
  {
    "country": "IR",
    "name": "Jājarm",
    "lat": "36.95012",
    "lng": "56.38005"
  },
  {
    "country": "IR",
    "name": "Jahrom",
    "lat": "28.5",
    "lng": "53.5605"
  },
  {
    "country": "IR",
    "name": "Īlām",
    "lat": "33.6374",
    "lng": "46.4227"
  },
  {
    "country": "IR",
    "name": "Hoveyzeh",
    "lat": "31.4619",
    "lng": "48.074"
  },
  {
    "country": "IR",
    "name": "Herīs",
    "lat": "38.24816",
    "lng": "47.11678"
  },
  {
    "country": "IR",
    "name": "Hendījān",
    "lat": "30.2363",
    "lng": "49.7119"
  },
  {
    "country": "IR",
    "name": "Hashtgerd",
    "lat": "35.962",
    "lng": "50.6799"
  },
  {
    "country": "IR",
    "name": "Harsīn",
    "lat": "34.2721",
    "lng": "47.5861"
  },
  {
    "country": "IR",
    "name": "Hamadān",
    "lat": "34.79922",
    "lng": "48.51456"
  },
  {
    "country": "IR",
    "name": "Ḩājjīābād",
    "lat": "28.35735",
    "lng": "54.42335"
  },
  {
    "country": "IR",
    "name": "Ḩājjīābād",
    "lat": "28.3091",
    "lng": "55.9017"
  },
  {
    "country": "IR",
    "name": "Haftkel",
    "lat": "31.44686",
    "lng": "49.52951"
  },
  {
    "country": "IR",
    "name": "Gorgān",
    "lat": "36.8427",
    "lng": "54.44391"
  },
  {
    "country": "IR",
    "name": "Gonbad-e Kāvūs",
    "lat": "37.25004",
    "lng": "55.16721"
  },
  {
    "country": "IR",
    "name": "Gonābād",
    "lat": "34.35287",
    "lng": "58.68365"
  },
  {
    "country": "IR",
    "name": "Golpāyegān",
    "lat": "33.4537",
    "lng": "50.28836"
  },
  {
    "country": "IR",
    "name": "Gīlān-e Gharb",
    "lat": "34.1421",
    "lng": "45.9203"
  },
  {
    "country": "IR",
    "name": "Gerāsh",
    "lat": "27.66966",
    "lng": "54.13586"
  },
  {
    "country": "IR",
    "name": "Gāvbandī",
    "lat": "27.2083",
    "lng": "53.0361"
  },
  {
    "country": "IR",
    "name": "Garmsār",
    "lat": "35.21824",
    "lng": "52.34085"
  },
  {
    "country": "IR",
    "name": "Germī",
    "lat": "39.0215",
    "lng": "48.0801"
  },
  {
    "country": "IR",
    "name": "Garmeh",
    "lat": "36.987",
    "lng": "56.28942"
  },
  {
    "country": "IR",
    "name": "Bandar-e Genāveh",
    "lat": "29.5791",
    "lng": "50.517"
  },
  {
    "country": "IR",
    "name": "Galūgāh",
    "lat": "36.72734",
    "lng": "53.80888"
  },
  {
    "country": "IR",
    "name": "Gālīkesh",
    "lat": "37.27259",
    "lng": "55.43394"
  },
  {
    "country": "IR",
    "name": "Fūman",
    "lat": "37.224",
    "lng": "49.3125"
  },
  {
    "country": "IR",
    "name": "Fīrūzkūh",
    "lat": "35.75674",
    "lng": "52.77062"
  },
  {
    "country": "IR",
    "name": "Fīrūzābād",
    "lat": "28.8438",
    "lng": "52.5707"
  },
  {
    "country": "IR",
    "name": "Feyẕābād",
    "lat": "35.01891",
    "lng": "58.78343"
  },
  {
    "country": "IR",
    "name": "Fareydūnshahr",
    "lat": "32.94098",
    "lng": "50.121"
  },
  {
    "country": "IR",
    "name": "Fereydūnkenār",
    "lat": "36.68642",
    "lng": "52.52255"
  },
  {
    "country": "IR",
    "name": "Ferdows",
    "lat": "34.0185",
    "lng": "58.17222"
  },
  {
    "country": "IR",
    "name": "Fasā",
    "lat": "28.9383",
    "lng": "53.6482"
  },
  {
    "country": "IR",
    "name": "Fāryāb",
    "lat": "28.0987",
    "lng": "57.23181"
  },
  {
    "country": "IR",
    "name": "Fārūj",
    "lat": "37.23121",
    "lng": "58.219"
  },
  {
    "country": "IR",
    "name": "Fārsān",
    "lat": "32.25694",
    "lng": "50.56095"
  },
  {
    "country": "IR",
    "name": "Farāshband",
    "lat": "28.8713",
    "lng": "52.0916"
  },
  {
    "country": "IR",
    "name": "Farmahīn",
    "lat": "34.50383",
    "lng": "49.68437"
  },
  {
    "country": "IR",
    "name": "Farīmān",
    "lat": "35.70685",
    "lng": "59.85006"
  },
  {
    "country": "IR",
    "name": "pamas",
    "lat": "34.03791",
    "lng": "48.462"
  },
  {
    "country": "IR",
    "name": "Fāmenīn",
    "lat": "35.11593",
    "lng": "48.97336"
  },
  {
    "country": "IR",
    "name": "Fahraj",
    "lat": "28.9502",
    "lng": "58.885"
  },
  {
    "country": "IR",
    "name": "Estahbān",
    "lat": "29.1266",
    "lng": "54.0421"
  },
  {
    "country": "IR",
    "name": "Eslāmābād-e Gharb",
    "lat": "34.1094",
    "lng": "46.5275"
  },
  {
    "country": "IR",
    "name": "Eshtehārd",
    "lat": "35.7255",
    "lng": "50.3662"
  },
  {
    "country": "IR",
    "name": "Esfarāyen",
    "lat": "37.07645",
    "lng": "57.51009"
  },
  {
    "country": "IR",
    "name": "Eqlīd",
    "lat": "30.89885",
    "lng": "52.69701"
  },
  {
    "country": "IR",
    "name": "Shahrud",
    "lat": "36.41819",
    "lng": "54.97628"
  },
  {
    "country": "IR",
    "name": "Dowlatābād",
    "lat": "35.28219",
    "lng": "59.51972"
  },
  {
    "country": "IR",
    "name": "Dorūd",
    "lat": "33.49218",
    "lng": "49.0616"
  },
  {
    "country": "IR",
    "name": "Dogonbadan",
    "lat": "30.3586",
    "lng": "50.7981"
  },
  {
    "country": "IR",
    "name": "Dīvāndarreh",
    "lat": "35.9139",
    "lng": "47.0239"
  },
  {
    "country": "IR",
    "name": "Dezful",
    "lat": "32.38114",
    "lng": "48.40581"
  },
  {
    "country": "IR",
    "name": "Deyr",
    "lat": "27.8399",
    "lng": "51.9378"
  },
  {
    "country": "IR",
    "name": "Delījān",
    "lat": "33.9905",
    "lng": "50.6838"
  },
  {
    "country": "IR",
    "name": "Dehlorān",
    "lat": "32.6941",
    "lng": "47.2679"
  },
  {
    "country": "IR",
    "name": "Dehgolān",
    "lat": "35.278",
    "lng": "47.4184"
  },
  {
    "country": "IR",
    "name": "Dehdasht",
    "lat": "30.7949",
    "lng": "50.56457"
  },
  {
    "country": "IR",
    "name": "Sīsakht",
    "lat": "30.86393",
    "lng": "51.4559"
  },
  {
    "country": "IR",
    "name": "Şafāshahr",
    "lat": "30.6131",
    "lng": "53.1954"
  },
  {
    "country": "IR",
    "name": "Dehāqān",
    "lat": "31.94004",
    "lng": "51.64786"
  },
  {
    "country": "IR",
    "name": "Sūsangerd",
    "lat": "31.5635",
    "lng": "48.18958"
  },
  {
    "country": "IR",
    "name": "Darreh Shahr",
    "lat": "33.14447",
    "lng": "47.3799"
  },
  {
    "country": "IR",
    "name": "Dargaz",
    "lat": "37.44447",
    "lng": "59.10809"
  },
  {
    "country": "IR",
    "name": "Dārān",
    "lat": "32.98871",
    "lng": "50.41267"
  },
  {
    "country": "IR",
    "name": "Dārāb",
    "lat": "28.75194",
    "lng": "54.54444"
  },
  {
    "country": "IR",
    "name": "Dāmghān",
    "lat": "36.1679",
    "lng": "54.34292"
  },
  {
    "country": "IR",
    "name": "Damāvand",
    "lat": "35.71842",
    "lng": "52.06958"
  },
  {
    "country": "IR",
    "name": "Chenārān",
    "lat": "36.64546",
    "lng": "59.12123"
  },
  {
    "country": "IR",
    "name": "Chelgard",
    "lat": "32.46668",
    "lng": "50.12308"
  },
  {
    "country": "IR",
    "name": "Chālūs",
    "lat": "36.655",
    "lng": "51.4204"
  },
  {
    "country": "IR",
    "name": "Chādegān",
    "lat": "32.76825",
    "lng": "50.62873"
  },
  {
    "country": "IR",
    "name": "Bushehr",
    "lat": "28.96887",
    "lng": "50.83657"
  },
  {
    "country": "IR",
    "name": "Būkān",
    "lat": "36.521",
    "lng": "46.2089"
  },
  {
    "country": "IR",
    "name": "Bū’īn Zahrā",
    "lat": "35.7669",
    "lng": "50.0578"
  },
  {
    "country": "IR",
    "name": "Borūjerd",
    "lat": "33.8973",
    "lng": "48.7516"
  },
  {
    "country": "IR",
    "name": "Borūjen",
    "lat": "31.96523",
    "lng": "51.2873"
  },
  {
    "country": "IR",
    "name": "Borāzjān",
    "lat": "29.2699",
    "lng": "51.2188"
  },
  {
    "country": "IR",
    "name": "Shahrak-e Kūlūrī",
    "lat": "32.35276",
    "lng": "48.47059"
  },
  {
    "country": "IR",
    "name": "Bojnūrd",
    "lat": "37.47473",
    "lng": "57.32903"
  },
  {
    "country": "IR",
    "name": "Bīrjand",
    "lat": "32.86628",
    "lng": "59.22114"
  },
  {
    "country": "IR",
    "name": "Bīleh Savār",
    "lat": "39.37961",
    "lng": "48.35463"
  },
  {
    "country": "IR",
    "name": "Bījār",
    "lat": "35.8668",
    "lng": "47.60506"
  },
  {
    "country": "IR",
    "name": "Bonāb",
    "lat": "37.3404",
    "lng": "46.0561"
  },
  {
    "country": "IR",
    "name": "Behshahr",
    "lat": "36.69235",
    "lng": "53.55262"
  },
  {
    "country": "IR",
    "name": "Behbahān",
    "lat": "30.5959",
    "lng": "50.2417"
  },
  {
    "country": "IR",
    "name": "Māsāl",
    "lat": "37.3631",
    "lng": "49.1329"
  },
  {
    "country": "IR",
    "name": "Bastak",
    "lat": "27.19908",
    "lng": "54.36676"
  },
  {
    "country": "IR",
    "name": "Bāsht",
    "lat": "30.361",
    "lng": "51.15735"
  },
  {
    "country": "IR",
    "name": "Bardaskan",
    "lat": "35.26218",
    "lng": "57.97075"
  },
  {
    "country": "IR",
    "name": "Bāneh",
    "lat": "35.9975",
    "lng": "45.8853"
  },
  {
    "country": "IR",
    "name": "Bandar-e Torkaman",
    "lat": "36.90124",
    "lng": "54.07195"
  },
  {
    "country": "IR",
    "name": "Bandar-e Māhshahr",
    "lat": "30.55655",
    "lng": "49.18852"
  },
  {
    "country": "IR",
    "name": "Bandar-e Lengeh",
    "lat": "26.55792",
    "lng": "54.88067"
  },
  {
    "country": "IR",
    "name": "Bandar-e Gaz",
    "lat": "36.77409",
    "lng": "53.94798"
  },
  {
    "country": "IR",
    "name": "Bandar-e Deylam",
    "lat": "30.0542",
    "lng": "50.159"
  },
  {
    "country": "IR",
    "name": "Bandar-e Anzalī",
    "lat": "37.47318",
    "lng": "49.45785"
  },
  {
    "country": "IR",
    "name": "Bandar Abbas",
    "lat": "27.1865",
    "lng": "56.2808"
  },
  {
    "country": "IR",
    "name": "Bam",
    "lat": "29.106",
    "lng": "58.357"
  },
  {
    "country": "IR",
    "name": "Bajestān",
    "lat": "34.51639",
    "lng": "58.1845"
  },
  {
    "country": "IR",
    "name": "Bahār",
    "lat": "34.9072",
    "lng": "48.4414"
  },
  {
    "country": "IR",
    "name": "Bāgh-e Malek",
    "lat": "31.52398",
    "lng": "49.88558"
  },
  {
    "country": "IR",
    "name": "Bāft",
    "lat": "29.2331",
    "lng": "56.6022"
  },
  {
    "country": "IR",
    "name": "Bāfq",
    "lat": "31.6035",
    "lng": "55.40249"
  },
  {
    "country": "IR",
    "name": "Bābolsar",
    "lat": "36.70251",
    "lng": "52.6576"
  },
  {
    "country": "IR",
    "name": "Bābol",
    "lat": "36.55132",
    "lng": "52.67895"
  },
  {
    "country": "IR",
    "name": "Aznā",
    "lat": "33.6095",
    "lng": "48.9307"
  },
  {
    "country": "IR",
    "name": "Aznā",
    "lat": "33.45643",
    "lng": "49.45646"
  },
  {
    "country": "IR",
    "name": "Hashtrūd",
    "lat": "37.4779",
    "lng": "47.0508"
  },
  {
    "country": "IR",
    "name": "Shāzand",
    "lat": "33.93132",
    "lng": "49.40629"
  },
  {
    "country": "IR",
    "name": "Āstārā",
    "lat": "38.4291",
    "lng": "48.872"
  },
  {
    "country": "IR",
    "name": "Āstāneh-ye Ashrafīyeh",
    "lat": "37.26318",
    "lng": "49.94325"
  },
  {
    "country": "IR",
    "name": "Āshtīān",
    "lat": "34.52298",
    "lng": "50.00608"
  },
  {
    "country": "IR",
    "name": "Āshkhāneh",
    "lat": "37.5615",
    "lng": "56.92125"
  },
  {
    "country": "IR",
    "name": "Bandar-e ‘Asalūyeh",
    "lat": "27.4761",
    "lng": "52.6074"
  },
  {
    "country": "IR",
    "name": "Asadīyeh",
    "lat": "32.9428",
    "lng": "59.71998"
  },
  {
    "country": "IR",
    "name": "Asadābād",
    "lat": "34.78241",
    "lng": "48.12012"
  },
  {
    "country": "IR",
    "name": "Arzū’īyeh",
    "lat": "28.4414",
    "lng": "56.3728"
  },
  {
    "country": "IR",
    "name": "Arsanjān",
    "lat": "29.9124",
    "lng": "53.3085"
  },
  {
    "country": "IR",
    "name": "Ardestān",
    "lat": "33.3761",
    "lng": "52.3694"
  },
  {
    "country": "IR",
    "name": "Ardal",
    "lat": "31.99969",
    "lng": "50.66231"
  },
  {
    "country": "IR",
    "name": "Ardakān",
    "lat": "32.31001",
    "lng": "54.01747"
  },
  {
    "country": "IR",
    "name": "Ardabīl",
    "lat": "38.2498",
    "lng": "48.2933"
  },
  {
    "country": "IR",
    "name": "Ārān Bīdgol",
    "lat": "34.05751",
    "lng": "51.48291"
  },
  {
    "country": "IR",
    "name": "Arāk",
    "lat": "34.09493",
    "lng": "49.69809"
  },
  {
    "country": "IR",
    "name": "Ārādān",
    "lat": "35.24941",
    "lng": "52.49422"
  },
  {
    "country": "IR",
    "name": "Anūch",
    "lat": "34.10829",
    "lng": "48.57375"
  },
  {
    "country": "IR",
    "name": "Andīmeshk",
    "lat": "32.4615",
    "lng": "48.35368"
  },
  {
    "country": "IR",
    "name": "‘Anbarābād",
    "lat": "28.4759",
    "lng": "57.848"
  },
  {
    "country": "IR",
    "name": "Anār",
    "lat": "30.87066",
    "lng": "55.27025"
  },
  {
    "country": "IR",
    "name": "Āmol",
    "lat": "36.46961",
    "lng": "52.35072"
  },
  {
    "country": "IR",
    "name": "Amlash",
    "lat": "37.0966",
    "lng": "50.18709"
  },
  {
    "country": "IR",
    "name": "Alvand",
    "lat": "36.31885",
    "lng": "49.16773"
  },
  {
    "country": "IR",
    "name": "Shahrīār",
    "lat": "35.65884",
    "lng": "51.05775"
  },
  {
    "country": "IR",
    "name": "Alīgūdarz",
    "lat": "33.404",
    "lng": "49.69179"
  },
  {
    "country": "IR",
    "name": "‘Alīābād-e Katūl",
    "lat": "36.91011",
    "lng": "54.86737"
  },
  {
    "country": "IR",
    "name": "Aleshtar",
    "lat": "33.86419",
    "lng": "48.26258"
  },
  {
    "country": "IR",
    "name": "Akbarābād",
    "lat": "29.2464",
    "lng": "52.7793"
  },
  {
    "country": "IR",
    "name": "‘Ajab Shīr",
    "lat": "37.4776",
    "lng": "45.8943"
  },
  {
    "country": "IR",
    "name": "Ahvaz",
    "lat": "31.31901",
    "lng": "48.6842"
  },
  {
    "country": "IR",
    "name": "Ahram",
    "lat": "28.8826",
    "lng": "51.2746"
  },
  {
    "country": "IR",
    "name": "Ahar",
    "lat": "38.4774",
    "lng": "47.0699"
  },
  {
    "country": "IR",
    "name": "Aghajari",
    "lat": "30.7006",
    "lng": "49.8315"
  },
  {
    "country": "IR",
    "name": "Ābyek",
    "lat": "36.06667",
    "lng": "50.55"
  },
  {
    "country": "IR",
    "name": "Ābyek",
    "lat": "36.03993",
    "lng": "50.53101"
  },
  {
    "country": "IR",
    "name": "Abhar",
    "lat": "36.1468",
    "lng": "49.218"
  },
  {
    "country": "IR",
    "name": "Ābdānān",
    "lat": "32.9926",
    "lng": "47.4198"
  },
  {
    "country": "IR",
    "name": "‘Abbāsābād",
    "lat": "36.72769",
    "lng": "51.10574"
  },
  {
    "country": "IR",
    "name": "Ābbar",
    "lat": "36.92627",
    "lng": "48.95832"
  },
  {
    "country": "IR",
    "name": "Abarkūh",
    "lat": "31.1289",
    "lng": "53.2824"
  },
  {
    "country": "IR",
    "name": "Ābādeh",
    "lat": "31.1608",
    "lng": "52.6506"
  },
  {
    "country": "IR",
    "name": "Abadan",
    "lat": "30.3392",
    "lng": "48.3043"
  },
  {
    "country": "IR",
    "name": "Kūh Sefīd",
    "lat": "29.2762",
    "lng": "56.8014"
  },
  {
    "country": "IR",
    "name": "Abū Mūsā",
    "lat": "25.86698",
    "lng": "55.02363"
  },
  {
    "country": "IR",
    "name": "Showţ",
    "lat": "39.2192",
    "lng": "44.77"
  },
  {
    "country": "IR",
    "name": "Pāsārgād",
    "lat": "30.20194",
    "lng": "53.18"
  },
  {
    "country": "IR",
    "name": "Shahrak-e Pābedānā",
    "lat": "31.13444",
    "lng": "56.39806"
  },
  {
    "country": "IR",
    "name": "Khavāş Kūh",
    "lat": "32.30611",
    "lng": "53.67444"
  },
  {
    "country": "IR",
    "name": "Sepīdān",
    "lat": "30.26061",
    "lng": "51.98424"
  },
  {
    "country": "IR",
    "name": "Eqbālīyeh",
    "lat": "35.3022",
    "lng": "51.5358"
  },
  {
    "country": "IR",
    "name": "Shāhīn Shahr",
    "lat": "32.85788",
    "lng": "51.5529"
  },
  {
    "country": "IR",
    "name": "Shāhreẕā",
    "lat": "32.03389",
    "lng": "51.87944"
  },
  {
    "country": "IR",
    "name": "Zarrīn Shahr",
    "lat": "32.3897",
    "lng": "51.3766"
  },
  {
    "country": "IR",
    "name": "Tīrān",
    "lat": "32.7026",
    "lng": "51.1537"
  },
  {
    "country": "IR",
    "name": "Rehnān",
    "lat": "32.68325",
    "lng": "51.60158"
  },
  {
    "country": "IR",
    "name": "Shahreẕā",
    "lat": "32.0089",
    "lng": "51.8668"
  },
  {
    "country": "IR",
    "name": "Qahderījān",
    "lat": "32.5767",
    "lng": "51.455"
  },
  {
    "country": "IR",
    "name": "Najafābād",
    "lat": "32.6344",
    "lng": "51.3668"
  },
  {
    "country": "IR",
    "name": "Mobārakeh",
    "lat": "32.34651",
    "lng": "51.50449"
  },
  {
    "country": "IR",
    "name": "Khomeynī Shahr",
    "lat": "32.6856",
    "lng": "51.53609"
  },
  {
    "country": "IR",
    "name": "Kelīshād va Sūdarjān",
    "lat": "32.55118",
    "lng": "51.52758"
  },
  {
    "country": "IR",
    "name": "Falāvarjān",
    "lat": "32.5553",
    "lng": "51.50973"
  },
  {
    "country": "IR",
    "name": "Isfahan",
    "lat": "32.65246",
    "lng": "51.67462"
  },
  {
    "country": "IR",
    "name": "Dowlatābād",
    "lat": "32.79978",
    "lng": "51.69553"
  },
  {
    "country": "IR",
    "name": "Dorcheh Pīāz",
    "lat": "32.61528",
    "lng": "51.55556"
  },
  {
    "country": "IR",
    "name": "Eslāmshahr",
    "lat": "35.55222",
    "lng": "51.23504"
  },
  {
    "country": "IR",
    "name": "Shahrak-e Bākharz",
    "lat": "34.99204",
    "lng": "60.31714"
  },
  {
    "country": "IR",
    "name": "Zābol",
    "lat": "31.0306",
    "lng": "61.4949"
  },
  {
    "country": "IR",
    "name": "Zahedan",
    "lat": "29.4963",
    "lng": "60.8629"
  },
  {
    "country": "IR",
    "name": "Zehak",
    "lat": "30.894",
    "lng": "61.6804"
  },
  {
    "country": "IR",
    "name": "Zābolī",
    "lat": "27.131",
    "lng": "61.67445"
  },
  {
    "country": "IR",
    "name": "Torbat-e Jām",
    "lat": "35.244",
    "lng": "60.6225"
  },
  {
    "country": "IR",
    "name": "Tāybād",
    "lat": "34.74",
    "lng": "60.7756"
  },
  {
    "country": "IR",
    "name": "Sūrān",
    "lat": "27.2855",
    "lng": "61.9965"
  },
  {
    "country": "IR",
    "name": "Sarakhs",
    "lat": "36.5449",
    "lng": "61.1577"
  },
  {
    "country": "IR",
    "name": "Rāsak",
    "lat": "26.23682",
    "lng": "61.39901"
  },
  {
    "country": "IR",
    "name": "Qaşr-e Qand",
    "lat": "26.24833",
    "lng": "60.7525"
  },
  {
    "country": "IR",
    "name": "Nīkshahr",
    "lat": "26.2258",
    "lng": "60.2143"
  },
  {
    "country": "IR",
    "name": "Nehbandān",
    "lat": "31.54185",
    "lng": "60.03648"
  },
  {
    "country": "IR",
    "name": "Konārak",
    "lat": "25.3604",
    "lng": "60.3995"
  },
  {
    "country": "IR",
    "name": "Khvāf",
    "lat": "34.5763",
    "lng": "60.14093"
  },
  {
    "country": "IR",
    "name": "Khāsh",
    "lat": "28.22107",
    "lng": "61.21582"
  },
  {
    "country": "IR",
    "name": "Iranshahr",
    "lat": "27.20245",
    "lng": "60.68476"
  },
  {
    "country": "IR",
    "name": "Ḩājjīābād",
    "lat": "33.60496",
    "lng": "59.9934"
  },
  {
    "country": "IR",
    "name": "Dūst Moḩammad Khān",
    "lat": "31.1447",
    "lng": "61.7925"
  },
  {
    "country": "IR",
    "name": "Chabahar",
    "lat": "25.2919",
    "lng": "60.643"
  },
  {
    "country": "IR",
    "name": "Māmūnīyeh",
    "lat": "35.30555",
    "lng": "50.4992"
  },
  {
    "country": "IR",
    "name": "Āz̄arshahr",
    "lat": "37.759",
    "lng": "45.9783"
  },
  {
    "country": "IR",
    "name": "Tāzehābād",
    "lat": "34.7387",
    "lng": "46.1496"
  },
  {
    "country": "IR",
    "name": "Kāshān",
    "lat": "33.99728",
    "lng": "51.44158"
  },
  {
    "country": "IR",
    "name": "Jīroft",
    "lat": "28.67806",
    "lng": "57.74056"
  },
  {
    "country": "IR",
    "name": "Eslāmābād",
    "lat": "28.02611",
    "lng": "58"
  },
  {
    "country": "IR",
    "name": "Famast",
    "lat": "34.03897",
    "lng": "48.4626"
  },
  {
    "country": "IR",
    "name": "Kahnūj",
    "lat": "27.9519",
    "lng": "57.6996"
  },
  {
    "country": "IR",
    "name": "Mahdishahr",
    "lat": "35.71071",
    "lng": "53.35394"
  },
  {
    "country": "IR",
    "name": "Dalgān",
    "lat": "27.48232",
    "lng": "59.44656"
  },
  {
    "country": "IR",
    "name": "Āq Qalā",
    "lat": "37.0139",
    "lng": "54.45504"
  },
  {
    "country": "IR",
    "name": "Bandar-e Emam Khomeyni",
    "lat": "30.43698",
    "lng": "49.10288"
  },
  {
    "country": "IR",
    "name": "Qā’em Shahr",
    "lat": "36.48144",
    "lng": "52.89109"
  },
  {
    "country": "IR",
    "name": "Pākdasht",
    "lat": "35.47854",
    "lng": "51.6834"
  },
  {
    "country": "IR",
    "name": "Boshrūyeh",
    "lat": "33.86845",
    "lng": "57.42885"
  },
  {
    "country": "IR",
    "name": "Taft",
    "lat": "31.76056",
    "lng": "54.22303"
  },
  {
    "country": "IR",
    "name": "Gīvī",
    "lat": "37.68585",
    "lng": "48.34204"
  },
  {
    "country": "IR",
    "name": "Rey",
    "lat": "35.59354",
    "lng": "51.43997"
  },
  {
    "country": "IR",
    "name": "Bahābād",
    "lat": "31.87091",
    "lng": "56.02433"
  },
  {
    "country": "IR",
    "name": "Pasragad Branch",
    "lat": "34.77772",
    "lng": "48.47168"
  },
  {
    "country": "IS",
    "name": "Siglufjörður",
    "lat": "66.15198",
    "lng": "-18.90815"
  },
  {
    "country": "IS",
    "name": "Sauðárkrókur",
    "lat": "65.74611",
    "lng": "-19.63944"
  },
  {
    "country": "IS",
    "name": "Neskaupstaður",
    "lat": "65.14819",
    "lng": "-13.68368"
  },
  {
    "country": "IS",
    "name": "Húsavík",
    "lat": "66.04148",
    "lng": "-17.33834"
  },
  {
    "country": "IS",
    "name": "Höfn",
    "lat": "64.25388",
    "lng": "-15.21212"
  },
  {
    "country": "IS",
    "name": "Eskifjörður",
    "lat": "65.07306",
    "lng": "-14.01525"
  },
  {
    "country": "IS",
    "name": "Egilsstaðir",
    "lat": "65.26687",
    "lng": "-14.39485"
  },
  {
    "country": "IS",
    "name": "Dalvík",
    "lat": "65.97018",
    "lng": "-18.52861"
  },
  {
    "country": "IS",
    "name": "Reyðarfjörður",
    "lat": "65.03164",
    "lng": "-14.21832"
  },
  {
    "country": "IS",
    "name": "Akureyri",
    "lat": "65.68353",
    "lng": "-18.0878"
  },
  {
    "country": "IS",
    "name": "Vogar",
    "lat": "63.9816",
    "lng": "-22.38473"
  },
  {
    "country": "IS",
    "name": "Vestmannaeyjar",
    "lat": "63.44273",
    "lng": "-20.27339"
  },
  {
    "country": "IS",
    "name": "Þorlákshöfn",
    "lat": "63.85591",
    "lng": "-21.38337"
  },
  {
    "country": "IS",
    "name": "Stykkishólmur",
    "lat": "65.07537",
    "lng": "-22.72977"
  },
  {
    "country": "IS",
    "name": "Selfoss",
    "lat": "63.93311",
    "lng": "-20.99712"
  },
  {
    "country": "IS",
    "name": "Sandgerði",
    "lat": "64.03762",
    "lng": "-22.70799"
  },
  {
    "country": "IS",
    "name": "Reykjavík",
    "lat": "64.13548",
    "lng": "-21.89541"
  },
  {
    "country": "IS",
    "name": "Ólafsvík",
    "lat": "64.89429",
    "lng": "-23.70918"
  },
  {
    "country": "IS",
    "name": "Seltjarnarnes",
    "lat": "64.15309",
    "lng": "-21.99499"
  },
  {
    "country": "IS",
    "name": "Mosfellsbær",
    "lat": "64.16667",
    "lng": "-21.7"
  },
  {
    "country": "IS",
    "name": "Kópavogur",
    "lat": "64.11234",
    "lng": "-21.91298"
  },
  {
    "country": "IS",
    "name": "Keflavík",
    "lat": "64.00492",
    "lng": "-22.56242"
  },
  {
    "country": "IS",
    "name": "Ísafjörður",
    "lat": "66.07475",
    "lng": "-23.13498"
  },
  {
    "country": "IS",
    "name": "Hveragerði",
    "lat": "64.00039",
    "lng": "-21.18602"
  },
  {
    "country": "IS",
    "name": "Hafnarfjörður",
    "lat": "64.0671",
    "lng": "-21.93774"
  },
  {
    "country": "IS",
    "name": "Grindavík",
    "lat": "63.83849",
    "lng": "-22.43931"
  },
  {
    "country": "IS",
    "name": "Garður",
    "lat": "64.06558",
    "lng": "-22.64656"
  },
  {
    "country": "IS",
    "name": "Garðabær",
    "lat": "64.08865",
    "lng": "-21.92298"
  },
  {
    "country": "IS",
    "name": "Álftanes",
    "lat": "64.1",
    "lng": "-22.01667"
  },
  {
    "country": "IS",
    "name": "Borgarnes",
    "lat": "64.53834",
    "lng": "-21.92064"
  },
  {
    "country": "IS",
    "name": "Akranes",
    "lat": "64.32179",
    "lng": "-22.0749"
  },
  {
    "country": "IS",
    "name": "Laugar",
    "lat": "65.72159",
    "lng": "-17.37352"
  },
  {
    "country": "IS",
    "name": "Reykjanesbær",
    "lat": "63.99813",
    "lng": "-22.56111"
  },
  {
    "country": "IT",
    "name": "Zumpano",
    "lat": "39.31053",
    "lng": "16.29269"
  },
  {
    "country": "IT",
    "name": "Zerfaliu",
    "lat": "39.96088",
    "lng": "8.70971"
  },
  {
    "country": "IT",
    "name": "Zeddiani",
    "lat": "39.98898",
    "lng": "8.5958"
  },
  {
    "country": "IT",
    "name": "Zambrone",
    "lat": "38.69878",
    "lng": "15.98982"
  },
  {
    "country": "IT",
    "name": "Zagarise",
    "lat": "38.99985",
    "lng": "16.6642"
  },
  {
    "country": "IT",
    "name": "Zafferana Etnea",
    "lat": "37.67895",
    "lng": "15.10432"
  },
  {
    "country": "IT",
    "name": "Zaccanopoli",
    "lat": "38.66548",
    "lng": "15.92874"
  },
  {
    "country": "IT",
    "name": "Vizzini",
    "lat": "37.16188",
    "lng": "14.75712"
  },
  {
    "country": "IT",
    "name": "Vittoria",
    "lat": "36.95151",
    "lng": "14.52788"
  },
  {
    "country": "IT",
    "name": "Vita",
    "lat": "37.86886",
    "lng": "12.82755"
  },
  {
    "country": "IT",
    "name": "Villaurbana",
    "lat": "39.88505",
    "lng": "8.77831"
  },
  {
    "country": "IT",
    "name": "Villaspeciosa",
    "lat": "39.31142",
    "lng": "8.92584"
  },
  {
    "country": "IT",
    "name": "Villasor",
    "lat": "39.3813",
    "lng": "8.9427"
  },
  {
    "country": "IT",
    "name": "Villasmundo",
    "lat": "37.25132",
    "lng": "15.09087"
  },
  {
    "country": "IT",
    "name": "Villasimius",
    "lat": "39.14481",
    "lng": "9.51823"
  },
  {
    "country": "IT",
    "name": "Villa San Giovanni",
    "lat": "38.21991",
    "lng": "15.63689"
  },
  {
    "country": "IT",
    "name": "Villasalto",
    "lat": "39.49209",
    "lng": "9.39023"
  },
  {
    "country": "IT",
    "name": "Villarosa",
    "lat": "37.58753",
    "lng": "14.17089"
  },
  {
    "country": "IT",
    "name": "Villaputzu",
    "lat": "39.44058",
    "lng": "9.57564"
  },
  {
    "country": "IT",
    "name": "Villapiana",
    "lat": "39.84573",
    "lng": "16.45528"
  },
  {
    "country": "IT",
    "name": "Villanova Truschedu",
    "lat": "39.98842",
    "lng": "8.75177"
  },
  {
    "country": "IT",
    "name": "Villanovafranca",
    "lat": "39.64442",
    "lng": "9.00244"
  },
  {
    "country": "IT",
    "name": "Villanovaforru",
    "lat": "39.63196",
    "lng": "8.86979"
  },
  {
    "country": "IT",
    "name": "Villamassargia",
    "lat": "39.27484",
    "lng": "8.6411"
  },
  {
    "country": "IT",
    "name": "Villamar",
    "lat": "39.61884",
    "lng": "8.95877"
  },
  {
    "country": "IT",
    "name": "Villalba",
    "lat": "37.65457",
    "lng": "13.84452"
  },
  {
    "country": "IT",
    "name": "Villagrande Strisaili",
    "lat": "39.95929",
    "lng": "9.50943"
  },
  {
    "country": "IT",
    "name": "Villafrati",
    "lat": "37.90646",
    "lng": "13.48486"
  },
  {
    "country": "IT",
    "name": "Villafranca Tirrena",
    "lat": "38.23952",
    "lng": "15.43885"
  },
  {
    "country": "IT",
    "name": "Villafranca Sicula",
    "lat": "37.58761",
    "lng": "13.29048"
  },
  {
    "country": "IT",
    "name": "Villacidro",
    "lat": "39.45734",
    "lng": "8.74105"
  },
  {
    "country": "IT",
    "name": "Villabate",
    "lat": "38.07789",
    "lng": "13.44275"
  },
  {
    "country": "IT",
    "name": "Viggianello",
    "lat": "39.97227",
    "lng": "16.08521"
  },
  {
    "country": "IT",
    "name": "Vicari",
    "lat": "37.82371",
    "lng": "13.56889"
  },
  {
    "country": "IT",
    "name": "Vibo Valentia",
    "lat": "38.67618",
    "lng": "16.10094"
  },
  {
    "country": "IT",
    "name": "Viagrande",
    "lat": "37.61032",
    "lng": "15.09794"
  },
  {
    "country": "IT",
    "name": "Verzino",
    "lat": "39.31325",
    "lng": "16.85613"
  },
  {
    "country": "IT",
    "name": "Verbicaro",
    "lat": "39.76076",
    "lng": "15.9073"
  },
  {
    "country": "IT",
    "name": "Ventimiglia di Sicilia",
    "lat": "37.92361",
    "lng": "13.56768"
  },
  {
    "country": "IT",
    "name": "Venetico Superiore",
    "lat": "38.19307",
    "lng": "15.38119"
  },
  {
    "country": "IT",
    "name": "Vazzano",
    "lat": "38.63288",
    "lng": "16.248"
  },
  {
    "country": "IT",
    "name": "Varapodio",
    "lat": "38.31633",
    "lng": "15.98347"
  },
  {
    "country": "IT",
    "name": "Vallermosa",
    "lat": "39.36389",
    "lng": "8.79556"
  },
  {
    "country": "IT",
    "name": "Vallelunga Pratameno",
    "lat": "37.68205",
    "lng": "13.83156"
  },
  {
    "country": "IT",
    "name": "Vallelonga",
    "lat": "38.64742",
    "lng": "16.29659"
  },
  {
    "country": "IT",
    "name": "Vallefiorita",
    "lat": "38.77638",
    "lng": "16.461"
  },
  {
    "country": "IT",
    "name": "Valledolmo",
    "lat": "37.74703",
    "lng": "13.82811"
  },
  {
    "country": "IT",
    "name": "Valguarnera Caropepe",
    "lat": "37.49527",
    "lng": "14.39025"
  },
  {
    "country": "IT",
    "name": "Valdina",
    "lat": "38.19351",
    "lng": "15.3698"
  },
  {
    "country": "IT",
    "name": "Vaccarizzo Albanese",
    "lat": "39.5854",
    "lng": "16.43289"
  },
  {
    "country": "IT",
    "name": "Uta",
    "lat": "39.29186",
    "lng": "8.95234"
  },
  {
    "country": "IT",
    "name": "Ustica",
    "lat": "38.70985",
    "lng": "13.19293"
  },
  {
    "country": "IT",
    "name": "Ussassai",
    "lat": "39.80998",
    "lng": "9.39508"
  },
  {
    "country": "IT",
    "name": "Ussaramanna",
    "lat": "39.6925",
    "lng": "8.9085"
  },
  {
    "country": "IT",
    "name": "Ussana",
    "lat": "39.39374",
    "lng": "9.07496"
  },
  {
    "country": "IT",
    "name": "Usellus",
    "lat": "39.80833",
    "lng": "8.85167"
  },
  {
    "country": "IT",
    "name": "Uras",
    "lat": "39.69799",
    "lng": "8.70143"
  },
  {
    "country": "IT",
    "name": "Umbriatico",
    "lat": "39.35336",
    "lng": "16.91798"
  },
  {
    "country": "IT",
    "name": "San Ciro-Ulmi-Filci",
    "lat": "37.83328",
    "lng": "12.78229"
  },
  {
    "country": "IT",
    "name": "Ulassai",
    "lat": "39.81033",
    "lng": "9.49962"
  },
  {
    "country": "IT",
    "name": "Ugento",
    "lat": "39.92724",
    "lng": "18.15832"
  },
  {
    "country": "IT",
    "name": "Ucria",
    "lat": "38.04624",
    "lng": "14.88087"
  },
  {
    "country": "IT",
    "name": "Tusa",
    "lat": "37.98385",
    "lng": "14.23606"
  },
  {
    "country": "IT",
    "name": "Turri",
    "lat": "39.70476",
    "lng": "8.91656"
  },
  {
    "country": "IT",
    "name": "Tuili",
    "lat": "39.71477",
    "lng": "8.9602"
  },
  {
    "country": "IT",
    "name": "Tropea",
    "lat": "38.67449",
    "lng": "15.89505"
  },
  {
    "country": "IT",
    "name": "Troina",
    "lat": "37.78437",
    "lng": "14.59605"
  },
  {
    "country": "IT",
    "name": "Tripi",
    "lat": "38.04673",
    "lng": "15.0967"
  },
  {
    "country": "IT",
    "name": "Tricase",
    "lat": "39.93018",
    "lng": "18.35421"
  },
  {
    "country": "IT",
    "name": "Trenta",
    "lat": "39.28541",
    "lng": "16.32093"
  },
  {
    "country": "IT",
    "name": "Trecastagni",
    "lat": "37.61543",
    "lng": "15.07796"
  },
  {
    "country": "IT",
    "name": "Trebisacce",
    "lat": "39.87128",
    "lng": "16.5342"
  },
  {
    "country": "IT",
    "name": "Tratalias",
    "lat": "39.10347",
    "lng": "8.57858"
  },
  {
    "country": "IT",
    "name": "Trapani",
    "lat": "38.0176",
    "lng": "12.53617"
  },
  {
    "country": "IT",
    "name": "Tramatza",
    "lat": "40.00292",
    "lng": "8.64944"
  },
  {
    "country": "IT",
    "name": "Trabia",
    "lat": "38.0042",
    "lng": "13.63393"
  },
  {
    "country": "IT",
    "name": "Tortorici",
    "lat": "38.02973",
    "lng": "14.82212"
  },
  {
    "country": "IT",
    "name": "Tortora",
    "lat": "39.9413",
    "lng": "15.80518"
  },
  {
    "country": "IT",
    "name": "Tortolì",
    "lat": "39.92626",
    "lng": "9.65569"
  },
  {
    "country": "IT",
    "name": "Torretta",
    "lat": "39.45358",
    "lng": "17.03632"
  },
  {
    "country": "IT",
    "name": "Torretta",
    "lat": "38.13036",
    "lng": "13.23549"
  },
  {
    "country": "IT",
    "name": "Campora San Giovanni",
    "lat": "39.06798",
    "lng": "16.09566"
  },
  {
    "country": "IT",
    "name": "Torrenova",
    "lat": "38.09246",
    "lng": "14.67917"
  },
  {
    "country": "IT",
    "name": "Torre Melissa",
    "lat": "39.31013",
    "lng": "17.1066"
  },
  {
    "country": "IT",
    "name": "Torregrotta",
    "lat": "38.20262",
    "lng": "15.3501"
  },
  {
    "country": "IT",
    "name": "Torre di Ruggiero",
    "lat": "38.65293",
    "lng": "16.37211"
  },
  {
    "country": "IT",
    "name": "Torano Castello",
    "lat": "39.50396",
    "lng": "16.16103"
  },
  {
    "country": "IT",
    "name": "Tiriolo",
    "lat": "38.94069",
    "lng": "16.51046"
  },
  {
    "country": "IT",
    "name": "Tiggiano",
    "lat": "39.90284",
    "lng": "18.36501"
  },
  {
    "country": "IT",
    "name": "Teulada",
    "lat": "38.96658",
    "lng": "8.77149"
  },
  {
    "country": "IT",
    "name": "Tertenia",
    "lat": "39.69518",
    "lng": "9.57878"
  },
  {
    "country": "IT",
    "name": "Terravecchia",
    "lat": "39.46594",
    "lng": "16.94623"
  },
  {
    "country": "IT",
    "name": "Terrasini",
    "lat": "38.14621",
    "lng": "13.08319"
  },
  {
    "country": "IT",
    "name": "Terranova Sappo Minulio",
    "lat": "38.32175",
    "lng": "16.00747"
  },
  {
    "country": "IT",
    "name": "Terranova da Sibari",
    "lat": "39.65548",
    "lng": "16.33979"
  },
  {
    "country": "IT",
    "name": "Terranova di Pollino",
    "lat": "39.97765",
    "lng": "16.29583"
  },
  {
    "country": "IT",
    "name": "Terralba",
    "lat": "39.72056",
    "lng": "8.63504"
  },
  {
    "country": "IT",
    "name": "Termini Imerese",
    "lat": "37.98225",
    "lng": "13.69729"
  },
  {
    "country": "IT",
    "name": "Taviano",
    "lat": "39.98224",
    "lng": "18.08151"
  },
  {
    "country": "IT",
    "name": "Taverna",
    "lat": "39.022",
    "lng": "16.58081"
  },
  {
    "country": "IT",
    "name": "Taurisano",
    "lat": "39.95746",
    "lng": "18.21498"
  },
  {
    "country": "IT",
    "name": "Taurianova",
    "lat": "38.35525",
    "lng": "16.01306"
  },
  {
    "country": "IT",
    "name": "Tarsia",
    "lat": "39.62311",
    "lng": "16.27337"
  },
  {
    "country": "IT",
    "name": "Taormina",
    "lat": "37.85358",
    "lng": "15.28851"
  },
  {
    "country": "IT",
    "name": "Sutera",
    "lat": "37.52493",
    "lng": "13.73274"
  },
  {
    "country": "IT",
    "name": "Surdo",
    "lat": "39.32752",
    "lng": "16.20139"
  },
  {
    "country": "IT",
    "name": "Suelli",
    "lat": "39.56257",
    "lng": "9.13245"
  },
  {
    "country": "IT",
    "name": "Strongoli",
    "lat": "39.26576",
    "lng": "17.05413"
  },
  {
    "country": "IT",
    "name": "Stilo",
    "lat": "38.47628",
    "lng": "16.46746"
  },
  {
    "country": "IT",
    "name": "Stignano",
    "lat": "38.41705",
    "lng": "16.47011"
  },
  {
    "country": "IT",
    "name": "Staletti",
    "lat": "38.76428",
    "lng": "16.53932"
  },
  {
    "country": "IT",
    "name": "Staiti",
    "lat": "37.99989",
    "lng": "16.03341"
  },
  {
    "country": "IT",
    "name": "Squillace",
    "lat": "38.78091",
    "lng": "16.51175"
  },
  {
    "country": "IT",
    "name": "Spilinga",
    "lat": "38.62825",
    "lng": "15.90572"
  },
  {
    "country": "IT",
    "name": "Spezzano Piccolo",
    "lat": "39.2901",
    "lng": "16.34211"
  },
  {
    "country": "IT",
    "name": "Spezzano della Sila",
    "lat": "39.30033",
    "lng": "16.33923"
  },
  {
    "country": "IT",
    "name": "Spezzano Albanese",
    "lat": "39.66854",
    "lng": "16.30939"
  },
  {
    "country": "IT",
    "name": "Sperlinga",
    "lat": "37.76653",
    "lng": "14.35075"
  },
  {
    "country": "IT",
    "name": "Specchia",
    "lat": "39.93913",
    "lng": "18.29784"
  },
  {
    "country": "IT",
    "name": "Sparta'",
    "lat": "38.29371",
    "lng": "15.53503"
  },
  {
    "country": "IT",
    "name": "Spadafora",
    "lat": "38.22349",
    "lng": "15.38178"
  },
  {
    "country": "IT",
    "name": "Soveria Simeri",
    "lat": "38.94986",
    "lng": "16.67854"
  },
  {
    "country": "IT",
    "name": "Soveria Mannelli",
    "lat": "39.07784",
    "lng": "16.37708"
  },
  {
    "country": "IT",
    "name": "Soverato Superiore",
    "lat": "38.68993",
    "lng": "16.53391"
  },
  {
    "country": "IT",
    "name": "Soverato Marina",
    "lat": "38.68498",
    "lng": "16.54991"
  },
  {
    "country": "IT",
    "name": "Sortino",
    "lat": "37.15881",
    "lng": "15.02998"
  },
  {
    "country": "IT",
    "name": "Soriano Calabro",
    "lat": "38.60038",
    "lng": "16.22205"
  },
  {
    "country": "IT",
    "name": "Sorianello",
    "lat": "38.59415",
    "lng": "16.23212"
  },
  {
    "country": "IT",
    "name": "Sorbo San Basile",
    "lat": "39.01939",
    "lng": "16.5691"
  },
  {
    "country": "IT",
    "name": "Sommatino",
    "lat": "37.33471",
    "lng": "13.99739"
  },
  {
    "country": "IT",
    "name": "Soleminis",
    "lat": "39.3476",
    "lng": "9.18127"
  },
  {
    "country": "IT",
    "name": "Solarussa",
    "lat": "39.95499",
    "lng": "8.67393"
  },
  {
    "country": "IT",
    "name": "Solarino",
    "lat": "37.10136",
    "lng": "15.11988"
  },
  {
    "country": "IT",
    "name": "Solanas",
    "lat": "39.93031",
    "lng": "8.5534"
  },
  {
    "country": "IT",
    "name": "Siris",
    "lat": "39.71228",
    "lng": "8.77507"
  },
  {
    "country": "IT",
    "name": "Siracusa",
    "lat": "37.07542",
    "lng": "15.28664"
  },
  {
    "country": "IT",
    "name": "Sinopoli",
    "lat": "38.26342",
    "lng": "15.8771"
  },
  {
    "country": "IT",
    "name": "Sinnai",
    "lat": "39.30286",
    "lng": "9.20283"
  },
  {
    "country": "IT",
    "name": "Sini",
    "lat": "39.75353",
    "lng": "8.90486"
  },
  {
    "country": "IT",
    "name": "Sinagra",
    "lat": "38.08191",
    "lng": "14.85009"
  },
  {
    "country": "IT",
    "name": "Simbario",
    "lat": "38.61157",
    "lng": "16.33597"
  },
  {
    "country": "IT",
    "name": "Simaxis",
    "lat": "39.92995",
    "lng": "8.68979"
  },
  {
    "country": "IT",
    "name": "Simala",
    "lat": "39.72099",
    "lng": "8.82802"
  },
  {
    "country": "IT",
    "name": "Silius",
    "lat": "39.51695",
    "lng": "9.2936"
  },
  {
    "country": "IT",
    "name": "Siliqua",
    "lat": "39.301",
    "lng": "8.80584"
  },
  {
    "country": "IT",
    "name": "Silì",
    "lat": "39.91789",
    "lng": "8.62194"
  },
  {
    "country": "IT",
    "name": "Siderno",
    "lat": "38.26993",
    "lng": "16.29607"
  },
  {
    "country": "IT",
    "name": "Siddi",
    "lat": "39.67255",
    "lng": "8.88815"
  },
  {
    "country": "IT",
    "name": "Siculiana",
    "lat": "37.33515",
    "lng": "13.42432"
  },
  {
    "country": "IT",
    "name": "Sibari",
    "lat": "39.74733",
    "lng": "16.4551"
  },
  {
    "country": "IT",
    "name": "Siapiccia",
    "lat": "39.92765",
    "lng": "8.7627"
  },
  {
    "country": "IT",
    "name": "Siano",
    "lat": "38.91547",
    "lng": "16.60224"
  },
  {
    "country": "IT",
    "name": "Siamanna",
    "lat": "39.91936",
    "lng": "8.76185"
  },
  {
    "country": "IT",
    "name": "Siamaggiore",
    "lat": "39.94966",
    "lng": "8.63461"
  },
  {
    "country": "IT",
    "name": "Seulo",
    "lat": "39.86955",
    "lng": "9.23606"
  },
  {
    "country": "IT",
    "name": "Seui",
    "lat": "39.83908",
    "lng": "9.32347"
  },
  {
    "country": "IT",
    "name": "Setzu",
    "lat": "39.72306",
    "lng": "8.93972"
  },
  {
    "country": "IT",
    "name": "Settimo San Pietro",
    "lat": "39.2911",
    "lng": "9.1857"
  },
  {
    "country": "IT",
    "name": "Sestu",
    "lat": "39.29846",
    "lng": "9.09248"
  },
  {
    "country": "IT",
    "name": "Sersale",
    "lat": "39.01013",
    "lng": "16.7296"
  },
  {
    "country": "IT",
    "name": "Serri",
    "lat": "39.7015",
    "lng": "9.1449"
  },
  {
    "country": "IT",
    "name": "Serrenti",
    "lat": "39.49277",
    "lng": "8.97659"
  },
  {
    "country": "IT",
    "name": "Serrata",
    "lat": "38.51288",
    "lng": "16.1007"
  },
  {
    "country": "IT",
    "name": "Serrastretta",
    "lat": "39.01319",
    "lng": "16.4163"
  },
  {
    "country": "IT",
    "name": "Serra San Bruno",
    "lat": "38.57474",
    "lng": "16.32622"
  },
  {
    "country": "IT",
    "name": "Serra Pedace",
    "lat": "39.27898",
    "lng": "16.34557"
  },
  {
    "country": "IT",
    "name": "Serramanna",
    "lat": "39.42335",
    "lng": "8.92243"
  },
  {
    "country": "IT",
    "name": "Serradifalco",
    "lat": "37.45384",
    "lng": "13.88046"
  },
  {
    "country": "IT",
    "name": "Serra d'Aiello",
    "lat": "39.09004",
    "lng": "16.12612"
  },
  {
    "country": "IT",
    "name": "Serdiana",
    "lat": "39.37457",
    "lng": "9.15851"
  },
  {
    "country": "IT",
    "name": "Senorbì",
    "lat": "39.53341",
    "lng": "9.13168"
  },
  {
    "country": "IT",
    "name": "Senis",
    "lat": "39.82318",
    "lng": "8.93916"
  },
  {
    "country": "IT",
    "name": "Seminara",
    "lat": "38.33603",
    "lng": "15.87025"
  },
  {
    "country": "IT",
    "name": "Sellia",
    "lat": "38.98206",
    "lng": "16.6307"
  },
  {
    "country": "IT",
    "name": "Selegas",
    "lat": "39.5678",
    "lng": "9.10348"
  },
  {
    "country": "IT",
    "name": "Selargius",
    "lat": "39.25779",
    "lng": "9.16323"
  },
  {
    "country": "IT",
    "name": "Segariu",
    "lat": "39.56403",
    "lng": "8.98163"
  },
  {
    "country": "IT",
    "name": "Scordia",
    "lat": "37.29548",
    "lng": "14.84058"
  },
  {
    "country": "IT",
    "name": "Scoglitti",
    "lat": "36.89424",
    "lng": "14.43355"
  },
  {
    "country": "IT",
    "name": "Sclafani Bagni",
    "lat": "37.82175",
    "lng": "13.85476"
  },
  {
    "country": "IT",
    "name": "Scillato",
    "lat": "37.85778",
    "lng": "13.90632"
  },
  {
    "country": "IT",
    "name": "Scilla",
    "lat": "38.25201",
    "lng": "15.71837"
  },
  {
    "country": "IT",
    "name": "Scido",
    "lat": "38.24439",
    "lng": "15.93251"
  },
  {
    "country": "IT",
    "name": "Scicli",
    "lat": "36.79014",
    "lng": "14.7028"
  },
  {
    "country": "IT",
    "name": "Sciara",
    "lat": "37.91511",
    "lng": "13.76177"
  },
  {
    "country": "IT",
    "name": "Sciacca",
    "lat": "37.50693",
    "lng": "13.08399"
  },
  {
    "country": "IT",
    "name": "Scarcelli",
    "lat": "39.4",
    "lng": "16.01667"
  },
  {
    "country": "IT",
    "name": "Scandale",
    "lat": "39.12339",
    "lng": "16.96185"
  },
  {
    "country": "IT",
    "name": "Scaletta Zanclea",
    "lat": "38.04796",
    "lng": "15.46769"
  },
  {
    "country": "IT",
    "name": "Scalea",
    "lat": "39.80605",
    "lng": "15.79635"
  },
  {
    "country": "IT",
    "name": "Scala Coeli",
    "lat": "39.44824",
    "lng": "16.88658"
  },
  {
    "country": "IT",
    "name": "Savelli",
    "lat": "39.31278",
    "lng": "16.77642"
  },
  {
    "country": "IT",
    "name": "Satriano",
    "lat": "38.6664",
    "lng": "16.4797"
  },
  {
    "country": "IT",
    "name": "Sartano",
    "lat": "39.51169",
    "lng": "16.17915"
  },
  {
    "country": "IT",
    "name": "Sarroch",
    "lat": "39.06577",
    "lng": "9.00937"
  },
  {
    "country": "IT",
    "name": "Sardara",
    "lat": "39.61465",
    "lng": "8.82088"
  },
  {
    "country": "IT",
    "name": "Saracena",
    "lat": "39.77862",
    "lng": "16.15913"
  },
  {
    "country": "IT",
    "name": "Saponara",
    "lat": "38.19241",
    "lng": "15.43442"
  },
  {
    "country": "IT",
    "name": "San Vito Sullo Ionio",
    "lat": "38.70749",
    "lng": "16.40862"
  },
  {
    "country": "IT",
    "name": "San Vito Lo Capo",
    "lat": "38.17395",
    "lng": "12.73599"
  },
  {
    "country": "IT",
    "name": "San Vito",
    "lat": "39.44142",
    "lng": "9.54065"
  },
  {
    "country": "IT",
    "name": "San Vincenzo la Costa",
    "lat": "39.36544",
    "lng": "16.1511"
  },
  {
    "country": "IT",
    "name": "Santo Stefano Quisquina",
    "lat": "37.62606",
    "lng": "13.48976"
  },
  {
    "country": "IT",
    "name": "Santo Stefano in Aspromonte",
    "lat": "38.16909",
    "lng": "15.78983"
  },
  {
    "country": "IT",
    "name": "Santo Stefano di Rogliano",
    "lat": "39.19223",
    "lng": "16.32079"
  },
  {
    "country": "IT",
    "name": "Santo Stefano di Camastra",
    "lat": "38.01295",
    "lng": "14.35142"
  },
  {
    "country": "IT",
    "name": "San Sperate",
    "lat": "39.35758",
    "lng": "9.00814"
  },
  {
    "country": "IT",
    "name": "Sant'Onofrio",
    "lat": "38.69752",
    "lng": "16.14755"
  },
  {
    "country": "IT",
    "name": "Sant'Ilario dello Ionio",
    "lat": "38.21914",
    "lng": "16.19517"
  },
  {
    "country": "IT",
    "name": "Santa Eufemia Lamezia",
    "lat": "38.91982",
    "lng": "16.25221"
  },
  {
    "country": "IT",
    "name": "Sant'Eufemia d'Aspromonte",
    "lat": "38.26314",
    "lng": "15.85669"
  },
  {
    "country": "IT",
    "name": "San Teodoro",
    "lat": "37.84797",
    "lng": "14.69878"
  },
  {
    "country": "IT",
    "name": "Sant'Elia",
    "lat": "38.95788",
    "lng": "16.58521"
  },
  {
    "country": "IT",
    "name": "Santa Venerina",
    "lat": "37.69103",
    "lng": "15.1388"
  },
  {
    "country": "IT",
    "name": "Santa Teresa di Riva",
    "lat": "37.94635",
    "lng": "15.36671"
  },
  {
    "country": "IT",
    "name": "Santa Sofia d'Epiro",
    "lat": "39.54597",
    "lng": "16.32815"
  },
  {
    "country": "IT",
    "name": "Santa Severina",
    "lat": "39.1477",
    "lng": "16.91112"
  },
  {
    "country": "IT",
    "name": "Sant'Antioco",
    "lat": "39.07017",
    "lng": "8.45243"
  },
  {
    "country": "IT",
    "name": "Sant'Anna Arresi",
    "lat": "39.00618",
    "lng": "8.64236"
  },
  {
    "country": "IT",
    "name": "Santa Ninfa",
    "lat": "37.77042",
    "lng": "12.87744"
  },
  {
    "country": "IT",
    "name": "Sant'Angelo Muxaro",
    "lat": "37.48014",
    "lng": "13.54554"
  },
  {
    "country": "IT",
    "name": "Sant'Angelo di Brolo",
    "lat": "38.11518",
    "lng": "14.88403"
  },
  {
    "country": "IT",
    "name": "Gerocarne",
    "lat": "38.58767",
    "lng": "16.21818"
  },
  {
    "country": "IT",
    "name": "Sant'Andrea Frius",
    "lat": "39.47917",
    "lng": "9.17"
  },
  {
    "country": "IT",
    "name": "Sant'Andrea Apostolo dello Ionio",
    "lat": "38.62165",
    "lng": "16.53048"
  },
  {
    "country": "IT",
    "name": "Santa Marina Salina",
    "lat": "38.56117",
    "lng": "14.87077"
  },
  {
    "country": "IT",
    "name": "Santa Maria di Licodia",
    "lat": "37.61684",
    "lng": "14.89337"
  },
  {
    "country": "IT",
    "name": "Santa Margherita di Belice",
    "lat": "37.69281",
    "lng": "13.01584"
  },
  {
    "country": "IT",
    "name": "Santa Lucia del Mela",
    "lat": "38.14408",
    "lng": "15.28055"
  },
  {
    "country": "IT",
    "name": "Sant'Alfio",
    "lat": "37.74393",
    "lng": "15.13952"
  },
  {
    "country": "IT",
    "name": "Sant'Alessio Siculo",
    "lat": "37.92516",
    "lng": "15.34968"
  },
  {
    "country": "IT",
    "name": "Sant'Alessio in Aspromonte",
    "lat": "38.1722",
    "lng": "15.7573"
  },
  {
    "country": "IT",
    "name": "Santa Giusta",
    "lat": "39.8807",
    "lng": "8.60916"
  },
  {
    "country": "IT",
    "name": "Sant'Agata di Militello",
    "lat": "38.06838",
    "lng": "14.636"
  },
  {
    "country": "IT",
    "name": "Sant'Agata di Esaro",
    "lat": "39.62235",
    "lng": "15.98295"
  },
  {
    "country": "IT",
    "name": "Santa Flavia",
    "lat": "38.10448",
    "lng": "13.5334"
  },
  {
    "country": "IT",
    "name": "Santa Elisabetta",
    "lat": "37.43171",
    "lng": "13.55386"
  },
  {
    "country": "IT",
    "name": "Santa Domenica Vittoria",
    "lat": "37.91624",
    "lng": "14.96288"
  },
  {
    "country": "IT",
    "name": "Santa Domenica Talao",
    "lat": "39.81875",
    "lng": "15.8538"
  },
  {
    "country": "IT",
    "name": "Santa Domenica",
    "lat": "38.6622",
    "lng": "15.86289"
  },
  {
    "country": "IT",
    "name": "Santadi",
    "lat": "39.09356",
    "lng": "8.71259"
  },
  {
    "country": "IT",
    "name": "Santa Croce Camerina",
    "lat": "36.82842",
    "lng": "14.52538"
  },
  {
    "country": "IT",
    "name": "Santa Cristina Gela",
    "lat": "37.98514",
    "lng": "13.32747"
  },
  {
    "country": "IT",
    "name": "Santa Cristina d'Aspromonte",
    "lat": "38.2548",
    "lng": "15.96996"
  },
  {
    "country": "IT",
    "name": "Santa Caterina Villarmosa",
    "lat": "37.59034",
    "lng": "14.03554"
  },
  {
    "country": "IT",
    "name": "Santa Caterina dello Ionio",
    "lat": "38.53324",
    "lng": "16.52176"
  },
  {
    "country": "IT",
    "name": "Santa Caterina Albanese",
    "lat": "39.5859",
    "lng": "16.07039"
  },
  {
    "country": "IT",
    "name": "San Sosti",
    "lat": "39.65879",
    "lng": "16.02958"
  },
  {
    "country": "IT",
    "name": "San Sostene",
    "lat": "38.63733",
    "lng": "16.48751"
  },
  {
    "country": "IT",
    "name": "San Salvatore di Fitalia",
    "lat": "38.06841",
    "lng": "14.77799"
  },
  {
    "country": "IT",
    "name": "San Roberto",
    "lat": "38.21114",
    "lng": "15.73594"
  },
  {
    "country": "IT",
    "name": "San Procopio",
    "lat": "38.28214",
    "lng": "15.89083"
  },
  {
    "country": "IT",
    "name": "Villa San Pietro",
    "lat": "39.03554",
    "lng": "8.99695"
  },
  {
    "country": "IT",
    "name": "San Pietro in Guarano",
    "lat": "39.34164",
    "lng": "16.31304"
  },
  {
    "country": "IT",
    "name": "San Pietro in Amantea",
    "lat": "39.13658",
    "lng": "16.11243"
  },
  {
    "country": "IT",
    "name": "San Pietro Apostolo",
    "lat": "39.00413",
    "lng": "16.46783"
  },
  {
    "country": "IT",
    "name": "San Pietro a Maida",
    "lat": "38.84731",
    "lng": "16.34116"
  },
  {
    "country": "IT",
    "name": "San Piero Patti",
    "lat": "38.05214",
    "lng": "14.96816"
  },
  {
    "country": "IT",
    "name": "San Pier Niceto",
    "lat": "38.1605",
    "lng": "15.34982"
  },
  {
    "country": "IT",
    "name": "San Nicolo'Gerrei",
    "lat": "39.49833",
    "lng": "9.30611"
  },
  {
    "country": "IT",
    "name": "San Nicolò d'Arcidano",
    "lat": "39.68417",
    "lng": "8.64361"
  },
  {
    "country": "IT",
    "name": "San Nicolò",
    "lat": "38.63426",
    "lng": "15.85147"
  },
  {
    "country": "IT",
    "name": "San Nicola dell'Alto",
    "lat": "39.29094",
    "lng": "16.97179"
  },
  {
    "country": "IT",
    "name": "San Nicola da Crissa",
    "lat": "38.66354",
    "lng": "16.28592"
  },
  {
    "country": "IT",
    "name": "San Nicola Arcella",
    "lat": "39.84341",
    "lng": "15.78634"
  },
  {
    "country": "IT",
    "name": "San Michele di Ganzaria",
    "lat": "37.28042",
    "lng": "14.42633"
  },
  {
    "country": "IT",
    "name": "San Mauro Marchesato",
    "lat": "39.10559",
    "lng": "16.92561"
  },
  {
    "country": "IT",
    "name": "San Mauro Castelverde",
    "lat": "37.91478",
    "lng": "14.18961"
  },
  {
    "country": "IT",
    "name": "San Martino di Finita",
    "lat": "39.48988",
    "lng": "16.10968"
  },
  {
    "country": "IT",
    "name": "San Martino",
    "lat": "38.36157",
    "lng": "15.97634"
  },
  {
    "country": "IT",
    "name": "San Marco d'Alunzio",
    "lat": "38.07261",
    "lng": "14.70093"
  },
  {
    "country": "IT",
    "name": "San Marco Argentano",
    "lat": "39.55725",
    "lng": "16.12452"
  },
  {
    "country": "IT",
    "name": "San Mango d'Aquino",
    "lat": "39.06036",
    "lng": "16.19224"
  },
  {
    "country": "IT",
    "name": "Sanluri",
    "lat": "39.56176",
    "lng": "8.89969"
  },
  {
    "country": "IT",
    "name": "San Lucido",
    "lat": "39.31012",
    "lng": "16.05317"
  },
  {
    "country": "IT",
    "name": "San Luca",
    "lat": "38.14672",
    "lng": "16.06625"
  },
  {
    "country": "IT",
    "name": "San Lorenzo del Vallo",
    "lat": "39.66739",
    "lng": "16.29866"
  },
  {
    "country": "IT",
    "name": "San Lorenzo Bellizzi",
    "lat": "39.88867",
    "lng": "16.33029"
  },
  {
    "country": "IT",
    "name": "San Lorenzo",
    "lat": "38.01097",
    "lng": "15.8344"
  },
  {
    "country": "IT",
    "name": "San Leone Mosè",
    "lat": "37.26497",
    "lng": "13.58434"
  },
  {
    "country": "IT",
    "name": "San Gregorio d'Ippona",
    "lat": "38.64528",
    "lng": "16.10356"
  },
  {
    "country": "IT",
    "name": "San Gregorio di Catania",
    "lat": "37.56764",
    "lng": "15.1112"
  },
  {
    "country": "IT",
    "name": "San Giuseppe Jato",
    "lat": "37.97331",
    "lng": "13.18889"
  },
  {
    "country": "IT",
    "name": "San Giovanni Suergiu",
    "lat": "39.10955",
    "lng": "8.52039"
  },
  {
    "country": "IT",
    "name": "Samo",
    "lat": "38.07399",
    "lng": "16.05933"
  },
  {
    "country": "IT",
    "name": "San Giovanni la Punta",
    "lat": "37.5769",
    "lng": "15.09371"
  },
  {
    "country": "IT",
    "name": "San Giovanni in Fiore",
    "lat": "39.25446",
    "lng": "16.69699"
  },
  {
    "country": "IT",
    "name": "San Giovanni Gemini",
    "lat": "37.62785",
    "lng": "13.64357"
  },
  {
    "country": "IT",
    "name": "San Giovanni di Gerace",
    "lat": "38.36508",
    "lng": "16.2777"
  },
  {
    "country": "IT",
    "name": "San Giorgio Morgeto",
    "lat": "38.3919",
    "lng": "16.0879"
  },
  {
    "country": "IT",
    "name": "San Giorgio Albanese",
    "lat": "39.5823",
    "lng": "16.45349"
  },
  {
    "country": "IT",
    "name": "San Giorgio",
    "lat": "38.16834",
    "lng": "14.94825"
  },
  {
    "country": "IT",
    "name": "Sangineto",
    "lat": "39.60553",
    "lng": "15.91481"
  },
  {
    "country": "IT",
    "name": "San Gavino Monreale",
    "lat": "39.55008",
    "lng": "8.79065"
  },
  {
    "country": "IT",
    "name": "San Fratello",
    "lat": "38.01556",
    "lng": "14.59818"
  },
  {
    "country": "IT",
    "name": "San Floro",
    "lat": "38.83799",
    "lng": "16.5187"
  },
  {
    "country": "IT",
    "name": "San Filippo del Mela",
    "lat": "38.17007",
    "lng": "15.27338"
  },
  {
    "country": "IT",
    "name": "San Fili",
    "lat": "39.33971",
    "lng": "16.14448"
  },
  {
    "country": "IT",
    "name": "San Ferdinando",
    "lat": "38.48403",
    "lng": "15.91877"
  },
  {
    "country": "IT",
    "name": "San Donato di Ninea",
    "lat": "39.71156",
    "lng": "16.04742"
  },
  {
    "country": "IT",
    "name": "San Demetrio Corone",
    "lat": "39.5699",
    "lng": "16.36149"
  },
  {
    "country": "IT",
    "name": "San Costantino Calabro",
    "lat": "38.63283",
    "lng": "16.07571"
  },
  {
    "country": "IT",
    "name": "San Cosmo Albanese",
    "lat": "39.58363",
    "lng": "16.41469"
  },
  {
    "country": "IT",
    "name": "San Cono",
    "lat": "37.28992",
    "lng": "14.36709"
  },
  {
    "country": "IT",
    "name": "San Cipirello",
    "lat": "37.96067",
    "lng": "13.17732"
  },
  {
    "country": "IT",
    "name": "San Cataldo",
    "lat": "37.48412",
    "lng": "13.98542"
  },
  {
    "country": "IT",
    "name": "San Carlo-Condofuri Marina",
    "lat": "37.93324",
    "lng": "15.87166"
  },
  {
    "country": "IT",
    "name": "San Calogero",
    "lat": "38.57447",
    "lng": "16.01933"
  },
  {
    "country": "IT",
    "name": "San Biagio Platani",
    "lat": "37.50927",
    "lng": "13.52844"
  },
  {
    "country": "IT",
    "name": "San Benedetto Ullano",
    "lat": "39.4271",
    "lng": "16.12379"
  },
  {
    "country": "IT",
    "name": "San Basilio",
    "lat": "39.53785",
    "lng": "9.19753"
  },
  {
    "country": "IT",
    "name": "San Basile",
    "lat": "39.8096",
    "lng": "16.16328"
  },
  {
    "country": "IT",
    "name": "Samugheo",
    "lat": "39.94854",
    "lng": "8.94152"
  },
  {
    "country": "IT",
    "name": "Sambuca di Sicilia",
    "lat": "37.65294",
    "lng": "13.11462"
  },
  {
    "country": "IT",
    "name": "Sambiase",
    "lat": "38.96667",
    "lng": "16.28333"
  },
  {
    "country": "IT",
    "name": "Samatzai",
    "lat": "39.48297",
    "lng": "9.03466"
  },
  {
    "country": "IT",
    "name": "Samassi",
    "lat": "39.48208",
    "lng": "8.90538"
  },
  {
    "country": "IT",
    "name": "Salve",
    "lat": "39.86111",
    "lng": "18.29493"
  },
  {
    "country": "IT",
    "name": "Saline Ioniche",
    "lat": "37.93957",
    "lng": "15.71943"
  },
  {
    "country": "IT",
    "name": "Salemi",
    "lat": "37.82199",
    "lng": "12.80506"
  },
  {
    "country": "IT",
    "name": "Salaparuta",
    "lat": "37.75694",
    "lng": "13.00981"
  },
  {
    "country": "IT",
    "name": "Sadali",
    "lat": "39.81456",
    "lng": "9.27246"
  },
  {
    "country": "IT",
    "name": "Ruinas",
    "lat": "39.90631",
    "lng": "8.89705"
  },
  {
    "country": "IT",
    "name": "Ruffano",
    "lat": "39.98195",
    "lng": "18.24974"
  },
  {
    "country": "IT",
    "name": "Rovito",
    "lat": "39.30636",
    "lng": "16.31746"
  },
  {
    "country": "IT",
    "name": "Rotonda",
    "lat": "39.95215",
    "lng": "16.03904"
  },
  {
    "country": "IT",
    "name": "Rota Greca",
    "lat": "39.46703",
    "lng": "16.11412"
  },
  {
    "country": "IT",
    "name": "Rossano Stazione",
    "lat": "39.59855",
    "lng": "16.63485"
  },
  {
    "country": "IT",
    "name": "Rossano",
    "lat": "39.57622",
    "lng": "16.63447"
  },
  {
    "country": "IT",
    "name": "Rosolini",
    "lat": "36.82145",
    "lng": "14.95132"
  },
  {
    "country": "IT",
    "name": "Roseto Capo Spulico",
    "lat": "39.98643",
    "lng": "16.60363"
  },
  {
    "country": "IT",
    "name": "Rose",
    "lat": "39.39932",
    "lng": "16.29446"
  },
  {
    "country": "IT",
    "name": "Rosarno",
    "lat": "38.48717",
    "lng": "15.97956"
  },
  {
    "country": "IT",
    "name": "Rombiolo",
    "lat": "38.59535",
    "lng": "16.00237"
  },
  {
    "country": "IT",
    "name": "Rogliano",
    "lat": "39.17841",
    "lng": "16.31709"
  },
  {
    "country": "IT",
    "name": "Roggiano Gravina",
    "lat": "39.61786",
    "lng": "16.16173"
  },
  {
    "country": "IT",
    "name": "Rodì",
    "lat": "38.10823",
    "lng": "15.16933"
  },
  {
    "country": "IT",
    "name": "Roccella Valdemone",
    "lat": "37.93289",
    "lng": "15.00997"
  },
  {
    "country": "IT",
    "name": "Roccella Ionica",
    "lat": "38.32117",
    "lng": "16.39689"
  },
  {
    "country": "IT",
    "name": "Roccavaldina",
    "lat": "38.18296",
    "lng": "15.37402"
  },
  {
    "country": "IT",
    "name": "Roccapalumba",
    "lat": "37.80825",
    "lng": "13.63671"
  },
  {
    "country": "IT",
    "name": "Roccamena",
    "lat": "37.83824",
    "lng": "13.15513"
  },
  {
    "country": "IT",
    "name": "Roccalumera",
    "lat": "37.97554",
    "lng": "15.39439"
  },
  {
    "country": "IT",
    "name": "Roccaforte del Greco",
    "lat": "38.04751",
    "lng": "15.89198"
  },
  {
    "country": "IT",
    "name": "Rocca di Neto",
    "lat": "39.18292",
    "lng": "17.00764"
  },
  {
    "country": "IT",
    "name": "Roccabernarda",
    "lat": "39.13276",
    "lng": "16.86082"
  },
  {
    "country": "IT",
    "name": "Rizziconi",
    "lat": "38.40994",
    "lng": "15.95974"
  },
  {
    "country": "IT",
    "name": "Riposto",
    "lat": "37.73183",
    "lng": "15.20576"
  },
  {
    "country": "IT",
    "name": "Riola Sardo",
    "lat": "39.99361",
    "lng": "8.54127"
  },
  {
    "country": "IT",
    "name": "Riesi",
    "lat": "37.28079",
    "lng": "14.08317"
  },
  {
    "country": "IT",
    "name": "Ricadi",
    "lat": "38.62517",
    "lng": "15.86674"
  },
  {
    "country": "IT",
    "name": "Ribera",
    "lat": "37.49773",
    "lng": "13.26676"
  },
  {
    "country": "IT",
    "name": "Riace Marina",
    "lat": "38.39186",
    "lng": "16.53033"
  },
  {
    "country": "IT",
    "name": "Resuttano",
    "lat": "37.67865",
    "lng": "14.02946"
  },
  {
    "country": "IT",
    "name": "Rende",
    "lat": "39.33154",
    "lng": "16.18041"
  },
  {
    "country": "IT",
    "name": "Reitano",
    "lat": "37.97198",
    "lng": "14.34418"
  },
  {
    "country": "IT",
    "name": "Reggio Calabria",
    "lat": "38.11047",
    "lng": "15.66129"
  },
  {
    "country": "IT",
    "name": "Regalbuto",
    "lat": "37.65195",
    "lng": "14.63915"
  },
  {
    "country": "IT",
    "name": "Realmonte",
    "lat": "37.30847",
    "lng": "13.46429"
  },
  {
    "country": "IT",
    "name": "Ravanusa",
    "lat": "37.26659",
    "lng": "13.96834"
  },
  {
    "country": "IT",
    "name": "Randazzo",
    "lat": "37.87736",
    "lng": "14.95012"
  },
  {
    "country": "IT",
    "name": "Ramacca",
    "lat": "37.38616",
    "lng": "14.69241"
  },
  {
    "country": "IT",
    "name": "Ragusa",
    "lat": "36.92574",
    "lng": "14.72443"
  },
  {
    "country": "IT",
    "name": "Raffadali",
    "lat": "37.40214",
    "lng": "13.53175"
  },
  {
    "country": "IT",
    "name": "Raddusa",
    "lat": "37.47529",
    "lng": "14.53521"
  },
  {
    "country": "IT",
    "name": "Raccuja",
    "lat": "38.05583",
    "lng": "14.91044"
  },
  {
    "country": "IT",
    "name": "Racalmuto",
    "lat": "37.40498",
    "lng": "13.72995"
  },
  {
    "country": "IT",
    "name": "Racale",
    "lat": "39.96086",
    "lng": "18.09154"
  },
  {
    "country": "IT",
    "name": "Quattromiglia",
    "lat": "39.34474",
    "lng": "16.23802"
  },
  {
    "country": "IT",
    "name": "Quartu Sant'Elena",
    "lat": "39.22935",
    "lng": "9.25004"
  },
  {
    "country": "IT",
    "name": "Quartucciu",
    "lat": "39.25262",
    "lng": "9.17764"
  },
  {
    "country": "IT",
    "name": "Pula",
    "lat": "39.00727",
    "lng": "9.00223"
  },
  {
    "country": "IT",
    "name": "Prizzi",
    "lat": "37.72088",
    "lng": "13.43435"
  },
  {
    "country": "IT",
    "name": "Priolo Gargallo",
    "lat": "37.15512",
    "lng": "15.18248"
  },
  {
    "country": "IT",
    "name": "Presicce",
    "lat": "39.90055",
    "lng": "18.26282"
  },
  {
    "country": "IT",
    "name": "Praia a Mare",
    "lat": "39.8941",
    "lng": "15.78421"
  },
  {
    "country": "IT",
    "name": "Pozzallo",
    "lat": "36.73028",
    "lng": "14.84672"
  },
  {
    "country": "IT",
    "name": "Portoscuso",
    "lat": "39.20739",
    "lng": "8.38086"
  },
  {
    "country": "IT",
    "name": "Portopalo di Capo Passero",
    "lat": "36.68219",
    "lng": "15.13378"
  },
  {
    "country": "IT",
    "name": "Porto Empedocle",
    "lat": "37.28942",
    "lng": "13.52494"
  },
  {
    "country": "IT",
    "name": "Portigliola",
    "lat": "38.22712",
    "lng": "16.20287"
  },
  {
    "country": "IT",
    "name": "Portella di Mare",
    "lat": "38.07304",
    "lng": "13.46199"
  },
  {
    "country": "IT",
    "name": "Pompu",
    "lat": "39.72518",
    "lng": "8.7964"
  },
  {
    "country": "IT",
    "name": "Pollina",
    "lat": "37.99309",
    "lng": "14.14586"
  },
  {
    "country": "IT",
    "name": "Polizzi Generosa",
    "lat": "37.81159",
    "lng": "14.00268"
  },
  {
    "country": "IT",
    "name": "Polistena",
    "lat": "38.40544",
    "lng": "16.0733"
  },
  {
    "country": "IT",
    "name": "Polia",
    "lat": "38.75118",
    "lng": "16.3122"
  },
  {
    "country": "IT",
    "name": "Nuovo Centro Urbano Poggioreale",
    "lat": "37.76404",
    "lng": "13.03594"
  },
  {
    "country": "IT",
    "name": "Platì",
    "lat": "38.22149",
    "lng": "16.0453"
  },
  {
    "country": "IT",
    "name": "Platania",
    "lat": "39.0062",
    "lng": "16.32194"
  },
  {
    "country": "IT",
    "name": "Plataci",
    "lat": "39.90042",
    "lng": "16.43272"
  },
  {
    "country": "IT",
    "name": "Placanica",
    "lat": "38.41078",
    "lng": "16.45274"
  },
  {
    "country": "IT",
    "name": "Pizzoni",
    "lat": "38.62286",
    "lng": "16.24876"
  },
  {
    "country": "IT",
    "name": "Pizzo",
    "lat": "38.75259",
    "lng": "16.18696"
  },
  {
    "country": "IT",
    "name": "Piscopio",
    "lat": "38.66361",
    "lng": "16.11101"
  },
  {
    "country": "IT",
    "name": "Piscinas",
    "lat": "39.07435",
    "lng": "8.66634"
  },
  {
    "country": "IT",
    "name": "Piraino",
    "lat": "38.16127",
    "lng": "14.861"
  },
  {
    "country": "IT",
    "name": "Pioppo",
    "lat": "38.05",
    "lng": "13.23333"
  },
  {
    "country": "IT",
    "name": "Pimentel",
    "lat": "39.48718",
    "lng": "9.06516"
  },
  {
    "country": "IT",
    "name": "Pietraperzia",
    "lat": "37.41852",
    "lng": "14.13739"
  },
  {
    "country": "IT",
    "name": "Pietrapaola",
    "lat": "39.48701",
    "lng": "16.81597"
  },
  {
    "country": "IT",
    "name": "Pietrafitta",
    "lat": "39.26103",
    "lng": "16.3394"
  },
  {
    "country": "IT",
    "name": "Piedimonte Etneo",
    "lat": "37.80677",
    "lng": "15.17516"
  },
  {
    "country": "IT",
    "name": "Piazza Armerina",
    "lat": "37.38417",
    "lng": "14.36921"
  },
  {
    "country": "IT",
    "name": "Pianopoli",
    "lat": "38.95246",
    "lng": "16.38863"
  },
  {
    "country": "IT",
    "name": "Piane Crati",
    "lat": "39.23472",
    "lng": "16.32313"
  },
  {
    "country": "IT",
    "name": "Piana degli Albanesi",
    "lat": "37.99372",
    "lng": "13.28464"
  },
  {
    "country": "IT",
    "name": "Pettineo",
    "lat": "37.96793",
    "lng": "14.29118"
  },
  {
    "country": "IT",
    "name": "Petrosino",
    "lat": "37.71271",
    "lng": "12.49964"
  },
  {
    "country": "IT",
    "name": "Petronà",
    "lat": "39.0437",
    "lng": "16.75796"
  },
  {
    "country": "IT",
    "name": "Petrizzi",
    "lat": "38.70179",
    "lng": "16.47187"
  },
  {
    "country": "IT",
    "name": "Petralia Sottana",
    "lat": "37.80919",
    "lng": "14.09293"
  },
  {
    "country": "IT",
    "name": "Petralia Soprana",
    "lat": "37.80064",
    "lng": "14.10813"
  },
  {
    "country": "IT",
    "name": "Petilia Policastro",
    "lat": "39.11293",
    "lng": "16.78167"
  },
  {
    "country": "IT",
    "name": "Pernocari-Presinaci",
    "lat": "38.61184",
    "lng": "16.00463"
  },
  {
    "country": "IT",
    "name": "Perdaxius",
    "lat": "39.16028",
    "lng": "8.61083"
  },
  {
    "country": "IT",
    "name": "Perdasdefogu",
    "lat": "39.67959",
    "lng": "9.44082"
  },
  {
    "country": "IT",
    "name": "Pentone",
    "lat": "38.98579",
    "lng": "16.5825"
  },
  {
    "country": "IT",
    "name": "Pedivigliano",
    "lat": "39.11034",
    "lng": "16.30486"
  },
  {
    "country": "IT",
    "name": "Pedara",
    "lat": "37.62386",
    "lng": "15.05672"
  },
  {
    "country": "IT",
    "name": "Pedagaggi",
    "lat": "37.19182",
    "lng": "14.93654"
  },
  {
    "country": "IT",
    "name": "Pedace-Perito",
    "lat": "39.27639",
    "lng": "16.33639"
  },
  {
    "country": "IT",
    "name": "Pazzano",
    "lat": "38.47612",
    "lng": "16.45107"
  },
  {
    "country": "IT",
    "name": "Pavigliana",
    "lat": "38.10721",
    "lng": "15.72108"
  },
  {
    "country": "IT",
    "name": "Pauli Arbarei",
    "lat": "39.66183",
    "lng": "8.92212"
  },
  {
    "country": "IT",
    "name": "Pau",
    "lat": "39.79167",
    "lng": "8.80222"
  },
  {
    "country": "IT",
    "name": "Patù",
    "lat": "39.84078",
    "lng": "18.33784"
  },
  {
    "country": "IT",
    "name": "Patti",
    "lat": "38.14736",
    "lng": "14.96409"
  },
  {
    "country": "IT",
    "name": "Paterno Calabro",
    "lat": "39.22849",
    "lng": "16.26489"
  },
  {
    "country": "IT",
    "name": "Paternò",
    "lat": "37.56675",
    "lng": "14.90254"
  },
  {
    "country": "IT",
    "name": "Partinico",
    "lat": "38.04657",
    "lng": "13.11785"
  },
  {
    "country": "IT",
    "name": "Partanna",
    "lat": "37.7268",
    "lng": "12.88917"
  },
  {
    "country": "IT",
    "name": "Parghelia",
    "lat": "38.68189",
    "lng": "15.92075"
  },
  {
    "country": "IT",
    "name": "Parenti",
    "lat": "39.16071",
    "lng": "16.4114"
  },
  {
    "country": "IT",
    "name": "Paravati",
    "lat": "38.5902",
    "lng": "16.05815"
  },
  {
    "country": "IT",
    "name": "Papasidero",
    "lat": "39.87159",
    "lng": "15.90581"
  },
  {
    "country": "IT",
    "name": "Papanice",
    "lat": "39.07077",
    "lng": "17.02721"
  },
  {
    "country": "IT",
    "name": "Paola",
    "lat": "39.36313",
    "lng": "16.03691"
  },
  {
    "country": "IT",
    "name": "Pantelleria",
    "lat": "36.82836",
    "lng": "11.94611"
  },
  {
    "country": "IT",
    "name": "Pannaconi",
    "lat": "38.69291",
    "lng": "16.04411"
  },
  {
    "country": "IT",
    "name": "Panettieri",
    "lat": "39.06007",
    "lng": "16.45375"
  },
  {
    "country": "IT",
    "name": "Paludi",
    "lat": "39.52943",
    "lng": "16.67963"
  },
  {
    "country": "IT",
    "name": "Palmi",
    "lat": "38.35943",
    "lng": "15.85155"
  },
  {
    "country": "IT",
    "name": "Palmas Arborea",
    "lat": "39.8767",
    "lng": "8.64391"
  },
  {
    "country": "IT",
    "name": "Palma di Montechiaro",
    "lat": "37.19066",
    "lng": "13.76603"
  },
  {
    "country": "IT",
    "name": "Pallagorio",
    "lat": "39.30764",
    "lng": "16.90816"
  },
  {
    "country": "IT",
    "name": "Palizzi Marina",
    "lat": "37.91995",
    "lng": "15.97927"
  },
  {
    "country": "IT",
    "name": "Palizzi",
    "lat": "37.96667",
    "lng": "15.9867"
  },
  {
    "country": "IT",
    "name": "Palermo",
    "lat": "38.13205",
    "lng": "13.33561"
  },
  {
    "country": "IT",
    "name": "Palermiti",
    "lat": "38.74868",
    "lng": "16.4522"
  },
  {
    "country": "IT",
    "name": "Palazzolo Acreide",
    "lat": "37.06261",
    "lng": "14.90593"
  },
  {
    "country": "IT",
    "name": "Palazzo Adriano",
    "lat": "37.68066",
    "lng": "13.37941"
  },
  {
    "country": "IT",
    "name": "Palagonia",
    "lat": "37.32955",
    "lng": "14.74474"
  },
  {
    "country": "IT",
    "name": "Pagliarelle",
    "lat": "39.14017",
    "lng": "16.75101"
  },
  {
    "country": "IT",
    "name": "Pagliara",
    "lat": "37.98546",
    "lng": "15.35969"
  },
  {
    "country": "IT",
    "name": "Pachino",
    "lat": "36.71522",
    "lng": "15.09019"
  },
  {
    "country": "IT",
    "name": "Paceco",
    "lat": "37.98026",
    "lng": "12.55766"
  },
  {
    "country": "IT",
    "name": "Pabillonis",
    "lat": "39.59228",
    "lng": "8.72143"
  },
  {
    "country": "IT",
    "name": "Osini",
    "lat": "39.82257",
    "lng": "9.4964"
  },
  {
    "country": "IT",
    "name": "Ortacesus",
    "lat": "39.53904",
    "lng": "9.08695"
  },
  {
    "country": "IT",
    "name": "Orsomarso",
    "lat": "39.7991",
    "lng": "15.90748"
  },
  {
    "country": "IT",
    "name": "Orroli",
    "lat": "39.69237",
    "lng": "9.24995"
  },
  {
    "country": "IT",
    "name": "Oristano",
    "lat": "39.9036",
    "lng": "8.59257"
  },
  {
    "country": "IT",
    "name": "Albagiara",
    "lat": "39.78724",
    "lng": "8.86184"
  },
  {
    "country": "IT",
    "name": "Oliveri",
    "lat": "38.12515",
    "lng": "15.06068"
  },
  {
    "country": "IT",
    "name": "Olivadi",
    "lat": "38.72558",
    "lng": "16.4237"
  },
  {
    "country": "IT",
    "name": "Nuxis",
    "lat": "39.15456",
    "lng": "8.73953"
  },
  {
    "country": "IT",
    "name": "Nurri",
    "lat": "39.71122",
    "lng": "9.2299"
  },
  {
    "country": "IT",
    "name": "Nureci",
    "lat": "39.82329",
    "lng": "8.97484"
  },
  {
    "country": "IT",
    "name": "Nuraxinieddu",
    "lat": "39.93843",
    "lng": "8.5991"
  },
  {
    "country": "IT",
    "name": "Nuraminis",
    "lat": "39.44258",
    "lng": "9.01395"
  },
  {
    "country": "IT",
    "name": "Nurallao",
    "lat": "39.78908",
    "lng": "9.07802"
  },
  {
    "country": "IT",
    "name": "Nuragus",
    "lat": "39.77771",
    "lng": "9.03724"
  },
  {
    "country": "IT",
    "name": "Nurachi",
    "lat": "39.97451",
    "lng": "8.53965"
  },
  {
    "country": "IT",
    "name": "Nunziata",
    "lat": "37.75858",
    "lng": "15.17058"
  },
  {
    "country": "IT",
    "name": "Novara di Sicilia",
    "lat": "38.01538",
    "lng": "15.13134"
  },
  {
    "country": "IT",
    "name": "Noto",
    "lat": "36.89244",
    "lng": "15.06977"
  },
  {
    "country": "IT",
    "name": "Nocera Terinese",
    "lat": "39.03474",
    "lng": "16.16737"
  },
  {
    "country": "IT",
    "name": "Nizza di Sicilia",
    "lat": "37.99081",
    "lng": "15.40956"
  },
  {
    "country": "IT",
    "name": "Nissoria",
    "lat": "37.6541",
    "lng": "14.4481"
  },
  {
    "country": "IT",
    "name": "Niscemi",
    "lat": "37.14649",
    "lng": "14.39381"
  },
  {
    "country": "IT",
    "name": "Nicotera",
    "lat": "38.54915",
    "lng": "15.93584"
  },
  {
    "country": "IT",
    "name": "Nicosia",
    "lat": "37.74747",
    "lng": "14.39218"
  },
  {
    "country": "IT",
    "name": "Nicolosi",
    "lat": "37.62148",
    "lng": "15.02785"
  },
  {
    "country": "IT",
    "name": "Nicastro",
    "lat": "38.97089",
    "lng": "16.31285"
  },
  {
    "country": "IT",
    "name": "Naso",
    "lat": "38.12215",
    "lng": "14.78702"
  },
  {
    "country": "IT",
    "name": "Naro",
    "lat": "37.29248",
    "lng": "13.79337"
  },
  {
    "country": "IT",
    "name": "Nardodipace",
    "lat": "38.47418",
    "lng": "16.34295"
  },
  {
    "country": "IT",
    "name": "Narcao",
    "lat": "39.1675",
    "lng": "8.675"
  },
  {
    "country": "IT",
    "name": "Mussomeli",
    "lat": "37.58067",
    "lng": "13.75214"
  },
  {
    "country": "IT",
    "name": "Musei",
    "lat": "39.30232",
    "lng": "8.66613"
  },
  {
    "country": "IT",
    "name": "Muravera",
    "lat": "39.41972",
    "lng": "9.57471"
  },
  {
    "country": "IT",
    "name": "Motta Sant'Anastasia",
    "lat": "37.51205",
    "lng": "14.96628"
  },
  {
    "country": "IT",
    "name": "Motta Santa Lucia",
    "lat": "39.09122",
    "lng": "16.29313"
  },
  {
    "country": "IT",
    "name": "Motta San Giovanni",
    "lat": "38.01027",
    "lng": "15.71262"
  },
  {
    "country": "IT",
    "name": "Mottafollone",
    "lat": "39.6485",
    "lng": "16.06451"
  },
  {
    "country": "IT",
    "name": "Mosorrofa",
    "lat": "38.095",
    "lng": "15.71259"
  },
  {
    "country": "IT",
    "name": "Mormanno",
    "lat": "39.8934",
    "lng": "15.99175"
  },
  {
    "country": "IT",
    "name": "Morgongiori",
    "lat": "39.7463",
    "lng": "8.77041"
  },
  {
    "country": "IT",
    "name": "Morciano di Leuca",
    "lat": "39.84719",
    "lng": "18.31089"
  },
  {
    "country": "IT",
    "name": "Morano Calabro",
    "lat": "39.84138",
    "lng": "16.13837"
  },
  {
    "country": "IT",
    "name": "Montevago",
    "lat": "37.70224",
    "lng": "12.98584"
  },
  {
    "country": "IT",
    "name": "Montesardo",
    "lat": "39.87572",
    "lng": "18.33967"
  },
  {
    "country": "IT",
    "name": "Montesano Salentino",
    "lat": "39.97544",
    "lng": "18.32277"
  },
  {
    "country": "IT",
    "name": "Monterosso Almo",
    "lat": "37.08884",
    "lng": "14.76498"
  },
  {
    "country": "IT",
    "name": "Monterosso Calabro",
    "lat": "38.71746",
    "lng": "16.29066"
  },
  {
    "country": "IT",
    "name": "Montepaone",
    "lat": "38.72222",
    "lng": "16.49795"
  },
  {
    "country": "IT",
    "name": "Montemaggiore Belsito",
    "lat": "37.84818",
    "lng": "13.76206"
  },
  {
    "country": "IT",
    "name": "Montelepre",
    "lat": "38.09026",
    "lng": "13.17518"
  },
  {
    "country": "IT",
    "name": "Montedoro",
    "lat": "37.45431",
    "lng": "13.81684"
  },
  {
    "country": "IT",
    "name": "Montebello Jonico",
    "lat": "37.98277",
    "lng": "15.758"
  },
  {
    "country": "IT",
    "name": "Montauro",
    "lat": "38.74927",
    "lng": "16.51226"
  },
  {
    "country": "IT",
    "name": "Montalto Uffugo",
    "lat": "39.40331",
    "lng": "16.15534"
  },
  {
    "country": "IT",
    "name": "Montallegro",
    "lat": "37.39121",
    "lng": "13.35179"
  },
  {
    "country": "IT",
    "name": "Montalbano Elicona",
    "lat": "38.0236",
    "lng": "15.01393"
  },
  {
    "country": "IT",
    "name": "Montagnareale",
    "lat": "38.13216",
    "lng": "14.94658"
  },
  {
    "country": "IT",
    "name": "Monserrato",
    "lat": "39.25642",
    "lng": "9.1444"
  },
  {
    "country": "IT",
    "name": "Monreale",
    "lat": "38.08125",
    "lng": "13.28947"
  },
  {
    "country": "IT",
    "name": "Mongrassano",
    "lat": "39.52644",
    "lng": "16.11225"
  },
  {
    "country": "IT",
    "name": "Mongiuffi Melia",
    "lat": "37.90336",
    "lng": "15.27539"
  },
  {
    "country": "IT",
    "name": "Mongiana",
    "lat": "38.51477",
    "lng": "16.3194"
  },
  {
    "country": "IT",
    "name": "Monforte San Giorgio",
    "lat": "38.15733",
    "lng": "15.38132"
  },
  {
    "country": "IT",
    "name": "Monastir",
    "lat": "39.3836",
    "lng": "9.04445"
  },
  {
    "country": "IT",
    "name": "Monasterace",
    "lat": "38.45318",
    "lng": "16.55163"
  },
  {
    "country": "IT",
    "name": "Molochio",
    "lat": "38.30789",
    "lng": "16.03141"
  },
  {
    "country": "IT",
    "name": "Moio Alcantara",
    "lat": "37.90056",
    "lng": "15.05072"
  },
  {
    "country": "IT",
    "name": "Mogoro",
    "lat": "39.68415",
    "lng": "8.77661"
  },
  {
    "country": "IT",
    "name": "Mogorella",
    "lat": "39.86447",
    "lng": "8.85913"
  },
  {
    "country": "IT",
    "name": "Modica",
    "lat": "36.85868",
    "lng": "14.75966"
  },
  {
    "country": "IT",
    "name": "Mistretta",
    "lat": "37.92823",
    "lng": "14.3578"
  },
  {
    "country": "IT",
    "name": "Misterbianco",
    "lat": "37.51803",
    "lng": "15.00913"
  },
  {
    "country": "IT",
    "name": "Misilmeri",
    "lat": "38.03183",
    "lng": "13.44795"
  },
  {
    "country": "IT",
    "name": "Mirto",
    "lat": "39.60069",
    "lng": "16.7739"
  },
  {
    "country": "IT",
    "name": "Mirto",
    "lat": "38.08439",
    "lng": "14.74609"
  },
  {
    "country": "IT",
    "name": "Mirabella Imbaccari",
    "lat": "37.32702",
    "lng": "14.44605"
  },
  {
    "country": "IT",
    "name": "Mineo",
    "lat": "37.26494",
    "lng": "14.69381"
  },
  {
    "country": "IT",
    "name": "Milo",
    "lat": "37.7245",
    "lng": "15.11554"
  },
  {
    "country": "IT",
    "name": "Militello Rosmarino",
    "lat": "38.04575",
    "lng": "14.67584"
  },
  {
    "country": "IT",
    "name": "Militello in Val di Catania",
    "lat": "37.27594",
    "lng": "14.79342"
  },
  {
    "country": "IT",
    "name": "Mileto",
    "lat": "38.6078",
    "lng": "16.06751"
  },
  {
    "country": "IT",
    "name": "Milena",
    "lat": "37.47133",
    "lng": "13.73613"
  },
  {
    "country": "IT",
    "name": "Milazzo",
    "lat": "38.22008",
    "lng": "15.24023"
  },
  {
    "country": "IT",
    "name": "Miglierina",
    "lat": "38.9506",
    "lng": "16.47233"
  },
  {
    "country": "IT",
    "name": "Miggiano",
    "lat": "39.9618",
    "lng": "18.31119"
  },
  {
    "country": "IT",
    "name": "Mezzojuso",
    "lat": "37.86509",
    "lng": "13.46509"
  },
  {
    "country": "IT",
    "name": "Messina",
    "lat": "38.19394",
    "lng": "15.55256"
  },
  {
    "country": "IT",
    "name": "Messignadi",
    "lat": "38.29964",
    "lng": "15.99642"
  },
  {
    "country": "IT",
    "name": "Mesoraca",
    "lat": "39.07948",
    "lng": "16.78808"
  },
  {
    "country": "IT",
    "name": "Merì",
    "lat": "38.1663",
    "lng": "15.2497"
  },
  {
    "country": "IT",
    "name": "Menfi",
    "lat": "37.60409",
    "lng": "12.96889"
  },
  {
    "country": "IT",
    "name": "Mendicino",
    "lat": "39.26282",
    "lng": "16.19452"
  },
  {
    "country": "IT",
    "name": "Melito di Porto Salvo",
    "lat": "37.92629",
    "lng": "15.7499"
  },
  {
    "country": "IT",
    "name": "Melissano",
    "lat": "39.97315",
    "lng": "18.12113"
  },
  {
    "country": "IT",
    "name": "Melissa",
    "lat": "39.30953",
    "lng": "17.02968"
  },
  {
    "country": "IT",
    "name": "Melilli",
    "lat": "37.17821",
    "lng": "15.1302"
  },
  {
    "country": "IT",
    "name": "Melicucco",
    "lat": "38.43298",
    "lng": "16.05748"
  },
  {
    "country": "IT",
    "name": "Melicuccà",
    "lat": "38.30311",
    "lng": "15.88153"
  },
  {
    "country": "IT",
    "name": "Meana Sardo",
    "lat": "39.94467",
    "lng": "9.07355"
  },
  {
    "country": "IT",
    "name": "Mazzarrà Sant'Andrea",
    "lat": "38.08969",
    "lng": "15.13535"
  },
  {
    "country": "IT",
    "name": "Mazzarino",
    "lat": "37.30188",
    "lng": "14.20959"
  },
  {
    "country": "IT",
    "name": "Mazara del Vallo",
    "lat": "37.65535",
    "lng": "12.58986"
  },
  {
    "country": "IT",
    "name": "Maracalagonis",
    "lat": "39.28574",
    "lng": "9.22874"
  },
  {
    "country": "IT",
    "name": "Masullas",
    "lat": "39.70044",
    "lng": "8.78371"
  },
  {
    "country": "IT",
    "name": "Mascalucia",
    "lat": "37.57465",
    "lng": "15.04964"
  },
  {
    "country": "IT",
    "name": "Mascali",
    "lat": "37.75794",
    "lng": "15.19662"
  },
  {
    "country": "IT",
    "name": "Masainas",
    "lat": "39.04993",
    "lng": "8.62924"
  },
  {
    "country": "IT",
    "name": "Marzi",
    "lat": "39.17063",
    "lng": "16.30705"
  },
  {
    "country": "IT",
    "name": "Martone",
    "lat": "38.35353",
    "lng": "16.288"
  },
  {
    "country": "IT",
    "name": "Martirano Lombardo",
    "lat": "39.07469",
    "lng": "16.232"
  },
  {
    "country": "IT",
    "name": "Martirano",
    "lat": "39.08119",
    "lng": "16.24829"
  },
  {
    "country": "IT",
    "name": "Marsala",
    "lat": "37.7992",
    "lng": "12.4367"
  },
  {
    "country": "IT",
    "name": "Marrubiu",
    "lat": "39.75124",
    "lng": "8.63766"
  },
  {
    "country": "IT",
    "name": "Marittima",
    "lat": "39.99609",
    "lng": "18.39895"
  },
  {
    "country": "IT",
    "name": "Marineo",
    "lat": "37.95185",
    "lng": "13.41781"
  },
  {
    "country": "IT",
    "name": "Marinella",
    "lat": "37.59475",
    "lng": "12.84434"
  },
  {
    "country": "IT",
    "name": "Marina di Schiavonea",
    "lat": "39.65",
    "lng": "16.53333"
  },
  {
    "country": "IT",
    "name": "Marina di Ragusa",
    "lat": "36.78575",
    "lng": "14.55474"
  },
  {
    "country": "IT",
    "name": "Monasterace Marina",
    "lat": "38.43489",
    "lng": "16.57025"
  },
  {
    "country": "IT",
    "name": "Marina di Gioiosa Ionica",
    "lat": "38.30159",
    "lng": "16.33148"
  },
  {
    "country": "IT",
    "name": "Marina di Fuscaldo",
    "lat": "39.42418",
    "lng": "16.00694"
  },
  {
    "country": "IT",
    "name": "Marina di Camerota",
    "lat": "40.00356",
    "lng": "15.36717"
  },
  {
    "country": "IT",
    "name": "Marianopoli",
    "lat": "37.5984",
    "lng": "13.9152"
  },
  {
    "country": "IT",
    "name": "Marcellinara",
    "lat": "38.92574",
    "lng": "16.48757"
  },
  {
    "country": "IT",
    "name": "Marcedusa",
    "lat": "39.02675",
    "lng": "16.83612"
  },
  {
    "country": "IT",
    "name": "Marausa",
    "lat": "37.94166",
    "lng": "12.50948"
  },
  {
    "country": "IT",
    "name": "Maratea",
    "lat": "39.99932",
    "lng": "15.71539"
  },
  {
    "country": "IT",
    "name": "Marano Principato",
    "lat": "39.29782",
    "lng": "16.1743"
  },
  {
    "country": "IT",
    "name": "Marano Marchesato",
    "lat": "39.31274",
    "lng": "16.17354"
  },
  {
    "country": "IT",
    "name": "Mangone",
    "lat": "39.20437",
    "lng": "16.33262"
  },
  {
    "country": "IT",
    "name": "Mandatoriccio",
    "lat": "39.46675",
    "lng": "16.8342"
  },
  {
    "country": "IT",
    "name": "Mandas",
    "lat": "39.65514",
    "lng": "9.12955"
  },
  {
    "country": "IT",
    "name": "Mandanici",
    "lat": "38.00356",
    "lng": "15.31669"
  },
  {
    "country": "IT",
    "name": "Mammola",
    "lat": "38.36262",
    "lng": "16.23871"
  },
  {
    "country": "IT",
    "name": "Malvito",
    "lat": "39.60105",
    "lng": "16.05341"
  },
  {
    "country": "IT",
    "name": "Malvagna",
    "lat": "37.91752",
    "lng": "15.05548"
  },
  {
    "country": "IT",
    "name": "Malito",
    "lat": "39.15775",
    "lng": "16.24677"
  },
  {
    "country": "IT",
    "name": "Malfa",
    "lat": "38.5773",
    "lng": "14.83598"
  },
  {
    "country": "IT",
    "name": "Maletto",
    "lat": "37.82914",
    "lng": "14.86403"
  },
  {
    "country": "IT",
    "name": "Maierato",
    "lat": "38.71111",
    "lng": "16.17532"
  },
  {
    "country": "IT",
    "name": "Maierà",
    "lat": "39.71655",
    "lng": "15.85012"
  },
  {
    "country": "IT",
    "name": "Maida",
    "lat": "38.85884",
    "lng": "16.36277"
  },
  {
    "country": "IT",
    "name": "Magisano",
    "lat": "39.01339",
    "lng": "16.6279"
  },
  {
    "country": "IT",
    "name": "Luzzi",
    "lat": "39.44799",
    "lng": "16.2873"
  },
  {
    "country": "IT",
    "name": "Lungro",
    "lat": "39.73772",
    "lng": "16.12586"
  },
  {
    "country": "IT",
    "name": "Lunamatrona",
    "lat": "39.64943",
    "lng": "8.89966"
  },
  {
    "country": "IT",
    "name": "Lucugnano",
    "lat": "39.9349",
    "lng": "18.32174"
  },
  {
    "country": "IT",
    "name": "Lucca Sicula",
    "lat": "37.57783",
    "lng": "13.30579"
  },
  {
    "country": "IT",
    "name": "Lotzorai",
    "lat": "39.9694",
    "lng": "9.6635"
  },
  {
    "country": "IT",
    "name": "Longobucco",
    "lat": "39.4483",
    "lng": "16.6105"
  },
  {
    "country": "IT",
    "name": "Longobardi",
    "lat": "39.21059",
    "lng": "16.07464"
  },
  {
    "country": "IT",
    "name": "Longi",
    "lat": "38.02617",
    "lng": "14.75306"
  },
  {
    "country": "IT",
    "name": "Locri",
    "lat": "38.23868",
    "lng": "16.25957"
  },
  {
    "country": "IT",
    "name": "Loceri",
    "lat": "39.85816",
    "lng": "9.58368"
  },
  {
    "country": "IT",
    "name": "Lipari",
    "lat": "38.46743",
    "lng": "14.95398"
  },
  {
    "country": "IT",
    "name": "Linguaglossa",
    "lat": "37.84243",
    "lng": "15.13774"
  },
  {
    "country": "IT",
    "name": "Linera",
    "lat": "37.6638",
    "lng": "15.13653"
  },
  {
    "country": "IT",
    "name": "Limbadi-Caroni",
    "lat": "38.55902",
    "lng": "15.96441"
  },
  {
    "country": "IT",
    "name": "Licodia Eubea",
    "lat": "37.15674",
    "lng": "14.70555"
  },
  {
    "country": "IT",
    "name": "Licata",
    "lat": "37.10267",
    "lng": "13.93972"
  },
  {
    "country": "IT",
    "name": "Librizzi",
    "lat": "38.09719",
    "lng": "14.95909"
  },
  {
    "country": "IT",
    "name": "Leuca",
    "lat": "39.79949",
    "lng": "18.35815"
  },
  {
    "country": "IT",
    "name": "Letojanni",
    "lat": "37.8805",
    "lng": "15.30735"
  },
  {
    "country": "IT",
    "name": "Lercara Friddi",
    "lat": "37.74657",
    "lng": "13.60391"
  },
  {
    "country": "IT",
    "name": "Leonforte",
    "lat": "37.64197",
    "lng": "14.39766"
  },
  {
    "country": "IT",
    "name": "Lentini",
    "lat": "37.28556",
    "lng": "14.99737"
  },
  {
    "country": "IT",
    "name": "Leni",
    "lat": "38.55534",
    "lng": "14.82497"
  },
  {
    "country": "IT",
    "name": "Le Castella",
    "lat": "38.9101",
    "lng": "17.02216"
  },
  {
    "country": "IT",
    "name": "Lazzaro",
    "lat": "37.97276",
    "lng": "15.66511"
  },
  {
    "country": "IT",
    "name": "Laurignano",
    "lat": "39.27915",
    "lng": "16.24232"
  },
  {
    "country": "IT",
    "name": "Laureana di Borrello",
    "lat": "38.49215",
    "lng": "16.08429"
  },
  {
    "country": "IT",
    "name": "Lattarico",
    "lat": "39.45105",
    "lng": "16.127"
  },
  {
    "country": "IT",
    "name": "Las Plassas",
    "lat": "39.67979",
    "lng": "8.98442"
  },
  {
    "country": "IT",
    "name": "Lascari",
    "lat": "38.00067",
    "lng": "13.94053"
  },
  {
    "country": "IT",
    "name": "Rocca di Capri Leone",
    "lat": "38.10677",
    "lng": "14.71032"
  },
  {
    "country": "IT",
    "name": "Larderia",
    "lat": "38.14101",
    "lng": "15.50287"
  },
  {
    "country": "IT",
    "name": "Lappano",
    "lat": "39.31964",
    "lng": "16.31143"
  },
  {
    "country": "IT",
    "name": "Lanusei",
    "lat": "39.87927",
    "lng": "9.54022"
  },
  {
    "country": "IT",
    "name": "Lampedusa",
    "lat": "35.50142",
    "lng": "12.60964"
  },
  {
    "country": "IT",
    "name": "La Maddalena",
    "lat": "39.14429",
    "lng": "9.01223"
  },
  {
    "country": "IT",
    "name": "Laino Castello-Nuovo Centro",
    "lat": "39.9363",
    "lng": "15.97658"
  },
  {
    "country": "IT",
    "name": "Laino Borgo",
    "lat": "39.9543",
    "lng": "15.97348"
  },
  {
    "country": "IT",
    "name": "Lago",
    "lat": "39.17068",
    "lng": "16.14825"
  },
  {
    "country": "IT",
    "name": "Laganadi",
    "lat": "38.17391",
    "lng": "15.74133"
  },
  {
    "country": "IT",
    "name": "Laconi",
    "lat": "39.85325",
    "lng": "9.05196"
  },
  {
    "country": "IT",
    "name": "Kamma",
    "lat": "36.79701",
    "lng": "12.03617"
  },
  {
    "country": "IT",
    "name": "Itala",
    "lat": "38.05144",
    "lng": "15.43706"
  },
  {
    "country": "IT",
    "name": "Ispica",
    "lat": "36.78622",
    "lng": "14.9053"
  },
  {
    "country": "IT",
    "name": "Isola delle Femmine",
    "lat": "38.19123",
    "lng": "13.24691"
  },
  {
    "country": "IT",
    "name": "Isola di Capo Rizzuto",
    "lat": "38.95844",
    "lng": "17.09242"
  },
  {
    "country": "IT",
    "name": "Isnello",
    "lat": "37.94324",
    "lng": "14.00724"
  },
  {
    "country": "IT",
    "name": "Isili",
    "lat": "39.73952",
    "lng": "9.11114"
  },
  {
    "country": "IT",
    "name": "Isca sullo Ionio",
    "lat": "38.60103",
    "lng": "16.5201"
  },
  {
    "country": "IT",
    "name": "Joppolo Giancaxio",
    "lat": "37.38681",
    "lng": "13.55586"
  },
  {
    "country": "IT",
    "name": "Ilbono",
    "lat": "39.89258",
    "lng": "9.54582"
  },
  {
    "country": "IT",
    "name": "Iglesias",
    "lat": "39.3092",
    "lng": "8.5372"
  },
  {
    "country": "IT",
    "name": "Jerzu",
    "lat": "39.79289",
    "lng": "9.51785"
  },
  {
    "country": "IT",
    "name": "Guspini",
    "lat": "39.53954",
    "lng": "8.63502"
  },
  {
    "country": "IT",
    "name": "Guasila",
    "lat": "39.5598",
    "lng": "9.04404"
  },
  {
    "country": "IT",
    "name": "Aprigliano",
    "lat": "39.24228",
    "lng": "16.34046"
  },
  {
    "country": "IT",
    "name": "Guardia Piemontese",
    "lat": "39.46572",
    "lng": "15.9997"
  },
  {
    "country": "IT",
    "name": "Guardavalle",
    "lat": "38.5051",
    "lng": "16.50669"
  },
  {
    "country": "IT",
    "name": "Guamaggiore",
    "lat": "39.56849",
    "lng": "9.07391"
  },
  {
    "country": "IT",
    "name": "Grotteria",
    "lat": "38.36509",
    "lng": "16.26522"
  },
  {
    "country": "IT",
    "name": "Grotte",
    "lat": "37.40346",
    "lng": "13.69889"
  },
  {
    "country": "IT",
    "name": "Grisolia",
    "lat": "39.72538",
    "lng": "15.85605"
  },
  {
    "country": "IT",
    "name": "Grimaldi",
    "lat": "39.14111",
    "lng": "16.23511"
  },
  {
    "country": "IT",
    "name": "Gratteri",
    "lat": "37.96607",
    "lng": "13.97314"
  },
  {
    "country": "IT",
    "name": "Grammichele",
    "lat": "37.21326",
    "lng": "14.63311"
  },
  {
    "country": "IT",
    "name": "Gonnostramatza",
    "lat": "39.68306",
    "lng": "8.83283"
  },
  {
    "country": "IT",
    "name": "Gonnosnò",
    "lat": "39.76104",
    "lng": "8.87135"
  },
  {
    "country": "IT",
    "name": "Gonnosfanadiga",
    "lat": "39.49426",
    "lng": "8.662"
  },
  {
    "country": "IT",
    "name": "Gonnoscodina",
    "lat": "39.69962",
    "lng": "8.83598"
  },
  {
    "country": "IT",
    "name": "Gonnesa",
    "lat": "39.26535",
    "lng": "8.47038"
  },
  {
    "country": "IT",
    "name": "Goni",
    "lat": "39.57906",
    "lng": "9.28519"
  },
  {
    "country": "IT",
    "name": "Godrano",
    "lat": "37.9031",
    "lng": "13.42823"
  },
  {
    "country": "IT",
    "name": "Gizzeria",
    "lat": "38.98025",
    "lng": "16.20671"
  },
  {
    "country": "IT",
    "name": "Giuliana",
    "lat": "37.6728",
    "lng": "13.23737"
  },
  {
    "country": "IT",
    "name": "Girifalco",
    "lat": "38.82594",
    "lng": "16.42688"
  },
  {
    "country": "IT",
    "name": "Girasole",
    "lat": "39.95205",
    "lng": "9.66098"
  },
  {
    "country": "IT",
    "name": "Gioiosa Marea",
    "lat": "38.17373",
    "lng": "14.89932"
  },
  {
    "country": "IT",
    "name": "Gioiosa Ionica",
    "lat": "38.32723",
    "lng": "16.30407"
  },
  {
    "country": "IT",
    "name": "Gioia Tauro",
    "lat": "38.4251",
    "lng": "15.8975"
  },
  {
    "country": "IT",
    "name": "Gimigliano",
    "lat": "38.97338",
    "lng": "16.53165"
  },
  {
    "country": "IT",
    "name": "Giffone",
    "lat": "38.43957",
    "lng": "16.14898"
  },
  {
    "country": "IT",
    "name": "Nuova Gibellina",
    "lat": "37.80704",
    "lng": "12.86954"
  },
  {
    "country": "IT",
    "name": "Giba",
    "lat": "39.07151",
    "lng": "8.6358"
  },
  {
    "country": "IT",
    "name": "Giarre",
    "lat": "37.7244",
    "lng": "15.18165"
  },
  {
    "country": "IT",
    "name": "Giarratana",
    "lat": "37.04741",
    "lng": "14.79454"
  },
  {
    "country": "IT",
    "name": "Giardini-Naxos",
    "lat": "37.82755",
    "lng": "15.26713"
  },
  {
    "country": "IT",
    "name": "Giardinello",
    "lat": "38.08706",
    "lng": "13.15648"
  },
  {
    "country": "IT",
    "name": "Giardina Gallotti",
    "lat": "37.35073",
    "lng": "13.52272"
  },
  {
    "country": "IT",
    "name": "Gesturi",
    "lat": "39.73237",
    "lng": "9.02077"
  },
  {
    "country": "IT",
    "name": "Gesico",
    "lat": "39.61636",
    "lng": "9.10665"
  },
  {
    "country": "IT",
    "name": "Gergei",
    "lat": "39.69878",
    "lng": "9.09965"
  },
  {
    "country": "IT",
    "name": "Geraci Siculo",
    "lat": "37.85901",
    "lng": "14.15333"
  },
  {
    "country": "IT",
    "name": "Gerace",
    "lat": "38.27137",
    "lng": "16.2207"
  },
  {
    "country": "IT",
    "name": "Genuri",
    "lat": "39.74327",
    "lng": "8.92407"
  },
  {
    "country": "IT",
    "name": "Genoni",
    "lat": "39.79361",
    "lng": "9.00797"
  },
  {
    "country": "IT",
    "name": "Gemini",
    "lat": "39.91134",
    "lng": "18.18742"
  },
  {
    "country": "IT",
    "name": "Gela",
    "lat": "37.07381",
    "lng": "14.24038"
  },
  {
    "country": "IT",
    "name": "Gasperina",
    "lat": "38.74039",
    "lng": "16.50666"
  },
  {
    "country": "IT",
    "name": "Gangi",
    "lat": "37.79565",
    "lng": "14.20437"
  },
  {
    "country": "IT",
    "name": "Gallodoro",
    "lat": "37.90206",
    "lng": "15.29359"
  },
  {
    "country": "IT",
    "name": "Galatro",
    "lat": "38.46067",
    "lng": "16.1084"
  },
  {
    "country": "IT",
    "name": "Galati Mamertino",
    "lat": "38.03176",
    "lng": "14.77145"
  },
  {
    "country": "IT",
    "name": "Gairo Sant'Elena",
    "lat": "39.84972",
    "lng": "9.50472"
  },
  {
    "country": "IT",
    "name": "Gagliano del Capo",
    "lat": "39.84323",
    "lng": "18.36962"
  },
  {
    "country": "IT",
    "name": "Gagliano Castelferrato",
    "lat": "37.70967",
    "lng": "14.53524"
  },
  {
    "country": "IT",
    "name": "Gaggi",
    "lat": "37.85995",
    "lng": "15.22126"
  },
  {
    "country": "IT",
    "name": "Gadoni",
    "lat": "39.91388",
    "lng": "9.1856"
  },
  {
    "country": "IT",
    "name": "Fuscaldo",
    "lat": "39.41421",
    "lng": "16.02839"
  },
  {
    "country": "IT",
    "name": "Furtei",
    "lat": "39.56253",
    "lng": "8.94773"
  },
  {
    "country": "IT",
    "name": "Furci Siculo",
    "lat": "37.96159",
    "lng": "15.37763"
  },
  {
    "country": "IT",
    "name": "Frazzanò",
    "lat": "38.07202",
    "lng": "14.74407"
  },
  {
    "country": "IT",
    "name": "Frascineto",
    "lat": "39.83382",
    "lng": "16.26378"
  },
  {
    "country": "IT",
    "name": "Francofonte",
    "lat": "37.22477",
    "lng": "14.87488"
  },
  {
    "country": "IT",
    "name": "Francica",
    "lat": "38.61697",
    "lng": "16.10007"
  },
  {
    "country": "IT",
    "name": "Francavilla Marittima",
    "lat": "39.8161",
    "lng": "16.39499"
  },
  {
    "country": "IT",
    "name": "Francavilla di Sicilia",
    "lat": "37.90197",
    "lng": "15.13821"
  },
  {
    "country": "IT",
    "name": "Francavilla Angitola",
    "lat": "38.78016",
    "lng": "16.27228"
  },
  {
    "country": "IT",
    "name": "Fossato Serralta",
    "lat": "38.99629",
    "lng": "16.5796"
  },
  {
    "country": "IT",
    "name": "Fossato Ionico-Fossatello-San Luca Marcelluzzo",
    "lat": "38.01065",
    "lng": "15.76302"
  },
  {
    "country": "IT",
    "name": "Forza d'Agrò",
    "lat": "37.91539",
    "lng": "15.33409"
  },
  {
    "country": "IT",
    "name": "Fordongianus",
    "lat": "39.99436",
    "lng": "8.81019"
  },
  {
    "country": "IT",
    "name": "Fluminimaggiore",
    "lat": "39.43878",
    "lng": "8.49758"
  },
  {
    "country": "IT",
    "name": "Floridia",
    "lat": "37.08343",
    "lng": "15.15332"
  },
  {
    "country": "IT",
    "name": "Floresta",
    "lat": "37.98779",
    "lng": "14.91096"
  },
  {
    "country": "IT",
    "name": "Fiumefreddo Sicilia",
    "lat": "37.79146",
    "lng": "15.20919"
  },
  {
    "country": "IT",
    "name": "Fiumefreddo Bruzio",
    "lat": "39.23568",
    "lng": "16.07056"
  },
  {
    "country": "IT",
    "name": "Fiumedinisi",
    "lat": "38.02596",
    "lng": "15.38099"
  },
  {
    "country": "IT",
    "name": "Firmo",
    "lat": "39.72208",
    "lng": "16.16344"
  },
  {
    "country": "IT",
    "name": "Finale",
    "lat": "38.01891",
    "lng": "14.16151"
  },
  {
    "country": "IT",
    "name": "Filogaso",
    "lat": "38.68287",
    "lng": "16.22584"
  },
  {
    "country": "IT",
    "name": "Filadelfia",
    "lat": "38.78468",
    "lng": "16.292"
  },
  {
    "country": "IT",
    "name": "Ficarra",
    "lat": "38.10849",
    "lng": "14.8299"
  },
  {
    "country": "IT",
    "name": "Ficarazzi",
    "lat": "38.09229",
    "lng": "13.4639"
  },
  {
    "country": "IT",
    "name": "Ferruzzano",
    "lat": "38.03699",
    "lng": "16.08918"
  },
  {
    "country": "IT",
    "name": "Feroleto della Chiesa",
    "lat": "38.46609",
    "lng": "16.07012"
  },
  {
    "country": "IT",
    "name": "Ferla",
    "lat": "37.11978",
    "lng": "14.93881"
  },
  {
    "country": "IT",
    "name": "Felline",
    "lat": "39.93651",
    "lng": "18.11822"
  },
  {
    "country": "IT",
    "name": "Favignana",
    "lat": "37.92951",
    "lng": "12.32958"
  },
  {
    "country": "IT",
    "name": "Favara",
    "lat": "37.31754",
    "lng": "13.66226"
  },
  {
    "country": "IT",
    "name": "Faro Superiore",
    "lat": "38.26794",
    "lng": "15.58268"
  },
  {
    "country": "IT",
    "name": "Falerna",
    "lat": "39.00298",
    "lng": "16.17151"
  },
  {
    "country": "IT",
    "name": "Falcone",
    "lat": "38.11698",
    "lng": "15.07965"
  },
  {
    "country": "IT",
    "name": "Falconara Albanese",
    "lat": "39.27524",
    "lng": "16.08819"
  },
  {
    "country": "IT",
    "name": "Fagnano Castello",
    "lat": "39.5716",
    "lng": "16.06253"
  },
  {
    "country": "IT",
    "name": "Fabrizia",
    "lat": "38.48989",
    "lng": "16.29832"
  },
  {
    "country": "IT",
    "name": "Esterzili",
    "lat": "39.78041",
    "lng": "9.28357"
  },
  {
    "country": "IT",
    "name": "Escolca",
    "lat": "39.69861",
    "lng": "9.12139"
  },
  {
    "country": "IT",
    "name": "Escalaplano",
    "lat": "39.62574",
    "lng": "9.3535"
  },
  {
    "country": "IT",
    "name": "Erice",
    "lat": "38.03785",
    "lng": "12.58778"
  },
  {
    "country": "IT",
    "name": "Enna",
    "lat": "37.5655",
    "lng": "14.27433"
  },
  {
    "country": "IT",
    "name": "Elmas",
    "lat": "39.26878",
    "lng": "9.05021"
  },
  {
    "country": "IT",
    "name": "Elini",
    "lat": "39.89952",
    "lng": "9.53198"
  },
  {
    "country": "IT",
    "name": "Drapia",
    "lat": "38.66612",
    "lng": "15.91122"
  },
  {
    "country": "IT",
    "name": "Doria",
    "lat": "39.73042",
    "lng": "16.35597"
  },
  {
    "country": "IT",
    "name": "Donorì",
    "lat": "39.43182",
    "lng": "9.12674"
  },
  {
    "country": "IT",
    "name": "Donnici Inferiore",
    "lat": "39.2502",
    "lng": "16.29307"
  },
  {
    "country": "IT",
    "name": "Donnalucata",
    "lat": "36.76117",
    "lng": "14.64022"
  },
  {
    "country": "IT",
    "name": "Donigala Fenugheddu",
    "lat": "39.93501",
    "lng": "8.57311"
  },
  {
    "country": "IT",
    "name": "Domusnovas",
    "lat": "39.32404",
    "lng": "8.64921"
  },
  {
    "country": "IT",
    "name": "Domus de Maria",
    "lat": "38.94451",
    "lng": "8.8625"
  },
  {
    "country": "IT",
    "name": "Domanico",
    "lat": "39.21693",
    "lng": "16.20721"
  },
  {
    "country": "IT",
    "name": "Dolianova",
    "lat": "39.37791",
    "lng": "9.17697"
  },
  {
    "country": "IT",
    "name": "Diso",
    "lat": "40.00915",
    "lng": "18.39144"
  },
  {
    "country": "IT",
    "name": "Dinami",
    "lat": "38.53136",
    "lng": "16.14461"
  },
  {
    "country": "IT",
    "name": "Diamante",
    "lat": "39.6807",
    "lng": "15.82168"
  },
  {
    "country": "IT",
    "name": "Depressa",
    "lat": "39.95908",
    "lng": "18.36174"
  },
  {
    "country": "IT",
    "name": "Delianuova",
    "lat": "38.23587",
    "lng": "15.91714"
  },
  {
    "country": "IT",
    "name": "Delia",
    "lat": "37.35796",
    "lng": "13.92867"
  },
  {
    "country": "IT",
    "name": "Decollatura",
    "lat": "39.04645",
    "lng": "16.35753"
  },
  {
    "country": "IT",
    "name": "Decimoputzu",
    "lat": "39.33522",
    "lng": "8.9144"
  },
  {
    "country": "IT",
    "name": "Decimomannu",
    "lat": "39.31033",
    "lng": "8.96964"
  },
  {
    "country": "IT",
    "name": "Davoli",
    "lat": "38.64904",
    "lng": "16.48764"
  },
  {
    "country": "IT",
    "name": "Dasà",
    "lat": "38.56514",
    "lng": "16.19521"
  },
  {
    "country": "IT",
    "name": "Cutro",
    "lat": "39.03484",
    "lng": "16.98658"
  },
  {
    "country": "IT",
    "name": "Custonaci",
    "lat": "38.07931",
    "lng": "12.68571"
  },
  {
    "country": "IT",
    "name": "Curinga",
    "lat": "38.82811",
    "lng": "16.31344"
  },
  {
    "country": "IT",
    "name": "Curcuris",
    "lat": "39.74625",
    "lng": "8.83154"
  },
  {
    "country": "IT",
    "name": "Crucoli",
    "lat": "39.42713",
    "lng": "17.00281"
  },
  {
    "country": "IT",
    "name": "Crotone",
    "lat": "39.08077",
    "lng": "17.12764"
  },
  {
    "country": "IT",
    "name": "Crosia",
    "lat": "39.56822",
    "lng": "16.77126"
  },
  {
    "country": "IT",
    "name": "Cropani",
    "lat": "38.9669",
    "lng": "16.78022"
  },
  {
    "country": "IT",
    "name": "Cropalati",
    "lat": "39.51673",
    "lng": "16.72674"
  },
  {
    "country": "IT",
    "name": "Crichi",
    "lat": "38.95296",
    "lng": "16.64178"
  },
  {
    "country": "IT",
    "name": "Cotronei",
    "lat": "39.15935",
    "lng": "16.77688"
  },
  {
    "country": "IT",
    "name": "Cosoleto",
    "lat": "38.27483",
    "lng": "15.92814"
  },
  {
    "country": "IT",
    "name": "Cosenza",
    "lat": "39.2989",
    "lng": "16.25307"
  },
  {
    "country": "IT",
    "name": "Cortale",
    "lat": "38.84009",
    "lng": "16.4096"
  },
  {
    "country": "IT",
    "name": "Corsano",
    "lat": "39.88911",
    "lng": "18.36747"
  },
  {
    "country": "IT",
    "name": "Corleone",
    "lat": "37.81338",
    "lng": "13.3017"
  },
  {
    "country": "IT",
    "name": "Corigliano Calabro",
    "lat": "39.59553",
    "lng": "16.51907"
  },
  {
    "country": "IT",
    "name": "Contessa Entellina",
    "lat": "37.73005",
    "lng": "13.18425"
  },
  {
    "country": "IT",
    "name": "Condrò",
    "lat": "38.17375",
    "lng": "15.3266"
  },
  {
    "country": "IT",
    "name": "Condofuri",
    "lat": "38.00447",
    "lng": "15.8577"
  },
  {
    "country": "IT",
    "name": "Comitini",
    "lat": "37.40735",
    "lng": "13.6453"
  },
  {
    "country": "IT",
    "name": "Comiso",
    "lat": "36.94893",
    "lng": "14.60731"
  },
  {
    "country": "IT",
    "name": "Colosimi",
    "lat": "39.11911",
    "lng": "16.39909"
  },
  {
    "country": "IT",
    "name": "Collinas",
    "lat": "39.64059",
    "lng": "8.83955"
  },
  {
    "country": "IT",
    "name": "Collesano",
    "lat": "37.91809",
    "lng": "13.93702"
  },
  {
    "country": "IT",
    "name": "Cleto",
    "lat": "39.09019",
    "lng": "16.15839"
  },
  {
    "country": "IT",
    "name": "Civita",
    "lat": "39.82804",
    "lng": "16.31337"
  },
  {
    "country": "IT",
    "name": "Cittanova",
    "lat": "38.35431",
    "lng": "16.07898"
  },
  {
    "country": "IT",
    "name": "Cittadella del Capo",
    "lat": "39.55932",
    "lng": "15.87602"
  },
  {
    "country": "IT",
    "name": "Cirò Marina",
    "lat": "39.36876",
    "lng": "17.12477"
  },
  {
    "country": "IT",
    "name": "Cirò",
    "lat": "39.38297",
    "lng": "17.06377"
  },
  {
    "country": "IT",
    "name": "Cinque Frondi",
    "lat": "38.41618",
    "lng": "16.0842"
  },
  {
    "country": "IT",
    "name": "Cinisi",
    "lat": "38.16082",
    "lng": "13.10099"
  },
  {
    "country": "IT",
    "name": "Ciminna",
    "lat": "37.89765",
    "lng": "13.55966"
  },
  {
    "country": "IT",
    "name": "Ciminà",
    "lat": "38.24618",
    "lng": "16.14023"
  },
  {
    "country": "IT",
    "name": "Cicala",
    "lat": "39.02219",
    "lng": "16.4861"
  },
  {
    "country": "IT",
    "name": "Ciavolo",
    "lat": "37.77943",
    "lng": "12.53774"
  },
  {
    "country": "IT",
    "name": "Cianciana",
    "lat": "37.51896",
    "lng": "13.43349"
  },
  {
    "country": "IT",
    "name": "Chiusa Sclafani",
    "lat": "37.67692",
    "lng": "13.27074"
  },
  {
    "country": "IT",
    "name": "Chiaravalle Centrale",
    "lat": "38.67936",
    "lng": "16.40864"
  },
  {
    "country": "IT",
    "name": "Chiaramonte Gulfi",
    "lat": "37.0305",
    "lng": "14.70302"
  },
  {
    "country": "IT",
    "name": "Cetraro",
    "lat": "39.5166",
    "lng": "15.94158"
  },
  {
    "country": "IT",
    "name": "Cessaniti",
    "lat": "38.66395",
    "lng": "16.02959"
  },
  {
    "country": "IT",
    "name": "Cesarò",
    "lat": "37.84476",
    "lng": "14.71308"
  },
  {
    "country": "IT",
    "name": "Cerzeto",
    "lat": "39.50789",
    "lng": "16.11603"
  },
  {
    "country": "IT",
    "name": "Cervicati",
    "lat": "39.54237",
    "lng": "16.12682"
  },
  {
    "country": "IT",
    "name": "Cerva",
    "lat": "39.02397",
    "lng": "16.74538"
  },
  {
    "country": "IT",
    "name": "Cerisano",
    "lat": "39.27715",
    "lng": "16.17654"
  },
  {
    "country": "IT",
    "name": "Cerenzia",
    "lat": "39.24554",
    "lng": "16.78758"
  },
  {
    "country": "IT",
    "name": "Cerda",
    "lat": "37.90578",
    "lng": "13.81496"
  },
  {
    "country": "IT",
    "name": "Cerchiara di Calabria",
    "lat": "39.85978",
    "lng": "16.38368"
  },
  {
    "country": "IT",
    "name": "Ceramida-Pellegrina",
    "lat": "38.29667",
    "lng": "15.82572"
  },
  {
    "country": "IT",
    "name": "Cerami",
    "lat": "37.80953",
    "lng": "14.5066"
  },
  {
    "country": "IT",
    "name": "Centuripe",
    "lat": "37.62336",
    "lng": "14.74049"
  },
  {
    "country": "IT",
    "name": "Centrache",
    "lat": "38.72872",
    "lng": "16.43101"
  },
  {
    "country": "IT",
    "name": "Cenadi",
    "lat": "38.71934",
    "lng": "16.41582"
  },
  {
    "country": "IT",
    "name": "Cellara",
    "lat": "39.21849",
    "lng": "16.3348"
  },
  {
    "country": "IT",
    "name": "Celico",
    "lat": "39.31009",
    "lng": "16.33989"
  },
  {
    "country": "IT",
    "name": "Cefalù",
    "lat": "38.03856",
    "lng": "14.02285"
  },
  {
    "country": "IT",
    "name": "Cefalà Diana",
    "lat": "37.91565",
    "lng": "13.46325"
  },
  {
    "country": "IT",
    "name": "Cava d'Aliga",
    "lat": "36.72964",
    "lng": "14.69031"
  },
  {
    "country": "IT",
    "name": "Caulonia",
    "lat": "38.38171",
    "lng": "16.40951"
  },
  {
    "country": "IT",
    "name": "Cattolica Eraclea",
    "lat": "37.44069",
    "lng": "13.39265"
  },
  {
    "country": "IT",
    "name": "Catenanuova",
    "lat": "37.56876",
    "lng": "14.69076"
  },
  {
    "country": "IT",
    "name": "Catanzaro",
    "lat": "38.88247",
    "lng": "16.60086"
  },
  {
    "country": "IT",
    "name": "Catania",
    "lat": "37.49223",
    "lng": "15.07041"
  },
  {
    "country": "IT",
    "name": "Castrovillari",
    "lat": "39.81632",
    "lng": "16.20183"
  },
  {
    "country": "IT",
    "name": "Castroregio",
    "lat": "39.9922",
    "lng": "16.47846"
  },
  {
    "country": "IT",
    "name": "Castroreale",
    "lat": "38.09857",
    "lng": "15.21012"
  },
  {
    "country": "IT",
    "name": "Castronuovo di Sicilia",
    "lat": "37.67894",
    "lng": "13.60346"
  },
  {
    "country": "IT",
    "name": "Castrolibero",
    "lat": "39.31002",
    "lng": "16.19453"
  },
  {
    "country": "IT",
    "name": "Castrofilippo",
    "lat": "37.35046",
    "lng": "13.75001"
  },
  {
    "country": "IT",
    "name": "Castrignano del Capo",
    "lat": "39.8328",
    "lng": "18.35087"
  },
  {
    "country": "IT",
    "name": "Castiglione",
    "lat": "39.98333",
    "lng": "18.35"
  },
  {
    "country": "IT",
    "name": "Castiglione di Sicilia",
    "lat": "37.8815",
    "lng": "15.12156"
  },
  {
    "country": "IT",
    "name": "Castiglione Cosentino",
    "lat": "39.35271",
    "lng": "16.28821"
  },
  {
    "country": "IT",
    "name": "Castiadas",
    "lat": "39.23704",
    "lng": "9.49975"
  },
  {
    "country": "IT",
    "name": "Castelvetrano",
    "lat": "37.68081",
    "lng": "12.79194"
  },
  {
    "country": "IT",
    "name": "Casteltermini",
    "lat": "37.53874",
    "lng": "13.64601"
  },
  {
    "country": "IT",
    "name": "Castelmola",
    "lat": "37.85829",
    "lng": "15.27713"
  },
  {
    "country": "IT",
    "name": "Castelluzzo",
    "lat": "38.10096",
    "lng": "12.73599"
  },
  {
    "country": "IT",
    "name": "Castell'Umberto",
    "lat": "38.08626",
    "lng": "14.80686"
  },
  {
    "country": "IT",
    "name": "Castelluccio Inferiore",
    "lat": "40.00151",
    "lng": "15.98149"
  },
  {
    "country": "IT",
    "name": "Castellana Sicula",
    "lat": "37.78686",
    "lng": "14.03906"
  },
  {
    "country": "IT",
    "name": "Castellammare del Golfo",
    "lat": "38.02653",
    "lng": "12.88183"
  },
  {
    "country": "IT",
    "name": "Castel di Lucio",
    "lat": "37.88698",
    "lng": "14.31116"
  },
  {
    "country": "IT",
    "name": "Castel di Judica",
    "lat": "37.49475",
    "lng": "14.64744"
  },
  {
    "country": "IT",
    "name": "Casteldaccia",
    "lat": "38.05121",
    "lng": "13.53041"
  },
  {
    "country": "IT",
    "name": "Castelbuono",
    "lat": "37.9253",
    "lng": "14.08665"
  },
  {
    "country": "IT",
    "name": "Castanea delle Furie",
    "lat": "38.26165",
    "lng": "15.52178"
  },
  {
    "country": "IT",
    "name": "Cassibile",
    "lat": "36.97862",
    "lng": "15.20061"
  },
  {
    "country": "IT",
    "name": "Cassaro",
    "lat": "37.10571",
    "lng": "14.94697"
  },
  {
    "country": "IT",
    "name": "Cassano Allo Ionio",
    "lat": "39.78142",
    "lng": "16.32738"
  },
  {
    "country": "IT",
    "name": "Casole Bruzio",
    "lat": "39.28384",
    "lng": "16.33193"
  },
  {
    "country": "IT",
    "name": "Casignana",
    "lat": "38.10187",
    "lng": "16.0899"
  },
  {
    "country": "IT",
    "name": "Casarano",
    "lat": "40.01131",
    "lng": "18.16237"
  },
  {
    "country": "IT",
    "name": "Casalvecchio Siculo",
    "lat": "37.9585",
    "lng": "15.32371"
  },
  {
    "country": "IT",
    "name": "Casabona",
    "lat": "39.24951",
    "lng": "16.95446"
  },
  {
    "country": "IT",
    "name": "Carpanzano",
    "lat": "39.14817",
    "lng": "16.30451"
  },
  {
    "country": "IT",
    "name": "Marina di Caronia",
    "lat": "38.03545",
    "lng": "14.44182"
  },
  {
    "country": "IT",
    "name": "Caronia",
    "lat": "38.02381",
    "lng": "14.44142"
  },
  {
    "country": "IT",
    "name": "Carolei",
    "lat": "39.25472",
    "lng": "16.21979"
  },
  {
    "country": "IT",
    "name": "Carlopoli",
    "lat": "39.05406",
    "lng": "16.45455"
  },
  {
    "country": "IT",
    "name": "Carloforte",
    "lat": "39.14081",
    "lng": "8.3039"
  },
  {
    "country": "IT",
    "name": "Carlentini",
    "lat": "37.28071",
    "lng": "15.0102"
  },
  {
    "country": "IT",
    "name": "Carini",
    "lat": "38.1324",
    "lng": "13.18274"
  },
  {
    "country": "IT",
    "name": "Cariati",
    "lat": "39.49627",
    "lng": "16.95495"
  },
  {
    "country": "IT",
    "name": "Carfizzi",
    "lat": "39.30771",
    "lng": "16.97447"
  },
  {
    "country": "IT",
    "name": "Careri",
    "lat": "38.17741",
    "lng": "16.11614"
  },
  {
    "country": "IT",
    "name": "Cardinale",
    "lat": "38.65379",
    "lng": "16.38715"
  },
  {
    "country": "IT",
    "name": "Cardeto",
    "lat": "38.0844",
    "lng": "15.76577"
  },
  {
    "country": "IT",
    "name": "Carbonia",
    "lat": "39.16465",
    "lng": "8.5213"
  },
  {
    "country": "IT",
    "name": "Caraffa di Catanzaro",
    "lat": "38.88194",
    "lng": "16.48675"
  },
  {
    "country": "IT",
    "name": "Caraffa del Bianco",
    "lat": "38.09259",
    "lng": "16.08766"
  },
  {
    "country": "IT",
    "name": "Capri Leone",
    "lat": "38.08682",
    "lng": "14.72959"
  },
  {
    "country": "IT",
    "name": "Capoterra",
    "lat": "39.1752",
    "lng": "8.97199"
  },
  {
    "country": "IT",
    "name": "Capo Rizzuto",
    "lat": "38.90412",
    "lng": "17.09872"
  },
  {
    "country": "IT",
    "name": "Capo d'Orlando",
    "lat": "38.14262",
    "lng": "14.73292"
  },
  {
    "country": "IT",
    "name": "Dipignano",
    "lat": "39.23869",
    "lng": "16.25184"
  },
  {
    "country": "IT",
    "name": "Capizzi",
    "lat": "37.84788",
    "lng": "14.47976"
  },
  {
    "country": "IT",
    "name": "Capistrano",
    "lat": "38.69131",
    "lng": "16.28935"
  },
  {
    "country": "IT",
    "name": "Capaci",
    "lat": "38.17107",
    "lng": "13.2393"
  },
  {
    "country": "IT",
    "name": "Canolo",
    "lat": "38.31497",
    "lng": "16.1999"
  },
  {
    "country": "IT",
    "name": "Canneto",
    "lat": "38.49505",
    "lng": "14.96037"
  },
  {
    "country": "IT",
    "name": "Canicattini Bagni",
    "lat": "37.03171",
    "lng": "15.06388"
  },
  {
    "country": "IT",
    "name": "Canicattì",
    "lat": "37.35842",
    "lng": "13.84786"
  },
  {
    "country": "IT",
    "name": "Candidoni",
    "lat": "38.50548",
    "lng": "16.0863"
  },
  {
    "country": "IT",
    "name": "Camporeale",
    "lat": "37.88612",
    "lng": "13.10107"
  },
  {
    "country": "IT",
    "name": "Campofranco",
    "lat": "37.51208",
    "lng": "13.71213"
  },
  {
    "country": "IT",
    "name": "Campofiorito",
    "lat": "37.75374",
    "lng": "13.26875"
  },
  {
    "country": "IT",
    "name": "Campofelice di Roccella",
    "lat": "37.9927",
    "lng": "13.87648"
  },
  {
    "country": "IT",
    "name": "Campofelice di Fitalia",
    "lat": "37.82686",
    "lng": "13.48572"
  },
  {
    "country": "IT",
    "name": "Campobello di Mazara",
    "lat": "37.63464",
    "lng": "12.74946"
  },
  {
    "country": "IT",
    "name": "Campobello di Licata",
    "lat": "37.25759",
    "lng": "13.91811"
  },
  {
    "country": "IT",
    "name": "Campana",
    "lat": "39.4136",
    "lng": "16.8222"
  },
  {
    "country": "IT",
    "name": "Cammarata",
    "lat": "37.63361",
    "lng": "13.62722"
  },
  {
    "country": "IT",
    "name": "Camini",
    "lat": "38.43179",
    "lng": "16.48321"
  },
  {
    "country": "IT",
    "name": "Camastra",
    "lat": "37.2538",
    "lng": "13.79211"
  },
  {
    "country": "IT",
    "name": "Caltavuturo",
    "lat": "37.8204",
    "lng": "13.89158"
  },
  {
    "country": "IT",
    "name": "Caltanissetta",
    "lat": "37.49025",
    "lng": "14.06216"
  },
  {
    "country": "IT",
    "name": "Caltagirone",
    "lat": "37.23785",
    "lng": "14.51551"
  },
  {
    "country": "IT",
    "name": "Caltabellotta",
    "lat": "37.57543",
    "lng": "13.21632"
  },
  {
    "country": "IT",
    "name": "Caloveto",
    "lat": "39.50656",
    "lng": "16.76065"
  },
  {
    "country": "IT",
    "name": "Caloppezzati",
    "lat": "39.5612",
    "lng": "16.8018"
  },
  {
    "country": "IT",
    "name": "Calatafimi",
    "lat": "37.9144",
    "lng": "12.86364"
  },
  {
    "country": "IT",
    "name": "Calatabiano",
    "lat": "37.82049",
    "lng": "15.23069"
  },
  {
    "country": "IT",
    "name": "Calasetta",
    "lat": "39.10697",
    "lng": "8.36803"
  },
  {
    "country": "IT",
    "name": "Calascibetta",
    "lat": "37.59024",
    "lng": "14.2718"
  },
  {
    "country": "IT",
    "name": "Calanna",
    "lat": "38.18457",
    "lng": "15.72293"
  },
  {
    "country": "IT",
    "name": "Calamonaci",
    "lat": "37.52566",
    "lng": "13.29053"
  },
  {
    "country": "IT",
    "name": "Cagliari",
    "lat": "39.23054",
    "lng": "9.11917"
  },
  {
    "country": "IT",
    "name": "Caccuri",
    "lat": "39.22562",
    "lng": "16.77767"
  },
  {
    "country": "IT",
    "name": "Caccamo",
    "lat": "37.93357",
    "lng": "13.66808"
  },
  {
    "country": "IT",
    "name": "Cabras",
    "lat": "39.92871",
    "lng": "8.53242"
  },
  {
    "country": "IT",
    "name": "Butera",
    "lat": "37.191",
    "lng": "14.18232"
  },
  {
    "country": "IT",
    "name": "Buscemi",
    "lat": "37.08604",
    "lng": "14.88499"
  },
  {
    "country": "IT",
    "name": "Burgio",
    "lat": "37.60094",
    "lng": "13.28826"
  },
  {
    "country": "IT",
    "name": "Burcei",
    "lat": "39.34379",
    "lng": "9.36027"
  },
  {
    "country": "IT",
    "name": "Buonvicino",
    "lat": "39.68877",
    "lng": "15.884"
  },
  {
    "country": "IT",
    "name": "Buggerru",
    "lat": "39.39831",
    "lng": "8.40186"
  },
  {
    "country": "IT",
    "name": "Buccheri",
    "lat": "37.12494",
    "lng": "14.85222"
  },
  {
    "country": "IT",
    "name": "Bruzzano Zeffirio",
    "lat": "38.01327",
    "lng": "16.0826"
  },
  {
    "country": "IT",
    "name": "Brucoli",
    "lat": "37.28191",
    "lng": "15.18836"
  },
  {
    "country": "IT",
    "name": "Bronte",
    "lat": "37.78863",
    "lng": "14.83377"
  },
  {
    "country": "IT",
    "name": "Brolo",
    "lat": "38.15623",
    "lng": "14.82799"
  },
  {
    "country": "IT",
    "name": "Briatico",
    "lat": "38.72254",
    "lng": "16.02737"
  },
  {
    "country": "IT",
    "name": "Brancaleone",
    "lat": "37.96297",
    "lng": "16.1004"
  },
  {
    "country": "IT",
    "name": "Brancaleone-Marina",
    "lat": "37.96667",
    "lng": "16.1"
  },
  {
    "country": "IT",
    "name": "Bova Marina",
    "lat": "37.93503",
    "lng": "15.91736"
  },
  {
    "country": "IT",
    "name": "Bovalino Superiore",
    "lat": "38.16905",
    "lng": "16.15849"
  },
  {
    "country": "IT",
    "name": "Bovalino",
    "lat": "38.15376",
    "lng": "16.17232"
  },
  {
    "country": "IT",
    "name": "Botricello",
    "lat": "38.92997",
    "lng": "16.85801"
  },
  {
    "country": "IT",
    "name": "Borgia",
    "lat": "38.82627",
    "lng": "16.5077"
  },
  {
    "country": "IT",
    "name": "Borgetto",
    "lat": "38.04664",
    "lng": "13.14071"
  },
  {
    "country": "IT",
    "name": "Bonifati",
    "lat": "39.58595",
    "lng": "15.90163"
  },
  {
    "country": "IT",
    "name": "Bompietro",
    "lat": "37.74394",
    "lng": "14.0947"
  },
  {
    "country": "IT",
    "name": "Bompensiere",
    "lat": "37.4724",
    "lng": "13.7814"
  },
  {
    "country": "IT",
    "name": "Bolognetta",
    "lat": "37.9712",
    "lng": "13.45627"
  },
  {
    "country": "IT",
    "name": "Bocchigliero",
    "lat": "39.4193",
    "lng": "16.75057"
  },
  {
    "country": "IT",
    "name": "Bivongi",
    "lat": "38.48328",
    "lng": "16.45251"
  },
  {
    "country": "IT",
    "name": "Bivona",
    "lat": "37.61797",
    "lng": "13.43895"
  },
  {
    "country": "IT",
    "name": "Bisignano",
    "lat": "39.50727",
    "lng": "16.28106"
  },
  {
    "country": "IT",
    "name": "Bisacquino",
    "lat": "37.70352",
    "lng": "13.26051"
  },
  {
    "country": "IT",
    "name": "Bianco",
    "lat": "38.0917",
    "lng": "16.15159"
  },
  {
    "country": "IT",
    "name": "Bianchi",
    "lat": "39.10058",
    "lng": "16.41018"
  },
  {
    "country": "IT",
    "name": "Biancavilla",
    "lat": "37.64442",
    "lng": "14.86685"
  },
  {
    "country": "IT",
    "name": "Benestare",
    "lat": "38.18487",
    "lng": "16.139"
  },
  {
    "country": "IT",
    "name": "Belvì",
    "lat": "39.96181",
    "lng": "9.18419"
  },
  {
    "country": "IT",
    "name": "Belvedere",
    "lat": "37.08839",
    "lng": "15.21314"
  },
  {
    "country": "IT",
    "name": "Belvedere Marittimo",
    "lat": "39.6193",
    "lng": "15.8622"
  },
  {
    "country": "IT",
    "name": "Belvedere Spinello",
    "lat": "39.20674",
    "lng": "16.89233"
  },
  {
    "country": "IT",
    "name": "Belsito",
    "lat": "39.17685",
    "lng": "16.28745"
  },
  {
    "country": "IT",
    "name": "Belpasso",
    "lat": "37.59192",
    "lng": "14.97985"
  },
  {
    "country": "IT",
    "name": "Belmonte Mezzagno",
    "lat": "38.04653",
    "lng": "13.39207"
  },
  {
    "country": "IT",
    "name": "Belmonte Calabro",
    "lat": "39.16398",
    "lng": "16.08215"
  },
  {
    "country": "IT",
    "name": "Baucina",
    "lat": "37.92521",
    "lng": "13.53636"
  },
  {
    "country": "IT",
    "name": "Basicò",
    "lat": "38.06077",
    "lng": "15.06263"
  },
  {
    "country": "IT",
    "name": "Barumini",
    "lat": "39.70215",
    "lng": "9.00338"
  },
  {
    "country": "IT",
    "name": "Barrali",
    "lat": "39.47532",
    "lng": "9.10204"
  },
  {
    "country": "IT",
    "name": "Barrafranca",
    "lat": "37.3785",
    "lng": "14.2027"
  },
  {
    "country": "IT",
    "name": "Bari Sardo",
    "lat": "39.84135",
    "lng": "9.64606"
  },
  {
    "country": "IT",
    "name": "Baressa",
    "lat": "39.71308",
    "lng": "8.87459"
  },
  {
    "country": "IT",
    "name": "Barcellona Pozzo di Gotto",
    "lat": "38.14772",
    "lng": "15.21469"
  },
  {
    "country": "IT",
    "name": "Baratili San Pietro",
    "lat": "39.9922",
    "lng": "8.55586"
  },
  {
    "country": "IT",
    "name": "Baradili",
    "lat": "39.72189",
    "lng": "8.89731"
  },
  {
    "country": "IT",
    "name": "Villa Verde",
    "lat": "39.79551",
    "lng": "8.82114"
  },
  {
    "country": "IT",
    "name": "Ballao",
    "lat": "39.54919",
    "lng": "9.36178"
  },
  {
    "country": "IT",
    "name": "Balestrate",
    "lat": "38.05125",
    "lng": "13.00724"
  },
  {
    "country": "IT",
    "name": "Bagnara Calabra",
    "lat": "38.28778",
    "lng": "15.80591"
  },
  {
    "country": "IT",
    "name": "Bagheria",
    "lat": "38.07892",
    "lng": "13.51237"
  },
  {
    "country": "IT",
    "name": "Bagaladi",
    "lat": "38.0256",
    "lng": "15.82152"
  },
  {
    "country": "IT",
    "name": "Badolato Marina",
    "lat": "38.57613",
    "lng": "16.56527"
  },
  {
    "country": "IT",
    "name": "Badolato",
    "lat": "38.56868",
    "lng": "16.52461"
  },
  {
    "country": "IT",
    "name": "Bacu Abis",
    "lat": "39.24301",
    "lng": "8.46491"
  },
  {
    "country": "IT",
    "name": "Avola",
    "lat": "36.9084",
    "lng": "15.13937"
  },
  {
    "country": "IT",
    "name": "Augusta",
    "lat": "37.24065",
    "lng": "15.22121"
  },
  {
    "country": "IT",
    "name": "Atzara",
    "lat": "39.99249",
    "lng": "9.07616"
  },
  {
    "country": "IT",
    "name": "Asuni",
    "lat": "39.87101",
    "lng": "8.94603"
  },
  {
    "country": "IT",
    "name": "Assoro",
    "lat": "37.6221",
    "lng": "14.4181"
  },
  {
    "country": "IT",
    "name": "Assolo",
    "lat": "39.80915",
    "lng": "8.91932"
  },
  {
    "country": "IT",
    "name": "Assemini",
    "lat": "39.29123",
    "lng": "8.99879"
  },
  {
    "country": "IT",
    "name": "Arzana",
    "lat": "39.91742",
    "lng": "9.52766"
  },
  {
    "country": "IT",
    "name": "Armungia",
    "lat": "39.52154",
    "lng": "9.38066"
  },
  {
    "country": "IT",
    "name": "Aritzo",
    "lat": "39.95903",
    "lng": "9.19265"
  },
  {
    "country": "IT",
    "name": "Argusto",
    "lat": "38.68051",
    "lng": "16.43627"
  },
  {
    "country": "IT",
    "name": "Arena",
    "lat": "38.56235",
    "lng": "16.2106"
  },
  {
    "country": "IT",
    "name": "Ardore Marina",
    "lat": "38.16667",
    "lng": "16.2"
  },
  {
    "country": "IT",
    "name": "Ardore",
    "lat": "38.19173",
    "lng": "16.16734"
  },
  {
    "country": "IT",
    "name": "Arbus",
    "lat": "39.52616",
    "lng": "8.5997"
  },
  {
    "country": "IT",
    "name": "Arborea",
    "lat": "39.77276",
    "lng": "8.58129"
  },
  {
    "country": "IT",
    "name": "Arbatax",
    "lat": "39.93444",
    "lng": "9.70556"
  },
  {
    "country": "IT",
    "name": "Aragona",
    "lat": "37.39904",
    "lng": "13.61974"
  },
  {
    "country": "IT",
    "name": "Antonimina",
    "lat": "38.27298",
    "lng": "16.14824"
  },
  {
    "country": "IT",
    "name": "Antillo",
    "lat": "37.97937",
    "lng": "15.24029"
  },
  {
    "country": "IT",
    "name": "Anoia Superiore",
    "lat": "38.43144",
    "lng": "16.0974"
  },
  {
    "country": "IT",
    "name": "Anoia Inferiore",
    "lat": "38.43618",
    "lng": "16.0794"
  },
  {
    "country": "IT",
    "name": "Andrano",
    "lat": "39.98546",
    "lng": "18.38232"
  },
  {
    "country": "IT",
    "name": "Andali",
    "lat": "39.01281",
    "lng": "16.76926"
  },
  {
    "country": "IT",
    "name": "Amica",
    "lat": "39.60085",
    "lng": "16.66694"
  },
  {
    "country": "IT",
    "name": "Amendolara",
    "lat": "39.95162",
    "lng": "16.58293"
  },
  {
    "country": "IT",
    "name": "Amato",
    "lat": "38.38333",
    "lng": "16.13333"
  },
  {
    "country": "IT",
    "name": "Amaroni",
    "lat": "38.79424",
    "lng": "16.44809"
  },
  {
    "country": "IT",
    "name": "Amantea",
    "lat": "39.12658",
    "lng": "16.07512"
  },
  {
    "country": "IT",
    "name": "Altomonte",
    "lat": "39.699",
    "lng": "16.12999"
  },
  {
    "country": "IT",
    "name": "Altofonte",
    "lat": "38.04298",
    "lng": "13.29434"
  },
  {
    "country": "IT",
    "name": "Altilia",
    "lat": "39.13049",
    "lng": "16.25269"
  },
  {
    "country": "IT",
    "name": "Altavilla Milicia",
    "lat": "38.038",
    "lng": "13.54947"
  },
  {
    "country": "IT",
    "name": "Alliste",
    "lat": "39.94803",
    "lng": "18.08971"
  },
  {
    "country": "IT",
    "name": "Allai",
    "lat": "39.95701",
    "lng": "8.86354"
  },
  {
    "country": "IT",
    "name": "Aliminusa",
    "lat": "37.86395",
    "lng": "13.78126"
  },
  {
    "country": "IT",
    "name": "Alimena",
    "lat": "37.6931",
    "lng": "14.11369"
  },
  {
    "country": "IT",
    "name": "Alia",
    "lat": "37.77867",
    "lng": "13.71391"
  },
  {
    "country": "IT",
    "name": "Alì",
    "lat": "38.02678",
    "lng": "15.4191"
  },
  {
    "country": "IT",
    "name": "Alessano",
    "lat": "39.89381",
    "lng": "18.33221"
  },
  {
    "country": "IT",
    "name": "Alessandria della Rocca",
    "lat": "37.56767",
    "lng": "13.45343"
  },
  {
    "country": "IT",
    "name": "Alessandria del Carretto",
    "lat": "39.95874",
    "lng": "16.37963"
  },
  {
    "country": "IT",
    "name": "Ales",
    "lat": "39.7683",
    "lng": "8.8152"
  },
  {
    "country": "IT",
    "name": "Alcara Li Fusi",
    "lat": "38.02143",
    "lng": "14.70142"
  },
  {
    "country": "IT",
    "name": "Alcamo",
    "lat": "37.9779",
    "lng": "12.96473"
  },
  {
    "country": "IT",
    "name": "Albidona",
    "lat": "39.92332",
    "lng": "16.47237"
  },
  {
    "country": "IT",
    "name": "Albi",
    "lat": "39.02456",
    "lng": "16.59721"
  },
  {
    "country": "IT",
    "name": "Aieta",
    "lat": "39.9278",
    "lng": "15.82348"
  },
  {
    "country": "IT",
    "name": "Aiello Calabro",
    "lat": "39.11785",
    "lng": "16.16539"
  },
  {
    "country": "IT",
    "name": "Aidone",
    "lat": "37.41468",
    "lng": "14.44542"
  },
  {
    "country": "IT",
    "name": "Agrigento",
    "lat": "37.31065",
    "lng": "13.57661"
  },
  {
    "country": "IT",
    "name": "Agnana Calabra",
    "lat": "38.30206",
    "lng": "16.22718"
  },
  {
    "country": "IT",
    "name": "Agira",
    "lat": "37.6558",
    "lng": "14.51972"
  },
  {
    "country": "IT",
    "name": "Africo Vecchio",
    "lat": "38.06667",
    "lng": "15.98333"
  },
  {
    "country": "IT",
    "name": "Adrano",
    "lat": "37.66358",
    "lng": "14.83283"
  },
  {
    "country": "IT",
    "name": "Acri",
    "lat": "39.49624",
    "lng": "16.38635"
  },
  {
    "country": "IT",
    "name": "Acquedolci",
    "lat": "38.05708",
    "lng": "14.5855"
  },
  {
    "country": "IT",
    "name": "Acquaviva Platani",
    "lat": "37.57174",
    "lng": "13.70156"
  },
  {
    "country": "IT",
    "name": "Acquaro",
    "lat": "38.55729",
    "lng": "16.18781"
  },
  {
    "country": "IT",
    "name": "Acquarica del Capo",
    "lat": "39.90979",
    "lng": "18.2468"
  },
  {
    "country": "IT",
    "name": "Acquappesa",
    "lat": "39.49573",
    "lng": "15.95419"
  },
  {
    "country": "IT",
    "name": "Acquaformosa",
    "lat": "39.72278",
    "lng": "16.09096"
  },
  {
    "country": "IT",
    "name": "Aci Sant'Antonio",
    "lat": "37.60499",
    "lng": "15.12294"
  },
  {
    "country": "IT",
    "name": "Acireale",
    "lat": "37.60886",
    "lng": "15.16577"
  },
  {
    "country": "IT",
    "name": "Aci Catena",
    "lat": "37.60614",
    "lng": "15.14165"
  },
  {
    "country": "IT",
    "name": "Aci Castello",
    "lat": "37.55564",
    "lng": "15.14535"
  },
  {
    "country": "IT",
    "name": "Aci Bonaccorsi",
    "lat": "37.5964",
    "lng": "15.10724"
  },
  {
    "country": "IT",
    "name": "Acate",
    "lat": "37.02318",
    "lng": "14.49302"
  },
  {
    "country": "IT",
    "name": "Olia Speciosa",
    "lat": "39.27806",
    "lng": "9.525"
  },
  {
    "country": "IT",
    "name": "Santa Maria Navarrese",
    "lat": "39.99029",
    "lng": "9.68398"
  },
  {
    "country": "IT",
    "name": "Cardedu",
    "lat": "39.79714",
    "lng": "9.62652"
  },
  {
    "country": "IT",
    "name": "Siurgus Donigala",
    "lat": "39.59961",
    "lng": "9.18746"
  },
  {
    "country": "IT",
    "name": "Volpago del Montello",
    "lat": "45.7777",
    "lng": "12.11857"
  },
  {
    "country": "IT",
    "name": "Granarolo dell'Emilia e Viadagola",
    "lat": "44.55327",
    "lng": "11.44291"
  },
  {
    "country": "IT",
    "name": "Zungoli",
    "lat": "41.12766",
    "lng": "15.20255"
  },
  {
    "country": "IT",
    "name": "Zuglio",
    "lat": "46.4583",
    "lng": "13.02589"
  },
  {
    "country": "IT",
    "name": "Zuccarello",
    "lat": "44.10973",
    "lng": "8.11814"
  },
  {
    "country": "IT",
    "name": "Zovencedo",
    "lat": "45.42893",
    "lng": "11.50387"
  },
  {
    "country": "IT",
    "name": "Zoppola",
    "lat": "45.96624",
    "lng": "12.76828"
  },
  {
    "country": "IT",
    "name": "Zollino",
    "lat": "40.20581",
    "lng": "18.24774"
  },
  {
    "country": "IT",
    "name": "Zolla",
    "lat": "45.71698",
    "lng": "13.81038"
  },
  {
    "country": "IT",
    "name": "Zola Predosa",
    "lat": "44.48967",
    "lng": "11.21831"
  },
  {
    "country": "IT",
    "name": "Zogno",
    "lat": "45.79378",
    "lng": "9.65992"
  },
  {
    "country": "IT",
    "name": "Zocca",
    "lat": "44.34566",
    "lng": "10.99308"
  },
  {
    "country": "IT",
    "name": "Zoagli",
    "lat": "44.33668",
    "lng": "9.2668"
  },
  {
    "country": "IT",
    "name": "Zinasco Vecchio",
    "lat": "45.12836",
    "lng": "9.02975"
  },
  {
    "country": "IT",
    "name": "Zimone",
    "lat": "45.44912",
    "lng": "8.03734"
  },
  {
    "country": "IT",
    "name": "Zibido San Giacomo",
    "lat": "45.36041",
    "lng": "9.11119"
  },
  {
    "country": "IT",
    "name": "Zibello",
    "lat": "45.01847",
    "lng": "10.12968"
  },
  {
    "country": "IT",
    "name": "Ziano Piacentino",
    "lat": "44.9998",
    "lng": "9.39486"
  },
  {
    "country": "IT",
    "name": "Ziano di Fiemme",
    "lat": "46.28572",
    "lng": "11.56496"
  },
  {
    "country": "IT",
    "name": "Panchià",
    "lat": "46.28648",
    "lng": "11.54061"
  },
  {
    "country": "IT",
    "name": "Zevio",
    "lat": "45.37209",
    "lng": "11.12929"
  },
  {
    "country": "IT",
    "name": "Zero Branco",
    "lat": "45.59952",
    "lng": "12.16381"
  },
  {
    "country": "IT",
    "name": "Zermeghedo",
    "lat": "45.47585",
    "lng": "11.37438"
  },
  {
    "country": "IT",
    "name": "Zerbolò",
    "lat": "45.20676",
    "lng": "9.01441"
  },
  {
    "country": "IT",
    "name": "Zerbo",
    "lat": "45.11046",
    "lng": "9.39606"
  },
  {
    "country": "IT",
    "name": "Zepponami",
    "lat": "42.52518",
    "lng": "12.05411"
  },
  {
    "country": "IT",
    "name": "Zenson di Piave",
    "lat": "45.67971",
    "lng": "12.48913"
  },
  {
    "country": "IT",
    "name": "Zeme",
    "lat": "45.19686",
    "lng": "8.66733"
  },
  {
    "country": "IT",
    "name": "Zelo Buon Persico",
    "lat": "45.4117",
    "lng": "9.43171"
  },
  {
    "country": "IT",
    "name": "Zelarino",
    "lat": "45.51508",
    "lng": "12.2079"
  },
  {
    "country": "IT",
    "name": "Zavattarello",
    "lat": "44.86766",
    "lng": "9.26662"
  },
  {
    "country": "IT",
    "name": "Zapponeta",
    "lat": "41.4571",
    "lng": "15.95615"
  },
  {
    "country": "IT",
    "name": "Zanica",
    "lat": "45.64088",
    "lng": "9.68566"
  },
  {
    "country": "IT",
    "name": "Zanè",
    "lat": "45.722",
    "lng": "11.44932"
  },
  {
    "country": "IT",
    "name": "Zandobbio",
    "lat": "45.68613",
    "lng": "9.85785"
  },
  {
    "country": "IT",
    "name": "Zambana",
    "lat": "46.1517",
    "lng": "11.09618"
  },
  {
    "country": "IT",
    "name": "Zagarolo",
    "lat": "41.84159",
    "lng": "12.8154"
  },
  {
    "country": "IT",
    "name": "Volvera",
    "lat": "44.95484",
    "lng": "7.51142"
  },
  {
    "country": "IT",
    "name": "Volturino",
    "lat": "41.47723",
    "lng": "15.12424"
  },
  {
    "country": "IT",
    "name": "Volturara Irpina",
    "lat": "40.88293",
    "lng": "14.91801"
  },
  {
    "country": "IT",
    "name": "Volturara Appula",
    "lat": "41.49603",
    "lng": "15.05224"
  },
  {
    "country": "IT",
    "name": "Voltido",
    "lat": "45.11197",
    "lng": "10.33298"
  },
  {
    "country": "IT",
    "name": "Volterra",
    "lat": "43.40251",
    "lng": "10.86152"
  },
  {
    "country": "IT",
    "name": "Voltana",
    "lat": "44.54109",
    "lng": "11.93533"
  },
  {
    "country": "IT",
    "name": "Volta Mantovana",
    "lat": "45.32192",
    "lng": "10.65891"
  },
  {
    "country": "IT",
    "name": "Voltago Agordino",
    "lat": "46.27139",
    "lng": "12.00574"
  },
  {
    "country": "IT",
    "name": "Voltaggio",
    "lat": "44.62095",
    "lng": "8.84274"
  },
  {
    "country": "IT",
    "name": "Volpiano",
    "lat": "45.1994",
    "lng": "7.77546"
  },
  {
    "country": "IT",
    "name": "Volpedo",
    "lat": "44.88887",
    "lng": "8.98615"
  },
  {
    "country": "IT",
    "name": "Volpara",
    "lat": "44.95379",
    "lng": "9.2975"
  },
  {
    "country": "IT",
    "name": "Volongo",
    "lat": "45.21155",
    "lng": "10.30242"
  },
  {
    "country": "IT",
    "name": "Volargne",
    "lat": "45.53684",
    "lng": "10.8182"
  },
  {
    "country": "IT",
    "name": "Volano",
    "lat": "45.91718",
    "lng": "11.06351"
  },
  {
    "country": "IT",
    "name": "Vogogna",
    "lat": "46.01002",
    "lng": "8.29137"
  },
  {
    "country": "IT",
    "name": "Voghera",
    "lat": "44.99151",
    "lng": "9.01175"
  },
  {
    "country": "IT",
    "name": "Vodo",
    "lat": "46.41921",
    "lng": "12.24557"
  },
  {
    "country": "IT",
    "name": "Vobbia",
    "lat": "44.60125",
    "lng": "9.03866"
  },
  {
    "country": "IT",
    "name": "Vobarno",
    "lat": "45.64153",
    "lng": "10.49866"
  },
  {
    "country": "IT",
    "name": "Vizzola Ticino",
    "lat": "45.62615",
    "lng": "8.69651"
  },
  {
    "country": "IT",
    "name": "Vivaro Romano",
    "lat": "42.10095",
    "lng": "13.00589"
  },
  {
    "country": "IT",
    "name": "Vivaro",
    "lat": "46.07656",
    "lng": "12.77912"
  },
  {
    "country": "IT",
    "name": "Viù",
    "lat": "45.23785",
    "lng": "7.37333"
  },
  {
    "country": "IT",
    "name": "Vitulazio",
    "lat": "41.16302",
    "lng": "14.21341"
  },
  {
    "country": "IT",
    "name": "Vitulano",
    "lat": "41.17419",
    "lng": "14.64821"
  },
  {
    "country": "IT",
    "name": "Vittuone",
    "lat": "45.48792",
    "lng": "8.95141"
  },
  {
    "country": "IT",
    "name": "Vittorito",
    "lat": "42.12703",
    "lng": "13.8167"
  },
  {
    "country": "IT",
    "name": "Vittorio Veneto",
    "lat": "45.98026",
    "lng": "12.30065"
  },
  {
    "country": "IT",
    "name": "Vitorchiano",
    "lat": "42.46565",
    "lng": "12.17151"
  },
  {
    "country": "IT",
    "name": "Vitigliano",
    "lat": "40.03951",
    "lng": "18.4117"
  },
  {
    "country": "IT",
    "name": "Viticuso",
    "lat": "41.52475",
    "lng": "13.97027"
  },
  {
    "country": "IT",
    "name": "Viterbo",
    "lat": "42.41937",
    "lng": "12.1056"
  },
  {
    "country": "IT",
    "name": "Vistrorio",
    "lat": "45.44147",
    "lng": "7.76781"
  },
  {
    "country": "IT",
    "name": "Visso",
    "lat": "42.93351",
    "lng": "13.08051"
  },
  {
    "country": "IT",
    "name": "Visciano",
    "lat": "40.9238",
    "lng": "14.58237"
  },
  {
    "country": "IT",
    "name": "Visano",
    "lat": "45.31684",
    "lng": "10.37092"
  },
  {
    "country": "IT",
    "name": "Virle Piemonte",
    "lat": "44.86369",
    "lng": "7.57033"
  },
  {
    "country": "IT",
    "name": "Vipiteno",
    "lat": "46.89313",
    "lng": "11.42961"
  },
  {
    "country": "IT",
    "name": "Vione",
    "lat": "46.24808",
    "lng": "10.44842"
  },
  {
    "country": "IT",
    "name": "Viola",
    "lat": "44.29081",
    "lng": "7.96491"
  },
  {
    "country": "IT",
    "name": "Vinzaglio",
    "lat": "45.32309",
    "lng": "8.51979"
  },
  {
    "country": "IT",
    "name": "Vinci",
    "lat": "43.78133",
    "lng": "10.92365"
  },
  {
    "country": "IT",
    "name": "Vinchiaturo",
    "lat": "41.49282",
    "lng": "14.592"
  },
  {
    "country": "IT",
    "name": "Vinadio",
    "lat": "44.30759",
    "lng": "7.17628"
  },
  {
    "country": "IT",
    "name": "Vimodrone",
    "lat": "45.51461",
    "lng": "9.28772"
  },
  {
    "country": "IT",
    "name": "Vimercate",
    "lat": "45.61545",
    "lng": "9.36801"
  },
  {
    "country": "IT",
    "name": "Villotta",
    "lat": "45.86336",
    "lng": "12.75418"
  },
  {
    "country": "IT",
    "name": "Lancenigo-Villorba",
    "lat": "45.71289",
    "lng": "12.25697"
  },
  {
    "country": "IT",
    "name": "Villongo",
    "lat": "45.66939",
    "lng": "9.93076"
  },
  {
    "country": "IT",
    "name": "Villimpenta",
    "lat": "45.14111",
    "lng": "11.0317"
  },
  {
    "country": "IT",
    "name": "Villetta Barrea",
    "lat": "41.77646",
    "lng": "13.93892"
  },
  {
    "country": "IT",
    "name": "Villesse",
    "lat": "45.86526",
    "lng": "13.4438"
  },
  {
    "country": "IT",
    "name": "Villefranche",
    "lat": "45.74064",
    "lng": "7.41598"
  },
  {
    "country": "IT",
    "name": "Villa Vicentina",
    "lat": "45.81378",
    "lng": "13.39332"
  },
  {
    "country": "IT",
    "name": "Villa Verucchio",
    "lat": "44.0051",
    "lng": "12.43575"
  },
  {
    "country": "IT",
    "name": "Villaverla",
    "lat": "45.64939",
    "lng": "11.49176"
  },
  {
    "country": "IT",
    "name": "Vergano-Villa",
    "lat": "45.79416",
    "lng": "9.3746"
  },
  {
    "country": "IT",
    "name": "Villavallelonga",
    "lat": "41.87104",
    "lng": "13.62088"
  },
  {
    "country": "IT",
    "name": "Villata",
    "lat": "45.3865",
    "lng": "8.43279"
  },
  {
    "country": "IT",
    "name": "Villastellone",
    "lat": "44.92201",
    "lng": "7.7436"
  },
  {
    "country": "IT",
    "name": "Villa Santo Stefano",
    "lat": "41.51683",
    "lng": "13.31046"
  },
  {
    "country": "IT",
    "name": "Villa Santina",
    "lat": "46.41368",
    "lng": "12.92445"
  },
  {
    "country": "IT",
    "name": "Villa Santa Maria",
    "lat": "41.9513",
    "lng": "14.35148"
  },
  {
    "country": "IT",
    "name": "Villa Santa Lucia degli Abruzzi",
    "lat": "42.33286",
    "lng": "13.77792"
  },
  {
    "country": "IT",
    "name": "Villa Santa Lucia",
    "lat": "41.51217",
    "lng": "13.76929"
  },
  {
    "country": "IT",
    "name": "Villasanta",
    "lat": "45.60634",
    "lng": "9.30797"
  },
  {
    "country": "IT",
    "name": "Villa San Secondo",
    "lat": "45.00513",
    "lng": "8.13462"
  },
  {
    "country": "IT",
    "name": "Villar Perosa",
    "lat": "44.91849",
    "lng": "7.24821"
  },
  {
    "country": "IT",
    "name": "Villar Pellice",
    "lat": "44.80893",
    "lng": "7.15978"
  },
  {
    "country": "IT",
    "name": "Villarotta",
    "lat": "44.92517",
    "lng": "10.74382"
  },
  {
    "country": "IT",
    "name": "Villaricca",
    "lat": "40.92006",
    "lng": "14.19339"
  },
  {
    "country": "IT",
    "name": "Villar Focchiardo",
    "lat": "45.11244",
    "lng": "7.23841"
  },
  {
    "country": "IT",
    "name": "Villareggia",
    "lat": "45.30885",
    "lng": "7.97724"
  },
  {
    "country": "IT",
    "name": "Villarboit",
    "lat": "45.43775",
    "lng": "8.33694"
  },
  {
    "country": "IT",
    "name": "Villa Potenza",
    "lat": "43.32149",
    "lng": "13.42649"
  },
  {
    "country": "IT",
    "name": "Villa Pedergnano",
    "lat": "45.58528",
    "lng": "9.99381"
  },
  {
    "country": "IT",
    "name": "Villanuova sul Clisi",
    "lat": "45.59938",
    "lng": "10.45275"
  },
  {
    "country": "IT",
    "name": "Villanterio",
    "lat": "45.2178",
    "lng": "9.361"
  },
  {
    "country": "IT",
    "name": "Villanova",
    "lat": "45.02597",
    "lng": "9.99865"
  },
  {
    "country": "IT",
    "name": "Villanova Monteleone",
    "lat": "40.50264",
    "lng": "8.47115"
  },
  {
    "country": "IT",
    "name": "Villanova Monferrato",
    "lat": "45.18111",
    "lng": "8.47813"
  },
  {
    "country": "IT",
    "name": "Villanova Mondovì",
    "lat": "44.34804",
    "lng": "7.76752"
  },
  {
    "country": "IT",
    "name": "Villanova Marchesana",
    "lat": "44.99231",
    "lng": "11.96675"
  },
  {
    "country": "IT",
    "name": "Villanova del Battista",
    "lat": "41.11897",
    "lng": "15.15839"
  },
  {
    "country": "IT",
    "name": "Villanova d'Asti",
    "lat": "44.94299",
    "lng": "7.93671"
  },
  {
    "country": "IT",
    "name": "Villanova d'Ardenghi",
    "lat": "45.17049",
    "lng": "9.04078"
  },
  {
    "country": "IT",
    "name": "Villanova d'Albenga",
    "lat": "44.04725",
    "lng": "8.14336"
  },
  {
    "country": "IT",
    "name": "Villanova",
    "lat": "46.13226",
    "lng": "12.97084"
  },
  {
    "country": "IT",
    "name": "Villanova",
    "lat": "44.49995",
    "lng": "11.43109"
  },
  {
    "country": "IT",
    "name": "Villanova",
    "lat": "44.448",
    "lng": "12.05007"
  },
  {
    "country": "IT",
    "name": "Villammare",
    "lat": "40.07747",
    "lng": "15.59401"
  },
  {
    "country": "IT",
    "name": "Villa Minozzo",
    "lat": "44.3648",
    "lng": "10.46545"
  },
  {
    "country": "IT",
    "name": "Villamarzana",
    "lat": "45.01457",
    "lng": "11.69225"
  },
  {
    "country": "IT",
    "name": "Villamaina",
    "lat": "40.97144",
    "lng": "15.08855"
  },
  {
    "country": "IT",
    "name": "Villamagna",
    "lat": "42.32984",
    "lng": "14.23689"
  },
  {
    "country": "IT",
    "name": "Villalvernia",
    "lat": "44.81387",
    "lng": "8.85532"
  },
  {
    "country": "IT",
    "name": "Villa Literno",
    "lat": "41.00942",
    "lng": "14.07612"
  },
  {
    "country": "IT",
    "name": "Villalfonsina",
    "lat": "42.16038",
    "lng": "14.56932"
  },
  {
    "country": "IT",
    "name": "Villa Latina",
    "lat": "41.61522",
    "lng": "13.83591"
  },
  {
    "country": "IT",
    "name": "Villalago",
    "lat": "41.93514",
    "lng": "13.83868"
  },
  {
    "country": "IT",
    "name": "Villa Lagarina",
    "lat": "45.91843",
    "lng": "11.03303"
  },
  {
    "country": "IT",
    "name": "Villa Guardia",
    "lat": "45.77505",
    "lng": "9.02321"
  },
  {
    "country": "IT",
    "name": "Villaganzerla",
    "lat": "45.43612",
    "lng": "11.61859"
  },
  {
    "country": "IT",
    "name": "Villaga",
    "lat": "45.40273",
    "lng": "11.53468"
  },
  {
    "country": "IT",
    "name": "Villafranca Piemonte",
    "lat": "44.78824",
    "lng": "7.50788"
  },
  {
    "country": "IT",
    "name": "Villafranca in Lunigiana",
    "lat": "44.29844",
    "lng": "9.95347"
  },
  {
    "country": "IT",
    "name": "Villafranca di Verona",
    "lat": "45.35405",
    "lng": "10.84462"
  },
  {
    "country": "IT",
    "name": "Villafranca d'Asti",
    "lat": "44.91539",
    "lng": "8.02658"
  },
  {
    "country": "IT",
    "name": "Villa Faraldi",
    "lat": "43.96843",
    "lng": "8.08965"
  },
  {
    "country": "IT",
    "name": "Villafalletto",
    "lat": "44.54624",
    "lng": "7.54069"
  },
  {
    "country": "IT",
    "name": "Villa Estense",
    "lat": "45.17465",
    "lng": "11.67022"
  },
  {
    "country": "IT",
    "name": "Villadossola",
    "lat": "46.0708",
    "lng": "8.26709"
  },
  {
    "country": "IT",
    "name": "Villadose",
    "lat": "45.07219",
    "lng": "11.89899"
  },
  {
    "country": "IT",
    "name": "Villa",
    "lat": "46.2039",
    "lng": "10.13385"
  },
  {
    "country": "IT",
    "name": "Villa di Serio",
    "lat": "45.7226",
    "lng": "9.73522"
  },
  {
    "country": "IT",
    "name": "Villa di Chiavenna",
    "lat": "46.33069",
    "lng": "9.48114"
  },
  {
    "country": "IT",
    "name": "Villa del Conte",
    "lat": "45.58475",
    "lng": "11.85942"
  },
  {
    "country": "IT",
    "name": "Villa del Bosco",
    "lat": "45.61669",
    "lng": "8.27776"
  },
  {
    "country": "IT",
    "name": "Villa d'Almè",
    "lat": "45.74843",
    "lng": "9.61702"
  },
  {
    "country": "IT",
    "name": "Villa Cortese",
    "lat": "45.56666",
    "lng": "8.88712"
  },
  {
    "country": "IT",
    "name": "Villachiara",
    "lat": "45.35445",
    "lng": "9.93081"
  },
  {
    "country": "IT",
    "name": "Villa Celiera",
    "lat": "42.38184",
    "lng": "13.8586"
  },
  {
    "country": "IT",
    "name": "Villa Castelli",
    "lat": "40.58293",
    "lng": "17.47468"
  },
  {
    "country": "IT",
    "name": "Villa Caldari",
    "lat": "42.29566",
    "lng": "14.36157"
  },
  {
    "country": "IT",
    "name": "Villabruna-Umin",
    "lat": "46.05675",
    "lng": "11.927"
  },
  {
    "country": "IT",
    "name": "Villabassa",
    "lat": "46.73781",
    "lng": "12.17266"
  },
  {
    "country": "IT",
    "name": "Villa Basilica",
    "lat": "43.92572",
    "lng": "10.64518"
  },
  {
    "country": "IT",
    "name": "Villa Bartolomea",
    "lat": "45.15461",
    "lng": "11.3538"
  },
  {
    "country": "IT",
    "name": "Villa",
    "lat": "45.71824",
    "lng": "10.27906"
  },
  {
    "country": "IT",
    "name": "Villa Carcina",
    "lat": "45.63329",
    "lng": "10.19556"
  },
  {
    "country": "IT",
    "name": "Viguzzolo",
    "lat": "44.90567",
    "lng": "8.91968"
  },
  {
    "country": "IT",
    "name": "Vigonza",
    "lat": "45.43484",
    "lng": "11.97465"
  },
  {
    "country": "IT",
    "name": "Vigonovo-Fontanafredda",
    "lat": "45.98927",
    "lng": "12.54707"
  },
  {
    "country": "IT",
    "name": "Vigonovo",
    "lat": "45.38691",
    "lng": "12.00642"
  },
  {
    "country": "IT",
    "name": "Vigone",
    "lat": "44.84236",
    "lng": "7.49774"
  },
  {
    "country": "IT",
    "name": "Vigolzone",
    "lat": "44.91394",
    "lng": "9.66852"
  },
  {
    "country": "IT",
    "name": "Vigolo Vattaro",
    "lat": "46.00523",
    "lng": "11.1979"
  },
  {
    "country": "IT",
    "name": "Vigolo",
    "lat": "45.71642",
    "lng": "10.02634"
  },
  {
    "country": "IT",
    "name": "Vigo di Fassa",
    "lat": "46.41898",
    "lng": "11.67418"
  },
  {
    "country": "IT",
    "name": "Vigo di Cadore",
    "lat": "46.49904",
    "lng": "12.47111"
  },
  {
    "country": "IT",
    "name": "Vigodarzere",
    "lat": "45.45751",
    "lng": "11.88555"
  },
  {
    "country": "IT",
    "name": "Vignolo",
    "lat": "44.36364",
    "lng": "7.47208"
  },
  {
    "country": "IT",
    "name": "Vignola",
    "lat": "46.04436",
    "lng": "11.27738"
  },
  {
    "country": "IT",
    "name": "Vignola",
    "lat": "44.48383",
    "lng": "11.01096"
  },
  {
    "country": "IT",
    "name": "Vignate",
    "lat": "45.49939",
    "lng": "9.37719"
  },
  {
    "country": "IT",
    "name": "Vignanello",
    "lat": "42.37879",
    "lng": "12.27845"
  },
  {
    "country": "IT",
    "name": "Vignale Monferrato",
    "lat": "45.00996",
    "lng": "8.39703"
  },
  {
    "country": "IT",
    "name": "Vignacastrisi",
    "lat": "40.01604",
    "lng": "18.40704"
  },
  {
    "country": "IT",
    "name": "Vigliano Biellese",
    "lat": "45.56317",
    "lng": "8.10509"
  },
  {
    "country": "IT",
    "name": "Viggiù",
    "lat": "45.87096",
    "lng": "8.90861"
  },
  {
    "country": "IT",
    "name": "Viggiano",
    "lat": "40.34213",
    "lng": "15.89964"
  },
  {
    "country": "IT",
    "name": "Vigevano",
    "lat": "45.31407",
    "lng": "8.85437"
  },
  {
    "country": "IT",
    "name": "Vigatto",
    "lat": "44.71999",
    "lng": "10.33037"
  },
  {
    "country": "IT",
    "name": "Vigasio",
    "lat": "45.3178",
    "lng": "10.94371"
  },
  {
    "country": "IT",
    "name": "Vigarano Pieve",
    "lat": "44.86126",
    "lng": "11.5095"
  },
  {
    "country": "IT",
    "name": "Vigarano Mainarda",
    "lat": "44.84079",
    "lng": "11.49354"
  },
  {
    "country": "IT",
    "name": "Vietri sul Mare",
    "lat": "40.6702",
    "lng": "14.72661"
  },
  {
    "country": "IT",
    "name": "Vietri di Potenza",
    "lat": "40.60027",
    "lng": "15.50787"
  },
  {
    "country": "IT",
    "name": "Vieste",
    "lat": "41.88209",
    "lng": "16.17139"
  },
  {
    "country": "IT",
    "name": "Vidor",
    "lat": "45.86659",
    "lng": "12.04517"
  },
  {
    "country": "IT",
    "name": "Vidigulfo",
    "lat": "45.29245",
    "lng": "9.23498"
  },
  {
    "country": "IT",
    "name": "Vicovaro",
    "lat": "42.01924",
    "lng": "12.90001"
  },
  {
    "country": "IT",
    "name": "Vicopisano",
    "lat": "43.69305",
    "lng": "10.58359"
  },
  {
    "country": "IT",
    "name": "Vico nel Lazio",
    "lat": "41.77822",
    "lng": "13.34279"
  },
  {
    "country": "IT",
    "name": "Vicomoscano",
    "lat": "44.97476",
    "lng": "10.45045"
  },
  {
    "country": "IT",
    "name": "Vicolungo",
    "lat": "45.47522",
    "lng": "8.46124"
  },
  {
    "country": "IT",
    "name": "Vicoli",
    "lat": "42.34095",
    "lng": "13.89688"
  },
  {
    "country": "IT",
    "name": "Vicofertile",
    "lat": "44.78557",
    "lng": "10.262"
  },
  {
    "country": "IT",
    "name": "Vico Equense",
    "lat": "40.65977",
    "lng": "14.43386"
  },
  {
    "country": "IT",
    "name": "Vico del Gargano",
    "lat": "41.89661",
    "lng": "15.95682"
  },
  {
    "country": "IT",
    "name": "Vico Canavese",
    "lat": "45.49342",
    "lng": "7.77887"
  },
  {
    "country": "IT",
    "name": "Viciomaggio",
    "lat": "43.43218",
    "lng": "11.77323"
  },
  {
    "country": "IT",
    "name": "Vicenza",
    "lat": "45.54672",
    "lng": "11.5475"
  },
  {
    "country": "IT",
    "name": "Vicchio",
    "lat": "43.93413",
    "lng": "11.46004"
  },
  {
    "country": "IT",
    "name": "Vicarello",
    "lat": "43.61238",
    "lng": "10.46515"
  },
  {
    "country": "IT",
    "name": "Vicalvi",
    "lat": "41.67809",
    "lng": "13.70813"
  },
  {
    "country": "IT",
    "name": "Vibonati",
    "lat": "40.09921",
    "lng": "15.58357"
  },
  {
    "country": "IT",
    "name": "Viareggio",
    "lat": "43.86693",
    "lng": "10.2502"
  },
  {
    "country": "IT",
    "name": "Viano",
    "lat": "44.54516",
    "lng": "10.62435"
  },
  {
    "country": "IT",
    "name": "Viadana",
    "lat": "44.93553",
    "lng": "10.51898"
  },
  {
    "country": "IT",
    "name": "Vezzano sul Crostolo",
    "lat": "44.60241",
    "lng": "10.54469"
  },
  {
    "country": "IT",
    "name": "Vezzano Ligure",
    "lat": "44.14144",
    "lng": "9.88692"
  },
  {
    "country": "IT",
    "name": "Vezzano",
    "lat": "46.07867",
    "lng": "10.99735"
  },
  {
    "country": "IT",
    "name": "Vezza d'Oglio",
    "lat": "46.23867",
    "lng": "10.39825"
  },
  {
    "country": "IT",
    "name": "Vetto",
    "lat": "44.48407",
    "lng": "10.33882"
  },
  {
    "country": "IT",
    "name": "Vetralla",
    "lat": "42.31787",
    "lng": "12.07323"
  },
  {
    "country": "IT",
    "name": "Vestone",
    "lat": "45.70783",
    "lng": "10.39611"
  },
  {
    "country": "IT",
    "name": "Vestignè",
    "lat": "45.38655",
    "lng": "7.95336"
  },
  {
    "country": "IT",
    "name": "Vestenanova",
    "lat": "45.57421",
    "lng": "11.22868"
  },
  {
    "country": "IT",
    "name": "Vessalico",
    "lat": "44.04559",
    "lng": "7.96013"
  },
  {
    "country": "IT",
    "name": "Vespolate",
    "lat": "45.34953",
    "lng": "8.66878"
  },
  {
    "country": "IT",
    "name": "Vesime",
    "lat": "44.63535",
    "lng": "8.22683"
  },
  {
    "country": "IT",
    "name": "Vescovato",
    "lat": "45.17419",
    "lng": "10.16451"
  },
  {
    "country": "IT",
    "name": "Vescovana",
    "lat": "45.13422",
    "lng": "11.71261"
  },
  {
    "country": "IT",
    "name": "Verzuolo",
    "lat": "44.59279",
    "lng": "7.48164"
  },
  {
    "country": "IT",
    "name": "Vervò",
    "lat": "46.30989",
    "lng": "11.11972"
  },
  {
    "country": "IT",
    "name": "Verucchio",
    "lat": "43.98171",
    "lng": "12.42317"
  },
  {
    "country": "IT",
    "name": "Vertova",
    "lat": "45.81",
    "lng": "9.84944"
  },
  {
    "country": "IT",
    "name": "Vertemate Con Minoprio",
    "lat": "45.72518",
    "lng": "9.073"
  },
  {
    "country": "IT",
    "name": "Verrone",
    "lat": "45.50824",
    "lng": "8.11514"
  },
  {
    "country": "IT",
    "name": "Verres",
    "lat": "45.66656",
    "lng": "7.68911"
  },
  {
    "country": "IT",
    "name": "Veronella",
    "lat": "45.32378",
    "lng": "11.32582"
  },
  {
    "country": "IT",
    "name": "Verona",
    "lat": "45.4299",
    "lng": "10.98444"
  },
  {
    "country": "IT",
    "name": "Veroli",
    "lat": "41.69433",
    "lng": "13.41664"
  },
  {
    "country": "IT",
    "name": "Verolengo",
    "lat": "45.1904",
    "lng": "7.97126"
  },
  {
    "country": "IT",
    "name": "Verolavecchia",
    "lat": "45.32862",
    "lng": "10.05493"
  },
  {
    "country": "IT",
    "name": "Verolanuova",
    "lat": "45.32834",
    "lng": "10.07857"
  },
  {
    "country": "IT",
    "name": "Vernole",
    "lat": "40.28834",
    "lng": "18.30165"
  },
  {
    "country": "IT",
    "name": "Vernio",
    "lat": "44.04755",
    "lng": "11.15052"
  },
  {
    "country": "IT",
    "name": "Vernazza",
    "lat": "44.13501",
    "lng": "9.68346"
  },
  {
    "country": "IT",
    "name": "Vernate",
    "lat": "45.31589",
    "lng": "9.06045"
  },
  {
    "country": "IT",
    "name": "Vernasca",
    "lat": "44.79867",
    "lng": "9.83054"
  },
  {
    "country": "IT",
    "name": "Vernante",
    "lat": "44.24447",
    "lng": "7.53455"
  },
  {
    "country": "IT",
    "name": "Vermiglio",
    "lat": "46.29691",
    "lng": "10.69136"
  },
  {
    "country": "IT",
    "name": "Vermezzo",
    "lat": "45.39627",
    "lng": "8.97904"
  },
  {
    "country": "IT",
    "name": "Vergiate",
    "lat": "45.7221",
    "lng": "8.6953"
  },
  {
    "country": "IT",
    "name": "Verghereto",
    "lat": "43.7945",
    "lng": "12.0052"
  },
  {
    "country": "IT",
    "name": "Vergato",
    "lat": "44.28232",
    "lng": "11.10953"
  },
  {
    "country": "IT",
    "name": "Verdello",
    "lat": "45.60372",
    "lng": "9.62852"
  },
  {
    "country": "IT",
    "name": "Vercurago",
    "lat": "45.80943",
    "lng": "9.42211"
  },
  {
    "country": "IT",
    "name": "Vercelli",
    "lat": "45.32163",
    "lng": "8.41989"
  },
  {
    "country": "IT",
    "name": "Verceia",
    "lat": "46.19869",
    "lng": "9.45474"
  },
  {
    "country": "IT",
    "name": "Venzone",
    "lat": "46.33031",
    "lng": "13.13825"
  },
  {
    "country": "IT",
    "name": "Venturina",
    "lat": "43.02883",
    "lng": "10.60147"
  },
  {
    "country": "IT",
    "name": "Ventotene",
    "lat": "40.79404",
    "lng": "13.42777"
  },
  {
    "country": "IT",
    "name": "Ventoso",
    "lat": "44.58621",
    "lng": "10.68767"
  },
  {
    "country": "IT",
    "name": "Ventimiglia",
    "lat": "43.78956",
    "lng": "7.60872"
  },
  {
    "country": "IT",
    "name": "Venosa",
    "lat": "40.96283",
    "lng": "15.81285"
  },
  {
    "country": "IT",
    "name": "Venice",
    "lat": "45.43713",
    "lng": "12.33265"
  },
  {
    "country": "IT",
    "name": "Venegono Superiore",
    "lat": "45.75246",
    "lng": "8.89734"
  },
  {
    "country": "IT",
    "name": "Venegono Inferiore",
    "lat": "45.73569",
    "lng": "8.89545"
  },
  {
    "country": "IT",
    "name": "Venasca",
    "lat": "44.56134",
    "lng": "7.39698"
  },
  {
    "country": "IT",
    "name": "Venarotta",
    "lat": "42.88266",
    "lng": "13.49157"
  },
  {
    "country": "IT",
    "name": "Venaria Reale",
    "lat": "45.12597",
    "lng": "7.63136"
  },
  {
    "country": "IT",
    "name": "Venaus",
    "lat": "45.1571",
    "lng": "7.0107"
  },
  {
    "country": "IT",
    "name": "Venafro",
    "lat": "41.48275",
    "lng": "14.04773"
  },
  {
    "country": "IT",
    "name": "Velturno",
    "lat": "46.66705",
    "lng": "11.59712"
  },
  {
    "country": "IT",
    "name": "Vellezzo Bellini",
    "lat": "45.26948",
    "lng": "9.10088"
  },
  {
    "country": "IT",
    "name": "Velletri",
    "lat": "41.68573",
    "lng": "12.77753"
  },
  {
    "country": "IT",
    "name": "Veleso",
    "lat": "45.90875",
    "lng": "9.1809"
  },
  {
    "country": "IT",
    "name": "Vejano",
    "lat": "42.21905",
    "lng": "12.09398"
  },
  {
    "country": "IT",
    "name": "Veglie",
    "lat": "40.33474",
    "lng": "17.96238"
  },
  {
    "country": "IT",
    "name": "Veggiano",
    "lat": "45.44719",
    "lng": "11.7128"
  },
  {
    "country": "IT",
    "name": "Vedeseta",
    "lat": "45.89102",
    "lng": "9.53927"
  },
  {
    "country": "IT",
    "name": "Vedelago",
    "lat": "45.68722",
    "lng": "12.01853"
  },
  {
    "country": "IT",
    "name": "Vedano Olona",
    "lat": "45.7757",
    "lng": "8.88771"
  },
  {
    "country": "IT",
    "name": "Vecchiano-Nodica",
    "lat": "43.78334",
    "lng": "10.3844"
  },
  {
    "country": "IT",
    "name": "Vazzola",
    "lat": "45.83511",
    "lng": "12.40851"
  },
  {
    "country": "IT",
    "name": "Vattaro",
    "lat": "45.99388",
    "lng": "11.21792"
  },
  {
    "country": "IT",
    "name": "Vastogirardi",
    "lat": "41.7746",
    "lng": "14.25844"
  },
  {
    "country": "IT",
    "name": "Vasto",
    "lat": "42.1115",
    "lng": "14.70649"
  },
  {
    "country": "IT",
    "name": "Vasia",
    "lat": "43.93268",
    "lng": "7.95389"
  },
  {
    "country": "IT",
    "name": "Vasanello",
    "lat": "42.41507",
    "lng": "12.34767"
  },
  {
    "country": "IT",
    "name": "Vas",
    "lat": "45.93804",
    "lng": "11.93579"
  },
  {
    "country": "IT",
    "name": "Varzo",
    "lat": "46.20736",
    "lng": "8.25267"
  },
  {
    "country": "IT",
    "name": "Varzi",
    "lat": "44.82297",
    "lng": "9.19762"
  },
  {
    "country": "IT",
    "name": "Varsi",
    "lat": "44.66274",
    "lng": "9.84879"
  },
  {
    "country": "IT",
    "name": "Varna",
    "lat": "46.73901",
    "lng": "11.63749"
  },
  {
    "country": "IT",
    "name": "Varmo",
    "lat": "45.8863",
    "lng": "12.99005"
  },
  {
    "country": "IT",
    "name": "Varese Ligure",
    "lat": "44.37687",
    "lng": "9.59372"
  },
  {
    "country": "IT",
    "name": "Varese",
    "lat": "45.82058",
    "lng": "8.82511"
  },
  {
    "country": "IT",
    "name": "Varenna",
    "lat": "46.01078",
    "lng": "9.28465"
  },
  {
    "country": "IT",
    "name": "Varedo",
    "lat": "45.59761",
    "lng": "9.16323"
  },
  {
    "country": "IT",
    "name": "Varco Sabino",
    "lat": "42.24016",
    "lng": "13.02052"
  },
  {
    "country": "IT",
    "name": "Varazze",
    "lat": "44.36412",
    "lng": "8.5963"
  },
  {
    "country": "IT",
    "name": "Varano De' Melegari",
    "lat": "44.68806",
    "lng": "10.01148"
  },
  {
    "country": "IT",
    "name": "Varallo Pombia",
    "lat": "45.66784",
    "lng": "8.6285"
  },
  {
    "country": "IT",
    "name": "Varallo",
    "lat": "45.81383",
    "lng": "8.25814"
  },
  {
    "country": "IT",
    "name": "Varago",
    "lat": "45.73726",
    "lng": "12.31083"
  },
  {
    "country": "IT",
    "name": "Vaprio D'Agogna",
    "lat": "45.60322",
    "lng": "8.55402"
  },
  {
    "country": "IT",
    "name": "Vaprio d'Adda",
    "lat": "45.5764",
    "lng": "9.52407"
  },
  {
    "country": "IT",
    "name": "Vanzone",
    "lat": "45.97785",
    "lng": "8.10826"
  },
  {
    "country": "IT",
    "name": "Vanzago",
    "lat": "45.52566",
    "lng": "8.99097"
  },
  {
    "country": "IT",
    "name": "Vanzaghello",
    "lat": "45.57964",
    "lng": "8.78234"
  },
  {
    "country": "IT",
    "name": "Vandoies di Sotto",
    "lat": "46.816",
    "lng": "11.72183"
  },
  {
    "country": "IT",
    "name": "Valvasone",
    "lat": "45.99331",
    "lng": "12.86659"
  },
  {
    "country": "IT",
    "name": "Valva",
    "lat": "40.73871",
    "lng": "15.26805"
  },
  {
    "country": "IT",
    "name": "Valtorta",
    "lat": "45.97685",
    "lng": "9.53478"
  },
  {
    "country": "IT",
    "name": "Valstagna",
    "lat": "45.85108",
    "lng": "11.66642"
  },
  {
    "country": "IT",
    "name": "Valsinni",
    "lat": "40.17098",
    "lng": "16.44388"
  },
  {
    "country": "IT",
    "name": "Valprato Soana",
    "lat": "45.52166",
    "lng": "7.54948"
  },
  {
    "country": "IT",
    "name": "Valperga",
    "lat": "45.37004",
    "lng": "7.66124"
  },
  {
    "country": "IT",
    "name": "Valpelline",
    "lat": "45.82486",
    "lng": "7.3255"
  },
  {
    "country": "IT",
    "name": "Valnegra",
    "lat": "45.94909",
    "lng": "9.68935"
  },
  {
    "country": "IT",
    "name": "Valmontone",
    "lat": "41.77323",
    "lng": "12.91856"
  },
  {
    "country": "IT",
    "name": "Valmadrera-Caserta",
    "lat": "45.84628",
    "lng": "9.35824"
  },
  {
    "country": "IT",
    "name": "Valmacca",
    "lat": "45.10101",
    "lng": "8.58382"
  },
  {
    "country": "IT",
    "name": "Vallo della Lucania",
    "lat": "40.22786",
    "lng": "15.26635"
  },
  {
    "country": "IT",
    "name": "Vallinfreda",
    "lat": "42.08485",
    "lng": "12.99595"
  },
  {
    "country": "IT",
    "name": "Valli del Pasubio",
    "lat": "45.7403",
    "lng": "11.26354"
  },
  {
    "country": "IT",
    "name": "Vallese",
    "lat": "45.32827",
    "lng": "11.08608"
  },
  {
    "country": "IT",
    "name": "Valle San Nicolao",
    "lat": "45.60706",
    "lng": "8.14102"
  },
  {
    "country": "IT",
    "name": "Vallerotonda",
    "lat": "41.55135",
    "lng": "13.91372"
  },
  {
    "country": "IT",
    "name": "Vallerano",
    "lat": "42.38331",
    "lng": "12.26144"
  },
  {
    "country": "IT",
    "name": "Vallepietra",
    "lat": "41.92552",
    "lng": "13.23127"
  },
  {
    "country": "IT",
    "name": "Valle Mosso",
    "lat": "45.63069",
    "lng": "8.14764"
  },
  {
    "country": "IT",
    "name": "Vallemaio",
    "lat": "41.36628",
    "lng": "13.80839"
  },
  {
    "country": "IT",
    "name": "Valle Lomellina",
    "lat": "45.15096",
    "lng": "8.66957"
  },
  {
    "country": "IT",
    "name": "Valle di Maddaloni",
    "lat": "41.07946",
    "lng": "14.41788"
  },
  {
    "country": "IT",
    "name": "Valle dell'Angelo",
    "lat": "40.34381",
    "lng": "15.36846"
  },
  {
    "country": "IT",
    "name": "Vallecupa",
    "lat": "42.25366",
    "lng": "13.57467"
  },
  {
    "country": "IT",
    "name": "Vallecrosia",
    "lat": "43.78671",
    "lng": "7.63902"
  },
  {
    "country": "IT",
    "name": "Vallecorsa",
    "lat": "41.44351",
    "lng": "13.40634"
  },
  {
    "country": "IT",
    "name": "Valle Castellana",
    "lat": "42.73614",
    "lng": "13.49709"
  },
  {
    "country": "IT",
    "name": "Vallebona",
    "lat": "43.8122",
    "lng": "7.66535"
  },
  {
    "country": "IT",
    "name": "Valle Agricola",
    "lat": "41.42477",
    "lng": "14.25584"
  },
  {
    "country": "IT",
    "name": "Vallata",
    "lat": "41.04019",
    "lng": "15.25383"
  },
  {
    "country": "IT",
    "name": "Vall'Alta",
    "lat": "45.76116",
    "lng": "9.8264"
  },
  {
    "country": "IT",
    "name": "Vallà",
    "lat": "45.70711",
    "lng": "11.93271"
  },
  {
    "country": "IT",
    "name": "Valgrana",
    "lat": "44.41181",
    "lng": "7.38068"
  },
  {
    "country": "IT",
    "name": "Valgioie",
    "lat": "45.064",
    "lng": "7.34927"
  },
  {
    "country": "IT",
    "name": "Valganna",
    "lat": "45.90228",
    "lng": "8.82333"
  },
  {
    "country": "IT",
    "name": "San Nicolò",
    "lat": "46.46299",
    "lng": "10.40998"
  },
  {
    "country": "IT",
    "name": "Valfenera",
    "lat": "44.90175",
    "lng": "7.96433"
  },
  {
    "country": "IT",
    "name": "Valfabbrica",
    "lat": "43.15784",
    "lng": "12.60202"
  },
  {
    "country": "IT",
    "name": "Valenzano",
    "lat": "41.04376",
    "lng": "16.88491"
  },
  {
    "country": "IT",
    "name": "Valenza",
    "lat": "45.01242",
    "lng": "8.64379"
  },
  {
    "country": "IT",
    "name": "Valentano",
    "lat": "42.56377",
    "lng": "11.82748"
  },
  {
    "country": "IT",
    "name": "Valeggio sul Mincio",
    "lat": "45.35333",
    "lng": "10.73635"
  },
  {
    "country": "IT",
    "name": "Valeggio",
    "lat": "45.15065",
    "lng": "8.86132"
  },
  {
    "country": "IT",
    "name": "Valduggia",
    "lat": "45.72722",
    "lng": "8.3273"
  },
  {
    "country": "IT",
    "name": "Valdottavo",
    "lat": "43.94187",
    "lng": "10.48115"
  },
  {
    "country": "IT",
    "name": "Valdobbiadene",
    "lat": "45.89689",
    "lng": "11.98245"
  },
  {
    "country": "IT",
    "name": "Valdieri",
    "lat": "44.27763",
    "lng": "7.39763"
  },
  {
    "country": "IT",
    "name": "Valdaora di Mezzo",
    "lat": "46.76027",
    "lng": "12.02951"
  },
  {
    "country": "IT",
    "name": "Valdagno",
    "lat": "45.64498",
    "lng": "11.29886"
  },
  {
    "country": "IT",
    "name": "Bondione",
    "lat": "46.03541",
    "lng": "10.00832"
  },
  {
    "country": "IT",
    "name": "Vairano-Patenora",
    "lat": "41.33702",
    "lng": "14.13112"
  },
  {
    "country": "IT",
    "name": "Vajont",
    "lat": "46.14534",
    "lng": "12.69647"
  },
  {
    "country": "IT",
    "name": "Vailate",
    "lat": "45.46231",
    "lng": "9.60326"
  },
  {
    "country": "IT",
    "name": "Vaiano Cremasco",
    "lat": "45.37133",
    "lng": "9.58793"
  },
  {
    "country": "IT",
    "name": "Vaiano",
    "lat": "43.96792",
    "lng": "11.12374"
  },
  {
    "country": "IT",
    "name": "Vaglio Basilicata",
    "lat": "40.66643",
    "lng": "15.91434"
  },
  {
    "country": "IT",
    "name": "Vaglia",
    "lat": "43.9107",
    "lng": "11.27997"
  },
  {
    "country": "IT",
    "name": "Vado Ligure",
    "lat": "44.26913",
    "lng": "8.43375"
  },
  {
    "country": "IT",
    "name": "Vado",
    "lat": "44.31689",
    "lng": "11.25851"
  },
  {
    "country": "IT",
    "name": "Vadena",
    "lat": "46.41361",
    "lng": "11.30498"
  },
  {
    "country": "IT",
    "name": "Vada",
    "lat": "43.35264",
    "lng": "10.45564"
  },
  {
    "country": "IT",
    "name": "Vacri",
    "lat": "42.29764",
    "lng": "14.22901"
  },
  {
    "country": "IT",
    "name": "Vacone",
    "lat": "42.381",
    "lng": "12.64504"
  },
  {
    "country": "IT",
    "name": "Uzzano",
    "lat": "43.89728",
    "lng": "10.70403"
  },
  {
    "country": "IT",
    "name": "Usseglio",
    "lat": "45.23274",
    "lng": "7.21993"
  },
  {
    "country": "IT",
    "name": "Usmate-Velate",
    "lat": "45.64798",
    "lng": "9.36245"
  },
  {
    "country": "IT",
    "name": "Usini",
    "lat": "40.66416",
    "lng": "8.53919"
  },
  {
    "country": "IT",
    "name": "Uscio",
    "lat": "44.41233",
    "lng": "9.16227"
  },
  {
    "country": "IT",
    "name": "Urzulei",
    "lat": "40.09284",
    "lng": "9.508"
  },
  {
    "country": "IT",
    "name": "Ururi",
    "lat": "41.81518",
    "lng": "15.01611"
  },
  {
    "country": "IT",
    "name": "Uri",
    "lat": "40.63841",
    "lng": "8.48881"
  },
  {
    "country": "IT",
    "name": "Urgnano",
    "lat": "45.59943",
    "lng": "9.69473"
  },
  {
    "country": "IT",
    "name": "Urbisaglia",
    "lat": "43.19304",
    "lng": "13.37474"
  },
  {
    "country": "IT",
    "name": "Urbino",
    "lat": "43.72621",
    "lng": "12.63633"
  },
  {
    "country": "IT",
    "name": "Urbania",
    "lat": "43.66832",
    "lng": "12.52093"
  },
  {
    "country": "IT",
    "name": "Umbertide",
    "lat": "43.30341",
    "lng": "12.33749"
  },
  {
    "country": "IT",
    "name": "Uliveto Terme",
    "lat": "43.69609",
    "lng": "10.51728"
  },
  {
    "country": "IT",
    "name": "Ulà Tirso",
    "lat": "40.0457",
    "lng": "8.90326"
  },
  {
    "country": "IT",
    "name": "Uggiate Trevano",
    "lat": "45.82338",
    "lng": "8.95964"
  },
  {
    "country": "IT",
    "name": "Uggiano Montefusco",
    "lat": "40.38612",
    "lng": "17.6046"
  },
  {
    "country": "IT",
    "name": "Uggiano la Chiesa",
    "lat": "40.10091",
    "lng": "18.44872"
  },
  {
    "country": "IT",
    "name": "Udine",
    "lat": "46.0693",
    "lng": "13.23715"
  },
  {
    "country": "IT",
    "name": "Tuscania",
    "lat": "42.41889",
    "lng": "11.86846"
  },
  {
    "country": "IT",
    "name": "Tursi",
    "lat": "40.24651",
    "lng": "16.4714"
  },
  {
    "country": "IT",
    "name": "Turrivalignani",
    "lat": "42.26296",
    "lng": "14.02852"
  },
  {
    "country": "IT",
    "name": "Turriaco",
    "lat": "45.82119",
    "lng": "13.44369"
  },
  {
    "country": "IT",
    "name": "Turi",
    "lat": "40.91657",
    "lng": "17.02038"
  },
  {
    "country": "IT",
    "name": "Turbigo",
    "lat": "45.53076",
    "lng": "8.73671"
  },
  {
    "country": "IT",
    "name": "Turano Lodigiano",
    "lat": "45.24785",
    "lng": "9.62221"
  },
  {
    "country": "IT",
    "name": "Turania",
    "lat": "42.13517",
    "lng": "13.00983"
  },
  {
    "country": "IT",
    "name": "Tuoro sul Trasimeno",
    "lat": "43.20654",
    "lng": "12.07465"
  },
  {
    "country": "IT",
    "name": "Tula",
    "lat": "40.73246",
    "lng": "8.98392"
  },
  {
    "country": "IT",
    "name": "Tuglie",
    "lat": "40.07346",
    "lng": "18.09872"
  },
  {
    "country": "IT",
    "name": "Tufino",
    "lat": "40.95586",
    "lng": "14.56568"
  },
  {
    "country": "IT",
    "name": "Tufillo",
    "lat": "41.91685",
    "lng": "14.62558"
  },
  {
    "country": "IT",
    "name": "Tuenno",
    "lat": "46.32844",
    "lng": "11.02306"
  },
  {
    "country": "IT",
    "name": "Tubre",
    "lat": "46.64403",
    "lng": "10.46328"
  },
  {
    "country": "IT",
    "name": "Truccazzano",
    "lat": "45.48455",
    "lng": "9.4695"
  },
  {
    "country": "IT",
    "name": "Trovo",
    "lat": "45.28296",
    "lng": "9.03545"
  },
  {
    "country": "IT",
    "name": "Troviggiano",
    "lat": "43.37868",
    "lng": "13.25022"
  },
  {
    "country": "IT",
    "name": "Tronzano Vercellese",
    "lat": "45.34226",
    "lng": "8.17368"
  },
  {
    "country": "IT",
    "name": "Tronzano Lago Maggiore",
    "lat": "46.08871",
    "lng": "8.7331"
  },
  {
    "country": "IT",
    "name": "Tromello",
    "lat": "45.2089",
    "lng": "8.87054"
  },
  {
    "country": "IT",
    "name": "Troia",
    "lat": "41.36428",
    "lng": "15.3173"
  },
  {
    "country": "IT",
    "name": "Trofarello",
    "lat": "44.98238",
    "lng": "7.74688"
  },
  {
    "country": "IT",
    "name": "Trodena",
    "lat": "46.32181",
    "lng": "11.34982"
  },
  {
    "country": "IT",
    "name": "Trivigno",
    "lat": "40.58015",
    "lng": "15.98857"
  },
  {
    "country": "IT",
    "name": "Trivignano Udinese",
    "lat": "45.94601",
    "lng": "13.34019"
  },
  {
    "country": "IT",
    "name": "Trivero-Prativero-Ponzone",
    "lat": "45.66047",
    "lng": "8.17402"
  },
  {
    "country": "IT",
    "name": "Trivento",
    "lat": "41.77004",
    "lng": "14.54613"
  },
  {
    "country": "IT",
    "name": "Triuggio",
    "lat": "45.66144",
    "lng": "9.26691"
  },
  {
    "country": "IT",
    "name": "Trissino",
    "lat": "45.55994",
    "lng": "11.37678"
  },
  {
    "country": "IT",
    "name": "Trisobbio",
    "lat": "44.66063",
    "lng": "8.58621"
  },
  {
    "country": "IT",
    "name": "Triora",
    "lat": "43.99309",
    "lng": "7.76369"
  },
  {
    "country": "IT",
    "name": "Trino",
    "lat": "45.19538",
    "lng": "8.29621"
  },
  {
    "country": "IT",
    "name": "Trinitapoli",
    "lat": "41.35654",
    "lng": "16.08924"
  },
  {
    "country": "IT",
    "name": "Trinità d'Agultu e Vignola",
    "lat": "40.98377",
    "lng": "8.91562"
  },
  {
    "country": "IT",
    "name": "Trinità",
    "lat": "44.5073",
    "lng": "7.75637"
  },
  {
    "country": "IT",
    "name": "Trigolo",
    "lat": "45.32997",
    "lng": "9.81415"
  },
  {
    "country": "IT",
    "name": "Triggiano",
    "lat": "41.06549",
    "lng": "16.92501"
  },
  {
    "country": "IT",
    "name": "Trieste",
    "lat": "45.64953",
    "lng": "13.77678"
  },
  {
    "country": "IT",
    "name": "Triei",
    "lat": "40.03498",
    "lng": "9.63995"
  },
  {
    "country": "IT",
    "name": "Tricesimo",
    "lat": "46.16058",
    "lng": "13.21566"
  },
  {
    "country": "IT",
    "name": "Tricerro",
    "lat": "45.2357",
    "lng": "8.32746"
  },
  {
    "country": "IT",
    "name": "Tricarico",
    "lat": "40.61458",
    "lng": "16.14259"
  },
  {
    "country": "IT",
    "name": "Tribiano",
    "lat": "45.41323",
    "lng": "9.37693"
  },
  {
    "country": "IT",
    "name": "Tribano",
    "lat": "45.20912",
    "lng": "11.83639"
  },
  {
    "country": "IT",
    "name": "Trezzo sull'Adda",
    "lat": "45.60523",
    "lng": "9.51417"
  },
  {
    "country": "IT",
    "name": "Trezzano sul Naviglio",
    "lat": "45.42212",
    "lng": "9.06342"
  },
  {
    "country": "IT",
    "name": "Trezzano Rosa",
    "lat": "45.58228",
    "lng": "9.48567"
  },
  {
    "country": "IT",
    "name": "Treviso",
    "lat": "45.66673",
    "lng": "12.2416"
  },
  {
    "country": "IT",
    "name": "Trevi nel Lazio",
    "lat": "41.86258",
    "lng": "13.24793"
  },
  {
    "country": "IT",
    "name": "Trevignano Romano",
    "lat": "42.1602",
    "lng": "12.23775"
  },
  {
    "country": "IT",
    "name": "Trevignano",
    "lat": "45.7367",
    "lng": "12.06719"
  },
  {
    "country": "IT",
    "name": "Treviglio",
    "lat": "45.52081",
    "lng": "9.59102"
  },
  {
    "country": "IT",
    "name": "Trevico",
    "lat": "41.04808",
    "lng": "15.23292"
  },
  {
    "country": "IT",
    "name": "Trevi",
    "lat": "42.87769",
    "lng": "12.74938"
  },
  {
    "country": "IT",
    "name": "Trevenzuolo",
    "lat": "45.26974",
    "lng": "10.93386"
  },
  {
    "country": "IT",
    "name": "Tresnuraghes",
    "lat": "40.25235",
    "lng": "8.52092"
  },
  {
    "country": "IT",
    "name": "Tresigallo-Final di Rero",
    "lat": "44.81598",
    "lng": "11.89472"
  },
  {
    "country": "IT",
    "name": "Trescore Cremasco",
    "lat": "45.40298",
    "lng": "9.62278"
  },
  {
    "country": "IT",
    "name": "Trescore Balneario",
    "lat": "45.69409",
    "lng": "9.84173"
  },
  {
    "country": "IT",
    "name": "Trescine",
    "lat": "41.02256",
    "lng": "14.62039"
  },
  {
    "country": "IT",
    "name": "Tres",
    "lat": "46.32179",
    "lng": "11.09654"
  },
  {
    "country": "IT",
    "name": "Trequanda",
    "lat": "43.18749",
    "lng": "11.66818"
  },
  {
    "country": "IT",
    "name": "Trepuzzi",
    "lat": "40.40535",
    "lng": "18.07625"
  },
  {
    "country": "IT",
    "name": "Treppo Grande",
    "lat": "46.19988",
    "lng": "13.1535"
  },
  {
    "country": "IT",
    "name": "Treponti",
    "lat": "45.36727",
    "lng": "11.70905"
  },
  {
    "country": "IT",
    "name": "Trentola-Ducenta",
    "lat": "40.97517",
    "lng": "14.1749"
  },
  {
    "country": "IT",
    "name": "Trento",
    "lat": "46.06787",
    "lng": "11.12108"
  },
  {
    "country": "IT",
    "name": "Trentinara",
    "lat": "40.39998",
    "lng": "15.11545"
  },
  {
    "country": "IT",
    "name": "Tremignon",
    "lat": "45.52076",
    "lng": "11.80577"
  },
  {
    "country": "IT",
    "name": "Tremezzo",
    "lat": "45.98423",
    "lng": "9.21613"
  },
  {
    "country": "IT",
    "name": "Tremenico",
    "lat": "46.07592",
    "lng": "9.36602"
  },
  {
    "country": "IT",
    "name": "Treia",
    "lat": "43.3085",
    "lng": "13.31036"
  },
  {
    "country": "IT",
    "name": "Tregnago",
    "lat": "45.51397",
    "lng": "11.16421"
  },
  {
    "country": "IT",
    "name": "Treglio",
    "lat": "42.26184",
    "lng": "14.42315"
  },
  {
    "country": "IT",
    "name": "Treggiaia",
    "lat": "43.62305",
    "lng": "10.67325"
  },
  {
    "country": "IT",
    "name": "Tredozio",
    "lat": "44.07958",
    "lng": "11.7414"
  },
  {
    "country": "IT",
    "name": "Trecenta",
    "lat": "45.02937",
    "lng": "11.45931"
  },
  {
    "country": "IT",
    "name": "Trecchina",
    "lat": "40.02611",
    "lng": "15.77585"
  },
  {
    "country": "IT",
    "name": "Trecate",
    "lat": "45.43399",
    "lng": "8.7364"
  },
  {
    "country": "IT",
    "name": "Trecasali",
    "lat": "44.93747",
    "lng": "10.27279"
  },
  {
    "country": "IT",
    "name": "Trebaseleghe",
    "lat": "45.59295",
    "lng": "12.04392"
  },
  {
    "country": "IT",
    "name": "Travo",
    "lat": "44.86321",
    "lng": "9.5443"
  },
  {
    "country": "IT",
    "name": "Travesio",
    "lat": "46.19667",
    "lng": "12.8674"
  },
  {
    "country": "IT",
    "name": "Traversetolo",
    "lat": "44.64244",
    "lng": "10.38036"
  },
  {
    "country": "IT",
    "name": "Traversella",
    "lat": "45.50907",
    "lng": "7.74938"
  },
  {
    "country": "IT",
    "name": "Travedona Monate",
    "lat": "45.80427",
    "lng": "8.67143"
  },
  {
    "country": "IT",
    "name": "Travagliato",
    "lat": "45.52391",
    "lng": "10.08013"
  },
  {
    "country": "IT",
    "name": "Trasaghis",
    "lat": "46.28164",
    "lng": "13.07545"
  },
  {
    "country": "IT",
    "name": "Trasacco",
    "lat": "41.95742",
    "lng": "13.5327"
  },
  {
    "country": "IT",
    "name": "Trarivi",
    "lat": "43.93672",
    "lng": "12.544"
  },
  {
    "country": "IT",
    "name": "Trarego",
    "lat": "46.03435",
    "lng": "8.66998"
  },
  {
    "country": "IT",
    "name": "Traona",
    "lat": "46.14737",
    "lng": "9.53256"
  },
  {
    "country": "IT",
    "name": "Transacqua",
    "lat": "46.17367",
    "lng": "11.83279"
  },
  {
    "country": "IT",
    "name": "Trani",
    "lat": "41.27733",
    "lng": "16.41011"
  },
  {
    "country": "IT",
    "name": "Trana",
    "lat": "45.03862",
    "lng": "7.421"
  },
  {
    "country": "IT",
    "name": "Tramutola",
    "lat": "40.31858",
    "lng": "15.78753"
  },
  {
    "country": "IT",
    "name": "Tramonti di Sopra",
    "lat": "46.31023",
    "lng": "12.78994"
  },
  {
    "country": "IT",
    "name": "Tramonti",
    "lat": "40.69154",
    "lng": "14.6449"
  },
  {
    "country": "IT",
    "name": "Tragliatella Campitello",
    "lat": "42.01334",
    "lng": "12.252"
  },
  {
    "country": "IT",
    "name": "Tradate",
    "lat": "45.70843",
    "lng": "8.90763"
  },
  {
    "country": "IT",
    "name": "Tossicia",
    "lat": "42.54472",
    "lng": "13.64595"
  },
  {
    "country": "IT",
    "name": "Toscolano Maderno",
    "lat": "45.63977",
    "lng": "10.6076"
  },
  {
    "country": "IT",
    "name": "Torviscosa",
    "lat": "45.82337",
    "lng": "13.2805"
  },
  {
    "country": "IT",
    "name": "Tortoreto",
    "lat": "42.80371",
    "lng": "13.91346"
  },
  {
    "country": "IT",
    "name": "Tortorella",
    "lat": "40.14236",
    "lng": "15.60625"
  },
  {
    "country": "IT",
    "name": "Tortona",
    "lat": "44.89784",
    "lng": "8.86374"
  },
  {
    "country": "IT",
    "name": "Torrita Tiberina",
    "lat": "42.23821",
    "lng": "12.61633"
  },
  {
    "country": "IT",
    "name": "Torrita di Siena",
    "lat": "43.17245",
    "lng": "11.78376"
  },
  {
    "country": "IT",
    "name": "Torrioni",
    "lat": "41.0341",
    "lng": "14.81351"
  },
  {
    "country": "IT",
    "name": "Torrile",
    "lat": "44.92522",
    "lng": "10.32381"
  },
  {
    "country": "IT",
    "name": "Torri in Sabina",
    "lat": "42.35057",
    "lng": "12.64157"
  },
  {
    "country": "IT",
    "name": "Torriglia",
    "lat": "44.51755",
    "lng": "9.15811"
  },
  {
    "country": "IT",
    "name": "Torri di Quartesolo",
    "lat": "45.51901",
    "lng": "11.62469"
  },
  {
    "country": "IT",
    "name": "Torri del Benaco",
    "lat": "45.61013",
    "lng": "10.68669"
  },
  {
    "country": "IT",
    "name": "Torricella",
    "lat": "42.65904",
    "lng": "13.65719"
  },
  {
    "country": "IT",
    "name": "Torricella Peligna",
    "lat": "42.02397",
    "lng": "14.25854"
  },
  {
    "country": "IT",
    "name": "Torricella in Sabina",
    "lat": "42.26252",
    "lng": "12.8717"
  },
  {
    "country": "IT",
    "name": "Torricella del Pizzo",
    "lat": "45.02023",
    "lng": "10.29497"
  },
  {
    "country": "IT",
    "name": "Torricella",
    "lat": "40.35509",
    "lng": "17.49846"
  },
  {
    "country": "IT",
    "name": "Torrice",
    "lat": "41.63374",
    "lng": "13.40375"
  },
  {
    "country": "IT",
    "name": "Torriana",
    "lat": "43.98485",
    "lng": "12.38541"
  },
  {
    "country": "IT",
    "name": "Torrevecchia",
    "lat": "42.38274",
    "lng": "14.21331"
  },
  {
    "country": "IT",
    "name": "Torre Santa Susanna",
    "lat": "40.46762",
    "lng": "17.73864"
  },
  {
    "country": "IT",
    "name": "Torre San Patrizio",
    "lat": "43.18311",
    "lng": "13.61113"
  },
  {
    "country": "IT",
    "name": "Torre Pellice",
    "lat": "44.82102",
    "lng": "7.21672"
  },
  {
    "country": "IT",
    "name": "Torre Orsaia",
    "lat": "40.13277",
    "lng": "15.4725"
  },
  {
    "country": "IT",
    "name": "Torrenieri",
    "lat": "43.08566",
    "lng": "11.54839"
  },
  {
    "country": "IT",
    "name": "Torremaggiore",
    "lat": "41.68894",
    "lng": "15.29408"
  },
  {
    "country": "IT",
    "name": "Torre le Nocelle",
    "lat": "41.02312",
    "lng": "14.90934"
  },
  {
    "country": "IT",
    "name": "Torreglia",
    "lat": "45.33617",
    "lng": "11.73608"
  },
  {
    "country": "IT",
    "name": "Torre d'Isola",
    "lat": "45.21796",
    "lng": "9.07651"
  },
  {
    "country": "IT",
    "name": "Torre di Santa Maria",
    "lat": "46.23356",
    "lng": "9.85228"
  },
  {
    "country": "IT",
    "name": "Torre di Mosto",
    "lat": "45.68629",
    "lng": "12.70027"
  },
  {
    "country": "IT",
    "name": "Torre de' Picenardi",
    "lat": "45.14317",
    "lng": "10.28803"
  },
  {
    "country": "IT",
    "name": "Torre de' Passeri",
    "lat": "42.24324",
    "lng": "13.9333"
  },
  {
    "country": "IT",
    "name": "Torre del Mangano",
    "lat": "45.25208",
    "lng": "9.13042"
  },
  {
    "country": "IT",
    "name": "Torre del Lago Puccini",
    "lat": "43.82887",
    "lng": "10.28912"
  },
  {
    "country": "IT",
    "name": "Torre del Greco",
    "lat": "40.78931",
    "lng": "14.36806"
  },
  {
    "country": "IT",
    "name": "Torre de' Busi",
    "lat": "45.77408",
    "lng": "9.48025"
  },
  {
    "country": "IT",
    "name": "Torrecuso",
    "lat": "41.18582",
    "lng": "14.68126"
  },
  {
    "country": "IT",
    "name": "Torrebruna",
    "lat": "41.86742",
    "lng": "14.54148"
  },
  {
    "country": "IT",
    "name": "Torre Boldone",
    "lat": "45.71725",
    "lng": "9.70792"
  },
  {
    "country": "IT",
    "name": "Torre Beretti",
    "lat": "45.05996",
    "lng": "8.67094"
  },
  {
    "country": "IT",
    "name": "Torrebelvicino",
    "lat": "45.71583",
    "lng": "11.31869"
  },
  {
    "country": "IT",
    "name": "Torreano",
    "lat": "46.12786",
    "lng": "13.42933"
  },
  {
    "country": "IT",
    "name": "Torre Annunziata",
    "lat": "40.75337",
    "lng": "14.45251"
  },
  {
    "country": "IT",
    "name": "Torrazzo",
    "lat": "45.49874",
    "lng": "7.95428"
  },
  {
    "country": "IT",
    "name": "Torrazza Coste",
    "lat": "44.9782",
    "lng": "9.07613"
  },
  {
    "country": "IT",
    "name": "Torralba",
    "lat": "40.51296",
    "lng": "8.76532"
  },
  {
    "country": "IT",
    "name": "Torraca",
    "lat": "40.11099",
    "lng": "15.63632"
  },
  {
    "country": "IT",
    "name": "Torpè",
    "lat": "40.6278",
    "lng": "9.67916"
  },
  {
    "country": "IT",
    "name": "Toro",
    "lat": "41.57313",
    "lng": "14.76183"
  },
  {
    "country": "IT",
    "name": "Tornolo",
    "lat": "44.48524",
    "lng": "9.62744"
  },
  {
    "country": "IT",
    "name": "Torno",
    "lat": "45.85593",
    "lng": "9.11707"
  },
  {
    "country": "IT",
    "name": "Tornata",
    "lat": "45.10437",
    "lng": "10.43078"
  },
  {
    "country": "IT",
    "name": "Tornareccio",
    "lat": "42.03763",
    "lng": "14.41525"
  },
  {
    "country": "IT",
    "name": "Tornaco",
    "lat": "45.35651",
    "lng": "8.71745"
  },
  {
    "country": "IT",
    "name": "Torlino Vimercati",
    "lat": "45.41747",
    "lng": "9.59476"
  },
  {
    "country": "IT",
    "name": "Toritto",
    "lat": "40.99774",
    "lng": "16.67945"
  },
  {
    "country": "IT",
    "name": "Torino di Sangro",
    "lat": "42.191",
    "lng": "14.54272"
  },
  {
    "country": "IT",
    "name": "Turin",
    "lat": "45.07049",
    "lng": "7.68682"
  },
  {
    "country": "IT",
    "name": "Torgnon",
    "lat": "45.80616",
    "lng": "7.5698"
  },
  {
    "country": "IT",
    "name": "Torgiano",
    "lat": "43.02761",
    "lng": "12.44015"
  },
  {
    "country": "IT",
    "name": "Torella del Sannio",
    "lat": "41.63878",
    "lng": "14.52031"
  },
  {
    "country": "IT",
    "name": "Torella dei Lombardi",
    "lat": "40.93731",
    "lng": "15.10784"
  },
  {
    "country": "IT",
    "name": "Torchiarolo",
    "lat": "40.48349",
    "lng": "18.05122"
  },
  {
    "country": "IT",
    "name": "Torchiara",
    "lat": "40.32162",
    "lng": "15.0537"
  },
  {
    "country": "IT",
    "name": "Torbole sul Garda",
    "lat": "45.86951",
    "lng": "10.87561"
  },
  {
    "country": "IT",
    "name": "Torbole Casaglia",
    "lat": "45.51279",
    "lng": "10.117"
  },
  {
    "country": "IT",
    "name": "Torano Nuovo",
    "lat": "42.82305",
    "lng": "13.77729"
  },
  {
    "country": "IT",
    "name": "Tora",
    "lat": "41.33987",
    "lng": "14.02399"
  },
  {
    "country": "IT",
    "name": "Tonezza del Cimone",
    "lat": "45.85889",
    "lng": "11.34592"
  },
  {
    "country": "IT",
    "name": "Tonco",
    "lat": "45.02344",
    "lng": "8.18942"
  },
  {
    "country": "IT",
    "name": "Tonara",
    "lat": "40.02465",
    "lng": "9.17204"
  },
  {
    "country": "IT",
    "name": "Tonadico",
    "lat": "46.18111",
    "lng": "11.83939"
  },
  {
    "country": "IT",
    "name": "Tombolo",
    "lat": "45.63916",
    "lng": "11.82435"
  },
  {
    "country": "IT",
    "name": "Tolve",
    "lat": "40.69422",
    "lng": "16.01627"
  },
  {
    "country": "IT",
    "name": "Tolmezzo",
    "lat": "46.39996",
    "lng": "13.02051"
  },
  {
    "country": "IT",
    "name": "Tollo",
    "lat": "42.34542",
    "lng": "14.3236"
  },
  {
    "country": "IT",
    "name": "Tollegno",
    "lat": "45.59077",
    "lng": "8.05089"
  },
  {
    "country": "IT",
    "name": "Tolfa",
    "lat": "42.15023",
    "lng": "11.93216"
  },
  {
    "country": "IT",
    "name": "Tolentino",
    "lat": "43.20918",
    "lng": "13.28524"
  },
  {
    "country": "IT",
    "name": "Toirano",
    "lat": "44.12732",
    "lng": "8.20725"
  },
  {
    "country": "IT",
    "name": "Toffia",
    "lat": "42.213",
    "lng": "12.755"
  },
  {
    "country": "IT",
    "name": "Todi",
    "lat": "42.77881",
    "lng": "12.41202"
  },
  {
    "country": "IT",
    "name": "Tocco da Casauria",
    "lat": "42.21203",
    "lng": "13.91547"
  },
  {
    "country": "IT",
    "name": "Tocco Caudio",
    "lat": "41.12587",
    "lng": "14.63422"
  },
  {
    "country": "IT",
    "name": "Toano",
    "lat": "44.37601",
    "lng": "10.56311"
  },
  {
    "country": "IT",
    "name": "Tizzano Val Parma",
    "lat": "44.51931",
    "lng": "10.19819"
  },
  {
    "country": "IT",
    "name": "Tivoli",
    "lat": "41.95952",
    "lng": "12.8016"
  },
  {
    "country": "IT",
    "name": "Tito",
    "lat": "40.5837",
    "lng": "15.67621"
  },
  {
    "country": "IT",
    "name": "Tissi",
    "lat": "40.67832",
    "lng": "8.56127"
  },
  {
    "country": "IT",
    "name": "Marina di Pisa-Tirrenia-Calambrone",
    "lat": "43.62719",
    "lng": "10.29204"
  },
  {
    "country": "IT",
    "name": "Tires",
    "lat": "46.46817",
    "lng": "11.52704"
  },
  {
    "country": "IT",
    "name": "Tirano",
    "lat": "46.21482",
    "lng": "10.16335"
  },
  {
    "country": "IT",
    "name": "Tione di Trento",
    "lat": "46.0355",
    "lng": "10.72679"
  },
  {
    "country": "IT",
    "name": "Tione degli Abruzzi",
    "lat": "42.20393",
    "lng": "13.6357"
  },
  {
    "country": "IT",
    "name": "Tinnura",
    "lat": "40.26916",
    "lng": "8.54815"
  },
  {
    "country": "IT",
    "name": "Tiglieto",
    "lat": "44.52324",
    "lng": "8.61925"
  },
  {
    "country": "IT",
    "name": "Ticineto",
    "lat": "45.09627",
    "lng": "8.55315"
  },
  {
    "country": "IT",
    "name": "Ticengo",
    "lat": "45.36927",
    "lng": "9.82766"
  },
  {
    "country": "IT",
    "name": "Tecchiena",
    "lat": "41.68822",
    "lng": "13.34538"
  },
  {
    "country": "IT",
    "name": "Tiana",
    "lat": "40.06746",
    "lng": "9.14817"
  },
  {
    "country": "IT",
    "name": "Thiesi",
    "lat": "40.52398",
    "lng": "8.72001"
  },
  {
    "country": "IT",
    "name": "Thiene",
    "lat": "45.7088",
    "lng": "11.47959"
  },
  {
    "country": "IT",
    "name": "Tezze",
    "lat": "45.69011",
    "lng": "11.70672"
  },
  {
    "country": "IT",
    "name": "Tezze",
    "lat": "45.53402",
    "lng": "11.36997"
  },
  {
    "country": "IT",
    "name": "Teti",
    "lat": "40.09737",
    "lng": "9.11923"
  },
  {
    "country": "IT",
    "name": "Testico",
    "lat": "44.00553",
    "lng": "8.02639"
  },
  {
    "country": "IT",
    "name": "Tessera",
    "lat": "45.50241",
    "lng": "12.32632"
  },
  {
    "country": "IT",
    "name": "Tessennano",
    "lat": "42.47803",
    "lng": "11.79101"
  },
  {
    "country": "IT",
    "name": "Tesimo",
    "lat": "46.56542",
    "lng": "11.16937"
  },
  {
    "country": "IT",
    "name": "Tesero",
    "lat": "46.29184",
    "lng": "11.50946"
  },
  {
    "country": "IT",
    "name": "Terzorio",
    "lat": "43.85232",
    "lng": "7.89835"
  },
  {
    "country": "IT",
    "name": "Terzigno",
    "lat": "40.804",
    "lng": "14.49309"
  },
  {
    "country": "IT",
    "name": "Terruggia",
    "lat": "45.08199",
    "lng": "8.44428"
  },
  {
    "country": "IT",
    "name": "Terrossa",
    "lat": "45.4634",
    "lng": "11.3186"
  },
  {
    "country": "IT",
    "name": "Terricciola",
    "lat": "43.52505",
    "lng": "10.67961"
  },
  {
    "country": "IT",
    "name": "Terrazzo",
    "lat": "45.1726",
    "lng": "11.39485"
  },
  {
    "country": "IT",
    "name": "Terrarossa",
    "lat": "44.23362",
    "lng": "9.9611"
  },
  {
    "country": "IT",
    "name": "Terranuova Bracciolini",
    "lat": "43.55081",
    "lng": "11.58075"
  },
  {
    "country": "IT",
    "name": "Terracina",
    "lat": "41.29174",
    "lng": "13.24359"
  },
  {
    "country": "IT",
    "name": "Terontola",
    "lat": "43.21009",
    "lng": "12.01113"
  },
  {
    "country": "IT",
    "name": "Terni",
    "lat": "42.56335",
    "lng": "12.64329"
  },
  {
    "country": "IT",
    "name": "Ternate",
    "lat": "45.78673",
    "lng": "8.69931"
  },
  {
    "country": "IT",
    "name": "Termoli",
    "lat": "41.99994",
    "lng": "14.99389"
  },
  {
    "country": "IT",
    "name": "Termeno",
    "lat": "46.34151",
    "lng": "11.24228"
  },
  {
    "country": "IT",
    "name": "Terlizzi",
    "lat": "41.12905",
    "lng": "16.54536"
  },
  {
    "country": "IT",
    "name": "Terlano",
    "lat": "46.53216",
    "lng": "11.24689"
  },
  {
    "country": "IT",
    "name": "Terlago",
    "lat": "46.09737",
    "lng": "11.04505"
  },
  {
    "country": "IT",
    "name": "Terenzo",
    "lat": "44.61048",
    "lng": "10.08956"
  },
  {
    "country": "IT",
    "name": "Zugliano-Terenzano-Cargnacco",
    "lat": "46.0075",
    "lng": "13.21694"
  },
  {
    "country": "IT",
    "name": "Terento",
    "lat": "46.82992",
    "lng": "11.78288"
  },
  {
    "country": "IT",
    "name": "Terelle",
    "lat": "41.55212",
    "lng": "13.77841"
  },
  {
    "country": "IT",
    "name": "Terdobbiate",
    "lat": "45.37588",
    "lng": "8.69458"
  },
  {
    "country": "IT",
    "name": "Teramo",
    "lat": "42.66123",
    "lng": "13.69901"
  },
  {
    "country": "IT",
    "name": "Teora",
    "lat": "40.85282",
    "lng": "15.25335"
  },
  {
    "country": "IT",
    "name": "Teor",
    "lat": "45.85416",
    "lng": "13.05608"
  },
  {
    "country": "IT",
    "name": "Tenno",
    "lat": "45.91937",
    "lng": "10.8316"
  },
  {
    "country": "IT",
    "name": "Tencarola",
    "lat": "45.3949",
    "lng": "11.80919"
  },
  {
    "country": "IT",
    "name": "Temù",
    "lat": "46.25022",
    "lng": "10.46592"
  },
  {
    "country": "IT",
    "name": "Tempio Pausania",
    "lat": "40.90068",
    "lng": "9.10456"
  },
  {
    "country": "IT",
    "name": "Telve",
    "lat": "46.07011",
    "lng": "11.48022"
  },
  {
    "country": "IT",
    "name": "Telti",
    "lat": "40.87575",
    "lng": "9.35328"
  },
  {
    "country": "IT",
    "name": "Telgate",
    "lat": "45.62792",
    "lng": "9.84912"
  },
  {
    "country": "IT",
    "name": "Telese",
    "lat": "41.21752",
    "lng": "14.52681"
  },
  {
    "country": "IT",
    "name": "Tegoleto",
    "lat": "43.39458",
    "lng": "11.7853"
  },
  {
    "country": "IT",
    "name": "Teglio Veneto",
    "lat": "45.81637",
    "lng": "12.88414"
  },
  {
    "country": "IT",
    "name": "Teglio",
    "lat": "46.17235",
    "lng": "10.06399"
  },
  {
    "country": "IT",
    "name": "Teggiano-Macchiaroli",
    "lat": "40.37921",
    "lng": "15.54046"
  },
  {
    "country": "IT",
    "name": "Teano",
    "lat": "41.25132",
    "lng": "14.06652"
  },
  {
    "country": "IT",
    "name": "Teana",
    "lat": "40.12586",
    "lng": "16.15281"
  },
  {
    "country": "IT",
    "name": "Tavullia",
    "lat": "43.89791",
    "lng": "12.75108"
  },
  {
    "country": "IT",
    "name": "Tavoleto",
    "lat": "43.84402",
    "lng": "12.59418"
  },
  {
    "country": "IT",
    "name": "Tavernole",
    "lat": "45.74618",
    "lng": "10.23952"
  },
  {
    "country": "IT",
    "name": "Tavernola Bergamasca",
    "lat": "45.70846",
    "lng": "10.04454"
  },
  {
    "country": "IT",
    "name": "Tavernelle",
    "lat": "43.73203",
    "lng": "12.88349"
  },
  {
    "country": "IT",
    "name": "Tavernelle",
    "lat": "43.00333",
    "lng": "12.1452"
  },
  {
    "country": "IT",
    "name": "Taverne D'Arbia",
    "lat": "43.2949",
    "lng": "11.39483"
  },
  {
    "country": "IT",
    "name": "Tavenna",
    "lat": "41.90898",
    "lng": "14.76176"
  },
  {
    "country": "IT",
    "name": "Tavazzano",
    "lat": "45.32783",
    "lng": "9.40473"
  },
  {
    "country": "IT",
    "name": "Tavarnuzze",
    "lat": "43.71019",
    "lng": "11.21721"
  },
  {
    "country": "IT",
    "name": "Tavagnasco",
    "lat": "45.54448",
    "lng": "7.82293"
  },
  {
    "country": "IT",
    "name": "Tavagnacco",
    "lat": "46.10976",
    "lng": "13.22251"
  },
  {
    "country": "IT",
    "name": "Taurasi",
    "lat": "41.0108",
    "lng": "14.9598"
  },
  {
    "country": "IT",
    "name": "Taurano",
    "lat": "40.88444",
    "lng": "14.63427"
  },
  {
    "country": "IT",
    "name": "Tassullo",
    "lat": "46.34298",
    "lng": "11.04539"
  },
  {
    "country": "IT",
    "name": "Tarzo",
    "lat": "45.97711",
    "lng": "12.22917"
  },
  {
    "country": "IT",
    "name": "Tarvisio",
    "lat": "46.50567",
    "lng": "13.58689"
  },
  {
    "country": "IT",
    "name": "Tarquinia",
    "lat": "42.25419",
    "lng": "11.75657"
  },
  {
    "country": "IT",
    "name": "Tarcento",
    "lat": "46.21251",
    "lng": "13.21514"
  },
  {
    "country": "IT",
    "name": "Taranto",
    "lat": "40.46438",
    "lng": "17.24707"
  },
  {
    "country": "IT",
    "name": "Tarantasca",
    "lat": "44.49322",
    "lng": "7.54459"
  },
  {
    "country": "IT",
    "name": "Taranta Peligna",
    "lat": "42.02052",
    "lng": "14.17103"
  },
  {
    "country": "IT",
    "name": "Tarano",
    "lat": "42.35593",
    "lng": "12.59497"
  },
  {
    "country": "IT",
    "name": "Taneto",
    "lat": "44.77202",
    "lng": "10.45563"
  },
  {
    "country": "IT",
    "name": "La Saletta-Tamara",
    "lat": "44.88151",
    "lng": "11.77236"
  },
  {
    "country": "IT",
    "name": "Tamai",
    "lat": "45.92427",
    "lng": "12.57187"
  },
  {
    "country": "IT",
    "name": "Talmassons",
    "lat": "45.9281",
    "lng": "13.12199"
  },
  {
    "country": "IT",
    "name": "Talla",
    "lat": "43.60185",
    "lng": "11.78714"
  },
  {
    "country": "IT",
    "name": "Talana",
    "lat": "40.04157",
    "lng": "9.49554"
  },
  {
    "country": "IT",
    "name": "Talamello",
    "lat": "43.90566",
    "lng": "12.28484"
  },
  {
    "country": "IT",
    "name": "Taipana",
    "lat": "46.24911",
    "lng": "13.3415"
  },
  {
    "country": "IT",
    "name": "Taino",
    "lat": "45.76249",
    "lng": "8.61654"
  },
  {
    "country": "IT",
    "name": "Taibon Agordino",
    "lat": "46.29838",
    "lng": "12.01312"
  },
  {
    "country": "IT",
    "name": "Taglio di Po",
    "lat": "45.00189",
    "lng": "12.21386"
  },
  {
    "country": "IT",
    "name": "Taglio",
    "lat": "45.02222",
    "lng": "12.21083"
  },
  {
    "country": "IT",
    "name": "Tagliacozzo",
    "lat": "42.06933",
    "lng": "13.25469"
  },
  {
    "country": "IT",
    "name": "Taggia",
    "lat": "43.84612",
    "lng": "7.85223"
  },
  {
    "country": "IT",
    "name": "Tadasuni",
    "lat": "40.10995",
    "lng": "8.88353"
  },
  {
    "country": "IT",
    "name": "Taceno",
    "lat": "46.02253",
    "lng": "9.364"
  },
  {
    "country": "IT",
    "name": "Suzzara",
    "lat": "44.99242",
    "lng": "10.74407"
  },
  {
    "country": "IT",
    "name": "Suvereto",
    "lat": "43.07669",
    "lng": "10.6774"
  },
  {
    "country": "IT",
    "name": "Sutri",
    "lat": "42.24596",
    "lng": "12.21715"
  },
  {
    "country": "IT",
    "name": "Sustinente",
    "lat": "45.07096",
    "lng": "11.02178"
  },
  {
    "country": "IT",
    "name": "Susegana",
    "lat": "45.85604",
    "lng": "12.25741"
  },
  {
    "country": "IT",
    "name": "Susa",
    "lat": "45.13677",
    "lng": "7.05809"
  },
  {
    "country": "IT",
    "name": "Surbo",
    "lat": "40.39383",
    "lng": "18.13456"
  },
  {
    "country": "IT",
    "name": "Surano",
    "lat": "40.02818",
    "lng": "18.34591"
  },
  {
    "country": "IT",
    "name": "Supino",
    "lat": "41.62135",
    "lng": "13.23452"
  },
  {
    "country": "IT",
    "name": "Supersano",
    "lat": "40.01655",
    "lng": "18.24205"
  },
  {
    "country": "IT",
    "name": "Suno",
    "lat": "45.63137",
    "lng": "8.54437"
  },
  {
    "country": "IT",
    "name": "Suni",
    "lat": "40.28085",
    "lng": "8.54942"
  },
  {
    "country": "IT",
    "name": "Summonte",
    "lat": "40.94874",
    "lng": "14.74458"
  },
  {
    "country": "IT",
    "name": "Sumirago",
    "lat": "45.73651",
    "lng": "8.78356"
  },
  {
    "country": "IT",
    "name": "Sulzano",
    "lat": "45.68732",
    "lng": "10.09988"
  },
  {
    "country": "IT",
    "name": "Sulmona",
    "lat": "42.04945",
    "lng": "13.92578"
  },
  {
    "country": "IT",
    "name": "Sueglio",
    "lat": "46.08579",
    "lng": "9.33374"
  },
  {
    "country": "IT",
    "name": "Subiaco",
    "lat": "41.92619",
    "lng": "13.08906"
  },
  {
    "country": "IT",
    "name": "Subbiano",
    "lat": "43.57815",
    "lng": "11.8714"
  },
  {
    "country": "IT",
    "name": "Suardi",
    "lat": "45.03247",
    "lng": "8.74127"
  },
  {
    "country": "IT",
    "name": "Sturno",
    "lat": "41.02217",
    "lng": "15.11248"
  },
  {
    "country": "IT",
    "name": "Strudà",
    "lat": "40.31991",
    "lng": "18.28176"
  },
  {
    "country": "IT",
    "name": "Strozza",
    "lat": "45.77294",
    "lng": "9.57886"
  },
  {
    "country": "IT",
    "name": "Stroppo",
    "lat": "44.50653",
    "lng": "7.12652"
  },
  {
    "country": "IT",
    "name": "Stroppiana",
    "lat": "45.23037",
    "lng": "8.45461"
  },
  {
    "country": "IT",
    "name": "Stroncone",
    "lat": "42.51196",
    "lng": "12.6477"
  },
  {
    "country": "IT",
    "name": "Strigno",
    "lat": "46.0669",
    "lng": "11.52224"
  },
  {
    "country": "IT",
    "name": "Striano",
    "lat": "40.81543",
    "lng": "14.57534"
  },
  {
    "country": "IT",
    "name": "Strevi",
    "lat": "44.69985",
    "lng": "8.5247"
  },
  {
    "country": "IT",
    "name": "Strettoia",
    "lat": "43.98987",
    "lng": "10.19357"
  },
  {
    "country": "IT",
    "name": "Stresa",
    "lat": "45.88158",
    "lng": "8.53834"
  },
  {
    "country": "IT",
    "name": "Stregna",
    "lat": "46.12689",
    "lng": "13.57761"
  },
  {
    "country": "IT",
    "name": "Strangolagalli",
    "lat": "41.59992",
    "lng": "13.49228"
  },
  {
    "country": "IT",
    "name": "Strambino",
    "lat": "45.3799",
    "lng": "7.88967"
  },
  {
    "country": "IT",
    "name": "Stradella",
    "lat": "45.07445",
    "lng": "9.30169"
  },
  {
    "country": "IT",
    "name": "Strada in Chianti",
    "lat": "43.65874",
    "lng": "11.29678"
  },
  {
    "country": "IT",
    "name": "Stra",
    "lat": "45.41123",
    "lng": "12.01418"
  },
  {
    "country": "IT",
    "name": "Storo",
    "lat": "45.84925",
    "lng": "10.58022"
  },
  {
    "country": "IT",
    "name": "Stornarella",
    "lat": "41.25591",
    "lng": "15.73023"
  },
  {
    "country": "IT",
    "name": "Stornara",
    "lat": "41.28672",
    "lng": "15.77003"
  },
  {
    "country": "IT",
    "name": "Stio",
    "lat": "40.3102",
    "lng": "15.25153"
  },
  {
    "country": "IT",
    "name": "Stintino",
    "lat": "40.95201",
    "lng": "8.21978"
  },
  {
    "country": "IT",
    "name": "Stimigliano",
    "lat": "42.30103",
    "lng": "12.56337"
  },
  {
    "country": "IT",
    "name": "Stigliano",
    "lat": "40.40237",
    "lng": "16.22983"
  },
  {
    "country": "IT",
    "name": "Stienta",
    "lat": "44.9397",
    "lng": "11.54375"
  },
  {
    "country": "IT",
    "name": "Stia",
    "lat": "43.79877",
    "lng": "11.70894"
  },
  {
    "country": "IT",
    "name": "Stezzano",
    "lat": "45.64968",
    "lng": "9.65192"
  },
  {
    "country": "IT",
    "name": "Sternatia",
    "lat": "40.22022",
    "lng": "18.22748"
  },
  {
    "country": "IT",
    "name": "Stenico",
    "lat": "46.05124",
    "lng": "10.85562"
  },
  {
    "country": "IT",
    "name": "Stelvio",
    "lat": "46.59767",
    "lng": "10.5458"
  },
  {
    "country": "IT",
    "name": "Stellanello",
    "lat": "43.99993",
    "lng": "8.06025"
  },
  {
    "country": "IT",
    "name": "Stella Cilento",
    "lat": "40.2318",
    "lng": "15.09286"
  },
  {
    "country": "IT",
    "name": "Stazzano",
    "lat": "44.72728",
    "lng": "8.86846"
  },
  {
    "country": "IT",
    "name": "Statte",
    "lat": "40.52856",
    "lng": "17.20122"
  },
  {
    "country": "IT",
    "name": "Staranzano",
    "lat": "45.80233",
    "lng": "13.50226"
  },
  {
    "country": "IT",
    "name": "Stanghella",
    "lat": "45.13509",
    "lng": "11.75741"
  },
  {
    "country": "IT",
    "name": "Stanghe",
    "lat": "46.88219",
    "lng": "11.37764"
  },
  {
    "country": "IT",
    "name": "Stagno Lombardo",
    "lat": "45.07459",
    "lng": "10.0889"
  },
  {
    "country": "IT",
    "name": "Staggia",
    "lat": "43.42182",
    "lng": "11.18364"
  },
  {
    "country": "IT",
    "name": "Staffolo",
    "lat": "43.43326",
    "lng": "13.18487"
  },
  {
    "country": "IT",
    "name": "Staffa",
    "lat": "45.96855",
    "lng": "7.96708"
  },
  {
    "country": "IT",
    "name": "Stabbia",
    "lat": "43.78266",
    "lng": "10.83475"
  },
  {
    "country": "IT",
    "name": "Squinzano",
    "lat": "40.43513",
    "lng": "18.04086"
  },
  {
    "country": "IT",
    "name": "Spresiano",
    "lat": "45.77908",
    "lng": "12.25628"
  },
  {
    "country": "IT",
    "name": "Spotorno",
    "lat": "44.22638",
    "lng": "8.41647"
  },
  {
    "country": "IT",
    "name": "Sporminore",
    "lat": "46.23692",
    "lng": "11.02919"
  },
  {
    "country": "IT",
    "name": "Spormaggiore",
    "lat": "46.21853",
    "lng": "11.04805"
  },
  {
    "country": "IT",
    "name": "Spongano",
    "lat": "40.01782",
    "lng": "18.36563"
  },
  {
    "country": "IT",
    "name": "Spoltore",
    "lat": "42.45501",
    "lng": "14.13988"
  },
  {
    "country": "IT",
    "name": "Spoleto",
    "lat": "42.74071",
    "lng": "12.73899"
  },
  {
    "country": "IT",
    "name": "Spirano",
    "lat": "45.58144",
    "lng": "9.66863"
  },
  {
    "country": "IT",
    "name": "Spinoso",
    "lat": "40.26921",
    "lng": "15.96658"
  },
  {
    "country": "IT",
    "name": "Spino d'Adda",
    "lat": "45.40086",
    "lng": "9.48674"
  },
  {
    "country": "IT",
    "name": "Spinetta Marengo",
    "lat": "44.88554",
    "lng": "8.6775"
  },
  {
    "country": "IT",
    "name": "Spinetoli",
    "lat": "42.88984",
    "lng": "13.76497"
  },
  {
    "country": "IT",
    "name": "Spinete",
    "lat": "41.54431",
    "lng": "14.48743"
  },
  {
    "country": "IT",
    "name": "Le Casine-Perignano-Spinelli",
    "lat": "43.6",
    "lng": "10.58333"
  },
  {
    "country": "IT",
    "name": "Spineda",
    "lat": "45.0614",
    "lng": "10.51165"
  },
  {
    "country": "IT",
    "name": "Spinazzola",
    "lat": "40.96399",
    "lng": "16.09111"
  },
  {
    "country": "IT",
    "name": "Spilimbergo",
    "lat": "46.11345",
    "lng": "12.89241"
  },
  {
    "country": "IT",
    "name": "Spilamberto",
    "lat": "44.53273",
    "lng": "11.01697"
  },
  {
    "country": "IT",
    "name": "Spigno Saturnia Superiore",
    "lat": "41.31425",
    "lng": "13.70888"
  },
  {
    "country": "IT",
    "name": "Spigno Monferrato",
    "lat": "44.54314",
    "lng": "8.33395"
  },
  {
    "country": "IT",
    "name": "Spianate",
    "lat": "43.81075",
    "lng": "10.7151"
  },
  {
    "country": "IT",
    "name": "Sperlonga",
    "lat": "41.25897",
    "lng": "13.43302"
  },
  {
    "country": "IT",
    "name": "Spello",
    "lat": "42.99231",
    "lng": "12.66632"
  },
  {
    "country": "IT",
    "name": "Sparone",
    "lat": "45.41442",
    "lng": "7.54516"
  },
  {
    "country": "IT",
    "name": "Sparanise",
    "lat": "41.18788",
    "lng": "14.09628"
  },
  {
    "country": "IT",
    "name": "Sozzago",
    "lat": "45.39832",
    "lng": "8.72271"
  },
  {
    "country": "IT",
    "name": "Sovicille",
    "lat": "43.28033",
    "lng": "11.22828"
  },
  {
    "country": "IT",
    "name": "Soverzene",
    "lat": "46.20331",
    "lng": "12.30301"
  },
  {
    "country": "IT",
    "name": "Sovere",
    "lat": "45.81188",
    "lng": "10.03438"
  },
  {
    "country": "IT",
    "name": "Sotto il Monte Giovanni XXIII",
    "lat": "45.70568",
    "lng": "9.50345"
  },
  {
    "country": "IT",
    "name": "Sossano",
    "lat": "45.35754",
    "lng": "11.50819"
  },
  {
    "country": "IT",
    "name": "Sospirolo",
    "lat": "46.14134",
    "lng": "12.07365"
  },
  {
    "country": "IT",
    "name": "Sospiro",
    "lat": "45.10762",
    "lng": "10.15853"
  },
  {
    "country": "IT",
    "name": "Sorso",
    "lat": "40.79949",
    "lng": "8.5757"
  },
  {
    "country": "IT",
    "name": "Sorrento",
    "lat": "40.62678",
    "lng": "14.37771"
  },
  {
    "country": "IT",
    "name": "Sorradile",
    "lat": "40.10634",
    "lng": "8.93236"
  },
  {
    "country": "IT",
    "name": "Sormano",
    "lat": "45.87803",
    "lng": "9.24582"
  },
  {
    "country": "IT",
    "name": "Sorisole",
    "lat": "45.7314",
    "lng": "9.63715"
  },
  {
    "country": "IT",
    "name": "Soriano nel Cimino",
    "lat": "42.4182",
    "lng": "12.23414"
  },
  {
    "country": "IT",
    "name": "Sori",
    "lat": "44.37301",
    "lng": "9.1047"
  },
  {
    "country": "IT",
    "name": "Sorgono",
    "lat": "40.02595",
    "lng": "9.10203"
  },
  {
    "country": "IT",
    "name": "Soresina",
    "lat": "45.28819",
    "lng": "9.85862"
  },
  {
    "country": "IT",
    "name": "Sordevolo",
    "lat": "45.57346",
    "lng": "7.97342"
  },
  {
    "country": "IT",
    "name": "Sorbo Serpico",
    "lat": "40.91685",
    "lng": "14.88709"
  },
  {
    "country": "IT",
    "name": "Sorbolo",
    "lat": "44.84587",
    "lng": "10.44375"
  },
  {
    "country": "IT",
    "name": "Sorbara",
    "lat": "44.74808",
    "lng": "11.00731"
  },
  {
    "country": "IT",
    "name": "Sorano",
    "lat": "42.68118",
    "lng": "11.71943"
  },
  {
    "country": "IT",
    "name": "Soragna",
    "lat": "44.92686",
    "lng": "10.12013"
  },
  {
    "country": "IT",
    "name": "Sora",
    "lat": "41.71829",
    "lng": "13.61356"
  },
  {
    "country": "IT",
    "name": "Soprabolzano",
    "lat": "46.52899",
    "lng": "11.40408"
  },
  {
    "country": "IT",
    "name": "Sonnino",
    "lat": "41.41673",
    "lng": "13.24592"
  },
  {
    "country": "IT",
    "name": "Sonico",
    "lat": "46.1664",
    "lng": "10.35071"
  },
  {
    "country": "IT",
    "name": "Sondrio",
    "lat": "46.16852",
    "lng": "9.87134"
  },
  {
    "country": "IT",
    "name": "Sondalo",
    "lat": "46.32983",
    "lng": "10.3269"
  },
  {
    "country": "IT",
    "name": "Soncino",
    "lat": "45.40033",
    "lng": "9.86845"
  },
  {
    "country": "IT",
    "name": "Sona",
    "lat": "45.43271",
    "lng": "10.8399"
  },
  {
    "country": "IT",
    "name": "Somma Vesuviana",
    "lat": "40.87329",
    "lng": "14.43865"
  },
  {
    "country": "IT",
    "name": "Sommariva Perno",
    "lat": "44.74564",
    "lng": "7.90063"
  },
  {
    "country": "IT",
    "name": "Sommariva del Bosco",
    "lat": "44.77257",
    "lng": "7.78177"
  },
  {
    "country": "IT",
    "name": "Somma Lombardo",
    "lat": "45.68213",
    "lng": "8.70759"
  },
  {
    "country": "IT",
    "name": "Sommacampagna",
    "lat": "45.40528",
    "lng": "10.84382"
  },
  {
    "country": "IT",
    "name": "Solto Collina",
    "lat": "45.7823",
    "lng": "10.02638"
  },
  {
    "country": "IT",
    "name": "Solopaca",
    "lat": "41.19535",
    "lng": "14.54767"
  },
  {
    "country": "IT",
    "name": "Solofra",
    "lat": "40.83343",
    "lng": "14.83705"
  },
  {
    "country": "IT",
    "name": "Solignano Nuovo",
    "lat": "44.52746",
    "lng": "10.92626"
  },
  {
    "country": "IT",
    "name": "Soliera",
    "lat": "44.73387",
    "lng": "10.92177"
  },
  {
    "country": "IT",
    "name": "Solferino",
    "lat": "45.37236",
    "lng": "10.56648"
  },
  {
    "country": "IT",
    "name": "Soleto",
    "lat": "40.18781",
    "lng": "18.2063"
  },
  {
    "country": "IT",
    "name": "Solesino",
    "lat": "45.17922",
    "lng": "11.74647"
  },
  {
    "country": "IT",
    "name": "Solero",
    "lat": "44.91835",
    "lng": "8.50754"
  },
  {
    "country": "IT",
    "name": "Soldano",
    "lat": "43.82954",
    "lng": "7.65627"
  },
  {
    "country": "IT",
    "name": "Solbiate Olona",
    "lat": "45.65028",
    "lng": "8.88198"
  },
  {
    "country": "IT",
    "name": "Solbiate Arno",
    "lat": "45.7196",
    "lng": "8.81372"
  },
  {
    "country": "IT",
    "name": "Solarolo Rainerio",
    "lat": "45.08126",
    "lng": "10.35711"
  },
  {
    "country": "IT",
    "name": "Solarolo",
    "lat": "44.35892",
    "lng": "11.84661"
  },
  {
    "country": "IT",
    "name": "Solaro",
    "lat": "45.61427",
    "lng": "9.08304"
  },
  {
    "country": "IT",
    "name": "Solaro",
    "lat": "44.8799",
    "lng": "9.17315"
  },
  {
    "country": "IT",
    "name": "Solagna",
    "lat": "45.81951",
    "lng": "11.71787"
  },
  {
    "country": "IT",
    "name": "Sogliano Cavour",
    "lat": "40.14827",
    "lng": "18.19741"
  },
  {
    "country": "IT",
    "name": "Sogliano al Rubicone",
    "lat": "44.005",
    "lng": "12.30122"
  },
  {
    "country": "IT",
    "name": "Soddì",
    "lat": "40.12991",
    "lng": "8.87798"
  },
  {
    "country": "IT",
    "name": "Soci",
    "lat": "43.72821",
    "lng": "11.81096"
  },
  {
    "country": "IT",
    "name": "Soave",
    "lat": "45.41955",
    "lng": "11.24594"
  },
  {
    "country": "IT",
    "name": "Soave",
    "lat": "45.19509",
    "lng": "10.72365"
  },
  {
    "country": "IT",
    "name": "Sluderno",
    "lat": "46.66524",
    "lng": "10.58345"
  },
  {
    "country": "IT",
    "name": "Sizzano",
    "lat": "45.57663",
    "lng": "8.43613"
  },
  {
    "country": "IT",
    "name": "Siziano",
    "lat": "45.31606",
    "lng": "9.20357"
  },
  {
    "country": "IT",
    "name": "Siviano",
    "lat": "45.71487",
    "lng": "10.08026"
  },
  {
    "country": "IT",
    "name": "Siusi",
    "lat": "46.54133",
    "lng": "11.55868"
  },
  {
    "country": "IT",
    "name": "Sistiana-Visogliano",
    "lat": "45.77237",
    "lng": "13.63824"
  },
  {
    "country": "IT",
    "name": "Sissa",
    "lat": "44.95927",
    "lng": "10.26058"
  },
  {
    "country": "IT",
    "name": "Siror",
    "lat": "46.18784",
    "lng": "11.83116"
  },
  {
    "country": "IT",
    "name": "Sirolo",
    "lat": "43.52246",
    "lng": "13.61498"
  },
  {
    "country": "IT",
    "name": "Sirmione",
    "lat": "45.49744",
    "lng": "10.60507"
  },
  {
    "country": "IT",
    "name": "Sirignano",
    "lat": "40.94969",
    "lng": "14.62935"
  },
  {
    "country": "IT",
    "name": "Siniscola",
    "lat": "40.57344",
    "lng": "9.69695"
  },
  {
    "country": "IT",
    "name": "Sindia",
    "lat": "40.29518",
    "lng": "8.65707"
  },
  {
    "country": "IT",
    "name": "Sinalunga",
    "lat": "43.21492",
    "lng": "11.74507"
  },
  {
    "country": "IT",
    "name": "Silvi",
    "lat": "42.54984",
    "lng": "14.11759"
  },
  {
    "country": "IT",
    "name": "Silvano Pietra",
    "lat": "45.03923",
    "lng": "8.94637"
  },
  {
    "country": "IT",
    "name": "Silvano d'Orba",
    "lat": "44.6858",
    "lng": "8.67182"
  },
  {
    "country": "IT",
    "name": "Sillavengo",
    "lat": "45.52067",
    "lng": "8.44103"
  },
  {
    "country": "IT",
    "name": "Sillano",
    "lat": "44.22298",
    "lng": "10.30235"
  },
  {
    "country": "IT",
    "name": "Siligo",
    "lat": "40.57483",
    "lng": "8.72835"
  },
  {
    "country": "IT",
    "name": "Silea",
    "lat": "45.65444",
    "lng": "12.29701"
  },
  {
    "country": "IT",
    "name": "Silanus",
    "lat": "40.28709",
    "lng": "8.89199"
  },
  {
    "country": "IT",
    "name": "Silandro",
    "lat": "46.62831",
    "lng": "10.76809"
  },
  {
    "country": "IT",
    "name": "Signa",
    "lat": "43.7942",
    "lng": "11.1036"
  },
  {
    "country": "IT",
    "name": "Sigillo",
    "lat": "43.33111",
    "lng": "12.74059"
  },
  {
    "country": "IT",
    "name": "Siena",
    "lat": "43.31822",
    "lng": "11.33064"
  },
  {
    "country": "IT",
    "name": "Sicignano degli Alburni",
    "lat": "40.55882",
    "lng": "15.3056"
  },
  {
    "country": "IT",
    "name": "Siano",
    "lat": "40.80207",
    "lng": "14.69334"
  },
  {
    "country": "IT",
    "name": "Sgurgola",
    "lat": "41.66897",
    "lng": "13.15009"
  },
  {
    "country": "IT",
    "name": "Sgonico",
    "lat": "45.73583",
    "lng": "13.74708"
  },
  {
    "country": "IT",
    "name": "Sforzacosta",
    "lat": "43.25676",
    "lng": "13.42284"
  },
  {
    "country": "IT",
    "name": "Sezze",
    "lat": "41.50032",
    "lng": "13.06176"
  },
  {
    "country": "IT",
    "name": "Seveso",
    "lat": "45.6467",
    "lng": "9.14296"
  },
  {
    "country": "IT",
    "name": "Settimo Vittone",
    "lat": "45.54929",
    "lng": "7.83328"
  },
  {
    "country": "IT",
    "name": "Settimo Torinese",
    "lat": "45.13925",
    "lng": "7.77008"
  },
  {
    "country": "IT",
    "name": "Settimo Rottaro",
    "lat": "45.40776",
    "lng": "7.99352"
  },
  {
    "country": "IT",
    "name": "Settimo",
    "lat": "45.47929",
    "lng": "10.9091"
  },
  {
    "country": "IT",
    "name": "Settefrati",
    "lat": "41.67045",
    "lng": "13.8507"
  },
  {
    "country": "IT",
    "name": "Sestri Levante",
    "lat": "44.27317",
    "lng": "9.39683"
  },
  {
    "country": "IT",
    "name": "Sestriere",
    "lat": "44.95864",
    "lng": "6.87751"
  },
  {
    "country": "IT",
    "name": "Sesto San Giovanni",
    "lat": "45.53329",
    "lng": "9.22585"
  },
  {
    "country": "IT",
    "name": "Sestola",
    "lat": "44.22994",
    "lng": "10.77349"
  },
  {
    "country": "IT",
    "name": "Sesto Imolese",
    "lat": "44.45952",
    "lng": "11.72919"
  },
  {
    "country": "IT",
    "name": "Sesto Fiorentino",
    "lat": "43.83193",
    "lng": "11.19924"
  },
  {
    "country": "IT",
    "name": "Sesto ed Uniti",
    "lat": "45.17647",
    "lng": "9.91407"
  },
  {
    "country": "IT",
    "name": "Sesto Campano",
    "lat": "41.42042",
    "lng": "14.07782"
  },
  {
    "country": "IT",
    "name": "Sesto Calende",
    "lat": "45.72608",
    "lng": "8.63397"
  },
  {
    "country": "IT",
    "name": "Sesto al Reghena",
    "lat": "45.84938",
    "lng": "12.81295"
  },
  {
    "country": "IT",
    "name": "Sesto",
    "lat": "46.70216",
    "lng": "12.34962"
  },
  {
    "country": "IT",
    "name": "Sestino",
    "lat": "43.70966",
    "lng": "12.29785"
  },
  {
    "country": "IT",
    "name": "Sesta Godano",
    "lat": "44.29375",
    "lng": "9.67535"
  },
  {
    "country": "IT",
    "name": "Sessano del Molise",
    "lat": "41.63926",
    "lng": "14.32779"
  },
  {
    "country": "IT",
    "name": "Sessa Cilento",
    "lat": "40.2592",
    "lng": "15.07576"
  },
  {
    "country": "IT",
    "name": "Sessa Aurunca",
    "lat": "41.23987",
    "lng": "13.92966"
  },
  {
    "country": "IT",
    "name": "Servigliano",
    "lat": "43.07993",
    "lng": "13.49268"
  },
  {
    "country": "IT",
    "name": "Serrone",
    "lat": "41.84212",
    "lng": "13.09519"
  },
  {
    "country": "IT",
    "name": "Serre di Rapolano",
    "lat": "43.25658",
    "lng": "11.61655"
  },
  {
    "country": "IT",
    "name": "Serre",
    "lat": "40.58251",
    "lng": "15.18555"
  },
  {
    "country": "IT",
    "name": "Serravalle Sesia",
    "lat": "45.68485",
    "lng": "8.3085"
  },
  {
    "country": "IT",
    "name": "Serravalle Scrivia",
    "lat": "44.72277",
    "lng": "8.85635"
  },
  {
    "country": "IT",
    "name": "Serravalle Pistoiese",
    "lat": "43.90605",
    "lng": "10.83271"
  },
  {
    "country": "IT",
    "name": "Serravalle di Chienti",
    "lat": "43.07185",
    "lng": "12.95217"
  },
  {
    "country": "IT",
    "name": "Serravalle Langhe",
    "lat": "44.55995",
    "lng": "8.05944"
  },
  {
    "country": "IT",
    "name": "Serra Sant'Abbondio",
    "lat": "43.49155",
    "lng": "12.77409"
  },
  {
    "country": "IT",
    "name": "Serra San Quirico",
    "lat": "43.44637",
    "lng": "13.02266"
  },
  {
    "country": "IT",
    "name": "Serra Riccò",
    "lat": "44.51071",
    "lng": "8.93806"
  },
  {
    "country": "IT",
    "name": "Serrara Fontana",
    "lat": "40.71475",
    "lng": "13.89593"
  },
  {
    "country": "IT",
    "name": "Serrapetrona",
    "lat": "43.17671",
    "lng": "13.18981"
  },
  {
    "country": "IT",
    "name": "Serrano",
    "lat": "40.18438",
    "lng": "18.35156"
  },
  {
    "country": "IT",
    "name": "Serramonacesca",
    "lat": "42.24795",
    "lng": "14.09297"
  },
  {
    "country": "IT",
    "name": "Serramezzana",
    "lat": "40.2446",
    "lng": "15.03246"
  },
  {
    "country": "IT",
    "name": "Serramazzoni",
    "lat": "44.42735",
    "lng": "10.79055"
  },
  {
    "country": "IT",
    "name": "Serralunga di Crea",
    "lat": "45.1011",
    "lng": "8.28069"
  },
  {
    "country": "IT",
    "name": "Serra de' Conti",
    "lat": "43.54196",
    "lng": "13.03566"
  },
  {
    "country": "IT",
    "name": "Serracapriola",
    "lat": "41.80912",
    "lng": "15.16098"
  },
  {
    "country": "IT",
    "name": "Serole",
    "lat": "44.55404",
    "lng": "8.25974"
  },
  {
    "country": "IT",
    "name": "Sernaglia della Battaglia",
    "lat": "45.87147",
    "lng": "12.13302"
  },
  {
    "country": "IT",
    "name": "Sermoneta",
    "lat": "41.54919",
    "lng": "12.98481"
  },
  {
    "country": "IT",
    "name": "Sermide",
    "lat": "45.00349",
    "lng": "11.2929"
  },
  {
    "country": "IT",
    "name": "Serle",
    "lat": "45.56137",
    "lng": "10.36821"
  },
  {
    "country": "IT",
    "name": "Serino",
    "lat": "40.85481",
    "lng": "14.87224"
  },
  {
    "country": "IT",
    "name": "Serina",
    "lat": "45.87071",
    "lng": "9.73102"
  },
  {
    "country": "IT",
    "name": "Seriate",
    "lat": "45.68532",
    "lng": "9.72487"
  },
  {
    "country": "IT",
    "name": "Sergnano",
    "lat": "45.42755",
    "lng": "9.70122"
  },
  {
    "country": "IT",
    "name": "Seren del Grappa",
    "lat": "45.99594",
    "lng": "11.85624"
  },
  {
    "country": "IT",
    "name": "Seregno",
    "lat": "45.65002",
    "lng": "9.20548"
  },
  {
    "country": "IT",
    "name": "Seravezza",
    "lat": "43.99471",
    "lng": "10.2272"
  },
  {
    "country": "IT",
    "name": "Sequals",
    "lat": "46.16385",
    "lng": "12.83037"
  },
  {
    "country": "IT",
    "name": "Sepino",
    "lat": "41.40782",
    "lng": "14.61938"
  },
  {
    "country": "IT",
    "name": "Sennori",
    "lat": "40.7878",
    "lng": "8.59285"
  },
  {
    "country": "IT",
    "name": "Sennariolo",
    "lat": "40.21235",
    "lng": "8.55572"
  },
  {
    "country": "IT",
    "name": "Senna Lodigiana",
    "lat": "45.15023",
    "lng": "9.59379"
  },
  {
    "country": "IT",
    "name": "Senise",
    "lat": "40.14616",
    "lng": "16.28867"
  },
  {
    "country": "IT",
    "name": "Senigallia",
    "lat": "43.71626",
    "lng": "13.20882"
  },
  {
    "country": "IT",
    "name": "Seniga",
    "lat": "45.24479",
    "lng": "10.17759"
  },
  {
    "country": "IT",
    "name": "Senerchia",
    "lat": "40.74133",
    "lng": "15.20502"
  },
  {
    "country": "IT",
    "name": "Seneghe",
    "lat": "40.08128",
    "lng": "8.61353"
  },
  {
    "country": "IT",
    "name": "Senale",
    "lat": "46.51077",
    "lng": "11.11012"
  },
  {
    "country": "IT",
    "name": "Senago",
    "lat": "45.57562",
    "lng": "9.1262"
  },
  {
    "country": "IT",
    "name": "Semiana",
    "lat": "45.13737",
    "lng": "8.72973"
  },
  {
    "country": "IT",
    "name": "Semestene",
    "lat": "40.39846",
    "lng": "8.72542"
  },
  {
    "country": "IT",
    "name": "Selvino",
    "lat": "45.78525",
    "lng": "9.75292"
  },
  {
    "country": "IT",
    "name": "Selvazzano Dentro",
    "lat": "45.38764",
    "lng": "11.79232"
  },
  {
    "country": "IT",
    "name": "Selvatelle",
    "lat": "43.56281",
    "lng": "10.69091"
  },
  {
    "country": "IT",
    "name": "Selva di Cadore",
    "lat": "46.45028",
    "lng": "12.05694"
  },
  {
    "country": "IT",
    "name": "Selva dei Molini",
    "lat": "46.89031",
    "lng": "11.85832"
  },
  {
    "country": "IT",
    "name": "Selva",
    "lat": "46.55472",
    "lng": "11.76038"
  },
  {
    "country": "IT",
    "name": "Sellero",
    "lat": "46.05145",
    "lng": "10.34764"
  },
  {
    "country": "IT",
    "name": "Sellano",
    "lat": "42.88735",
    "lng": "12.92311"
  },
  {
    "country": "IT",
    "name": "Selci",
    "lat": "42.30293",
    "lng": "12.62135"
  },
  {
    "country": "IT",
    "name": "Segrate",
    "lat": "45.49185",
    "lng": "9.29812"
  },
  {
    "country": "IT",
    "name": "Segni",
    "lat": "41.68893",
    "lng": "13.01934"
  },
  {
    "country": "IT",
    "name": "Seggiano",
    "lat": "42.92897",
    "lng": "11.55736"
  },
  {
    "country": "IT",
    "name": "Sefro",
    "lat": "43.14743",
    "lng": "12.94859"
  },
  {
    "country": "IT",
    "name": "Sedrina",
    "lat": "45.78067",
    "lng": "9.62362"
  },
  {
    "country": "IT",
    "name": "Sedriano",
    "lat": "45.49105",
    "lng": "8.97161"
  },
  {
    "country": "IT",
    "name": "Sedini",
    "lat": "40.85277",
    "lng": "8.8167"
  },
  {
    "country": "IT",
    "name": "Sedilo",
    "lat": "40.17292",
    "lng": "8.91993"
  },
  {
    "country": "IT",
    "name": "Sedico",
    "lat": "46.10563",
    "lng": "12.0933"
  },
  {
    "country": "IT",
    "name": "Sedegliano",
    "lat": "46.01396",
    "lng": "12.97734"
  },
  {
    "country": "IT",
    "name": "Secugnago",
    "lat": "45.23132",
    "lng": "9.59394"
  },
  {
    "country": "IT",
    "name": "Seclì",
    "lat": "40.11897",
    "lng": "18.10931"
  },
  {
    "country": "IT",
    "name": "Secinaro",
    "lat": "42.15062",
    "lng": "13.68145"
  },
  {
    "country": "IT",
    "name": "Secchiano",
    "lat": "43.92399",
    "lng": "12.31615"
  },
  {
    "country": "IT",
    "name": "Seborga",
    "lat": "43.8273",
    "lng": "7.69585"
  },
  {
    "country": "IT",
    "name": "Seano",
    "lat": "43.83035",
    "lng": "11.02122"
  },
  {
    "country": "IT",
    "name": "Scurcola Marsicana",
    "lat": "42.06313",
    "lng": "13.33919"
  },
  {
    "country": "IT",
    "name": "Scorzè",
    "lat": "45.57405",
    "lng": "12.11156"
  },
  {
    "country": "IT",
    "name": "Scortichino",
    "lat": "44.88333",
    "lng": "11.33333"
  },
  {
    "country": "IT",
    "name": "Scorrano",
    "lat": "40.09018",
    "lng": "18.29993"
  },
  {
    "country": "IT",
    "name": "Scoppito",
    "lat": "42.36948",
    "lng": "13.25936"
  },
  {
    "country": "IT",
    "name": "Scopello",
    "lat": "45.77369",
    "lng": "8.09435"
  },
  {
    "country": "IT",
    "name": "Scontrone",
    "lat": "41.74681",
    "lng": "14.0388"
  },
  {
    "country": "IT",
    "name": "Scomigo",
    "lat": "45.94255",
    "lng": "12.32014"
  },
  {
    "country": "IT",
    "name": "Sciolze",
    "lat": "45.09453",
    "lng": "7.87818"
  },
  {
    "country": "IT",
    "name": "Naz-Sciaves - Natz-Schabs",
    "lat": "46.76883",
    "lng": "11.66558"
  },
  {
    "country": "IT",
    "name": "Schio",
    "lat": "45.71262",
    "lng": "11.35671"
  },
  {
    "country": "IT",
    "name": "Schilpario",
    "lat": "46.00874",
    "lng": "10.15534"
  },
  {
    "country": "IT",
    "name": "Schiavon",
    "lat": "45.69654",
    "lng": "11.64573"
  },
  {
    "country": "IT",
    "name": "Schiavi di Abruzzo",
    "lat": "41.81311",
    "lng": "14.48655"
  },
  {
    "country": "IT",
    "name": "Gazzada Schianno",
    "lat": "45.78017",
    "lng": "8.83344"
  },
  {
    "country": "IT",
    "name": "Scheggino",
    "lat": "42.71304",
    "lng": "12.83007"
  },
  {
    "country": "IT",
    "name": "Scheggia",
    "lat": "43.40364",
    "lng": "12.66584"
  },
  {
    "country": "IT",
    "name": "Scerni",
    "lat": "42.10418",
    "lng": "14.57428"
  },
  {
    "country": "IT",
    "name": "Scerne",
    "lat": "42.64754",
    "lng": "14.03791"
  },
  {
    "country": "IT",
    "name": "Scarperia",
    "lat": "43.99357",
    "lng": "11.35415"
  },
  {
    "country": "IT",
    "name": "Scarnafigi",
    "lat": "44.67944",
    "lng": "7.56513"
  },
  {
    "country": "IT",
    "name": "Scarmagno",
    "lat": "45.38492",
    "lng": "7.8411"
  },
  {
    "country": "IT",
    "name": "Scarlino",
    "lat": "42.90799",
    "lng": "10.85148"
  },
  {
    "country": "IT",
    "name": "Scario",
    "lat": "40.06207",
    "lng": "15.47421"
  },
  {
    "country": "IT",
    "name": "Scapoli",
    "lat": "41.61447",
    "lng": "14.05929"
  },
  {
    "country": "IT",
    "name": "Scanzano Jonico",
    "lat": "40.25085",
    "lng": "16.69824"
  },
  {
    "country": "IT",
    "name": "Scansano",
    "lat": "42.68779",
    "lng": "11.32975"
  },
  {
    "country": "IT",
    "name": "Scano di Montiferro",
    "lat": "40.21525",
    "lng": "8.58692"
  },
  {
    "country": "IT",
    "name": "Scanno",
    "lat": "41.90442",
    "lng": "13.87961"
  },
  {
    "country": "IT",
    "name": "Scandriglia",
    "lat": "42.16128",
    "lng": "12.84096"
  },
  {
    "country": "IT",
    "name": "Scandolara Ripa d'Oglio",
    "lat": "45.22171",
    "lng": "10.15717"
  },
  {
    "country": "IT",
    "name": "Scandolara Ravara",
    "lat": "45.05309",
    "lng": "10.30215"
  },
  {
    "country": "IT",
    "name": "Scandicci",
    "lat": "43.75423",
    "lng": "11.18794"
  },
  {
    "country": "IT",
    "name": "Scandiano",
    "lat": "44.5983",
    "lng": "10.69558"
  },
  {
    "country": "IT",
    "name": "Scampitella",
    "lat": "41.09252",
    "lng": "15.29995"
  },
  {
    "country": "IT",
    "name": "Scaltenigo",
    "lat": "45.4712",
    "lng": "12.08106"
  },
  {
    "country": "IT",
    "name": "Scalenghe",
    "lat": "44.8899",
    "lng": "7.49423"
  },
  {
    "country": "IT",
    "name": "Scaldasole",
    "lat": "45.12495",
    "lng": "8.91029"
  },
  {
    "country": "IT",
    "name": "Scala",
    "lat": "40.65665",
    "lng": "14.60761"
  },
  {
    "country": "IT",
    "name": "Scafati",
    "lat": "40.7602",
    "lng": "14.53723"
  },
  {
    "country": "IT",
    "name": "Scafa",
    "lat": "42.26575",
    "lng": "13.99665"
  },
  {
    "country": "IT",
    "name": "Savona",
    "lat": "44.30905",
    "lng": "8.47715"
  },
  {
    "country": "IT",
    "name": "Savoia di Lucania",
    "lat": "40.56949",
    "lng": "15.55132"
  },
  {
    "country": "IT",
    "name": "Savogna d'Isonzo",
    "lat": "45.90894",
    "lng": "13.57936"
  },
  {
    "country": "IT",
    "name": "Saviore",
    "lat": "46.08049",
    "lng": "10.39823"
  },
  {
    "country": "IT",
    "name": "Savio",
    "lat": "44.31139",
    "lng": "12.29472"
  },
  {
    "country": "IT",
    "name": "Savigno",
    "lat": "44.39186",
    "lng": "11.07481"
  },
  {
    "country": "IT",
    "name": "Savignano sul Rubicone",
    "lat": "44.09009",
    "lng": "12.39935"
  },
  {
    "country": "IT",
    "name": "Savignano sul Panaro",
    "lat": "44.48036",
    "lng": "11.0351"
  },
  {
    "country": "IT",
    "name": "Savignano Irpino",
    "lat": "41.22698",
    "lng": "15.17933"
  },
  {
    "country": "IT",
    "name": "Savigliano",
    "lat": "44.64808",
    "lng": "7.65677"
  },
  {
    "country": "IT",
    "name": "Saviano",
    "lat": "40.90507",
    "lng": "14.50498"
  },
  {
    "country": "IT",
    "name": "Sava",
    "lat": "40.40203",
    "lng": "17.55267"
  },
  {
    "country": "IT",
    "name": "Sauze d'Oulx",
    "lat": "45.02659",
    "lng": "6.86074"
  },
  {
    "country": "IT",
    "name": "Sauze di Cesana",
    "lat": "44.94058",
    "lng": "6.85988"
  },
  {
    "country": "IT",
    "name": "Sauris di Sotto",
    "lat": "46.46624",
    "lng": "12.70852"
  },
  {
    "country": "IT",
    "name": "Satriano di Lucania",
    "lat": "40.54296",
    "lng": "15.64024"
  },
  {
    "country": "IT",
    "name": "Sassuolo",
    "lat": "44.5432",
    "lng": "10.7848"
  },
  {
    "country": "IT",
    "name": "Sasso Marconi",
    "lat": "44.40064",
    "lng": "11.25177"
  },
  {
    "country": "IT",
    "name": "Sassoferrato",
    "lat": "43.43109",
    "lng": "12.8566"
  },
  {
    "country": "IT",
    "name": "Sassofeltrio",
    "lat": "43.89212",
    "lng": "12.50974"
  },
  {
    "country": "IT",
    "name": "Sasso di Castalda",
    "lat": "40.48525",
    "lng": "15.67569"
  },
  {
    "country": "IT",
    "name": "Sassocorvaro",
    "lat": "43.78266",
    "lng": "12.4991"
  },
  {
    "country": "IT",
    "name": "Sassinoro",
    "lat": "41.37472",
    "lng": "14.66453"
  },
  {
    "country": "IT",
    "name": "Sassetta",
    "lat": "43.12874",
    "lng": "10.64359"
  },
  {
    "country": "IT",
    "name": "Sassello",
    "lat": "44.48036",
    "lng": "8.49375"
  },
  {
    "country": "IT",
    "name": "Sassari",
    "lat": "40.72586",
    "lng": "8.55552"
  },
  {
    "country": "IT",
    "name": "Sassano",
    "lat": "40.3403",
    "lng": "15.56555"
  },
  {
    "country": "IT",
    "name": "Sassa",
    "lat": "42.35204",
    "lng": "13.29924"
  },
  {
    "country": "IT",
    "name": "Sarzana",
    "lat": "44.11178",
    "lng": "9.9622"
  },
  {
    "country": "IT",
    "name": "Sarule",
    "lat": "40.22796",
    "lng": "9.16644"
  },
  {
    "country": "IT",
    "name": "Sartirana Lomellina",
    "lat": "45.11352",
    "lng": "8.66711"
  },
  {
    "country": "IT",
    "name": "Sarteano",
    "lat": "42.99193",
    "lng": "11.86472"
  },
  {
    "country": "IT",
    "name": "Sarsina",
    "lat": "43.91981",
    "lng": "12.14255"
  },
  {
    "country": "IT",
    "name": "Saronno",
    "lat": "45.62513",
    "lng": "9.03517"
  },
  {
    "country": "IT",
    "name": "Sarno",
    "lat": "40.80748",
    "lng": "14.62151"
  },
  {
    "country": "IT",
    "name": "Sarnico",
    "lat": "45.67099",
    "lng": "9.96152"
  },
  {
    "country": "IT",
    "name": "Sarnano",
    "lat": "43.03475",
    "lng": "13.29818"
  },
  {
    "country": "IT",
    "name": "Sarmeola",
    "lat": "45.424",
    "lng": "11.81674"
  },
  {
    "country": "IT",
    "name": "Sarmede",
    "lat": "45.97625",
    "lng": "12.38581"
  },
  {
    "country": "IT",
    "name": "Sarmato",
    "lat": "45.05679",
    "lng": "9.49683"
  },
  {
    "country": "IT",
    "name": "Sarezzo",
    "lat": "45.66067",
    "lng": "10.1969"
  },
  {
    "country": "IT",
    "name": "Sarezzano",
    "lat": "44.86878",
    "lng": "8.91237"
  },
  {
    "country": "IT",
    "name": "Sarentino",
    "lat": "46.64121",
    "lng": "11.35411"
  },
  {
    "country": "IT",
    "name": "Sarconi",
    "lat": "40.248",
    "lng": "15.88837"
  },
  {
    "country": "IT",
    "name": "Sarcedo",
    "lat": "45.70134",
    "lng": "11.52963"
  },
  {
    "country": "IT",
    "name": "Saracinesco",
    "lat": "42.00332",
    "lng": "12.95329"
  },
  {
    "country": "IT",
    "name": "Sapri",
    "lat": "40.07464",
    "lng": "15.63212"
  },
  {
    "country": "IT",
    "name": "Sappada",
    "lat": "46.56663",
    "lng": "12.68421"
  },
  {
    "country": "IT",
    "name": "San Zenone al Po",
    "lat": "45.10856",
    "lng": "9.36176"
  },
  {
    "country": "IT",
    "name": "San Zenone al Lambro",
    "lat": "45.32681",
    "lng": "9.35598"
  },
  {
    "country": "IT",
    "name": "San Zenone degli Ezzelini",
    "lat": "45.7804",
    "lng": "11.8372"
  },
  {
    "country": "IT",
    "name": "San Zeno di Montagna",
    "lat": "45.63749",
    "lng": "10.73218"
  },
  {
    "country": "IT",
    "name": "Sanzeno",
    "lat": "46.36614",
    "lng": "11.07559"
  },
  {
    "country": "IT",
    "name": "Sanza",
    "lat": "40.24389",
    "lng": "15.55416"
  },
  {
    "country": "IT",
    "name": "San Vittore del Lazio",
    "lat": "41.46212",
    "lng": "13.93367"
  },
  {
    "country": "IT",
    "name": "San Vittore",
    "lat": "46.30799",
    "lng": "9.3831"
  },
  {
    "country": "IT",
    "name": "San Vito Romano",
    "lat": "41.88001",
    "lng": "12.97793"
  },
  {
    "country": "IT",
    "name": "San Vito di Leguzzano",
    "lat": "45.68494",
    "lng": "11.38872"
  },
  {
    "country": "IT",
    "name": "San Vito di Fagagna",
    "lat": "46.09103",
    "lng": "13.06569"
  },
  {
    "country": "IT",
    "name": "San Vito",
    "lat": "46.46278",
    "lng": "12.20608"
  },
  {
    "country": "IT",
    "name": "San Vito dei Normanni",
    "lat": "40.65642",
    "lng": "17.70814"
  },
  {
    "country": "IT",
    "name": "San Vito Chietino",
    "lat": "42.29014",
    "lng": "14.4427"
  },
  {
    "country": "IT",
    "name": "San Vito al Tagliamento",
    "lat": "45.9168",
    "lng": "12.85945"
  },
  {
    "country": "IT",
    "name": "San Vito",
    "lat": "45.75514",
    "lng": "11.91553"
  },
  {
    "country": "IT",
    "name": "San Vito",
    "lat": "44.55822",
    "lng": "10.97432"
  },
  {
    "country": "IT",
    "name": "San Vincenzo Valle Roveto",
    "lat": "41.84452",
    "lng": "13.53566"
  },
  {
    "country": "IT",
    "name": "San Vincenzo",
    "lat": "43.09061",
    "lng": "10.54246"
  },
  {
    "country": "IT",
    "name": "San Vero Milis",
    "lat": "40.01377",
    "lng": "8.59833"
  },
  {
    "country": "IT",
    "name": "San Vendemiano",
    "lat": "45.88732",
    "lng": "12.35164"
  },
  {
    "country": "IT",
    "name": "San Venanzo",
    "lat": "42.86886",
    "lng": "12.26853"
  },
  {
    "country": "IT",
    "name": "San Valentino Torio",
    "lat": "40.79109",
    "lng": "14.60333"
  },
  {
    "country": "IT",
    "name": "San Valentino in Abruzzo Citeriore",
    "lat": "42.23304",
    "lng": "13.98561"
  },
  {
    "country": "IT",
    "name": "San Valentino",
    "lat": "45.79039",
    "lng": "13.41236"
  },
  {
    "country": "IT",
    "name": "Santu Lussurgiu",
    "lat": "40.1411",
    "lng": "8.65539"
  },
  {
    "country": "IT",
    "name": "San Stino di Livenza",
    "lat": "45.72559",
    "lng": "12.68971"
  },
  {
    "country": "IT",
    "name": "Santo Stefano Ticino",
    "lat": "45.48635",
    "lng": "8.91582"
  },
  {
    "country": "IT",
    "name": "Santo Stefano di Sessanio",
    "lat": "42.34339",
    "lng": "13.64477"
  },
  {
    "country": "IT",
    "name": "Santo Stefano di Magra",
    "lat": "44.14891",
    "lng": "9.92185"
  },
  {
    "country": "IT",
    "name": "Santo Stefano di Cadore",
    "lat": "46.55827",
    "lng": "12.54956"
  },
  {
    "country": "IT",
    "name": "Santo Stefano del Sole",
    "lat": "40.89414",
    "lng": "14.86674"
  },
  {
    "country": "IT",
    "name": "Santo Stefano d'Aveto",
    "lat": "44.54677",
    "lng": "9.45325"
  },
  {
    "country": "IT",
    "name": "Santo Stefano Belbo",
    "lat": "44.71023",
    "lng": "8.23269"
  },
  {
    "country": "IT",
    "name": "Santo Stefano al Mare",
    "lat": "43.83855",
    "lng": "7.89728"
  },
  {
    "country": "IT",
    "name": "Santorso",
    "lat": "45.73383",
    "lng": "11.38785"
  },
  {
    "country": "IT",
    "name": "Sant'Oreste",
    "lat": "42.23298",
    "lng": "12.51507"
  },
  {
    "country": "IT",
    "name": "Santopadre",
    "lat": "41.60193",
    "lng": "13.63548"
  },
  {
    "country": "IT",
    "name": "Sant'Omero",
    "lat": "42.79011",
    "lng": "13.78906"
  },
  {
    "country": "IT",
    "name": "Santomenna",
    "lat": "40.80685",
    "lng": "15.32639"
  },
  {
    "country": "IT",
    "name": "Celat-San Tomaso Agordino",
    "lat": "46.38072",
    "lng": "11.97439"
  },
  {
    "country": "IT",
    "name": "Sant'Ippolito",
    "lat": "43.67972",
    "lng": "12.87581"
  },
  {
    "country": "IT",
    "name": "Sant'Ilario d'Enza",
    "lat": "44.7589",
    "lng": "10.44737"
  },
  {
    "country": "IT",
    "name": "Santi Cosma e Damiano",
    "lat": "41.30091",
    "lng": "13.81565"
  },
  {
    "country": "IT",
    "name": "Santhià",
    "lat": "45.36795",
    "lng": "8.17012"
  },
  {
    "country": "IT",
    "name": "Sant'Eusanio Forconese",
    "lat": "42.28951",
    "lng": "13.52425"
  },
  {
    "country": "IT",
    "name": "Sant'Eusanio del Sangro",
    "lat": "42.16908",
    "lng": "14.32776"
  },
  {
    "country": "IT",
    "name": "Sant'Eufemia a Maiella",
    "lat": "42.12613",
    "lng": "14.02651"
  },
  {
    "country": "IT",
    "name": "Santerno",
    "lat": "44.43697",
    "lng": "12.05533"
  },
  {
    "country": "IT",
    "name": "San Terenzo",
    "lat": "44.08543",
    "lng": "9.89662"
  },
  {
    "country": "IT",
    "name": "San Terenziano",
    "lat": "42.86731",
    "lng": "12.47319"
  },
  {
    "country": "IT",
    "name": "Santeramo in Colle",
    "lat": "40.79236",
    "lng": "16.75873"
  },
  {
    "country": "IT",
    "name": "San Teodoro",
    "lat": "40.77354",
    "lng": "9.66929"
  },
  {
    "country": "IT",
    "name": "Sante Marie",
    "lat": "42.10369",
    "lng": "13.20163"
  },
  {
    "country": "IT",
    "name": "Sant'Elpidio a Mare",
    "lat": "43.23024",
    "lng": "13.68819"
  },
  {
    "country": "IT",
    "name": "Sant'Elia Fiumerapido",
    "lat": "41.53304",
    "lng": "13.86268"
  },
  {
    "country": "IT",
    "name": "Sant'Elia a Pianisi",
    "lat": "41.62043",
    "lng": "14.87523"
  },
  {
    "country": "IT",
    "name": "Sant'Elena Sannita",
    "lat": "41.57525",
    "lng": "14.4707"
  },
  {
    "country": "IT",
    "name": "Sant'Elena",
    "lat": "45.18744",
    "lng": "11.71169"
  },
  {
    "country": "IT",
    "name": "Sant'Egidio alla Vibrata",
    "lat": "42.81705",
    "lng": "13.72164"
  },
  {
    "country": "IT",
    "name": "San Vittoria in Matenano",
    "lat": "43.01975",
    "lng": "13.49618"
  },
  {
    "country": "IT",
    "name": "Santa Vittoria d'Alba",
    "lat": "44.69864",
    "lng": "7.93733"
  },
  {
    "country": "IT",
    "name": "Santa Vittoria",
    "lat": "44.85483",
    "lng": "10.63348"
  },
  {
    "country": "IT",
    "name": "Santa Valburga",
    "lat": "46.55",
    "lng": "11"
  },
  {
    "country": "IT",
    "name": "Santa Teresa Gallura",
    "lat": "41.23859",
    "lng": "9.18873"
  },
  {
    "country": "IT",
    "name": "Santa Tecla-Castelpagano",
    "lat": "40.67353",
    "lng": "14.91806"
  },
  {
    "country": "IT",
    "name": "Santa Sofia",
    "lat": "43.94724",
    "lng": "11.90867"
  },
  {
    "country": "IT",
    "name": "Santa Rufina",
    "lat": "42.40897",
    "lng": "12.91843"
  },
  {
    "country": "IT",
    "name": "Sant'Arsenio",
    "lat": "40.47109",
    "lng": "15.48401"
  },
  {
    "country": "IT",
    "name": "Sant'Arpino",
    "lat": "40.95716",
    "lng": "14.25075"
  },
  {
    "country": "IT",
    "name": "Sant'Arcangelo Trimonte",
    "lat": "41.16901",
    "lng": "14.93883"
  },
  {
    "country": "IT",
    "name": "Santarcangelo",
    "lat": "44.06326",
    "lng": "12.44657"
  },
  {
    "country": "IT",
    "name": "Sant'Arcangelo",
    "lat": "40.24852",
    "lng": "16.27046"
  },
  {
    "country": "IT",
    "name": "Sant'Apollinare",
    "lat": "41.40176",
    "lng": "13.82992"
  },
  {
    "country": "IT",
    "name": "Santa Paolina",
    "lat": "41.02202",
    "lng": "14.8463"
  },
  {
    "country": "IT",
    "name": "Roncofreddo-Santa Paola",
    "lat": "44.04251",
    "lng": "12.31523"
  },
  {
    "country": "IT",
    "name": "Sant'Antonino di Susa",
    "lat": "45.10763",
    "lng": "7.27333"
  },
  {
    "country": "IT",
    "name": "Sant'Antonio Abate",
    "lat": "40.72152",
    "lng": "14.54021"
  },
  {
    "country": "IT",
    "name": "Sant'Antonio",
    "lat": "46.4611",
    "lng": "10.41738"
  },
  {
    "country": "IT",
    "name": "Sant'Antonio",
    "lat": "45.19649",
    "lng": "10.79381"
  },
  {
    "country": "IT",
    "name": "Sant'Antonio di Gallura",
    "lat": "40.99146",
    "lng": "9.30153"
  },
  {
    "country": "IT",
    "name": "Sant'Antimo",
    "lat": "40.94223",
    "lng": "14.23476"
  },
  {
    "country": "IT",
    "name": "Sant'Anna d'Alfaedo",
    "lat": "45.62719",
    "lng": "10.95168"
  },
  {
    "country": "IT",
    "name": "Sant'Angelo Romano",
    "lat": "42.0357",
    "lng": "12.71342"
  },
  {
    "country": "IT",
    "name": "Sant'Angelo Lomellina",
    "lat": "45.24663",
    "lng": "8.64317"
  },
  {
    "country": "IT",
    "name": "Sant'Angelo Lodigiano",
    "lat": "45.23526",
    "lng": "9.40651"
  },
  {
    "country": "IT",
    "name": "Sant'Angelo Limosano",
    "lat": "41.69266",
    "lng": "14.60346"
  },
  {
    "country": "IT",
    "name": "Sant'Angelo le Fratte",
    "lat": "40.5449",
    "lng": "15.56156"
  },
  {
    "country": "IT",
    "name": "Sant'Angelo in Vado",
    "lat": "43.66526",
    "lng": "12.41757"
  },
  {
    "country": "IT",
    "name": "Sant'Angelo in Pontano",
    "lat": "43.0978",
    "lng": "13.3969"
  },
  {
    "country": "IT",
    "name": "Sant'Angelo in Lizzola",
    "lat": "43.82696",
    "lng": "12.80076"
  },
  {
    "country": "IT",
    "name": "Sant'Angelo in Formis",
    "lat": "41.11667",
    "lng": "14.25"
  },
  {
    "country": "IT",
    "name": "Sant'Angelo di Piove di Sacco",
    "lat": "45.31735",
    "lng": "12.00941"
  },
  {
    "country": "IT",
    "name": "Sant'Angelo del Pesco",
    "lat": "41.88193",
    "lng": "14.25354"
  },
  {
    "country": "IT",
    "name": "Sant'Angelo dei Lombardi",
    "lat": "40.92937",
    "lng": "15.17535"
  },
  {
    "country": "IT",
    "name": "Sant'Angelo d'Alife",
    "lat": "41.36119",
    "lng": "14.26125"
  },
  {
    "country": "IT",
    "name": "Sant'Angelo A Scala",
    "lat": "40.97465",
    "lng": "14.74041"
  },
  {
    "country": "IT",
    "name": "Sant'Angelo A Fasanella",
    "lat": "40.45724",
    "lng": "15.34091"
  },
  {
    "country": "IT",
    "name": "Sant'Angelo",
    "lat": "45.52031",
    "lng": "12.01862"
  },
  {
    "country": "IT",
    "name": "Sant'Andrea in Casale",
    "lat": "43.93333",
    "lng": "12.65"
  },
  {
    "country": "IT",
    "name": "Sant'Andrea di Conza",
    "lat": "40.84482",
    "lng": "15.36965"
  },
  {
    "country": "IT",
    "name": "Sant'Andrea del Garigliano",
    "lat": "41.36868",
    "lng": "13.84198"
  },
  {
    "country": "IT",
    "name": "Santandrà",
    "lat": "45.74778",
    "lng": "12.20111"
  },
  {
    "country": "IT",
    "name": "Sant'Anatolia di Narco",
    "lat": "42.73319",
    "lng": "12.83576"
  },
  {
    "country": "IT",
    "name": "Sant'Anastasia",
    "lat": "40.86842",
    "lng": "14.40196"
  },
  {
    "country": "IT",
    "name": "San Tammaro",
    "lat": "41.07588",
    "lng": "14.23105"
  },
  {
    "country": "IT",
    "name": "Sant'Ambrogio sul Garigliano",
    "lat": "41.39423",
    "lng": "13.86891"
  },
  {
    "country": "IT",
    "name": "Sant'Ambrogio di Valpollicella",
    "lat": "45.52089",
    "lng": "10.83618"
  },
  {
    "country": "IT",
    "name": "Sant'Ambrogio di Torino",
    "lat": "45.09622",
    "lng": "7.366"
  },
  {
    "country": "IT",
    "name": "Santa Marinella",
    "lat": "42.03425",
    "lng": "11.85416"
  },
  {
    "country": "IT",
    "name": "Santa Marina",
    "lat": "40.1052",
    "lng": "15.54153"
  },
  {
    "country": "IT",
    "name": "Santa Maria Nuova",
    "lat": "43.49164",
    "lng": "13.3237"
  },
  {
    "country": "IT",
    "name": "Santa Maria Nuova",
    "lat": "44.2",
    "lng": "12.19389"
  },
  {
    "country": "IT",
    "name": "Santa Maria Maggiore",
    "lat": "46.13683",
    "lng": "8.46108"
  },
  {
    "country": "IT",
    "name": "Santa Maria Maddalena",
    "lat": "44.90231",
    "lng": "11.60663"
  },
  {
    "country": "IT",
    "name": "Santa Maria la Longa",
    "lat": "45.93403",
    "lng": "13.28911"
  },
  {
    "country": "IT",
    "name": "Santa Maria la Fossa",
    "lat": "41.09171",
    "lng": "14.12822"
  },
  {
    "country": "IT",
    "name": "Santa Maria Imbaro",
    "lat": "42.21999",
    "lng": "14.45027"
  },
  {
    "country": "IT",
    "name": "Venezzano",
    "lat": "44.68333",
    "lng": "11.33333"
  },
  {
    "country": "IT",
    "name": "Santa Maria di Sala",
    "lat": "45.50699",
    "lng": "12.03565"
  },
  {
    "country": "IT",
    "name": "Santa Maria",
    "lat": "40.29782",
    "lng": "14.95214"
  },
  {
    "country": "IT",
    "name": "Santa Maria del Molise",
    "lat": "41.55285",
    "lng": "14.36762"
  },
  {
    "country": "IT",
    "name": "Santa Maria degli Angeli",
    "lat": "43.05691",
    "lng": "12.57497"
  },
  {
    "country": "IT",
    "name": "Santa Maria Codifiume",
    "lat": "44.66424",
    "lng": "11.65099"
  },
  {
    "country": "IT",
    "name": "Santa Maria Capua Vetere",
    "lat": "41.08156",
    "lng": "14.25342"
  },
  {
    "country": "IT",
    "name": "Santa Maria A Vico",
    "lat": "41.02611",
    "lng": "14.46515"
  },
  {
    "country": "IT",
    "name": "Santa Maria a Monte",
    "lat": "43.70793",
    "lng": "10.69196"
  },
  {
    "country": "IT",
    "name": "Santa Maria Coghinas",
    "lat": "40.90423",
    "lng": "8.86383"
  },
  {
    "country": "IT",
    "name": "Santa Margherita Ligure",
    "lat": "44.33456",
    "lng": "9.21204"
  },
  {
    "country": "IT",
    "name": "Santa Margherita d'Adige",
    "lat": "45.2121",
    "lng": "11.55759"
  },
  {
    "country": "IT",
    "name": "Santa Lucia di Serino",
    "lat": "40.87042",
    "lng": "14.87594"
  },
  {
    "country": "IT",
    "name": "Santa Luce",
    "lat": "43.47143",
    "lng": "10.56269"
  },
  {
    "country": "IT",
    "name": "Sant'Alberto",
    "lat": "44.53822",
    "lng": "12.16191"
  },
  {
    "country": "IT",
    "name": "Sant'Albano Stura",
    "lat": "44.50759",
    "lng": "7.72282"
  },
  {
    "country": "IT",
    "name": "Sant'Agostino",
    "lat": "44.79218",
    "lng": "11.38522"
  },
  {
    "country": "IT",
    "name": "Sant'Agnello",
    "lat": "40.62942",
    "lng": "14.39957"
  },
  {
    "country": "IT",
    "name": "Santa Giustina in Colle",
    "lat": "45.57506",
    "lng": "11.90039"
  },
  {
    "country": "IT",
    "name": "Santa Giustina",
    "lat": "46.08118",
    "lng": "12.03822"
  },
  {
    "country": "IT",
    "name": "Santa Giustina",
    "lat": "44.06778",
    "lng": "12.485"
  },
  {
    "country": "IT",
    "name": "Santa Giuletta",
    "lat": "45.03397",
    "lng": "9.18126"
  },
  {
    "country": "IT",
    "name": "Sant'Agata sul Santerno",
    "lat": "44.44351",
    "lng": "11.86112"
  },
  {
    "country": "IT",
    "name": "Sant'Agata sui Due Golfi",
    "lat": "40.60565",
    "lng": "14.37402"
  },
  {
    "country": "IT",
    "name": "Sant'Agata Feltria",
    "lat": "43.86282",
    "lng": "12.2069"
  },
  {
    "country": "IT",
    "name": "Sant'Agata di Puglia",
    "lat": "41.15127",
    "lng": "15.37968"
  },
  {
    "country": "IT",
    "name": "Sant'Agata de'Goti",
    "lat": "41.08932",
    "lng": "14.49743"
  },
  {
    "country": "IT",
    "name": "Sant'Agata Bolognese",
    "lat": "44.66016",
    "lng": "11.13292"
  },
  {
    "country": "IT",
    "name": "Sant'Agapito",
    "lat": "41.54372",
    "lng": "14.22204"
  },
  {
    "country": "IT",
    "name": "Santa Fiora",
    "lat": "42.83129",
    "lng": "11.58474"
  },
  {
    "country": "IT",
    "name": "Santa Croce sull'Arno",
    "lat": "43.71709",
    "lng": "10.77242"
  },
  {
    "country": "IT",
    "name": "Santa Croce",
    "lat": "45.73472",
    "lng": "13.69278"
  },
  {
    "country": "IT",
    "name": "Santa Croce di Magliano",
    "lat": "41.71223",
    "lng": "14.98732"
  },
  {
    "country": "IT",
    "name": "Santa Cristina",
    "lat": "45.15756",
    "lng": "9.39976"
  },
  {
    "country": "IT",
    "name": "Santa Cristina Valgardena",
    "lat": "46.56299",
    "lng": "11.73216"
  },
  {
    "country": "IT",
    "name": "Santa Cristina",
    "lat": "45.6435",
    "lng": "12.13903"
  },
  {
    "country": "IT",
    "name": "Santa Cesarea Terme",
    "lat": "40.03607",
    "lng": "18.45542"
  },
  {
    "country": "IT",
    "name": "Santa Brigida",
    "lat": "45.98489",
    "lng": "9.62115"
  },
  {
    "country": "IT",
    "name": "San Sossio Baronia",
    "lat": "41.07081",
    "lng": "15.20122"
  },
  {
    "country": "IT",
    "name": "San Severo",
    "lat": "41.68564",
    "lng": "15.38148"
  },
  {
    "country": "IT",
    "name": "San Severino Marche",
    "lat": "43.23028",
    "lng": "13.1799"
  },
  {
    "country": "IT",
    "name": "San Severino Lucano",
    "lat": "40.02021",
    "lng": "16.1386"
  },
  {
    "country": "IT",
    "name": "Sansepolcro",
    "lat": "43.57258",
    "lng": "12.13858"
  },
  {
    "country": "IT",
    "name": "San Secondo Parmense",
    "lat": "44.92218",
    "lng": "10.23038"
  },
  {
    "country": "IT",
    "name": "San Secondo",
    "lat": "43.40468",
    "lng": "12.23389"
  },
  {
    "country": "IT",
    "name": "San Sebastiano Curone",
    "lat": "44.78633",
    "lng": "9.06446"
  },
  {
    "country": "IT",
    "name": "San Sebastiano al Vesuvio",
    "lat": "40.84344",
    "lng": "14.36428"
  },
  {
    "country": "IT",
    "name": "San Sebastiano",
    "lat": "45.65192",
    "lng": "10.25681"
  },
  {
    "country": "IT",
    "name": "San Salvo",
    "lat": "42.04413",
    "lng": "14.73335"
  },
  {
    "country": "IT",
    "name": "San Salvatore Telesino",
    "lat": "41.23537",
    "lng": "14.49832"
  },
  {
    "country": "IT",
    "name": "San Salvatore Monferrato",
    "lat": "44.99489",
    "lng": "8.56639"
  },
  {
    "country": "IT",
    "name": "San Rufo",
    "lat": "40.43451",
    "lng": "15.46366"
  },
  {
    "country": "IT",
    "name": "San Romano",
    "lat": "43.68922",
    "lng": "10.769"
  },
  {
    "country": "IT",
    "name": "San Remo",
    "lat": "43.81725",
    "lng": "7.7772"
  },
  {
    "country": "IT",
    "name": "San Quirino",
    "lat": "46.03411",
    "lng": "12.67846"
  },
  {
    "country": "IT",
    "name": "San Quirico d'Orcia",
    "lat": "43.05782",
    "lng": "11.60525"
  },
  {
    "country": "IT",
    "name": "San Quirico",
    "lat": "45.67685",
    "lng": "11.2726"
  },
  {
    "country": "IT",
    "name": "San Prisco",
    "lat": "41.08592",
    "lng": "14.27675"
  },
  {
    "country": "IT",
    "name": "San Potito Ultra",
    "lat": "40.92796",
    "lng": "14.87124"
  },
  {
    "country": "IT",
    "name": "San Potito Sannitico",
    "lat": "41.33698",
    "lng": "14.39185"
  },
  {
    "country": "IT",
    "name": "San Ponso",
    "lat": "45.35101",
    "lng": "7.67111"
  },
  {
    "country": "IT",
    "name": "San Polomatese",
    "lat": "41.45932",
    "lng": "14.49343"
  },
  {
    "country": "IT",
    "name": "San Polo d'Enza",
    "lat": "44.6269",
    "lng": "10.42667"
  },
  {
    "country": "IT",
    "name": "San Polo dei Cavalieri",
    "lat": "42.01037",
    "lng": "12.83989"
  },
  {
    "country": "IT",
    "name": "San Polo",
    "lat": "44.97868",
    "lng": "9.7407"
  },
  {
    "country": "IT",
    "name": "San Pio delle Camere",
    "lat": "42.28423",
    "lng": "13.6557"
  },
  {
    "country": "IT",
    "name": "San Pietro Viminario",
    "lat": "45.24501",
    "lng": "11.82049"
  },
  {
    "country": "IT",
    "name": "San Pietro Vernotico",
    "lat": "40.4889",
    "lng": "17.99752"
  },
  {
    "country": "IT",
    "name": "San Pietro Mosezzo",
    "lat": "45.45455",
    "lng": "8.5445"
  },
  {
    "country": "IT",
    "name": "San Pietro In Vincoli",
    "lat": "44.30051",
    "lng": "12.14556"
  },
  {
    "country": "IT",
    "name": "San Pietro in Lama",
    "lat": "40.30711",
    "lng": "18.12787"
  },
  {
    "country": "IT",
    "name": "San Pietro in Gu",
    "lat": "45.60879",
    "lng": "11.67355"
  },
  {
    "country": "IT",
    "name": "San Pietro Infine",
    "lat": "41.44552",
    "lng": "13.96029"
  },
  {
    "country": "IT",
    "name": "San Pietro in Casale",
    "lat": "44.70079",
    "lng": "11.40492"
  },
  {
    "country": "IT",
    "name": "San Pietro d'Olba",
    "lat": "44.48762",
    "lng": "8.58951"
  },
  {
    "country": "IT",
    "name": "San Pietro di Feletto",
    "lat": "45.91391",
    "lng": "12.25101"
  },
  {
    "country": "IT",
    "name": "San Pietro di Cadore",
    "lat": "46.5719",
    "lng": "12.5869"
  },
  {
    "country": "IT",
    "name": "San Pietro Capofiume",
    "lat": "44.6504",
    "lng": "11.64802"
  },
  {
    "country": "IT",
    "name": "San Pietro Avellana",
    "lat": "41.78886",
    "lng": "14.18323"
  },
  {
    "country": "IT",
    "name": "San Pietro al Tanagro",
    "lat": "40.45488",
    "lng": "15.48692"
  },
  {
    "country": "IT",
    "name": "San Pietro al Natisone",
    "lat": "46.11444",
    "lng": "13.48296"
  },
  {
    "country": "IT",
    "name": "San Pietro",
    "lat": "46.64133",
    "lng": "11.68277"
  },
  {
    "country": "IT",
    "name": "San Piero in Bagno",
    "lat": "43.85793",
    "lng": "11.97716"
  },
  {
    "country": "IT",
    "name": "San Piero a Sieve",
    "lat": "43.96251",
    "lng": "11.32426"
  },
  {
    "country": "IT",
    "name": "San Pier d'Isonzo",
    "lat": "45.84452",
    "lng": "13.46764"
  },
  {
    "country": "IT",
    "name": "San Pellegrino Terme",
    "lat": "45.83443",
    "lng": "9.66753"
  },
  {
    "country": "IT",
    "name": "San Paolo di Jesi",
    "lat": "43.45456",
    "lng": "13.17277"
  },
  {
    "country": "IT",
    "name": "San Paolo di Civitate",
    "lat": "41.73893",
    "lng": "15.2608"
  },
  {
    "country": "IT",
    "name": "San Paolo Bel Sito",
    "lat": "40.91354",
    "lng": "14.54862"
  },
  {
    "country": "IT",
    "name": "San Paolo Albanese",
    "lat": "40.03567",
    "lng": "16.33498"
  },
  {
    "country": "IT",
    "name": "San Paolo",
    "lat": "45.37249",
    "lng": "10.02397"
  },
  {
    "country": "IT",
    "name": "San Panfilo d'Ocre",
    "lat": "42.28616",
    "lng": "13.47518"
  },
  {
    "country": "IT",
    "name": "San Pancrazio Salentino",
    "lat": "40.418",
    "lng": "17.83419"
  },
  {
    "country": "IT",
    "name": "San Pancrazio",
    "lat": "46.586",
    "lng": "11.08571"
  },
  {
    "country": "IT",
    "name": "San Pancrazio",
    "lat": "44.3581",
    "lng": "12.07852"
  },
  {
    "country": "IT",
    "name": "San Niccolò di Celle",
    "lat": "43.01667",
    "lng": "12.38333"
  },
  {
    "country": "IT",
    "name": "San Nicola Baronia",
    "lat": "41.05808",
    "lng": "15.20006"
  },
  {
    "country": "IT",
    "name": "Sannicola",
    "lat": "40.09244",
    "lng": "18.06765"
  },
  {
    "country": "IT",
    "name": "Sannicandro Garganico",
    "lat": "41.83844",
    "lng": "15.56535"
  },
  {
    "country": "IT",
    "name": "Sannicandro di Bari",
    "lat": "41.00047",
    "lng": "16.79714"
  },
  {
    "country": "IT",
    "name": "San Nazzaro Sesia",
    "lat": "45.43804",
    "lng": "8.42498"
  },
  {
    "country": "IT",
    "name": "Sannazzaro de' Burgondi",
    "lat": "45.10226",
    "lng": "8.90635"
  },
  {
    "country": "IT",
    "name": "San Nazario",
    "lat": "45.83982",
    "lng": "11.68893"
  },
  {
    "country": "IT",
    "name": "San Miniato",
    "lat": "43.67954",
    "lng": "10.84975"
  },
  {
    "country": "IT",
    "name": "San Miniato Basso",
    "lat": "43.69332",
    "lng": "10.84119"
  },
  {
    "country": "IT",
    "name": "San Michele Salentino",
    "lat": "40.63163",
    "lng": "17.63254"
  },
  {
    "country": "IT",
    "name": "San Michele Mondovì",
    "lat": "44.37595",
    "lng": "7.90829"
  },
  {
    "country": "IT",
    "name": "San Michele di Serino",
    "lat": "40.87562",
    "lng": "14.85464"
  },
  {
    "country": "IT",
    "name": "San Michele al Tagliamento",
    "lat": "45.76435",
    "lng": "12.99494"
  },
  {
    "country": "IT",
    "name": "San Michele All'Adige",
    "lat": "46.18967",
    "lng": "11.13212"
  },
  {
    "country": "IT",
    "name": "San Michele di Piave",
    "lat": "45.79667",
    "lng": "12.34634"
  },
  {
    "country": "IT",
    "name": "San Michele-San Giorgio",
    "lat": "45.69594",
    "lng": "9.05856"
  },
  {
    "country": "IT",
    "name": "Olivetta San Michele",
    "lat": "43.87872",
    "lng": "7.51504"
  },
  {
    "country": "IT",
    "name": "Borgo San Michele",
    "lat": "41.43828",
    "lng": "12.97351"
  },
  {
    "country": "IT",
    "name": "San Mauro Torinese",
    "lat": "45.10359",
    "lng": "7.76803"
  },
  {
    "country": "IT",
    "name": "San Mauro Pascoli",
    "lat": "44.1089",
    "lng": "12.41953"
  },
  {
    "country": "IT",
    "name": "San Mauro la Bruca",
    "lat": "40.12246",
    "lng": "15.29109"
  },
  {
    "country": "IT",
    "name": "San Mauro Forte",
    "lat": "40.48333",
    "lng": "16.25155"
  },
  {
    "country": "IT",
    "name": "San Mauro di Saline",
    "lat": "45.56452",
    "lng": "11.11234"
  },
  {
    "country": "IT",
    "name": "San Mauro Cilento",
    "lat": "40.22628",
    "lng": "15.04476"
  },
  {
    "country": "IT",
    "name": "San Mauro",
    "lat": "43.79418",
    "lng": "11.12499"
  },
  {
    "country": "IT",
    "name": "San Maurizio D'Opaglio",
    "lat": "45.77299",
    "lng": "8.39599"
  },
  {
    "country": "IT",
    "name": "San Maurizio",
    "lat": "45.21705",
    "lng": "7.63052"
  },
  {
    "country": "IT",
    "name": "San Massimo",
    "lat": "41.49292",
    "lng": "14.41023"
  },
  {
    "country": "IT",
    "name": "San Marzano sul Sarno",
    "lat": "40.77801",
    "lng": "14.58006"
  },
  {
    "country": "IT",
    "name": "San Marzano di San Giuseppe",
    "lat": "40.45455",
    "lng": "17.50351"
  },
  {
    "country": "IT",
    "name": "San Martino Valle Caudina",
    "lat": "41.02764",
    "lng": "14.66446"
  },
  {
    "country": "IT",
    "name": "San Martino sulla Marrucina",
    "lat": "42.22419",
    "lng": "14.21577"
  },
  {
    "country": "IT",
    "name": "San Martino Siccomario",
    "lat": "45.1634",
    "lng": "9.14062"
  },
  {
    "country": "IT",
    "name": "San Martino Sannita",
    "lat": "41.06546",
    "lng": "14.83492"
  },
  {
    "country": "IT",
    "name": "San Martino in Rio",
    "lat": "44.73368",
    "lng": "10.7849"
  },
  {
    "country": "IT",
    "name": "San Martino in Pensilis",
    "lat": "41.87814",
    "lng": "15.01824"
  },
  {
    "country": "IT",
    "name": "San Martino in Freddana-Monsagrati",
    "lat": "43.90921",
    "lng": "10.43778"
  },
  {
    "country": "IT",
    "name": "San Martino",
    "lat": "46.81097",
    "lng": "12.22684"
  },
  {
    "country": "IT",
    "name": "San Martino in Campo",
    "lat": "43.03608",
    "lng": "12.40265"
  },
  {
    "country": "IT",
    "name": "San Martino in Argine",
    "lat": "44.58876",
    "lng": "11.6065"
  },
  {
    "country": "IT",
    "name": "San Martino di Venezze",
    "lat": "45.12532",
    "lng": "11.87018"
  },
  {
    "country": "IT",
    "name": "San Martino di Lupari",
    "lat": "45.65128",
    "lng": "11.86004"
  },
  {
    "country": "IT",
    "name": "San Martino del Lago",
    "lat": "45.07243",
    "lng": "10.31568"
  },
  {
    "country": "IT",
    "name": "San Martino della Battaglia",
    "lat": "45.43832",
    "lng": "10.60053"
  },
  {
    "country": "IT",
    "name": "San Martino Dall'Argine",
    "lat": "45.09715",
    "lng": "10.51766"
  },
  {
    "country": "IT",
    "name": "San Martino d'Agri",
    "lat": "40.23913",
    "lng": "16.05216"
  },
  {
    "country": "IT",
    "name": "San Martino Canavese",
    "lat": "45.39453",
    "lng": "7.81622"
  },
  {
    "country": "IT",
    "name": "San Martino Buon Albergo",
    "lat": "45.42083",
    "lng": "11.09562"
  },
  {
    "country": "IT",
    "name": "San Martino al Cimino",
    "lat": "42.36978",
    "lng": "12.12515"
  },
  {
    "country": "IT",
    "name": "San Martino in Passiria",
    "lat": "46.78392",
    "lng": "11.22727"
  },
  {
    "country": "IT",
    "name": "San Martino",
    "lat": "44.77794",
    "lng": "11.58751"
  },
  {
    "country": "IT",
    "name": "San Marco la Catola",
    "lat": "41.52483",
    "lng": "15.00594"
  },
  {
    "country": "IT",
    "name": "San Marco in Lamis",
    "lat": "41.7121",
    "lng": "15.63825"
  },
  {
    "country": "IT",
    "name": "San Marco Evangelista",
    "lat": "41.03702",
    "lng": "14.33979"
  },
  {
    "country": "IT",
    "name": "San Marco dei Cavoti",
    "lat": "41.30881",
    "lng": "14.87924"
  },
  {
    "country": "IT",
    "name": "San Marcello Pistoiese",
    "lat": "44.05583",
    "lng": "10.79366"
  },
  {
    "country": "IT",
    "name": "San Marcello",
    "lat": "43.57526",
    "lng": "13.20827"
  },
  {
    "country": "IT",
    "name": "San Mango sul Calore",
    "lat": "40.9589",
    "lng": "14.97251"
  },
  {
    "country": "IT",
    "name": "San Mango Piemonte",
    "lat": "40.70024",
    "lng": "14.83919"
  },
  {
    "country": "IT",
    "name": "San Lupo",
    "lat": "41.26148",
    "lng": "14.63528"
  },
  {
    "country": "IT",
    "name": "San Lorenzo Nuovo",
    "lat": "42.68626",
    "lng": "11.90718"
  },
  {
    "country": "IT",
    "name": "San Lorenzo Maggiore",
    "lat": "41.24885",
    "lng": "14.62438"
  },
  {
    "country": "IT",
    "name": "San Lorenzo in Campo",
    "lat": "43.60149",
    "lng": "12.94398"
  },
  {
    "country": "IT",
    "name": "San Lorenzo di Sebato",
    "lat": "46.78514",
    "lng": "11.90812"
  },
  {
    "country": "IT",
    "name": "San Lorenzo al Mare",
    "lat": "43.85378",
    "lng": "7.96406"
  },
  {
    "country": "IT",
    "name": "San Lorenzo",
    "lat": "46.1272",
    "lng": "8.20065"
  },
  {
    "country": "IT",
    "name": "San Lorenzello",
    "lat": "41.27602",
    "lng": "14.54173"
  },
  {
    "country": "IT",
    "name": "San Leucio del Sannio-Cavuoti",
    "lat": "41.07442",
    "lng": "14.75744"
  },
  {
    "country": "IT",
    "name": "San Leonardo in Passiria",
    "lat": "46.81282",
    "lng": "11.24577"
  },
  {
    "country": "IT",
    "name": "San Leonardo",
    "lat": "46.11913",
    "lng": "13.53085"
  },
  {
    "country": "IT",
    "name": "San Leo",
    "lat": "43.89637",
    "lng": "12.3446"
  },
  {
    "country": "IT",
    "name": "San Lazzaro",
    "lat": "44.4705",
    "lng": "11.40851"
  },
  {
    "country": "IT",
    "name": "Sanguinetto",
    "lat": "45.18567",
    "lng": "11.14412"
  },
  {
    "country": "IT",
    "name": "San Gregorio Magno",
    "lat": "40.65992",
    "lng": "15.39914"
  },
  {
    "country": "IT",
    "name": "San Gregorio da Sassola",
    "lat": "41.91881",
    "lng": "12.87447"
  },
  {
    "country": "IT",
    "name": "San Gregorio Matese",
    "lat": "41.38556",
    "lng": "14.37217"
  },
  {
    "country": "IT",
    "name": "San Godenzo",
    "lat": "43.92504",
    "lng": "11.61982"
  },
  {
    "country": "IT",
    "name": "San Giusto Canavese",
    "lat": "45.31535",
    "lng": "7.81001"
  },
  {
    "country": "IT",
    "name": "San Giustino Valdarno",
    "lat": "43.55269",
    "lng": "11.70497"
  },
  {
    "country": "IT",
    "name": "San Giustino",
    "lat": "43.5466",
    "lng": "12.17528"
  },
  {
    "country": "IT",
    "name": "San Giuseppe Vesuviano",
    "lat": "40.8356",
    "lng": "14.50487"
  },
  {
    "country": "IT",
    "name": "San Giuseppe",
    "lat": "44.72202",
    "lng": "12.21712"
  },
  {
    "country": "IT",
    "name": "San Giuliano Vecchio",
    "lat": "44.88902",
    "lng": "8.76057"
  },
  {
    "country": "IT",
    "name": "San Giuliano Terme",
    "lat": "43.76372",
    "lng": "10.43856"
  },
  {
    "country": "IT",
    "name": "San Giuliano Milanese",
    "lat": "45.39402",
    "lng": "9.29109"
  },
  {
    "country": "IT",
    "name": "San Giuliano di Puglia",
    "lat": "41.68796",
    "lng": "14.96231"
  },
  {
    "country": "IT",
    "name": "San Giuliano del Sannio",
    "lat": "41.45752",
    "lng": "14.64169"
  },
  {
    "country": "IT",
    "name": "San Giovanni Valdarno",
    "lat": "43.56757",
    "lng": "11.52987"
  },
  {
    "country": "IT",
    "name": "San Giovanni Rotondo",
    "lat": "41.70643",
    "lng": "15.7277"
  },
  {
    "country": "IT",
    "name": "San Giovanni Lupatoto",
    "lat": "45.38193",
    "lng": "11.04474"
  },
  {
    "country": "IT",
    "name": "San Giovanni Lipioni",
    "lat": "41.84383",
    "lng": "14.56271"
  },
  {
    "country": "IT",
    "name": "San Giovanni in Persiceto",
    "lat": "44.63838",
    "lng": "11.18419"
  },
  {
    "country": "IT",
    "name": "San Giovanni in Marignano",
    "lat": "43.93989",
    "lng": "12.71166"
  },
  {
    "country": "IT",
    "name": "San Giovanni in Galdo",
    "lat": "41.5911",
    "lng": "14.75202"
  },
  {
    "country": "IT",
    "name": "San Giovanni in Croce",
    "lat": "45.07396",
    "lng": "10.37315"
  },
  {
    "country": "IT",
    "name": "San Giovanni Incarico",
    "lat": "41.50001",
    "lng": "13.55864"
  },
  {
    "country": "IT",
    "name": "San Giovanni Ilarione",
    "lat": "45.51927",
    "lng": "11.23707"
  },
  {
    "country": "IT",
    "name": "San Giovanni del Dosso",
    "lat": "44.96627",
    "lng": "11.08114"
  },
  {
    "country": "IT",
    "name": "San Giovanni d'Asso",
    "lat": "43.15334",
    "lng": "11.58938"
  },
  {
    "country": "IT",
    "name": "San Giovanni Bianco",
    "lat": "45.87342",
    "lng": "9.6542"
  },
  {
    "country": "IT",
    "name": "San Giovanni A Piro",
    "lat": "40.0515",
    "lng": "15.4462"
  },
  {
    "country": "IT",
    "name": "San Giovanni al Natisone",
    "lat": "45.97079",
    "lng": "13.40182"
  },
  {
    "country": "IT",
    "name": "San Giovanni",
    "lat": "46.02104",
    "lng": "12.51556"
  },
  {
    "country": "IT",
    "name": "San Giorio",
    "lat": "45.12752",
    "lng": "7.17683"
  },
  {
    "country": "IT",
    "name": "San Giorgio Piacentino",
    "lat": "44.95198",
    "lng": "9.73773"
  },
  {
    "country": "IT",
    "name": "San Giorgio Lucano",
    "lat": "40.11132",
    "lng": "16.3893"
  },
  {
    "country": "IT",
    "name": "San Giorgio la Molara",
    "lat": "41.27667",
    "lng": "14.93099"
  },
  {
    "country": "IT",
    "name": "San Giorgio Ionico",
    "lat": "40.45796",
    "lng": "17.38034"
  },
  {
    "country": "IT",
    "name": "San Giorgio in Salici",
    "lat": "45.42676",
    "lng": "10.78906"
  },
  {
    "country": "IT",
    "name": "San Giorgio in Bosco",
    "lat": "45.58863",
    "lng": "11.80736"
  },
  {
    "country": "IT",
    "name": "San Giorgio di Piano",
    "lat": "44.64724",
    "lng": "11.37446"
  },
  {
    "country": "IT",
    "name": "San Giorgio di Pesaro",
    "lat": "43.72248",
    "lng": "12.97969"
  },
  {
    "country": "IT",
    "name": "San Giorgio di Nogaro",
    "lat": "45.82745",
    "lng": "13.21088"
  },
  {
    "country": "IT",
    "name": "San Giorgio di Lomellina",
    "lat": "45.17486",
    "lng": "8.79014"
  },
  {
    "country": "IT",
    "name": "San Giorgio di Livenza",
    "lat": "45.6533",
    "lng": "12.79692"
  },
  {
    "country": "IT",
    "name": "San Giorgio del Sannio",
    "lat": "41.06844",
    "lng": "14.85322"
  },
  {
    "country": "IT",
    "name": "San Giorgio della Richinvelda",
    "lat": "46.04778",
    "lng": "12.86867"
  },
  {
    "country": "IT",
    "name": "San Giorgio Canavese",
    "lat": "45.33557",
    "lng": "7.79823"
  },
  {
    "country": "IT",
    "name": "San Giorgio a Liri",
    "lat": "41.40584",
    "lng": "13.75979"
  },
  {
    "country": "IT",
    "name": "San Giorgio a Cremano",
    "lat": "40.83261",
    "lng": "14.34162"
  },
  {
    "country": "IT",
    "name": "San Giorgio",
    "lat": "41.27065",
    "lng": "14.31278"
  },
  {
    "country": "IT",
    "name": "San Ginesio",
    "lat": "43.10752",
    "lng": "13.32121"
  },
  {
    "country": "IT",
    "name": "San Gimignano",
    "lat": "43.4738",
    "lng": "11.02975"
  },
  {
    "country": "IT",
    "name": "San Gillio",
    "lat": "45.1405",
    "lng": "7.53285"
  },
  {
    "country": "IT",
    "name": "San Giacomo delle Segnate",
    "lat": "44.97418",
    "lng": "11.03434"
  },
  {
    "country": "IT",
    "name": "San Giacomo degli Schiavoni",
    "lat": "41.96234",
    "lng": "14.94481"
  },
  {
    "country": "IT",
    "name": "San Giacomo",
    "lat": "42.79387",
    "lng": "12.75243"
  },
  {
    "country": "IT",
    "name": "San Gervasio Bresciano",
    "lat": "45.30774",
    "lng": "10.14652"
  },
  {
    "country": "IT",
    "name": "San Germano Vercellese",
    "lat": "45.3509",
    "lng": "8.24717"
  },
  {
    "country": "IT",
    "name": "San Gennaro Vesuviano",
    "lat": "40.86226",
    "lng": "14.52414"
  },
  {
    "country": "IT",
    "name": "San Genesio ed Uniti",
    "lat": "45.23414",
    "lng": "9.17997"
  },
  {
    "country": "IT",
    "name": "San Genesio Atesino",
    "lat": "46.5346",
    "lng": "11.32971"
  },
  {
    "country": "IT",
    "name": "San Gemini",
    "lat": "42.61378",
    "lng": "12.54528"
  },
  {
    "country": "IT",
    "name": "Sangano",
    "lat": "45.02508",
    "lng": "7.44987"
  },
  {
    "country": "IT",
    "name": "San Gabriele-Mondonuovo",
    "lat": "44.66667",
    "lng": "11.58333"
  },
  {
    "country": "IT",
    "name": "Sanfront",
    "lat": "44.64698",
    "lng": "7.32243"
  },
  {
    "country": "IT",
    "name": "Sanfrè",
    "lat": "44.7518",
    "lng": "7.80289"
  },
  {
    "country": "IT",
    "name": "Aglientu",
    "lat": "41.07906",
    "lng": "9.11267"
  },
  {
    "country": "IT",
    "name": "San Francesco al Campo",
    "lat": "45.22732",
    "lng": "7.65479"
  },
  {
    "country": "IT",
    "name": "San Floriano del Collio",
    "lat": "45.98088",
    "lng": "13.58875"
  },
  {
    "country": "IT",
    "name": "San Floriano",
    "lat": "45.51796",
    "lng": "10.90817"
  },
  {
    "country": "IT",
    "name": "San Fior di Sopra",
    "lat": "45.92219",
    "lng": "12.36137"
  },
  {
    "country": "IT",
    "name": "San Fiorano",
    "lat": "45.13815",
    "lng": "9.72063"
  },
  {
    "country": "IT",
    "name": "San Ferdinando di Puglia",
    "lat": "41.30263",
    "lng": "16.07046"
  },
  {
    "country": "IT",
    "name": "San Felice sul Panaro",
    "lat": "44.83671",
    "lng": "11.13791"
  },
  {
    "country": "IT",
    "name": "San Felice del Molise",
    "lat": "41.89",
    "lng": "14.70088"
  },
  {
    "country": "IT",
    "name": "San Felice del Benaco",
    "lat": "45.58276",
    "lng": "10.5538"
  },
  {
    "country": "IT",
    "name": "San Felice Circeo",
    "lat": "41.23716",
    "lng": "13.09416"
  },
  {
    "country": "IT",
    "name": "San Felice",
    "lat": "46.49429",
    "lng": "11.13022"
  },
  {
    "country": "IT",
    "name": "San Felice",
    "lat": "45.14301",
    "lng": "10.07373"
  },
  {
    "country": "IT",
    "name": "San Fele",
    "lat": "40.81647",
    "lng": "15.54043"
  },
  {
    "country": "IT",
    "name": "San Fedele Superiore",
    "lat": "45.96667",
    "lng": "9.06667"
  },
  {
    "country": "IT",
    "name": "Sandrigo",
    "lat": "45.66083",
    "lng": "11.58921"
  },
  {
    "country": "IT",
    "name": "Dolina",
    "lat": "45.6008",
    "lng": "13.85929"
  },
  {
    "country": "IT",
    "name": "San Donato Val di Comino",
    "lat": "41.70726",
    "lng": "13.8122"
  },
  {
    "country": "IT",
    "name": "San Donato Milanese",
    "lat": "45.41047",
    "lng": "9.26838"
  },
  {
    "country": "IT",
    "name": "San Donato di Lecce",
    "lat": "40.26728",
    "lng": "18.18256"
  },
  {
    "country": "IT",
    "name": "San Donà di Piave",
    "lat": "45.63019",
    "lng": "12.5681"
  },
  {
    "country": "IT",
    "name": "San Donaci",
    "lat": "40.44853",
    "lng": "17.92252"
  },
  {
    "country": "IT",
    "name": "Sandigliano",
    "lat": "45.52204",
    "lng": "8.0766"
  },
  {
    "country": "IT",
    "name": "San Demetrio Ne' Vestini",
    "lat": "42.28963",
    "lng": "13.55519"
  },
  {
    "country": "IT",
    "name": "San Daniele del Friuli",
    "lat": "46.15714",
    "lng": "13.00726"
  },
  {
    "country": "IT",
    "name": "San Damiano Macra",
    "lat": "44.48848",
    "lng": "7.25606"
  },
  {
    "country": "IT",
    "name": "San Damiano d'Asti",
    "lat": "44.83344",
    "lng": "8.06353"
  },
  {
    "country": "IT",
    "name": "San Damiano al Colle",
    "lat": "45.02713",
    "lng": "9.3486"
  },
  {
    "country": "IT",
    "name": "Santa Croce del Sannio",
    "lat": "41.38793",
    "lng": "14.73229"
  },
  {
    "country": "IT",
    "name": "San Cristoforo",
    "lat": "44.69304",
    "lng": "8.74939"
  },
  {
    "country": "IT",
    "name": "San Costanzo",
    "lat": "43.7672",
    "lng": "13.07306"
  },
  {
    "country": "IT",
    "name": "San Costantino Albanese",
    "lat": "40.03679",
    "lng": "16.30475"
  },
  {
    "country": "IT",
    "name": "San Colombano al Lambro",
    "lat": "45.18322",
    "lng": "9.49028"
  },
  {
    "country": "IT",
    "name": "San Clemente",
    "lat": "43.93269",
    "lng": "12.62707"
  },
  {
    "country": "IT",
    "name": "San Clemente",
    "lat": "41.34027",
    "lng": "13.95597"
  },
  {
    "country": "IT",
    "name": "San Cipriano Po",
    "lat": "45.10909",
    "lng": "9.28089"
  },
  {
    "country": "IT",
    "name": "San Cipriano Picentino",
    "lat": "40.72008",
    "lng": "14.87195"
  },
  {
    "country": "IT",
    "name": "San Chirico Raparo",
    "lat": "40.19242",
    "lng": "16.07618"
  },
  {
    "country": "IT",
    "name": "San Chirico Nuovo",
    "lat": "40.67764",
    "lng": "16.07892"
  },
  {
    "country": "IT",
    "name": "San Cesario sul Panaro",
    "lat": "44.56352",
    "lng": "11.03508"
  },
  {
    "country": "IT",
    "name": "San Cesario di Lecce",
    "lat": "40.30221",
    "lng": "18.16098"
  },
  {
    "country": "IT",
    "name": "San Cesareo",
    "lat": "41.82113",
    "lng": "12.80447"
  },
  {
    "country": "IT",
    "name": "San Castrese",
    "lat": "41.25862",
    "lng": "13.86541"
  },
  {
    "country": "IT",
    "name": "San Cassiano",
    "lat": "46.27697",
    "lng": "9.39743"
  },
  {
    "country": "IT",
    "name": "San Cassiano",
    "lat": "40.05631",
    "lng": "18.33392"
  },
  {
    "country": "IT",
    "name": "San Casciano in Val di Pesa",
    "lat": "43.65975",
    "lng": "11.18494"
  },
  {
    "country": "IT",
    "name": "San Casciano dei Bagni",
    "lat": "42.87008",
    "lng": "11.87656"
  },
  {
    "country": "IT",
    "name": "San Carlo",
    "lat": "44.80361",
    "lng": "11.40999"
  },
  {
    "country": "IT",
    "name": "San Candido",
    "lat": "46.7324",
    "lng": "12.27855"
  },
  {
    "country": "IT",
    "name": "San Buono",
    "lat": "41.9814",
    "lng": "14.56818"
  },
  {
    "country": "IT",
    "name": "San Bonifacio",
    "lat": "45.39595",
    "lng": "11.27352"
  },
  {
    "country": "IT",
    "name": "San Biase",
    "lat": "41.71526",
    "lng": "14.59049"
  },
  {
    "country": "IT",
    "name": "San Biagio Saracinisco",
    "lat": "41.61322",
    "lng": "13.92758"
  },
  {
    "country": "IT",
    "name": "San Biagio di Callalta",
    "lat": "45.68361",
    "lng": "12.37722"
  },
  {
    "country": "IT",
    "name": "San Biagio della Cima",
    "lat": "43.81784",
    "lng": "7.65133"
  },
  {
    "country": "IT",
    "name": "San Biagio",
    "lat": "44.58695",
    "lng": "11.86918"
  },
  {
    "country": "IT",
    "name": "San Benigno Canavese",
    "lat": "45.22617",
    "lng": "7.78427"
  },
  {
    "country": "IT",
    "name": "San Benedetto Val di Sambro",
    "lat": "44.21405",
    "lng": "11.23567"
  },
  {
    "country": "IT",
    "name": "San Benedetto Po",
    "lat": "45.04612",
    "lng": "10.93367"
  },
  {
    "country": "IT",
    "name": "San Benedetto in Perillis",
    "lat": "42.18377",
    "lng": "13.76996"
  },
  {
    "country": "IT",
    "name": "San Benedetto dei Marsi",
    "lat": "42.0076",
    "lng": "13.62381"
  },
  {
    "country": "IT",
    "name": "San Benedetto del Tronto",
    "lat": "42.9568",
    "lng": "13.87676"
  },
  {
    "country": "IT",
    "name": "San Bellino",
    "lat": "45.02943",
    "lng": "11.59222"
  },
  {
    "country": "IT",
    "name": "San Bassano",
    "lat": "45.24378",
    "lng": "9.80954"
  },
  {
    "country": "IT",
    "name": "San Bartolomeo in Galdo",
    "lat": "41.41595",
    "lng": "15.01709"
  },
  {
    "country": "IT",
    "name": "San Bartolomeo In Bosco",
    "lat": "44.73094",
    "lng": "11.63573"
  },
  {
    "country": "IT",
    "name": "Sanarica",
    "lat": "40.08908",
    "lng": "18.34803"
  },
  {
    "country": "IT",
    "name": "Sampeyre",
    "lat": "44.57846",
    "lng": "7.19039"
  },
  {
    "country": "IT",
    "name": "Samone",
    "lat": "45.44914",
    "lng": "7.84198"
  },
  {
    "country": "IT",
    "name": "Sammichele di Bari",
    "lat": "40.88711",
    "lng": "16.94919"
  },
  {
    "country": "IT",
    "name": "Sambuco",
    "lat": "44.3351",
    "lng": "7.07878"
  },
  {
    "country": "IT",
    "name": "Sambuci",
    "lat": "41.98536",
    "lng": "12.93817"
  },
  {
    "country": "IT",
    "name": "Samarate",
    "lat": "45.6241",
    "lng": "8.78507"
  },
  {
    "country": "IT",
    "name": "Salzano",
    "lat": "45.52221",
    "lng": "12.10151"
  },
  {
    "country": "IT",
    "name": "Salza Irpina",
    "lat": "40.91893",
    "lng": "14.88996"
  },
  {
    "country": "IT",
    "name": "Salvitelle",
    "lat": "40.59064",
    "lng": "15.4576"
  },
  {
    "country": "IT",
    "name": "Salvirola",
    "lat": "45.3563",
    "lng": "9.77924"
  },
  {
    "country": "IT",
    "name": "Salvatronda",
    "lat": "45.67425",
    "lng": "11.97709"
  },
  {
    "country": "IT",
    "name": "Salvaterra",
    "lat": "44.59925",
    "lng": "10.7686"
  },
  {
    "country": "IT",
    "name": "Saluzzo",
    "lat": "44.64671",
    "lng": "7.49309"
  },
  {
    "country": "IT",
    "name": "La Salute di Livenza",
    "lat": "45.65366",
    "lng": "12.80131"
  },
  {
    "country": "IT",
    "name": "Salussola",
    "lat": "45.44666",
    "lng": "8.111"
  },
  {
    "country": "IT",
    "name": "Saluggia",
    "lat": "45.23687",
    "lng": "8.0146"
  },
  {
    "country": "IT",
    "name": "Saludecio",
    "lat": "43.8754",
    "lng": "12.66118"
  },
  {
    "country": "IT",
    "name": "Saltara",
    "lat": "43.75252",
    "lng": "12.89853"
  },
  {
    "country": "IT",
    "name": "Salsomaggiore Terme",
    "lat": "44.81592",
    "lng": "9.98637"
  },
  {
    "country": "IT",
    "name": "Salorno",
    "lat": "46.24062",
    "lng": "11.21192"
  },
  {
    "country": "IT",
    "name": "Salò",
    "lat": "45.60685",
    "lng": "10.5205"
  },
  {
    "country": "IT",
    "name": "Salmour",
    "lat": "44.57556",
    "lng": "7.79148"
  },
  {
    "country": "IT",
    "name": "Salle",
    "lat": "42.17756",
    "lng": "13.96091"
  },
  {
    "country": "IT",
    "name": "Salizzole",
    "lat": "45.24004",
    "lng": "11.0954"
  },
  {
    "country": "IT",
    "name": "Sali Vercellese",
    "lat": "45.30986",
    "lng": "8.32893"
  },
  {
    "country": "IT",
    "name": "Salitto-Valle",
    "lat": "40.67412",
    "lng": "15.02241"
  },
  {
    "country": "IT",
    "name": "Salisano",
    "lat": "42.25947",
    "lng": "12.74774"
  },
  {
    "country": "IT",
    "name": "Salionze",
    "lat": "45.40493",
    "lng": "10.72259"
  },
  {
    "country": "IT",
    "name": "Saline",
    "lat": "43.36185",
    "lng": "10.81354"
  },
  {
    "country": "IT",
    "name": "Saliceto",
    "lat": "44.41334",
    "lng": "8.16864"
  },
  {
    "country": "IT",
    "name": "Salice Terme",
    "lat": "44.9151",
    "lng": "9.0263"
  },
  {
    "country": "IT",
    "name": "Salice Salentino",
    "lat": "40.38485",
    "lng": "17.96134"
  },
  {
    "country": "IT",
    "name": "Salgareda",
    "lat": "45.705",
    "lng": "12.48833"
  },
  {
    "country": "IT",
    "name": "Saletto-San Bartolomeo",
    "lat": "45.72639",
    "lng": "12.39556"
  },
  {
    "country": "IT",
    "name": "Saletto",
    "lat": "45.22889",
    "lng": "11.5378"
  },
  {
    "country": "IT",
    "name": "Salerno",
    "lat": "40.67545",
    "lng": "14.79328"
  },
  {
    "country": "IT",
    "name": "Salento",
    "lat": "40.24913",
    "lng": "15.18938"
  },
  {
    "country": "IT",
    "name": "Sale Marasino",
    "lat": "45.70638",
    "lng": "10.11216"
  },
  {
    "country": "IT",
    "name": "Sale",
    "lat": "44.97932",
    "lng": "8.80963"
  },
  {
    "country": "IT",
    "name": "Salcito",
    "lat": "41.7464",
    "lng": "14.51085"
  },
  {
    "country": "IT",
    "name": "Salcedo",
    "lat": "45.75783",
    "lng": "11.56621"
  },
  {
    "country": "IT",
    "name": "Salassa",
    "lat": "45.36175",
    "lng": "7.68297"
  },
  {
    "country": "IT",
    "name": "Salara",
    "lat": "44.98586",
    "lng": "11.42655"
  },
  {
    "country": "IT",
    "name": "Salandra",
    "lat": "40.52668",
    "lng": "16.32037"
  },
  {
    "country": "IT",
    "name": "Sala Monferrato",
    "lat": "45.07546",
    "lng": "8.36119"
  },
  {
    "country": "IT",
    "name": "Sala Consilina",
    "lat": "40.40134",
    "lng": "15.5914"
  },
  {
    "country": "IT",
    "name": "Sala Bolognese",
    "lat": "44.61387",
    "lng": "11.25669"
  },
  {
    "country": "IT",
    "name": "Sala Biellese",
    "lat": "45.50856",
    "lng": "7.958"
  },
  {
    "country": "IT",
    "name": "Salbertrand",
    "lat": "45.0735",
    "lng": "6.88744"
  },
  {
    "country": "IT",
    "name": "Sala Baganza",
    "lat": "44.71563",
    "lng": "10.22622"
  },
  {
    "country": "IT",
    "name": "Sairano",
    "lat": "45.13672",
    "lng": "9.05162"
  },
  {
    "country": "IT",
    "name": "Saint-Vincent",
    "lat": "45.75082",
    "lng": "7.64815"
  },
  {
    "country": "IT",
    "name": "San Leonardo",
    "lat": "45.82366",
    "lng": "7.1814"
  },
  {
    "country": "IT",
    "name": "Saint-Pierre",
    "lat": "45.71153",
    "lng": "7.22683"
  },
  {
    "country": "IT",
    "name": "Saint-Oyen",
    "lat": "45.82439",
    "lng": "7.21372"
  },
  {
    "country": "IT",
    "name": "Sagrado",
    "lat": "45.87393",
    "lng": "13.48418"
  },
  {
    "country": "IT",
    "name": "Sagama",
    "lat": "40.26155",
    "lng": "8.57752"
  },
  {
    "country": "IT",
    "name": "Sacrofano",
    "lat": "42.10457",
    "lng": "12.44781"
  },
  {
    "country": "IT",
    "name": "Sacile",
    "lat": "45.95412",
    "lng": "12.50274"
  },
  {
    "country": "IT",
    "name": "Saccolongo",
    "lat": "45.40152",
    "lng": "11.74863"
  },
  {
    "country": "IT",
    "name": "Sacco",
    "lat": "40.37671",
    "lng": "15.37783"
  },
  {
    "country": "IT",
    "name": "La Caletta",
    "lat": "40.60988",
    "lng": "9.75062"
  },
  {
    "country": "IT",
    "name": "Sabbioneta",
    "lat": "44.99787",
    "lng": "10.48848"
  },
  {
    "country": "IT",
    "name": "Sabbio Chiese",
    "lat": "45.65589",
    "lng": "10.42193"
  },
  {
    "country": "IT",
    "name": "Sabbia",
    "lat": "45.8572",
    "lng": "8.2358"
  },
  {
    "country": "IT",
    "name": "Sabaudia",
    "lat": "41.30025",
    "lng": "13.02815"
  },
  {
    "country": "IT",
    "name": "Ruvo di Puglia",
    "lat": "41.11758",
    "lng": "16.48421"
  },
  {
    "country": "IT",
    "name": "Ruvo del Monte",
    "lat": "40.84951",
    "lng": "15.54217"
  },
  {
    "country": "IT",
    "name": "Ruviano",
    "lat": "41.21063",
    "lng": "14.40983"
  },
  {
    "country": "IT",
    "name": "Rutino",
    "lat": "40.30072",
    "lng": "15.07328"
  },
  {
    "country": "IT",
    "name": "Rutigliano",
    "lat": "41.00997",
    "lng": "17.00558"
  },
  {
    "country": "IT",
    "name": "Russi",
    "lat": "44.37645",
    "lng": "12.03335"
  },
  {
    "country": "IT",
    "name": "Ruoti",
    "lat": "40.7166",
    "lng": "15.68369"
  },
  {
    "country": "IT",
    "name": "Rufina",
    "lat": "43.82396",
    "lng": "11.48673"
  },
  {
    "country": "IT",
    "name": "Ruffia",
    "lat": "44.70598",
    "lng": "7.60391"
  },
  {
    "country": "IT",
    "name": "Rudiano",
    "lat": "45.48952",
    "lng": "9.88606"
  },
  {
    "country": "IT",
    "name": "Rubiera",
    "lat": "44.65158",
    "lng": "10.7794"
  },
  {
    "country": "IT",
    "name": "Rubiana",
    "lat": "45.13622",
    "lng": "7.38439"
  },
  {
    "country": "IT",
    "name": "Rubano",
    "lat": "45.42514",
    "lng": "11.79146"
  },
  {
    "country": "IT",
    "name": "Pragelato-Ruà",
    "lat": "45.01364",
    "lng": "6.94161"
  },
  {
    "country": "IT",
    "name": "Rozzano",
    "lat": "45.38193",
    "lng": "9.1559"
  },
  {
    "country": "IT",
    "name": "Rovigo",
    "lat": "45.06982",
    "lng": "11.79022"
  },
  {
    "country": "IT",
    "name": "Roviano",
    "lat": "42.02643",
    "lng": "12.9939"
  },
  {
    "country": "IT",
    "name": "Rovetta",
    "lat": "45.89178",
    "lng": "9.98212"
  },
  {
    "country": "IT",
    "name": "Rovereto",
    "lat": "45.8904",
    "lng": "11.04053"
  },
  {
    "country": "IT",
    "name": "Rovereto",
    "lat": "44.83381",
    "lng": "10.95157"
  },
  {
    "country": "IT",
    "name": "Roveredo in Piano",
    "lat": "46.00847",
    "lng": "12.61938"
  },
  {
    "country": "IT",
    "name": "Roverè della Luna",
    "lat": "46.25008",
    "lng": "11.17233"
  },
  {
    "country": "IT",
    "name": "Roverbella",
    "lat": "45.26659",
    "lng": "10.77047"
  },
  {
    "country": "IT",
    "name": "Rovello Porro",
    "lat": "45.6521",
    "lng": "9.0394"
  },
  {
    "country": "IT",
    "name": "Rovellasca",
    "lat": "45.66664",
    "lng": "9.04884"
  },
  {
    "country": "IT",
    "name": "Rovato",
    "lat": "45.56342",
    "lng": "10.00213"
  },
  {
    "country": "IT",
    "name": "Rovasenda",
    "lat": "45.53866",
    "lng": "8.31592"
  },
  {
    "country": "IT",
    "name": "Rovagnate",
    "lat": "45.73692",
    "lng": "9.37111"
  },
  {
    "country": "IT",
    "name": "Rottofreno",
    "lat": "45.05527",
    "lng": "9.55007"
  },
  {
    "country": "IT",
    "name": "Rottanova",
    "lat": "45.14361",
    "lng": "12.01849"
  },
  {
    "country": "IT",
    "name": "Rotondi",
    "lat": "41.03293",
    "lng": "14.59548"
  },
  {
    "country": "IT",
    "name": "Rotondella",
    "lat": "40.17136",
    "lng": "16.52491"
  },
  {
    "country": "IT",
    "name": "Rotello",
    "lat": "41.74776",
    "lng": "15.00608"
  },
  {
    "country": "IT",
    "name": "Rotella",
    "lat": "42.95435",
    "lng": "13.55849"
  },
  {
    "country": "IT",
    "name": "Rossiglione",
    "lat": "44.56358",
    "lng": "8.66956"
  },
  {
    "country": "IT",
    "name": "Rossano Veneto",
    "lat": "45.70308",
    "lng": "11.80369"
  },
  {
    "country": "IT",
    "name": "Rossana",
    "lat": "44.5447",
    "lng": "7.43193"
  },
  {
    "country": "IT",
    "name": "Rosora",
    "lat": "43.48336",
    "lng": "13.06819"
  },
  {
    "country": "IT",
    "name": "Rosolina",
    "lat": "45.07674",
    "lng": "12.22977"
  },
  {
    "country": "IT",
    "name": "Rosignano Solvay-Castiglioncello",
    "lat": "43.38946",
    "lng": "10.43615"
  },
  {
    "country": "IT",
    "name": "Rosignano Marittimo",
    "lat": "43.40686",
    "lng": "10.47231"
  },
  {
    "country": "IT",
    "name": "Rosia",
    "lat": "43.24611",
    "lng": "11.22176"
  },
  {
    "country": "IT",
    "name": "Roseto Valfortore",
    "lat": "41.37544",
    "lng": "15.09824"
  },
  {
    "country": "IT",
    "name": "Roseto degli Abruzzi",
    "lat": "42.67164",
    "lng": "14.01481"
  },
  {
    "country": "IT",
    "name": "Rosello",
    "lat": "41.90116",
    "lng": "14.34919"
  },
  {
    "country": "IT",
    "name": "Roscigno",
    "lat": "40.39997",
    "lng": "15.34585"
  },
  {
    "country": "IT",
    "name": "Rosciano",
    "lat": "43.8162",
    "lng": "12.99992"
  },
  {
    "country": "IT",
    "name": "Rosciano",
    "lat": "42.32227",
    "lng": "14.04555"
  },
  {
    "country": "IT",
    "name": "Rosate",
    "lat": "45.34965",
    "lng": "9.01659"
  },
  {
    "country": "IT",
    "name": "Rosasco",
    "lat": "45.25031",
    "lng": "8.5793"
  },
  {
    "country": "IT",
    "name": "Rosa",
    "lat": "45.93056",
    "lng": "12.87083"
  },
  {
    "country": "IT",
    "name": "Rosà",
    "lat": "45.70198",
    "lng": "11.76141"
  },
  {
    "country": "IT",
    "name": "Ronzone",
    "lat": "46.42437",
    "lng": "11.15275"
  },
  {
    "country": "IT",
    "name": "Ronta",
    "lat": "44.0031",
    "lng": "11.42894"
  },
  {
    "country": "IT",
    "name": "Ronsecco",
    "lat": "45.25284",
    "lng": "8.27749"
  },
  {
    "country": "IT",
    "name": "Rondissone",
    "lat": "45.2463",
    "lng": "7.96426"
  },
  {
    "country": "IT",
    "name": "Ronco Scrivia",
    "lat": "44.61357",
    "lng": "8.95042"
  },
  {
    "country": "IT",
    "name": "Roncone",
    "lat": "45.9827",
    "lng": "10.66817"
  },
  {
    "country": "IT",
    "name": "Roncofreddo",
    "lat": "44.04222",
    "lng": "12.30083"
  },
  {
    "country": "IT",
    "name": "Roncoferraro",
    "lat": "45.13812",
    "lng": "10.9421"
  },
  {
    "country": "IT",
    "name": "Roncocesi",
    "lat": "44.73843",
    "lng": "10.57816"
  },
  {
    "country": "IT",
    "name": "Ronco Canavese",
    "lat": "45.50081",
    "lng": "7.54702"
  },
  {
    "country": "IT",
    "name": "Ronco All'Adige",
    "lat": "45.33647",
    "lng": "11.23658"
  },
  {
    "country": "IT",
    "name": "Ronciglione",
    "lat": "42.28899",
    "lng": "12.21479"
  },
  {
    "country": "IT",
    "name": "Ronchis",
    "lat": "45.80792",
    "lng": "12.99545"
  },
  {
    "country": "IT",
    "name": "Ronchi dei Legionari",
    "lat": "45.82735",
    "lng": "13.50417"
  },
  {
    "country": "IT",
    "name": "Roncegno",
    "lat": "46.04934",
    "lng": "11.40824"
  },
  {
    "country": "IT",
    "name": "Roncade",
    "lat": "45.62165",
    "lng": "12.37643"
  },
  {
    "country": "IT",
    "name": "Roncà",
    "lat": "45.47987",
    "lng": "11.29323"
  },
  {
    "country": "IT",
    "name": "Romentino",
    "lat": "45.46296",
    "lng": "8.71811"
  },
  {
    "country": "IT",
    "name": "Romeno",
    "lat": "46.39452",
    "lng": "11.1192"
  },
  {
    "country": "IT",
    "name": "Romans d'Isonzo",
    "lat": "45.88816",
    "lng": "13.44187"
  },
  {
    "country": "IT",
    "name": "Romano di Lombardia",
    "lat": "45.52081",
    "lng": "9.7544"
  },
  {
    "country": "IT",
    "name": "Romano Canavese",
    "lat": "45.39925",
    "lng": "7.86885"
  },
  {
    "country": "IT",
    "name": "Romanengo",
    "lat": "45.37815",
    "lng": "9.78777"
  },
  {
    "country": "IT",
    "name": "Romana",
    "lat": "40.48439",
    "lng": "8.58571"
  },
  {
    "country": "IT",
    "name": "Romagnese",
    "lat": "44.84131",
    "lng": "9.3281"
  },
  {
    "country": "IT",
    "name": "Romagnano Sesia",
    "lat": "45.63279",
    "lng": "8.38697"
  },
  {
    "country": "IT",
    "name": "Scalo Romagnano al Monte",
    "lat": "40.61031",
    "lng": "15.44768"
  },
  {
    "country": "IT",
    "name": "Romagnano",
    "lat": "46.01807",
    "lng": "11.10563"
  },
  {
    "country": "IT",
    "name": "Rome",
    "lat": "41.89193",
    "lng": "12.51133"
  },
  {
    "country": "IT",
    "name": "Rolo",
    "lat": "44.88482",
    "lng": "10.85961"
  },
  {
    "country": "IT",
    "name": "La Cretaz-Roisan",
    "lat": "45.78396",
    "lng": "7.3131"
  },
  {
    "country": "IT",
    "name": "Roio del Sangro",
    "lat": "41.91153",
    "lng": "14.37382"
  },
  {
    "country": "IT",
    "name": "Roiate",
    "lat": "41.87332",
    "lng": "13.06627"
  },
  {
    "country": "IT",
    "name": "Rogolo",
    "lat": "46.13721",
    "lng": "9.48528"
  },
  {
    "country": "IT",
    "name": "Rognano",
    "lat": "45.28847",
    "lng": "9.09025"
  },
  {
    "country": "IT",
    "name": "Rofrano",
    "lat": "40.21277",
    "lng": "15.42848"
  },
  {
    "country": "IT",
    "name": "Rodigo",
    "lat": "45.19912",
    "lng": "10.62527"
  },
  {
    "country": "IT",
    "name": "Rodi Garganico",
    "lat": "41.92745",
    "lng": "15.88217"
  },
  {
    "country": "IT",
    "name": "Rodengo",
    "lat": "46.8",
    "lng": "11.7"
  },
  {
    "country": "IT",
    "name": "Rodeano",
    "lat": "46.11085",
    "lng": "13.0111"
  },
  {
    "country": "IT",
    "name": "Lucino-Rodano",
    "lat": "45.47607",
    "lng": "9.35315"
  },
  {
    "country": "IT",
    "name": "Rocchetta Sant'Antonio",
    "lat": "41.10326",
    "lng": "15.45993"
  },
  {
    "country": "IT",
    "name": "Rocchetta Nervina",
    "lat": "43.88988",
    "lng": "7.60071"
  },
  {
    "country": "IT",
    "name": "Rocchetta Ligure",
    "lat": "44.70655",
    "lng": "9.05046"
  },
  {
    "country": "IT",
    "name": "Rocchetta di Vara",
    "lat": "44.25059",
    "lng": "9.75791"
  },
  {
    "country": "IT",
    "name": "Rocchetta a Volturno",
    "lat": "41.62582",
    "lng": "14.08902"
  },
  {
    "country": "IT",
    "name": "Rocchetta",
    "lat": "41.23716",
    "lng": "14.15765"
  },
  {
    "country": "IT",
    "name": "Roccavivi",
    "lat": "41.81214",
    "lng": "13.53662"
  },
  {
    "country": "IT",
    "name": "Roccavivara",
    "lat": "41.83336",
    "lng": "14.60013"
  },
  {
    "country": "IT",
    "name": "Roccavione",
    "lat": "44.31355",
    "lng": "7.47845"
  },
  {
    "country": "IT",
    "name": "Susella",
    "lat": "44.91267",
    "lng": "9.09651"
  },
  {
    "country": "IT",
    "name": "Roccastrada",
    "lat": "43.00888",
    "lng": "11.16762"
  },
  {
    "country": "IT",
    "name": "Roccaspinalveti-Santa Giusta",
    "lat": "41.94233",
    "lng": "14.47092"
  },
  {
    "country": "IT",
    "name": "Rocca Sinibalda",
    "lat": "42.27215",
    "lng": "12.92469"
  },
  {
    "country": "IT",
    "name": "Roccasicura",
    "lat": "41.69676",
    "lng": "14.23065"
  },
  {
    "country": "IT",
    "name": "Roccasecca dei Volsci",
    "lat": "41.47852",
    "lng": "13.2128"
  },
  {
    "country": "IT",
    "name": "Roccasecca",
    "lat": "41.55132",
    "lng": "13.66711"
  },
  {
    "country": "IT",
    "name": "Roccascalegna",
    "lat": "42.06212",
    "lng": "14.30802"
  },
  {
    "country": "IT",
    "name": "Rocca San Felice",
    "lat": "40.95014",
    "lng": "15.16656"
  },
  {
    "country": "IT",
    "name": "Rocca San Casciano",
    "lat": "44.05871",
    "lng": "11.84274"
  },
  {
    "country": "IT",
    "name": "Roccaromana",
    "lat": "41.2736",
    "lng": "14.2219"
  },
  {
    "country": "IT",
    "name": "Roccaraso",
    "lat": "41.84872",
    "lng": "14.07846"
  },
  {
    "country": "IT",
    "name": "Roccarainola",
    "lat": "40.9725",
    "lng": "14.54283"
  },
  {
    "country": "IT",
    "name": "Rocca Priora",
    "lat": "41.76585",
    "lng": "12.76577"
  },
  {
    "country": "IT",
    "name": "Roccapiemonte",
    "lat": "40.76009",
    "lng": "14.69089"
  },
  {
    "country": "IT",
    "name": "Rocca Pia",
    "lat": "41.93429",
    "lng": "13.97726"
  },
  {
    "country": "IT",
    "name": "Roccantica",
    "lat": "42.32073",
    "lng": "12.69398"
  },
  {
    "country": "IT",
    "name": "Roccanova",
    "lat": "40.2125",
    "lng": "16.20429"
  },
  {
    "country": "IT",
    "name": "San Rocco",
    "lat": "42.24294",
    "lng": "14.12891"
  },
  {
    "country": "IT",
    "name": "Roccamonfina",
    "lat": "41.28683",
    "lng": "13.97905"
  },
  {
    "country": "IT",
    "name": "Rocca Massima",
    "lat": "41.67907",
    "lng": "12.92116"
  },
  {
    "country": "IT",
    "name": "Roccamandolfi",
    "lat": "41.49583",
    "lng": "14.35217"
  },
  {
    "country": "IT",
    "name": "Roccalbegna",
    "lat": "42.7863",
    "lng": "11.50788"
  },
  {
    "country": "IT",
    "name": "Rocca Imperiale",
    "lat": "40.11014",
    "lng": "16.57822"
  },
  {
    "country": "IT",
    "name": "Roccagloriosa",
    "lat": "40.10628",
    "lng": "15.43642"
  },
  {
    "country": "IT",
    "name": "Roccagiovine",
    "lat": "42.05069",
    "lng": "12.89925"
  },
  {
    "country": "IT",
    "name": "Roccafranca",
    "lat": "45.46405",
    "lng": "9.9126"
  },
  {
    "country": "IT",
    "name": "Roccaforzata",
    "lat": "40.437",
    "lng": "17.38986"
  },
  {
    "country": "IT",
    "name": "Roccaforte Mondovì",
    "lat": "44.31721",
    "lng": "7.74426"
  },
  {
    "country": "IT",
    "name": "Roccaforte Ligure",
    "lat": "44.6778",
    "lng": "9.028"
  },
  {
    "country": "IT",
    "name": "Rocca di Papa",
    "lat": "41.7658",
    "lng": "12.70188"
  },
  {
    "country": "IT",
    "name": "Rocca di Mezzo",
    "lat": "42.20441",
    "lng": "13.5184"
  },
  {
    "country": "IT",
    "name": "Rocca di Cave",
    "lat": "41.84589",
    "lng": "12.94509"
  },
  {
    "country": "IT",
    "name": "Rocca di Cambio",
    "lat": "42.23755",
    "lng": "13.48906"
  },
  {
    "country": "IT",
    "name": "Rocca di Botte",
    "lat": "42.03102",
    "lng": "13.07185"
  },
  {
    "country": "IT",
    "name": "Roccadaspide",
    "lat": "40.42333",
    "lng": "15.19118"
  },
  {
    "country": "IT",
    "name": "Rocca d'Arce",
    "lat": "41.58712",
    "lng": "13.58511"
  },
  {
    "country": "IT",
    "name": "Roccacasale",
    "lat": "42.12249",
    "lng": "13.88758"
  },
  {
    "country": "IT",
    "name": "Rocca Canavese",
    "lat": "45.3087",
    "lng": "7.57875"
  },
  {
    "country": "IT",
    "name": "Roccabianca",
    "lat": "45.00772",
    "lng": "10.21824"
  },
  {
    "country": "IT",
    "name": "Robilante",
    "lat": "44.29288",
    "lng": "7.51367"
  },
  {
    "country": "IT",
    "name": "Robecco sul Naviglio",
    "lat": "45.43662",
    "lng": "8.88573"
  },
  {
    "country": "IT",
    "name": "Robecco d'Oglio",
    "lat": "45.25851",
    "lng": "10.07718"
  },
  {
    "country": "IT",
    "name": "Robecchetto Con Induno",
    "lat": "45.52848",
    "lng": "8.77068"
  },
  {
    "country": "IT",
    "name": "Robbio",
    "lat": "45.28901",
    "lng": "8.59289"
  },
  {
    "country": "IT",
    "name": "Robbiate",
    "lat": "45.68829",
    "lng": "9.43712"
  },
  {
    "country": "IT",
    "name": "Robassomero",
    "lat": "45.19841",
    "lng": "7.56754"
  },
  {
    "country": "IT",
    "name": "Roasio",
    "lat": "45.60457",
    "lng": "8.28482"
  },
  {
    "country": "IT",
    "name": "Roana",
    "lat": "45.87696",
    "lng": "11.45274"
  },
  {
    "country": "IT",
    "name": "Ro",
    "lat": "44.94695",
    "lng": "11.76006"
  },
  {
    "country": "IT",
    "name": "Rivolta d'Adda",
    "lat": "45.46962",
    "lng": "9.51251"
  },
  {
    "country": "IT",
    "name": "Rivoli",
    "lat": "45.07073",
    "lng": "7.51465"
  },
  {
    "country": "IT",
    "name": "Rivodutri",
    "lat": "42.51684",
    "lng": "12.85595"
  },
  {
    "country": "IT",
    "name": "Rivignano",
    "lat": "45.87575",
    "lng": "13.0419"
  },
  {
    "country": "IT",
    "name": "Rivergaro",
    "lat": "44.915",
    "lng": "9.60443"
  },
  {
    "country": "IT",
    "name": "Rivello",
    "lat": "40.07821",
    "lng": "15.75798"
  },
  {
    "country": "IT",
    "name": "Rive d'Arcano",
    "lat": "46.12722",
    "lng": "13.03222"
  },
  {
    "country": "IT",
    "name": "Rive",
    "lat": "45.21364",
    "lng": "8.41701"
  },
  {
    "country": "IT",
    "name": "Rivarolo Mantovano",
    "lat": "45.07272",
    "lng": "10.43713"
  },
  {
    "country": "IT",
    "name": "Rivarolo del Re",
    "lat": "45.03116",
    "lng": "10.47253"
  },
  {
    "country": "IT",
    "name": "Rivarolo Canavese",
    "lat": "45.32829",
    "lng": "7.7211"
  },
  {
    "country": "IT",
    "name": "Rivara",
    "lat": "45.33042",
    "lng": "7.649"
  },
  {
    "country": "IT",
    "name": "Riva Presso Chieri",
    "lat": "44.98338",
    "lng": "7.87313"
  },
  {
    "country": "IT",
    "name": "Rivanazzano",
    "lat": "44.92908",
    "lng": "9.01368"
  },
  {
    "country": "IT",
    "name": "Rivamonte Agordino",
    "lat": "46.25226",
    "lng": "12.02303"
  },
  {
    "country": "IT",
    "name": "Rivalta di Torino",
    "lat": "45.03268",
    "lng": "7.52042"
  },
  {
    "country": "IT",
    "name": "Riva Ligure",
    "lat": "43.83883",
    "lng": "7.87935"
  },
  {
    "country": "IT",
    "name": "Rivalba",
    "lat": "45.11669",
    "lng": "7.88811"
  },
  {
    "country": "IT",
    "name": "Riva del Garda",
    "lat": "45.88577",
    "lng": "10.84117"
  },
  {
    "country": "IT",
    "name": "Ripi",
    "lat": "41.61366",
    "lng": "13.424"
  },
  {
    "country": "IT",
    "name": "Ripe San Ginesio",
    "lat": "43.14202",
    "lng": "13.36724"
  },
  {
    "country": "IT",
    "name": "Ripe",
    "lat": "43.66906",
    "lng": "13.10586"
  },
  {
    "country": "IT",
    "name": "Ripatransone",
    "lat": "43.00015",
    "lng": "13.76203"
  },
  {
    "country": "IT",
    "name": "Ripa Teatina",
    "lat": "42.36603",
    "lng": "14.24441"
  },
  {
    "country": "IT",
    "name": "Riparbella",
    "lat": "43.36417",
    "lng": "10.59799"
  },
  {
    "country": "IT",
    "name": "Ripalta Nuova",
    "lat": "45.33203",
    "lng": "9.69244"
  },
  {
    "country": "IT",
    "name": "Ripalimosani",
    "lat": "41.61064",
    "lng": "14.66306"
  },
  {
    "country": "IT",
    "name": "Ripacandida",
    "lat": "40.91256",
    "lng": "15.72597"
  },
  {
    "country": "IT",
    "name": "Ripabottoni",
    "lat": "41.68996",
    "lng": "14.80866"
  },
  {
    "country": "IT",
    "name": "Vignale Riotorto",
    "lat": "42.97998",
    "lng": "10.68471"
  },
  {
    "country": "IT",
    "name": "Rio Saliceto",
    "lat": "44.81147",
    "lng": "10.80414"
  },
  {
    "country": "IT",
    "name": "Rionero Sannitico",
    "lat": "41.71219",
    "lng": "14.13917"
  },
  {
    "country": "IT",
    "name": "Rionero in Vulture",
    "lat": "40.92328",
    "lng": "15.6711"
  },
  {
    "country": "IT",
    "name": "Rio Marina",
    "lat": "42.81395",
    "lng": "10.426"
  },
  {
    "country": "IT",
    "name": "Riomaggiore",
    "lat": "44.09979",
    "lng": "9.73869"
  },
  {
    "country": "IT",
    "name": "Riolunato",
    "lat": "44.23102",
    "lng": "10.6531"
  },
  {
    "country": "IT",
    "name": "Riolo Terme",
    "lat": "44.27609",
    "lng": "11.72722"
  },
  {
    "country": "IT",
    "name": "Riofreddo",
    "lat": "42.05875",
    "lng": "12.99661"
  },
  {
    "country": "IT",
    "name": "Rio di Pusteria",
    "lat": "46.79658",
    "lng": "11.66754"
  },
  {
    "country": "IT",
    "name": "Rio nell'Elba",
    "lat": "42.81169",
    "lng": "10.40085"
  },
  {
    "country": "IT",
    "name": "Rimini",
    "lat": "44.05755",
    "lng": "12.56528"
  },
  {
    "country": "IT",
    "name": "Rimella",
    "lat": "45.90807",
    "lng": "8.18222"
  },
  {
    "country": "IT",
    "name": "Rimasco",
    "lat": "45.86025",
    "lng": "8.06412"
  },
  {
    "country": "IT",
    "name": "Rima",
    "lat": "45.88542",
    "lng": "7.99864"
  },
  {
    "country": "IT",
    "name": "Rigolato",
    "lat": "46.55393",
    "lng": "12.84619"
  },
  {
    "country": "IT",
    "name": "Rignano sull'Arno",
    "lat": "43.72145",
    "lng": "11.45183"
  },
  {
    "country": "IT",
    "name": "Rignano Garganico",
    "lat": "41.67934",
    "lng": "15.58835"
  },
  {
    "country": "IT",
    "name": "Rignano Flaminio",
    "lat": "42.2055",
    "lng": "12.48068"
  },
  {
    "country": "IT",
    "name": "Scena",
    "lat": "46.6884",
    "lng": "11.18855"
  },
  {
    "country": "IT",
    "name": "Rieti",
    "lat": "42.40476",
    "lng": "12.85735"
  },
  {
    "country": "IT",
    "name": "Riese Pio X",
    "lat": "45.72858",
    "lng": "11.91801"
  },
  {
    "country": "IT",
    "name": "Ricigliano",
    "lat": "40.66803",
    "lng": "15.4779"
  },
  {
    "country": "IT",
    "name": "Riccò del Golfo",
    "lat": "44.1541",
    "lng": "9.76414"
  },
  {
    "country": "IT",
    "name": "Riccione",
    "lat": "43.99942",
    "lng": "12.65689"
  },
  {
    "country": "IT",
    "name": "Riccia",
    "lat": "41.48314",
    "lng": "14.83181"
  },
  {
    "country": "IT",
    "name": "Ribolla",
    "lat": "42.97087",
    "lng": "11.03555"
  },
  {
    "country": "IT",
    "name": "Riardo",
    "lat": "41.26197",
    "lng": "14.15045"
  },
  {
    "country": "IT",
    "name": "Riano",
    "lat": "42.09347",
    "lng": "12.51462"
  },
  {
    "country": "IT",
    "name": "Riale",
    "lat": "44.48333",
    "lng": "11.23333"
  },
  {
    "country": "IT",
    "name": "Rho",
    "lat": "45.53245",
    "lng": "9.0402"
  },
  {
    "country": "IT",
    "name": "Rhemes-Notre-Dame",
    "lat": "45.56965",
    "lng": "7.1187"
  },
  {
    "country": "IT",
    "name": "Rezzoaglio",
    "lat": "44.52625",
    "lng": "9.38827"
  },
  {
    "country": "IT",
    "name": "Rezzo",
    "lat": "44.02101",
    "lng": "7.87199"
  },
  {
    "country": "IT",
    "name": "Rezzato",
    "lat": "45.51182",
    "lng": "10.31731"
  },
  {
    "country": "IT",
    "name": "Rezzago",
    "lat": "45.86673",
    "lng": "9.24863"
  },
  {
    "country": "IT",
    "name": "Revò",
    "lat": "46.39226",
    "lng": "11.05808"
  },
  {
    "country": "IT",
    "name": "Revine",
    "lat": "45.99935",
    "lng": "12.25561"
  },
  {
    "country": "IT",
    "name": "Revigliasco",
    "lat": "45.01589",
    "lng": "7.73306"
  },
  {
    "country": "IT",
    "name": "Revere",
    "lat": "45.05207",
    "lng": "11.13059"
  },
  {
    "country": "IT",
    "name": "Revello",
    "lat": "44.65451",
    "lng": "7.39026"
  },
  {
    "country": "IT",
    "name": "Retorbido",
    "lat": "44.9498",
    "lng": "9.0368"
  },
  {
    "country": "IT",
    "name": "Resiutta",
    "lat": "46.39371",
    "lng": "13.21796"
  },
  {
    "country": "IT",
    "name": "Rescaldina",
    "lat": "45.62002",
    "lng": "8.94878"
  },
  {
    "country": "IT",
    "name": "Resana",
    "lat": "45.63535",
    "lng": "11.95472"
  },
  {
    "country": "IT",
    "name": "Renazzo",
    "lat": "44.76527",
    "lng": "11.28605"
  },
  {
    "country": "IT",
    "name": "Remedello di Sopra",
    "lat": "45.27873",
    "lng": "10.37109"
  },
  {
    "country": "IT",
    "name": "Remanzacco",
    "lat": "46.08535",
    "lng": "13.32358"
  },
  {
    "country": "IT",
    "name": "Reino",
    "lat": "41.29219",
    "lng": "14.82347"
  },
  {
    "country": "IT",
    "name": "Reggio nell'Emilia",
    "lat": "44.69825",
    "lng": "10.63125"
  },
  {
    "country": "IT",
    "name": "Reggiolo",
    "lat": "44.91824",
    "lng": "10.81016"
  },
  {
    "country": "IT",
    "name": "Reggello",
    "lat": "43.67967",
    "lng": "11.52976"
  },
  {
    "country": "IT",
    "name": "Refrontolo",
    "lat": "45.92305",
    "lng": "12.20865"
  },
  {
    "country": "IT",
    "name": "Recoaro Terme",
    "lat": "45.70373",
    "lng": "11.22216"
  },
  {
    "country": "IT",
    "name": "Recetto",
    "lat": "45.45965",
    "lng": "8.43503"
  },
  {
    "country": "IT",
    "name": "Recco",
    "lat": "44.36227",
    "lng": "9.14354"
  },
  {
    "country": "IT",
    "name": "Recanati",
    "lat": "43.40381",
    "lng": "13.55379"
  },
  {
    "country": "IT",
    "name": "Recale",
    "lat": "41.05702",
    "lng": "14.3027"
  },
  {
    "country": "IT",
    "name": "Reano",
    "lat": "45.05217",
    "lng": "7.42779"
  },
  {
    "country": "IT",
    "name": "Re",
    "lat": "46.13148",
    "lng": "8.54569"
  },
  {
    "country": "IT",
    "name": "Raviscanina",
    "lat": "41.3709",
    "lng": "14.24335"
  },
  {
    "country": "IT",
    "name": "Raveo",
    "lat": "46.43392",
    "lng": "12.87165"
  },
  {
    "country": "IT",
    "name": "Ravenna",
    "lat": "44.41344",
    "lng": "12.20121"
  },
  {
    "country": "IT",
    "name": "Ravello",
    "lat": "40.64932",
    "lng": "14.61167"
  },
  {
    "country": "IT",
    "name": "Ravascletto",
    "lat": "46.52504",
    "lng": "12.92138"
  },
  {
    "country": "IT",
    "name": "Ravarino",
    "lat": "44.72475",
    "lng": "11.09588"
  },
  {
    "country": "IT",
    "name": "Rauscedo-Domanins",
    "lat": "46.04083",
    "lng": "12.82472"
  },
  {
    "country": "IT",
    "name": "Rasura",
    "lat": "46.10059",
    "lng": "9.55274"
  },
  {
    "country": "IT",
    "name": "Rassina",
    "lat": "43.64737",
    "lng": "11.83632"
  },
  {
    "country": "IT",
    "name": "Rapone",
    "lat": "40.8471",
    "lng": "15.49818"
  },
  {
    "country": "IT",
    "name": "Rapolla",
    "lat": "40.97499",
    "lng": "15.67201"
  },
  {
    "country": "IT",
    "name": "Rapolano Terme",
    "lat": "43.29498",
    "lng": "11.60264"
  },
  {
    "country": "IT",
    "name": "Rapino",
    "lat": "42.20931",
    "lng": "14.18493"
  },
  {
    "country": "IT",
    "name": "Rapallo",
    "lat": "44.3496",
    "lng": "9.22796"
  },
  {
    "country": "IT",
    "name": "Rapagnano",
    "lat": "43.15985",
    "lng": "13.58873"
  },
  {
    "country": "IT",
    "name": "Ranco",
    "lat": "45.79733",
    "lng": "8.57105"
  },
  {
    "country": "IT",
    "name": "Rancio Valcuvia",
    "lat": "45.91594",
    "lng": "8.77157"
  },
  {
    "country": "IT",
    "name": "Ramon",
    "lat": "45.71386",
    "lng": "11.86828"
  },
  {
    "country": "IT",
    "name": "Ramiseto",
    "lat": "44.41284",
    "lng": "10.27689"
  },
  {
    "country": "IT",
    "name": "Raldon",
    "lat": "45.34921",
    "lng": "11.03786"
  },
  {
    "country": "IT",
    "name": "Raiano",
    "lat": "42.10158",
    "lng": "13.81386"
  },
  {
    "country": "IT",
    "name": "Radicondoli",
    "lat": "43.26047",
    "lng": "11.04582"
  },
  {
    "country": "IT",
    "name": "Radicofani",
    "lat": "42.89618",
    "lng": "11.76839"
  },
  {
    "country": "IT",
    "name": "Radda in Chianti",
    "lat": "43.4854",
    "lng": "11.37437"
  },
  {
    "country": "IT",
    "name": "Racines",
    "lat": "46.86667",
    "lng": "11.3"
  },
  {
    "country": "IT",
    "name": "Racconigi",
    "lat": "44.76598",
    "lng": "7.67893"
  },
  {
    "country": "IT",
    "name": "Quistello",
    "lat": "45.00794",
    "lng": "10.98377"
  },
  {
    "country": "IT",
    "name": "Quinzano d'Oglio",
    "lat": "45.3143",
    "lng": "10.00785"
  },
  {
    "country": "IT",
    "name": "Quinto Vicentino",
    "lat": "45.57534",
    "lng": "11.62815"
  },
  {
    "country": "IT",
    "name": "Quinto Vercellese",
    "lat": "45.3792",
    "lng": "8.3621"
  },
  {
    "country": "IT",
    "name": "Quinto di Treviso",
    "lat": "45.64351",
    "lng": "12.16509"
  },
  {
    "country": "IT",
    "name": "Quingentole",
    "lat": "45.03801",
    "lng": "11.04575"
  },
  {
    "country": "IT",
    "name": "Quindici",
    "lat": "40.86497",
    "lng": "14.64663"
  },
  {
    "country": "IT",
    "name": "Quincinetto",
    "lat": "45.56157",
    "lng": "7.80834"
  },
  {
    "country": "IT",
    "name": "Quiliano",
    "lat": "44.29215",
    "lng": "8.41406"
  },
  {
    "country": "IT",
    "name": "Quero",
    "lat": "45.92094",
    "lng": "11.93151"
  },
  {
    "country": "IT",
    "name": "Quercianella",
    "lat": "43.45959",
    "lng": "10.36757"
  },
  {
    "country": "IT",
    "name": "Ripa-Pozzi-Querceta-Ponterosso",
    "lat": "43.97806",
    "lng": "10.20372"
  },
  {
    "country": "IT",
    "name": "Quattro Castella",
    "lat": "44.63496",
    "lng": "10.47429"
  },
  {
    "country": "IT",
    "name": "Quattordio",
    "lat": "44.89877",
    "lng": "8.40495"
  },
  {
    "country": "IT",
    "name": "Quassolo",
    "lat": "45.52294",
    "lng": "7.83305"
  },
  {
    "country": "IT",
    "name": "Quasano",
    "lat": "40.96724",
    "lng": "16.57354"
  },
  {
    "country": "IT",
    "name": "Quarto Inferiore",
    "lat": "44.5309",
    "lng": "11.41679"
  },
  {
    "country": "IT",
    "name": "Quarto d'Altino",
    "lat": "45.57944",
    "lng": "12.37333"
  },
  {
    "country": "IT",
    "name": "Quartesana",
    "lat": "44.8049",
    "lng": "11.73873"
  },
  {
    "country": "IT",
    "name": "Quart",
    "lat": "45.74096",
    "lng": "7.4152"
  },
  {
    "country": "IT",
    "name": "Quarrata",
    "lat": "43.84837",
    "lng": "10.97888"
  },
  {
    "country": "IT",
    "name": "Quarona",
    "lat": "45.76044",
    "lng": "8.26749"
  },
  {
    "country": "IT",
    "name": "Quarna Sopra",
    "lat": "45.87307",
    "lng": "8.37355"
  },
  {
    "country": "IT",
    "name": "Quargnento",
    "lat": "44.94566",
    "lng": "8.48821"
  },
  {
    "country": "IT",
    "name": "Quarata",
    "lat": "43.49859",
    "lng": "11.82742"
  },
  {
    "country": "IT",
    "name": "Quarantoli",
    "lat": "44.91954",
    "lng": "11.10324"
  },
  {
    "country": "IT",
    "name": "Qualiano",
    "lat": "40.91899",
    "lng": "14.15352"
  },
  {
    "country": "IT",
    "name": "Quagliuzzo",
    "lat": "45.42654",
    "lng": "7.78101"
  },
  {
    "country": "IT",
    "name": "Quadri",
    "lat": "41.92402",
    "lng": "14.28768"
  },
  {
    "country": "IT",
    "name": "Quadrelle",
    "lat": "40.94851",
    "lng": "14.63934"
  },
  {
    "country": "IT",
    "name": "Putignano",
    "lat": "40.85106",
    "lng": "17.1219"
  },
  {
    "country": "IT",
    "name": "Putifigari",
    "lat": "40.56145",
    "lng": "8.46063"
  },
  {
    "country": "IT",
    "name": "Pusiano",
    "lat": "45.81478",
    "lng": "9.28217"
  },
  {
    "country": "IT",
    "name": "Puos d'Alpago",
    "lat": "46.14154",
    "lng": "12.36176"
  },
  {
    "country": "IT",
    "name": "Punta Marina",
    "lat": "44.44272",
    "lng": "12.29089"
  },
  {
    "country": "IT",
    "name": "Pumenengo",
    "lat": "45.48002",
    "lng": "9.86775"
  },
  {
    "country": "IT",
    "name": "Pulsano",
    "lat": "40.38109",
    "lng": "17.35612"
  },
  {
    "country": "IT",
    "name": "Pulfero",
    "lat": "46.17376",
    "lng": "13.48363"
  },
  {
    "country": "IT",
    "name": "Puianello",
    "lat": "44.6263",
    "lng": "10.5642"
  },
  {
    "country": "IT",
    "name": "Puglianello",
    "lat": "41.22179",
    "lng": "14.45023"
  },
  {
    "country": "IT",
    "name": "Provvidenti",
    "lat": "41.71795",
    "lng": "14.82349"
  },
  {
    "country": "IT",
    "name": "Prossedi",
    "lat": "41.51674",
    "lng": "13.261"
  },
  {
    "country": "IT",
    "name": "Prosecco-Contovello",
    "lat": "45.70807",
    "lng": "13.73376"
  },
  {
    "country": "IT",
    "name": "Propata",
    "lat": "44.56487",
    "lng": "9.18587"
  },
  {
    "country": "IT",
    "name": "Procida",
    "lat": "40.75636",
    "lng": "14.01457"
  },
  {
    "country": "IT",
    "name": "Proceno",
    "lat": "42.75745",
    "lng": "11.829"
  },
  {
    "country": "IT",
    "name": "Priverno",
    "lat": "41.47047",
    "lng": "13.17867"
  },
  {
    "country": "IT",
    "name": "Priola",
    "lat": "44.24478",
    "lng": "8.02149"
  },
  {
    "country": "IT",
    "name": "Prignano sulla Secchia",
    "lat": "44.43836",
    "lng": "10.6919"
  },
  {
    "country": "IT",
    "name": "Prignano Cilento",
    "lat": "40.33335",
    "lng": "15.06739"
  },
  {
    "country": "IT",
    "name": "Prezza",
    "lat": "42.05789",
    "lng": "13.83592"
  },
  {
    "country": "IT",
    "name": "Preturo",
    "lat": "42.37808",
    "lng": "13.29633"
  },
  {
    "country": "IT",
    "name": "Pretoro",
    "lat": "42.21923",
    "lng": "14.14248"
  },
  {
    "country": "IT",
    "name": "Pressana",
    "lat": "45.28258",
    "lng": "11.40724"
  },
  {
    "country": "IT",
    "name": "Presenzano",
    "lat": "41.37823",
    "lng": "14.09162"
  },
  {
    "country": "IT",
    "name": "Prè Saint Didier",
    "lat": "45.76416",
    "lng": "6.98579"
  },
  {
    "country": "IT",
    "name": "Preore",
    "lat": "46.04663",
    "lng": "10.75969"
  },
  {
    "country": "IT",
    "name": "Premosello-Chiovenda",
    "lat": "46.0038",
    "lng": "8.32973"
  },
  {
    "country": "IT",
    "name": "Premilcuore",
    "lat": "43.98084",
    "lng": "11.78193"
  },
  {
    "country": "IT",
    "name": "Premeno",
    "lat": "45.97818",
    "lng": "8.59587"
  },
  {
    "country": "IT",
    "name": "Premariacco",
    "lat": "46.06145",
    "lng": "13.39461"
  },
  {
    "country": "IT",
    "name": "Premana",
    "lat": "46.05245",
    "lng": "9.42129"
  },
  {
    "country": "IT",
    "name": "Preganziol",
    "lat": "45.60139",
    "lng": "12.23722"
  },
  {
    "country": "IT",
    "name": "Predosa",
    "lat": "44.75049",
    "lng": "8.65568"
  },
  {
    "country": "IT",
    "name": "Predore",
    "lat": "45.68085",
    "lng": "10.01271"
  },
  {
    "country": "IT",
    "name": "Predoi",
    "lat": "47.04031",
    "lng": "12.10663"
  },
  {
    "country": "IT",
    "name": "Predazzo",
    "lat": "46.3114",
    "lng": "11.5996"
  },
  {
    "country": "IT",
    "name": "Preci",
    "lat": "42.88069",
    "lng": "13.03747"
  },
  {
    "country": "IT",
    "name": "Precenicco",
    "lat": "45.79694",
    "lng": "13.07554"
  },
  {
    "country": "IT",
    "name": "Prazzo Superiore",
    "lat": "44.48297",
    "lng": "7.05468"
  },
  {
    "country": "IT",
    "name": "Pray",
    "lat": "45.67508",
    "lng": "8.20951"
  },
  {
    "country": "IT",
    "name": "Pravisdomini",
    "lat": "45.81972",
    "lng": "12.69478"
  },
  {
    "country": "IT",
    "name": "Pratovecchio",
    "lat": "43.78685",
    "lng": "11.72353"
  },
  {
    "country": "IT",
    "name": "Prato Sesia",
    "lat": "45.65067",
    "lng": "8.37293"
  },
  {
    "country": "IT",
    "name": "Pratola Serra",
    "lat": "40.98655",
    "lng": "14.85149"
  },
  {
    "country": "IT",
    "name": "Pratola Peligna",
    "lat": "42.09701",
    "lng": "13.87467"
  },
  {
    "country": "IT",
    "name": "Prato",
    "lat": "46.37364",
    "lng": "13.30659"
  },
  {
    "country": "IT",
    "name": "Prato Carnico",
    "lat": "46.52049",
    "lng": "12.80886"
  },
  {
    "country": "IT",
    "name": "Prato Allo Stelvio",
    "lat": "46.61901",
    "lng": "10.59136"
  },
  {
    "country": "IT",
    "name": "Prato",
    "lat": "43.8805",
    "lng": "11.09699"
  },
  {
    "country": "IT",
    "name": "Pratella",
    "lat": "41.40579",
    "lng": "14.17913"
  },
  {
    "country": "IT",
    "name": "Prata Sannita Centro",
    "lat": "41.43282",
    "lng": "14.20272"
  },
  {
    "country": "IT",
    "name": "Pratantico-Indicatore",
    "lat": "43.48071",
    "lng": "11.80531"
  },
  {
    "country": "IT",
    "name": "Prata di Principato Ultra",
    "lat": "40.98626",
    "lng": "14.83803"
  },
  {
    "country": "IT",
    "name": "Prata di Pordenone",
    "lat": "45.89441",
    "lng": "12.58843"
  },
  {
    "country": "IT",
    "name": "Prata d'Ansidonia",
    "lat": "42.27793",
    "lng": "13.6083"
  },
  {
    "country": "IT",
    "name": "Prata Camportaccio",
    "lat": "46.30719",
    "lng": "9.39524"
  },
  {
    "country": "IT",
    "name": "Prascorsano",
    "lat": "45.36721",
    "lng": "7.61727"
  },
  {
    "country": "IT",
    "name": "Prarolo",
    "lat": "45.28149",
    "lng": "8.47784"
  },
  {
    "country": "IT",
    "name": "Pralungo",
    "lat": "45.58999",
    "lng": "8.03976"
  },
  {
    "country": "IT",
    "name": "Pralormo",
    "lat": "44.85976",
    "lng": "7.9044"
  },
  {
    "country": "IT",
    "name": "Prali",
    "lat": "44.88944",
    "lng": "7.05131"
  },
  {
    "country": "IT",
    "name": "Pralboino",
    "lat": "45.2672",
    "lng": "10.21839"
  },
  {
    "country": "IT",
    "name": "Praiano",
    "lat": "40.61213",
    "lng": "14.52461"
  },
  {
    "country": "IT",
    "name": "Pradleves",
    "lat": "44.41786",
    "lng": "7.28146"
  },
  {
    "country": "IT",
    "name": "Pozzuolo del Friuli",
    "lat": "45.98517",
    "lng": "13.19724"
  },
  {
    "country": "IT",
    "name": "Pozzuolo",
    "lat": "43.12165",
    "lng": "11.95599"
  },
  {
    "country": "IT",
    "name": "Pozzuoli",
    "lat": "40.84394",
    "lng": "14.0952"
  },
  {
    "country": "IT",
    "name": "Pozzonovo",
    "lat": "45.19629",
    "lng": "11.79171"
  },
  {
    "country": "IT",
    "name": "Pozzomaggiore",
    "lat": "40.39767",
    "lng": "8.65931"
  },
  {
    "country": "IT",
    "name": "Pozzolo Formigaro",
    "lat": "44.79925",
    "lng": "8.78364"
  },
  {
    "country": "IT",
    "name": "Pozzoleone",
    "lat": "45.64965",
    "lng": "11.67098"
  },
  {
    "country": "IT",
    "name": "Pozzolengo",
    "lat": "45.40515",
    "lng": "10.6304"
  },
  {
    "country": "IT",
    "name": "Pozzillo",
    "lat": "41.20337",
    "lng": "14.1953"
  },
  {
    "country": "IT",
    "name": "Pozzilli",
    "lat": "41.51142",
    "lng": "14.06252"
  },
  {
    "country": "IT",
    "name": "Pozzaglio ed Uniti",
    "lat": "45.20027",
    "lng": "10.05057"
  },
  {
    "country": "IT",
    "name": "Pozzaglia Sabino",
    "lat": "42.15863",
    "lng": "12.96428"
  },
  {
    "country": "IT",
    "name": "Pozza di Fassa",
    "lat": "46.42806",
    "lng": "11.68711"
  },
  {
    "country": "IT",
    "name": "Pozza",
    "lat": "44.52641",
    "lng": "10.89234"
  },
  {
    "country": "IT",
    "name": "Povoletto",
    "lat": "46.11568",
    "lng": "13.29171"
  },
  {
    "country": "IT",
    "name": "Poviglio",
    "lat": "44.84227",
    "lng": "10.53936"
  },
  {
    "country": "IT",
    "name": "Povegliano Veronese",
    "lat": "45.3473",
    "lng": "10.88056"
  },
  {
    "country": "IT",
    "name": "Potenza Picena",
    "lat": "43.36635",
    "lng": "13.62249"
  },
  {
    "country": "IT",
    "name": "Potenza",
    "lat": "40.64175",
    "lng": "15.80794"
  },
  {
    "country": "IT",
    "name": "Postua",
    "lat": "45.71355",
    "lng": "8.22853"
  },
  {
    "country": "IT",
    "name": "Postioma",
    "lat": "45.71753",
    "lng": "12.15218"
  },
  {
    "country": "IT",
    "name": "Postiglione",
    "lat": "40.55901",
    "lng": "15.23236"
  },
  {
    "country": "IT",
    "name": "Postalesio",
    "lat": "46.17379",
    "lng": "9.77659"
  },
  {
    "country": "IT",
    "name": "Postal",
    "lat": "46.60949",
    "lng": "11.19313"
  },
  {
    "country": "IT",
    "name": "Posta",
    "lat": "42.52562",
    "lng": "13.09723"
  },
  {
    "country": "IT",
    "name": "Posta Fibreno",
    "lat": "41.69189",
    "lng": "13.68013"
  },
  {
    "country": "IT",
    "name": "Possagno",
    "lat": "45.84795",
    "lng": "11.88467"
  },
  {
    "country": "IT",
    "name": "Positano",
    "lat": "40.62829",
    "lng": "14.48427"
  },
  {
    "country": "IT",
    "name": "Posina",
    "lat": "45.79106",
    "lng": "11.26244"
  },
  {
    "country": "IT",
    "name": "Posatora",
    "lat": "43.59917",
    "lng": "13.48984"
  },
  {
    "country": "IT",
    "name": "Posada",
    "lat": "40.63203",
    "lng": "9.71904"
  },
  {
    "country": "IT",
    "name": "Portula",
    "lat": "45.67512",
    "lng": "8.17244"
  },
  {
    "country": "IT",
    "name": "Portovenere",
    "lat": "44.05083",
    "lng": "9.83431"
  },
  {
    "country": "IT",
    "name": "Porto Valtravaglia",
    "lat": "45.96088",
    "lng": "8.68109"
  },
  {
    "country": "IT",
    "name": "Porto Torres",
    "lat": "40.83375",
    "lng": "8.40531"
  },
  {
    "country": "IT",
    "name": "Porto Tolle",
    "lat": "44.94969",
    "lng": "12.32453"
  },
  {
    "country": "IT",
    "name": "Porto Santo Stefano",
    "lat": "42.43825",
    "lng": "11.11542"
  },
  {
    "country": "IT",
    "name": "Porto Sant'Elpidio",
    "lat": "43.25297",
    "lng": "13.7597"
  },
  {
    "country": "IT",
    "name": "Porto San Giorgio",
    "lat": "43.17784",
    "lng": "13.79411"
  },
  {
    "country": "IT",
    "name": "Porto Recanati",
    "lat": "43.43296",
    "lng": "13.66165"
  },
  {
    "country": "IT",
    "name": "Porto Potenza Picena",
    "lat": "43.35751",
    "lng": "13.69746"
  },
  {
    "country": "IT",
    "name": "Portomaggiore",
    "lat": "44.69763",
    "lng": "11.8076"
  },
  {
    "country": "IT",
    "name": "Portogruaro",
    "lat": "45.78071",
    "lng": "12.84052"
  },
  {
    "country": "IT",
    "name": "Porto Garibaldi",
    "lat": "44.68123",
    "lng": "12.23678"
  },
  {
    "country": "IT",
    "name": "Porto Fuori",
    "lat": "44.40557",
    "lng": "12.25218"
  },
  {
    "country": "IT",
    "name": "Portofino",
    "lat": "44.30349",
    "lng": "9.20942"
  },
  {
    "country": "IT",
    "name": "Portoferraio",
    "lat": "42.81233",
    "lng": "10.31297"
  },
  {
    "country": "IT",
    "name": "Porto Corsini",
    "lat": "44.4941",
    "lng": "12.27875"
  },
  {
    "country": "IT",
    "name": "Civitanova Marche",
    "lat": "43.30491",
    "lng": "13.72068"
  },
  {
    "country": "IT",
    "name": "Porto Ceresio",
    "lat": "45.91285",
    "lng": "8.89684"
  },
  {
    "country": "IT",
    "name": "Portocannone",
    "lat": "41.91441",
    "lng": "15.00845"
  },
  {
    "country": "IT",
    "name": "Portobuffolè",
    "lat": "45.85665",
    "lng": "12.53761"
  },
  {
    "country": "IT",
    "name": "Porto Azzurro",
    "lat": "42.76754",
    "lng": "10.39723"
  },
  {
    "country": "IT",
    "name": "Portico di Romagna",
    "lat": "44.02657",
    "lng": "11.78133"
  },
  {
    "country": "IT",
    "name": "Portico di Caserta",
    "lat": "41.05562",
    "lng": "14.28022"
  },
  {
    "country": "IT",
    "name": "Portici",
    "lat": "40.81563",
    "lng": "14.33716"
  },
  {
    "country": "IT",
    "name": "Porto Ercole",
    "lat": "42.40171",
    "lng": "11.20523"
  },
  {
    "country": "IT",
    "name": "Portalbera",
    "lat": "45.09789",
    "lng": "9.31774"
  },
  {
    "country": "IT",
    "name": "Porretta Terme",
    "lat": "44.16325",
    "lng": "10.97432"
  },
  {
    "country": "IT",
    "name": "Porporano",
    "lat": "44.75266",
    "lng": "10.35054"
  },
  {
    "country": "IT",
    "name": "Porpetto",
    "lat": "45.857",
    "lng": "13.21703"
  },
  {
    "country": "IT",
    "name": "Porotto-Cassama",
    "lat": "44.85",
    "lng": "11.55"
  },
  {
    "country": "IT",
    "name": "Pornassio",
    "lat": "44.07053",
    "lng": "7.86954"
  },
  {
    "country": "IT",
    "name": "Porlezza",
    "lat": "46.03714",
    "lng": "9.12921"
  },
  {
    "country": "IT",
    "name": "Pordenone",
    "lat": "45.95689",
    "lng": "12.66051"
  },
  {
    "country": "IT",
    "name": "Porcia",
    "lat": "45.96301",
    "lng": "12.61642"
  },
  {
    "country": "IT",
    "name": "Porcellengo",
    "lat": "45.70613",
    "lng": "12.14225"
  },
  {
    "country": "IT",
    "name": "Porcari",
    "lat": "43.84152",
    "lng": "10.61632"
  },
  {
    "country": "IT",
    "name": "Porano",
    "lat": "42.68099",
    "lng": "12.10331"
  },
  {
    "country": "IT",
    "name": "Poppi",
    "lat": "43.72123",
    "lng": "11.76642"
  },
  {
    "country": "IT",
    "name": "Popoli",
    "lat": "42.16866",
    "lng": "13.82997"
  },
  {
    "country": "IT",
    "name": "Ponzone",
    "lat": "44.58814",
    "lng": "8.45935"
  },
  {
    "country": "IT",
    "name": "Ponzano di Fermo",
    "lat": "43.1039",
    "lng": "13.65979"
  },
  {
    "country": "IT",
    "name": "Ponza",
    "lat": "40.89541",
    "lng": "12.95889"
  },
  {
    "country": "IT",
    "name": "Pont-Saint-Martin",
    "lat": "45.59536",
    "lng": "7.79451"
  },
  {
    "country": "IT",
    "name": "Pontremoli",
    "lat": "44.37515",
    "lng": "9.87888"
  },
  {
    "country": "IT",
    "name": "Pontinvrea",
    "lat": "44.44205",
    "lng": "8.43623"
  },
  {
    "country": "IT",
    "name": "Pontinia",
    "lat": "41.41097",
    "lng": "13.04259"
  },
  {
    "country": "IT",
    "name": "Pontida",
    "lat": "45.73129",
    "lng": "9.51141"
  },
  {
    "country": "IT",
    "name": "Ponticino",
    "lat": "43.48012",
    "lng": "11.71622"
  },
  {
    "country": "IT",
    "name": "Ponti",
    "lat": "44.62847",
    "lng": "8.36461"
  },
  {
    "country": "IT",
    "name": "Pontevico",
    "lat": "45.27315",
    "lng": "10.09248"
  },
  {
    "country": "IT",
    "name": "Lavena Ponte Tresa",
    "lat": "45.9671",
    "lng": "8.85725"
  },
  {
    "country": "IT",
    "name": "Ponte Taro",
    "lat": "44.82872",
    "lng": "10.21037"
  },
  {
    "country": "IT",
    "name": "Pontestura",
    "lat": "45.14245",
    "lng": "8.33324"
  },
  {
    "country": "IT",
    "name": "Ponte San Pietro",
    "lat": "45.70596",
    "lng": "9.5905"
  },
  {
    "country": "IT",
    "name": "Ponte San Nicolò",
    "lat": "45.36718",
    "lng": "11.92341"
  },
  {
    "country": "IT",
    "name": "Ponte Ronca",
    "lat": "44.50166",
    "lng": "11.18973"
  },
  {
    "country": "IT",
    "name": "Pontenure",
    "lat": "44.99821",
    "lng": "9.79139"
  },
  {
    "country": "IT",
    "name": "Ponte Nossa",
    "lat": "45.86611",
    "lng": "9.88364"
  },
  {
    "country": "IT",
    "name": "Ponte Nizza",
    "lat": "44.85188",
    "lng": "9.09739"
  },
  {
    "country": "IT",
    "name": "Ponte nelle Alpi",
    "lat": "46.18083",
    "lng": "12.28333"
  },
  {
    "country": "IT",
    "name": "Pontelongo",
    "lat": "45.2459",
    "lng": "12.02582"
  },
  {
    "country": "IT",
    "name": "Pontelatone",
    "lat": "41.1946",
    "lng": "14.24814"
  },
  {
    "country": "IT",
    "name": "Pontelandolfo",
    "lat": "41.29231",
    "lng": "14.68956"
  },
  {
    "country": "IT",
    "name": "Ponte Lambro",
    "lat": "45.82539",
    "lng": "9.22455"
  },
  {
    "country": "IT",
    "name": "Ponte Gardena",
    "lat": "46.59712",
    "lng": "11.53088"
  },
  {
    "country": "IT",
    "name": "Ponte Galeria-La Pisana",
    "lat": "41.84634",
    "lng": "12.33925"
  },
  {
    "country": "IT",
    "name": "Ponte di Piave",
    "lat": "45.71904",
    "lng": "12.46186"
  },
  {
    "country": "IT",
    "name": "Ponte di Legno",
    "lat": "46.25896",
    "lng": "10.51048"
  },
  {
    "country": "IT",
    "name": "Ponte di Barbarano",
    "lat": "45.39206",
    "lng": "11.57847"
  },
  {
    "country": "IT",
    "name": "Pontedera",
    "lat": "43.66141",
    "lng": "10.63067"
  },
  {
    "country": "IT",
    "name": "Ponte dell'Olio",
    "lat": "44.86762",
    "lng": "9.64433"
  },
  {
    "country": "IT",
    "name": "Ponte Arche",
    "lat": "46.03526",
    "lng": "10.8732"
  },
  {
    "country": "IT",
    "name": "Ponte della Venturina",
    "lat": "44.13042",
    "lng": "10.99113"
  },
  {
    "country": "IT",
    "name": "Pontedassio",
    "lat": "43.9383",
    "lng": "8.01464"
  },
  {
    "country": "IT",
    "name": "Pontecurone",
    "lat": "44.9588",
    "lng": "8.93289"
  },
  {
    "country": "IT",
    "name": "Pontecorvo",
    "lat": "41.45861",
    "lng": "13.66618"
  },
  {
    "country": "IT",
    "name": "Pontecchio Polesine",
    "lat": "45.0202",
    "lng": "11.81321"
  },
  {
    "country": "IT",
    "name": "Pontecagnano",
    "lat": "40.64448",
    "lng": "14.87628"
  },
  {
    "country": "IT",
    "name": "Ponte Caffaro",
    "lat": "45.82078",
    "lng": "10.52707"
  },
  {
    "country": "IT",
    "name": "Ponte Buggianese",
    "lat": "43.84599",
    "lng": "10.74789"
  },
  {
    "country": "IT",
    "name": "Pontebba",
    "lat": "46.5054",
    "lng": "13.30622"
  },
  {
    "country": "IT",
    "name": "Ponte A Tressa",
    "lat": "43.25158",
    "lng": "11.39514"
  },
  {
    "country": "IT",
    "name": "Giovi-Ponte alla Chiassa",
    "lat": "43.52634",
    "lng": "11.86558"
  },
  {
    "country": "IT",
    "name": "Grassina Ponte a Ema",
    "lat": "43.73333",
    "lng": "11.3"
  },
  {
    "country": "IT",
    "name": "Ponte A Elsa",
    "lat": "43.68907",
    "lng": "10.89281"
  },
  {
    "country": "IT",
    "name": "Ponte",
    "lat": "41.21554",
    "lng": "14.69826"
  },
  {
    "country": "IT",
    "name": "Pont-Canavese",
    "lat": "45.42138",
    "lng": "7.60024"
  },
  {
    "country": "IT",
    "name": "Pontassieve",
    "lat": "43.77477",
    "lng": "11.43109"
  },
  {
    "country": "IT",
    "name": "Ponso",
    "lat": "45.18232",
    "lng": "11.57933"
  },
  {
    "country": "IT",
    "name": "Ponsacco",
    "lat": "43.62307",
    "lng": "10.62661"
  },
  {
    "country": "IT",
    "name": "Ponna Superiore",
    "lat": "45.98957",
    "lng": "9.09406"
  },
  {
    "country": "IT",
    "name": "Poncarale",
    "lat": "45.46089",
    "lng": "10.17976"
  },
  {
    "country": "IT",
    "name": "Pomponesco",
    "lat": "44.93118",
    "lng": "10.59402"
  },
  {
    "country": "IT",
    "name": "Pompiano",
    "lat": "45.43116",
    "lng": "9.9891"
  },
  {
    "country": "IT",
    "name": "Pompeiana",
    "lat": "43.85297",
    "lng": "7.88836"
  },
  {
    "country": "IT",
    "name": "Pompei",
    "lat": "40.74574",
    "lng": "14.49698"
  },
  {
    "country": "IT",
    "name": "Pomigliano d'Arco",
    "lat": "40.90975",
    "lng": "14.38316"
  },
  {
    "country": "IT",
    "name": "Pomezia",
    "lat": "41.66931",
    "lng": "12.50124"
  },
  {
    "country": "IT",
    "name": "Pometo",
    "lat": "44.92788",
    "lng": "9.27348"
  },
  {
    "country": "IT",
    "name": "Pombia",
    "lat": "45.6555",
    "lng": "8.62846"
  },
  {
    "country": "IT",
    "name": "Pomaro Monferrato",
    "lat": "45.06246",
    "lng": "8.59604"
  },
  {
    "country": "IT",
    "name": "Pomarico",
    "lat": "40.52804",
    "lng": "16.52708"
  },
  {
    "country": "IT",
    "name": "Pomaretto",
    "lat": "44.9559",
    "lng": "7.18128"
  },
  {
    "country": "IT",
    "name": "Pomarance",
    "lat": "43.29592",
    "lng": "10.87223"
  },
  {
    "country": "IT",
    "name": "Polvica",
    "lat": "40.69484",
    "lng": "14.64019"
  },
  {
    "country": "IT",
    "name": "Polverigi",
    "lat": "43.52876",
    "lng": "13.38294"
  },
  {
    "country": "IT",
    "name": "Polverara",
    "lat": "45.30945",
    "lng": "11.95474"
  },
  {
    "country": "IT",
    "name": "Ponte nelle Alpi-Polpet",
    "lat": "46.18833",
    "lng": "12.27833"
  },
  {
    "country": "IT",
    "name": "Pollutri",
    "lat": "42.13784",
    "lng": "14.59172"
  },
  {
    "country": "IT",
    "name": "Pollone",
    "lat": "45.57976",
    "lng": "8.00592"
  },
  {
    "country": "IT",
    "name": "Pollica",
    "lat": "40.1907",
    "lng": "15.05716"
  },
  {
    "country": "IT",
    "name": "Pollenza",
    "lat": "43.26595",
    "lng": "13.34788"
  },
  {
    "country": "IT",
    "name": "Pollein",
    "lat": "45.7278",
    "lng": "7.35146"
  },
  {
    "country": "IT",
    "name": "Polla",
    "lat": "40.51433",
    "lng": "15.49715"
  },
  {
    "country": "IT",
    "name": "Polino",
    "lat": "42.58423",
    "lng": "12.84437"
  },
  {
    "country": "IT",
    "name": "Polinago",
    "lat": "44.34502",
    "lng": "10.72597"
  },
  {
    "country": "IT",
    "name": "Polignano a Mare",
    "lat": "40.99221",
    "lng": "17.22149"
  },
  {
    "country": "IT",
    "name": "Policoro",
    "lat": "40.2128",
    "lng": "16.67795"
  },
  {
    "country": "IT",
    "name": "Policastro Bussentino",
    "lat": "40.07511",
    "lng": "15.52165"
  },
  {
    "country": "IT",
    "name": "Poli",
    "lat": "41.88913",
    "lng": "12.89037"
  },
  {
    "country": "IT",
    "name": "Polesine Parmense",
    "lat": "45.01682",
    "lng": "10.09015"
  },
  {
    "country": "IT",
    "name": "Polesella",
    "lat": "44.96457",
    "lng": "11.74887"
  },
  {
    "country": "IT",
    "name": "Polcenigo",
    "lat": "46.03822",
    "lng": "12.50321"
  },
  {
    "country": "IT",
    "name": "Poirino",
    "lat": "44.92047",
    "lng": "7.84465"
  },
  {
    "country": "IT",
    "name": "Poiano",
    "lat": "45.47029",
    "lng": "11.01875"
  },
  {
    "country": "IT",
    "name": "Poiana Maggiore",
    "lat": "45.29039",
    "lng": "11.5025"
  },
  {
    "country": "IT",
    "name": "Pogno",
    "lat": "45.75806",
    "lng": "8.38559"
  },
  {
    "country": "IT",
    "name": "Pognana Lario",
    "lat": "45.88044",
    "lng": "9.15762"
  },
  {
    "country": "IT",
    "name": "Pogliano Milanese",
    "lat": "45.53786",
    "lng": "8.99403"
  },
  {
    "country": "IT",
    "name": "Poggiridenti Alto",
    "lat": "46.1748",
    "lng": "9.92605"
  },
  {
    "country": "IT",
    "name": "Poggio San Vicino",
    "lat": "43.37466",
    "lng": "13.07964"
  },
  {
    "country": "IT",
    "name": "Poggio Sannita",
    "lat": "41.77939",
    "lng": "14.41485"
  },
  {
    "country": "IT",
    "name": "Poggio San Lorenzo",
    "lat": "42.25174",
    "lng": "12.84343"
  },
  {
    "country": "IT",
    "name": "Poggio Rusco",
    "lat": "44.96693",
    "lng": "11.10419"
  },
  {
    "country": "IT",
    "name": "Poggio Renatico",
    "lat": "44.76581",
    "lng": "11.48695"
  },
  {
    "country": "IT",
    "name": "Villa Opicina",
    "lat": "45.6878",
    "lng": "13.78861"
  },
  {
    "country": "IT",
    "name": "Poggio Picenze",
    "lat": "42.32061",
    "lng": "13.54036"
  },
  {
    "country": "IT",
    "name": "Poggio Nativo",
    "lat": "42.21783",
    "lng": "12.79691"
  },
  {
    "country": "IT",
    "name": "Poggio Moiano",
    "lat": "42.20411",
    "lng": "12.88136"
  },
  {
    "country": "IT",
    "name": "Poggio Mirteto",
    "lat": "42.26763",
    "lng": "12.68837"
  },
  {
    "country": "IT",
    "name": "Poggiomarino",
    "lat": "40.80114",
    "lng": "14.54066"
  },
  {
    "country": "IT",
    "name": "Battifolle-Ruscello-Poggiola",
    "lat": "43.45",
    "lng": "11.8"
  },
  {
    "country": "IT",
    "name": "Poggio Imperiale",
    "lat": "41.82503",
    "lng": "15.3668"
  },
  {
    "country": "IT",
    "name": "Poggiofiorito",
    "lat": "42.25414",
    "lng": "14.32082"
  },
  {
    "country": "IT",
    "name": "Poggiodomo",
    "lat": "42.71237",
    "lng": "12.93251"
  },
  {
    "country": "IT",
    "name": "Poggio Catino",
    "lat": "42.2942",
    "lng": "12.69838"
  },
  {
    "country": "IT",
    "name": "Poggio Bustone",
    "lat": "42.5033",
    "lng": "12.88524"
  },
  {
    "country": "IT",
    "name": "Poggio Berni",
    "lat": "44.02639",
    "lng": "12.40944"
  },
  {
    "country": "IT",
    "name": "Poggio A Caiano",
    "lat": "43.81378",
    "lng": "11.05186"
  },
  {
    "country": "IT",
    "name": "Poggibonsi",
    "lat": "43.47064",
    "lng": "11.14804"
  },
  {
    "country": "IT",
    "name": "Poggiardo",
    "lat": "40.05315",
    "lng": "18.37819"
  },
  {
    "country": "IT",
    "name": "Pofi",
    "lat": "41.56542",
    "lng": "13.4146"
  },
  {
    "country": "IT",
    "name": "Podenzano",
    "lat": "44.95484",
    "lng": "9.68315"
  },
  {
    "country": "IT",
    "name": "Podenzana",
    "lat": "44.20625",
    "lng": "9.94199"
  },
  {
    "country": "IT",
    "name": "Pocenia",
    "lat": "45.8357",
    "lng": "13.10145"
  },
  {
    "country": "IT",
    "name": "Ploaghe",
    "lat": "40.67068",
    "lng": "8.74962"
  },
  {
    "country": "IT",
    "name": "Plaus",
    "lat": "46.65623",
    "lng": "11.04178"
  },
  {
    "country": "IT",
    "name": "Pizzone",
    "lat": "41.67332",
    "lng": "14.03666"
  },
  {
    "country": "IT",
    "name": "Pizzoli",
    "lat": "42.43603",
    "lng": "13.29886"
  },
  {
    "country": "IT",
    "name": "Pizzoferrato",
    "lat": "41.92244",
    "lng": "14.23632"
  },
  {
    "country": "IT",
    "name": "Pizzighettone",
    "lat": "45.1869",
    "lng": "9.78781"
  },
  {
    "country": "IT",
    "name": "Piuro",
    "lat": "46.32979",
    "lng": "9.42064"
  },
  {
    "country": "IT",
    "name": "Piumazzo",
    "lat": "44.54631",
    "lng": "11.06727"
  },
  {
    "country": "IT",
    "name": "Piubega",
    "lat": "45.22677",
    "lng": "10.53195"
  },
  {
    "country": "IT",
    "name": "Pitigliano",
    "lat": "43.45",
    "lng": "11.93333"
  },
  {
    "country": "IT",
    "name": "Pitigliano",
    "lat": "42.63582",
    "lng": "11.67462"
  },
  {
    "country": "IT",
    "name": "Piteglio",
    "lat": "44.0279",
    "lng": "10.76571"
  },
  {
    "country": "IT",
    "name": "Pistrino",
    "lat": "43.50966",
    "lng": "12.15181"
  },
  {
    "country": "IT",
    "name": "Pistoia",
    "lat": "43.93064",
    "lng": "10.92365"
  },
  {
    "country": "IT",
    "name": "Pisticci",
    "lat": "40.39017",
    "lng": "16.55919"
  },
  {
    "country": "IT",
    "name": "Pisoniano",
    "lat": "41.90816",
    "lng": "12.95794"
  },
  {
    "country": "IT",
    "name": "Pisogne",
    "lat": "45.80777",
    "lng": "10.11023"
  },
  {
    "country": "IT",
    "name": "Pisignano",
    "lat": "40.3047",
    "lng": "18.27155"
  },
  {
    "country": "IT",
    "name": "Pisciotta",
    "lat": "40.1089",
    "lng": "15.23456"
  },
  {
    "country": "IT",
    "name": "Pisa",
    "lat": "43.70853",
    "lng": "10.4036"
  },
  {
    "country": "IT",
    "name": "Piozzano",
    "lat": "44.92533",
    "lng": "9.49559"
  },
  {
    "country": "IT",
    "name": "Piovene Rocchette",
    "lat": "45.75601",
    "lng": "11.43273"
  },
  {
    "country": "IT",
    "name": "Piove di Sacco-Piovega",
    "lat": "45.29665",
    "lng": "12.03683"
  },
  {
    "country": "IT",
    "name": "Piossasco",
    "lat": "44.98802",
    "lng": "7.4601"
  },
  {
    "country": "IT",
    "name": "Pioraco",
    "lat": "43.18074",
    "lng": "12.97676"
  },
  {
    "country": "IT",
    "name": "Piombino Dese",
    "lat": "45.60964",
    "lng": "11.99416"
  },
  {
    "country": "IT",
    "name": "Piombino",
    "lat": "42.92554",
    "lng": "10.52585"
  },
  {
    "country": "IT",
    "name": "Pioltello",
    "lat": "45.50147",
    "lng": "9.33053"
  },
  {
    "country": "IT",
    "name": "Piode",
    "lat": "45.77059",
    "lng": "8.05265"
  },
  {
    "country": "IT",
    "name": "Piobesi Torinese",
    "lat": "44.76667",
    "lng": "7.61667"
  },
  {
    "country": "IT",
    "name": "Piobesi d'Alba",
    "lat": "44.73444",
    "lng": "7.97937"
  },
  {
    "country": "IT",
    "name": "Piobbico",
    "lat": "43.58819",
    "lng": "12.50962"
  },
  {
    "country": "IT",
    "name": "Pinzolo",
    "lat": "46.15976",
    "lng": "10.76376"
  },
  {
    "country": "IT",
    "name": "Pinzano al Tagliamento",
    "lat": "46.18216",
    "lng": "12.94433"
  },
  {
    "country": "IT",
    "name": "Pino sulla Sponda del Lago Maggiore",
    "lat": "46.10078",
    "lng": "8.73873"
  },
  {
    "country": "IT",
    "name": "Pinocchio di Ancona",
    "lat": "43.58986",
    "lng": "13.49413"
  },
  {
    "country": "IT",
    "name": "Pineto",
    "lat": "42.60879",
    "lng": "14.06639"
  },
  {
    "country": "IT",
    "name": "Pinerolo",
    "lat": "44.88534",
    "lng": "7.33135"
  },
  {
    "country": "IT",
    "name": "Pincara",
    "lat": "45.00064",
    "lng": "11.62101"
  },
  {
    "country": "IT",
    "name": "Pimonte",
    "lat": "40.67361",
    "lng": "14.50984"
  },
  {
    "country": "IT",
    "name": "Pila",
    "lat": "43.05329",
    "lng": "12.32857"
  },
  {
    "country": "IT",
    "name": "Pigra",
    "lat": "45.95735",
    "lng": "9.12649"
  },
  {
    "country": "IT",
    "name": "Pignone",
    "lat": "44.1778",
    "lng": "9.72327"
  },
  {
    "country": "IT",
    "name": "Pignola",
    "lat": "40.57412",
    "lng": "15.78295"
  },
  {
    "country": "IT",
    "name": "Pignataro Maggiore",
    "lat": "41.19006",
    "lng": "14.16978"
  },
  {
    "country": "IT",
    "name": "Pignataro Interamna",
    "lat": "41.43922",
    "lng": "13.78621"
  },
  {
    "country": "IT",
    "name": "Pigna",
    "lat": "43.93205",
    "lng": "7.66123"
  },
  {
    "country": "IT",
    "name": "Piglio",
    "lat": "41.83006",
    "lng": "13.1333"
  },
  {
    "country": "IT",
    "name": "Pieve Vergonte",
    "lat": "46.01298",
    "lng": "8.26082"
  },
  {
    "country": "IT",
    "name": "Pieve Torina",
    "lat": "43.04299",
    "lng": "13.04769"
  },
  {
    "country": "IT",
    "name": "Pieve Tesino",
    "lat": "46.0682",
    "lng": "11.61122"
  },
  {
    "country": "IT",
    "name": "Pieve Santo Stefano",
    "lat": "43.67145",
    "lng": "12.04124"
  },
  {
    "country": "IT",
    "name": "Pieve San Giacomo",
    "lat": "45.13204",
    "lng": "10.18775"
  },
  {
    "country": "IT",
    "name": "Pieve Porto Morone",
    "lat": "45.10979",
    "lng": "9.44019"
  },
  {
    "country": "IT",
    "name": "Pievepelago",
    "lat": "44.20475",
    "lng": "10.6166"
  },
  {
    "country": "IT",
    "name": "Pieve Ligure",
    "lat": "44.37494",
    "lng": "9.0941"
  },
  {
    "country": "IT",
    "name": "Pieve Fosciana",
    "lat": "44.13067",
    "lng": "10.40952"
  },
  {
    "country": "IT",
    "name": "Pieve d'Olmi",
    "lat": "45.08957",
    "lng": "10.12368"
  },
  {
    "country": "IT",
    "name": "Pieve di Teco",
    "lat": "44.04706",
    "lng": "7.91564"
  },
  {
    "country": "IT",
    "name": "Pieve di Soligo",
    "lat": "45.89836",
    "lng": "12.17128"
  },
  {
    "country": "IT",
    "name": "Pieve di Cento",
    "lat": "44.71293",
    "lng": "11.30922"
  },
  {
    "country": "IT",
    "name": "Pieve di Cadore",
    "lat": "46.42466",
    "lng": "12.36416"
  },
  {
    "country": "IT",
    "name": "Pieve del Cairo",
    "lat": "45.0492",
    "lng": "8.80322"
  },
  {
    "country": "IT",
    "name": "Pieve d'Alpago",
    "lat": "46.16658",
    "lng": "12.35344"
  },
  {
    "country": "IT",
    "name": "Pievebovigliana",
    "lat": "43.06287",
    "lng": "13.08375"
  },
  {
    "country": "IT",
    "name": "Pieve Albignola",
    "lat": "45.11316",
    "lng": "8.95999"
  },
  {
    "country": "IT",
    "name": "Pieve",
    "lat": "45.77273",
    "lng": "10.75913"
  },
  {
    "country": "IT",
    "name": "Pietrelcina",
    "lat": "41.19942",
    "lng": "14.84414"
  },
  {
    "country": "IT",
    "name": "Pietravairano",
    "lat": "41.32522",
    "lng": "14.16592"
  },
  {
    "country": "IT",
    "name": "Pietrastornina",
    "lat": "40.99535",
    "lng": "14.71833"
  },
  {
    "country": "IT",
    "name": "Pietrasanta",
    "lat": "43.95952",
    "lng": "10.22784"
  },
  {
    "country": "IT",
    "name": "Pietraporzio",
    "lat": "44.34352",
    "lng": "7.03433"
  },
  {
    "country": "IT",
    "name": "Pietrapertosa",
    "lat": "40.51731",
    "lng": "16.06244"
  },
  {
    "country": "IT",
    "name": "Pietranico",
    "lat": "42.27565",
    "lng": "13.91077"
  },
  {
    "country": "IT",
    "name": "Pietramurata",
    "lat": "46.02033",
    "lng": "10.94316"
  },
  {
    "country": "IT",
    "name": "Pietramontecorvino",
    "lat": "41.54228",
    "lng": "15.12894"
  },
  {
    "country": "IT",
    "name": "Pietramelara",
    "lat": "41.27086",
    "lng": "14.18711"
  },
  {
    "country": "IT",
    "name": "Pietralunga",
    "lat": "43.43609",
    "lng": "12.42921"
  },
  {
    "country": "IT",
    "name": "Pietra Ligure",
    "lat": "44.1492",
    "lng": "8.28206"
  },
  {
    "country": "IT",
    "name": "Pietra la Croce",
    "lat": "43.60224",
    "lng": "13.53887"
  },
  {
    "country": "IT",
    "name": "Pietragalla",
    "lat": "40.74572",
    "lng": "15.87398"
  },
  {
    "country": "IT",
    "name": "Pietraferrazzana",
    "lat": "41.96943",
    "lng": "14.37451"
  },
  {
    "country": "IT",
    "name": "Pietra de' Giorgi",
    "lat": "45.02136",
    "lng": "9.23036"
  },
  {
    "country": "IT",
    "name": "Pietradefusi",
    "lat": "41.04316",
    "lng": "14.88415"
  },
  {
    "country": "IT",
    "name": "Pietracuta",
    "lat": "43.954",
    "lng": "12.37138"
  },
  {
    "country": "IT",
    "name": "Pietracupa",
    "lat": "41.68253",
    "lng": "14.51933"
  },
  {
    "country": "IT",
    "name": "Pietracatella",
    "lat": "41.58064",
    "lng": "14.87298"
  },
  {
    "country": "IT",
    "name": "Pietracamela",
    "lat": "42.52344",
    "lng": "13.55431"
  },
  {
    "country": "IT",
    "name": "Pietrabruna",
    "lat": "43.88927",
    "lng": "7.90319"
  },
  {
    "country": "IT",
    "name": "Pietrabbondante",
    "lat": "41.74527",
    "lng": "14.3848"
  },
  {
    "country": "IT",
    "name": "Pieris",
    "lat": "45.81243",
    "lng": "13.44917"
  },
  {
    "country": "IT",
    "name": "Pienza",
    "lat": "43.07873",
    "lng": "11.67671"
  },
  {
    "country": "IT",
    "name": "Piegaro",
    "lat": "42.96596",
    "lng": "12.08409"
  },
  {
    "country": "IT",
    "name": "Piedimulera",
    "lat": "46.02408",
    "lng": "8.25897"
  },
  {
    "country": "IT",
    "name": "Piedimonte San Germano",
    "lat": "41.49796",
    "lng": "13.75017"
  },
  {
    "country": "IT",
    "name": "Piedimonte",
    "lat": "41.18886",
    "lng": "13.89856"
  },
  {
    "country": "IT",
    "name": "Piedicavallo",
    "lat": "45.68986",
    "lng": "7.95482"
  },
  {
    "country": "IT",
    "name": "Pie' del Sasso",
    "lat": "42.99429",
    "lng": "12.99889"
  },
  {
    "country": "IT",
    "name": "Pie' del Colle",
    "lat": "43.02984",
    "lng": "13.17535"
  },
  {
    "country": "IT",
    "name": "Piea",
    "lat": "45.02706",
    "lng": "8.07146"
  },
  {
    "country": "IT",
    "name": "Pico",
    "lat": "41.45025",
    "lng": "13.55894"
  },
  {
    "country": "IT",
    "name": "Picinisco",
    "lat": "41.64568",
    "lng": "13.86791"
  },
  {
    "country": "IT",
    "name": "Picerno",
    "lat": "40.63975",
    "lng": "15.64232"
  },
  {
    "country": "IT",
    "name": "Picciano",
    "lat": "42.47525",
    "lng": "13.9899"
  },
  {
    "country": "IT",
    "name": "Piazzola sul Brenta",
    "lat": "45.53845",
    "lng": "11.78437"
  },
  {
    "country": "IT",
    "name": "Piazzatorre",
    "lat": "45.99273",
    "lng": "9.68942"
  },
  {
    "country": "IT",
    "name": "Piazza Brembana",
    "lat": "45.94769",
    "lng": "9.6733"
  },
  {
    "country": "IT",
    "name": "Piazza al Serchio-San Michele",
    "lat": "44.18455",
    "lng": "10.29689"
  },
  {
    "country": "IT",
    "name": "Piazza",
    "lat": "45.87705",
    "lng": "11.15809"
  },
  {
    "country": "IT",
    "name": "Piazza",
    "lat": "45.58725",
    "lng": "10.15526"
  },
  {
    "country": "IT",
    "name": "Piazza",
    "lat": "45.21585",
    "lng": "11.14244"
  },
  {
    "country": "IT",
    "name": "Piateda Centro",
    "lat": "46.1596",
    "lng": "9.93495"
  },
  {
    "country": "IT",
    "name": "Piasco",
    "lat": "44.56106",
    "lng": "7.4442"
  },
  {
    "country": "IT",
    "name": "Piantedo",
    "lat": "46.13663",
    "lng": "9.4277"
  },
  {
    "country": "IT",
    "name": "Piansano",
    "lat": "42.52449",
    "lng": "11.82978"
  },
  {
    "country": "IT",
    "name": "Pianoro",
    "lat": "44.38893",
    "lng": "11.34262"
  },
  {
    "country": "IT",
    "name": "Pianola",
    "lat": "42.32341",
    "lng": "13.40394"
  },
  {
    "country": "IT",
    "name": "Piano di Sorrento",
    "lat": "40.62806",
    "lng": "14.41729"
  },
  {
    "country": "IT",
    "name": "Piano di Follo",
    "lat": "44.16375",
    "lng": "9.86188"
  },
  {
    "country": "IT",
    "name": "Piano-Molini d'Isola",
    "lat": "44.83194",
    "lng": "8.18073"
  },
  {
    "country": "IT",
    "name": "Piano",
    "lat": "40.8205",
    "lng": "14.76005"
  },
  {
    "country": "IT",
    "name": "Pianillo",
    "lat": "40.63416",
    "lng": "14.54922"
  },
  {
    "country": "IT",
    "name": "Pianiga",
    "lat": "45.45708",
    "lng": "12.00762"
  },
  {
    "country": "IT",
    "name": "Piangipane",
    "lat": "44.42198",
    "lng": "12.09066"
  },
  {
    "country": "IT",
    "name": "Pianezze",
    "lat": "45.74141",
    "lng": "11.627"
  },
  {
    "country": "IT",
    "name": "Pianezza",
    "lat": "45.1042",
    "lng": "7.55003"
  },
  {
    "country": "IT",
    "name": "Pianello Val Tidone",
    "lat": "44.94666",
    "lng": "9.40516"
  },
  {
    "country": "IT",
    "name": "Pianella",
    "lat": "42.39918",
    "lng": "14.04781"
  },
  {
    "country": "IT",
    "name": "Pian di Scò",
    "lat": "43.64195",
    "lng": "11.54523"
  },
  {
    "country": "IT",
    "name": "Piandimeleto",
    "lat": "43.7232",
    "lng": "12.40855"
  },
  {
    "country": "IT",
    "name": "Piamborno",
    "lat": "45.91969",
    "lng": "10.22526"
  },
  {
    "country": "IT",
    "name": "Piancastagnaio",
    "lat": "42.85067",
    "lng": "11.69014"
  },
  {
    "country": "IT",
    "name": "Pian Camuno",
    "lat": "45.84186",
    "lng": "10.14181"
  },
  {
    "country": "IT",
    "name": "Pianazzo",
    "lat": "46.42815",
    "lng": "9.3442"
  },
  {
    "country": "IT",
    "name": "Piana Crixia",
    "lat": "44.48504",
    "lng": "8.30805"
  },
  {
    "country": "IT",
    "name": "Piana Battolla",
    "lat": "44.19322",
    "lng": "9.85345"
  },
  {
    "country": "IT",
    "name": "Piaggine",
    "lat": "40.34498",
    "lng": "15.37777"
  },
  {
    "country": "IT",
    "name": "Piagge",
    "lat": "43.73381",
    "lng": "12.96851"
  },
  {
    "country": "IT",
    "name": "Piadena",
    "lat": "45.12859",
    "lng": "10.37101"
  },
  {
    "country": "IT",
    "name": "Piacenza d'Adige",
    "lat": "45.12749",
    "lng": "11.54333"
  },
  {
    "country": "IT",
    "name": "Piacenza",
    "lat": "45.05242",
    "lng": "9.69342"
  },
  {
    "country": "IT",
    "name": "Lama Pezzoli",
    "lat": "45.04357",
    "lng": "11.90942"
  },
  {
    "country": "IT",
    "name": "Pezze di Greco",
    "lat": "40.81004",
    "lng": "17.41333"
  },
  {
    "country": "IT",
    "name": "Pezzana",
    "lat": "45.26152",
    "lng": "8.48396"
  },
  {
    "country": "IT",
    "name": "Peveragno",
    "lat": "44.3206",
    "lng": "7.61859"
  },
  {
    "country": "IT",
    "name": "Pettorazza Grimani",
    "lat": "45.13585",
    "lng": "11.98779"
  },
  {
    "country": "IT",
    "name": "Pettorano sul Gizio",
    "lat": "41.97326",
    "lng": "13.96001"
  },
  {
    "country": "IT",
    "name": "Pettoranello del Molise",
    "lat": "41.57331",
    "lng": "14.27839"
  },
  {
    "country": "IT",
    "name": "Pettinengo",
    "lat": "45.61306",
    "lng": "8.10422"
  },
  {
    "country": "IT",
    "name": "Petruro Irpino",
    "lat": "41.03192",
    "lng": "14.79754"
  },
  {
    "country": "IT",
    "name": "Petritoli",
    "lat": "43.06809",
    "lng": "13.66385"
  },
  {
    "country": "IT",
    "name": "Petriolo",
    "lat": "43.22141",
    "lng": "13.46173"
  },
  {
    "country": "IT",
    "name": "Petrignano",
    "lat": "43.10269",
    "lng": "12.53239"
  },
  {
    "country": "IT",
    "name": "Petriano",
    "lat": "43.77935",
    "lng": "12.73214"
  },
  {
    "country": "IT",
    "name": "Petrella Tifernina",
    "lat": "41.69135",
    "lng": "14.69751"
  },
  {
    "country": "IT",
    "name": "Petrella Salto",
    "lat": "42.29405",
    "lng": "13.06794"
  },
  {
    "country": "IT",
    "name": "Petina",
    "lat": "40.53211",
    "lng": "15.37346"
  },
  {
    "country": "IT",
    "name": "Petacciato",
    "lat": "42.00827",
    "lng": "14.86026"
  },
  {
    "country": "IT",
    "name": "Pessione",
    "lat": "44.96504",
    "lng": "7.84115"
  },
  {
    "country": "IT",
    "name": "Pessinetto",
    "lat": "45.28675",
    "lng": "7.41531"
  },
  {
    "country": "IT",
    "name": "Pessina Cremonese",
    "lat": "45.18505",
    "lng": "10.24815"
  },
  {
    "country": "IT",
    "name": "Pescosolido",
    "lat": "41.74864",
    "lng": "13.6569"
  },
  {
    "country": "IT",
    "name": "Pescosansonesco Nuovo",
    "lat": "42.25524",
    "lng": "13.8848"
  },
  {
    "country": "IT",
    "name": "Pesco Sannita",
    "lat": "41.23273",
    "lng": "14.81122"
  },
  {
    "country": "IT",
    "name": "Pescorocchiano",
    "lat": "42.20623",
    "lng": "13.14715"
  },
  {
    "country": "IT",
    "name": "Pescopennataro",
    "lat": "41.87777",
    "lng": "14.29398"
  },
  {
    "country": "IT",
    "name": "Pescopagano",
    "lat": "40.83494",
    "lng": "15.39946"
  },
  {
    "country": "IT",
    "name": "Pescolanciano",
    "lat": "41.67972",
    "lng": "14.33658"
  },
  {
    "country": "IT",
    "name": "Pescocostanzo",
    "lat": "41.88722",
    "lng": "14.06614"
  },
  {
    "country": "IT",
    "name": "Pescina",
    "lat": "42.02351",
    "lng": "13.65116"
  },
  {
    "country": "IT",
    "name": "Pescia Romana",
    "lat": "42.39963",
    "lng": "11.49651"
  },
  {
    "country": "IT",
    "name": "Pescia",
    "lat": "43.8871",
    "lng": "10.68849"
  },
  {
    "country": "IT",
    "name": "Peschiera del Garda",
    "lat": "45.43912",
    "lng": "10.68614"
  },
  {
    "country": "IT",
    "name": "Bettola-Zeloforomagno",
    "lat": "45.4308",
    "lng": "9.3087"
  },
  {
    "country": "IT",
    "name": "Peschici",
    "lat": "41.94521",
    "lng": "16.01612"
  },
  {
    "country": "IT",
    "name": "Pesche",
    "lat": "41.60552",
    "lng": "14.2762"
  },
  {
    "country": "IT",
    "name": "Pescasseroli",
    "lat": "41.80343",
    "lng": "13.78707"
  },
  {
    "country": "IT",
    "name": "Pescarolo",
    "lat": "45.19387",
    "lng": "10.18647"
  },
  {
    "country": "IT",
    "name": "Pescara",
    "lat": "42.4584",
    "lng": "14.20283"
  },
  {
    "country": "IT",
    "name": "Pescantina",
    "lat": "45.48548",
    "lng": "10.86796"
  },
  {
    "country": "IT",
    "name": "Pescaglia",
    "lat": "43.96517",
    "lng": "10.41292"
  },
  {
    "country": "IT",
    "name": "Pesaro",
    "lat": "43.90921",
    "lng": "12.9164"
  },
  {
    "country": "IT",
    "name": "Perugia",
    "lat": "43.1122",
    "lng": "12.38878"
  },
  {
    "country": "IT",
    "name": "Pertosa",
    "lat": "40.54346",
    "lng": "15.45009"
  },
  {
    "country": "IT",
    "name": "Pertengo",
    "lat": "45.23606",
    "lng": "8.41651"
  },
  {
    "country": "IT",
    "name": "Perrero",
    "lat": "44.93849",
    "lng": "7.11263"
  },
  {
    "country": "IT",
    "name": "Perosa Argentina",
    "lat": "44.95909",
    "lng": "7.19167"
  },
  {
    "country": "IT",
    "name": "Pernumia",
    "lat": "45.25899",
    "lng": "11.78721"
  },
  {
    "country": "IT",
    "name": "Pernate",
    "lat": "45.45958",
    "lng": "8.67845"
  },
  {
    "country": "IT",
    "name": "Perito",
    "lat": "40.29854",
    "lng": "15.14746"
  },
  {
    "country": "IT",
    "name": "Perinaldo",
    "lat": "43.86689",
    "lng": "7.67194"
  },
  {
    "country": "IT",
    "name": "Pergola",
    "lat": "43.55485",
    "lng": "12.83633"
  },
  {
    "country": "IT",
    "name": "Pergine Valsugana",
    "lat": "46.06434",
    "lng": "11.23758"
  },
  {
    "country": "IT",
    "name": "Pergine Valdarno",
    "lat": "43.47028",
    "lng": "11.68552"
  },
  {
    "country": "IT",
    "name": "Perfugas",
    "lat": "40.83231",
    "lng": "8.88354"
  },
  {
    "country": "IT",
    "name": "Pereto",
    "lat": "42.05821",
    "lng": "13.10231"
  },
  {
    "country": "IT",
    "name": "Perdifumo",
    "lat": "40.26694",
    "lng": "15.01652"
  },
  {
    "country": "IT",
    "name": "Percoto",
    "lat": "45.97471",
    "lng": "13.32304"
  },
  {
    "country": "IT",
    "name": "Percile",
    "lat": "42.09497",
    "lng": "12.91048"
  },
  {
    "country": "IT",
    "name": "Perca",
    "lat": "46.79343",
    "lng": "11.98339"
  },
  {
    "country": "IT",
    "name": "Perarolo di Cadore",
    "lat": "46.39383",
    "lng": "12.35636"
  },
  {
    "country": "IT",
    "name": "Perano",
    "lat": "42.1046",
    "lng": "14.39581"
  },
  {
    "country": "IT",
    "name": "Penne",
    "lat": "42.45474",
    "lng": "13.92754"
  },
  {
    "country": "IT",
    "name": "Penna Sant'Andrea",
    "lat": "42.59403",
    "lng": "13.77215"
  },
  {
    "country": "IT",
    "name": "Penna San Giovanni",
    "lat": "43.05608",
    "lng": "13.42539"
  },
  {
    "country": "IT",
    "name": "Pennapiedimonte",
    "lat": "42.15563",
    "lng": "14.19432"
  },
  {
    "country": "IT",
    "name": "Penna in Teverina",
    "lat": "42.49342",
    "lng": "12.35845"
  },
  {
    "country": "IT",
    "name": "Pennadomo",
    "lat": "42.00394",
    "lng": "14.32338"
  },
  {
    "country": "IT",
    "name": "Pennabilli",
    "lat": "43.81746",
    "lng": "12.26708"
  },
  {
    "country": "IT",
    "name": "Pellizzano",
    "lat": "46.3098",
    "lng": "10.7579"
  },
  {
    "country": "IT",
    "name": "Pellezzano",
    "lat": "40.72521",
    "lng": "14.75744"
  },
  {
    "country": "IT",
    "name": "Pellestrina",
    "lat": "45.27716",
    "lng": "12.30238"
  },
  {
    "country": "IT",
    "name": "Pellegrino Parmense",
    "lat": "44.7295",
    "lng": "9.9324"
  },
  {
    "country": "IT",
    "name": "Pella",
    "lat": "45.79722",
    "lng": "8.38444"
  },
  {
    "country": "IT",
    "name": "Pelago",
    "lat": "43.77255",
    "lng": "11.50148"
  },
  {
    "country": "IT",
    "name": "Pegolotte",
    "lat": "45.19178",
    "lng": "12.03791"
  },
  {
    "country": "IT",
    "name": "Pegognaga",
    "lat": "44.99456",
    "lng": "10.85967"
  },
  {
    "country": "IT",
    "name": "Peglio",
    "lat": "43.69646",
    "lng": "12.49785"
  },
  {
    "country": "IT",
    "name": "Pedesina",
    "lat": "46.08189",
    "lng": "9.54944"
  },
  {
    "country": "IT",
    "name": "Pederobba",
    "lat": "45.87567",
    "lng": "11.94977"
  },
  {
    "country": "IT",
    "name": "Pedavena",
    "lat": "46.03951",
    "lng": "11.8831"
  },
  {
    "country": "IT",
    "name": "Pedaso",
    "lat": "43.09839",
    "lng": "13.84083"
  },
  {
    "country": "IT",
    "name": "Pecorara",
    "lat": "44.87582",
    "lng": "9.38387"
  },
  {
    "country": "IT",
    "name": "Pecetto di Valenza",
    "lat": "44.98904",
    "lng": "8.66996"
  },
  {
    "country": "IT",
    "name": "Pecetto",
    "lat": "45.0176",
    "lng": "7.75107"
  },
  {
    "country": "IT",
    "name": "Peccioli",
    "lat": "43.54963",
    "lng": "10.7172"
  },
  {
    "country": "IT",
    "name": "Pavullo nel Frignano",
    "lat": "44.33352",
    "lng": "10.83544"
  },
  {
    "country": "IT",
    "name": "Pavone del Mella",
    "lat": "45.30147",
    "lng": "10.20984"
  },
  {
    "country": "IT",
    "name": "Pavone Canavese",
    "lat": "45.44193",
    "lng": "7.85294"
  },
  {
    "country": "IT",
    "name": "Pavona",
    "lat": "41.72629",
    "lng": "12.61642"
  },
  {
    "country": "IT",
    "name": "Pavia",
    "lat": "45.19205",
    "lng": "9.15917"
  },
  {
    "country": "IT",
    "name": "Pavarolo",
    "lat": "45.06665",
    "lng": "7.83943"
  },
  {
    "country": "IT",
    "name": "Paupisi",
    "lat": "41.19662",
    "lng": "14.66457"
  },
  {
    "country": "IT",
    "name": "Paullo",
    "lat": "45.41834",
    "lng": "9.40042"
  },
  {
    "country": "IT",
    "name": "Paulilatino",
    "lat": "40.0847",
    "lng": "8.76449"
  },
  {
    "country": "IT",
    "name": "Paularo",
    "lat": "46.53101",
    "lng": "13.11886"
  },
  {
    "country": "IT",
    "name": "Pattada",
    "lat": "40.58067",
    "lng": "9.11129"
  },
  {
    "country": "IT",
    "name": "Patrica",
    "lat": "41.59085",
    "lng": "13.24363"
  },
  {
    "country": "IT",
    "name": "Patigno",
    "lat": "44.35316",
    "lng": "9.76297"
  },
  {
    "country": "IT",
    "name": "Paternopoli",
    "lat": "40.97268",
    "lng": "15.03242"
  },
  {
    "country": "IT",
    "name": "Paterno",
    "lat": "40.37507",
    "lng": "15.7351"
  },
  {
    "country": "IT",
    "name": "Pastrengo",
    "lat": "45.49588",
    "lng": "10.79897"
  },
  {
    "country": "IT",
    "name": "Pastena",
    "lat": "41.46842",
    "lng": "13.49111"
  },
  {
    "country": "IT",
    "name": "Passo di Treia",
    "lat": "43.28647",
    "lng": "13.33246"
  },
  {
    "country": "IT",
    "name": "Passo di Mirabella-Pianopantano",
    "lat": "41.05468",
    "lng": "15.01649"
  },
  {
    "country": "IT",
    "name": "Passirano",
    "lat": "45.59673",
    "lng": "10.06986"
  },
  {
    "country": "IT",
    "name": "Passignano sul Trasimeno",
    "lat": "43.19043",
    "lng": "12.13535"
  },
  {
    "country": "IT",
    "name": "Passarella",
    "lat": "45.59436",
    "lng": "12.60537"
  },
  {
    "country": "IT",
    "name": "Paspardo",
    "lat": "46.03225",
    "lng": "10.36879"
  },
  {
    "country": "IT",
    "name": "Pasiano",
    "lat": "45.84972",
    "lng": "12.62722"
  },
  {
    "country": "IT",
    "name": "Pasian di Prato",
    "lat": "46.04667",
    "lng": "13.1878"
  },
  {
    "country": "IT",
    "name": "Parzanica",
    "lat": "45.73873",
    "lng": "10.03518"
  },
  {
    "country": "IT",
    "name": "Paruzzaro",
    "lat": "45.74818",
    "lng": "8.51486"
  },
  {
    "country": "IT",
    "name": "Parre",
    "lat": "45.87459",
    "lng": "9.89086"
  },
  {
    "country": "IT",
    "name": "Parrano",
    "lat": "42.86624",
    "lng": "12.11026"
  },
  {
    "country": "IT",
    "name": "Parona",
    "lat": "45.47882",
    "lng": "10.94414"
  },
  {
    "country": "IT",
    "name": "Parona",
    "lat": "45.28165",
    "lng": "8.75055"
  },
  {
    "country": "IT",
    "name": "Parolise",
    "lat": "40.93045",
    "lng": "14.88172"
  },
  {
    "country": "IT",
    "name": "Parma",
    "lat": "44.79935",
    "lng": "10.32618"
  },
  {
    "country": "IT",
    "name": "Parella",
    "lat": "45.43018",
    "lng": "7.79128"
  },
  {
    "country": "IT",
    "name": "Parcines",
    "lat": "46.68422",
    "lng": "11.07337"
  },
  {
    "country": "IT",
    "name": "Paratico",
    "lat": "45.65879",
    "lng": "9.95792"
  },
  {
    "country": "IT",
    "name": "Parabita",
    "lat": "40.05139",
    "lng": "18.12651"
  },
  {
    "country": "IT",
    "name": "Parabiago",
    "lat": "45.56034",
    "lng": "8.94545"
  },
  {
    "country": "IT",
    "name": "Papozze",
    "lat": "44.98333",
    "lng": "12.16667"
  },
  {
    "country": "IT",
    "name": "Paolisi",
    "lat": "41.03731",
    "lng": "14.57918"
  },
  {
    "country": "IT",
    "name": "Panzano in Chianti",
    "lat": "43.54422",
    "lng": "11.31438"
  },
  {
    "country": "IT",
    "name": "Pantigliate",
    "lat": "45.43526",
    "lng": "9.3522"
  },
  {
    "country": "IT",
    "name": "Pantalla",
    "lat": "42.87287",
    "lng": "12.39861"
  },
  {
    "country": "IT",
    "name": "Panni",
    "lat": "41.22082",
    "lng": "15.2756"
  },
  {
    "country": "IT",
    "name": "Pannarano",
    "lat": "41.01082",
    "lng": "14.70293"
  },
  {
    "country": "IT",
    "name": "Panicale",
    "lat": "43.0283",
    "lng": "12.09993"
  },
  {
    "country": "IT",
    "name": "Piazza di Pandola",
    "lat": "40.80748",
    "lng": "14.7718"
  },
  {
    "country": "IT",
    "name": "Pandino",
    "lat": "45.40559",
    "lng": "9.55218"
  },
  {
    "country": "IT",
    "name": "Pancarana",
    "lat": "45.07523",
    "lng": "9.05109"
  },
  {
    "country": "IT",
    "name": "Pancalieri",
    "lat": "44.83344",
    "lng": "7.58592"
  },
  {
    "country": "IT",
    "name": "Pamparato",
    "lat": "44.27666",
    "lng": "7.91432"
  },
  {
    "country": "IT",
    "name": "Paluzza",
    "lat": "46.53202",
    "lng": "13.01586"
  },
  {
    "country": "IT",
    "name": "Palù del Fersina",
    "lat": "46.12951",
    "lng": "11.35088"
  },
  {
    "country": "IT",
    "name": "Paludea",
    "lat": "46.1995",
    "lng": "12.90344"
  },
  {
    "country": "IT",
    "name": "Palù",
    "lat": "45.32473",
    "lng": "11.15635"
  },
  {
    "country": "IT",
    "name": "Palosco",
    "lat": "45.58928",
    "lng": "9.83646"
  },
  {
    "country": "IT",
    "name": "Palomonte",
    "lat": "40.66251",
    "lng": "15.29186"
  },
  {
    "country": "IT",
    "name": "Palombaro",
    "lat": "42.12323",
    "lng": "14.22989"
  },
  {
    "country": "IT",
    "name": "Palombara Sabina",
    "lat": "42.06909",
    "lng": "12.76684"
  },
  {
    "country": "IT",
    "name": "Palombaio",
    "lat": "41.07036",
    "lng": "16.60962"
  },
  {
    "country": "IT",
    "name": "Palo del Colle",
    "lat": "41.05562",
    "lng": "16.70321"
  },
  {
    "country": "IT",
    "name": "Palmiano",
    "lat": "42.89946",
    "lng": "13.45937"
  },
  {
    "country": "IT",
    "name": "Palmariggi",
    "lat": "40.13099",
    "lng": "18.37863"
  },
  {
    "country": "IT",
    "name": "Palmanova",
    "lat": "45.9054",
    "lng": "13.30998"
  },
  {
    "country": "IT",
    "name": "Palma Campania",
    "lat": "40.86608",
    "lng": "14.5517"
  },
  {
    "country": "IT",
    "name": "Pallerone",
    "lat": "44.20485",
    "lng": "10.00279"
  },
  {
    "country": "IT",
    "name": "Palazzolo sull'Oglio",
    "lat": "45.59665",
    "lng": "9.88688"
  },
  {
    "country": "IT",
    "name": "Pallare",
    "lat": "44.3277",
    "lng": "8.27864"
  },
  {
    "country": "IT",
    "name": "Pallanzeno",
    "lat": "46.04202",
    "lng": "8.25949"
  },
  {
    "country": "IT",
    "name": "Palinuro",
    "lat": "40.03681",
    "lng": "15.28812"
  },
  {
    "country": "IT",
    "name": "Palidano",
    "lat": "44.97203",
    "lng": "10.77943"
  },
  {
    "country": "IT",
    "name": "Paliano",
    "lat": "41.77975",
    "lng": "13.07661"
  },
  {
    "country": "IT",
    "name": "Palestro",
    "lat": "45.30302",
    "lng": "8.5332"
  },
  {
    "country": "IT",
    "name": "Palestrina",
    "lat": "41.83274",
    "lng": "12.88178"
  },
  {
    "country": "IT",
    "name": "Palena",
    "lat": "41.98353",
    "lng": "14.13696"
  },
  {
    "country": "IT",
    "name": "Palazzuolo sul Senio",
    "lat": "44.11298",
    "lng": "11.5427"
  },
  {
    "country": "IT",
    "name": "Palazzo San Gervasio",
    "lat": "40.93156",
    "lng": "15.98149"
  },
  {
    "country": "IT",
    "name": "Palazzolo Vercellese",
    "lat": "45.18554",
    "lng": "8.23302"
  },
  {
    "country": "IT",
    "name": "Palazzolo dello Stella",
    "lat": "45.79823",
    "lng": "13.08776"
  },
  {
    "country": "IT",
    "name": "Palazzo Canavese",
    "lat": "45.45962",
    "lng": "7.97776"
  },
  {
    "country": "IT",
    "name": "Palazzo",
    "lat": "43.09708",
    "lng": "12.56436"
  },
  {
    "country": "IT",
    "name": "Palau",
    "lat": "41.17936",
    "lng": "9.3819"
  },
  {
    "country": "IT",
    "name": "Palata",
    "lat": "41.8879",
    "lng": "14.78778"
  },
  {
    "country": "IT",
    "name": "Palanzano",
    "lat": "44.43629",
    "lng": "10.194"
  },
  {
    "country": "IT",
    "name": "Palaia",
    "lat": "43.60567",
    "lng": "10.7702"
  },
  {
    "country": "IT",
    "name": "Palagiano",
    "lat": "40.57762",
    "lng": "17.03812"
  },
  {
    "country": "IT",
    "name": "Palagianello",
    "lat": "40.60851",
    "lng": "16.97802"
  },
  {
    "country": "IT",
    "name": "Palagano",
    "lat": "44.32152",
    "lng": "10.6466"
  },
  {
    "country": "IT",
    "name": "Pago Veiano",
    "lat": "41.24243",
    "lng": "14.86497"
  },
  {
    "country": "IT",
    "name": "Pagnona",
    "lat": "46.05969",
    "lng": "9.40274"
  },
  {
    "country": "IT",
    "name": "Paglieta",
    "lat": "42.16139",
    "lng": "14.50306"
  },
  {
    "country": "IT",
    "name": "Paganico Sabino",
    "lat": "42.18963",
    "lng": "12.99689"
  },
  {
    "country": "IT",
    "name": "Paganica-Tempera",
    "lat": "42.35715",
    "lng": "13.47138"
  },
  {
    "country": "IT",
    "name": "Pagani",
    "lat": "40.74199",
    "lng": "14.61448"
  },
  {
    "country": "IT",
    "name": "Paese",
    "lat": "45.67417",
    "lng": "12.16389"
  },
  {
    "country": "IT",
    "name": "Paesana",
    "lat": "44.68332",
    "lng": "7.27571"
  },
  {
    "country": "IT",
    "name": "Padulle",
    "lat": "44.62945",
    "lng": "11.27738"
  },
  {
    "country": "IT",
    "name": "Paduli",
    "lat": "41.16793",
    "lng": "14.88688"
  },
  {
    "country": "IT",
    "name": "Stazione di Padule",
    "lat": "43.30766",
    "lng": "12.61557"
  },
  {
    "country": "IT",
    "name": "Padula",
    "lat": "40.33901",
    "lng": "15.65634"
  },
  {
    "country": "IT",
    "name": "Padru",
    "lat": "40.76619",
    "lng": "9.521"
  },
  {
    "country": "IT",
    "name": "Padria",
    "lat": "40.39635",
    "lng": "8.62992"
  },
  {
    "country": "IT",
    "name": "Padova",
    "lat": "45.40797",
    "lng": "11.88586"
  },
  {
    "country": "IT",
    "name": "Padivarma",
    "lat": "44.19648",
    "lng": "9.76753"
  },
  {
    "country": "IT",
    "name": "Paderno Franciacorta",
    "lat": "45.58687",
    "lng": "10.07975"
  },
  {
    "country": "IT",
    "name": "Paderno Dugnano",
    "lat": "45.56899",
    "lng": "9.16483"
  },
  {
    "country": "IT",
    "name": "Paderno d'Adda",
    "lat": "45.67879",
    "lng": "9.44491"
  },
  {
    "country": "IT",
    "name": "Paderno Ponchielli",
    "lat": "45.23797",
    "lng": "9.92876"
  },
  {
    "country": "IT",
    "name": "Paderna",
    "lat": "44.82148",
    "lng": "8.89088"
  },
  {
    "country": "IT",
    "name": "Padergnone",
    "lat": "46.05982",
    "lng": "10.98478"
  },
  {
    "country": "IT",
    "name": "Padenghe sul Garda",
    "lat": "45.50787",
    "lng": "10.51857"
  },
  {
    "country": "IT",
    "name": "Paciano",
    "lat": "43.02288",
    "lng": "12.06788"
  },
  {
    "country": "IT",
    "name": "Pacentro",
    "lat": "42.05043",
    "lng": "13.99151"
  },
  {
    "country": "IT",
    "name": "Ozzero",
    "lat": "45.36775",
    "lng": "8.9244"
  },
  {
    "country": "IT",
    "name": "Ozzano Monferrato",
    "lat": "45.10592",
    "lng": "8.37238"
  },
  {
    "country": "IT",
    "name": "Ozieri",
    "lat": "40.5863",
    "lng": "9.0034"
  },
  {
    "country": "IT",
    "name": "Ozegna",
    "lat": "45.34801",
    "lng": "7.74503"
  },
  {
    "country": "IT",
    "name": "Oyace",
    "lat": "45.85116",
    "lng": "7.383"
  },
  {
    "country": "IT",
    "name": "Ovodda",
    "lat": "40.09525",
    "lng": "9.16103"
  },
  {
    "country": "IT",
    "name": "Ovindoli",
    "lat": "42.13765",
    "lng": "13.51603"
  },
  {
    "country": "IT",
    "name": "Ovaro",
    "lat": "46.48409",
    "lng": "12.86704"
  },
  {
    "country": "IT",
    "name": "Ovada",
    "lat": "44.63727",
    "lng": "8.64196"
  },
  {
    "country": "IT",
    "name": "Oulx",
    "lat": "45.03641",
    "lng": "6.83372"
  },
  {
    "country": "IT",
    "name": "Ottone",
    "lat": "44.62325",
    "lng": "9.33267"
  },
  {
    "country": "IT",
    "name": "Ottobiano",
    "lat": "45.15418",
    "lng": "8.83198"
  },
  {
    "country": "IT",
    "name": "Ottiglio",
    "lat": "45.05426",
    "lng": "8.3398"
  },
  {
    "country": "IT",
    "name": "Ottaviano",
    "lat": "40.85193",
    "lng": "14.47826"
  },
  {
    "country": "IT",
    "name": "Ottati",
    "lat": "40.46291",
    "lng": "15.31526"
  },
  {
    "country": "IT",
    "name": "Ottana",
    "lat": "40.23402",
    "lng": "9.04459"
  },
  {
    "country": "IT",
    "name": "Otricoli",
    "lat": "42.42079",
    "lng": "12.47737"
  },
  {
    "country": "IT",
    "name": "Otranto",
    "lat": "40.14789",
    "lng": "18.48682"
  },
  {
    "country": "IT",
    "name": "Ostuni",
    "lat": "40.72913",
    "lng": "17.57675"
  },
  {
    "country": "IT",
    "name": "Ostra Vetere",
    "lat": "43.60336",
    "lng": "13.0615"
  },
  {
    "country": "IT",
    "name": "Ostra",
    "lat": "43.61611",
    "lng": "13.15849"
  },
  {
    "country": "IT",
    "name": "Ostiglia",
    "lat": "45.06978",
    "lng": "11.13499"
  },
  {
    "country": "IT",
    "name": "Ostiano",
    "lat": "45.2226",
    "lng": "10.2545"
  },
  {
    "country": "IT",
    "name": "Osteno-Claino",
    "lat": "46.00367",
    "lng": "9.08741"
  },
  {
    "country": "IT",
    "name": "Ostellato",
    "lat": "44.74556",
    "lng": "11.94276"
  },
  {
    "country": "IT",
    "name": "Ossona",
    "lat": "45.50708",
    "lng": "8.89314"
  },
  {
    "country": "IT",
    "name": "Ossi",
    "lat": "40.67483",
    "lng": "8.59254"
  },
  {
    "country": "IT",
    "name": "Ossago Lodigiano",
    "lat": "45.2421",
    "lng": "9.5372"
  },
  {
    "country": "IT",
    "name": "Ospitaletto",
    "lat": "45.55221",
    "lng": "10.07562"
  },
  {
    "country": "IT",
    "name": "Ospitale di Cadore",
    "lat": "46.32808",
    "lng": "12.32263"
  },
  {
    "country": "IT",
    "name": "Ospedalicchio",
    "lat": "43.07812",
    "lng": "12.50074"
  },
  {
    "country": "IT",
    "name": "Ospedaletto Euganeo",
    "lat": "45.21842",
    "lng": "11.60345"
  },
  {
    "country": "IT",
    "name": "Ospedaletto d'Alpinolo",
    "lat": "40.93906",
    "lng": "14.74652"
  },
  {
    "country": "IT",
    "name": "Ospedaletto",
    "lat": "46.04286",
    "lng": "11.55439"
  },
  {
    "country": "IT",
    "name": "Ospedaletto",
    "lat": "45.66194",
    "lng": "12.07884"
  },
  {
    "country": "IT",
    "name": "Ospedaletto",
    "lat": "43.9838",
    "lng": "12.57056"
  },
  {
    "country": "IT",
    "name": "Ospedaletti",
    "lat": "43.80221",
    "lng": "7.7183"
  },
  {
    "country": "IT",
    "name": "Osoppo",
    "lat": "46.25536",
    "lng": "13.08453"
  },
  {
    "country": "IT",
    "name": "Osnago",
    "lat": "45.67548",
    "lng": "9.39192"
  },
  {
    "country": "IT",
    "name": "Osmate",
    "lat": "45.78867",
    "lng": "8.65523"
  },
  {
    "country": "IT",
    "name": "Osimo",
    "lat": "43.48539",
    "lng": "13.48222"
  },
  {
    "country": "IT",
    "name": "Osilo",
    "lat": "40.74349",
    "lng": "8.67113"
  },
  {
    "country": "IT",
    "name": "Osiglia",
    "lat": "44.28145",
    "lng": "8.20096"
  },
  {
    "country": "IT",
    "name": "Osidda",
    "lat": "40.52368",
    "lng": "9.22053"
  },
  {
    "country": "IT",
    "name": "Oschiri",
    "lat": "40.71977",
    "lng": "9.10102"
  },
  {
    "country": "IT",
    "name": "Orzivecchi",
    "lat": "45.42058",
    "lng": "9.96326"
  },
  {
    "country": "IT",
    "name": "Orzinuovi",
    "lat": "45.40191",
    "lng": "9.92319"
  },
  {
    "country": "IT",
    "name": "Orvinio",
    "lat": "42.13039",
    "lng": "12.93762"
  },
  {
    "country": "IT",
    "name": "Orvieto",
    "lat": "42.71924",
    "lng": "12.11249"
  },
  {
    "country": "IT",
    "name": "Orune",
    "lat": "40.40786",
    "lng": "9.36963"
  },
  {
    "country": "IT",
    "name": "Ortueri",
    "lat": "40.03545",
    "lng": "8.98591"
  },
  {
    "country": "IT",
    "name": "Ortucchio",
    "lat": "41.95525",
    "lng": "13.64651"
  },
  {
    "country": "IT",
    "name": "Ortovero",
    "lat": "44.05385",
    "lng": "8.0995"
  },
  {
    "country": "IT",
    "name": "Ortona dei Marsi",
    "lat": "41.9982",
    "lng": "13.72909"
  },
  {
    "country": "IT",
    "name": "Ortona",
    "lat": "42.35087",
    "lng": "14.40342"
  },
  {
    "country": "IT",
    "name": "Ortisei",
    "lat": "46.57603",
    "lng": "11.67176"
  },
  {
    "country": "IT",
    "name": "Ortignano Raggiolo",
    "lat": "43.67995",
    "lng": "11.74883"
  },
  {
    "country": "IT",
    "name": "Ortezzano",
    "lat": "43.03042",
    "lng": "13.60531"
  },
  {
    "country": "IT",
    "name": "Ortelle",
    "lat": "40.03371",
    "lng": "18.39125"
  },
  {
    "country": "IT",
    "name": "Orte",
    "lat": "42.46117",
    "lng": "12.38635"
  },
  {
    "country": "IT",
    "name": "Orta San Giulio",
    "lat": "45.79727",
    "lng": "8.41437"
  },
  {
    "country": "IT",
    "name": "Orta Nova",
    "lat": "41.32879",
    "lng": "15.70994"
  },
  {
    "country": "IT",
    "name": "Orsogna",
    "lat": "42.22344",
    "lng": "14.28085"
  },
  {
    "country": "IT",
    "name": "Orsenigo",
    "lat": "45.77839",
    "lng": "9.17963"
  },
  {
    "country": "IT",
    "name": "Orsara di Puglia",
    "lat": "41.28163",
    "lng": "15.26765"
  },
  {
    "country": "IT",
    "name": "Orria",
    "lat": "40.29971",
    "lng": "15.17116"
  },
  {
    "country": "IT",
    "name": "Orotelli",
    "lat": "40.30663",
    "lng": "9.1215"
  },
  {
    "country": "IT",
    "name": "Orosei",
    "lat": "40.37826",
    "lng": "9.69248"
  },
  {
    "country": "IT",
    "name": "Ornica",
    "lat": "45.98892",
    "lng": "9.57848"
  },
  {
    "country": "IT",
    "name": "Ornavasso",
    "lat": "45.96795",
    "lng": "8.41584"
  },
  {
    "country": "IT",
    "name": "Ornago",
    "lat": "45.59987",
    "lng": "9.42099"
  },
  {
    "country": "IT",
    "name": "Ormea",
    "lat": "44.15586",
    "lng": "7.92811"
  },
  {
    "country": "IT",
    "name": "Oriolo Romano",
    "lat": "42.16261",
    "lng": "12.13859"
  },
  {
    "country": "IT",
    "name": "Oriolo",
    "lat": "40.0532",
    "lng": "16.44663"
  },
  {
    "country": "IT",
    "name": "Orio Litta",
    "lat": "45.16244",
    "lng": "9.55447"
  },
  {
    "country": "IT",
    "name": "Orio Canavese",
    "lat": "45.32883",
    "lng": "7.85991"
  },
  {
    "country": "IT",
    "name": "Orio al Serio",
    "lat": "45.6749",
    "lng": "9.69083"
  },
  {
    "country": "IT",
    "name": "Origgio",
    "lat": "45.59676",
    "lng": "9.01645"
  },
  {
    "country": "IT",
    "name": "Oricola",
    "lat": "42.04922",
    "lng": "13.03939"
  },
  {
    "country": "IT",
    "name": "Oria",
    "lat": "40.49999",
    "lng": "17.6428"
  },
  {
    "country": "IT",
    "name": "Orgosolo",
    "lat": "40.2053",
    "lng": "9.35445"
  },
  {
    "country": "IT",
    "name": "Orgiano",
    "lat": "45.33366",
    "lng": "11.45953"
  },
  {
    "country": "IT",
    "name": "Ordona",
    "lat": "41.31501",
    "lng": "15.62832"
  },
  {
    "country": "IT",
    "name": "Orciano di Pesaro",
    "lat": "43.68938",
    "lng": "12.97206"
  },
  {
    "country": "IT",
    "name": "Orcenico Inferiore",
    "lat": "45.94977",
    "lng": "12.76452"
  },
  {
    "country": "IT",
    "name": "Orbetello",
    "lat": "42.44158",
    "lng": "11.2214"
  },
  {
    "country": "IT",
    "name": "Orbassano",
    "lat": "45.00547",
    "lng": "7.53813"
  },
  {
    "country": "IT",
    "name": "Oratino",
    "lat": "41.58598",
    "lng": "14.59463"
  },
  {
    "country": "IT",
    "name": "Cursolo",
    "lat": "46.09858",
    "lng": "8.56822"
  },
  {
    "country": "IT",
    "name": "Orani",
    "lat": "40.252",
    "lng": "9.18149"
  },
  {
    "country": "IT",
    "name": "Ora",
    "lat": "46.34687",
    "lng": "11.29747"
  },
  {
    "country": "IT",
    "name": "Oppido Lucano",
    "lat": "40.76174",
    "lng": "15.98818"
  },
  {
    "country": "IT",
    "name": "Oppeano",
    "lat": "45.30331",
    "lng": "11.18005"
  },
  {
    "country": "IT",
    "name": "Opi",
    "lat": "41.77838",
    "lng": "13.82932"
  },
  {
    "country": "IT",
    "name": "Opera",
    "lat": "45.37355",
    "lng": "9.21084"
  },
  {
    "country": "IT",
    "name": "Oniferi",
    "lat": "40.27196",
    "lng": "9.17033"
  },
  {
    "country": "IT",
    "name": "Onifai",
    "lat": "40.40694",
    "lng": "9.65005"
  },
  {
    "country": "IT",
    "name": "Oneta",
    "lat": "45.87149",
    "lng": "9.81935"
  },
  {
    "country": "IT",
    "name": "Onano",
    "lat": "42.69104",
    "lng": "11.81552"
  },
  {
    "country": "IT",
    "name": "Onanì",
    "lat": "40.48536",
    "lng": "9.44324"
  },
  {
    "country": "IT",
    "name": "Omignano",
    "lat": "40.24932",
    "lng": "15.08406"
  },
  {
    "country": "IT",
    "name": "Omegna",
    "lat": "45.88002",
    "lng": "8.40665"
  },
  {
    "country": "IT",
    "name": "Olzai",
    "lat": "40.18238",
    "lng": "9.14679"
  },
  {
    "country": "IT",
    "name": "Oltrona di San Mamette",
    "lat": "45.75578",
    "lng": "8.97673"
  },
  {
    "country": "IT",
    "name": "Oltre Il Colle",
    "lat": "45.88949",
    "lng": "9.76925"
  },
  {
    "country": "IT",
    "name": "Olmo al Brembo",
    "lat": "45.97006",
    "lng": "9.65034"
  },
  {
    "country": "IT",
    "name": "Vignole-Olmi",
    "lat": "43.86696",
    "lng": "10.99045"
  },
  {
    "country": "IT",
    "name": "Olmeneta",
    "lat": "45.2354",
    "lng": "10.02318"
  },
  {
    "country": "IT",
    "name": "Olmedo",
    "lat": "40.65156",
    "lng": "8.38021"
  },
  {
    "country": "IT",
    "name": "Ollolai",
    "lat": "40.16805",
    "lng": "9.17776"
  },
  {
    "country": "IT",
    "name": "Oliveto Lucano",
    "lat": "40.53554",
    "lng": "16.18547"
  },
  {
    "country": "IT",
    "name": "Vassena",
    "lat": "45.92998",
    "lng": "9.28399"
  },
  {
    "country": "IT",
    "name": "Oliveto Citra",
    "lat": "40.69039",
    "lng": "15.23346"
  },
  {
    "country": "IT",
    "name": "Oliena",
    "lat": "40.27617",
    "lng": "9.40193"
  },
  {
    "country": "IT",
    "name": "Olginate",
    "lat": "45.79126",
    "lng": "9.41869"
  },
  {
    "country": "IT",
    "name": "Olgiate Olona",
    "lat": "45.63706",
    "lng": "8.88147"
  },
  {
    "country": "IT",
    "name": "Olgiate Comasco",
    "lat": "45.78436",
    "lng": "8.96816"
  },
  {
    "country": "IT",
    "name": "Olevano sul Tusciano",
    "lat": "40.65721",
    "lng": "15.02305"
  },
  {
    "country": "IT",
    "name": "Olevano Romano",
    "lat": "41.85869",
    "lng": "13.03601"
  },
  {
    "country": "IT",
    "name": "Olevano di Lomellina",
    "lat": "45.21322",
    "lng": "8.7175"
  },
  {
    "country": "IT",
    "name": "Oleggio",
    "lat": "45.59674",
    "lng": "8.64213"
  },
  {
    "country": "IT",
    "name": "Oldenico",
    "lat": "45.40276",
    "lng": "8.38103"
  },
  {
    "country": "IT",
    "name": "Olcenengo",
    "lat": "45.36346",
    "lng": "8.30983"
  },
  {
    "country": "IT",
    "name": "Olbia",
    "lat": "40.92337",
    "lng": "9.49802"
  },
  {
    "country": "IT",
    "name": "Ogliastro Cilento",
    "lat": "40.35113",
    "lng": "15.04638"
  },
  {
    "country": "IT",
    "name": "Oglianico",
    "lat": "45.34154",
    "lng": "7.69196"
  },
  {
    "country": "IT",
    "name": "Oggiono",
    "lat": "45.79133",
    "lng": "9.34815"
  },
  {
    "country": "IT",
    "name": "Offlaga",
    "lat": "45.38526",
    "lng": "10.11736"
  },
  {
    "country": "IT",
    "name": "Offida",
    "lat": "42.93499",
    "lng": "13.69773"
  },
  {
    "country": "IT",
    "name": "Offanengo",
    "lat": "45.37887",
    "lng": "9.74236"
  },
  {
    "country": "IT",
    "name": "Offagna",
    "lat": "43.52588",
    "lng": "13.44076"
  },
  {
    "country": "IT",
    "name": "Ofena",
    "lat": "42.32536",
    "lng": "13.75864"
  },
  {
    "country": "IT",
    "name": "Odolo",
    "lat": "45.6455",
    "lng": "10.38309"
  },
  {
    "country": "IT",
    "name": "Oderzo",
    "lat": "45.78114",
    "lng": "12.49442"
  },
  {
    "country": "IT",
    "name": "Occimiano",
    "lat": "45.05991",
    "lng": "8.50666"
  },
  {
    "country": "IT",
    "name": "Occhiobello",
    "lat": "44.9224",
    "lng": "11.58139"
  },
  {
    "country": "IT",
    "name": "Occhieppo Superiore",
    "lat": "45.564",
    "lng": "8.00618"
  },
  {
    "country": "IT",
    "name": "Occhieppo Inferiore",
    "lat": "45.55006",
    "lng": "8.02102"
  },
  {
    "country": "IT",
    "name": "Nuvolento",
    "lat": "45.54599",
    "lng": "10.38809"
  },
  {
    "country": "IT",
    "name": "Nusco",
    "lat": "40.8882",
    "lng": "15.09185"
  },
  {
    "country": "IT",
    "name": "Nuoro",
    "lat": "40.31991",
    "lng": "9.32568"
  },
  {
    "country": "IT",
    "name": "Numana",
    "lat": "43.51136",
    "lng": "13.62118"
  },
  {
    "country": "IT",
    "name": "Nulvi",
    "lat": "40.78447",
    "lng": "8.74358"
  },
  {
    "country": "IT",
    "name": "Nule",
    "lat": "40.46266",
    "lng": "9.19076"
  },
  {
    "country": "IT",
    "name": "Nughedu Santa Vittoria",
    "lat": "40.10135",
    "lng": "8.95247"
  },
  {
    "country": "IT",
    "name": "Nughedu San Nicolò",
    "lat": "40.55736",
    "lng": "9.02142"
  },
  {
    "country": "IT",
    "name": "Nucetto",
    "lat": "44.33963",
    "lng": "8.0596"
  },
  {
    "country": "IT",
    "name": "Novoli",
    "lat": "40.37673",
    "lng": "18.04757"
  },
  {
    "country": "IT",
    "name": "Novi Velia",
    "lat": "40.22262",
    "lng": "15.286"
  },
  {
    "country": "IT",
    "name": "Novi Ligure",
    "lat": "44.76246",
    "lng": "8.787"
  },
  {
    "country": "IT",
    "name": "Novi di Modena",
    "lat": "44.88974",
    "lng": "10.90027"
  },
  {
    "country": "IT",
    "name": "Noventa Vicentina",
    "lat": "45.29438",
    "lng": "11.54843"
  },
  {
    "country": "IT",
    "name": "Noventa di Piave",
    "lat": "45.65981",
    "lng": "12.53322"
  },
  {
    "country": "IT",
    "name": "Novello",
    "lat": "44.58882",
    "lng": "7.92587"
  },
  {
    "country": "IT",
    "name": "Novellara",
    "lat": "44.84488",
    "lng": "10.72745"
  },
  {
    "country": "IT",
    "name": "Nove",
    "lat": "45.72159",
    "lng": "11.67833"
  },
  {
    "country": "IT",
    "name": "Novate Milanese",
    "lat": "45.5305",
    "lng": "9.13954"
  },
  {
    "country": "IT",
    "name": "Novate Mezzola",
    "lat": "46.21939",
    "lng": "9.44971"
  },
  {
    "country": "IT",
    "name": "Nova Siri",
    "lat": "40.14823",
    "lng": "16.53976"
  },
  {
    "country": "IT",
    "name": "Novara",
    "lat": "45.44694",
    "lng": "8.62118"
  },
  {
    "country": "IT",
    "name": "Nova Ponente",
    "lat": "46.41404",
    "lng": "11.42523"
  },
  {
    "country": "IT",
    "name": "Nova Milanese",
    "lat": "45.58882",
    "lng": "9.19792"
  },
  {
    "country": "IT",
    "name": "Nova Levante",
    "lat": "46.42899",
    "lng": "11.53942"
  },
  {
    "country": "IT",
    "name": "Novalesa",
    "lat": "45.19065",
    "lng": "7.01416"
  },
  {
    "country": "IT",
    "name": "Novaledo",
    "lat": "46.0234",
    "lng": "11.36607"
  },
  {
    "country": "IT",
    "name": "Novafeltria",
    "lat": "43.89486",
    "lng": "12.28894"
  },
  {
    "country": "IT",
    "name": "Notaresco",
    "lat": "42.65742",
    "lng": "13.89491"
  },
  {
    "country": "IT",
    "name": "Nosate",
    "lat": "45.55074",
    "lng": "8.72509"
  },
  {
    "country": "IT",
    "name": "Norma",
    "lat": "41.58643",
    "lng": "12.97073"
  },
  {
    "country": "IT",
    "name": "Norcia",
    "lat": "42.79105",
    "lng": "13.096"
  },
  {
    "country": "IT",
    "name": "Norbello",
    "lat": "40.13475",
    "lng": "8.83203"
  },
  {
    "country": "IT",
    "name": "Noragugume",
    "lat": "40.22443",
    "lng": "8.92012"
  },
  {
    "country": "IT",
    "name": "None",
    "lat": "44.93645",
    "lng": "7.54015"
  },
  {
    "country": "IT",
    "name": "Nonantola",
    "lat": "44.67785",
    "lng": "11.03785"
  },
  {
    "country": "IT",
    "name": "Nomi",
    "lat": "45.92923",
    "lng": "11.07198"
  },
  {
    "country": "IT",
    "name": "Nomaglio",
    "lat": "45.53616",
    "lng": "7.86032"
  },
  {
    "country": "IT",
    "name": "Noli",
    "lat": "44.20608",
    "lng": "8.41458"
  },
  {
    "country": "IT",
    "name": "Nole",
    "lat": "45.24159",
    "lng": "7.56983"
  },
  {
    "country": "IT",
    "name": "Nola",
    "lat": "40.92606",
    "lng": "14.52816"
  },
  {
    "country": "IT",
    "name": "Noicattaro",
    "lat": "41.03449",
    "lng": "16.98963"
  },
  {
    "country": "IT",
    "name": "Noha",
    "lat": "40.15323",
    "lng": "18.16569"
  },
  {
    "country": "IT",
    "name": "Nogarole Rocca",
    "lat": "45.29027",
    "lng": "10.88342"
  },
  {
    "country": "IT",
    "name": "Nogara",
    "lat": "45.18109",
    "lng": "11.06008"
  },
  {
    "country": "IT",
    "name": "Noepoli",
    "lat": "40.08705",
    "lng": "16.32834"
  },
  {
    "country": "IT",
    "name": "Nociglia",
    "lat": "40.03804",
    "lng": "18.32757"
  },
  {
    "country": "IT",
    "name": "Noci",
    "lat": "40.79356",
    "lng": "17.12681"
  },
  {
    "country": "IT",
    "name": "Noceto",
    "lat": "44.80953",
    "lng": "10.1773"
  },
  {
    "country": "IT",
    "name": "Nocera Umbra",
    "lat": "43.114",
    "lng": "12.78925"
  },
  {
    "country": "IT",
    "name": "Nocera Superiore",
    "lat": "40.74248",
    "lng": "14.67447"
  },
  {
    "country": "IT",
    "name": "Nocera Inferiore",
    "lat": "40.7454",
    "lng": "14.64542"
  },
  {
    "country": "IT",
    "name": "Nocelleto",
    "lat": "41.17067",
    "lng": "14.01565"
  },
  {
    "country": "IT",
    "name": "Nocciano",
    "lat": "42.33366",
    "lng": "13.98571"
  },
  {
    "country": "IT",
    "name": "Nocara",
    "lat": "40.09941",
    "lng": "16.48189"
  },
  {
    "country": "IT",
    "name": "Noasca",
    "lat": "45.45332",
    "lng": "7.31494"
  },
  {
    "country": "IT",
    "name": "Noale",
    "lat": "45.54596",
    "lng": "12.06445"
  },
  {
    "country": "IT",
    "name": "Nizza Monferrato",
    "lat": "44.77416",
    "lng": "8.35784"
  },
  {
    "country": "IT",
    "name": "Nimis",
    "lat": "46.20659",
    "lng": "13.26777"
  },
  {
    "country": "IT",
    "name": "Niella Belbo",
    "lat": "44.51275",
    "lng": "8.08036"
  },
  {
    "country": "IT",
    "name": "Nichelino",
    "lat": "45.00031",
    "lng": "7.65305"
  },
  {
    "country": "IT",
    "name": "Nibbiano",
    "lat": "44.90506",
    "lng": "9.32826"
  },
  {
    "country": "IT",
    "name": "Neviano degli Arduini",
    "lat": "44.58344",
    "lng": "10.31638"
  },
  {
    "country": "IT",
    "name": "Neviano",
    "lat": "40.1065",
    "lng": "18.11517"
  },
  {
    "country": "IT",
    "name": "Nettuno",
    "lat": "41.45794",
    "lng": "12.66393"
  },
  {
    "country": "IT",
    "name": "Netro",
    "lat": "45.54004",
    "lng": "7.94695"
  },
  {
    "country": "IT",
    "name": "Nespolo",
    "lat": "42.15671",
    "lng": "13.06938"
  },
  {
    "country": "IT",
    "name": "Nerviano",
    "lat": "45.55343",
    "lng": "8.9792"
  },
  {
    "country": "IT",
    "name": "Nervesa della Battaglia",
    "lat": "45.81232",
    "lng": "12.19837"
  },
  {
    "country": "IT",
    "name": "Nerola",
    "lat": "42.16011",
    "lng": "12.78529"
  },
  {
    "country": "IT",
    "name": "Nerito",
    "lat": "42.54763",
    "lng": "13.47759"
  },
  {
    "country": "IT",
    "name": "Nereto",
    "lat": "42.81548",
    "lng": "13.81989"
  },
  {
    "country": "IT",
    "name": "Nepi",
    "lat": "42.24221",
    "lng": "12.34355"
  },
  {
    "country": "IT",
    "name": "Nepezzano",
    "lat": "42.68994",
    "lng": "13.7565"
  },
  {
    "country": "IT",
    "name": "Neoneli",
    "lat": "40.06475",
    "lng": "8.94673"
  },
  {
    "country": "IT",
    "name": "Nemoli",
    "lat": "40.06765",
    "lng": "15.79962"
  },
  {
    "country": "IT",
    "name": "Nemi",
    "lat": "41.72185",
    "lng": "12.71809"
  },
  {
    "country": "IT",
    "name": "Nembro",
    "lat": "45.74411",
    "lng": "9.76127"
  },
  {
    "country": "IT",
    "name": "Bricco di Neive",
    "lat": "44.71159",
    "lng": "8.13409"
  },
  {
    "country": "IT",
    "name": "Neirone",
    "lat": "44.45482",
    "lng": "9.19133"
  },
  {
    "country": "IT",
    "name": "Negrar",
    "lat": "45.52918",
    "lng": "10.93899"
  },
  {
    "country": "IT",
    "name": "Conscenti",
    "lat": "44.34491",
    "lng": "9.39537"
  },
  {
    "country": "IT",
    "name": "Nazzano",
    "lat": "42.23018",
    "lng": "12.5944"
  },
  {
    "country": "IT",
    "name": "Navelli",
    "lat": "42.23721",
    "lng": "13.72961"
  },
  {
    "country": "IT",
    "name": "Nave",
    "lat": "45.5848",
    "lng": "10.27947"
  },
  {
    "country": "IT",
    "name": "Naturno",
    "lat": "46.64801",
    "lng": "11.00129"
  },
  {
    "country": "IT",
    "name": "Nasino-Borgo",
    "lat": "44.11363",
    "lng": "8.03205"
  },
  {
    "country": "IT",
    "name": "Narzole",
    "lat": "44.59441",
    "lng": "7.86765"
  },
  {
    "country": "IT",
    "name": "Narni Scalo",
    "lat": "42.5362",
    "lng": "12.5168"
  },
  {
    "country": "IT",
    "name": "Narni",
    "lat": "42.51956",
    "lng": "12.52758"
  },
  {
    "country": "IT",
    "name": "Nardò",
    "lat": "40.17953",
    "lng": "18.03174"
  },
  {
    "country": "IT",
    "name": "Narbolia",
    "lat": "40.04784",
    "lng": "8.57552"
  },
  {
    "country": "IT",
    "name": "Naples",
    "lat": "40.85216",
    "lng": "14.26811"
  },
  {
    "country": "IT",
    "name": "Nalles",
    "lat": "46.54341",
    "lng": "11.20625"
  },
  {
    "country": "IT",
    "name": "Nago-Torbole",
    "lat": "45.87594",
    "lng": "10.89106"
  },
  {
    "country": "IT",
    "name": "Muzzana del Turgnano",
    "lat": "45.81799",
    "lng": "13.12751"
  },
  {
    "country": "IT",
    "name": "San Pietro Mussolino",
    "lat": "45.58359",
    "lng": "11.2593"
  },
  {
    "country": "IT",
    "name": "Musso",
    "lat": "46.11295",
    "lng": "9.27379"
  },
  {
    "country": "IT",
    "name": "Musile di Piave",
    "lat": "45.62057",
    "lng": "12.54177"
  },
  {
    "country": "IT",
    "name": "Musano",
    "lat": "45.72646",
    "lng": "12.11785"
  },
  {
    "country": "IT",
    "name": "Muros",
    "lat": "40.67902",
    "lng": "8.6178"
  },
  {
    "country": "IT",
    "name": "Muro Lucano",
    "lat": "40.75379",
    "lng": "15.48808"
  },
  {
    "country": "IT",
    "name": "Muro Leccese",
    "lat": "40.10286",
    "lng": "18.33674"
  },
  {
    "country": "IT",
    "name": "Murlo",
    "lat": "43.16114",
    "lng": "11.38794"
  },
  {
    "country": "IT",
    "name": "Murisengo",
    "lat": "45.08165",
    "lng": "8.13554"
  },
  {
    "country": "IT",
    "name": "Murialdo",
    "lat": "44.31693",
    "lng": "8.16815"
  },
  {
    "country": "IT",
    "name": "Murazzano",
    "lat": "44.47334",
    "lng": "8.01938"
  },
  {
    "country": "IT",
    "name": "Murano",
    "lat": "45.45857",
    "lng": "12.35683"
  },
  {
    "country": "IT",
    "name": "Mura",
    "lat": "45.71307",
    "lng": "10.34204"
  },
  {
    "country": "IT",
    "name": "Mulazzo",
    "lat": "44.31564",
    "lng": "9.89101"
  },
  {
    "country": "IT",
    "name": "Mugnano di Napoli",
    "lat": "40.90936",
    "lng": "14.20984"
  },
  {
    "country": "IT",
    "name": "Mugnano del Cardinale",
    "lat": "40.94248",
    "lng": "14.6361"
  },
  {
    "country": "IT",
    "name": "Muggiò",
    "lat": "45.58878",
    "lng": "9.22784"
  },
  {
    "country": "IT",
    "name": "Muggia",
    "lat": "45.60419",
    "lng": "13.76754"
  },
  {
    "country": "IT",
    "name": "Muccia",
    "lat": "43.08232",
    "lng": "13.04323"
  },
  {
    "country": "IT",
    "name": "Mozzecane",
    "lat": "45.30763",
    "lng": "10.81554"
  },
  {
    "country": "IT",
    "name": "Mozzate",
    "lat": "45.67473",
    "lng": "8.95644"
  },
  {
    "country": "IT",
    "name": "Mozzanica",
    "lat": "45.4768",
    "lng": "9.68849"
  },
  {
    "country": "IT",
    "name": "Mozzagrogna",
    "lat": "42.21267",
    "lng": "14.44258"
  },
  {
    "country": "IT",
    "name": "Mottola",
    "lat": "40.6389",
    "lng": "17.03432"
  },
  {
    "country": "IT",
    "name": "Motta Visconti",
    "lat": "45.28774",
    "lng": "8.99254"
  },
  {
    "country": "IT",
    "name": "Motta Montecorvino",
    "lat": "41.50743",
    "lng": "15.11414"
  },
  {
    "country": "IT",
    "name": "Mottalciata",
    "lat": "45.50019",
    "lng": "8.21065"
  },
  {
    "country": "IT",
    "name": "Motta di Livenza",
    "lat": "45.77552",
    "lng": "12.60411"
  },
  {
    "country": "IT",
    "name": "Motta Dè Conti",
    "lat": "45.19356",
    "lng": "8.52094"
  },
  {
    "country": "IT",
    "name": "Motta Baluffi",
    "lat": "45.05569",
    "lng": "10.25855"
  },
  {
    "country": "IT",
    "name": "Motta",
    "lat": "45.5954",
    "lng": "11.49798"
  },
  {
    "country": "IT",
    "name": "Mosso Santa Maria",
    "lat": "45.64958",
    "lng": "8.13682"
  },
  {
    "country": "IT",
    "name": "Mossa",
    "lat": "45.93674",
    "lng": "13.54933"
  },
  {
    "country": "IT",
    "name": "Moso in Passiria",
    "lat": "46.83154",
    "lng": "11.16708"
  },
  {
    "country": "IT",
    "name": "Mosnigo",
    "lat": "45.86303",
    "lng": "12.07852"
  },
  {
    "country": "IT",
    "name": "Moscufo",
    "lat": "42.42713",
    "lng": "14.05434"
  },
  {
    "country": "IT",
    "name": "Mosciano Sant'Angelo",
    "lat": "42.747",
    "lng": "13.88891"
  },
  {
    "country": "IT",
    "name": "Moscazzano",
    "lat": "45.29358",
    "lng": "9.68135"
  },
  {
    "country": "IT",
    "name": "Moruzzo",
    "lat": "46.11967",
    "lng": "13.124"
  },
  {
    "country": "IT",
    "name": "Morterone",
    "lat": "45.8748",
    "lng": "9.48233"
  },
  {
    "country": "IT",
    "name": "Mortegliano",
    "lat": "45.94553",
    "lng": "13.17255"
  },
  {
    "country": "IT",
    "name": "Mortara",
    "lat": "45.2494",
    "lng": "8.73302"
  },
  {
    "country": "IT",
    "name": "Morsano",
    "lat": "45.85969",
    "lng": "12.92769"
  },
  {
    "country": "IT",
    "name": "Morrovalle",
    "lat": "43.3183",
    "lng": "13.59535"
  },
  {
    "country": "IT",
    "name": "Morro Reatino",
    "lat": "42.52226",
    "lng": "12.83449"
  },
  {
    "country": "IT",
    "name": "Morrone del Sannio",
    "lat": "41.71107",
    "lng": "14.78087"
  },
  {
    "country": "IT",
    "name": "Morro d'Oro",
    "lat": "42.66291",
    "lng": "13.92129"
  },
  {
    "country": "IT",
    "name": "Morro d'Alba",
    "lat": "43.6",
    "lng": "13.21331"
  },
  {
    "country": "IT",
    "name": "Morra de Sanctis",
    "lat": "40.92902",
    "lng": "15.24285"
  },
  {
    "country": "IT",
    "name": "Morozzo",
    "lat": "44.42277",
    "lng": "7.71006"
  },
  {
    "country": "IT",
    "name": "Morolo",
    "lat": "41.63838",
    "lng": "13.19809"
  },
  {
    "country": "IT",
    "name": "Mornago",
    "lat": "45.74516",
    "lng": "8.75046"
  },
  {
    "country": "IT",
    "name": "Morlupo",
    "lat": "42.15002",
    "lng": "12.50306"
  },
  {
    "country": "IT",
    "name": "Morimondo",
    "lat": "45.35381",
    "lng": "8.95626"
  },
  {
    "country": "IT",
    "name": "Morigerati",
    "lat": "40.14056",
    "lng": "15.55508"
  },
  {
    "country": "IT",
    "name": "Moricone",
    "lat": "42.11661",
    "lng": "12.77234"
  },
  {
    "country": "IT",
    "name": "Moriago della Battaglia",
    "lat": "45.86589",
    "lng": "12.10077"
  },
  {
    "country": "IT",
    "name": "Mori",
    "lat": "45.85187",
    "lng": "10.98052"
  },
  {
    "country": "IT",
    "name": "Morgex",
    "lat": "45.75664",
    "lng": "7.04123"
  },
  {
    "country": "IT",
    "name": "Morfasso",
    "lat": "44.7227",
    "lng": "9.70221"
  },
  {
    "country": "IT",
    "name": "Moretta",
    "lat": "44.76137",
    "lng": "7.53632"
  },
  {
    "country": "IT",
    "name": "Moresco",
    "lat": "43.08666",
    "lng": "13.73041"
  },
  {
    "country": "IT",
    "name": "Mores",
    "lat": "40.54745",
    "lng": "8.83302"
  },
  {
    "country": "IT",
    "name": "Mordano",
    "lat": "44.39696",
    "lng": "11.80763"
  },
  {
    "country": "IT",
    "name": "Morcone",
    "lat": "41.34269",
    "lng": "14.66889"
  },
  {
    "country": "IT",
    "name": "Morciano di Romagna",
    "lat": "43.9144",
    "lng": "12.65104"
  },
  {
    "country": "IT",
    "name": "Morbegno",
    "lat": "46.1372",
    "lng": "9.57415"
  },
  {
    "country": "IT",
    "name": "Morano sul Po",
    "lat": "45.16621",
    "lng": "8.36674"
  },
  {
    "country": "IT",
    "name": "Monzuno",
    "lat": "44.27825",
    "lng": "11.26684"
  },
  {
    "country": "IT",
    "name": "Monzambano",
    "lat": "45.38534",
    "lng": "10.69331"
  },
  {
    "country": "IT",
    "name": "Monza",
    "lat": "45.58005",
    "lng": "9.27246"
  },
  {
    "country": "IT",
    "name": "Montù Beccaria",
    "lat": "45.03633",
    "lng": "9.31268"
  },
  {
    "country": "IT",
    "name": "Montresta",
    "lat": "40.37365",
    "lng": "8.49962"
  },
  {
    "country": "IT",
    "name": "Montottone",
    "lat": "43.06205",
    "lng": "13.59009"
  },
  {
    "country": "IT",
    "name": "Montorso Vicentino",
    "lat": "45.49089",
    "lng": "11.36019"
  },
  {
    "country": "IT",
    "name": "Montorio",
    "lat": "45.45826",
    "lng": "11.06589"
  },
  {
    "country": "IT",
    "name": "Montorio Romano",
    "lat": "42.13738",
    "lng": "12.80404"
  },
  {
    "country": "IT",
    "name": "Montorio Nei Frentani",
    "lat": "41.75884",
    "lng": "14.93314"
  },
  {
    "country": "IT",
    "name": "Montorio al Vomano",
    "lat": "42.58123",
    "lng": "13.63715"
  },
  {
    "country": "IT",
    "name": "Montopoli",
    "lat": "43.67354",
    "lng": "10.74951"
  },
  {
    "country": "IT",
    "name": "Montopoli in Sabina",
    "lat": "42.24593",
    "lng": "12.69208"
  },
  {
    "country": "IT",
    "name": "Montone",
    "lat": "43.36078",
    "lng": "12.32346"
  },
  {
    "country": "IT",
    "name": "Montoggio",
    "lat": "44.51699",
    "lng": "9.04923"
  },
  {
    "country": "IT",
    "name": "Montodine",
    "lat": "45.28419",
    "lng": "9.7091"
  },
  {
    "country": "IT",
    "name": "Montjovet",
    "lat": "45.70796",
    "lng": "7.67411"
  },
  {
    "country": "IT",
    "name": "Montignoso",
    "lat": "44.02405",
    "lng": "10.17259"
  },
  {
    "country": "IT",
    "name": "Montiglio",
    "lat": "45.06462",
    "lng": "8.09878"
  },
  {
    "country": "IT",
    "name": "Montieri",
    "lat": "43.13113",
    "lng": "11.01663"
  },
  {
    "country": "IT",
    "name": "Monticiano",
    "lat": "43.13965",
    "lng": "11.1771"
  },
  {
    "country": "IT",
    "name": "Montichiari",
    "lat": "45.41317",
    "lng": "10.39799"
  },
  {
    "country": "IT",
    "name": "Monticello Conte Otto",
    "lat": "45.59784",
    "lng": "11.57234"
  },
  {
    "country": "IT",
    "name": "Monticelli",
    "lat": "40.65",
    "lng": "15.01667"
  },
  {
    "country": "IT",
    "name": "Monticelli d'Ongina",
    "lat": "45.08851",
    "lng": "9.93424"
  },
  {
    "country": "IT",
    "name": "Monticchio",
    "lat": "42.32035",
    "lng": "13.46382"
  },
  {
    "country": "IT",
    "name": "Montiano",
    "lat": "44.08232",
    "lng": "12.30455"
  },
  {
    "country": "IT",
    "name": "Monti",
    "lat": "40.80715",
    "lng": "9.32553"
  },
  {
    "country": "IT",
    "name": "Monte Vidon Corrado",
    "lat": "43.12087",
    "lng": "13.48931"
  },
  {
    "country": "IT",
    "name": "Monteviale",
    "lat": "45.5592",
    "lng": "11.45715"
  },
  {
    "country": "IT",
    "name": "Monteverdi Marittimo",
    "lat": "43.17787",
    "lng": "10.71133"
  },
  {
    "country": "IT",
    "name": "Monteverde",
    "lat": "40.99858",
    "lng": "15.53361"
  },
  {
    "country": "IT",
    "name": "Montevarchi",
    "lat": "43.5252",
    "lng": "11.57238"
  },
  {
    "country": "IT",
    "name": "Monteu Roero",
    "lat": "44.78059",
    "lng": "7.93383"
  },
  {
    "country": "IT",
    "name": "Monte Urano",
    "lat": "43.19039",
    "lng": "13.6618"
  },
  {
    "country": "IT",
    "name": "Monteu da Po",
    "lat": "45.15031",
    "lng": "8.01428"
  },
  {
    "country": "IT",
    "name": "Montespertoli",
    "lat": "43.6426",
    "lng": "11.07331"
  },
  {
    "country": "IT",
    "name": "Montesilvano Marina",
    "lat": "42.5114",
    "lng": "14.14507"
  },
  {
    "country": "IT",
    "name": "Montesegale",
    "lat": "44.90696",
    "lng": "9.12636"
  },
  {
    "country": "IT",
    "name": "Montese",
    "lat": "44.26993",
    "lng": "10.94545"
  },
  {
    "country": "IT",
    "name": "Montescudo",
    "lat": "43.91753",
    "lng": "12.54083"
  },
  {
    "country": "IT",
    "name": "Montescaglioso",
    "lat": "40.55024",
    "lng": "16.66541"
  },
  {
    "country": "IT",
    "name": "Montesarchio",
    "lat": "41.06227",
    "lng": "14.64096"
  },
  {
    "country": "IT",
    "name": "Monte San Vito",
    "lat": "43.60056",
    "lng": "13.26817"
  },
  {
    "country": "IT",
    "name": "Monte Sant'Angelo",
    "lat": "41.7053",
    "lng": "15.96068"
  },
  {
    "country": "IT",
    "name": "Monte Santa Maria Tiberina",
    "lat": "43.43688",
    "lng": "12.1622"
  },
  {
    "country": "IT",
    "name": "Monte San Savino",
    "lat": "43.33213",
    "lng": "11.72663"
  },
  {
    "country": "IT",
    "name": "Monte San Pietrangeli",
    "lat": "43.18959",
    "lng": "13.57718"
  },
  {
    "country": "IT",
    "name": "Montesano sulla Marcellana",
    "lat": "40.2761",
    "lng": "15.7039"
  },
  {
    "country": "IT",
    "name": "Monte San Martino",
    "lat": "43.03219",
    "lng": "13.44033"
  },
  {
    "country": "IT",
    "name": "Monte San Giusto",
    "lat": "43.23565",
    "lng": "13.59316"
  },
  {
    "country": "IT",
    "name": "Monte San Giovanni in Sabina",
    "lat": "42.32703",
    "lng": "12.77858"
  },
  {
    "country": "IT",
    "name": "Monte San Giovanni Campano",
    "lat": "41.6431",
    "lng": "13.51088"
  },
  {
    "country": "IT",
    "name": "Monte San Giacomo",
    "lat": "40.34411",
    "lng": "15.54221"
  },
  {
    "country": "IT",
    "name": "Monte San Biagio",
    "lat": "41.3536",
    "lng": "13.35184"
  },
  {
    "country": "IT",
    "name": "Monterubbiano",
    "lat": "43.0856",
    "lng": "13.71911"
  },
  {
    "country": "IT",
    "name": "Monterotondo Marittimo",
    "lat": "43.14556",
    "lng": "10.85591"
  },
  {
    "country": "IT",
    "name": "Monterotondo",
    "lat": "42.05159",
    "lng": "12.61969"
  },
  {
    "country": "IT",
    "name": "Monterosso al Mare",
    "lat": "44.14666",
    "lng": "9.65494"
  },
  {
    "country": "IT",
    "name": "Monterosi",
    "lat": "42.19698",
    "lng": "12.30842"
  },
  {
    "country": "IT",
    "name": "Monteroni di Lecce",
    "lat": "40.31929",
    "lng": "18.09163"
  },
  {
    "country": "IT",
    "name": "Monteroni d'Arbia",
    "lat": "43.22968",
    "lng": "11.42228"
  },
  {
    "country": "IT",
    "name": "Monte Romano",
    "lat": "42.26745",
    "lng": "11.89658"
  },
  {
    "country": "IT",
    "name": "Monteroduni",
    "lat": "41.5224",
    "lng": "14.17641"
  },
  {
    "country": "IT",
    "name": "Monte Roberto",
    "lat": "43.48056",
    "lng": "13.13797"
  },
  {
    "country": "IT",
    "name": "Monte Rinaldo",
    "lat": "43.02825",
    "lng": "13.58198"
  },
  {
    "country": "IT",
    "name": "Monteriggioni",
    "lat": "43.38994",
    "lng": "11.22323"
  },
  {
    "country": "IT",
    "name": "Monterenzio",
    "lat": "44.32632",
    "lng": "11.40446"
  },
  {
    "country": "IT",
    "name": "Montereale Valcellina",
    "lat": "46.1511",
    "lng": "12.64771"
  },
  {
    "country": "IT",
    "name": "Montereale",
    "lat": "42.52332",
    "lng": "13.24585"
  },
  {
    "country": "IT",
    "name": "Monterchi",
    "lat": "43.48733",
    "lng": "12.11054"
  },
  {
    "country": "IT",
    "name": "Monterado",
    "lat": "43.69686",
    "lng": "13.09056"
  },
  {
    "country": "IT",
    "name": "Montepulciano Stazione",
    "lat": "43.1352",
    "lng": "11.85545"
  },
  {
    "country": "IT",
    "name": "Montepulciano",
    "lat": "43.09998",
    "lng": "11.78704"
  },
  {
    "country": "IT",
    "name": "Monteprandone",
    "lat": "42.9205",
    "lng": "13.8391"
  },
  {
    "country": "IT",
    "name": "Monte Porzio Catone",
    "lat": "41.81585",
    "lng": "12.71432"
  },
  {
    "country": "IT",
    "name": "Monteparano",
    "lat": "40.44335",
    "lng": "17.41308"
  },
  {
    "country": "IT",
    "name": "Monteodorisio",
    "lat": "42.08485",
    "lng": "14.65386"
  },
  {
    "country": "IT",
    "name": "Montenero Val Cocchiara",
    "lat": "41.71683",
    "lng": "14.06941"
  },
  {
    "country": "IT",
    "name": "Montenerodomo",
    "lat": "41.97682",
    "lng": "14.25177"
  },
  {
    "country": "IT",
    "name": "Montenero di Bisaccia",
    "lat": "41.96437",
    "lng": "14.78103"
  },
  {
    "country": "IT",
    "name": "Montemurro",
    "lat": "40.29765",
    "lng": "15.99182"
  },
  {
    "country": "IT",
    "name": "Montemurlo",
    "lat": "43.92686",
    "lng": "11.03718"
  },
  {
    "country": "IT",
    "name": "Montemonaco",
    "lat": "42.89871",
    "lng": "13.33018"
  },
  {
    "country": "IT",
    "name": "Montemitro",
    "lat": "41.88813",
    "lng": "14.64666"
  },
  {
    "country": "IT",
    "name": "Montemilone",
    "lat": "41.02742",
    "lng": "15.96661"
  },
  {
    "country": "IT",
    "name": "Montemiletto",
    "lat": "41.01168",
    "lng": "14.90034"
  },
  {
    "country": "IT",
    "name": "Montemesola",
    "lat": "40.5676",
    "lng": "17.33665"
  },
  {
    "country": "IT",
    "name": "Monte Marenzo",
    "lat": "45.77213",
    "lng": "9.45476"
  },
  {
    "country": "IT",
    "name": "Montemarciano",
    "lat": "43.63847",
    "lng": "13.30801"
  },
  {
    "country": "IT",
    "name": "Montemarano",
    "lat": "40.91414",
    "lng": "14.99766"
  },
  {
    "country": "IT",
    "name": "Montemagno",
    "lat": "44.98305",
    "lng": "8.32534"
  },
  {
    "country": "IT",
    "name": "Montemaggiore al Metauro",
    "lat": "43.73666",
    "lng": "12.94536"
  },
  {
    "country": "IT",
    "name": "Montelupone",
    "lat": "43.3427",
    "lng": "13.57074"
  },
  {
    "country": "IT",
    "name": "Montelupo Fiorentino",
    "lat": "43.72958",
    "lng": "11.00997"
  },
  {
    "country": "IT",
    "name": "Montelupo Albese",
    "lat": "44.62151",
    "lng": "8.0472"
  },
  {
    "country": "IT",
    "name": "Montelparo",
    "lat": "43.01755",
    "lng": "13.53698"
  },
  {
    "country": "IT",
    "name": "Montelongo",
    "lat": "41.73705",
    "lng": "14.95034"
  },
  {
    "country": "IT",
    "name": "Monteleone Sabino",
    "lat": "42.23267",
    "lng": "12.85828"
  },
  {
    "country": "IT",
    "name": "Monteleone Rocca Doria",
    "lat": "40.47206",
    "lng": "8.56071"
  },
  {
    "country": "IT",
    "name": "Monteleone d'Orvieto",
    "lat": "42.92171",
    "lng": "12.05347"
  },
  {
    "country": "IT",
    "name": "Monteleone di Spoleto",
    "lat": "42.65046",
    "lng": "12.95158"
  },
  {
    "country": "IT",
    "name": "Monteleone di Puglia",
    "lat": "41.16711",
    "lng": "15.25822"
  },
  {
    "country": "IT",
    "name": "Montelapiano",
    "lat": "41.96267",
    "lng": "14.34212"
  },
  {
    "country": "IT",
    "name": "Montelanico",
    "lat": "41.65069",
    "lng": "13.04027"
  },
  {
    "country": "IT",
    "name": "Montelabbate",
    "lat": "43.84732",
    "lng": "12.78763"
  },
  {
    "country": "IT",
    "name": "Monteiasi",
    "lat": "40.49992",
    "lng": "17.3826"
  },
  {
    "country": "IT",
    "name": "Montegrotto Terme",
    "lat": "45.33119",
    "lng": "11.78634"
  },
  {
    "country": "IT",
    "name": "Montegrosso Pian Latte",
    "lat": "44.06631",
    "lng": "7.81602"
  },
  {
    "country": "IT",
    "name": "Montegrosso",
    "lat": "44.82065",
    "lng": "8.23754"
  },
  {
    "country": "IT",
    "name": "Monte Grimano",
    "lat": "43.46667",
    "lng": "12.46667"
  },
  {
    "country": "IT",
    "name": "Montegranaro",
    "lat": "43.23099",
    "lng": "13.63047"
  },
  {
    "country": "IT",
    "name": "Montegiorgio",
    "lat": "43.12988",
    "lng": "13.53925"
  },
  {
    "country": "IT",
    "name": "Montegiordano",
    "lat": "40.04301",
    "lng": "16.53439"
  },
  {
    "country": "IT",
    "name": "Monte Giberto",
    "lat": "43.09092",
    "lng": "13.63133"
  },
  {
    "country": "IT",
    "name": "Montegaldella",
    "lat": "45.43717",
    "lng": "11.67022"
  },
  {
    "country": "IT",
    "name": "Montegabbione",
    "lat": "42.91973",
    "lng": "12.09212"
  },
  {
    "country": "IT",
    "name": "Montefusco",
    "lat": "41.03691",
    "lng": "14.85498"
  },
  {
    "country": "IT",
    "name": "Montefredane",
    "lat": "40.95978",
    "lng": "14.81374"
  },
  {
    "country": "IT",
    "name": "Montefranco",
    "lat": "42.59835",
    "lng": "12.76376"
  },
  {
    "country": "IT",
    "name": "Montefortino",
    "lat": "42.94351",
    "lng": "13.34417"
  },
  {
    "country": "IT",
    "name": "Monteforte Irpino",
    "lat": "40.90246",
    "lng": "14.744"
  },
  {
    "country": "IT",
    "name": "Monteforte d'Alpone",
    "lat": "45.42013",
    "lng": "11.28446"
  },
  {
    "country": "IT",
    "name": "Monteforte Cilento",
    "lat": "40.36481",
    "lng": "15.19486"
  },
  {
    "country": "IT",
    "name": "Monteflavio",
    "lat": "42.10935",
    "lng": "12.83076"
  },
  {
    "country": "IT",
    "name": "Montefiorino",
    "lat": "44.35382",
    "lng": "10.62375"
  },
  {
    "country": "IT",
    "name": "Montefiore dell'Aso",
    "lat": "43.05276",
    "lng": "13.75518"
  },
  {
    "country": "IT",
    "name": "Montefiore Conca",
    "lat": "43.88916",
    "lng": "12.61145"
  },
  {
    "country": "IT",
    "name": "Montefino",
    "lat": "42.54551",
    "lng": "13.88479"
  },
  {
    "country": "IT",
    "name": "Montefiascone",
    "lat": "42.54255",
    "lng": "12.03192"
  },
  {
    "country": "IT",
    "name": "Monteferrante",
    "lat": "41.95396",
    "lng": "14.38856"
  },
  {
    "country": "IT",
    "name": "Montefano",
    "lat": "43.40982",
    "lng": "13.4369"
  },
  {
    "country": "IT",
    "name": "Montefalcone di Val Fortore",
    "lat": "41.3243",
    "lng": "15.00898"
  },
  {
    "country": "IT",
    "name": "Montefalcone nel Sannio",
    "lat": "41.86663",
    "lng": "14.63823"
  },
  {
    "country": "IT",
    "name": "Montefalcone Appennino",
    "lat": "42.99005",
    "lng": "13.45688"
  },
  {
    "country": "IT",
    "name": "Montefalco",
    "lat": "42.89084",
    "lng": "12.64827"
  },
  {
    "country": "IT",
    "name": "Montefalcione",
    "lat": "40.96173",
    "lng": "14.88312"
  },
  {
    "country": "IT",
    "name": "Monte di Procida",
    "lat": "40.79809",
    "lng": "14.05023"
  },
  {
    "country": "IT",
    "name": "Montedinove",
    "lat": "42.97262",
    "lng": "13.58972"
  },
  {
    "country": "IT",
    "name": "Monte di Malo",
    "lat": "45.66011",
    "lng": "11.36127"
  },
  {
    "country": "IT",
    "name": "Montecosaro",
    "lat": "43.31619",
    "lng": "13.63762"
  },
  {
    "country": "IT",
    "name": "Montecorvino Rovella",
    "lat": "40.6918",
    "lng": "14.97862"
  },
  {
    "country": "IT",
    "name": "Montecorice",
    "lat": "40.23444",
    "lng": "14.98504"
  },
  {
    "country": "IT",
    "name": "Montecompatri",
    "lat": "41.80892",
    "lng": "12.73778"
  },
  {
    "country": "IT",
    "name": "Montecilfone",
    "lat": "41.90163",
    "lng": "14.8368"
  },
  {
    "country": "IT",
    "name": "Monteciccardo",
    "lat": "43.82415",
    "lng": "12.80344"
  },
  {
    "country": "IT",
    "name": "Montechiarugolo",
    "lat": "44.69261",
    "lng": "10.42128"
  },
  {
    "country": "IT",
    "name": "Montechiaro d'Asti",
    "lat": "45.00701",
    "lng": "8.11286"
  },
  {
    "country": "IT",
    "name": "Monte Cerignone",
    "lat": "43.83983",
    "lng": "12.41427"
  },
  {
    "country": "IT",
    "name": "Montecelio",
    "lat": "42.02067",
    "lng": "12.74354"
  },
  {
    "country": "IT",
    "name": "Montecchio Maggiore-Alte Ceccato",
    "lat": "45.50369",
    "lng": "11.412"
  },
  {
    "country": "IT",
    "name": "Montecchio Emilia",
    "lat": "44.69937",
    "lng": "10.45211"
  },
  {
    "country": "IT",
    "name": "Montecchio",
    "lat": "42.66234",
    "lng": "12.28803"
  },
  {
    "country": "IT",
    "name": "Montecchia di Crosara",
    "lat": "45.4819",
    "lng": "11.25438"
  },
  {
    "country": "IT",
    "name": "Montecavolo",
    "lat": "44.63275",
    "lng": "10.54264"
  },
  {
    "country": "IT",
    "name": "Montecatini-Terme",
    "lat": "43.88153",
    "lng": "10.7723"
  },
  {
    "country": "IT",
    "name": "Montecatini Val di Cecina",
    "lat": "43.39234",
    "lng": "10.74904"
  },
  {
    "country": "IT",
    "name": "Montecastrilli",
    "lat": "42.65087",
    "lng": "12.48811"
  },
  {
    "country": "IT",
    "name": "Monte Castello di Vibio",
    "lat": "42.8404",
    "lng": "12.3524"
  },
  {
    "country": "IT",
    "name": "Montecassiano",
    "lat": "43.36518",
    "lng": "13.4395"
  },
  {
    "country": "IT",
    "name": "Montecarotto",
    "lat": "43.52828",
    "lng": "13.06656"
  },
  {
    "country": "IT",
    "name": "Montecarlo",
    "lat": "43.85218",
    "lng": "10.66742"
  },
  {
    "country": "IT",
    "name": "Montecalvoli",
    "lat": "43.68576",
    "lng": "10.66508"
  },
  {
    "country": "IT",
    "name": "Montecalvo Irpino",
    "lat": "41.19616",
    "lng": "15.03446"
  },
  {
    "country": "IT",
    "name": "Montecalvo in Foglia",
    "lat": "43.81099",
    "lng": "12.63161"
  },
  {
    "country": "IT",
    "name": "Montebuono",
    "lat": "42.3677",
    "lng": "12.59721"
  },
  {
    "country": "IT",
    "name": "Montebruno",
    "lat": "44.52577",
    "lng": "9.24831"
  },
  {
    "country": "IT",
    "name": "Montebelluna",
    "lat": "45.77504",
    "lng": "12.04904"
  },
  {
    "country": "IT",
    "name": "Montebello Vicentino",
    "lat": "45.45919",
    "lng": "11.38272"
  },
  {
    "country": "IT",
    "name": "Montebello sul Sangro",
    "lat": "41.98663",
    "lng": "14.32402"
  },
  {
    "country": "IT",
    "name": "Montebello di Bertona",
    "lat": "42.41686",
    "lng": "13.87119"
  },
  {
    "country": "IT",
    "name": "Montebello",
    "lat": "44.99994",
    "lng": "9.10263"
  },
  {
    "country": "IT",
    "name": "Montazzoli",
    "lat": "41.94887",
    "lng": "14.43069"
  },
  {
    "country": "IT",
    "name": "Montasola",
    "lat": "42.38495",
    "lng": "12.68127"
  },
  {
    "country": "IT",
    "name": "Montaquila",
    "lat": "41.56502",
    "lng": "14.11333"
  },
  {
    "country": "IT",
    "name": "Montappone",
    "lat": "43.13617",
    "lng": "13.46932"
  },
  {
    "country": "IT",
    "name": "Montano Antilia",
    "lat": "40.16264",
    "lng": "15.36315"
  },
  {
    "country": "IT",
    "name": "Montanaso Lombardo",
    "lat": "45.33522",
    "lng": "9.46551"
  },
  {
    "country": "IT",
    "name": "Montanaro",
    "lat": "45.23274",
    "lng": "7.85492"
  },
  {
    "country": "IT",
    "name": "Montanara",
    "lat": "45.13531",
    "lng": "10.71879"
  },
  {
    "country": "IT",
    "name": "Montalto Pavese",
    "lat": "44.97802",
    "lng": "9.21232"
  },
  {
    "country": "IT",
    "name": "Montalto Ligure",
    "lat": "43.92868",
    "lng": "7.84491"
  },
  {
    "country": "IT",
    "name": "Montalto Dora",
    "lat": "45.48993",
    "lng": "7.86253"
  },
  {
    "country": "IT",
    "name": "Montalto di Castro",
    "lat": "42.34983",
    "lng": "11.60788"
  },
  {
    "country": "IT",
    "name": "Montalto delle Marche",
    "lat": "42.98964",
    "lng": "13.6082"
  },
  {
    "country": "IT",
    "name": "Montalenghe",
    "lat": "45.33666",
    "lng": "7.83794"
  },
  {
    "country": "IT",
    "name": "Montale",
    "lat": "44.56923",
    "lng": "10.90771"
  },
  {
    "country": "IT",
    "name": "Montale",
    "lat": "43.93486",
    "lng": "11.01655"
  },
  {
    "country": "IT",
    "name": "Montalcino",
    "lat": "43.05397",
    "lng": "11.48853"
  },
  {
    "country": "IT",
    "name": "Montalbano Jonico",
    "lat": "40.28591",
    "lng": "16.5696"
  },
  {
    "country": "IT",
    "name": "Montaione",
    "lat": "43.55144",
    "lng": "10.91371"
  },
  {
    "country": "IT",
    "name": "Montaguto",
    "lat": "41.24873",
    "lng": "15.24845"
  },
  {
    "country": "IT",
    "name": "Montagnana",
    "lat": "45.23229",
    "lng": "11.46483"
  },
  {
    "country": "IT",
    "name": "Montagna",
    "lat": "46.33033",
    "lng": "11.30027"
  },
  {
    "country": "IT",
    "name": "Montagano",
    "lat": "41.64538",
    "lng": "14.67405"
  },
  {
    "country": "IT",
    "name": "Montà",
    "lat": "44.81474",
    "lng": "7.95477"
  },
  {
    "country": "IT",
    "name": "Monsummano Terme",
    "lat": "43.8672",
    "lng": "10.81295"
  },
  {
    "country": "IT",
    "name": "Monselice",
    "lat": "45.239",
    "lng": "11.74984"
  },
  {
    "country": "IT",
    "name": "Monsano",
    "lat": "43.56221",
    "lng": "13.25186"
  },
  {
    "country": "IT",
    "name": "Monsampolo del Tronto",
    "lat": "42.89749",
    "lng": "13.79349"
  },
  {
    "country": "IT",
    "name": "Monsampietro Morico",
    "lat": "43.06775",
    "lng": "13.55568"
  },
  {
    "country": "IT",
    "name": "Monopoli",
    "lat": "40.94918",
    "lng": "17.29717"
  },
  {
    "country": "IT",
    "name": "Monno",
    "lat": "46.21225",
    "lng": "10.34012"
  },
  {
    "country": "IT",
    "name": "Moniga del Garda",
    "lat": "45.52665",
    "lng": "10.53728"
  },
  {
    "country": "IT",
    "name": "Monguelfo",
    "lat": "46.75774",
    "lng": "12.10556"
  },
  {
    "country": "IT",
    "name": "Mongrando",
    "lat": "45.52826",
    "lng": "8.00712"
  },
  {
    "country": "IT",
    "name": "Mongiardino Ligure",
    "lat": "44.63443",
    "lng": "9.06462"
  },
  {
    "country": "IT",
    "name": "Monghidoro",
    "lat": "44.22327",
    "lng": "11.32331"
  },
  {
    "country": "IT",
    "name": "Mongardino",
    "lat": "44.84915",
    "lng": "8.21906"
  },
  {
    "country": "IT",
    "name": "Monforte d'Alba",
    "lat": "44.58271",
    "lng": "7.96793"
  },
  {
    "country": "IT",
    "name": "Monfalcone",
    "lat": "45.80463",
    "lng": "13.53292"
  },
  {
    "country": "IT",
    "name": "Monesiglio",
    "lat": "44.4655",
    "lng": "8.11915"
  },
  {
    "country": "IT",
    "name": "Moneglia",
    "lat": "44.23905",
    "lng": "9.49081"
  },
  {
    "country": "IT",
    "name": "Mondragone",
    "lat": "41.11399",
    "lng": "13.89157"
  },
  {
    "country": "IT",
    "name": "Mondovì",
    "lat": "44.39603",
    "lng": "7.81764"
  },
  {
    "country": "IT",
    "name": "Mondolfo",
    "lat": "43.74529",
    "lng": "13.10229"
  },
  {
    "country": "IT",
    "name": "Mondavio",
    "lat": "43.67468",
    "lng": "12.96601"
  },
  {
    "country": "IT",
    "name": "Moncucco Torinese",
    "lat": "45.06738",
    "lng": "7.93246"
  },
  {
    "country": "IT",
    "name": "Monclassico",
    "lat": "46.3341",
    "lng": "10.88604"
  },
  {
    "country": "IT",
    "name": "Monchio delle Corti",
    "lat": "44.41172",
    "lng": "10.1237"
  },
  {
    "country": "IT",
    "name": "Monchiero Borgonuovo",
    "lat": "44.57054",
    "lng": "7.92024"
  },
  {
    "country": "IT",
    "name": "Moncalvo",
    "lat": "45.05057",
    "lng": "8.26277"
  },
  {
    "country": "IT",
    "name": "Moncalieri",
    "lat": "44.9994",
    "lng": "7.68236"
  },
  {
    "country": "IT",
    "name": "Monastier di Treviso",
    "lat": "45.65778",
    "lng": "12.4175"
  },
  {
    "country": "IT",
    "name": "Monasterolo del Castello",
    "lat": "45.76319",
    "lng": "9.93166"
  },
  {
    "country": "IT",
    "name": "Monacilioni",
    "lat": "41.61077",
    "lng": "14.81"
  },
  {
    "country": "IT",
    "name": "Mompeo",
    "lat": "42.2478",
    "lng": "12.7513"
  },
  {
    "country": "IT",
    "name": "Momo",
    "lat": "45.57424",
    "lng": "8.5539"
  },
  {
    "country": "IT",
    "name": "Mombaroccio",
    "lat": "43.79506",
    "lng": "12.85476"
  },
  {
    "country": "IT",
    "name": "Mombaldone",
    "lat": "44.57025",
    "lng": "8.33302"
  },
  {
    "country": "IT",
    "name": "Molveno",
    "lat": "46.14238",
    "lng": "10.963"
  },
  {
    "country": "IT",
    "name": "Molteno",
    "lat": "45.77819",
    "lng": "9.30386"
  },
  {
    "country": "IT",
    "name": "Mollia",
    "lat": "45.81667",
    "lng": "8.03031"
  },
  {
    "country": "IT",
    "name": "Moliterno",
    "lat": "40.24394",
    "lng": "15.86544"
  },
  {
    "country": "IT",
    "name": "Molise",
    "lat": "41.63147",
    "lng": "14.49252"
  },
  {
    "country": "IT",
    "name": "Molino del Piano",
    "lat": "43.81098",
    "lng": "11.39992"
  },
  {
    "country": "IT",
    "name": "Molino del Pallone",
    "lat": "44.10028",
    "lng": "10.96135"
  },
  {
    "country": "IT",
    "name": "Mühlen in Taufers",
    "lat": "46.89926",
    "lng": "11.94317"
  },
  {
    "country": "IT",
    "name": "Molini di Triora",
    "lat": "43.98905",
    "lng": "7.77463"
  },
  {
    "country": "IT",
    "name": "Molini",
    "lat": "43.92594",
    "lng": "7.93835"
  },
  {
    "country": "IT",
    "name": "Molinella",
    "lat": "44.61758",
    "lng": "11.66719"
  },
  {
    "country": "IT",
    "name": "Molinara",
    "lat": "41.29728",
    "lng": "14.90867"
  },
  {
    "country": "IT",
    "name": "Molina di Ledro",
    "lat": "45.87095",
    "lng": "10.77408"
  },
  {
    "country": "IT",
    "name": "Molina Aterno",
    "lat": "42.14903",
    "lng": "13.7354"
  },
  {
    "country": "IT",
    "name": "Molfetta",
    "lat": "41.20036",
    "lng": "16.59905"
  },
  {
    "country": "IT",
    "name": "Molazzana",
    "lat": "44.07175",
    "lng": "10.4178"
  },
  {
    "country": "IT",
    "name": "Molare",
    "lat": "44.61807",
    "lng": "8.5996"
  },
  {
    "country": "IT",
    "name": "Mola di Bari",
    "lat": "41.05997",
    "lng": "17.09001"
  },
  {
    "country": "IT",
    "name": "Moio della Civitella-Pellare",
    "lat": "40.2471",
    "lng": "15.26886"
  },
  {
    "country": "IT",
    "name": "Moimacco",
    "lat": "46.09145",
    "lng": "13.3727"
  },
  {
    "country": "IT",
    "name": "Moie",
    "lat": "43.50366",
    "lng": "13.13275"
  },
  {
    "country": "IT",
    "name": "Moiano",
    "lat": "41.07968",
    "lng": "14.54431"
  },
  {
    "country": "IT",
    "name": "Mogliano Veneto",
    "lat": "45.55594",
    "lng": "12.24294"
  },
  {
    "country": "IT",
    "name": "Mogliano",
    "lat": "43.1875",
    "lng": "13.49123"
  },
  {
    "country": "IT",
    "name": "Moglia",
    "lat": "44.93561",
    "lng": "10.91463"
  },
  {
    "country": "IT",
    "name": "Moggio Udinese",
    "lat": "46.41083",
    "lng": "13.20139"
  },
  {
    "country": "IT",
    "name": "Moggio",
    "lat": "45.93239",
    "lng": "9.48623"
  },
  {
    "country": "IT",
    "name": "Moena",
    "lat": "46.37655",
    "lng": "11.65941"
  },
  {
    "country": "IT",
    "name": "Modugno",
    "lat": "41.08433",
    "lng": "16.78342"
  },
  {
    "country": "IT",
    "name": "Modolo",
    "lat": "40.27535",
    "lng": "8.53002"
  },
  {
    "country": "IT",
    "name": "Modigliana",
    "lat": "44.15954",
    "lng": "11.79286"
  },
  {
    "country": "IT",
    "name": "Modena",
    "lat": "44.64783",
    "lng": "10.92539"
  },
  {
    "country": "IT",
    "name": "Missanello",
    "lat": "40.28311",
    "lng": "16.1665"
  },
  {
    "country": "IT",
    "name": "Missaglia",
    "lat": "45.70656",
    "lng": "9.33471"
  },
  {
    "country": "IT",
    "name": "Misinto",
    "lat": "45.66142",
    "lng": "9.08129"
  },
  {
    "country": "IT",
    "name": "Misano di Gera d'Adda",
    "lat": "45.46946",
    "lng": "9.62129"
  },
  {
    "country": "IT",
    "name": "Misano Adriatico",
    "lat": "43.97714",
    "lng": "12.69805"
  },
  {
    "country": "IT",
    "name": "Mirano",
    "lat": "45.49458",
    "lng": "12.10775"
  },
  {
    "country": "IT",
    "name": "Mirandola",
    "lat": "44.88515",
    "lng": "11.06902"
  },
  {
    "country": "IT",
    "name": "Miranda",
    "lat": "41.64434",
    "lng": "14.24643"
  },
  {
    "country": "IT",
    "name": "Miradolo Terme",
    "lat": "45.17094",
    "lng": "9.44442"
  },
  {
    "country": "IT",
    "name": "Mirabello Sannitico",
    "lat": "41.51628",
    "lng": "14.67315"
  },
  {
    "country": "IT",
    "name": "Mirabello Monferrato",
    "lat": "45.03496",
    "lng": "8.52385"
  },
  {
    "country": "IT",
    "name": "Mirabello",
    "lat": "44.82295",
    "lng": "11.45669"
  },
  {
    "country": "IT",
    "name": "Mirabella Eclano",
    "lat": "41.04496",
    "lng": "15.00022"
  },
  {
    "country": "IT",
    "name": "Mira Taglio",
    "lat": "45.4346",
    "lng": "12.12942"
  },
  {
    "country": "IT",
    "name": "Minucciano",
    "lat": "44.17",
    "lng": "10.20807"
  },
  {
    "country": "IT",
    "name": "Minturno",
    "lat": "41.26294",
    "lng": "13.74583"
  },
  {
    "country": "IT",
    "name": "Minori",
    "lat": "40.6503",
    "lng": "14.62684"
  },
  {
    "country": "IT",
    "name": "Minervino Murge",
    "lat": "41.08264",
    "lng": "16.07861"
  },
  {
    "country": "IT",
    "name": "Minervino di Lecce",
    "lat": "40.09025",
    "lng": "18.42139"
  },
  {
    "country": "IT",
    "name": "Minerbio",
    "lat": "44.61811",
    "lng": "11.47257"
  },
  {
    "country": "IT",
    "name": "Minerbe",
    "lat": "45.23198",
    "lng": "11.35249"
  },
  {
    "country": "IT",
    "name": "Millesimo",
    "lat": "44.36695",
    "lng": "8.20354"
  },
  {
    "country": "IT",
    "name": "Milis",
    "lat": "40.05045",
    "lng": "8.63702"
  },
  {
    "country": "IT",
    "name": "Milan",
    "lat": "45.46427",
    "lng": "9.18951"
  },
  {
    "country": "IT",
    "name": "Milanere",
    "lat": "45.10436",
    "lng": "7.43373"
  },
  {
    "country": "IT",
    "name": "Mignano Monte Lungo",
    "lat": "41.40592",
    "lng": "13.98552"
  },
  {
    "country": "IT",
    "name": "Mignanego",
    "lat": "44.52748",
    "lng": "8.91412"
  },
  {
    "country": "IT",
    "name": "Miglionico",
    "lat": "40.56763",
    "lng": "16.49964"
  },
  {
    "country": "IT",
    "name": "Migliaro",
    "lat": "44.79916",
    "lng": "11.9744"
  },
  {
    "country": "IT",
    "name": "Migliarino",
    "lat": "44.76993",
    "lng": "11.93304"
  },
  {
    "country": "IT",
    "name": "Migliarino",
    "lat": "43.76589",
    "lng": "10.33951"
  },
  {
    "country": "IT",
    "name": "Migliarina",
    "lat": "44.81042",
    "lng": "10.836"
  },
  {
    "country": "IT",
    "name": "Miglianico",
    "lat": "42.35773",
    "lng": "14.29179"
  },
  {
    "country": "IT",
    "name": "Micigliano",
    "lat": "42.45203",
    "lng": "13.05318"
  },
  {
    "country": "IT",
    "name": "Miazzina",
    "lat": "45.97566",
    "lng": "8.52308"
  },
  {
    "country": "IT",
    "name": "Miane",
    "lat": "45.94341",
    "lng": "12.09246"
  },
  {
    "country": "IT",
    "name": "Mezzomerico",
    "lat": "45.61991",
    "lng": "8.60616"
  },
  {
    "country": "IT",
    "name": "Mezzolombardo",
    "lat": "46.20774",
    "lng": "11.09636"
  },
  {
    "country": "IT",
    "name": "Mezzoldo",
    "lat": "46.01259",
    "lng": "9.66555"
  },
  {
    "country": "IT",
    "name": "Mezzolara",
    "lat": "44.58917",
    "lng": "11.56492"
  },
  {
    "country": "IT",
    "name": "Mezzogoro",
    "lat": "44.90256",
    "lng": "12.09925"
  },
  {
    "country": "IT",
    "name": "Mezzocorona",
    "lat": "46.21159",
    "lng": "11.12253"
  },
  {
    "country": "IT",
    "name": "Mezzano Inferiore",
    "lat": "44.91291",
    "lng": "10.45838"
  },
  {
    "country": "IT",
    "name": "Mezzano",
    "lat": "46.15393",
    "lng": "11.80876"
  },
  {
    "country": "IT",
    "name": "Mezzano",
    "lat": "44.46625",
    "lng": "12.08632"
  },
  {
    "country": "IT",
    "name": "Mezzanino",
    "lat": "45.12489",
    "lng": "9.20497"
  },
  {
    "country": "IT",
    "name": "Mezzanego",
    "lat": "44.38275",
    "lng": "9.37667"
  },
  {
    "country": "IT",
    "name": "Mezzana Rabattone",
    "lat": "45.09488",
    "lng": "9.03247"
  },
  {
    "country": "IT",
    "name": "Mezzana Bigli",
    "lat": "45.05988",
    "lng": "8.84728"
  },
  {
    "country": "IT",
    "name": "Mezzana",
    "lat": "46.31671",
    "lng": "10.80007"
  },
  {
    "country": "IT",
    "name": "Meta",
    "lat": "40.64081",
    "lng": "14.41582"
  },
  {
    "country": "IT",
    "name": "Mestrino",
    "lat": "45.44139",
    "lng": "11.75931"
  },
  {
    "country": "IT",
    "name": "Mestre",
    "lat": "45.49167",
    "lng": "12.24538"
  },
  {
    "country": "IT",
    "name": "Mesola",
    "lat": "44.91831",
    "lng": "12.23121"
  },
  {
    "country": "IT",
    "name": "Mese",
    "lat": "46.3036",
    "lng": "9.37769"
  },
  {
    "country": "IT",
    "name": "Mesagne",
    "lat": "40.55851",
    "lng": "17.80774"
  },
  {
    "country": "IT",
    "name": "Merlara",
    "lat": "45.167",
    "lng": "11.44504"
  },
  {
    "country": "IT",
    "name": "Merine",
    "lat": "40.33418",
    "lng": "18.22383"
  },
  {
    "country": "IT",
    "name": "Mergozzo",
    "lat": "45.96229",
    "lng": "8.45403"
  },
  {
    "country": "IT",
    "name": "Mergo",
    "lat": "43.4735",
    "lng": "13.03509"
  },
  {
    "country": "IT",
    "name": "Mereto di Tomba",
    "lat": "46.05128",
    "lng": "13.04432"
  },
  {
    "country": "IT",
    "name": "Mercogliano",
    "lat": "40.92157",
    "lng": "14.74491"
  },
  {
    "country": "IT",
    "name": "Mercenasco",
    "lat": "45.36002",
    "lng": "7.88013"
  },
  {
    "country": "IT",
    "name": "Mercato Vecchio",
    "lat": "43.80421",
    "lng": "12.37653"
  },
  {
    "country": "IT",
    "name": "Mercato Saraceno",
    "lat": "43.96274",
    "lng": "12.19638"
  },
  {
    "country": "IT",
    "name": "Mercato San Severino",
    "lat": "40.78468",
    "lng": "14.75369"
  },
  {
    "country": "IT",
    "name": "Mercato",
    "lat": "40.71612",
    "lng": "14.9401"
  },
  {
    "country": "IT",
    "name": "Mercatello sul Metauro",
    "lat": "43.64677",
    "lng": "12.33619"
  },
  {
    "country": "IT",
    "name": "Mercatale",
    "lat": "43.78276",
    "lng": "12.48478"
  },
  {
    "country": "IT",
    "name": "Mercallo",
    "lat": "45.74791",
    "lng": "8.66998"
  },
  {
    "country": "IT",
    "name": "Merate",
    "lat": "45.68858",
    "lng": "9.4208"
  },
  {
    "country": "IT",
    "name": "Merano",
    "lat": "46.66817",
    "lng": "11.15953"
  },
  {
    "country": "IT",
    "name": "Meolo",
    "lat": "45.6197",
    "lng": "12.45236"
  },
  {
    "country": "IT",
    "name": "Mentana",
    "lat": "42.03539",
    "lng": "12.64413"
  },
  {
    "country": "IT",
    "name": "Ruffrè",
    "lat": "46.41481",
    "lng": "11.17777"
  },
  {
    "country": "IT",
    "name": "Menconico",
    "lat": "44.79656",
    "lng": "9.27946"
  },
  {
    "country": "IT",
    "name": "Menaggio",
    "lat": "46.02075",
    "lng": "9.23907"
  },
  {
    "country": "IT",
    "name": "Melzo",
    "lat": "45.4981",
    "lng": "9.42043"
  },
  {
    "country": "IT",
    "name": "Meltina",
    "lat": "46.58744",
    "lng": "11.25487"
  },
  {
    "country": "IT",
    "name": "Melpignano",
    "lat": "40.15624",
    "lng": "18.29194"
  },
  {
    "country": "IT",
    "name": "Mello",
    "lat": "46.1549",
    "lng": "9.54734"
  },
  {
    "country": "IT",
    "name": "Melle",
    "lat": "44.56197",
    "lng": "7.31948"
  },
  {
    "country": "IT",
    "name": "Melizzano",
    "lat": "41.16181",
    "lng": "14.50554"
  },
  {
    "country": "IT",
    "name": "Melito Irpino",
    "lat": "41.10312",
    "lng": "15.05235"
  },
  {
    "country": "IT",
    "name": "Melito di Napoli",
    "lat": "40.91948",
    "lng": "14.23104"
  },
  {
    "country": "IT",
    "name": "Melfi",
    "lat": "40.99571",
    "lng": "15.65578"
  },
  {
    "country": "IT",
    "name": "Roccasecca Stazione",
    "lat": "41.53333",
    "lng": "13.65"
  },
  {
    "country": "IT",
    "name": "Meleti",
    "lat": "45.11967",
    "lng": "9.83568"
  },
  {
    "country": "IT",
    "name": "Melendugno",
    "lat": "40.27252",
    "lng": "18.33798"
  },
  {
    "country": "IT",
    "name": "Melegnano",
    "lat": "45.35781",
    "lng": "9.3236"
  },
  {
    "country": "IT",
    "name": "Meldola",
    "lat": "44.12775",
    "lng": "12.0626"
  },
  {
    "country": "IT",
    "name": "Melara",
    "lat": "45.06421",
    "lng": "11.20117"
  },
  {
    "country": "IT",
    "name": "Mel",
    "lat": "46.06379",
    "lng": "12.09"
  },
  {
    "country": "IT",
    "name": "Meina",
    "lat": "45.79123",
    "lng": "8.53761"
  },
  {
    "country": "IT",
    "name": "Megliadino San Vitale",
    "lat": "45.19577",
    "lng": "11.52402"
  },
  {
    "country": "IT",
    "name": "Meggiano",
    "lat": "42.75474",
    "lng": "12.86379"
  },
  {
    "country": "IT",
    "name": "Meduno",
    "lat": "46.21518",
    "lng": "12.79932"
  },
  {
    "country": "IT",
    "name": "Medolla",
    "lat": "44.84667",
    "lng": "11.0676"
  },
  {
    "country": "IT",
    "name": "Medole",
    "lat": "45.32588",
    "lng": "10.51357"
  },
  {
    "country": "IT",
    "name": "Medolago",
    "lat": "45.67129",
    "lng": "9.49807"
  },
  {
    "country": "IT",
    "name": "Mediis",
    "lat": "46.40336",
    "lng": "12.82341"
  },
  {
    "country": "IT",
    "name": "Medicina-Buda",
    "lat": "44.47867",
    "lng": "11.63812"
  },
  {
    "country": "IT",
    "name": "Medesano",
    "lat": "44.75824",
    "lng": "10.13794"
  },
  {
    "country": "IT",
    "name": "Mede",
    "lat": "45.09678",
    "lng": "8.73679"
  },
  {
    "country": "IT",
    "name": "Meda",
    "lat": "45.66121",
    "lng": "9.15337"
  },
  {
    "country": "IT",
    "name": "Mazzo di Valtellina",
    "lat": "46.25736",
    "lng": "10.25534"
  },
  {
    "country": "IT",
    "name": "Mazzin",
    "lat": "46.45742",
    "lng": "11.70018"
  },
  {
    "country": "IT",
    "name": "Mazze",
    "lat": "45.30025",
    "lng": "7.93272"
  },
  {
    "country": "IT",
    "name": "Mazzano Romano",
    "lat": "42.20597",
    "lng": "12.39554"
  },
  {
    "country": "IT",
    "name": "Mattinata",
    "lat": "41.71112",
    "lng": "16.05087"
  },
  {
    "country": "IT",
    "name": "Mattarello",
    "lat": "46.00865",
    "lng": "11.12984"
  },
  {
    "country": "IT",
    "name": "Matrice",
    "lat": "41.61878",
    "lng": "14.70977"
  },
  {
    "country": "IT",
    "name": "Matino",
    "lat": "40.03083",
    "lng": "18.1363"
  },
  {
    "country": "IT",
    "name": "Mathi",
    "lat": "45.25515",
    "lng": "7.54202"
  },
  {
    "country": "IT",
    "name": "Matera",
    "lat": "40.66599",
    "lng": "16.60463"
  },
  {
    "country": "IT",
    "name": "Matelica",
    "lat": "43.25788",
    "lng": "13.0075"
  },
  {
    "country": "IT",
    "name": "Massimeno",
    "lat": "46.1407",
    "lng": "10.77317"
  },
  {
    "country": "IT",
    "name": "Massignano",
    "lat": "43.05062",
    "lng": "13.79798"
  },
  {
    "country": "IT",
    "name": "Masserano",
    "lat": "45.59536",
    "lng": "8.22197"
  },
  {
    "country": "IT",
    "name": "Massenzatico",
    "lat": "44.73477",
    "lng": "10.69736"
  },
  {
    "country": "IT",
    "name": "Massello",
    "lat": "44.95874",
    "lng": "7.05671"
  },
  {
    "country": "IT",
    "name": "Massazza",
    "lat": "45.49183",
    "lng": "8.16495"
  },
  {
    "country": "IT",
    "name": "Massarosa",
    "lat": "43.86638",
    "lng": "10.34458"
  },
  {
    "country": "IT",
    "name": "Massa Martana",
    "lat": "42.77312",
    "lng": "12.52579"
  },
  {
    "country": "IT",
    "name": "Massa Marittima",
    "lat": "43.04779",
    "lng": "10.89293"
  },
  {
    "country": "IT",
    "name": "Massa Lubrense",
    "lat": "40.60937",
    "lng": "14.37202"
  },
  {
    "country": "IT",
    "name": "Massa Lombarda",
    "lat": "44.44703",
    "lng": "11.82095"
  },
  {
    "country": "IT",
    "name": "Massafra",
    "lat": "40.58618",
    "lng": "17.11635"
  },
  {
    "country": "IT",
    "name": "Massa Fiscaglia",
    "lat": "44.80983",
    "lng": "12.00746"
  },
  {
    "country": "IT",
    "name": "Massa Fermana",
    "lat": "43.14691",
    "lng": "13.47597"
  },
  {
    "country": "IT",
    "name": "Massa d'Albe-Corona",
    "lat": "42.10723",
    "lng": "13.39429"
  },
  {
    "country": "IT",
    "name": "Massa",
    "lat": "44.03541",
    "lng": "10.13927"
  },
  {
    "country": "IT",
    "name": "Massa",
    "lat": "43.90925",
    "lng": "10.74441"
  },
  {
    "country": "IT",
    "name": "Massa",
    "lat": "43.18803",
    "lng": "12.93142"
  },
  {
    "country": "IT",
    "name": "Masone",
    "lat": "44.50162",
    "lng": "8.71891"
  },
  {
    "country": "IT",
    "name": "Maslianico",
    "lat": "45.84301",
    "lng": "9.04836"
  },
  {
    "country": "IT",
    "name": "Masi-Torello",
    "lat": "44.79458",
    "lng": "11.80182"
  },
  {
    "country": "IT",
    "name": "Maserà di Padova",
    "lat": "45.31827",
    "lng": "11.86543"
  },
  {
    "country": "IT",
    "name": "Masera",
    "lat": "46.13888",
    "lng": "8.32526"
  },
  {
    "country": "IT",
    "name": "Maser",
    "lat": "45.8074",
    "lng": "11.975"
  },
  {
    "country": "IT",
    "name": "Maschito",
    "lat": "40.90892",
    "lng": "15.82946"
  },
  {
    "country": "IT",
    "name": "Marzio",
    "lat": "45.93818",
    "lng": "8.85813"
  },
  {
    "country": "IT",
    "name": "Marzano di Nola",
    "lat": "40.90141",
    "lng": "14.58359"
  },
  {
    "country": "IT",
    "name": "Marzano Appio",
    "lat": "41.31772",
    "lng": "14.04502"
  },
  {
    "country": "IT",
    "name": "Marzabotto",
    "lat": "44.34297",
    "lng": "11.20593"
  },
  {
    "country": "IT",
    "name": "Maruggio",
    "lat": "40.32054",
    "lng": "17.57052"
  },
  {
    "country": "IT",
    "name": "Martis",
    "lat": "40.77804",
    "lng": "8.80897"
  },
  {
    "country": "IT",
    "name": "Martinsicuro",
    "lat": "42.88031",
    "lng": "13.91326"
  },
  {
    "country": "IT",
    "name": "Martiniana Po",
    "lat": "44.62723",
    "lng": "7.36282"
  },
  {
    "country": "IT",
    "name": "Martinengo",
    "lat": "45.57216",
    "lng": "9.7675"
  },
  {
    "country": "IT",
    "name": "Urbe",
    "lat": "44.48714",
    "lng": "8.58615"
  },
  {
    "country": "IT",
    "name": "Martina Franca",
    "lat": "40.70355",
    "lng": "17.33814"
  },
  {
    "country": "IT",
    "name": "Martignano",
    "lat": "40.23821",
    "lng": "18.25602"
  },
  {
    "country": "IT",
    "name": "Martignacco",
    "lat": "46.09313",
    "lng": "13.13973"
  },
  {
    "country": "IT",
    "name": "Marti",
    "lat": "43.65453",
    "lng": "10.74058"
  },
  {
    "country": "IT",
    "name": "Martellago",
    "lat": "45.54383",
    "lng": "12.16363"
  },
  {
    "country": "IT",
    "name": "La Martella",
    "lat": "40.66251",
    "lng": "16.53551"
  },
  {
    "country": "IT",
    "name": "Martano",
    "lat": "40.20205",
    "lng": "18.30193"
  },
  {
    "country": "IT",
    "name": "Marta",
    "lat": "42.53318",
    "lng": "11.92423"
  },
  {
    "country": "IT",
    "name": "Marsicovetere",
    "lat": "40.37591",
    "lng": "15.82569"
  },
  {
    "country": "IT",
    "name": "Marsico Nuovo",
    "lat": "40.42359",
    "lng": "15.73462"
  },
  {
    "country": "IT",
    "name": "Marsia",
    "lat": "42.8603",
    "lng": "13.47619"
  },
  {
    "country": "IT",
    "name": "Marsciano",
    "lat": "42.92093",
    "lng": "12.35066"
  },
  {
    "country": "IT",
    "name": "Marsaglia",
    "lat": "44.71228",
    "lng": "9.38353"
  },
  {
    "country": "IT",
    "name": "Marradi",
    "lat": "44.07353",
    "lng": "11.61092"
  },
  {
    "country": "IT",
    "name": "Marotta",
    "lat": "43.76397",
    "lng": "13.14772"
  },
  {
    "country": "IT",
    "name": "Marostica",
    "lat": "45.74541",
    "lng": "11.66237"
  },
  {
    "country": "IT",
    "name": "Marone",
    "lat": "45.73719",
    "lng": "10.09579"
  },
  {
    "country": "IT",
    "name": "Marola",
    "lat": "45.53994",
    "lng": "11.62593"
  },
  {
    "country": "IT",
    "name": "Marnate",
    "lat": "45.62855",
    "lng": "8.90916"
  },
  {
    "country": "IT",
    "name": "Marmirolo",
    "lat": "45.21928",
    "lng": "10.75609"
  },
  {
    "country": "IT",
    "name": "Marliana",
    "lat": "43.93385",
    "lng": "10.77021"
  },
  {
    "country": "IT",
    "name": "Marlengo",
    "lat": "46.65262",
    "lng": "11.14546"
  },
  {
    "country": "IT",
    "name": "Mariotto",
    "lat": "41.05028",
    "lng": "16.56142"
  },
  {
    "country": "IT",
    "name": "Moriondo Torinese",
    "lat": "45.03853",
    "lng": "7.94086"
  },
  {
    "country": "IT",
    "name": "Marino",
    "lat": "41.76984",
    "lng": "12.65917"
  },
  {
    "country": "IT",
    "name": "Marina di San Vito",
    "lat": "42.30514",
    "lng": "14.44844"
  },
  {
    "country": "IT",
    "name": "Marina di Ravenna",
    "lat": "44.48625",
    "lng": "12.28087"
  },
  {
    "country": "IT",
    "name": "Marina di Pisa",
    "lat": "43.66667",
    "lng": "10.26667"
  },
  {
    "country": "IT",
    "name": "Marina di Montemarciano",
    "lat": "43.65063",
    "lng": "13.3364"
  },
  {
    "country": "IT",
    "name": "Marina di Grosseto",
    "lat": "42.71908",
    "lng": "10.98138"
  },
  {
    "country": "IT",
    "name": "Marina di Carrara",
    "lat": "44.03837",
    "lng": "10.04142"
  },
  {
    "country": "IT",
    "name": "Marina di Campo",
    "lat": "42.7426",
    "lng": "10.23428"
  },
  {
    "country": "IT",
    "name": "Marina di Andora",
    "lat": "43.95353",
    "lng": "8.1546"
  },
  {
    "country": "IT",
    "name": "Marigliano",
    "lat": "40.9248",
    "lng": "14.45612"
  },
  {
    "country": "IT",
    "name": "Mariglianella",
    "lat": "40.92962",
    "lng": "14.43703"
  },
  {
    "country": "IT",
    "name": "Mariano del Friuli",
    "lat": "45.91509",
    "lng": "13.45947"
  },
  {
    "country": "IT",
    "name": "Mariano Comense",
    "lat": "45.69651",
    "lng": "9.1818"
  },
  {
    "country": "IT",
    "name": "Margherita di Savoia",
    "lat": "41.37174",
    "lng": "16.15275"
  },
  {
    "country": "IT",
    "name": "Margarita",
    "lat": "44.40343",
    "lng": "7.68493"
  },
  {
    "country": "IT",
    "name": "Marene",
    "lat": "44.66113",
    "lng": "7.73436"
  },
  {
    "country": "IT",
    "name": "Mardimago",
    "lat": "45.10703",
    "lng": "11.83744"
  },
  {
    "country": "IT",
    "name": "Marcon-Gaggio-Colmello",
    "lat": "45.56444",
    "lng": "12.29889"
  },
  {
    "country": "IT",
    "name": "Marco",
    "lat": "45.84258",
    "lng": "11.00925"
  },
  {
    "country": "IT",
    "name": "Marcignana",
    "lat": "43.7183",
    "lng": "10.88436"
  },
  {
    "country": "IT",
    "name": "Marciano della Chiana",
    "lat": "43.30494",
    "lng": "11.78644"
  },
  {
    "country": "IT",
    "name": "Marcianise",
    "lat": "41.03064",
    "lng": "14.29868"
  },
  {
    "country": "IT",
    "name": "Marciana Marina",
    "lat": "42.80256",
    "lng": "10.19488"
  },
  {
    "country": "IT",
    "name": "Marciana",
    "lat": "42.79301",
    "lng": "10.1687"
  },
  {
    "country": "IT",
    "name": "Marcheno",
    "lat": "45.70649",
    "lng": "10.21449"
  },
  {
    "country": "IT",
    "name": "Marcetelli",
    "lat": "42.22663",
    "lng": "13.04589"
  },
  {
    "country": "IT",
    "name": "Marcellina",
    "lat": "42.02436",
    "lng": "12.80445"
  },
  {
    "country": "IT",
    "name": "Marcaria",
    "lat": "45.12225",
    "lng": "10.53278"
  },
  {
    "country": "IT",
    "name": "Marcallo",
    "lat": "45.48327",
    "lng": "8.87194"
  },
  {
    "country": "IT",
    "name": "Marano Vicentino",
    "lat": "45.696",
    "lng": "11.43237"
  },
  {
    "country": "IT",
    "name": "Marano Ticino",
    "lat": "45.62783",
    "lng": "8.63155"
  },
  {
    "country": "IT",
    "name": "Marano sul Panaro",
    "lat": "44.45924",
    "lng": "10.96879"
  },
  {
    "country": "IT",
    "name": "Marano Lagunare",
    "lat": "45.76353",
    "lng": "13.16733"
  },
  {
    "country": "IT",
    "name": "Maranola-Trivio",
    "lat": "41.28522",
    "lng": "13.62777"
  },
  {
    "country": "IT",
    "name": "Marano Equo",
    "lat": "41.99535",
    "lng": "13.01501"
  },
  {
    "country": "IT",
    "name": "Marano di Valpolicella",
    "lat": "45.55637",
    "lng": "10.91622"
  },
  {
    "country": "IT",
    "name": "Marano di Napoli",
    "lat": "40.8971",
    "lng": "14.18824"
  },
  {
    "country": "IT",
    "name": "Maranello",
    "lat": "44.53101",
    "lng": "10.86888"
  },
  {
    "country": "IT",
    "name": "Mara",
    "lat": "40.41019",
    "lng": "8.63664"
  },
  {
    "country": "IT",
    "name": "Mapello",
    "lat": "45.71259",
    "lng": "9.55443"
  },
  {
    "country": "IT",
    "name": "Manziana",
    "lat": "42.12998",
    "lng": "12.12537"
  },
  {
    "country": "IT",
    "name": "Manzano",
    "lat": "45.98843",
    "lng": "13.37674"
  },
  {
    "country": "IT",
    "name": "Mantova",
    "lat": "45.16031",
    "lng": "10.79784"
  },
  {
    "country": "IT",
    "name": "Mantignana",
    "lat": "43.15992",
    "lng": "12.28855"
  },
  {
    "country": "IT",
    "name": "Manta",
    "lat": "44.61583",
    "lng": "7.48703"
  },
  {
    "country": "IT",
    "name": "Mansuè",
    "lat": "45.82118",
    "lng": "12.5351"
  },
  {
    "country": "IT",
    "name": "Manoppello",
    "lat": "42.25918",
    "lng": "14.06024"
  },
  {
    "country": "IT",
    "name": "Manocalzati",
    "lat": "40.94151",
    "lng": "14.84767"
  },
  {
    "country": "IT",
    "name": "Maniago",
    "lat": "46.16644",
    "lng": "12.70602"
  },
  {
    "country": "IT",
    "name": "Mango",
    "lat": "44.68812",
    "lng": "8.14922"
  },
  {
    "country": "IT",
    "name": "Manfredonia",
    "lat": "41.63065",
    "lng": "15.91876"
  },
  {
    "country": "IT",
    "name": "Manerbio",
    "lat": "45.3539",
    "lng": "10.13803"
  },
  {
    "country": "IT",
    "name": "Manduria",
    "lat": "40.39899",
    "lng": "17.63726"
  },
  {
    "country": "IT",
    "name": "Mandello del Lario",
    "lat": "45.92199",
    "lng": "9.31974"
  },
  {
    "country": "IT",
    "name": "Mandela",
    "lat": "42.02795",
    "lng": "12.92089"
  },
  {
    "country": "IT",
    "name": "Manciano",
    "lat": "42.58875",
    "lng": "11.51806"
  },
  {
    "country": "IT",
    "name": "Mamoiada",
    "lat": "40.21487",
    "lng": "9.28189"
  },
  {
    "country": "IT",
    "name": "Malvicino",
    "lat": "44.55934",
    "lng": "8.41315"
  },
  {
    "country": "IT",
    "name": "Malonno",
    "lat": "46.12168",
    "lng": "10.31841"
  },
  {
    "country": "IT",
    "name": "Malo",
    "lat": "45.6591",
    "lng": "11.41601"
  },
  {
    "country": "IT",
    "name": "Malnate",
    "lat": "45.79377",
    "lng": "8.88104"
  },
  {
    "country": "IT",
    "name": "Malmantile",
    "lat": "43.74717",
    "lng": "11.07285"
  },
  {
    "country": "IT",
    "name": "Malles Venosta",
    "lat": "46.68791",
    "lng": "10.54655"
  },
  {
    "country": "IT",
    "name": "Malgrate",
    "lat": "45.84891",
    "lng": "9.3763"
  },
  {
    "country": "IT",
    "name": "Malesco",
    "lat": "46.128",
    "lng": "8.49801"
  },
  {
    "country": "IT",
    "name": "Maleo",
    "lat": "45.16633",
    "lng": "9.76241"
  },
  {
    "country": "IT",
    "name": "Malè",
    "lat": "46.35356",
    "lng": "10.91246"
  },
  {
    "country": "IT",
    "name": "Malcesine",
    "lat": "45.7614",
    "lng": "10.80863"
  },
  {
    "country": "IT",
    "name": "Malborghetto",
    "lat": "46.50679",
    "lng": "13.43946"
  },
  {
    "country": "IT",
    "name": "Malalbergo",
    "lat": "44.71867",
    "lng": "11.53221"
  },
  {
    "country": "IT",
    "name": "Maissana",
    "lat": "44.33675",
    "lng": "9.53588"
  },
  {
    "country": "IT",
    "name": "Mairano",
    "lat": "45.44802",
    "lng": "10.07977"
  },
  {
    "country": "IT",
    "name": "Mairano",
    "lat": "45.35794",
    "lng": "9.06939"
  },
  {
    "country": "IT",
    "name": "Maiori",
    "lat": "40.64848",
    "lng": "14.6407"
  },
  {
    "country": "IT",
    "name": "Serra di Maiolo",
    "lat": "43.87304",
    "lng": "12.31129"
  },
  {
    "country": "IT",
    "name": "Maiolati Spontini",
    "lat": "43.4764",
    "lng": "13.11991"
  },
  {
    "country": "IT",
    "name": "Magugnano",
    "lat": "45.70084",
    "lng": "10.76229"
  },
  {
    "country": "IT",
    "name": "Magreta",
    "lat": "44.6",
    "lng": "10.8"
  },
  {
    "country": "IT",
    "name": "Magomadas",
    "lat": "40.26321",
    "lng": "8.52327"
  },
  {
    "country": "IT",
    "name": "Magno",
    "lat": "45.70665",
    "lng": "10.19937"
  },
  {
    "country": "IT",
    "name": "Magnano in Riviera",
    "lat": "46.22369",
    "lng": "13.19483"
  },
  {
    "country": "IT",
    "name": "Magnago",
    "lat": "45.5792",
    "lng": "8.80245"
  },
  {
    "country": "IT",
    "name": "Magnacavallo",
    "lat": "45.00646",
    "lng": "11.18326"
  },
  {
    "country": "IT",
    "name": "Maglie",
    "lat": "40.12069",
    "lng": "18.29797"
  },
  {
    "country": "IT",
    "name": "Magliano Vetere",
    "lat": "40.34701",
    "lng": "15.23666"
  },
  {
    "country": "IT",
    "name": "Magliano Sabina",
    "lat": "42.36568",
    "lng": "12.4852"
  },
  {
    "country": "IT",
    "name": "Magliano Romano",
    "lat": "42.1575",
    "lng": "12.43662"
  },
  {
    "country": "IT",
    "name": "Magliano in Toscana",
    "lat": "42.59802",
    "lng": "11.29234"
  },
  {
    "country": "IT",
    "name": "Magliano di Tenna",
    "lat": "43.13795",
    "lng": "13.58718"
  },
  {
    "country": "IT",
    "name": "Magliano De'Marsi",
    "lat": "42.09153",
    "lng": "13.36379"
  },
  {
    "country": "IT",
    "name": "Magliano Alpi",
    "lat": "44.45808",
    "lng": "7.81926"
  },
  {
    "country": "IT",
    "name": "Magliano",
    "lat": "40.3374",
    "lng": "18.06287"
  },
  {
    "country": "IT",
    "name": "Magione",
    "lat": "43.14179",
    "lng": "12.21169"
  },
  {
    "country": "IT",
    "name": "Magenta",
    "lat": "45.46456",
    "lng": "8.88453"
  },
  {
    "country": "IT",
    "name": "Magasa",
    "lat": "45.78139",
    "lng": "10.61597"
  },
  {
    "country": "IT",
    "name": "Mafalda",
    "lat": "41.94308",
    "lng": "14.7161"
  },
  {
    "country": "IT",
    "name": "Maerne",
    "lat": "45.52313",
    "lng": "12.15477"
  },
  {
    "country": "IT",
    "name": "Maenza",
    "lat": "41.52402",
    "lng": "13.18344"
  },
  {
    "country": "IT",
    "name": "Madonna dell'Acqua",
    "lat": "43.74264",
    "lng": "10.37513"
  },
  {
    "country": "IT",
    "name": "Madignano",
    "lat": "45.34515",
    "lng": "9.72271"
  },
  {
    "country": "IT",
    "name": "Maddaloni",
    "lat": "41.03578",
    "lng": "14.3823"
  },
  {
    "country": "IT",
    "name": "Macugnaga",
    "lat": "45.96929",
    "lng": "7.96783"
  },
  {
    "country": "IT",
    "name": "Macomer",
    "lat": "40.26233",
    "lng": "8.76733"
  },
  {
    "country": "IT",
    "name": "Macere",
    "lat": "41.74873",
    "lng": "12.85835"
  },
  {
    "country": "IT",
    "name": "Macerata Feltria",
    "lat": "43.80285",
    "lng": "12.44204"
  },
  {
    "country": "IT",
    "name": "Macerata Campania",
    "lat": "41.06327",
    "lng": "14.2775"
  },
  {
    "country": "IT",
    "name": "Macerata",
    "lat": "43.29789",
    "lng": "13.45293"
  },
  {
    "country": "IT",
    "name": "Macchia Valfortore",
    "lat": "41.59487",
    "lng": "14.91238"
  },
  {
    "country": "IT",
    "name": "Macchiagodena",
    "lat": "41.55899",
    "lng": "14.41049"
  },
  {
    "country": "IT",
    "name": "Macchia d'Isernia",
    "lat": "41.56057",
    "lng": "14.17015"
  },
  {
    "country": "IT",
    "name": "Maccarese",
    "lat": "41.87696",
    "lng": "12.21975"
  },
  {
    "country": "IT",
    "name": "Maccagno",
    "lat": "46.04357",
    "lng": "8.73413"
  },
  {
    "country": "IT",
    "name": "Maccacari",
    "lat": "45.14276",
    "lng": "11.13499"
  },
  {
    "country": "IT",
    "name": "Luzzara",
    "lat": "44.95925",
    "lng": "10.68953"
  },
  {
    "country": "IT",
    "name": "Luzzano",
    "lat": "41.06818",
    "lng": "14.53611"
  },
  {
    "country": "IT",
    "name": "Luzzana",
    "lat": "45.7153",
    "lng": "9.88105"
  },
  {
    "country": "IT",
    "name": "Lustra",
    "lat": "40.2883",
    "lng": "15.06826"
  },
  {
    "country": "IT",
    "name": "Luson - Luesen",
    "lat": "46.74623",
    "lng": "11.76098"
  },
  {
    "country": "IT",
    "name": "Lusiana",
    "lat": "45.78428",
    "lng": "11.57478"
  },
  {
    "country": "IT",
    "name": "Lusia",
    "lat": "45.09848",
    "lng": "11.66511"
  },
  {
    "country": "IT",
    "name": "Lusevera",
    "lat": "46.27529",
    "lng": "13.26922"
  },
  {
    "country": "IT",
    "name": "Luserna",
    "lat": "44.80745",
    "lng": "7.24579"
  },
  {
    "country": "IT",
    "name": "Luserna",
    "lat": "45.9226",
    "lng": "11.32289"
  },
  {
    "country": "IT",
    "name": "Lurate Caccivio",
    "lat": "45.76701",
    "lng": "8.99897"
  },
  {
    "country": "IT",
    "name": "Luras",
    "lat": "40.93643",
    "lng": "9.1748"
  },
  {
    "country": "IT",
    "name": "Lurago Marinone",
    "lat": "45.70482",
    "lng": "8.9833"
  },
  {
    "country": "IT",
    "name": "Lurago d'Erba",
    "lat": "45.75097",
    "lng": "9.21817"
  },
  {
    "country": "IT",
    "name": "Lupara",
    "lat": "41.76141",
    "lng": "14.7339"
  },
  {
    "country": "IT",
    "name": "Luogosanto",
    "lat": "41.04681",
    "lng": "9.20553"
  },
  {
    "country": "IT",
    "name": "Luogosano",
    "lat": "40.98643",
    "lng": "14.99206"
  },
  {
    "country": "IT",
    "name": "Lungavilla",
    "lat": "45.04151",
    "lng": "9.07842"
  },
  {
    "country": "IT",
    "name": "Lunano",
    "lat": "43.73214",
    "lng": "12.44326"
  },
  {
    "country": "IT",
    "name": "Lumignano",
    "lat": "45.45968",
    "lng": "11.58786"
  },
  {
    "country": "IT",
    "name": "Lumellogno",
    "lat": "45.40801",
    "lng": "8.58787"
  },
  {
    "country": "IT",
    "name": "Lula",
    "lat": "40.47048",
    "lng": "9.48684"
  },
  {
    "country": "IT",
    "name": "Luino",
    "lat": "46.00185",
    "lng": "8.74512"
  },
  {
    "country": "IT",
    "name": "Lugugnana",
    "lat": "45.73277",
    "lng": "12.95958"
  },
  {
    "country": "IT",
    "name": "Stallavena-Lugo",
    "lat": "45.56289",
    "lng": "10.99669"
  },
  {
    "country": "IT",
    "name": "Lugo",
    "lat": "44.42137",
    "lng": "11.91094"
  },
  {
    "country": "IT",
    "name": "Lugnano in Teverina",
    "lat": "42.57592",
    "lng": "12.33336"
  },
  {
    "country": "IT",
    "name": "Lugagnano Val d'Arda",
    "lat": "44.82304",
    "lng": "9.82828"
  },
  {
    "country": "IT",
    "name": "Lugagnano",
    "lat": "45.43327",
    "lng": "10.88402"
  },
  {
    "country": "IT",
    "name": "Lucrezia",
    "lat": "43.7731",
    "lng": "12.93995"
  },
  {
    "country": "IT",
    "name": "Luco dei Marsi",
    "lat": "41.95925",
    "lng": "13.47349"
  },
  {
    "country": "IT",
    "name": "Lucito",
    "lat": "41.73193",
    "lng": "14.68723"
  },
  {
    "country": "IT",
    "name": "Montano Lucino",
    "lat": "45.78378",
    "lng": "9.04244"
  },
  {
    "country": "IT",
    "name": "Lucinasco",
    "lat": "43.96602",
    "lng": "7.96005"
  },
  {
    "country": "IT",
    "name": "Lucignano",
    "lat": "43.27259",
    "lng": "11.74599"
  },
  {
    "country": "IT",
    "name": "Lucera",
    "lat": "41.5055",
    "lng": "15.3391"
  },
  {
    "country": "IT",
    "name": "Lucca",
    "lat": "43.84369",
    "lng": "10.50447"
  },
  {
    "country": "IT",
    "name": "Lubriano",
    "lat": "42.63623",
    "lng": "12.10876"
  },
  {
    "country": "IT",
    "name": "Lu",
    "lat": "45.00184",
    "lng": "8.48561"
  },
  {
    "country": "IT",
    "name": "Lozzolo",
    "lat": "45.61894",
    "lng": "8.32284"
  },
  {
    "country": "IT",
    "name": "Lozzo di Cadore",
    "lat": "46.48644",
    "lng": "12.44493"
  },
  {
    "country": "IT",
    "name": "Lozzo Atestino",
    "lat": "45.29384",
    "lng": "11.60495"
  },
  {
    "country": "IT",
    "name": "Lovere",
    "lat": "45.81379",
    "lng": "10.06995"
  },
  {
    "country": "IT",
    "name": "Loseto",
    "lat": "41.04214",
    "lng": "16.84917"
  },
  {
    "country": "IT",
    "name": "Lorsica",
    "lat": "44.43415",
    "lng": "9.27677"
  },
  {
    "country": "IT",
    "name": "Loro Piceno",
    "lat": "43.16442",
    "lng": "13.41162"
  },
  {
    "country": "IT",
    "name": "Loro Ciuffenna",
    "lat": "43.58827",
    "lng": "11.62885"
  },
  {
    "country": "IT",
    "name": "Loria Bessica",
    "lat": "45.73",
    "lng": "11.8654"
  },
  {
    "country": "IT",
    "name": "Loreto Aprutino",
    "lat": "42.43104",
    "lng": "13.98057"
  },
  {
    "country": "IT",
    "name": "Loreto",
    "lat": "43.43617",
    "lng": "13.61232"
  },
  {
    "country": "IT",
    "name": "Loreo",
    "lat": "45.06213",
    "lng": "12.18812"
  },
  {
    "country": "IT",
    "name": "Lorenzana",
    "lat": "43.53533",
    "lng": "10.53477"
  },
  {
    "country": "IT",
    "name": "Lorenzago di Cadore",
    "lat": "46.47954",
    "lng": "12.45984"
  },
  {
    "country": "IT",
    "name": "Loreggiola",
    "lat": "45.60892",
    "lng": "11.91899"
  },
  {
    "country": "IT",
    "name": "Loreggia",
    "lat": "45.59733",
    "lng": "11.94769"
  },
  {
    "country": "IT",
    "name": "Loranzè",
    "lat": "45.44269",
    "lng": "7.81328"
  },
  {
    "country": "IT",
    "name": "Lonigo",
    "lat": "45.38576",
    "lng": "11.38402"
  },
  {
    "country": "IT",
    "name": "Longone Sabino",
    "lat": "42.2726",
    "lng": "12.96653"
  },
  {
    "country": "IT",
    "name": "Longiano",
    "lat": "44.07446",
    "lng": "12.3297"
  },
  {
    "country": "IT",
    "name": "Longastrino",
    "lat": "44.58848",
    "lng": "12.00982"
  },
  {
    "country": "IT",
    "name": "Longarone",
    "lat": "46.26579",
    "lng": "12.29992"
  },
  {
    "country": "IT",
    "name": "Longare",
    "lat": "45.47726",
    "lng": "11.60696"
  },
  {
    "country": "IT",
    "name": "Longano",
    "lat": "41.52199",
    "lng": "14.24665"
  },
  {
    "country": "IT",
    "name": "Londa",
    "lat": "43.86344",
    "lng": "11.56425"
  },
  {
    "country": "IT",
    "name": "Lonato",
    "lat": "45.46079",
    "lng": "10.47732"
  },
  {
    "country": "IT",
    "name": "Lonate Pozzolo",
    "lat": "45.59213",
    "lng": "8.75194"
  },
  {
    "country": "IT",
    "name": "Lonate Ceppino",
    "lat": "45.70863",
    "lng": "8.87936"
  },
  {
    "country": "IT",
    "name": "Lomello",
    "lat": "45.12001",
    "lng": "8.79612"
  },
  {
    "country": "IT",
    "name": "Lombardore",
    "lat": "45.2358",
    "lng": "7.73703"
  },
  {
    "country": "IT",
    "name": "Lomazzo",
    "lat": "45.6967",
    "lng": "9.03427"
  },
  {
    "country": "IT",
    "name": "Lomagna",
    "lat": "45.6664",
    "lng": "9.37654"
  },
  {
    "country": "IT",
    "name": "Loiri Porto San Paolo",
    "lat": "40.84262",
    "lng": "9.4982"
  },
  {
    "country": "IT",
    "name": "Loiano",
    "lat": "44.26806",
    "lng": "11.32841"
  },
  {
    "country": "IT",
    "name": "Lograto",
    "lat": "45.48458",
    "lng": "10.05664"
  },
  {
    "country": "IT",
    "name": "Lodi Vecchio",
    "lat": "45.30422",
    "lng": "9.4176"
  },
  {
    "country": "IT",
    "name": "Lodine",
    "lat": "40.14926",
    "lng": "9.21873"
  },
  {
    "country": "IT",
    "name": "Lodi",
    "lat": "45.30989",
    "lng": "9.50085"
  },
  {
    "country": "IT",
    "name": "Lodè",
    "lat": "40.59137",
    "lng": "9.53873"
  },
  {
    "country": "IT",
    "name": "Loculi",
    "lat": "40.40696",
    "lng": "9.61056"
  },
  {
    "country": "IT",
    "name": "Locorotondo",
    "lat": "40.75661",
    "lng": "17.32392"
  },
  {
    "country": "IT",
    "name": "Locate Varesino",
    "lat": "45.68969",
    "lng": "8.92992"
  },
  {
    "country": "IT",
    "name": "Locate di Triulzi",
    "lat": "45.35691",
    "lng": "9.22516"
  },
  {
    "country": "IT",
    "name": "Locana",
    "lat": "45.41419",
    "lng": "7.45712"
  },
  {
    "country": "IT",
    "name": "Loano",
    "lat": "44.12777",
    "lng": "8.25743"
  },
  {
    "country": "IT",
    "name": "Lizzano in Belvedere",
    "lat": "44.16135",
    "lng": "10.89408"
  },
  {
    "country": "IT",
    "name": "Lizzano",
    "lat": "40.39301",
    "lng": "17.44571"
  },
  {
    "country": "IT",
    "name": "Lizzanello",
    "lat": "40.30475",
    "lng": "18.22283"
  },
  {
    "country": "IT",
    "name": "Livorno Ferraris",
    "lat": "45.28271",
    "lng": "8.0778"
  },
  {
    "country": "IT",
    "name": "Livorno",
    "lat": "43.54427",
    "lng": "10.32615"
  },
  {
    "country": "IT",
    "name": "Livo",
    "lat": "46.40471",
    "lng": "11.01927"
  },
  {
    "country": "IT",
    "name": "Livo",
    "lat": "46.16849",
    "lng": "9.30414"
  },
  {
    "country": "IT",
    "name": "Livinallongo del Col di Lana",
    "lat": "46.48162",
    "lng": "11.95399"
  },
  {
    "country": "IT",
    "name": "Livigno",
    "lat": "46.5363",
    "lng": "10.13348"
  },
  {
    "country": "IT",
    "name": "Liveri",
    "lat": "40.90406",
    "lng": "14.56536"
  },
  {
    "country": "IT",
    "name": "Lissone",
    "lat": "45.61236",
    "lng": "9.23985"
  },
  {
    "country": "IT",
    "name": "Liscate",
    "lat": "45.48316",
    "lng": "9.4103"
  },
  {
    "country": "IT",
    "name": "Lioni",
    "lat": "40.88083",
    "lng": "15.18335"
  },
  {
    "country": "IT",
    "name": "Linate",
    "lat": "45.44701",
    "lng": "9.27229"
  },
  {
    "country": "IT",
    "name": "Limosano",
    "lat": "41.67554",
    "lng": "14.6223"
  },
  {
    "country": "IT",
    "name": "Limone sul Garda",
    "lat": "45.8145",
    "lng": "10.79278"
  },
  {
    "country": "IT",
    "name": "Limone Piemonte",
    "lat": "44.20091",
    "lng": "7.57861"
  },
  {
    "country": "IT",
    "name": "Limiti di Greccio",
    "lat": "42.45329",
    "lng": "12.76955"
  },
  {
    "country": "IT",
    "name": "Limite",
    "lat": "43.7445",
    "lng": "10.97996"
  },
  {
    "country": "IT",
    "name": "Limena",
    "lat": "45.46948",
    "lng": "11.84574"
  },
  {
    "country": "IT",
    "name": "Limbiate",
    "lat": "45.59951",
    "lng": "9.12509"
  },
  {
    "country": "IT",
    "name": "Limatola",
    "lat": "41.14012",
    "lng": "14.39437"
  },
  {
    "country": "IT",
    "name": "Lillianes",
    "lat": "45.62948",
    "lng": "7.84126"
  },
  {
    "country": "IT",
    "name": "Ligosullo",
    "lat": "46.54008",
    "lng": "13.07547"
  },
  {
    "country": "IT",
    "name": "Ligonchio",
    "lat": "44.31635",
    "lng": "10.34224"
  },
  {
    "country": "IT",
    "name": "Lignano Sabbiadoro",
    "lat": "45.6759",
    "lng": "13.11727"
  },
  {
    "country": "IT",
    "name": "Lignana",
    "lat": "45.28606",
    "lng": "8.34393"
  },
  {
    "country": "IT",
    "name": "Lierna",
    "lat": "45.95818",
    "lng": "9.30513"
  },
  {
    "country": "IT",
    "name": "Lido di Ostia",
    "lat": "41.73212",
    "lng": "12.27654"
  },
  {
    "country": "IT",
    "name": "Lido di Jesolo",
    "lat": "45.50694",
    "lng": "12.64694"
  },
  {
    "country": "IT",
    "name": "Lido",
    "lat": "45.4105",
    "lng": "12.36649"
  },
  {
    "country": "IT",
    "name": "Licusati",
    "lat": "40.0541",
    "lng": "15.36437"
  },
  {
    "country": "IT",
    "name": "Licenza",
    "lat": "42.07413",
    "lng": "12.90008"
  },
  {
    "country": "IT",
    "name": "Licciana Nardi",
    "lat": "44.26472",
    "lng": "10.03725"
  },
  {
    "country": "IT",
    "name": "Liberi",
    "lat": "41.22648",
    "lng": "14.28985"
  },
  {
    "country": "IT",
    "name": "Lezzeno",
    "lat": "45.94411",
    "lng": "9.18488"
  },
  {
    "country": "IT",
    "name": "Levico Terme",
    "lat": "46.01217",
    "lng": "11.30427"
  },
  {
    "country": "IT",
    "name": "Levice",
    "lat": "44.53824",
    "lng": "8.15504"
  },
  {
    "country": "IT",
    "name": "Leverano",
    "lat": "40.28852",
    "lng": "17.9965"
  },
  {
    "country": "IT",
    "name": "Levanto",
    "lat": "44.17424",
    "lng": "9.6167"
  },
  {
    "country": "IT",
    "name": "Levada",
    "lat": "45.73442",
    "lng": "12.47128"
  },
  {
    "country": "IT",
    "name": "Lettopalena",
    "lat": "42.00251",
    "lng": "14.15652"
  },
  {
    "country": "IT",
    "name": "Lettomanoppello",
    "lat": "42.24336",
    "lng": "14.03843"
  },
  {
    "country": "IT",
    "name": "Lestizza",
    "lat": "45.95656",
    "lng": "13.14221"
  },
  {
    "country": "IT",
    "name": "Lestans",
    "lat": "46.15793",
    "lng": "12.88872"
  },
  {
    "country": "IT",
    "name": "Lessona",
    "lat": "45.58693",
    "lng": "8.19433"
  },
  {
    "country": "IT",
    "name": "Lessolo",
    "lat": "45.47794",
    "lng": "7.81576"
  },
  {
    "country": "IT",
    "name": "Lesina",
    "lat": "41.86125",
    "lng": "15.35322"
  },
  {
    "country": "IT",
    "name": "Lesignano de'Bagni",
    "lat": "44.64346",
    "lng": "10.30039"
  },
  {
    "country": "IT",
    "name": "Lesegno",
    "lat": "44.4011",
    "lng": "7.96943"
  },
  {
    "country": "IT",
    "name": "Lesa",
    "lat": "45.82066",
    "lng": "8.55964"
  },
  {
    "country": "IT",
    "name": "Lerma",
    "lat": "44.63577",
    "lng": "8.71323"
  },
  {
    "country": "IT",
    "name": "Lerici",
    "lat": "44.07587",
    "lng": "9.91121"
  },
  {
    "country": "IT",
    "name": "Lequile",
    "lat": "40.30583",
    "lng": "18.14022"
  },
  {
    "country": "IT",
    "name": "Leporano",
    "lat": "40.38218",
    "lng": "17.33426"
  },
  {
    "country": "IT",
    "name": "Leonessa",
    "lat": "42.56855",
    "lng": "12.95996"
  },
  {
    "country": "IT",
    "name": "Lentigione-Sorbolo a Mane",
    "lat": "44.86667",
    "lng": "10.48333"
  },
  {
    "country": "IT",
    "name": "Lentiai",
    "lat": "46.04504",
    "lng": "12.02053"
  },
  {
    "country": "IT",
    "name": "Lentella",
    "lat": "41.99576",
    "lng": "14.67692"
  },
  {
    "country": "IT",
    "name": "Lentate sul Seveso",
    "lat": "45.67637",
    "lng": "9.11774"
  },
  {
    "country": "IT",
    "name": "Lenta",
    "lat": "45.55691",
    "lng": "8.38402"
  },
  {
    "country": "IT",
    "name": "Lenola",
    "lat": "41.40485",
    "lng": "13.45934"
  },
  {
    "country": "IT",
    "name": "Leno",
    "lat": "45.3693",
    "lng": "10.21675"
  },
  {
    "country": "IT",
    "name": "Lenno",
    "lat": "45.97298",
    "lng": "9.19084"
  },
  {
    "country": "IT",
    "name": "Lenna",
    "lat": "45.94273",
    "lng": "9.67876"
  },
  {
    "country": "IT",
    "name": "Lendinara",
    "lat": "45.08301",
    "lng": "11.60318"
  },
  {
    "country": "IT",
    "name": "Villa Lempa",
    "lat": "42.79345",
    "lng": "13.64433"
  },
  {
    "country": "IT",
    "name": "Lemie",
    "lat": "45.22866",
    "lng": "7.29248"
  },
  {
    "country": "IT",
    "name": "Leini",
    "lat": "45.18275",
    "lng": "7.71422"
  },
  {
    "country": "IT",
    "name": "Lei",
    "lat": "40.30641",
    "lng": "8.91858"
  },
  {
    "country": "IT",
    "name": "Le Grazie di Ancona",
    "lat": "43.60081",
    "lng": "13.51529"
  },
  {
    "country": "IT",
    "name": "Le Grazie",
    "lat": "44.06699",
    "lng": "9.83392"
  },
  {
    "country": "IT",
    "name": "Legnaro",
    "lat": "45.34238",
    "lng": "11.96482"
  },
  {
    "country": "IT",
    "name": "Legnano",
    "lat": "45.59788",
    "lng": "8.91506"
  },
  {
    "country": "IT",
    "name": "Legnago",
    "lat": "45.19365",
    "lng": "11.30227"
  },
  {
    "country": "IT",
    "name": "Leffe",
    "lat": "45.79793",
    "lng": "9.88426"
  },
  {
    "country": "IT",
    "name": "Lecco",
    "lat": "45.85589",
    "lng": "9.39704"
  },
  {
    "country": "IT",
    "name": "Lecce Nei Marsi",
    "lat": "41.93436",
    "lng": "13.6843"
  },
  {
    "country": "IT",
    "name": "Lecce",
    "lat": "40.35481",
    "lng": "18.17244"
  },
  {
    "country": "IT",
    "name": "Lazzeretto",
    "lat": "43.78305",
    "lng": "10.86054"
  },
  {
    "country": "IT",
    "name": "Lazise",
    "lat": "45.50499",
    "lng": "10.73923"
  },
  {
    "country": "IT",
    "name": "Lavis",
    "lat": "46.14131",
    "lng": "11.10931"
  },
  {
    "country": "IT",
    "name": "Laviano",
    "lat": "40.78619",
    "lng": "15.30791"
  },
  {
    "country": "IT",
    "name": "Lavezzola",
    "lat": "44.56099",
    "lng": "11.87557"
  },
  {
    "country": "IT",
    "name": "Lavenone",
    "lat": "45.73853",
    "lng": "10.4393"
  },
  {
    "country": "IT",
    "name": "Laveno",
    "lat": "45.90888",
    "lng": "8.62036"
  },
  {
    "country": "IT",
    "name": "Lavello",
    "lat": "41.04769",
    "lng": "15.78915"
  },
  {
    "country": "IT",
    "name": "La Valle Agordina",
    "lat": "46.28198",
    "lng": "12.06844"
  },
  {
    "country": "IT",
    "name": "Lavagna",
    "lat": "44.3062",
    "lng": "9.35383"
  },
  {
    "country": "IT",
    "name": "Lauzacco",
    "lat": "45.98134",
    "lng": "13.28024"
  },
  {
    "country": "IT",
    "name": "Lauro",
    "lat": "41.26365",
    "lng": "13.89059"
  },
  {
    "country": "IT",
    "name": "Lauro",
    "lat": "40.87972",
    "lng": "14.63013"
  },
  {
    "country": "IT",
    "name": "Laurito",
    "lat": "40.16915",
    "lng": "15.40741"
  },
  {
    "country": "IT",
    "name": "Laurino",
    "lat": "40.33915",
    "lng": "15.3381"
  },
  {
    "country": "IT",
    "name": "Lauriano",
    "lat": "45.15989",
    "lng": "7.99474"
  },
  {
    "country": "IT",
    "name": "Lauria",
    "lat": "40.04702",
    "lng": "15.83812"
  },
  {
    "country": "IT",
    "name": "Laurenzana",
    "lat": "40.45908",
    "lng": "15.97075"
  },
  {
    "country": "IT",
    "name": "Lauregno",
    "lat": "46.45431",
    "lng": "11.06177"
  },
  {
    "country": "IT",
    "name": "Laureana Cilento",
    "lat": "40.3011",
    "lng": "15.03876"
  },
  {
    "country": "IT",
    "name": "Lauco",
    "lat": "46.42397",
    "lng": "12.93222"
  },
  {
    "country": "IT",
    "name": "Latronico",
    "lat": "40.08909",
    "lng": "16.00947"
  },
  {
    "country": "IT",
    "name": "Latisana",
    "lat": "45.76859",
    "lng": "13.00618"
  },
  {
    "country": "IT",
    "name": "Latina",
    "lat": "41.46614",
    "lng": "12.9043"
  },
  {
    "country": "IT",
    "name": "Latiano",
    "lat": "40.55052",
    "lng": "17.71856"
  },
  {
    "country": "IT",
    "name": "La Thuile",
    "lat": "45.71366",
    "lng": "6.95099"
  },
  {
    "country": "IT",
    "name": "Laterza",
    "lat": "40.62881",
    "lng": "16.79947"
  },
  {
    "country": "IT",
    "name": "Laterina",
    "lat": "43.50193",
    "lng": "11.71737"
  },
  {
    "country": "IT",
    "name": "Latera",
    "lat": "42.62922",
    "lng": "11.82922"
  },
  {
    "country": "IT",
    "name": "Lastra a Signa",
    "lat": "43.76998",
    "lng": "11.11271"
  },
  {
    "country": "IT",
    "name": "Lastebasse",
    "lat": "45.9151",
    "lng": "11.27389"
  },
  {
    "country": "IT",
    "name": "La Spezia",
    "lat": "44.103",
    "lng": "9.82375"
  },
  {
    "country": "IT",
    "name": "Lasino",
    "lat": "46.0242",
    "lng": "10.98357"
  },
  {
    "country": "IT",
    "name": "La Salle",
    "lat": "45.74497",
    "lng": "7.07295"
  },
  {
    "country": "IT",
    "name": "Lasa",
    "lat": "46.61783",
    "lng": "10.69777"
  },
  {
    "country": "IT",
    "name": "Larino",
    "lat": "41.80449",
    "lng": "14.91843"
  },
  {
    "country": "IT",
    "name": "Lariano",
    "lat": "41.71847",
    "lng": "12.82868"
  },
  {
    "country": "IT",
    "name": "Lari",
    "lat": "43.56606",
    "lng": "10.59211"
  },
  {
    "country": "IT",
    "name": "Lardirago",
    "lat": "45.23572",
    "lng": "9.23272"
  },
  {
    "country": "IT",
    "name": "Lardaro",
    "lat": "45.96946",
    "lng": "10.66126"
  },
  {
    "country": "IT",
    "name": "L'Aquila",
    "lat": "42.35055",
    "lng": "13.39954"
  },
  {
    "country": "IT",
    "name": "Lapio",
    "lat": "40.98293",
    "lng": "14.9465"
  },
  {
    "country": "IT",
    "name": "Lapedona",
    "lat": "43.1092",
    "lng": "13.77063"
  },
  {
    "country": "IT",
    "name": "Panighina",
    "lat": "44.17162",
    "lng": "12.16324"
  },
  {
    "country": "IT",
    "name": "Lanzo Torinese",
    "lat": "45.27657",
    "lng": "7.48235"
  },
  {
    "country": "IT",
    "name": "Lanzo d'Intelvi",
    "lat": "45.97943",
    "lng": "9.02166"
  },
  {
    "country": "IT",
    "name": "Lanuvio",
    "lat": "41.67297",
    "lng": "12.69403"
  },
  {
    "country": "IT",
    "name": "Langosco",
    "lat": "45.21453",
    "lng": "8.56372"
  },
  {
    "country": "IT",
    "name": "Langhirano",
    "lat": "44.61913",
    "lng": "10.26652"
  },
  {
    "country": "IT",
    "name": "Landriano",
    "lat": "45.31155",
    "lng": "9.26046"
  },
  {
    "country": "IT",
    "name": "Landiona",
    "lat": "45.49703",
    "lng": "8.42224"
  },
  {
    "country": "IT",
    "name": "Lanciano",
    "lat": "42.22718",
    "lng": "14.39024"
  },
  {
    "country": "IT",
    "name": "Lana",
    "lat": "46.61209",
    "lng": "11.15653"
  },
  {
    "country": "IT",
    "name": "Lamporo",
    "lat": "45.23092",
    "lng": "8.09846"
  },
  {
    "country": "IT",
    "name": "Lamporecchio",
    "lat": "43.80742",
    "lng": "10.87733"
  },
  {
    "country": "IT",
    "name": "La Morra",
    "lat": "44.6379",
    "lng": "7.93078"
  },
  {
    "country": "IT",
    "name": "Lamon",
    "lat": "46.04717",
    "lng": "11.74991"
  },
  {
    "country": "IT",
    "name": "Lama",
    "lat": "44.30726",
    "lng": "10.7306"
  },
  {
    "country": "IT",
    "name": "La Magdeleine",
    "lat": "45.80996",
    "lng": "7.61871"
  },
  {
    "country": "IT",
    "name": "Lama dei Peligni",
    "lat": "42.04214",
    "lng": "14.18678"
  },
  {
    "country": "IT",
    "name": "La Maddalena",
    "lat": "41.21424",
    "lng": "9.40833"
  },
  {
    "country": "IT",
    "name": "Selci-Lama",
    "lat": "43.51719",
    "lng": "12.21293"
  },
  {
    "country": "IT",
    "name": "La Loggia",
    "lat": "44.95495",
    "lng": "7.66864"
  },
  {
    "country": "IT",
    "name": "Lallio",
    "lat": "45.66283",
    "lng": "9.62887"
  },
  {
    "country": "IT",
    "name": "Laives",
    "lat": "46.42679",
    "lng": "11.33841"
  },
  {
    "country": "IT",
    "name": "Laion",
    "lat": "46.60809",
    "lng": "11.56559"
  },
  {
    "country": "IT",
    "name": "Lainate",
    "lat": "45.57176",
    "lng": "9.02681"
  },
  {
    "country": "IT",
    "name": "Laigueglia",
    "lat": "43.9759",
    "lng": "8.15823"
  },
  {
    "country": "IT",
    "name": "Lajatico",
    "lat": "43.47457",
    "lng": "10.72844"
  },
  {
    "country": "IT",
    "name": "Lagundo",
    "lat": "46.68113",
    "lng": "11.12572"
  },
  {
    "country": "IT",
    "name": "Lagosanto",
    "lat": "44.76282",
    "lng": "12.14005"
  },
  {
    "country": "IT",
    "name": "Lagonegro",
    "lat": "40.12785",
    "lng": "15.76212"
  },
  {
    "country": "IT",
    "name": "Laglio",
    "lat": "45.88056",
    "lng": "9.13697"
  },
  {
    "country": "IT",
    "name": "Giudecca",
    "lat": "45.42477",
    "lng": "12.32906"
  },
  {
    "country": "IT",
    "name": "Laghetti",
    "lat": "46.27473",
    "lng": "11.24011"
  },
  {
    "country": "IT",
    "name": "Laerru",
    "lat": "40.81705",
    "lng": "8.8365"
  },
  {
    "country": "IT",
    "name": "Ladispoli",
    "lat": "41.95068",
    "lng": "12.075"
  },
  {
    "country": "IT",
    "name": "Laces",
    "lat": "46.61641",
    "lng": "10.85726"
  },
  {
    "country": "IT",
    "name": "Lacedonia",
    "lat": "41.05022",
    "lng": "15.42169"
  },
  {
    "country": "IT",
    "name": "Lacco Ameno",
    "lat": "40.74901",
    "lng": "13.88718"
  },
  {
    "country": "IT",
    "name": "Lacchiarella",
    "lat": "45.3229",
    "lng": "9.13777"
  },
  {
    "country": "IT",
    "name": "Casinina",
    "lat": "43.81667",
    "lng": "12.58333"
  },
  {
    "country": "IT",
    "name": "Cappelletta",
    "lat": "45.10514",
    "lng": "10.77847"
  },
  {
    "country": "IT",
    "name": "Labro",
    "lat": "42.52603",
    "lng": "12.80068"
  },
  {
    "country": "IT",
    "name": "Labico",
    "lat": "41.7926",
    "lng": "12.87127"
  },
  {
    "country": "IT",
    "name": "Izano",
    "lat": "45.35552",
    "lng": "9.75138"
  },
  {
    "country": "IT",
    "name": "Ivrea",
    "lat": "45.46723",
    "lng": "7.87617"
  },
  {
    "country": "IT",
    "name": "Ittiri",
    "lat": "40.59151",
    "lng": "8.56976"
  },
  {
    "country": "IT",
    "name": "Ittireddu",
    "lat": "40.54398",
    "lng": "8.90118"
  },
  {
    "country": "IT",
    "name": "Itri",
    "lat": "41.29034",
    "lng": "13.53"
  },
  {
    "country": "IT",
    "name": "Istrana",
    "lat": "45.67691",
    "lng": "12.10119"
  },
  {
    "country": "IT",
    "name": "Istia D'Ombrone-Le Stiacciole",
    "lat": "42.78243",
    "lng": "11.1882"
  },
  {
    "country": "IT",
    "name": "Issogne",
    "lat": "45.65496",
    "lng": "7.68571"
  },
  {
    "country": "IT",
    "name": "Issime",
    "lat": "45.68546",
    "lng": "7.85411"
  },
  {
    "country": "IT",
    "name": "Ispra",
    "lat": "45.8148",
    "lng": "8.61294"
  },
  {
    "country": "IT",
    "name": "Isorella",
    "lat": "45.30912",
    "lng": "10.32281"
  },
  {
    "country": "IT",
    "name": "Isola Vicentina",
    "lat": "45.6293",
    "lng": "11.44608"
  },
  {
    "country": "IT",
    "name": "Isola Sant'Antonio",
    "lat": "45.03019",
    "lng": "8.84928"
  },
  {
    "country": "IT",
    "name": "Isola Dovarese",
    "lat": "45.17292",
    "lng": "10.30879"
  },
  {
    "country": "IT",
    "name": "Isola del Piano",
    "lat": "43.73776",
    "lng": "12.78406"
  },
  {
    "country": "IT",
    "name": "Isola del Liri",
    "lat": "41.68678",
    "lng": "13.59679"
  },
  {
    "country": "IT",
    "name": "Isola della Scala",
    "lat": "45.26943",
    "lng": "11.00824"
  },
  {
    "country": "IT",
    "name": "Isola del Gran Sasso d'Italia",
    "lat": "42.50324",
    "lng": "13.65721"
  },
  {
    "country": "IT",
    "name": "Isola del Cantone",
    "lat": "44.64783",
    "lng": "8.95746"
  },
  {
    "country": "IT",
    "name": "Isolabona",
    "lat": "43.88076",
    "lng": "7.63993"
  },
  {
    "country": "IT",
    "name": "Isola D'Arbia",
    "lat": "43.25864",
    "lng": "11.37866"
  },
  {
    "country": "IT",
    "name": "Isernia",
    "lat": "41.59603",
    "lng": "14.23399"
  },
  {
    "country": "IT",
    "name": "Iseo",
    "lat": "45.65883",
    "lng": "10.05024"
  },
  {
    "country": "IT",
    "name": "Ischitella",
    "lat": "41.90434",
    "lng": "15.89945"
  },
  {
    "country": "IT",
    "name": "Ischia Porto",
    "lat": "40.73913",
    "lng": "13.951"
  },
  {
    "country": "IT",
    "name": "Ischia di Castro",
    "lat": "42.5442",
    "lng": "11.75759"
  },
  {
    "country": "IT",
    "name": "Ischia",
    "lat": "40.73793",
    "lng": "13.94862"
  },
  {
    "country": "IT",
    "name": "Irsina",
    "lat": "40.75015",
    "lng": "16.23816"
  },
  {
    "country": "IT",
    "name": "Irgoli",
    "lat": "40.40999",
    "lng": "9.63135"
  },
  {
    "country": "IT",
    "name": "Jolanda di Savoia",
    "lat": "44.88319",
    "lng": "11.9791"
  },
  {
    "country": "IT",
    "name": "Inzago",
    "lat": "45.53991",
    "lng": "9.48343"
  },
  {
    "country": "IT",
    "name": "Invorio",
    "lat": "45.75679",
    "lng": "8.48741"
  },
  {
    "country": "IT",
    "name": "Inveruno",
    "lat": "45.51399",
    "lng": "8.84954"
  },
  {
    "country": "IT",
    "name": "Inverno",
    "lat": "45.19859",
    "lng": "9.38429"
  },
  {
    "country": "IT",
    "name": "Inverigo",
    "lat": "45.73795",
    "lng": "9.21836"
  },
  {
    "country": "IT",
    "name": "Introdacqua",
    "lat": "42.00968",
    "lng": "13.89779"
  },
  {
    "country": "IT",
    "name": "Introbio",
    "lat": "45.97387",
    "lng": "9.44998"
  },
  {
    "country": "IT",
    "name": "Pallanza-Intra-Suna",
    "lat": "45.93778",
    "lng": "8.57088"
  },
  {
    "country": "IT",
    "name": "Ingria",
    "lat": "45.4665",
    "lng": "7.57119"
  },
  {
    "country": "IT",
    "name": "Induno Olona",
    "lat": "45.84571",
    "lng": "8.84056"
  },
  {
    "country": "IT",
    "name": "Incisa in Val d'Arno",
    "lat": "43.6548",
    "lng": "11.44901"
  },
  {
    "country": "IT",
    "name": "Impruneta",
    "lat": "43.68453",
    "lng": "11.25434"
  },
  {
    "country": "IT",
    "name": "Imperia",
    "lat": "43.88917",
    "lng": "8.03933"
  },
  {
    "country": "IT",
    "name": "Imola",
    "lat": "44.35916",
    "lng": "11.7132"
  },
  {
    "country": "IT",
    "name": "Illorai",
    "lat": "40.35271",
    "lng": "9.0017"
  },
  {
    "country": "IT",
    "name": "Illasi",
    "lat": "45.46663",
    "lng": "11.18165"
  },
  {
    "country": "IT",
    "name": "Capitello",
    "lat": "45.20792",
    "lng": "11.14014"
  },
  {
    "country": "IT",
    "name": "Barba",
    "lat": "43.88291",
    "lng": "10.97608"
  },
  {
    "country": "IT",
    "name": "Iesolo",
    "lat": "45.53311",
    "lng": "12.64475"
  },
  {
    "country": "IT",
    "name": "Jesi",
    "lat": "43.52142",
    "lng": "13.24368"
  },
  {
    "country": "IT",
    "name": "Jelsi",
    "lat": "41.51704",
    "lng": "14.7979"
  },
  {
    "country": "IT",
    "name": "Ialmicco",
    "lat": "45.91333",
    "lng": "13.34611"
  },
  {
    "country": "IT",
    "name": "Borgo Hermada",
    "lat": "41.30559",
    "lng": "13.17235"
  },
  {
    "country": "IT",
    "name": "Gussola",
    "lat": "45.01165",
    "lng": "10.34894"
  },
  {
    "country": "IT",
    "name": "Gussago",
    "lat": "45.58358",
    "lng": "10.15717"
  },
  {
    "country": "IT",
    "name": "Guilmi",
    "lat": "41.99653",
    "lng": "14.47882"
  },
  {
    "country": "IT",
    "name": "Guiglia",
    "lat": "44.42432",
    "lng": "10.96125"
  },
  {
    "country": "IT",
    "name": "Guidonia",
    "lat": "41.99232",
    "lng": "12.71876"
  },
  {
    "country": "IT",
    "name": "Guidizzolo",
    "lat": "45.32056",
    "lng": "10.57801"
  },
  {
    "country": "IT",
    "name": "Guglionesi",
    "lat": "41.92093",
    "lng": "14.916"
  },
  {
    "country": "IT",
    "name": "Gubbio",
    "lat": "43.34996",
    "lng": "12.57309"
  },
  {
    "country": "IT",
    "name": "Guazzora",
    "lat": "45.01392",
    "lng": "8.84822"
  },
  {
    "country": "IT",
    "name": "Guazzino",
    "lat": "43.21276",
    "lng": "11.78209"
  },
  {
    "country": "IT",
    "name": "Guasticce",
    "lat": "43.59805",
    "lng": "10.40865"
  },
  {
    "country": "IT",
    "name": "Guastalla",
    "lat": "44.91172",
    "lng": "10.66186"
  },
  {
    "country": "IT",
    "name": "Guardistallo",
    "lat": "43.31408",
    "lng": "10.62944"
  },
  {
    "country": "IT",
    "name": "Guardia Sanframondi",
    "lat": "41.2564",
    "lng": "14.59851"
  },
  {
    "country": "IT",
    "name": "Guardiaregia",
    "lat": "41.43436",
    "lng": "14.54344"
  },
  {
    "country": "IT",
    "name": "Guardia Perticara",
    "lat": "40.36167",
    "lng": "16.09845"
  },
  {
    "country": "IT",
    "name": "Guardia Lombardi",
    "lat": "40.95177",
    "lng": "15.20878"
  },
  {
    "country": "IT",
    "name": "Guardialfiera",
    "lat": "41.80423",
    "lng": "14.79293"
  },
  {
    "country": "IT",
    "name": "Guardiagrele",
    "lat": "42.19406",
    "lng": "14.21939"
  },
  {
    "country": "IT",
    "name": "Guardea",
    "lat": "42.6237",
    "lng": "12.29928"
  },
  {
    "country": "IT",
    "name": "Guarda Veneta",
    "lat": "44.98188",
    "lng": "11.80178"
  },
  {
    "country": "IT",
    "name": "Guardamiglio",
    "lat": "45.10742",
    "lng": "9.68481"
  },
  {
    "country": "IT",
    "name": "Guarcino",
    "lat": "41.79917",
    "lng": "13.31439"
  },
  {
    "country": "IT",
    "name": "Gualtieri",
    "lat": "44.89736",
    "lng": "10.6286"
  },
  {
    "country": "IT",
    "name": "Gualdo Tadino",
    "lat": "43.22941",
    "lng": "12.77862"
  },
  {
    "country": "IT",
    "name": "Gualdo Cattaneo",
    "lat": "42.91228",
    "lng": "12.55666"
  },
  {
    "country": "IT",
    "name": "Guagnano",
    "lat": "40.40123",
    "lng": "17.94902"
  },
  {
    "country": "IT",
    "name": "Grumo Nevano",
    "lat": "40.93591",
    "lng": "14.25983"
  },
  {
    "country": "IT",
    "name": "Grumolo Pedemonte",
    "lat": "45.7243",
    "lng": "11.49236"
  },
  {
    "country": "IT",
    "name": "Grumolo delle Abbadesse",
    "lat": "45.51692",
    "lng": "11.67198"
  },
  {
    "country": "IT",
    "name": "Grumo Appula",
    "lat": "41.01089",
    "lng": "16.70844"
  },
  {
    "country": "IT",
    "name": "Grumes",
    "lat": "46.22117",
    "lng": "11.29346"
  },
  {
    "country": "IT",
    "name": "Grumento Nova",
    "lat": "40.28281",
    "lng": "15.88877"
  },
  {
    "country": "IT",
    "name": "Grumello del Monte",
    "lat": "45.63535",
    "lng": "9.87526"
  },
  {
    "country": "IT",
    "name": "Grumello Cremonese",
    "lat": "45.19415",
    "lng": "9.86443"
  },
  {
    "country": "IT",
    "name": "Grugliasco",
    "lat": "45.06516",
    "lng": "7.57954"
  },
  {
    "country": "IT",
    "name": "Gruaro",
    "lat": "45.83472",
    "lng": "12.84111"
  },
  {
    "country": "IT",
    "name": "Grottolella",
    "lat": "40.97144",
    "lng": "14.78894"
  },
  {
    "country": "IT",
    "name": "Grottole",
    "lat": "40.60333",
    "lng": "16.37831"
  },
  {
    "country": "IT",
    "name": "Grotte Santo Stefano",
    "lat": "42.51691",
    "lng": "12.17226"
  },
  {
    "country": "IT",
    "name": "Grotte di Castro",
    "lat": "42.67567",
    "lng": "11.86908"
  },
  {
    "country": "IT",
    "name": "Grottazzolina",
    "lat": "43.1188",
    "lng": "13.60691"
  },
  {
    "country": "IT",
    "name": "Grottammare",
    "lat": "42.98182",
    "lng": "13.86765"
  },
  {
    "country": "IT",
    "name": "Grottaminarda",
    "lat": "41.06972",
    "lng": "15.05894"
  },
  {
    "country": "IT",
    "name": "Grottaglie",
    "lat": "40.53694",
    "lng": "17.43723"
  },
  {
    "country": "IT",
    "name": "Grottaferrata",
    "lat": "41.78664",
    "lng": "12.67144"
  },
  {
    "country": "IT",
    "name": "Grosseto",
    "lat": "42.76296",
    "lng": "11.10941"
  },
  {
    "country": "IT",
    "name": "Grosotto",
    "lat": "46.28196",
    "lng": "10.25908"
  },
  {
    "country": "IT",
    "name": "Grosio",
    "lat": "46.2997",
    "lng": "10.27572"
  },
  {
    "country": "IT",
    "name": "Groscavallo",
    "lat": "45.36805",
    "lng": "7.25801"
  },
  {
    "country": "IT",
    "name": "Gropparello",
    "lat": "44.83354",
    "lng": "9.72801"
  },
  {
    "country": "IT",
    "name": "Gropello Cairoli",
    "lat": "45.17707",
    "lng": "8.99353"
  },
  {
    "country": "IT",
    "name": "Grontardo",
    "lat": "45.20136",
    "lng": "10.1515"
  },
  {
    "country": "IT",
    "name": "Gromo",
    "lat": "45.9619",
    "lng": "9.92637"
  },
  {
    "country": "IT",
    "name": "Gromlongo",
    "lat": "45.72895",
    "lng": "9.54097"
  },
  {
    "country": "IT",
    "name": "Grizzana Morandi",
    "lat": "44.2582",
    "lng": "11.15288"
  },
  {
    "country": "IT",
    "name": "Grisignano di Zocco",
    "lat": "45.48681",
    "lng": "11.70794"
  },
  {
    "country": "IT",
    "name": "Grigno",
    "lat": "46.01569",
    "lng": "11.63563"
  },
  {
    "country": "IT",
    "name": "Grignasco",
    "lat": "45.67982",
    "lng": "8.34442"
  },
  {
    "country": "IT",
    "name": "Gricignano di Aversa",
    "lat": "40.97973",
    "lng": "14.23087"
  },
  {
    "country": "IT",
    "name": "Griante",
    "lat": "45.99528",
    "lng": "9.23554"
  },
  {
    "country": "IT",
    "name": "Grezzana",
    "lat": "45.52272",
    "lng": "11.01743"
  },
  {
    "country": "IT",
    "name": "Greve in Chianti",
    "lat": "43.58514",
    "lng": "11.31712"
  },
  {
    "country": "IT",
    "name": "Gressoney-Saint-Jean",
    "lat": "45.77272",
    "lng": "7.82802"
  },
  {
    "country": "IT",
    "name": "Gressoney-La-Trinitè",
    "lat": "45.82967",
    "lng": "7.82321"
  },
  {
    "country": "IT",
    "name": "Gressan",
    "lat": "45.7205",
    "lng": "7.29311"
  },
  {
    "country": "IT",
    "name": "Fontane-Zurane-Gresine",
    "lat": "45.63336",
    "lng": "10.0472"
  },
  {
    "country": "IT",
    "name": "Greggio",
    "lat": "45.45148",
    "lng": "8.38494"
  },
  {
    "country": "IT",
    "name": "Greci",
    "lat": "41.25182",
    "lng": "15.16915"
  },
  {
    "country": "IT",
    "name": "Grazzano Badoglio",
    "lat": "45.03996",
    "lng": "8.31105"
  },
  {
    "country": "IT",
    "name": "Grazzanise",
    "lat": "41.0897",
    "lng": "14.09878"
  },
  {
    "country": "IT",
    "name": "Gravina in Puglia",
    "lat": "40.81748",
    "lng": "16.41915"
  },
  {
    "country": "IT",
    "name": "Gravellona Toce",
    "lat": "45.92859",
    "lng": "8.43209"
  },
  {
    "country": "IT",
    "name": "Gravellona",
    "lat": "45.32766",
    "lng": "8.76414"
  },
  {
    "country": "IT",
    "name": "Gravedona-San Gregorio",
    "lat": "46.14639",
    "lng": "9.30094"
  },
  {
    "country": "IT",
    "name": "Cravagliana",
    "lat": "45.84827",
    "lng": "8.20182"
  },
  {
    "country": "IT",
    "name": "Grauno",
    "lat": "46.23032",
    "lng": "11.29847"
  },
  {
    "country": "IT",
    "name": "Gratacasolo",
    "lat": "45.82897",
    "lng": "10.12918"
  },
  {
    "country": "IT",
    "name": "Grassano",
    "lat": "40.63457",
    "lng": "16.27792"
  },
  {
    "country": "IT",
    "name": "Granze",
    "lat": "45.15649",
    "lng": "11.71471"
  },
  {
    "country": "IT",
    "name": "Grantorto",
    "lat": "45.60268",
    "lng": "11.73175"
  },
  {
    "country": "IT",
    "name": "Granozzo con Monticello",
    "lat": "45.36016",
    "lng": "8.57334"
  },
  {
    "country": "IT",
    "name": "Grandate",
    "lat": "45.76715",
    "lng": "9.05349"
  },
  {
    "country": "IT",
    "name": "Gragnano Trebbiense",
    "lat": "45.01225",
    "lng": "9.57139"
  },
  {
    "country": "IT",
    "name": "Gragnano",
    "lat": "40.68907",
    "lng": "14.52036"
  },
  {
    "country": "IT",
    "name": "Graglia",
    "lat": "45.558",
    "lng": "7.97899"
  },
  {
    "country": "IT",
    "name": "Graffignano",
    "lat": "42.57539",
    "lng": "12.20121"
  },
  {
    "country": "IT",
    "name": "Gradoli",
    "lat": "42.64502",
    "lng": "11.8558"
  },
  {
    "country": "IT",
    "name": "Grado",
    "lat": "45.67774",
    "lng": "13.40323"
  },
  {
    "country": "IT",
    "name": "Gradisca d'Isonzo",
    "lat": "45.8925",
    "lng": "13.50167"
  },
  {
    "country": "IT",
    "name": "Gradara",
    "lat": "43.93858",
    "lng": "12.76965"
  },
  {
    "country": "IT",
    "name": "Gozzano",
    "lat": "45.74273",
    "lng": "8.43659"
  },
  {
    "country": "IT",
    "name": "Gottolengo",
    "lat": "45.29278",
    "lng": "10.26855"
  },
  {
    "country": "IT",
    "name": "Gossolengo",
    "lat": "45.00248",
    "lng": "9.61799"
  },
  {
    "country": "IT",
    "name": "Gosaldo",
    "lat": "46.22142",
    "lng": "11.9557"
  },
  {
    "country": "IT",
    "name": "Gorzegno",
    "lat": "44.51236",
    "lng": "8.1348"
  },
  {
    "country": "IT",
    "name": "Gorreto",
    "lat": "44.60485",
    "lng": "9.29126"
  },
  {
    "country": "IT",
    "name": "Goro",
    "lat": "44.8515",
    "lng": "12.29651"
  },
  {
    "country": "IT",
    "name": "Gorno",
    "lat": "45.86249",
    "lng": "9.84155"
  },
  {
    "country": "IT",
    "name": "Gorle",
    "lat": "45.70127",
    "lng": "9.71382"
  },
  {
    "country": "IT",
    "name": "Gorla Maggiore",
    "lat": "45.66388",
    "lng": "8.89537"
  },
  {
    "country": "IT",
    "name": "Gorizia",
    "lat": "45.94088",
    "lng": "13.62167"
  },
  {
    "country": "IT",
    "name": "Goriano Sicoli",
    "lat": "42.08011",
    "lng": "13.77459"
  },
  {
    "country": "IT",
    "name": "Gorgonzola",
    "lat": "45.53069",
    "lng": "9.40531"
  },
  {
    "country": "IT",
    "name": "Gorgoglione",
    "lat": "40.39532",
    "lng": "16.14456"
  },
  {
    "country": "IT",
    "name": "Gorga",
    "lat": "41.65468",
    "lng": "13.10663"
  },
  {
    "country": "IT",
    "name": "Gordona",
    "lat": "46.29176",
    "lng": "9.367"
  },
  {
    "country": "IT",
    "name": "Gonzaga",
    "lat": "44.95193",
    "lng": "10.81913"
  },
  {
    "country": "IT",
    "name": "Gonars",
    "lat": "45.8974",
    "lng": "13.24402"
  },
  {
    "country": "IT",
    "name": "Golfo Aranci",
    "lat": "40.98333",
    "lng": "9.63333"
  },
  {
    "country": "IT",
    "name": "Golasecca",
    "lat": "45.69821",
    "lng": "8.66112"
  },
  {
    "country": "IT",
    "name": "Goito",
    "lat": "45.25076",
    "lng": "10.66121"
  },
  {
    "country": "IT",
    "name": "Godo",
    "lat": "44.39173",
    "lng": "12.07495"
  },
  {
    "country": "IT",
    "name": "Godiasco",
    "lat": "44.89645",
    "lng": "9.05667"
  },
  {
    "country": "IT",
    "name": "Godega",
    "lat": "45.92859",
    "lng": "12.39687"
  },
  {
    "country": "IT",
    "name": "Glorenza",
    "lat": "46.67105",
    "lng": "10.55684"
  },
  {
    "country": "IT",
    "name": "Giussano",
    "lat": "45.70004",
    "lng": "9.2089"
  },
  {
    "country": "IT",
    "name": "Giussago",
    "lat": "45.28417",
    "lng": "9.13996"
  },
  {
    "country": "IT",
    "name": "Giurdignano",
    "lat": "40.12367",
    "lng": "18.43155"
  },
  {
    "country": "IT",
    "name": "Giungano",
    "lat": "40.3945",
    "lng": "15.10792"
  },
  {
    "country": "IT",
    "name": "Giulianova",
    "lat": "42.75381",
    "lng": "13.9665"
  },
  {
    "country": "IT",
    "name": "Giuliano Teatino",
    "lat": "42.3122",
    "lng": "14.28082"
  },
  {
    "country": "IT",
    "name": "Giuliano di Roma",
    "lat": "41.53933",
    "lng": "13.28028"
  },
  {
    "country": "IT",
    "name": "Giulianello",
    "lat": "41.6861",
    "lng": "12.87917"
  },
  {
    "country": "IT",
    "name": "Giugliano in Campania",
    "lat": "40.92849",
    "lng": "14.20197"
  },
  {
    "country": "IT",
    "name": "Giuggianello",
    "lat": "40.09383",
    "lng": "18.36894"
  },
  {
    "country": "IT",
    "name": "Gissi",
    "lat": "42.01803",
    "lng": "14.54484"
  },
  {
    "country": "IT",
    "name": "Giovinazzo",
    "lat": "41.185",
    "lng": "16.67054"
  },
  {
    "country": "IT",
    "name": "Giove",
    "lat": "42.50988",
    "lng": "12.33015"
  },
  {
    "country": "IT",
    "name": "Gioia Sannitica",
    "lat": "41.29965",
    "lng": "14.44381"
  },
  {
    "country": "IT",
    "name": "Gioia del Colle",
    "lat": "40.79968",
    "lng": "16.92298"
  },
  {
    "country": "IT",
    "name": "Gioia dei Marsi",
    "lat": "41.95697",
    "lng": "13.69057"
  },
  {
    "country": "IT",
    "name": "Gioi",
    "lat": "40.2897",
    "lng": "15.21806"
  },
  {
    "country": "IT",
    "name": "Marina di Ginosa",
    "lat": "40.42833",
    "lng": "16.88003"
  },
  {
    "country": "IT",
    "name": "Ginosa",
    "lat": "40.5769",
    "lng": "16.75655"
  },
  {
    "country": "IT",
    "name": "Ginestra degli Schiavoni",
    "lat": "41.27992",
    "lng": "15.04374"
  },
  {
    "country": "IT",
    "name": "Ginestra Fiorentina",
    "lat": "43.70939",
    "lng": "11.07384"
  },
  {
    "country": "IT",
    "name": "Ginestra",
    "lat": "40.93092",
    "lng": "15.73497"
  },
  {
    "country": "IT",
    "name": "Gildone",
    "lat": "41.50901",
    "lng": "14.7402"
  },
  {
    "country": "IT",
    "name": "Gignese",
    "lat": "45.86396",
    "lng": "8.50943"
  },
  {
    "country": "IT",
    "name": "Giglio Castello",
    "lat": "42.36486",
    "lng": "10.9014"
  },
  {
    "country": "IT",
    "name": "Giffoni Valle Piana",
    "lat": "40.71811",
    "lng": "14.94235"
  },
  {
    "country": "IT",
    "name": "Giavera del Montello",
    "lat": "45.79374",
    "lng": "12.16667"
  },
  {
    "country": "IT",
    "name": "Giaveno",
    "lat": "45.04435",
    "lng": "7.34722"
  },
  {
    "country": "IT",
    "name": "Giave",
    "lat": "40.45224",
    "lng": "8.75175"
  },
  {
    "country": "IT",
    "name": "Giarole",
    "lat": "45.06148",
    "lng": "8.5673"
  },
  {
    "country": "IT",
    "name": "Giano Vetusto",
    "lat": "41.20272",
    "lng": "14.19342"
  },
  {
    "country": "IT",
    "name": "Giano dell'Umbria",
    "lat": "42.83384",
    "lng": "12.57777"
  },
  {
    "country": "IT",
    "name": "Piano di Coreglia-Ghivizzano",
    "lat": "44.03333",
    "lng": "10.51667"
  },
  {
    "country": "IT",
    "name": "Ghislarengo",
    "lat": "45.52856",
    "lng": "8.38514"
  },
  {
    "country": "IT",
    "name": "Ghisalba",
    "lat": "45.59354",
    "lng": "9.75765"
  },
  {
    "country": "IT",
    "name": "Ghilarza",
    "lat": "40.12119",
    "lng": "8.83612"
  },
  {
    "country": "IT",
    "name": "Ghiffa",
    "lat": "45.95298",
    "lng": "8.6043"
  },
  {
    "country": "IT",
    "name": "Ghemme",
    "lat": "45.59863",
    "lng": "8.42013"
  },
  {
    "country": "IT",
    "name": "Ghedi",
    "lat": "45.40204",
    "lng": "10.27681"
  },
  {
    "country": "IT",
    "name": "Gesualdo",
    "lat": "41.00554",
    "lng": "15.07262"
  },
  {
    "country": "IT",
    "name": "Gessopalena",
    "lat": "42.05521",
    "lng": "14.27367"
  },
  {
    "country": "IT",
    "name": "Quartiano",
    "lat": "45.358",
    "lng": "9.4176"
  },
  {
    "country": "IT",
    "name": "Gerosa",
    "lat": "45.8498",
    "lng": "9.57161"
  },
  {
    "country": "IT",
    "name": "Gerola Alta",
    "lat": "46.06003",
    "lng": "9.55025"
  },
  {
    "country": "IT",
    "name": "Germagnano",
    "lat": "45.26317",
    "lng": "7.46886"
  },
  {
    "country": "IT",
    "name": "Gerenzago",
    "lat": "45.20633",
    "lng": "9.36137"
  },
  {
    "country": "IT",
    "name": "Gerano",
    "lat": "41.93474",
    "lng": "12.99034"
  },
  {
    "country": "IT",
    "name": "Gera Lario",
    "lat": "46.17003",
    "lng": "9.36736"
  },
  {
    "country": "IT",
    "name": "Genzone",
    "lat": "45.17962",
    "lng": "9.34829"
  },
  {
    "country": "IT",
    "name": "Genzano di Roma",
    "lat": "41.70706",
    "lng": "12.68904"
  },
  {
    "country": "IT",
    "name": "Genzano di Lucania",
    "lat": "40.84589",
    "lng": "16.03124"
  },
  {
    "country": "IT",
    "name": "Genoa",
    "lat": "44.40478",
    "lng": "8.94439"
  },
  {
    "country": "IT",
    "name": "Genola",
    "lat": "44.59053",
    "lng": "7.66114"
  },
  {
    "country": "IT",
    "name": "Genivolta",
    "lat": "45.33257",
    "lng": "9.87726"
  },
  {
    "country": "IT",
    "name": "Genga",
    "lat": "43.43032",
    "lng": "12.93549"
  },
  {
    "country": "IT",
    "name": "Genazzano",
    "lat": "41.82807",
    "lng": "12.97196"
  },
  {
    "country": "IT",
    "name": "Gemonio",
    "lat": "45.87878",
    "lng": "8.67478"
  },
  {
    "country": "IT",
    "name": "Gemona",
    "lat": "46.27405",
    "lng": "13.12237"
  },
  {
    "country": "IT",
    "name": "Gemmano",
    "lat": "43.90393",
    "lng": "12.58091"
  },
  {
    "country": "IT",
    "name": "Gazzuolo",
    "lat": "45.06238",
    "lng": "10.57161"
  },
  {
    "country": "IT",
    "name": "Gazzo",
    "lat": "45.58241",
    "lng": "11.70724"
  },
  {
    "country": "IT",
    "name": "Gazzo",
    "lat": "45.17968",
    "lng": "10.89706"
  },
  {
    "country": "IT",
    "name": "Gazzaniga",
    "lat": "45.79339",
    "lng": "9.82976"
  },
  {
    "country": "IT",
    "name": "Gazoldo degli Ippoliti",
    "lat": "45.19999",
    "lng": "10.57839"
  },
  {
    "country": "IT",
    "name": "Gavorrano",
    "lat": "42.92526",
    "lng": "10.90681"
  },
  {
    "country": "IT",
    "name": "Gavoi",
    "lat": "40.1613",
    "lng": "9.19462"
  },
  {
    "country": "IT",
    "name": "Gavirate",
    "lat": "45.83707",
    "lng": "8.72619"
  },
  {
    "country": "IT",
    "name": "Gavignano",
    "lat": "41.69891",
    "lng": "13.05032"
  },
  {
    "country": "IT",
    "name": "Gavi",
    "lat": "44.68627",
    "lng": "8.80717"
  },
  {
    "country": "IT",
    "name": "Gavello",
    "lat": "45.02469",
    "lng": "11.91368"
  },
  {
    "country": "IT",
    "name": "Gavardo-Sopraponte",
    "lat": "45.58939",
    "lng": "10.44257"
  },
  {
    "country": "IT",
    "name": "Gattinara",
    "lat": "45.61309",
    "lng": "8.36463"
  },
  {
    "country": "IT",
    "name": "Gassino Torinese",
    "lat": "45.12907",
    "lng": "7.82934"
  },
  {
    "country": "IT",
    "name": "Garzeno",
    "lat": "46.13409",
    "lng": "9.24964"
  },
  {
    "country": "IT",
    "name": "Garlenda",
    "lat": "44.03325",
    "lng": "8.09546"
  },
  {
    "country": "IT",
    "name": "Garlasco",
    "lat": "45.1954",
    "lng": "8.92314"
  },
  {
    "country": "IT",
    "name": "Gargnano",
    "lat": "45.68586",
    "lng": "10.65869"
  },
  {
    "country": "IT",
    "name": "Gargazzone",
    "lat": "46.58456",
    "lng": "11.20156"
  },
  {
    "country": "IT",
    "name": "Garessio",
    "lat": "44.20705",
    "lng": "8.01778"
  },
  {
    "country": "IT",
    "name": "Gardone Val Trompia",
    "lat": "45.69137",
    "lng": "10.18635"
  },
  {
    "country": "IT",
    "name": "Gardone Riviera",
    "lat": "45.62396",
    "lng": "10.56682"
  },
  {
    "country": "IT",
    "name": "Garda",
    "lat": "45.57889",
    "lng": "10.71763"
  },
  {
    "country": "IT",
    "name": "Garbagnate Milanese",
    "lat": "45.57438",
    "lng": "9.07537"
  },
  {
    "country": "IT",
    "name": "Garaguso",
    "lat": "40.54866",
    "lng": "16.22827"
  },
  {
    "country": "IT",
    "name": "Garadassi",
    "lat": "44.75429",
    "lng": "9.15393"
  },
  {
    "country": "IT",
    "name": "Ganna",
    "lat": "45.90212",
    "lng": "8.82606"
  },
  {
    "country": "IT",
    "name": "Gandino",
    "lat": "45.81088",
    "lng": "9.89767"
  },
  {
    "country": "IT",
    "name": "Ganda",
    "lat": "46.55459",
    "lng": "10.78042"
  },
  {
    "country": "IT",
    "name": "Gambolò",
    "lat": "45.26209",
    "lng": "8.8582"
  },
  {
    "country": "IT",
    "name": "Gambettola",
    "lat": "44.11748",
    "lng": "12.33705"
  },
  {
    "country": "IT",
    "name": "Gamberale",
    "lat": "41.90529",
    "lng": "14.20845"
  },
  {
    "country": "IT",
    "name": "Gambatesa",
    "lat": "41.50861",
    "lng": "14.9124"
  },
  {
    "country": "IT",
    "name": "Gambassi Terme",
    "lat": "43.53576",
    "lng": "10.95161"
  },
  {
    "country": "IT",
    "name": "Gambasca",
    "lat": "44.6295",
    "lng": "7.34686"
  },
  {
    "country": "IT",
    "name": "Gambarana",
    "lat": "45.02874",
    "lng": "8.76282"
  },
  {
    "country": "IT",
    "name": "Gambara",
    "lat": "45.25366",
    "lng": "10.29434"
  },
  {
    "country": "IT",
    "name": "Gamalero",
    "lat": "44.8085",
    "lng": "8.54116"
  },
  {
    "country": "IT",
    "name": "Galzignano",
    "lat": "45.30798",
    "lng": "11.73134"
  },
  {
    "country": "IT",
    "name": "Galugnano",
    "lat": "40.25601",
    "lng": "18.21473"
  },
  {
    "country": "IT",
    "name": "Galtellì",
    "lat": "40.38451",
    "lng": "9.61241"
  },
  {
    "country": "IT",
    "name": "Galluccio",
    "lat": "41.35232",
    "lng": "13.95372"
  },
  {
    "country": "IT",
    "name": "Gallo",
    "lat": "44.73144",
    "lng": "11.55284"
  },
  {
    "country": "IT",
    "name": "Gallo Matese",
    "lat": "41.46452",
    "lng": "14.22502"
  },
  {
    "country": "IT",
    "name": "Gallipoli",
    "lat": "40.05594",
    "lng": "17.99088"
  },
  {
    "country": "IT",
    "name": "Gallio",
    "lat": "45.88506",
    "lng": "11.53417"
  },
  {
    "country": "IT",
    "name": "Gallinaro",
    "lat": "41.65502",
    "lng": "13.79799"
  },
  {
    "country": "IT",
    "name": "Galliera Veneta",
    "lat": "45.6675",
    "lng": "11.82217"
  },
  {
    "country": "IT",
    "name": "Gallicchio",
    "lat": "40.29232",
    "lng": "16.13561"
  },
  {
    "country": "IT",
    "name": "Gallicano nel Lazio",
    "lat": "41.86433",
    "lng": "12.83543"
  },
  {
    "country": "IT",
    "name": "Gallicano",
    "lat": "44.05833",
    "lng": "10.44209"
  },
  {
    "country": "IT",
    "name": "Galliate",
    "lat": "45.47942",
    "lng": "8.69815"
  },
  {
    "country": "IT",
    "name": "Gallese",
    "lat": "42.37376",
    "lng": "12.39646"
  },
  {
    "country": "IT",
    "name": "Gallarate",
    "lat": "45.66019",
    "lng": "8.79164"
  },
  {
    "country": "IT",
    "name": "Galeata",
    "lat": "43.99607",
    "lng": "11.91057"
  },
  {
    "country": "IT",
    "name": "Galbiate",
    "lat": "45.81635",
    "lng": "9.37902"
  },
  {
    "country": "IT",
    "name": "Galatone",
    "lat": "40.14673",
    "lng": "18.06937"
  },
  {
    "country": "IT",
    "name": "Galatina",
    "lat": "40.17416",
    "lng": "18.17032"
  },
  {
    "country": "IT",
    "name": "Gais",
    "lat": "46.83658",
    "lng": "11.94931"
  },
  {
    "country": "IT",
    "name": "Gaiole in Chianti",
    "lat": "43.46697",
    "lng": "11.43386"
  },
  {
    "country": "IT",
    "name": "Gaiola",
    "lat": "44.33554",
    "lng": "7.40896"
  },
  {
    "country": "IT",
    "name": "Gaibanella-Sant'Edigio",
    "lat": "44.76667",
    "lng": "11.65"
  },
  {
    "country": "IT",
    "name": "Gaiba",
    "lat": "44.94573",
    "lng": "11.48087"
  },
  {
    "country": "IT",
    "name": "Gaiarine",
    "lat": "45.88083",
    "lng": "12.48142"
  },
  {
    "country": "IT",
    "name": "Gagliole",
    "lat": "43.23812",
    "lng": "13.06782"
  },
  {
    "country": "IT",
    "name": "Gagliano Aterno",
    "lat": "42.12598",
    "lng": "13.70023"
  },
  {
    "country": "IT",
    "name": "Galliano",
    "lat": "44.01725",
    "lng": "11.29353"
  },
  {
    "country": "IT",
    "name": "Gaglianico",
    "lat": "45.53718",
    "lng": "8.07839"
  },
  {
    "country": "IT",
    "name": "Gaggio Montano",
    "lat": "44.19583",
    "lng": "10.93518"
  },
  {
    "country": "IT",
    "name": "Gaggio",
    "lat": "44.63458",
    "lng": "11.01334"
  },
  {
    "country": "IT",
    "name": "Gaggiano",
    "lat": "45.40484",
    "lng": "9.03488"
  },
  {
    "country": "IT",
    "name": "Gaeta",
    "lat": "41.21408",
    "lng": "13.57082"
  },
  {
    "country": "IT",
    "name": "Gaby",
    "lat": "45.713",
    "lng": "7.88224"
  },
  {
    "country": "IT",
    "name": "Gabicce Mare",
    "lat": "43.96471",
    "lng": "12.75641"
  },
  {
    "country": "IT",
    "name": "Gabiano",
    "lat": "45.15714",
    "lng": "8.19469"
  },
  {
    "country": "IT",
    "name": "Futani",
    "lat": "40.15156",
    "lng": "15.32366"
  },
  {
    "country": "IT",
    "name": "Fusine",
    "lat": "46.37589",
    "lng": "12.12547"
  },
  {
    "country": "IT",
    "name": "Fusine",
    "lat": "46.14949",
    "lng": "9.74975"
  },
  {
    "country": "IT",
    "name": "Fusignano",
    "lat": "44.46656",
    "lng": "11.95636"
  },
  {
    "country": "IT",
    "name": "Furore",
    "lat": "40.62061",
    "lng": "14.54904"
  },
  {
    "country": "IT",
    "name": "Furci",
    "lat": "42.00746",
    "lng": "14.58802"
  },
  {
    "country": "IT",
    "name": "Fumone",
    "lat": "41.73461",
    "lng": "13.27015"
  },
  {
    "country": "IT",
    "name": "Fumane",
    "lat": "45.5416",
    "lng": "10.88548"
  },
  {
    "country": "IT",
    "name": "Fucecchio",
    "lat": "43.73292",
    "lng": "10.79749"
  },
  {
    "country": "IT",
    "name": "Fubine",
    "lat": "44.96305",
    "lng": "8.42814"
  },
  {
    "country": "IT",
    "name": "Frugarolo",
    "lat": "44.83924",
    "lng": "8.68165"
  },
  {
    "country": "IT",
    "name": "Frosolone",
    "lat": "41.60006",
    "lng": "14.44578"
  },
  {
    "country": "IT",
    "name": "Frosinone",
    "lat": "41.63976",
    "lng": "13.34109"
  },
  {
    "country": "IT",
    "name": "Frontone",
    "lat": "43.51478",
    "lng": "12.73791"
  },
  {
    "country": "IT",
    "name": "Frontino",
    "lat": "43.76456",
    "lng": "12.37675"
  },
  {
    "country": "IT",
    "name": "Front",
    "lat": "45.27941",
    "lng": "7.66425"
  },
  {
    "country": "IT",
    "name": "Frisanco",
    "lat": "46.21246",
    "lng": "12.72626"
  },
  {
    "country": "IT",
    "name": "Frisa",
    "lat": "42.26572",
    "lng": "14.37625"
  },
  {
    "country": "IT",
    "name": "Frigento",
    "lat": "41.01103",
    "lng": "15.10026"
  },
  {
    "country": "IT",
    "name": "Fresagrandinaria",
    "lat": "41.979",
    "lng": "14.66211"
  },
  {
    "country": "IT",
    "name": "Fregona",
    "lat": "46.00795",
    "lng": "12.33864"
  },
  {
    "country": "IT",
    "name": "Fregene",
    "lat": "41.85051",
    "lng": "12.19671"
  },
  {
    "country": "IT",
    "name": "Fratta Todina",
    "lat": "42.85684",
    "lng": "12.36366"
  },
  {
    "country": "IT",
    "name": "Fratta Polesine",
    "lat": "45.02819",
    "lng": "11.64265"
  },
  {
    "country": "IT",
    "name": "Frattaminore",
    "lat": "40.9558",
    "lng": "14.27201"
  },
  {
    "country": "IT",
    "name": "Frattamaggiore",
    "lat": "40.9414",
    "lng": "14.27588"
  },
  {
    "country": "IT",
    "name": "Frasso Telesino",
    "lat": "41.15682",
    "lng": "14.52783"
  },
  {
    "country": "IT",
    "name": "Frasso Sabino",
    "lat": "42.22927",
    "lng": "12.80658"
  },
  {
    "country": "IT",
    "name": "Frassinoro",
    "lat": "44.29451",
    "lng": "10.57117"
  },
  {
    "country": "IT",
    "name": "Frassino",
    "lat": "44.57211",
    "lng": "7.27536"
  },
  {
    "country": "IT",
    "name": "Frassinetto",
    "lat": "45.43834",
    "lng": "7.60886"
  },
  {
    "country": "IT",
    "name": "Frassineto Po",
    "lat": "45.13271",
    "lng": "8.53525"
  },
  {
    "country": "IT",
    "name": "Frassinello Monferrato",
    "lat": "45.03322",
    "lng": "8.38666"
  },
  {
    "country": "IT",
    "name": "Frascati",
    "lat": "41.8091",
    "lng": "12.67942"
  },
  {
    "country": "IT",
    "name": "Frascaro",
    "lat": "44.82575",
    "lng": "8.53127"
  },
  {
    "country": "IT",
    "name": "Francolise",
    "lat": "41.18501",
    "lng": "14.05672"
  },
  {
    "country": "IT",
    "name": "Francolino",
    "lat": "44.89662",
    "lng": "11.65701"
  },
  {
    "country": "IT",
    "name": "Francavilla in Sinni",
    "lat": "40.08142",
    "lng": "16.20417"
  },
  {
    "country": "IT",
    "name": "Francavilla Fontana",
    "lat": "40.53123",
    "lng": "17.58522"
  },
  {
    "country": "IT",
    "name": "Francavilla d'Ete",
    "lat": "43.18837",
    "lng": "13.54033"
  },
  {
    "country": "IT",
    "name": "Francavilla al Mare",
    "lat": "42.42158",
    "lng": "14.28217"
  },
  {
    "country": "IT",
    "name": "Framura",
    "lat": "44.20946",
    "lng": "9.55399"
  },
  {
    "country": "IT",
    "name": "Fraine",
    "lat": "41.90624",
    "lng": "14.48788"
  },
  {
    "country": "IT",
    "name": "Fragneto Monforte",
    "lat": "41.24634",
    "lng": "14.76342"
  },
  {
    "country": "IT",
    "name": "Fragneto L'Abate",
    "lat": "41.2558",
    "lng": "14.78382"
  },
  {
    "country": "IT",
    "name": "Fragagnano",
    "lat": "40.4302",
    "lng": "17.47553"
  },
  {
    "country": "IT",
    "name": "Frabosa Soprana",
    "lat": "44.29094",
    "lng": "7.80353"
  },
  {
    "country": "IT",
    "name": "Foza",
    "lat": "45.89703",
    "lng": "11.63053"
  },
  {
    "country": "IT",
    "name": "Fossombrone",
    "lat": "43.69017",
    "lng": "12.81173"
  },
  {
    "country": "IT",
    "name": "Fossato di Vico",
    "lat": "43.29644",
    "lng": "12.76121"
  },
  {
    "country": "IT",
    "name": "Fossano",
    "lat": "44.55077",
    "lng": "7.71922"
  },
  {
    "country": "IT",
    "name": "San Vendemiano-Fossamerlo",
    "lat": "45.8918",
    "lng": "12.32992"
  },
  {
    "country": "IT",
    "name": "Fossalunga",
    "lat": "45.6916",
    "lng": "12.0532"
  },
  {
    "country": "IT",
    "name": "Fossalto",
    "lat": "41.67293",
    "lng": "14.54573"
  },
  {
    "country": "IT",
    "name": "Fossalta di Portogruaro",
    "lat": "45.79329",
    "lng": "12.90998"
  },
  {
    "country": "IT",
    "name": "Fossalta di Piave",
    "lat": "45.64497",
    "lng": "12.50902"
  },
  {
    "country": "IT",
    "name": "Fossacesia",
    "lat": "42.24198",
    "lng": "14.48339"
  },
  {
    "country": "IT",
    "name": "Fossa",
    "lat": "42.29273",
    "lng": "13.48779"
  },
  {
    "country": "IT",
    "name": "Fosdinovo",
    "lat": "44.1332",
    "lng": "10.01778"
  },
  {
    "country": "IT",
    "name": "Fortunago",
    "lat": "44.9216",
    "lng": "9.18471"
  },
  {
    "country": "IT",
    "name": "Fortezza",
    "lat": "46.78963",
    "lng": "11.60998"
  },
  {
    "country": "IT",
    "name": "Forte dei Marmi",
    "lat": "43.96388",
    "lng": "10.17478"
  },
  {
    "country": "IT",
    "name": "Fornovo San Giovanni",
    "lat": "45.49742",
    "lng": "9.67739"
  },
  {
    "country": "IT",
    "name": "Fornovo di Taro",
    "lat": "44.69465",
    "lng": "10.10178"
  },
  {
    "country": "IT",
    "name": "Forno di Zoldo",
    "lat": "46.3501",
    "lng": "12.17913"
  },
  {
    "country": "IT",
    "name": "Forno Canavese",
    "lat": "45.34287",
    "lng": "7.58951"
  },
  {
    "country": "IT",
    "name": "Forni di Sotto",
    "lat": "46.39379",
    "lng": "12.6721"
  },
  {
    "country": "IT",
    "name": "Forni di Sopra",
    "lat": "46.42028",
    "lng": "12.58312"
  },
  {
    "country": "IT",
    "name": "Forni Avoltri",
    "lat": "46.58615",
    "lng": "12.7751"
  },
  {
    "country": "IT",
    "name": "Fornelli",
    "lat": "41.60678",
    "lng": "14.14041"
  },
  {
    "country": "IT",
    "name": "Fornaci di Barga",
    "lat": "44.04899",
    "lng": "10.47111"
  },
  {
    "country": "IT",
    "name": "Fornaci",
    "lat": "45.6517",
    "lng": "12.43738"
  },
  {
    "country": "IT",
    "name": "Fornacette",
    "lat": "43.67023",
    "lng": "10.58512"
  },
  {
    "country": "IT",
    "name": "Fornacelle",
    "lat": "43.92377",
    "lng": "11.03525"
  },
  {
    "country": "IT",
    "name": "Formignana",
    "lat": "44.8423",
    "lng": "11.85935"
  },
  {
    "country": "IT",
    "name": "Formigliana",
    "lat": "45.42926",
    "lng": "8.29193"
  },
  {
    "country": "IT",
    "name": "Formigine",
    "lat": "44.57268",
    "lng": "10.84737"
  },
  {
    "country": "IT",
    "name": "Formigara",
    "lat": "45.22307",
    "lng": "9.77076"
  },
  {
    "country": "IT",
    "name": "Formicola",
    "lat": "41.21084",
    "lng": "14.23462"
  },
  {
    "country": "IT",
    "name": "Formia",
    "lat": "41.25632",
    "lng": "13.60888"
  },
  {
    "country": "IT",
    "name": "Formello",
    "lat": "42.06246",
    "lng": "12.39435"
  },
  {
    "country": "IT",
    "name": "Formazza",
    "lat": "46.37689",
    "lng": "8.42571"
  },
  {
    "country": "IT",
    "name": "Forlimpopoli",
    "lat": "44.19107",
    "lng": "12.12873"
  },
  {
    "country": "IT",
    "name": "Forlì del Sannio",
    "lat": "41.69593",
    "lng": "14.17952"
  },
  {
    "country": "IT",
    "name": "Forlì",
    "lat": "44.22177",
    "lng": "12.04144"
  },
  {
    "country": "IT",
    "name": "Forio",
    "lat": "40.73757",
    "lng": "13.86003"
  },
  {
    "country": "IT",
    "name": "Forino",
    "lat": "40.85829",
    "lng": "14.73254"
  },
  {
    "country": "IT",
    "name": "Forenza",
    "lat": "40.86041",
    "lng": "15.85457"
  },
  {
    "country": "IT",
    "name": "Forcoli",
    "lat": "43.60374",
    "lng": "10.70514"
  },
  {
    "country": "IT",
    "name": "Forchia",
    "lat": "41.03144",
    "lng": "14.53573"
  },
  {
    "country": "IT",
    "name": "Forano",
    "lat": "42.29768",
    "lng": "12.59469"
  },
  {
    "country": "IT",
    "name": "Foppolo",
    "lat": "46.04297",
    "lng": "9.75775"
  },
  {
    "country": "IT",
    "name": "Fonzaso",
    "lat": "46.0164",
    "lng": "11.79897"
  },
  {
    "country": "IT",
    "name": "Fontignano",
    "lat": "43.02436",
    "lng": "12.1919"
  },
  {
    "country": "IT",
    "name": "Fontevivo",
    "lat": "44.85942",
    "lng": "10.17281"
  },
  {
    "country": "IT",
    "name": "Fontegreca",
    "lat": "41.45653",
    "lng": "14.18385"
  },
  {
    "country": "IT",
    "name": "Fontechiari",
    "lat": "41.66788",
    "lng": "13.67504"
  },
  {
    "country": "IT",
    "name": "Fontecchio",
    "lat": "42.23027",
    "lng": "13.60613"
  },
  {
    "country": "IT",
    "name": "Fonteblanda",
    "lat": "42.56463",
    "lng": "11.17325"
  },
  {
    "country": "IT",
    "name": "Fontaniva",
    "lat": "45.63516",
    "lng": "11.75381"
  },
  {
    "country": "IT",
    "name": "Fontanile",
    "lat": "44.75295",
    "lng": "8.42134"
  },
  {
    "country": "IT",
    "name": "Fontanigorda",
    "lat": "44.5454",
    "lng": "9.30548"
  },
  {
    "country": "IT",
    "name": "Fontanetto Po",
    "lat": "45.19436",
    "lng": "8.19206"
  },
  {
    "country": "IT",
    "name": "Fontaneto D'Agogna",
    "lat": "45.64347",
    "lng": "8.47879"
  },
  {
    "country": "IT",
    "name": "Fontanelle",
    "lat": "45.83345",
    "lng": "12.46625"
  },
  {
    "country": "IT",
    "name": "Fontanellato",
    "lat": "44.88187",
    "lng": "10.17631"
  },
  {
    "country": "IT",
    "name": "Fontanella",
    "lat": "45.46903",
    "lng": "9.80248"
  },
  {
    "country": "IT",
    "name": "Fontanelice",
    "lat": "44.25932",
    "lng": "11.55852"
  },
  {
    "country": "IT",
    "name": "Fontanarosa",
    "lat": "41.01812",
    "lng": "15.02055"
  },
  {
    "country": "IT",
    "name": "Collefontana-Fontana Liri Inferiore",
    "lat": "41.61166",
    "lng": "13.54945"
  },
  {
    "country": "IT",
    "name": "Fontana Nuova-Bevia",
    "lat": "46.41159",
    "lng": "10.96843"
  },
  {
    "country": "IT",
    "name": "Monticelli-Fontana",
    "lat": "45.42965",
    "lng": "11.13729"
  },
  {
    "country": "IT",
    "name": "Fonni",
    "lat": "40.11932",
    "lng": "9.25347"
  },
  {
    "country": "IT",
    "name": "Fondo",
    "lat": "46.4388",
    "lng": "11.13723"
  },
  {
    "country": "IT",
    "name": "Fondi",
    "lat": "41.35787",
    "lng": "13.42718"
  },
  {
    "country": "IT",
    "name": "Fombio",
    "lat": "45.14126",
    "lng": "9.68043"
  },
  {
    "country": "IT",
    "name": "Follonica",
    "lat": "42.92779",
    "lng": "10.76451"
  },
  {
    "country": "IT",
    "name": "Follina",
    "lat": "45.95352",
    "lng": "12.11985"
  },
  {
    "country": "IT",
    "name": "Foligno",
    "lat": "42.95488",
    "lng": "12.70268"
  },
  {
    "country": "IT",
    "name": "Folignano",
    "lat": "42.8207",
    "lng": "13.63273"
  },
  {
    "country": "IT",
    "name": "Folgaria",
    "lat": "45.91543",
    "lng": "11.1682"
  },
  {
    "country": "IT",
    "name": "Foiano di Val Fortore",
    "lat": "41.35283",
    "lng": "14.97635"
  },
  {
    "country": "IT",
    "name": "Foiano della Chiana",
    "lat": "43.25318",
    "lng": "11.81647"
  },
  {
    "country": "IT",
    "name": "Fognano",
    "lat": "44.20509",
    "lng": "11.73782"
  },
  {
    "country": "IT",
    "name": "Foglizzo",
    "lat": "45.27361",
    "lng": "7.82087"
  },
  {
    "country": "IT",
    "name": "Fogliano",
    "lat": "45.86556",
    "lng": "13.48222"
  },
  {
    "country": "IT",
    "name": "Foglianise",
    "lat": "41.16127",
    "lng": "14.67112"
  },
  {
    "country": "IT",
    "name": "Foggia",
    "lat": "41.45845",
    "lng": "15.55188"
  },
  {
    "country": "IT",
    "name": "Fobello",
    "lat": "45.89002",
    "lng": "8.15799"
  },
  {
    "country": "IT",
    "name": "Flussio",
    "lat": "40.26545",
    "lng": "8.5381"
  },
  {
    "country": "IT",
    "name": "Flumeri",
    "lat": "41.07623",
    "lng": "15.15072"
  },
  {
    "country": "IT",
    "name": "Florinas",
    "lat": "40.649",
    "lng": "8.66548"
  },
  {
    "country": "IT",
    "name": "Flero",
    "lat": "45.48254",
    "lng": "10.17694"
  },
  {
    "country": "IT",
    "name": "Flavon",
    "lat": "46.29809",
    "lng": "11.02993"
  },
  {
    "country": "IT",
    "name": "Flaibano",
    "lat": "46.05837",
    "lng": "12.98424"
  },
  {
    "country": "IT",
    "name": "Fivizzano",
    "lat": "44.23784",
    "lng": "10.1265"
  },
  {
    "country": "IT",
    "name": "Fiumicino-Isola Sacra",
    "lat": "41.77093",
    "lng": "12.23662"
  },
  {
    "country": "IT",
    "name": "Fiume Veneto",
    "lat": "45.92865",
    "lng": "12.73811"
  },
  {
    "country": "IT",
    "name": "Fiumana",
    "lat": "44.14325",
    "lng": "11.98719"
  },
  {
    "country": "IT",
    "name": "Fiumalbo-Dogana",
    "lat": "44.17925",
    "lng": "10.6472"
  },
  {
    "country": "IT",
    "name": "Fiuggi",
    "lat": "41.7978",
    "lng": "13.22386"
  },
  {
    "country": "IT",
    "name": "Fisciano",
    "lat": "40.77175",
    "lng": "14.79454"
  },
  {
    "country": "IT",
    "name": "Firenzuola",
    "lat": "44.11968",
    "lng": "11.38185"
  },
  {
    "country": "IT",
    "name": "Florence",
    "lat": "43.77925",
    "lng": "11.24626"
  },
  {
    "country": "IT",
    "name": "Fiorenzuola d'Arda",
    "lat": "44.92435",
    "lng": "9.91329"
  },
  {
    "country": "IT",
    "name": "Fiorano",
    "lat": "44.53889",
    "lng": "10.81166"
  },
  {
    "country": "IT",
    "name": "Fino Mornasco",
    "lat": "45.7429",
    "lng": "9.04996"
  },
  {
    "country": "IT",
    "name": "Finale Ligure",
    "lat": "44.16952",
    "lng": "8.3436"
  },
  {
    "country": "IT",
    "name": "Finale Emilia",
    "lat": "44.83373",
    "lng": "11.29378"
  },
  {
    "country": "IT",
    "name": "Filottrano",
    "lat": "43.43553",
    "lng": "13.35141"
  },
  {
    "country": "IT",
    "name": "Filignano",
    "lat": "41.54578",
    "lng": "14.05757"
  },
  {
    "country": "IT",
    "name": "Filighera",
    "lat": "45.17496",
    "lng": "9.31646"
  },
  {
    "country": "IT",
    "name": "Filiano",
    "lat": "40.81042",
    "lng": "15.70984"
  },
  {
    "country": "IT",
    "name": "Filettole",
    "lat": "43.81307",
    "lng": "10.40239"
  },
  {
    "country": "IT",
    "name": "Filetto",
    "lat": "42.22931",
    "lng": "14.24501"
  },
  {
    "country": "IT",
    "name": "Filettino",
    "lat": "41.89131",
    "lng": "13.32531"
  },
  {
    "country": "IT",
    "name": "Filacciano",
    "lat": "42.25445",
    "lng": "12.5988"
  },
  {
    "country": "IT",
    "name": "Figline Valdarno",
    "lat": "43.61995",
    "lng": "11.47191"
  },
  {
    "country": "IT",
    "name": "Fiesso Umbertiano",
    "lat": "44.96072",
    "lng": "11.60576"
  },
  {
    "country": "IT",
    "name": "Fiesse",
    "lat": "45.23207",
    "lng": "10.32417"
  },
  {
    "country": "IT",
    "name": "Fiesole",
    "lat": "43.80455",
    "lng": "11.29487"
  },
  {
    "country": "IT",
    "name": "Fiera di Primiero",
    "lat": "46.17621",
    "lng": "11.82879"
  },
  {
    "country": "IT",
    "name": "Fiè Allo Sciliar",
    "lat": "46.51672",
    "lng": "11.50128"
  },
  {
    "country": "IT",
    "name": "Fidenza",
    "lat": "44.86694",
    "lng": "10.06039"
  },
  {
    "country": "IT",
    "name": "Ficulle",
    "lat": "42.83194",
    "lng": "12.06801"
  },
  {
    "country": "IT",
    "name": "Ficarolo",
    "lat": "44.95425",
    "lng": "11.43662"
  },
  {
    "country": "IT",
    "name": "Fiavè",
    "lat": "46.00457",
    "lng": "10.84225"
  },
  {
    "country": "IT",
    "name": "Trebbio",
    "lat": "43.03685",
    "lng": "13.15394"
  },
  {
    "country": "IT",
    "name": "Fiano Romano",
    "lat": "42.15538",
    "lng": "12.59467"
  },
  {
    "country": "IT",
    "name": "Fiano",
    "lat": "45.21631",
    "lng": "7.52603"
  },
  {
    "country": "IT",
    "name": "Fiamignano",
    "lat": "42.26546",
    "lng": "13.12413"
  },
  {
    "country": "IT",
    "name": "Ferriere",
    "lat": "44.64385",
    "lng": "9.49657"
  },
  {
    "country": "IT",
    "name": "Ferrera Erbognone",
    "lat": "45.11456",
    "lng": "8.86454"
  },
  {
    "country": "IT",
    "name": "Ferrazzano",
    "lat": "41.53033",
    "lng": "14.67223"
  },
  {
    "country": "IT",
    "name": "Ferrara di Monte Baldo",
    "lat": "45.67408",
    "lng": "10.85911"
  },
  {
    "country": "IT",
    "name": "Ferrara",
    "lat": "44.83804",
    "lng": "11.62057"
  },
  {
    "country": "IT",
    "name": "Ferrandina",
    "lat": "40.50084",
    "lng": "16.45258"
  },
  {
    "country": "IT",
    "name": "Ferrada",
    "lat": "44.42008",
    "lng": "9.21016"
  },
  {
    "country": "IT",
    "name": "Ferno",
    "lat": "45.61496",
    "lng": "8.75695"
  },
  {
    "country": "IT",
    "name": "Fermo",
    "lat": "43.16296",
    "lng": "13.72274"
  },
  {
    "country": "IT",
    "name": "Fermignano",
    "lat": "43.69311",
    "lng": "12.65437"
  },
  {
    "country": "IT",
    "name": "Ferentino",
    "lat": "41.69119",
    "lng": "13.2562"
  },
  {
    "country": "IT",
    "name": "Ferentillo",
    "lat": "42.62027",
    "lng": "12.78726"
  },
  {
    "country": "IT",
    "name": "Fenestrelle",
    "lat": "45.03594",
    "lng": "7.04941"
  },
  {
    "country": "IT",
    "name": "Feltre",
    "lat": "46.02085",
    "lng": "11.90031"
  },
  {
    "country": "IT",
    "name": "Felizzano",
    "lat": "44.89935",
    "lng": "8.43584"
  },
  {
    "country": "IT",
    "name": "Felino",
    "lat": "44.69902",
    "lng": "10.23828"
  },
  {
    "country": "IT",
    "name": "Feletto Umberto",
    "lat": "46.10317",
    "lng": "13.22196"
  },
  {
    "country": "IT",
    "name": "Feletto",
    "lat": "45.30336",
    "lng": "7.74481"
  },
  {
    "country": "IT",
    "name": "Felegara",
    "lat": "44.72187",
    "lng": "10.11273"
  },
  {
    "country": "IT",
    "name": "Favria",
    "lat": "45.33099",
    "lng": "7.68834"
  },
  {
    "country": "IT",
    "name": "Favale di Malvaro",
    "lat": "44.45163",
    "lng": "9.26"
  },
  {
    "country": "IT",
    "name": "Fauglia",
    "lat": "43.5711",
    "lng": "10.51383"
  },
  {
    "country": "IT",
    "name": "Fascia",
    "lat": "44.58255",
    "lng": "9.22136"
  },
  {
    "country": "IT",
    "name": "Fasano",
    "lat": "40.83625",
    "lng": "17.36007"
  },
  {
    "country": "IT",
    "name": "Farra di Soligo",
    "lat": "45.90528",
    "lng": "12.12444"
  },
  {
    "country": "IT",
    "name": "Farra d'Alpago",
    "lat": "46.12079",
    "lng": "12.35876"
  },
  {
    "country": "IT",
    "name": "Farnese",
    "lat": "42.54926",
    "lng": "11.72638"
  },
  {
    "country": "IT",
    "name": "Farini",
    "lat": "44.71266",
    "lng": "9.56887"
  },
  {
    "country": "IT",
    "name": "Farindola",
    "lat": "42.44292",
    "lng": "13.82137"
  },
  {
    "country": "IT",
    "name": "Fardella",
    "lat": "40.11381",
    "lng": "16.16978"
  },
  {
    "country": "IT",
    "name": "Fara Vicentino",
    "lat": "45.74369",
    "lng": "11.54529"
  },
  {
    "country": "IT",
    "name": "Fara San Martino",
    "lat": "42.09248",
    "lng": "14.20896"
  },
  {
    "country": "IT",
    "name": "Fara Novarese",
    "lat": "45.5544",
    "lng": "8.45664"
  },
  {
    "country": "IT",
    "name": "Fara in Sabina",
    "lat": "42.20807",
    "lng": "12.7296"
  },
  {
    "country": "IT",
    "name": "Fara Gera d'Adda",
    "lat": "45.55656",
    "lng": "9.53656"
  },
  {
    "country": "IT",
    "name": "Fara Filiorum Petri",
    "lat": "42.24152",
    "lng": "14.18026"
  },
  {
    "country": "IT",
    "name": "Fanzolo",
    "lat": "45.71218",
    "lng": "11.99023"
  },
  {
    "country": "IT",
    "name": "Fano Adriano",
    "lat": "42.5523",
    "lng": "13.53764"
  },
  {
    "country": "IT",
    "name": "Fano",
    "lat": "43.84052",
    "lng": "13.01665"
  },
  {
    "country": "IT",
    "name": "Fanna",
    "lat": "46.18455",
    "lng": "12.75161"
  },
  {
    "country": "IT",
    "name": "Fanano",
    "lat": "44.21245",
    "lng": "10.7966"
  },
  {
    "country": "IT",
    "name": "Falzes",
    "lat": "46.81359",
    "lng": "11.88308"
  },
  {
    "country": "IT",
    "name": "Falzè di Piave",
    "lat": "45.86796",
    "lng": "12.17891"
  },
  {
    "country": "IT",
    "name": "Falvaterra",
    "lat": "41.50438",
    "lng": "13.52341"
  },
  {
    "country": "IT",
    "name": "Falmenta",
    "lat": "46.07309",
    "lng": "8.58944"
  },
  {
    "country": "IT",
    "name": "Fallo",
    "lat": "41.93833",
    "lng": "14.32362"
  },
  {
    "country": "IT",
    "name": "Falerone",
    "lat": "43.10429",
    "lng": "13.47189"
  },
  {
    "country": "IT",
    "name": "Faleria",
    "lat": "42.2258",
    "lng": "12.44518"
  },
  {
    "country": "IT",
    "name": "Falconara Marittima",
    "lat": "43.62558",
    "lng": "13.39954"
  },
  {
    "country": "IT",
    "name": "Falcade Alto",
    "lat": "46.35549",
    "lng": "11.85712"
  },
  {
    "country": "IT",
    "name": "Fai della Paganella",
    "lat": "46.17801",
    "lng": "11.0695"
  },
  {
    "country": "IT",
    "name": "Faicchio",
    "lat": "41.27816",
    "lng": "14.4774"
  },
  {
    "country": "IT",
    "name": "Faiano",
    "lat": "40.66254",
    "lng": "14.90244"
  },
  {
    "country": "IT",
    "name": "Fagnano Olona-Bergoro",
    "lat": "45.66977",
    "lng": "8.85994"
  },
  {
    "country": "IT",
    "name": "Faggiano",
    "lat": "40.41616",
    "lng": "17.38861"
  },
  {
    "country": "IT",
    "name": "Fagagna",
    "lat": "46.10698",
    "lng": "13.09361"
  },
  {
    "country": "IT",
    "name": "Faeto",
    "lat": "41.32489",
    "lng": "15.16045"
  },
  {
    "country": "IT",
    "name": "Faenza",
    "lat": "44.29007",
    "lng": "11.87948"
  },
  {
    "country": "IT",
    "name": "Faedo Valtellino",
    "lat": "46.15299",
    "lng": "9.90605"
  },
  {
    "country": "IT",
    "name": "Faedis",
    "lat": "46.14931",
    "lng": "13.34463"
  },
  {
    "country": "IT",
    "name": "Fabro",
    "lat": "42.87267",
    "lng": "12.0154"
  },
  {
    "country": "IT",
    "name": "Fabrica di Roma",
    "lat": "42.33444",
    "lng": "12.29873"
  },
  {
    "country": "IT",
    "name": "Fabriano",
    "lat": "43.33941",
    "lng": "12.90327"
  },
  {
    "country": "IT",
    "name": "Fabbrico",
    "lat": "44.87214",
    "lng": "10.80893"
  },
  {
    "country": "IT",
    "name": "Fabbriche di Vallico",
    "lat": "43.99765",
    "lng": "10.4279"
  },
  {
    "country": "IT",
    "name": "Exilles",
    "lat": "45.09754",
    "lng": "6.9292"
  },
  {
    "country": "IT",
    "name": "Etroubles",
    "lat": "45.82082",
    "lng": "7.23137"
  },
  {
    "country": "IT",
    "name": "Este",
    "lat": "45.22338",
    "lng": "11.66379"
  },
  {
    "country": "IT",
    "name": "Esperia",
    "lat": "41.38237",
    "lng": "13.68491"
  },
  {
    "country": "IT",
    "name": "Esino Lario",
    "lat": "45.99437",
    "lng": "9.33399"
  },
  {
    "country": "IT",
    "name": "Esine",
    "lat": "45.92515",
    "lng": "10.25102"
  },
  {
    "country": "IT",
    "name": "Esanatoglia",
    "lat": "43.25248",
    "lng": "12.9493"
  },
  {
    "country": "IT",
    "name": "Erula",
    "lat": "40.79244",
    "lng": "8.94418"
  },
  {
    "country": "IT",
    "name": "Erto",
    "lat": "46.2764",
    "lng": "12.37149"
  },
  {
    "country": "IT",
    "name": "Erli",
    "lat": "44.13719",
    "lng": "8.1043"
  },
  {
    "country": "IT",
    "name": "Ercolano",
    "lat": "40.80783",
    "lng": "14.35012"
  },
  {
    "country": "IT",
    "name": "Erchie",
    "lat": "40.43609",
    "lng": "17.7361"
  },
  {
    "country": "IT",
    "name": "Erbezzo",
    "lat": "45.6396",
    "lng": "11.00057"
  },
  {
    "country": "IT",
    "name": "Erbè",
    "lat": "45.24231",
    "lng": "10.97135"
  },
  {
    "country": "IT",
    "name": "Erba",
    "lat": "45.8088",
    "lng": "9.22609"
  },
  {
    "country": "IT",
    "name": "Eraclea",
    "lat": "45.57766",
    "lng": "12.6732"
  },
  {
    "country": "IT",
    "name": "Episcopia",
    "lat": "40.07481",
    "lng": "16.09818"
  },
  {
    "country": "IT",
    "name": "Envie",
    "lat": "44.6821",
    "lng": "7.37206"
  },
  {
    "country": "IT",
    "name": "Entracque",
    "lat": "44.24028",
    "lng": "7.39847"
  },
  {
    "country": "IT",
    "name": "Enemonzo-Quinis",
    "lat": "46.40833",
    "lng": "12.87944"
  },
  {
    "country": "IT",
    "name": "Endine",
    "lat": "45.7898",
    "lng": "9.97561"
  },
  {
    "country": "IT",
    "name": "Empoli",
    "lat": "43.71795",
    "lng": "10.94758"
  },
  {
    "country": "IT",
    "name": "Emarese",
    "lat": "45.72489",
    "lng": "7.68976"
  },
  {
    "country": "IT",
    "name": "Serre",
    "lat": "44.54033",
    "lng": "7.09032"
  },
  {
    "country": "IT",
    "name": "Elice",
    "lat": "42.52279",
    "lng": "13.97071"
  },
  {
    "country": "IT",
    "name": "Egna",
    "lat": "46.31777",
    "lng": "11.27337"
  },
  {
    "country": "IT",
    "name": "Edolo",
    "lat": "46.17799",
    "lng": "10.33322"
  },
  {
    "country": "IT",
    "name": "Eboli",
    "lat": "40.61747",
    "lng": "15.05693"
  },
  {
    "country": "IT",
    "name": "Dusino",
    "lat": "44.92566",
    "lng": "7.97165"
  },
  {
    "country": "IT",
    "name": "Duronia",
    "lat": "41.65786",
    "lng": "14.46015"
  },
  {
    "country": "IT",
    "name": "Durazzano",
    "lat": "41.06286",
    "lng": "14.44947"
  },
  {
    "country": "IT",
    "name": "Dumenza",
    "lat": "46.02088",
    "lng": "8.78674"
  },
  {
    "country": "IT",
    "name": "Duino",
    "lat": "45.77342",
    "lng": "13.60436"
  },
  {
    "country": "IT",
    "name": "Dugenta",
    "lat": "41.13468",
    "lng": "14.45353"
  },
  {
    "country": "IT",
    "name": "Dueville",
    "lat": "45.63556",
    "lng": "11.55135"
  },
  {
    "country": "IT",
    "name": "Dubino",
    "lat": "46.16705",
    "lng": "9.43049"
  },
  {
    "country": "IT",
    "name": "Dualchi",
    "lat": "40.22935",
    "lng": "8.89723"
  },
  {
    "country": "IT",
    "name": "Druogno",
    "lat": "46.13421",
    "lng": "8.43276"
  },
  {
    "country": "IT",
    "name": "Druento",
    "lat": "45.13306",
    "lng": "7.57512"
  },
  {
    "country": "IT",
    "name": "Dronero",
    "lat": "44.46476",
    "lng": "7.36242"
  },
  {
    "country": "IT",
    "name": "Dro",
    "lat": "45.96121",
    "lng": "10.91201"
  },
  {
    "country": "IT",
    "name": "Drena",
    "lat": "45.96926",
    "lng": "10.9454"
  },
  {
    "country": "IT",
    "name": "Dragoni",
    "lat": "41.27619",
    "lng": "14.30368"
  },
  {
    "country": "IT",
    "name": "Dozza",
    "lat": "44.36195",
    "lng": "11.63547"
  },
  {
    "country": "IT",
    "name": "Dovera",
    "lat": "45.36428",
    "lng": "9.54445"
  },
  {
    "country": "IT",
    "name": "Dovadola",
    "lat": "44.12211",
    "lng": "11.88707"
  },
  {
    "country": "IT",
    "name": "Dosson",
    "lat": "45.63605",
    "lng": "12.25409"
  },
  {
    "country": "IT",
    "name": "Dossobuono",
    "lat": "45.39333",
    "lng": "10.91054"
  },
  {
    "country": "IT",
    "name": "Dosso",
    "lat": "44.76806",
    "lng": "11.33938"
  },
  {
    "country": "IT",
    "name": "Dosolo",
    "lat": "44.95259",
    "lng": "10.6355"
  },
  {
    "country": "IT",
    "name": "Dosimo",
    "lat": "45.18469",
    "lng": "10.10362"
  },
  {
    "country": "IT",
    "name": "Dorno",
    "lat": "45.15352",
    "lng": "8.95076"
  },
  {
    "country": "IT",
    "name": "Dorio",
    "lat": "46.1002",
    "lng": "9.31883"
  },
  {
    "country": "IT",
    "name": "Dorgali",
    "lat": "40.29221",
    "lng": "9.58702"
  },
  {
    "country": "IT",
    "name": "Donzella",
    "lat": "44.93047",
    "lng": "12.33119"
  },
  {
    "country": "IT",
    "name": "Dongo",
    "lat": "46.12999",
    "lng": "9.28169"
  },
  {
    "country": "IT",
    "name": "Domodossola",
    "lat": "46.1165",
    "lng": "8.29313"
  },
  {
    "country": "IT",
    "name": "Domicella",
    "lat": "40.88019",
    "lng": "14.58716"
  },
  {
    "country": "IT",
    "name": "Domegge di Cadore",
    "lat": "46.45666",
    "lng": "12.40724"
  },
  {
    "country": "IT",
    "name": "Domaso",
    "lat": "46.15284",
    "lng": "9.3315"
  },
  {
    "country": "IT",
    "name": "Dolo",
    "lat": "45.42528",
    "lng": "12.08429"
  },
  {
    "country": "IT",
    "name": "Dolcedo",
    "lat": "43.90735",
    "lng": "7.94943"
  },
  {
    "country": "IT",
    "name": "Dolceacqua",
    "lat": "43.84975",
    "lng": "7.62373"
  },
  {
    "country": "IT",
    "name": "Dolcè",
    "lat": "45.60069",
    "lng": "10.85248"
  },
  {
    "country": "IT",
    "name": "Dogna",
    "lat": "46.44793",
    "lng": "13.31502"
  },
  {
    "country": "IT",
    "name": "Dogliola",
    "lat": "41.94238",
    "lng": "14.63507"
  },
  {
    "country": "IT",
    "name": "Dogliani",
    "lat": "44.53326",
    "lng": "7.9451"
  },
  {
    "country": "IT",
    "name": "Doberdò del Lago",
    "lat": "45.84444",
    "lng": "13.53908"
  },
  {
    "country": "IT",
    "name": "Dobbiaco",
    "lat": "46.72878",
    "lng": "12.22225"
  },
  {
    "country": "IT",
    "name": "Dizzasco-Biazzeno",
    "lat": "45.94378",
    "lng": "9.09974"
  },
  {
    "country": "IT",
    "name": "Divignano",
    "lat": "45.66247",
    "lng": "8.59987"
  },
  {
    "country": "IT",
    "name": "Dimaro",
    "lat": "46.32573",
    "lng": "10.87342"
  },
  {
    "country": "IT",
    "name": "Dignano",
    "lat": "46.08392",
    "lng": "12.94009"
  },
  {
    "country": "IT",
    "name": "Dicomano",
    "lat": "43.89267",
    "lng": "11.52182"
  },
  {
    "country": "IT",
    "name": "Diano San Pietro",
    "lat": "43.92953",
    "lng": "8.07249"
  },
  {
    "country": "IT",
    "name": "Diano Marina",
    "lat": "43.91088",
    "lng": "8.08029"
  },
  {
    "country": "IT",
    "name": "Diano d'Alba",
    "lat": "44.65294",
    "lng": "8.02704"
  },
  {
    "country": "IT",
    "name": "Diano Castello",
    "lat": "43.92423",
    "lng": "8.06602"
  },
  {
    "country": "IT",
    "name": "Desio",
    "lat": "45.61831",
    "lng": "9.20249"
  },
  {
    "country": "IT",
    "name": "Desenzano del Garda",
    "lat": "45.47127",
    "lng": "10.53559"
  },
  {
    "country": "IT",
    "name": "Desana",
    "lat": "45.26915",
    "lng": "8.35777"
  },
  {
    "country": "IT",
    "name": "Dervio",
    "lat": "46.07696",
    "lng": "9.30659"
  },
  {
    "country": "IT",
    "name": "Deruta",
    "lat": "42.98465",
    "lng": "12.4176"
  },
  {
    "country": "IT",
    "name": "Taio",
    "lat": "46.32139",
    "lng": "11.06624"
  },
  {
    "country": "IT",
    "name": "Denno",
    "lat": "46.27424",
    "lng": "11.04913"
  },
  {
    "country": "IT",
    "name": "Demonte",
    "lat": "44.31646",
    "lng": "7.29808"
  },
  {
    "country": "IT",
    "name": "Dello",
    "lat": "45.41916",
    "lng": "10.07621"
  },
  {
    "country": "IT",
    "name": "Deliceto",
    "lat": "41.22289",
    "lng": "15.38447"
  },
  {
    "country": "IT",
    "name": "Delebio",
    "lat": "46.13648",
    "lng": "9.46157"
  },
  {
    "country": "IT",
    "name": "Deiva Marina",
    "lat": "44.21931",
    "lng": "9.52064"
  },
  {
    "country": "IT",
    "name": "Dego",
    "lat": "44.44455",
    "lng": "8.30761"
  },
  {
    "country": "IT",
    "name": "Decima",
    "lat": "44.71045",
    "lng": "11.22978"
  },
  {
    "country": "IT",
    "name": "Dazio",
    "lat": "46.16129",
    "lng": "9.60064"
  },
  {
    "country": "IT",
    "name": "Darfo",
    "lat": "45.87794",
    "lng": "10.18115"
  },
  {
    "country": "IT",
    "name": "Daone",
    "lat": "45.9472",
    "lng": "10.62107"
  },
  {
    "country": "IT",
    "name": "Danta",
    "lat": "46.567",
    "lng": "12.52055"
  },
  {
    "country": "IT",
    "name": "Dambel",
    "lat": "46.40471",
    "lng": "11.09307"
  },
  {
    "country": "IT",
    "name": "Dalmine",
    "lat": "45.64933",
    "lng": "9.60617"
  },
  {
    "country": "IT",
    "name": "Dairago",
    "lat": "45.5658",
    "lng": "8.86265"
  },
  {
    "country": "IT",
    "name": "Cutrofiano",
    "lat": "40.12616",
    "lng": "18.2026"
  },
  {
    "country": "IT",
    "name": "Cutigliano",
    "lat": "44.10059",
    "lng": "10.75617"
  },
  {
    "country": "IT",
    "name": "Cusio",
    "lat": "45.99089",
    "lng": "9.60175"
  },
  {
    "country": "IT",
    "name": "Cusercoli",
    "lat": "44.04514",
    "lng": "12.0074"
  },
  {
    "country": "IT",
    "name": "Cusano Mutri",
    "lat": "41.33624",
    "lng": "14.51013"
  },
  {
    "country": "IT",
    "name": "Cusano Milanino",
    "lat": "45.55187",
    "lng": "9.18373"
  },
  {
    "country": "IT",
    "name": "Curtarolo",
    "lat": "45.52366",
    "lng": "11.83691"
  },
  {
    "country": "IT",
    "name": "Cursi",
    "lat": "40.14847",
    "lng": "18.31605"
  },
  {
    "country": "IT",
    "name": "Curon Venosta",
    "lat": "46.80832",
    "lng": "10.54265"
  },
  {
    "country": "IT",
    "name": "Curno",
    "lat": "45.68876",
    "lng": "9.60872"
  },
  {
    "country": "IT",
    "name": "Curiglia",
    "lat": "46.06065",
    "lng": "8.80484"
  },
  {
    "country": "IT",
    "name": "Cupramontana",
    "lat": "43.44975",
    "lng": "13.11312"
  },
  {
    "country": "IT",
    "name": "Cupra Marittima",
    "lat": "43.01905",
    "lng": "13.86171"
  },
  {
    "country": "IT",
    "name": "Cupello",
    "lat": "42.06936",
    "lng": "14.67054"
  },
  {
    "country": "IT",
    "name": "Cuorgnè",
    "lat": "45.39341",
    "lng": "7.65015"
  },
  {
    "country": "IT",
    "name": "Cunico",
    "lat": "45.0405",
    "lng": "8.09554"
  },
  {
    "country": "IT",
    "name": "Cuneo",
    "lat": "44.39071",
    "lng": "7.54828"
  },
  {
    "country": "IT",
    "name": "Cumignano sul Naviglio",
    "lat": "45.35459",
    "lng": "9.83621"
  },
  {
    "country": "IT",
    "name": "Cumiana",
    "lat": "44.97629",
    "lng": "7.37761"
  },
  {
    "country": "IT",
    "name": "Cugnoli",
    "lat": "42.30692",
    "lng": "13.9349"
  },
  {
    "country": "IT",
    "name": "Cuglieri",
    "lat": "40.18804",
    "lng": "8.56806"
  },
  {
    "country": "IT",
    "name": "Cuggiono",
    "lat": "45.50683",
    "lng": "8.8155"
  },
  {
    "country": "IT",
    "name": "Cuceglio",
    "lat": "45.35853",
    "lng": "7.81588"
  },
  {
    "country": "IT",
    "name": "Cuccurano",
    "lat": "43.79311",
    "lng": "12.95927"
  },
  {
    "country": "IT",
    "name": "Cuccaro Vetere",
    "lat": "40.16404",
    "lng": "15.30677"
  },
  {
    "country": "IT",
    "name": "Crugnola",
    "lat": "45.72955",
    "lng": "8.74525"
  },
  {
    "country": "IT",
    "name": "Croviana",
    "lat": "46.3448",
    "lng": "10.90313"
  },
  {
    "country": "IT",
    "name": "Crova",
    "lat": "45.33066",
    "lng": "8.21083"
  },
  {
    "country": "IT",
    "name": "Crotta d'Adda",
    "lat": "45.15888",
    "lng": "9.85684"
  },
  {
    "country": "IT",
    "name": "Maglione-Crosa",
    "lat": "45.60297",
    "lng": "8.14937"
  },
  {
    "country": "IT",
    "name": "Crone",
    "lat": "45.73741",
    "lng": "10.47503"
  },
  {
    "country": "IT",
    "name": "Crognaleto",
    "lat": "42.58771",
    "lng": "13.4889"
  },
  {
    "country": "IT",
    "name": "Crodo",
    "lat": "46.21726",
    "lng": "8.32238"
  },
  {
    "country": "IT",
    "name": "Crocetta del Montello",
    "lat": "45.83667",
    "lng": "12.03361"
  },
  {
    "country": "IT",
    "name": "Crocefieschi",
    "lat": "44.58077",
    "lng": "9.0236"
  },
  {
    "country": "IT",
    "name": "Crissolo",
    "lat": "44.69953",
    "lng": "7.15602"
  },
  {
    "country": "IT",
    "name": "Crispiano",
    "lat": "40.60379",
    "lng": "17.2329"
  },
  {
    "country": "IT",
    "name": "Crevalcore",
    "lat": "44.71966",
    "lng": "11.14765"
  },
  {
    "country": "IT",
    "name": "Crevacuore",
    "lat": "45.68548",
    "lng": "8.24404"
  },
  {
    "country": "IT",
    "name": "Cretone",
    "lat": "42.07116",
    "lng": "12.70365"
  },
  {
    "country": "IT",
    "name": "Creto",
    "lat": "45.9411",
    "lng": "10.64027"
  },
  {
    "country": "IT",
    "name": "Cressa",
    "lat": "45.64762",
    "lng": "8.50942"
  },
  {
    "country": "IT",
    "name": "Crespino",
    "lat": "44.98527",
    "lng": "11.88958"
  },
  {
    "country": "IT",
    "name": "Crespina",
    "lat": "43.57304",
    "lng": "10.56431"
  },
  {
    "country": "IT",
    "name": "Crespiatica",
    "lat": "45.35136",
    "lng": "9.57659"
  },
  {
    "country": "IT",
    "name": "Crespellano",
    "lat": "44.51196",
    "lng": "11.13224"
  },
  {
    "country": "IT",
    "name": "Crespano del Grappa",
    "lat": "45.82793",
    "lng": "11.83358"
  },
  {
    "country": "IT",
    "name": "Crespadoro",
    "lat": "45.62019",
    "lng": "11.22589"
  },
  {
    "country": "IT",
    "name": "Crescentino",
    "lat": "45.19941",
    "lng": "8.08635"
  },
  {
    "country": "IT",
    "name": "Cremona",
    "lat": "45.13325",
    "lng": "10.02129"
  },
  {
    "country": "IT",
    "name": "Cremolino",
    "lat": "44.63674",
    "lng": "8.58584"
  },
  {
    "country": "IT",
    "name": "Cremeno",
    "lat": "45.93492",
    "lng": "9.47099"
  },
  {
    "country": "IT",
    "name": "Crema",
    "lat": "45.36264",
    "lng": "9.68176"
  },
  {
    "country": "IT",
    "name": "Credera",
    "lat": "45.30301",
    "lng": "9.65498"
  },
  {
    "country": "IT",
    "name": "Crecchio",
    "lat": "42.29778",
    "lng": "14.32656"
  },
  {
    "country": "IT",
    "name": "Creazzo",
    "lat": "45.53154",
    "lng": "11.47789"
  },
  {
    "country": "IT",
    "name": "Craveggia",
    "lat": "46.14124",
    "lng": "8.48907"
  },
  {
    "country": "IT",
    "name": "Cravanzana",
    "lat": "44.57448",
    "lng": "8.12731"
  },
  {
    "country": "IT",
    "name": "Craco-Sant'Angelo",
    "lat": "40.37992",
    "lng": "16.43708"
  },
  {
    "country": "IT",
    "name": "Cozzo",
    "lat": "45.19213",
    "lng": "8.61112"
  },
  {
    "country": "IT",
    "name": "Cozzana",
    "lat": "40.92025",
    "lng": "17.22259"
  },
  {
    "country": "IT",
    "name": "Covo",
    "lat": "45.49906",
    "lng": "9.77068"
  },
  {
    "country": "IT",
    "name": "Courmayeur",
    "lat": "45.79659",
    "lng": "6.96893"
  },
  {
    "country": "IT",
    "name": "Cottanello",
    "lat": "42.40811",
    "lng": "12.68592"
  },
  {
    "country": "IT",
    "name": "Cotignola",
    "lat": "44.38572",
    "lng": "11.93852"
  },
  {
    "country": "IT",
    "name": "Costiglione Saluzzo",
    "lat": "44.56453",
    "lng": "7.48543"
  },
  {
    "country": "IT",
    "name": "Costigliole d'Asti",
    "lat": "44.78517",
    "lng": "8.18405"
  },
  {
    "country": "IT",
    "name": "Costermano",
    "lat": "45.58606",
    "lng": "10.739"
  },
  {
    "country": "IT",
    "name": "Costa Volpino",
    "lat": "45.82768",
    "lng": "10.10076"
  },
  {
    "country": "IT",
    "name": "Costa Valle Imagna",
    "lat": "45.8028",
    "lng": "9.50413"
  },
  {
    "country": "IT",
    "name": "Costa Sant'Abramo",
    "lat": "45.16667",
    "lng": "9.96667"
  },
  {
    "country": "IT",
    "name": "Costarainera",
    "lat": "43.85477",
    "lng": "7.94106"
  },
  {
    "country": "IT",
    "name": "Costanzana",
    "lat": "45.23742",
    "lng": "8.36943"
  },
  {
    "country": "IT",
    "name": "Costano",
    "lat": "43.0442",
    "lng": "12.5341"
  },
  {
    "country": "IT",
    "name": "Costa di Rovigo",
    "lat": "45.05181",
    "lng": "11.6956"
  },
  {
    "country": "IT",
    "name": "Costa di Mezzate",
    "lat": "45.66278",
    "lng": "9.79556"
  },
  {
    "country": "IT",
    "name": "Costacciaro",
    "lat": "43.35866",
    "lng": "12.71262"
  },
  {
    "country": "IT",
    "name": "Costabissara",
    "lat": "45.58252",
    "lng": "11.48529"
  },
  {
    "country": "IT",
    "name": "Cossombrato",
    "lat": "44.98976",
    "lng": "8.13897"
  },
  {
    "country": "IT",
    "name": "Cossoine",
    "lat": "40.43068",
    "lng": "8.71578"
  },
  {
    "country": "IT",
    "name": "Cossignano",
    "lat": "42.98355",
    "lng": "13.69026"
  },
  {
    "country": "IT",
    "name": "Cossato",
    "lat": "45.57032",
    "lng": "8.18471"
  },
  {
    "country": "IT",
    "name": "Coseano",
    "lat": "46.09636",
    "lng": "13.02028"
  },
  {
    "country": "IT",
    "name": "Corvaro",
    "lat": "42.20538",
    "lng": "13.26496"
  },
  {
    "country": "IT",
    "name": "Corvara in Badia",
    "lat": "46.55037",
    "lng": "11.87342"
  },
  {
    "country": "IT",
    "name": "Corvara",
    "lat": "42.27511",
    "lng": "13.87363"
  },
  {
    "country": "IT",
    "name": "Cortona",
    "lat": "43.27467",
    "lng": "11.98533"
  },
  {
    "country": "IT",
    "name": "Cortina d'Ampezzo",
    "lat": "46.5369",
    "lng": "12.13903"
  },
  {
    "country": "IT",
    "name": "Cortiglione",
    "lat": "44.82225",
    "lng": "8.35796"
  },
  {
    "country": "IT",
    "name": "Corteolona",
    "lat": "45.15787",
    "lng": "9.37215"
  },
  {
    "country": "IT",
    "name": "Cortemilia",
    "lat": "44.58044",
    "lng": "8.19367"
  },
  {
    "country": "IT",
    "name": "Cortemaggiore",
    "lat": "44.99185",
    "lng": "9.92844"
  },
  {
    "country": "IT",
    "name": "Corte Franca",
    "lat": "45.62998",
    "lng": "9.98846"
  },
  {
    "country": "IT",
    "name": "Corte de' Cortesi",
    "lat": "45.27265",
    "lng": "10.00738"
  },
  {
    "country": "IT",
    "name": "Corte",
    "lat": "45.30835",
    "lng": "12.07174"
  },
  {
    "country": "IT",
    "name": "Cortazzone",
    "lat": "44.97915",
    "lng": "8.06123"
  },
  {
    "country": "IT",
    "name": "Cortanze",
    "lat": "45.01404",
    "lng": "8.08879"
  },
  {
    "country": "IT",
    "name": "Cortandone",
    "lat": "44.95915",
    "lng": "8.05843"
  },
  {
    "country": "IT",
    "name": "Cortaccia sulla Strada del Vino",
    "lat": "46.31401",
    "lng": "11.22388"
  },
  {
    "country": "IT",
    "name": "Corsico",
    "lat": "45.43099",
    "lng": "9.11093"
  },
  {
    "country": "IT",
    "name": "Corropoli",
    "lat": "42.8272",
    "lng": "13.83471"
  },
  {
    "country": "IT",
    "name": "Corridonia",
    "lat": "43.24677",
    "lng": "13.5069"
  },
  {
    "country": "IT",
    "name": "Correzzola",
    "lat": "45.23548",
    "lng": "12.06739"
  },
  {
    "country": "IT",
    "name": "Correggio",
    "lat": "44.76737",
    "lng": "10.78345"
  },
  {
    "country": "IT",
    "name": "Corpolò",
    "lat": "44.01905",
    "lng": "12.45266"
  },
  {
    "country": "IT",
    "name": "Cornuda",
    "lat": "45.83152",
    "lng": "12.00598"
  },
  {
    "country": "IT",
    "name": "Corno Giovine",
    "lat": "45.13415",
    "lng": "9.75766"
  },
  {
    "country": "IT",
    "name": "Corno di Rosazzo",
    "lat": "45.9911",
    "lng": "13.44368"
  },
  {
    "country": "IT",
    "name": "Corniglio",
    "lat": "44.47425",
    "lng": "10.09009"
  },
  {
    "country": "IT",
    "name": "Cornedo Vicentino",
    "lat": "45.61626",
    "lng": "11.33225"
  },
  {
    "country": "IT",
    "name": "Cornate d'Adda",
    "lat": "45.62811",
    "lng": "9.47378"
  },
  {
    "country": "IT",
    "name": "Cornaredo",
    "lat": "45.50128",
    "lng": "9.02681"
  },
  {
    "country": "IT",
    "name": "Cornale",
    "lat": "45.04344",
    "lng": "8.91096"
  },
  {
    "country": "IT",
    "name": "Cornalba",
    "lat": "45.84927",
    "lng": "9.74593"
  },
  {
    "country": "IT",
    "name": "Cornaiano",
    "lat": "46.46329",
    "lng": "11.28115"
  },
  {
    "country": "IT",
    "name": "Cormons",
    "lat": "45.95531",
    "lng": "13.46683"
  },
  {
    "country": "IT",
    "name": "Cormano",
    "lat": "45.54917",
    "lng": "9.15964"
  },
  {
    "country": "IT",
    "name": "Corleto Perticara",
    "lat": "40.38214",
    "lng": "16.03917"
  },
  {
    "country": "IT",
    "name": "Corleto Monforte",
    "lat": "40.43756",
    "lng": "15.38013"
  },
  {
    "country": "IT",
    "name": "Corio",
    "lat": "45.31222",
    "lng": "7.53351"
  },
  {
    "country": "IT",
    "name": "Corinaldo",
    "lat": "43.64107",
    "lng": "13.06004"
  },
  {
    "country": "IT",
    "name": "Corigliano d'Otranto",
    "lat": "40.15925",
    "lng": "18.25598"
  },
  {
    "country": "IT",
    "name": "Coriano",
    "lat": "43.96907",
    "lng": "12.60055"
  },
  {
    "country": "IT",
    "name": "Cori",
    "lat": "41.64358",
    "lng": "12.91121"
  },
  {
    "country": "IT",
    "name": "Corgeno",
    "lat": "45.74588",
    "lng": "8.68797"
  },
  {
    "country": "IT",
    "name": "Corfinio",
    "lat": "42.12149",
    "lng": "13.8394"
  },
  {
    "country": "IT",
    "name": "Coreglia Antelminelli",
    "lat": "44.06278",
    "lng": "10.52426"
  },
  {
    "country": "IT",
    "name": "Coredo",
    "lat": "46.34906",
    "lng": "11.09001"
  },
  {
    "country": "IT",
    "name": "Cordovado",
    "lat": "45.84425",
    "lng": "12.88537"
  },
  {
    "country": "IT",
    "name": "Cordignano",
    "lat": "45.94936",
    "lng": "12.41567"
  },
  {
    "country": "IT",
    "name": "Cordenons",
    "lat": "45.9836",
    "lng": "12.70038"
  },
  {
    "country": "IT",
    "name": "Corcolle",
    "lat": "41.90421",
    "lng": "12.73654"
  },
  {
    "country": "IT",
    "name": "Corciano",
    "lat": "43.12821",
    "lng": "12.28684"
  },
  {
    "country": "IT",
    "name": "Corchiano",
    "lat": "42.34495",
    "lng": "12.35688"
  },
  {
    "country": "IT",
    "name": "Corbola",
    "lat": "45.00272",
    "lng": "12.08567"
  },
  {
    "country": "IT",
    "name": "Corbetta",
    "lat": "45.46723",
    "lng": "8.91867"
  },
  {
    "country": "IT",
    "name": "Corbara",
    "lat": "40.72278",
    "lng": "14.59187"
  },
  {
    "country": "IT",
    "name": "Corbanese",
    "lat": "45.9457",
    "lng": "12.24027"
  },
  {
    "country": "IT",
    "name": "Corato",
    "lat": "41.15171",
    "lng": "16.41143"
  },
  {
    "country": "IT",
    "name": "Corana",
    "lat": "45.06289",
    "lng": "8.96952"
  },
  {
    "country": "IT",
    "name": "Coppito",
    "lat": "42.3673",
    "lng": "13.34358"
  },
  {
    "country": "IT",
    "name": "Copparo",
    "lat": "44.89263",
    "lng": "11.82287"
  },
  {
    "country": "IT",
    "name": "Copiano",
    "lat": "45.1975",
    "lng": "9.32462"
  },
  {
    "country": "IT",
    "name": "Copertino",
    "lat": "40.26821",
    "lng": "18.0543"
  },
  {
    "country": "IT",
    "name": "Nuova Conza della Campania",
    "lat": "40.8586",
    "lng": "15.33645"
  },
  {
    "country": "IT",
    "name": "Conversano",
    "lat": "40.96836",
    "lng": "17.11329"
  },
  {
    "country": "IT",
    "name": "Contursi Terme",
    "lat": "40.65026",
    "lng": "15.24163"
  },
  {
    "country": "IT",
    "name": "Controne",
    "lat": "40.51018",
    "lng": "15.20404"
  },
  {
    "country": "IT",
    "name": "Controguerra",
    "lat": "42.85398",
    "lng": "13.81775"
  },
  {
    "country": "IT",
    "name": "Contrada",
    "lat": "40.86811",
    "lng": "14.77747"
  },
  {
    "country": "IT",
    "name": "Contigliano",
    "lat": "42.41058",
    "lng": "12.77202"
  },
  {
    "country": "IT",
    "name": "Conselve",
    "lat": "45.23154",
    "lng": "11.87498"
  },
  {
    "country": "IT",
    "name": "Conselice",
    "lat": "44.51163",
    "lng": "11.82848"
  },
  {
    "country": "IT",
    "name": "Conscio",
    "lat": "45.61701",
    "lng": "12.28219"
  },
  {
    "country": "IT",
    "name": "Consandolo",
    "lat": "44.65606",
    "lng": "11.77524"
  },
  {
    "country": "IT",
    "name": "Configni",
    "lat": "42.42543",
    "lng": "12.64431"
  },
  {
    "country": "IT",
    "name": "Confienza",
    "lat": "45.33148",
    "lng": "8.55886"
  },
  {
    "country": "IT",
    "name": "Conegliano",
    "lat": "45.88805",
    "lng": "12.30201"
  },
  {
    "country": "IT",
    "name": "Condove",
    "lat": "45.11591",
    "lng": "7.30859"
  },
  {
    "country": "IT",
    "name": "Condino",
    "lat": "45.88167",
    "lng": "10.59366"
  },
  {
    "country": "IT",
    "name": "Concorezzo",
    "lat": "45.58854",
    "lng": "9.33393"
  },
  {
    "country": "IT",
    "name": "Concordia sulla Secchia",
    "lat": "44.91258",
    "lng": "10.98802"
  },
  {
    "country": "IT",
    "name": "Concordia Sagittaria",
    "lat": "45.76118",
    "lng": "12.82362"
  },
  {
    "country": "IT",
    "name": "Conco",
    "lat": "45.80043",
    "lng": "11.60962"
  },
  {
    "country": "IT",
    "name": "Concerviano",
    "lat": "42.32214",
    "lng": "12.98534"
  },
  {
    "country": "IT",
    "name": "Conca della Campania",
    "lat": "41.33174",
    "lng": "13.99142"
  },
  {
    "country": "IT",
    "name": "Conca dei Marini",
    "lat": "40.61754",
    "lng": "14.57311"
  },
  {
    "country": "IT",
    "name": "Conca Casale",
    "lat": "41.49512",
    "lng": "14.00682"
  },
  {
    "country": "IT",
    "name": "Comun Nuovo",
    "lat": "45.62291",
    "lng": "9.662"
  },
  {
    "country": "IT",
    "name": "Comunanza",
    "lat": "42.95719",
    "lng": "13.41341"
  },
  {
    "country": "IT",
    "name": "Compiobbi",
    "lat": "43.78485",
    "lng": "11.35909"
  },
  {
    "country": "IT",
    "name": "Compiano",
    "lat": "44.49605",
    "lng": "9.66207"
  },
  {
    "country": "IT",
    "name": "Como",
    "lat": "45.80819",
    "lng": "9.0832"
  },
  {
    "country": "IT",
    "name": "Commessaggio",
    "lat": "45.03754",
    "lng": "10.54535"
  },
  {
    "country": "IT",
    "name": "Comiziano",
    "lat": "40.95163",
    "lng": "14.55124"
  },
  {
    "country": "IT",
    "name": "Cizzago-Comezzano",
    "lat": "45.4688",
    "lng": "9.95816"
  },
  {
    "country": "IT",
    "name": "Comerio",
    "lat": "45.84191",
    "lng": "8.74207"
  },
  {
    "country": "IT",
    "name": "Comeglians",
    "lat": "46.51614",
    "lng": "12.86619"
  },
  {
    "country": "IT",
    "name": "Comeana",
    "lat": "43.79334",
    "lng": "11.05825"
  },
  {
    "country": "IT",
    "name": "Comazzo",
    "lat": "45.4419",
    "lng": "9.46278"
  },
  {
    "country": "IT",
    "name": "Comacchio",
    "lat": "44.69478",
    "lng": "12.18194"
  },
  {
    "country": "IT",
    "name": "Comabbio",
    "lat": "45.77359",
    "lng": "8.67833"
  },
  {
    "country": "IT",
    "name": "Colturano",
    "lat": "45.38151",
    "lng": "9.33443"
  },
  {
    "country": "IT",
    "name": "Colorno",
    "lat": "44.92572",
    "lng": "10.37361"
  },
  {
    "country": "IT",
    "name": "Colonnella",
    "lat": "42.8723",
    "lng": "13.86987"
  },
  {
    "country": "IT",
    "name": "Colonna",
    "lat": "41.83454",
    "lng": "12.75495"
  },
  {
    "country": "IT",
    "name": "Colombaro-Timoline",
    "lat": "45.64405",
    "lng": "9.99413"
  },
  {
    "country": "IT",
    "name": "Colombaro",
    "lat": "44.55153",
    "lng": "10.89628"
  },
  {
    "country": "IT",
    "name": "Cologno Monzese",
    "lat": "45.53004",
    "lng": "9.27795"
  },
  {
    "country": "IT",
    "name": "Cologno al Serio",
    "lat": "45.57604",
    "lng": "9.70892"
  },
  {
    "country": "IT",
    "name": "Cologne",
    "lat": "45.57862",
    "lng": "9.9418"
  },
  {
    "country": "IT",
    "name": "Cologna Veneta",
    "lat": "45.30777",
    "lng": "11.38032"
  },
  {
    "country": "IT",
    "name": "Colobraro",
    "lat": "40.18841",
    "lng": "16.4248"
  },
  {
    "country": "IT",
    "name": "Colmurano",
    "lat": "43.16485",
    "lng": "13.35908"
  },
  {
    "country": "IT",
    "name": "Colloredo di Prato",
    "lat": "46.05124",
    "lng": "13.14394"
  },
  {
    "country": "IT",
    "name": "Collobiano",
    "lat": "45.39665",
    "lng": "8.3475"
  },
  {
    "country": "IT",
    "name": "Colli sul Velino",
    "lat": "42.49828",
    "lng": "12.78153"
  },
  {
    "country": "IT",
    "name": "Collio",
    "lat": "45.81088",
    "lng": "10.33511"
  },
  {
    "country": "IT",
    "name": "Colli del Tronto",
    "lat": "42.8769",
    "lng": "13.74745"
  },
  {
    "country": "IT",
    "name": "Colliano",
    "lat": "40.72293",
    "lng": "15.28969"
  },
  {
    "country": "IT",
    "name": "Colli a Volturno",
    "lat": "41.60039",
    "lng": "14.10301"
  },
  {
    "country": "IT",
    "name": "Collevecchio",
    "lat": "42.33368",
    "lng": "12.55329"
  },
  {
    "country": "IT",
    "name": "Colletorto",
    "lat": "41.66165",
    "lng": "14.96773"
  },
  {
    "country": "IT",
    "name": "Colle Santa Lucia",
    "lat": "46.44852",
    "lng": "12.01399"
  },
  {
    "country": "IT",
    "name": "Colle Sannita",
    "lat": "41.36374",
    "lng": "14.8345"
  },
  {
    "country": "IT",
    "name": "Colle San Magno",
    "lat": "41.55019",
    "lng": "13.69485"
  },
  {
    "country": "IT",
    "name": "Collesalvetti",
    "lat": "43.59073",
    "lng": "10.47523"
  },
  {
    "country": "IT",
    "name": "Collepietro",
    "lat": "42.22089",
    "lng": "13.78101"
  },
  {
    "country": "IT",
    "name": "Collepepe",
    "lat": "42.91548",
    "lng": "12.39486"
  },
  {
    "country": "IT",
    "name": "Collepasso",
    "lat": "40.07115",
    "lng": "18.16222"
  },
  {
    "country": "IT",
    "name": "Collepardo",
    "lat": "41.76417",
    "lng": "13.36846"
  },
  {
    "country": "IT",
    "name": "Collemeto",
    "lat": "40.20885",
    "lng": "18.10285"
  },
  {
    "country": "IT",
    "name": "Collelongo",
    "lat": "41.88659",
    "lng": "13.5838"
  },
  {
    "country": "IT",
    "name": "Colle Isarco",
    "lat": "46.93857",
    "lng": "11.44245"
  },
  {
    "country": "IT",
    "name": "Collegno",
    "lat": "45.07873",
    "lng": "7.56735"
  },
  {
    "country": "IT",
    "name": "Collegiove",
    "lat": "42.17506",
    "lng": "13.03844"
  },
  {
    "country": "IT",
    "name": "Colleferro",
    "lat": "41.72722",
    "lng": "13.00481"
  },
  {
    "country": "IT",
    "name": "Colle di Val d'Elsa",
    "lat": "43.42107",
    "lng": "11.12739"
  },
  {
    "country": "IT",
    "name": "Colle di Tora",
    "lat": "42.20809",
    "lng": "12.94746"
  },
  {
    "country": "IT",
    "name": "Colledimezzo",
    "lat": "41.98606",
    "lng": "14.3869"
  },
  {
    "country": "IT",
    "name": "Colledimacine",
    "lat": "42.0037",
    "lng": "14.20079"
  },
  {
    "country": "IT",
    "name": "Colle di Fuori",
    "lat": "41.80091",
    "lng": "12.80683"
  },
  {
    "country": "IT",
    "name": "Colledara",
    "lat": "42.53918",
    "lng": "13.67556"
  },
  {
    "country": "IT",
    "name": "Colle d'Anchise",
    "lat": "41.50986",
    "lng": "14.51873"
  },
  {
    "country": "IT",
    "name": "Collecorvino",
    "lat": "42.46024",
    "lng": "14.01564"
  },
  {
    "country": "IT",
    "name": "Collecchio",
    "lat": "44.75197",
    "lng": "10.2154"
  },
  {
    "country": "IT",
    "name": "Collazzone",
    "lat": "42.90147",
    "lng": "12.43582"
  },
  {
    "country": "IT",
    "name": "Collarmele",
    "lat": "42.06031",
    "lng": "13.6267"
  },
  {
    "country": "IT",
    "name": "Collalto Sabino",
    "lat": "42.13522",
    "lng": "13.04841"
  },
  {
    "country": "IT",
    "name": "Collalbo",
    "lat": "46.53988",
    "lng": "11.45933"
  },
  {
    "country": "IT",
    "name": "Collagna",
    "lat": "44.34694",
    "lng": "10.2735"
  },
  {
    "country": "IT",
    "name": "Colico Piano",
    "lat": "46.13205",
    "lng": "9.37714"
  },
  {
    "country": "IT",
    "name": "Coli",
    "lat": "44.74582",
    "lng": "9.41468"
  },
  {
    "country": "IT",
    "name": "Colere",
    "lat": "45.97522",
    "lng": "10.08356"
  },
  {
    "country": "IT",
    "name": "Coldragone",
    "lat": "41.55458",
    "lng": "13.60399"
  },
  {
    "country": "IT",
    "name": "Colbordolo",
    "lat": "43.82006",
    "lng": "12.72105"
  },
  {
    "country": "IT",
    "name": "Colà",
    "lat": "45.47428",
    "lng": "10.74257"
  },
  {
    "country": "IT",
    "name": "Cogolo",
    "lat": "46.35252",
    "lng": "10.69282"
  },
  {
    "country": "IT",
    "name": "Cogollo del Cengio",
    "lat": "45.78397",
    "lng": "11.42527"
  },
  {
    "country": "IT",
    "name": "Cogoleto",
    "lat": "44.38996",
    "lng": "8.64692"
  },
  {
    "country": "IT",
    "name": "Cogne",
    "lat": "45.60742",
    "lng": "7.35803"
  },
  {
    "country": "IT",
    "name": "Coggiola",
    "lat": "45.6864",
    "lng": "8.18252"
  },
  {
    "country": "IT",
    "name": "Codrongianos",
    "lat": "40.65603",
    "lng": "8.6814"
  },
  {
    "country": "IT",
    "name": "Codroipo",
    "lat": "45.96469",
    "lng": "12.97985"
  },
  {
    "country": "IT",
    "name": "Codogno",
    "lat": "45.16187",
    "lng": "9.70216"
  },
  {
    "country": "IT",
    "name": "Codognè",
    "lat": "45.86047",
    "lng": "12.41284"
  },
  {
    "country": "IT",
    "name": "Codisotto",
    "lat": "44.98278",
    "lng": "10.7275"
  },
  {
    "country": "IT",
    "name": "Codigoro",
    "lat": "44.83093",
    "lng": "12.11073"
  },
  {
    "country": "IT",
    "name": "Codevilla",
    "lat": "44.96353",
    "lng": "9.05773"
  },
  {
    "country": "IT",
    "name": "Codevigo",
    "lat": "45.26628",
    "lng": "12.09961"
  },
  {
    "country": "IT",
    "name": "Codemondo-Quaresimo",
    "lat": "44.69082",
    "lng": "10.55098"
  },
  {
    "country": "IT",
    "name": "Codaruina",
    "lat": "40.92847",
    "lng": "8.82398"
  },
  {
    "country": "IT",
    "name": "Cocullo",
    "lat": "42.03283",
    "lng": "13.775"
  },
  {
    "country": "IT",
    "name": "Cocquio",
    "lat": "45.86288",
    "lng": "8.68823"
  },
  {
    "country": "IT",
    "name": "Cocconato",
    "lat": "45.08642",
    "lng": "8.04019"
  },
  {
    "country": "IT",
    "name": "Coccaglio",
    "lat": "45.56399",
    "lng": "9.97224"
  },
  {
    "country": "IT",
    "name": "Coazze",
    "lat": "45.05181",
    "lng": "7.30063"
  },
  {
    "country": "IT",
    "name": "Clusone",
    "lat": "45.88663",
    "lng": "9.94646"
  },
  {
    "country": "IT",
    "name": "Clusane",
    "lat": "45.66247",
    "lng": "10.00005"
  },
  {
    "country": "IT",
    "name": "Cles",
    "lat": "46.36294",
    "lng": "11.03276"
  },
  {
    "country": "IT",
    "name": "Claviere",
    "lat": "44.93922",
    "lng": "6.75213"
  },
  {
    "country": "IT",
    "name": "Clauzetto",
    "lat": "46.22931",
    "lng": "12.91662"
  },
  {
    "country": "IT",
    "name": "Classe",
    "lat": "44.37955",
    "lng": "12.23654"
  },
  {
    "country": "IT",
    "name": "Cizzago",
    "lat": "45.47128",
    "lng": "9.95006"
  },
  {
    "country": "IT",
    "name": "Civitella San Paolo",
    "lat": "42.19935",
    "lng": "12.57455"
  },
  {
    "country": "IT",
    "name": "Civitella Roveto",
    "lat": "41.91329",
    "lng": "13.42396"
  },
  {
    "country": "IT",
    "name": "Civitella Messer Raimondo",
    "lat": "42.08893",
    "lng": "14.21701"
  },
  {
    "country": "IT",
    "name": "Civitella Marittima",
    "lat": "42.99408",
    "lng": "11.28116"
  },
  {
    "country": "IT",
    "name": "Civitella in Val di Chiana",
    "lat": "43.41731",
    "lng": "11.7229"
  },
  {
    "country": "IT",
    "name": "Civitella di Romagna",
    "lat": "44.00785",
    "lng": "11.94398"
  },
  {
    "country": "IT",
    "name": "Civitella del Tronto",
    "lat": "42.77298",
    "lng": "13.67626"
  },
  {
    "country": "IT",
    "name": "Civitella d'Agliano",
    "lat": "42.60296",
    "lng": "12.18624"
  },
  {
    "country": "IT",
    "name": "Civitella Casanova",
    "lat": "42.36391",
    "lng": "13.88514"
  },
  {
    "country": "IT",
    "name": "Civitella Alfedena",
    "lat": "41.76533",
    "lng": "13.94271"
  },
  {
    "country": "IT",
    "name": "Civitavecchia",
    "lat": "42.09325",
    "lng": "11.79674"
  },
  {
    "country": "IT",
    "name": "Civitaquana",
    "lat": "42.32578",
    "lng": "13.90012"
  },
  {
    "country": "IT",
    "name": "Civitanova del Sannio",
    "lat": "41.66829",
    "lng": "14.40285"
  },
  {
    "country": "IT",
    "name": "Civitanova Alta",
    "lat": "43.31619",
    "lng": "13.67978"
  },
  {
    "country": "IT",
    "name": "Civitaluparella",
    "lat": "41.9449",
    "lng": "14.30135"
  },
  {
    "country": "IT",
    "name": "Civita d'Antino",
    "lat": "41.88629",
    "lng": "13.47215"
  },
  {
    "country": "IT",
    "name": "Civita Castellana",
    "lat": "42.29304",
    "lng": "12.40885"
  },
  {
    "country": "IT",
    "name": "Civitacampomarano",
    "lat": "41.78032",
    "lng": "14.68919"
  },
  {
    "country": "IT",
    "name": "Cividate Camuno",
    "lat": "45.94087",
    "lng": "10.2661"
  },
  {
    "country": "IT",
    "name": "Cividate al Piano",
    "lat": "45.55465",
    "lng": "9.83024"
  },
  {
    "country": "IT",
    "name": "Cividale del Friuli",
    "lat": "46.09019",
    "lng": "13.42861"
  },
  {
    "country": "IT",
    "name": "Civezzano",
    "lat": "46.09133",
    "lng": "11.18468"
  },
  {
    "country": "IT",
    "name": "Civezza",
    "lat": "43.87982",
    "lng": "7.95165"
  },
  {
    "country": "IT",
    "name": "Cittiglio",
    "lat": "45.89587",
    "lng": "8.66551"
  },
  {
    "country": "IT",
    "name": "Città Sant'Angelo",
    "lat": "42.51254",
    "lng": "14.06203"
  },
  {
    "country": "IT",
    "name": "Cittareale",
    "lat": "42.61624",
    "lng": "13.15788"
  },
  {
    "country": "IT",
    "name": "Cittaducale",
    "lat": "42.38664",
    "lng": "12.95497"
  },
  {
    "country": "IT",
    "name": "Città di Castello",
    "lat": "43.46556",
    "lng": "12.2375"
  },
  {
    "country": "IT",
    "name": "Città della Pieve",
    "lat": "42.95934",
    "lng": "12.00696"
  },
  {
    "country": "IT",
    "name": "Cittadella",
    "lat": "45.64523",
    "lng": "11.78453"
  },
  {
    "country": "IT",
    "name": "Citerna",
    "lat": "43.49882",
    "lng": "12.11376"
  },
  {
    "country": "IT",
    "name": "Cisternino",
    "lat": "40.74326",
    "lng": "17.42587"
  },
  {
    "country": "IT",
    "name": "Cisterna di Latina",
    "lat": "41.5908",
    "lng": "12.82808"
  },
  {
    "country": "IT",
    "name": "Cisterna d'Asti",
    "lat": "44.82525",
    "lng": "8.00076"
  },
  {
    "country": "IT",
    "name": "Cison di Valmarino",
    "lat": "45.96694",
    "lng": "12.14267"
  },
  {
    "country": "IT",
    "name": "Cismon del Grappa",
    "lat": "45.92026",
    "lng": "11.72816"
  },
  {
    "country": "IT",
    "name": "Cisliano",
    "lat": "45.44371",
    "lng": "8.98695"
  },
  {
    "country": "IT",
    "name": "Cislago",
    "lat": "45.65928",
    "lng": "8.97272"
  },
  {
    "country": "IT",
    "name": "Ciserano",
    "lat": "45.58792",
    "lng": "9.60115"
  },
  {
    "country": "IT",
    "name": "Cisano",
    "lat": "44.08565",
    "lng": "8.14829"
  },
  {
    "country": "IT",
    "name": "Cisano Bergamasco",
    "lat": "45.742",
    "lng": "9.47146"
  },
  {
    "country": "IT",
    "name": "Cirimido",
    "lat": "45.69978",
    "lng": "9.01254"
  },
  {
    "country": "IT",
    "name": "Cirigliano",
    "lat": "40.39376",
    "lng": "16.17194"
  },
  {
    "country": "IT",
    "name": "Ciriè",
    "lat": "45.23486",
    "lng": "7.60125"
  },
  {
    "country": "IT",
    "name": "Circello",
    "lat": "41.35455",
    "lng": "14.8091"
  },
  {
    "country": "IT",
    "name": "Cipressa",
    "lat": "43.85205",
    "lng": "7.93144"
  },
  {
    "country": "IT",
    "name": "Ciorlano",
    "lat": "41.45022",
    "lng": "14.15832"
  },
  {
    "country": "IT",
    "name": "Cinzano",
    "lat": "45.09528",
    "lng": "7.92427"
  },
  {
    "country": "IT",
    "name": "Cinto Caomaggiore",
    "lat": "45.82758",
    "lng": "12.78126"
  },
  {
    "country": "IT",
    "name": "Cinte Tesino",
    "lat": "46.05726",
    "lng": "11.61435"
  },
  {
    "country": "IT",
    "name": "Cintano",
    "lat": "45.42812",
    "lng": "7.68827"
  },
  {
    "country": "IT",
    "name": "Capanne-Prato-Cinquale",
    "lat": "43.9972",
    "lng": "10.15636"
  },
  {
    "country": "IT",
    "name": "Cinisello Balsamo",
    "lat": "45.55823",
    "lng": "9.21495"
  },
  {
    "country": "IT",
    "name": "Cinigiano",
    "lat": "42.89059",
    "lng": "11.39196"
  },
  {
    "country": "IT",
    "name": "Cingoli",
    "lat": "43.37573",
    "lng": "13.20787"
  },
  {
    "country": "IT",
    "name": "Cingia de' Botti",
    "lat": "45.08507",
    "lng": "10.27548"
  },
  {
    "country": "IT",
    "name": "Cineto Romano",
    "lat": "42.05014",
    "lng": "12.9608"
  },
  {
    "country": "IT",
    "name": "Cimolais",
    "lat": "46.289",
    "lng": "12.43792"
  },
  {
    "country": "IT",
    "name": "Cimitile",
    "lat": "40.94231",
    "lng": "14.52558"
  },
  {
    "country": "IT",
    "name": "Cimego",
    "lat": "45.9119",
    "lng": "10.61337"
  },
  {
    "country": "IT",
    "name": "Cimbergo",
    "lat": "46.0241",
    "lng": "10.36566"
  },
  {
    "country": "IT",
    "name": "Cimadolmo",
    "lat": "45.78524",
    "lng": "12.3651"
  },
  {
    "country": "IT",
    "name": "Cilavegna",
    "lat": "45.31067",
    "lng": "8.74469"
  },
  {
    "country": "IT",
    "name": "Cigole",
    "lat": "45.3076",
    "lng": "10.18977"
  },
  {
    "country": "IT",
    "name": "Cigliano",
    "lat": "45.30804",
    "lng": "8.02316"
  },
  {
    "country": "IT",
    "name": "Cicognolo",
    "lat": "45.16762",
    "lng": "10.19407"
  },
  {
    "country": "IT",
    "name": "Ciciliano",
    "lat": "41.9599",
    "lng": "12.94163"
  },
  {
    "country": "IT",
    "name": "Cicerale",
    "lat": "40.34404",
    "lng": "15.12959"
  },
  {
    "country": "IT",
    "name": "Cicciano",
    "lat": "40.96402",
    "lng": "14.53487"
  },
  {
    "country": "IT",
    "name": "Cicagna",
    "lat": "44.40714",
    "lng": "9.23917"
  },
  {
    "country": "IT",
    "name": "Cibiana",
    "lat": "46.38856",
    "lng": "12.28658"
  },
  {
    "country": "IT",
    "name": "Ciano d'Enza",
    "lat": "44.59982",
    "lng": "10.4104"
  },
  {
    "country": "IT",
    "name": "Sant'Andrea-Pizzone-Ciamprisco",
    "lat": "41.15",
    "lng": "14.03333"
  },
  {
    "country": "IT",
    "name": "Ciampino",
    "lat": "41.80064",
    "lng": "12.60158"
  },
  {
    "country": "IT",
    "name": "Chivasso",
    "lat": "45.19093",
    "lng": "7.88981"
  },
  {
    "country": "IT",
    "name": "Chiusi della Verna",
    "lat": "43.69745",
    "lng": "11.93504"
  },
  {
    "country": "IT",
    "name": "Chiusi",
    "lat": "43.01418",
    "lng": "11.94791"
  },
  {
    "country": "IT",
    "name": "Chiusdino",
    "lat": "43.15454",
    "lng": "11.0831"
  },
  {
    "country": "IT",
    "name": "Chiusavecchia",
    "lat": "43.96726",
    "lng": "7.98443"
  },
  {
    "country": "IT",
    "name": "Chiusano di San Domenico",
    "lat": "40.93312",
    "lng": "14.91634"
  },
  {
    "country": "IT",
    "name": "Chiusanico",
    "lat": "43.97303",
    "lng": "7.99185"
  },
  {
    "country": "IT",
    "name": "Chiusaforte",
    "lat": "46.40663",
    "lng": "13.30552"
  },
  {
    "country": "IT",
    "name": "Chiusa di Pesio",
    "lat": "44.32588",
    "lng": "7.67431"
  },
  {
    "country": "IT",
    "name": "Chiusa",
    "lat": "46.64001",
    "lng": "11.56573"
  },
  {
    "country": "IT",
    "name": "Chiuro",
    "lat": "46.16722",
    "lng": "9.98584"
  },
  {
    "country": "IT",
    "name": "Chiuppano",
    "lat": "45.763",
    "lng": "11.45777"
  },
  {
    "country": "IT",
    "name": "Chitignano",
    "lat": "43.66163",
    "lng": "11.88135"
  },
  {
    "country": "IT",
    "name": "Chions",
    "lat": "45.84546",
    "lng": "12.71232"
  },
  {
    "country": "IT",
    "name": "Chiomonte",
    "lat": "45.11909",
    "lng": "6.9842"
  },
  {
    "country": "IT",
    "name": "Chioggia",
    "lat": "45.21857",
    "lng": "12.27774"
  },
  {
    "country": "IT",
    "name": "Chieuti",
    "lat": "41.84486",
    "lng": "15.16681"
  },
  {
    "country": "IT",
    "name": "Chieti",
    "lat": "42.34827",
    "lng": "14.16494"
  },
  {
    "country": "IT",
    "name": "Chiesina Uzzanese",
    "lat": "43.83891",
    "lng": "10.72044"
  },
  {
    "country": "IT",
    "name": "Chiesa in Valmalenco",
    "lat": "46.26715",
    "lng": "9.84905"
  },
  {
    "country": "IT",
    "name": "Gionghi-Cappella",
    "lat": "45.9368",
    "lng": "11.27478"
  },
  {
    "country": "IT",
    "name": "Chieri",
    "lat": "45.01054",
    "lng": "7.82133"
  },
  {
    "country": "IT",
    "name": "Chienes",
    "lat": "46.8068",
    "lng": "11.84002"
  },
  {
    "country": "IT",
    "name": "Chiavenna",
    "lat": "46.32063",
    "lng": "9.39816"
  },
  {
    "country": "IT",
    "name": "Chiavari",
    "lat": "44.31771",
    "lng": "9.32241"
  },
  {
    "country": "IT",
    "name": "Chiauci",
    "lat": "41.67791",
    "lng": "14.38393"
  },
  {
    "country": "IT",
    "name": "Chiaromonte",
    "lat": "40.12323",
    "lng": "16.2144"
  },
  {
    "country": "IT",
    "name": "Chiari",
    "lat": "45.53763",
    "lng": "9.92699"
  },
  {
    "country": "IT",
    "name": "Chiaravalle",
    "lat": "43.60114",
    "lng": "13.32511"
  },
  {
    "country": "IT",
    "name": "Chiarano",
    "lat": "45.72959",
    "lng": "12.57166"
  },
  {
    "country": "IT",
    "name": "Chiaramonti",
    "lat": "40.74829",
    "lng": "8.82114"
  },
  {
    "country": "IT",
    "name": "Chianni",
    "lat": "43.48153",
    "lng": "10.64133"
  },
  {
    "country": "IT",
    "name": "Chianciano Terme",
    "lat": "43.04181",
    "lng": "11.81205"
  },
  {
    "country": "IT",
    "name": "Chianche",
    "lat": "41.04632",
    "lng": "14.78904"
  },
  {
    "country": "IT",
    "name": "Chiampo",
    "lat": "45.54746",
    "lng": "11.28285"
  },
  {
    "country": "IT",
    "name": "Chialamberto",
    "lat": "45.36295",
    "lng": "7.34363"
  },
  {
    "country": "IT",
    "name": "Cheremule",
    "lat": "40.50455",
    "lng": "8.72582"
  },
  {
    "country": "IT",
    "name": "Cherasco",
    "lat": "44.64345",
    "lng": "7.85818"
  },
  {
    "country": "IT",
    "name": "Chatillon",
    "lat": "45.74991",
    "lng": "7.61668"
  },
  {
    "country": "IT",
    "name": "Charvensod",
    "lat": "45.72025",
    "lng": "7.32433"
  },
  {
    "country": "IT",
    "name": "Champdepraz",
    "lat": "45.68526",
    "lng": "7.65681"
  },
  {
    "country": "IT",
    "name": "Chambave",
    "lat": "45.74426",
    "lng": "7.54931"
  },
  {
    "country": "IT",
    "name": "Cevo",
    "lat": "46.08089",
    "lng": "10.36952"
  },
  {
    "country": "IT",
    "name": "Ceva",
    "lat": "44.38505",
    "lng": "8.02769"
  },
  {
    "country": "IT",
    "name": "Cetona",
    "lat": "42.96655",
    "lng": "11.90268"
  },
  {
    "country": "IT",
    "name": "Ceto",
    "lat": "46.00259",
    "lng": "10.35196"
  },
  {
    "country": "IT",
    "name": "Cetara",
    "lat": "40.64756",
    "lng": "14.70091"
  },
  {
    "country": "IT",
    "name": "Coccanile-Cesta",
    "lat": "44.91667",
    "lng": "11.86667"
  },
  {
    "country": "IT",
    "name": "Cessole",
    "lat": "44.64877",
    "lng": "8.24438"
  },
  {
    "country": "IT",
    "name": "Cessapalombo",
    "lat": "43.10825",
    "lng": "13.25758"
  },
  {
    "country": "IT",
    "name": "Cessalto",
    "lat": "45.71356",
    "lng": "12.61302"
  },
  {
    "country": "IT",
    "name": "Cesiomaggiore",
    "lat": "46.08675",
    "lng": "11.98539"
  },
  {
    "country": "IT",
    "name": "Cesio",
    "lat": "44.00803",
    "lng": "7.97515"
  },
  {
    "country": "IT",
    "name": "Cesenatico",
    "lat": "44.19987",
    "lng": "12.3991"
  },
  {
    "country": "IT",
    "name": "Cesena",
    "lat": "44.1391",
    "lng": "12.24315"
  },
  {
    "country": "IT",
    "name": "Cesarolo",
    "lat": "45.71884",
    "lng": "13.01555"
  },
  {
    "country": "IT",
    "name": "Porto Cesareo",
    "lat": "40.26228",
    "lng": "17.89896"
  },
  {
    "country": "IT",
    "name": "Cesara",
    "lat": "45.83379",
    "lng": "8.36777"
  },
  {
    "country": "IT",
    "name": "Cesano Maderno",
    "lat": "45.62915",
    "lng": "9.15189"
  },
  {
    "country": "IT",
    "name": "Cesano",
    "lat": "42.07375",
    "lng": "12.33711"
  },
  {
    "country": "IT",
    "name": "Cesana Torinese",
    "lat": "44.9534",
    "lng": "6.79199"
  },
  {
    "country": "IT",
    "name": "Cesa",
    "lat": "43.31624",
    "lng": "11.81262"
  },
  {
    "country": "IT",
    "name": "Cesa",
    "lat": "40.96287",
    "lng": "14.23081"
  },
  {
    "country": "IT",
    "name": "Cervo",
    "lat": "43.92572",
    "lng": "8.11529"
  },
  {
    "country": "IT",
    "name": "Cervino",
    "lat": "41.04001",
    "lng": "14.42403"
  },
  {
    "country": "IT",
    "name": "Cervignano del Friuli",
    "lat": "45.82082",
    "lng": "13.33929"
  },
  {
    "country": "IT",
    "name": "Cervia",
    "lat": "44.26204",
    "lng": "12.34812"
  },
  {
    "country": "IT",
    "name": "Cerveteri",
    "lat": "41.9908",
    "lng": "12.09082"
  },
  {
    "country": "IT",
    "name": "Cervesina",
    "lat": "45.06054",
    "lng": "9.01676"
  },
  {
    "country": "IT",
    "name": "Cervere",
    "lat": "44.63428",
    "lng": "7.78884"
  },
  {
    "country": "IT",
    "name": "Cerveno",
    "lat": "46.00176",
    "lng": "10.3283"
  },
  {
    "country": "IT",
    "name": "Cervaro",
    "lat": "41.48278",
    "lng": "13.90218"
  },
  {
    "country": "IT",
    "name": "Cervara di Roma",
    "lat": "41.98822",
    "lng": "13.06799"
  },
  {
    "country": "IT",
    "name": "Certosa di Pavia",
    "lat": "45.2542",
    "lng": "9.1329"
  },
  {
    "country": "IT",
    "name": "Certosa",
    "lat": "46.7045",
    "lng": "10.91088"
  },
  {
    "country": "IT",
    "name": "Certaldo",
    "lat": "43.54768",
    "lng": "11.03924"
  },
  {
    "country": "IT",
    "name": "Cersosimo",
    "lat": "40.04703",
    "lng": "16.35059"
  },
  {
    "country": "IT",
    "name": "Cerro Maggiore",
    "lat": "45.59366",
    "lng": "8.95428"
  },
  {
    "country": "IT",
    "name": "Cerro al Volturno",
    "lat": "41.65418",
    "lng": "14.10321"
  },
  {
    "country": "IT",
    "name": "Cerrione",
    "lat": "45.46933",
    "lng": "8.0684"
  },
  {
    "country": "IT",
    "name": "Cerreto Sannita",
    "lat": "41.28296",
    "lng": "14.56147"
  },
  {
    "country": "IT",
    "name": "Cerreto Laziale",
    "lat": "41.94332",
    "lng": "12.98169"
  },
  {
    "country": "IT",
    "name": "Cerreto Guidi",
    "lat": "43.75851",
    "lng": "10.88191"
  },
  {
    "country": "IT",
    "name": "Cerreto di Spoleto",
    "lat": "42.82188",
    "lng": "12.92032"
  },
  {
    "country": "IT",
    "name": "Cerreto d'Esi",
    "lat": "43.31668",
    "lng": "12.98771"
  },
  {
    "country": "IT",
    "name": "Cerratina",
    "lat": "42.39007",
    "lng": "14.10338"
  },
  {
    "country": "IT",
    "name": "Cernusco sul Naviglio",
    "lat": "45.52526",
    "lng": "9.33297"
  },
  {
    "country": "IT",
    "name": "Cernobbio",
    "lat": "45.84307",
    "lng": "9.07194"
  },
  {
    "country": "IT",
    "name": "Cermignano",
    "lat": "42.59131",
    "lng": "13.7954"
  },
  {
    "country": "IT",
    "name": "Cermes",
    "lat": "46.63277",
    "lng": "11.14696"
  },
  {
    "country": "IT",
    "name": "Cermenate",
    "lat": "45.70198",
    "lng": "9.08361"
  },
  {
    "country": "IT",
    "name": "Cerlongo",
    "lat": "45.27862",
    "lng": "10.64985"
  },
  {
    "country": "IT",
    "name": "Cerignola",
    "lat": "41.26523",
    "lng": "15.89559"
  },
  {
    "country": "IT",
    "name": "Ceriano Laghetto",
    "lat": "45.62928",
    "lng": "9.08017"
  },
  {
    "country": "IT",
    "name": "Ceriana",
    "lat": "43.88091",
    "lng": "7.77476"
  },
  {
    "country": "IT",
    "name": "Ceriale",
    "lat": "44.09128",
    "lng": "8.22893"
  },
  {
    "country": "IT",
    "name": "Cergnago",
    "lat": "45.19826",
    "lng": "8.77164"
  },
  {
    "country": "IT",
    "name": "Cerfignano",
    "lat": "40.06107",
    "lng": "18.44291"
  },
  {
    "country": "IT",
    "name": "Cerete Alto",
    "lat": "45.86729",
    "lng": "9.99466"
  },
  {
    "country": "IT",
    "name": "Ceresole Reale",
    "lat": "45.43235",
    "lng": "7.23506"
  },
  {
    "country": "IT",
    "name": "Cereseto",
    "lat": "45.08685",
    "lng": "8.31817"
  },
  {
    "country": "IT",
    "name": "Cerese",
    "lat": "45.11814",
    "lng": "10.78877"
  },
  {
    "country": "IT",
    "name": "Ceresara",
    "lat": "45.26228",
    "lng": "10.56958"
  },
  {
    "country": "IT",
    "name": "Ceres",
    "lat": "45.31336",
    "lng": "7.38961"
  },
  {
    "country": "IT",
    "name": "Ceregnano",
    "lat": "45.04811",
    "lng": "11.86792"
  },
  {
    "country": "IT",
    "name": "Cerea",
    "lat": "45.18936",
    "lng": "11.21661"
  },
  {
    "country": "IT",
    "name": "Cercola",
    "lat": "40.86043",
    "lng": "14.35733"
  },
  {
    "country": "IT",
    "name": "Cercino",
    "lat": "46.15809",
    "lng": "9.50814"
  },
  {
    "country": "IT",
    "name": "Cerchio",
    "lat": "42.06357",
    "lng": "13.60006"
  },
  {
    "country": "IT",
    "name": "Cercepiccola",
    "lat": "41.45982",
    "lng": "14.66487"
  },
  {
    "country": "IT",
    "name": "Cercemaggiore",
    "lat": "41.4613",
    "lng": "14.72402"
  },
  {
    "country": "IT",
    "name": "Cerbaia",
    "lat": "43.68519",
    "lng": "11.12889"
  },
  {
    "country": "IT",
    "name": "Cerasolo",
    "lat": "43.98805",
    "lng": "12.52988"
  },
  {
    "country": "IT",
    "name": "Ceraso",
    "lat": "40.1943",
    "lng": "15.25606"
  },
  {
    "country": "IT",
    "name": "Cerano",
    "lat": "45.40915",
    "lng": "8.78351"
  },
  {
    "country": "IT",
    "name": "Ceprano",
    "lat": "41.54572",
    "lng": "13.51473"
  },
  {
    "country": "IT",
    "name": "Ceppaloni",
    "lat": "41.04523",
    "lng": "14.76102"
  },
  {
    "country": "IT",
    "name": "Ceparana-Carpena",
    "lat": "44.16667",
    "lng": "9.88333"
  },
  {
    "country": "IT",
    "name": "Cepagatti",
    "lat": "42.36506",
    "lng": "14.07424"
  },
  {
    "country": "IT",
    "name": "Centrale",
    "lat": "45.72737",
    "lng": "11.48031"
  },
  {
    "country": "IT",
    "name": "Centola",
    "lat": "40.0698",
    "lng": "15.31191"
  },
  {
    "country": "IT",
    "name": "Cento",
    "lat": "44.73099",
    "lng": "11.28716"
  },
  {
    "country": "IT",
    "name": "Centa San Nicolò",
    "lat": "45.9693",
    "lng": "11.23238"
  },
  {
    "country": "IT",
    "name": "Centallo",
    "lat": "44.50153",
    "lng": "7.58783"
  },
  {
    "country": "IT",
    "name": "Cengio Alto",
    "lat": "44.38443",
    "lng": "8.19758"
  },
  {
    "country": "IT",
    "name": "Ceneselli",
    "lat": "45.01377",
    "lng": "11.36936"
  },
  {
    "country": "IT",
    "name": "Cene",
    "lat": "45.78062",
    "lng": "9.82657"
  },
  {
    "country": "IT",
    "name": "Cencenighe Agordino",
    "lat": "46.35184",
    "lng": "11.96823"
  },
  {
    "country": "IT",
    "name": "Cenaia",
    "lat": "43.60637",
    "lng": "10.53571"
  },
  {
    "country": "IT",
    "name": "Cembra",
    "lat": "46.17489",
    "lng": "11.22174"
  },
  {
    "country": "IT",
    "name": "Cellole",
    "lat": "41.20338",
    "lng": "13.85332"
  },
  {
    "country": "IT",
    "name": "Cellio",
    "lat": "45.75505",
    "lng": "8.31185"
  },
  {
    "country": "IT",
    "name": "Cellino San Marco",
    "lat": "40.47133",
    "lng": "17.96427"
  },
  {
    "country": "IT",
    "name": "Cellino Attanasio",
    "lat": "42.58574",
    "lng": "13.8605"
  },
  {
    "country": "IT",
    "name": "Celle di San Vito",
    "lat": "41.32593",
    "lng": "15.18104"
  },
  {
    "country": "IT",
    "name": "Cellere",
    "lat": "42.51024",
    "lng": "11.77079"
  },
  {
    "country": "IT",
    "name": "Celleno",
    "lat": "42.56039",
    "lng": "12.12442"
  },
  {
    "country": "IT",
    "name": "Celle Ligure",
    "lat": "44.34509",
    "lng": "8.54685"
  },
  {
    "country": "IT",
    "name": "Celle di Bulgheria",
    "lat": "40.0954",
    "lng": "15.40324"
  },
  {
    "country": "IT",
    "name": "Cellamare",
    "lat": "41.01969",
    "lng": "16.92741"
  },
  {
    "country": "IT",
    "name": "Celenza Valfortore",
    "lat": "41.56048",
    "lng": "14.97898"
  },
  {
    "country": "IT",
    "name": "Celenza sul Trigno",
    "lat": "41.87198",
    "lng": "14.57893"
  },
  {
    "country": "IT",
    "name": "Celano",
    "lat": "42.08077",
    "lng": "13.517"
  },
  {
    "country": "IT",
    "name": "Ceglie Messapica",
    "lat": "40.6462",
    "lng": "17.51661"
  },
  {
    "country": "IT",
    "name": "Ceggia",
    "lat": "45.687",
    "lng": "12.64228"
  },
  {
    "country": "IT",
    "name": "Cedrasco",
    "lat": "46.14932",
    "lng": "9.76803"
  },
  {
    "country": "IT",
    "name": "Cedegolo",
    "lat": "46.07398",
    "lng": "10.35141"
  },
  {
    "country": "IT",
    "name": "Cecina",
    "lat": "43.30621",
    "lng": "10.51729"
  },
  {
    "country": "IT",
    "name": "Cecchini",
    "lat": "45.86551",
    "lng": "12.6222"
  },
  {
    "country": "IT",
    "name": "Cecchina",
    "lat": "41.70161",
    "lng": "12.64972"
  },
  {
    "country": "IT",
    "name": "Ceccano",
    "lat": "41.57236",
    "lng": "13.32901"
  },
  {
    "country": "IT",
    "name": "Cazzano Sant'Andrea",
    "lat": "45.81118",
    "lng": "9.88493"
  },
  {
    "country": "IT",
    "name": "Cazzago San Martino-Calino",
    "lat": "45.58434",
    "lng": "10.02328"
  },
  {
    "country": "IT",
    "name": "Cavriglia-Monastero",
    "lat": "43.52025",
    "lng": "11.48693"
  },
  {
    "country": "IT",
    "name": "Cavriana",
    "lat": "45.34766",
    "lng": "10.59598"
  },
  {
    "country": "IT",
    "name": "Cavriago",
    "lat": "44.69457",
    "lng": "10.52591"
  },
  {
    "country": "IT",
    "name": "Cavour",
    "lat": "44.79286",
    "lng": "7.37438"
  },
  {
    "country": "IT",
    "name": "Cavolano-Schiavoi",
    "lat": "45.93333",
    "lng": "12.5"
  },
  {
    "country": "IT",
    "name": "Cavezzo",
    "lat": "44.835",
    "lng": "11.0289"
  },
  {
    "country": "IT",
    "name": "Cavenago di Brianza",
    "lat": "45.58297",
    "lng": "9.41261"
  },
  {
    "country": "IT",
    "name": "Cavenago d'Adda",
    "lat": "45.28253",
    "lng": "9.59872"
  },
  {
    "country": "IT",
    "name": "Cavedago",
    "lat": "46.18486",
    "lng": "11.03277"
  },
  {
    "country": "IT",
    "name": "Cave",
    "lat": "41.81682",
    "lng": "12.94055"
  },
  {
    "country": "IT",
    "name": "Cavazzo Carnico",
    "lat": "46.36793",
    "lng": "13.04075"
  },
  {
    "country": "IT",
    "name": "Cavasso Nuovo",
    "lat": "46.19441",
    "lng": "12.77193"
  },
  {
    "country": "IT",
    "name": "Cavarzere",
    "lat": "45.13518",
    "lng": "12.08453"
  },
  {
    "country": "IT",
    "name": "Cavaria Con Premezzo",
    "lat": "45.69247",
    "lng": "8.80299"
  },
  {
    "country": "IT",
    "name": "Cavargna",
    "lat": "46.09068",
    "lng": "9.11205"
  },
  {
    "country": "IT",
    "name": "Cavareno",
    "lat": "46.4078",
    "lng": "11.13934"
  },
  {
    "country": "IT",
    "name": "Cava Manara",
    "lat": "45.14014",
    "lng": "9.10774"
  },
  {
    "country": "IT",
    "name": "Cavallirio",
    "lat": "45.66227",
    "lng": "8.39694"
  },
  {
    "country": "IT",
    "name": "Cavallino",
    "lat": "40.3102",
    "lng": "18.20221"
  },
  {
    "country": "IT",
    "name": "Cavallermaggiore",
    "lat": "44.70639",
    "lng": "7.68693"
  },
  {
    "country": "IT",
    "name": "Cavalese",
    "lat": "46.29048",
    "lng": "11.45862"
  },
  {
    "country": "IT",
    "name": "Cavajon Veronese",
    "lat": "45.54009",
    "lng": "10.77048"
  },
  {
    "country": "IT",
    "name": "Cavaglià",
    "lat": "45.40602",
    "lng": "8.09163"
  },
  {
    "country": "IT",
    "name": "Cava Dè Tirreni",
    "lat": "40.69954",
    "lng": "14.70773"
  },
  {
    "country": "IT",
    "name": "Cavacurta",
    "lat": "45.18977",
    "lng": "9.74186"
  },
  {
    "country": "IT",
    "name": "Cautano",
    "lat": "41.15009",
    "lng": "14.64425"
  },
  {
    "country": "IT",
    "name": "Cattolica",
    "lat": "43.96182",
    "lng": "12.73631"
  },
  {
    "country": "IT",
    "name": "Catignano",
    "lat": "42.34697",
    "lng": "13.9519"
  },
  {
    "country": "IT",
    "name": "Ca' Tiepolo",
    "lat": "44.94861",
    "lng": "12.33917"
  },
  {
    "country": "IT",
    "name": "Cataeggio",
    "lat": "46.21447",
    "lng": "9.63781"
  },
  {
    "country": "IT",
    "name": "Castropignano",
    "lat": "41.61788",
    "lng": "14.55856"
  },
  {
    "country": "IT",
    "name": "Castronuovo di Sant'Andrea",
    "lat": "40.18903",
    "lng": "16.18559"
  },
  {
    "country": "IT",
    "name": "Castronno",
    "lat": "45.74793",
    "lng": "8.81442"
  },
  {
    "country": "IT",
    "name": "Castro dei Volsci",
    "lat": "41.50822",
    "lng": "13.4063"
  },
  {
    "country": "IT",
    "name": "Castrocielo",
    "lat": "41.52736",
    "lng": "13.69588"
  },
  {
    "country": "IT",
    "name": "Castrocaro Terme",
    "lat": "44.17556",
    "lng": "11.94952"
  },
  {
    "country": "IT",
    "name": "Castro",
    "lat": "45.80378",
    "lng": "10.0659"
  },
  {
    "country": "IT",
    "name": "Castrignano De' Greci",
    "lat": "40.17342",
    "lng": "18.29643"
  },
  {
    "country": "IT",
    "name": "Castri di Lecce",
    "lat": "40.2736",
    "lng": "18.2624"
  },
  {
    "country": "IT",
    "name": "Castorano",
    "lat": "42.89779",
    "lng": "13.72967"
  },
  {
    "country": "IT",
    "name": "Casto",
    "lat": "45.69489",
    "lng": "10.32117"
  },
  {
    "country": "IT",
    "name": "Castions di Strada",
    "lat": "45.91247",
    "lng": "13.18167"
  },
  {
    "country": "IT",
    "name": "Castions",
    "lat": "45.97218",
    "lng": "12.79961"
  },
  {
    "country": "IT",
    "name": "Castione della Presolana",
    "lat": "45.91471",
    "lng": "10.0554"
  },
  {
    "country": "IT",
    "name": "Castino",
    "lat": "44.61784",
    "lng": "8.18244"
  },
  {
    "country": "IT",
    "name": "Castilenti",
    "lat": "42.53334",
    "lng": "13.9171"
  },
  {
    "country": "IT",
    "name": "Castignano",
    "lat": "42.93935",
    "lng": "13.62514"
  },
  {
    "country": "IT",
    "name": "Castiglion Fiorentino",
    "lat": "43.34308",
    "lng": "11.91995"
  },
  {
    "country": "IT",
    "name": "Castiglion Fibocchi",
    "lat": "43.52742",
    "lng": "11.76151"
  },
  {
    "country": "IT",
    "name": "Castiglione Olona",
    "lat": "45.75256",
    "lng": "8.87278"
  },
  {
    "country": "IT",
    "name": "Castiglione Messer Raimondo",
    "lat": "42.53194",
    "lng": "13.87953"
  },
  {
    "country": "IT",
    "name": "Castiglione Messer Marino",
    "lat": "41.86833",
    "lng": "14.44996"
  },
  {
    "country": "IT",
    "name": "Castiglione in Teverina",
    "lat": "42.65076",
    "lng": "12.20305"
  },
  {
    "country": "IT",
    "name": "Castiglione d'Orcia",
    "lat": "43.0046",
    "lng": "11.61451"
  },
  {
    "country": "IT",
    "name": "Castiglione d'Intelvi",
    "lat": "45.95751",
    "lng": "9.08987"
  },
  {
    "country": "IT",
    "name": "Castiglione di Garfagnana",
    "lat": "44.15248",
    "lng": "10.41212"
  },
  {
    "country": "IT",
    "name": "Castiglione delle Stiviere",
    "lat": "45.3902",
    "lng": "10.48619"
  },
  {
    "country": "IT",
    "name": "Castiglione della Pescaia",
    "lat": "42.76854",
    "lng": "10.87746"
  },
  {
    "country": "IT",
    "name": "Castiglione del Lago",
    "lat": "43.12457",
    "lng": "12.03982"
  },
  {
    "country": "IT",
    "name": "Castiglione dei Pepoli",
    "lat": "44.1428",
    "lng": "11.16028"
  },
  {
    "country": "IT",
    "name": "Castiglione del Genovesi",
    "lat": "40.72367",
    "lng": "14.84796"
  },
  {
    "country": "IT",
    "name": "Castiglione d'Adda",
    "lat": "45.21702",
    "lng": "9.69279"
  },
  {
    "country": "IT",
    "name": "Castiglione",
    "lat": "44.27539",
    "lng": "9.51687"
  },
  {
    "country": "IT",
    "name": "Castiglione a Casauria",
    "lat": "42.23601",
    "lng": "13.89832"
  },
  {
    "country": "IT",
    "name": "Castenedolo",
    "lat": "45.4743",
    "lng": "10.29131"
  },
  {
    "country": "IT",
    "name": "Castenaso",
    "lat": "44.51398",
    "lng": "11.46842"
  },
  {
    "country": "IT",
    "name": "Castel Volturno",
    "lat": "41.03288",
    "lng": "13.94354"
  },
  {
    "country": "IT",
    "name": "Castel Vittorio",
    "lat": "43.92752",
    "lng": "7.67471"
  },
  {
    "country": "IT",
    "name": "Castel Viscardo",
    "lat": "42.75359",
    "lng": "12.00072"
  },
  {
    "country": "IT",
    "name": "Castelvetro Piacentino",
    "lat": "45.10223",
    "lng": "9.99041"
  },
  {
    "country": "IT",
    "name": "Castelvetro di Modena",
    "lat": "44.50422",
    "lng": "10.94666"
  },
  {
    "country": "IT",
    "name": "Castelvetere sul Calore",
    "lat": "40.9298",
    "lng": "14.9864"
  },
  {
    "country": "IT",
    "name": "Castelvetere in Val Fortore",
    "lat": "41.44257",
    "lng": "14.94118"
  },
  {
    "country": "IT",
    "name": "Castelverrino",
    "lat": "41.76713",
    "lng": "14.39756"
  },
  {
    "country": "IT",
    "name": "Castelverde",
    "lat": "45.18753",
    "lng": "9.99693"
  },
  {
    "country": "IT",
    "name": "Castelvenere",
    "lat": "41.23445",
    "lng": "14.5475"
  },
  {
    "country": "IT",
    "name": "Castelvecchio Subequo",
    "lat": "42.12881",
    "lng": "13.72868"
  },
  {
    "country": "IT",
    "name": "Castelvecchio Calvisio",
    "lat": "42.31134",
    "lng": "13.6872"
  },
  {
    "country": "IT",
    "name": "Casteltodino",
    "lat": "42.66667",
    "lng": "12.5"
  },
  {
    "country": "IT",
    "name": "Castelseprio",
    "lat": "45.71372",
    "lng": "8.86161"
  },
  {
    "country": "IT",
    "name": "Castelsardo",
    "lat": "40.91256",
    "lng": "8.71453"
  },
  {
    "country": "IT",
    "name": "Castelsaraceno",
    "lat": "40.16213",
    "lng": "15.99281"
  },
  {
    "country": "IT",
    "name": "Castel San Vincenzo",
    "lat": "41.65543",
    "lng": "14.06178"
  },
  {
    "country": "IT",
    "name": "Castel Sant'Elia",
    "lat": "42.25112",
    "lng": "12.37032"
  },
  {
    "country": "IT",
    "name": "Castelsantangelo sul Nera",
    "lat": "42.89379",
    "lng": "13.15462"
  },
  {
    "country": "IT",
    "name": "Castel Sant'Angelo",
    "lat": "42.39373",
    "lng": "13.02738"
  },
  {
    "country": "IT",
    "name": "Castel San Pietro Terme",
    "lat": "44.39854",
    "lng": "11.58546"
  },
  {
    "country": "IT",
    "name": "Castel San Pietro Romano",
    "lat": "41.84572",
    "lng": "12.89489"
  },
  {
    "country": "IT",
    "name": "Castel San Niccolò",
    "lat": "43.74445",
    "lng": "11.70913"
  },
  {
    "country": "IT",
    "name": "Castel San Lorenzo",
    "lat": "40.41979",
    "lng": "15.22523"
  },
  {
    "country": "IT",
    "name": "Castel San Giovanni",
    "lat": "45.06014",
    "lng": "9.43784"
  },
  {
    "country": "IT",
    "name": "Castel San Giorgio",
    "lat": "40.78198",
    "lng": "14.7009"
  },
  {
    "country": "IT",
    "name": "Castelrotto",
    "lat": "46.56662",
    "lng": "11.56098"
  },
  {
    "country": "IT",
    "name": "Castel Ritaldi",
    "lat": "42.82247",
    "lng": "12.6742"
  },
  {
    "country": "IT",
    "name": "Castelraimondo",
    "lat": "43.20853",
    "lng": "13.05486"
  },
  {
    "country": "IT",
    "name": "Castelpoto",
    "lat": "41.14066",
    "lng": "14.70069"
  },
  {
    "country": "IT",
    "name": "Castelplanio",
    "lat": "43.4942",
    "lng": "13.0818"
  },
  {
    "country": "IT",
    "name": "Castelpizzuto",
    "lat": "41.52128",
    "lng": "14.29205"
  },
  {
    "country": "IT",
    "name": "Castelpetroso",
    "lat": "41.56027",
    "lng": "14.34637"
  },
  {
    "country": "IT",
    "name": "Castelpagano",
    "lat": "41.40177",
    "lng": "14.80711"
  },
  {
    "country": "IT",
    "name": "Castelnuovo Scrivia",
    "lat": "44.97932",
    "lng": "8.88246"
  },
  {
    "country": "IT",
    "name": "Castelnuovo Rangone",
    "lat": "44.54935",
    "lng": "10.9335"
  },
  {
    "country": "IT",
    "name": "Castelnuovo Parano",
    "lat": "41.37912",
    "lng": "13.75621"
  },
  {
    "country": "IT",
    "name": "Castelnuovo Nigra",
    "lat": "45.43816",
    "lng": "7.69461"
  },
  {
    "country": "IT",
    "name": "Castelnuovo Don Bosco",
    "lat": "45.04077",
    "lng": "7.96389"
  },
  {
    "country": "IT",
    "name": "Castelnuovo di Val di Cecina",
    "lat": "43.21148",
    "lng": "10.90413"
  },
  {
    "country": "IT",
    "name": "Castelnuovo di Porto",
    "lat": "42.1228",
    "lng": "12.51043"
  },
  {
    "country": "IT",
    "name": "Castelnuovo Magra",
    "lat": "44.09957",
    "lng": "10.01715"
  },
  {
    "country": "IT",
    "name": "Castelnuovo di Garfagnana",
    "lat": "44.1126",
    "lng": "10.40518"
  },
  {
    "country": "IT",
    "name": "Castelnuovo di Farfa",
    "lat": "42.23193",
    "lng": "12.74308"
  },
  {
    "country": "IT",
    "name": "Castelnuovo di Conza",
    "lat": "40.82062",
    "lng": "15.31875"
  },
  {
    "country": "IT",
    "name": "Castelnuovo dei Sabbioni",
    "lat": "43.54093",
    "lng": "11.45234"
  },
  {
    "country": "IT",
    "name": "Castelnuovo della Daunia",
    "lat": "41.58139",
    "lng": "15.11796"
  },
  {
    "country": "IT",
    "name": "Castelnuovo Cilento",
    "lat": "40.21846",
    "lng": "15.17802"
  },
  {
    "country": "IT",
    "name": "Castelnuovo Bormida",
    "lat": "44.74236",
    "lng": "8.5506"
  },
  {
    "country": "IT",
    "name": "Castelnuovo Bocca d'Adda",
    "lat": "45.11147",
    "lng": "9.86359"
  },
  {
    "country": "IT",
    "name": "Castelnuovo Berardenga",
    "lat": "43.34548",
    "lng": "11.50039"
  },
  {
    "country": "IT",
    "name": "Castelnuovo",
    "lat": "46.05412",
    "lng": "11.48916"
  },
  {
    "country": "IT",
    "name": "Castelnuovo Calcea",
    "lat": "44.78688",
    "lng": "8.28421"
  },
  {
    "country": "IT",
    "name": "Castelnovo ne'Monti",
    "lat": "44.43556",
    "lng": "10.40329"
  },
  {
    "country": "IT",
    "name": "Castelnovo di Sotto",
    "lat": "44.81253",
    "lng": "10.56694"
  },
  {
    "country": "IT",
    "name": "Castelnovetto",
    "lat": "45.25438",
    "lng": "8.61142"
  },
  {
    "country": "IT",
    "name": "Castelmezzano",
    "lat": "40.52832",
    "lng": "16.04585"
  },
  {
    "country": "IT",
    "name": "Castel Mella",
    "lat": "45.49913",
    "lng": "10.14553"
  },
  {
    "country": "IT",
    "name": "Castelmauro",
    "lat": "41.82846",
    "lng": "14.71066"
  },
  {
    "country": "IT",
    "name": "Castelmassa",
    "lat": "45.01826",
    "lng": "11.31505"
  },
  {
    "country": "IT",
    "name": "Campomolino",
    "lat": "44.40883",
    "lng": "7.21192"
  },
  {
    "country": "IT",
    "name": "Castel Maggiore",
    "lat": "44.57707",
    "lng": "11.36071"
  },
  {
    "country": "IT",
    "name": "Castel Madama",
    "lat": "41.9735",
    "lng": "12.86782"
  },
  {
    "country": "IT",
    "name": "Castelluccio Valmaggiore",
    "lat": "41.3429",
    "lng": "15.19944"
  },
  {
    "country": "IT",
    "name": "Castelluccio Superiore",
    "lat": "40.01003",
    "lng": "15.97184"
  },
  {
    "country": "IT",
    "name": "Castellucchio",
    "lat": "45.15038",
    "lng": "10.64875"
  },
  {
    "country": "IT",
    "name": "Castello Tesino",
    "lat": "46.06302",
    "lng": "11.63247"
  },
  {
    "country": "IT",
    "name": "Castello di Godego",
    "lat": "45.6927",
    "lng": "11.87998"
  },
  {
    "country": "IT",
    "name": "Castello Molina di Fiemme",
    "lat": "46.28241",
    "lng": "11.43348"
  },
  {
    "country": "IT",
    "name": "Castello di Annone",
    "lat": "44.87944",
    "lng": "8.31701"
  },
  {
    "country": "IT",
    "name": "Castello dell'Acqua",
    "lat": "46.14549",
    "lng": "10.01582"
  },
  {
    "country": "IT",
    "name": "Aviano-Castello",
    "lat": "46.06759",
    "lng": "12.58324"
  },
  {
    "country": "IT",
    "name": "Castello d'Argile",
    "lat": "44.67797",
    "lng": "11.29715"
  },
  {
    "country": "IT",
    "name": "Castello",
    "lat": "45.56954",
    "lng": "10.50861"
  },
  {
    "country": "IT",
    "name": "Castelliri",
    "lat": "41.67764",
    "lng": "13.53978"
  },
  {
    "country": "IT",
    "name": "Castellino del Biferno",
    "lat": "41.7016",
    "lng": "14.73179"
  },
  {
    "country": "IT",
    "name": "Castellina Marittima",
    "lat": "43.41301",
    "lng": "10.57594"
  },
  {
    "country": "IT",
    "name": "Castellina in Chianti",
    "lat": "43.46438",
    "lng": "11.2895"
  },
  {
    "country": "IT",
    "name": "Castelli Calepio",
    "lat": "45.61316",
    "lng": "9.8854"
  },
  {
    "country": "IT",
    "name": "Castelli",
    "lat": "42.48476",
    "lng": "13.71201"
  },
  {
    "country": "IT",
    "name": "Castelletto Uzzone",
    "lat": "44.49527",
    "lng": "8.18772"
  },
  {
    "country": "IT",
    "name": "Castelletto Sopra Ticino",
    "lat": "45.72002",
    "lng": "8.63362"
  },
  {
    "country": "IT",
    "name": "Castelleone",
    "lat": "45.29579",
    "lng": "9.76091"
  },
  {
    "country": "IT",
    "name": "Castellazzo Novarese",
    "lat": "45.51337",
    "lng": "8.48693"
  },
  {
    "country": "IT",
    "name": "Castellazzo Bormida",
    "lat": "44.84353",
    "lng": "8.579"
  },
  {
    "country": "IT",
    "name": "Castell'Azzara",
    "lat": "42.77275",
    "lng": "11.69794"
  },
  {
    "country": "IT",
    "name": "Castell'Arquato",
    "lat": "44.85451",
    "lng": "9.87326"
  },
  {
    "country": "IT",
    "name": "Castellaro",
    "lat": "43.86436",
    "lng": "7.86881"
  },
  {
    "country": "IT",
    "name": "Castellar Guidobono",
    "lat": "44.90483",
    "lng": "8.94835"
  },
  {
    "country": "IT",
    "name": "Castellarano",
    "lat": "44.51825",
    "lng": "10.73727"
  },
  {
    "country": "IT",
    "name": "Castellanza",
    "lat": "45.61079",
    "lng": "8.89616"
  },
  {
    "country": "IT",
    "name": "Castellaneta",
    "lat": "40.62794",
    "lng": "16.9329"
  },
  {
    "country": "IT",
    "name": "Castellana",
    "lat": "40.88643",
    "lng": "17.16549"
  },
  {
    "country": "IT",
    "name": "Castellamonte",
    "lat": "45.38267",
    "lng": "7.70886"
  },
  {
    "country": "IT",
    "name": "Castellammare di Stabia",
    "lat": "40.70211",
    "lng": "14.48685"
  },
  {
    "country": "IT",
    "name": "Castellalto",
    "lat": "42.67705",
    "lng": "13.82101"
  },
  {
    "country": "IT",
    "name": "Castell'Alfero",
    "lat": "44.98505",
    "lng": "8.22309"
  },
  {
    "country": "IT",
    "name": "Castellafiume",
    "lat": "41.98913",
    "lng": "13.3344"
  },
  {
    "country": "IT",
    "name": "Castelguidone",
    "lat": "41.82258",
    "lng": "14.52286"
  },
  {
    "country": "IT",
    "name": "Castelguglielmo",
    "lat": "45.02539",
    "lng": "11.5369"
  },
  {
    "country": "IT",
    "name": "Castel Guelfo di Bologna",
    "lat": "44.43166",
    "lng": "11.67591"
  },
  {
    "country": "IT",
    "name": "Castelgrande",
    "lat": "40.78639",
    "lng": "15.43109"
  },
  {
    "country": "IT",
    "name": "Castelgomberto",
    "lat": "45.58267",
    "lng": "11.39007"
  },
  {
    "country": "IT",
    "name": "Castel Goffredo",
    "lat": "45.29403",
    "lng": "10.473"
  },
  {
    "country": "IT",
    "name": "Castel Giorgio",
    "lat": "42.70697",
    "lng": "11.97717"
  },
  {
    "country": "IT",
    "name": "Castel Gandolfo",
    "lat": "41.74875",
    "lng": "12.64975"
  },
  {
    "country": "IT",
    "name": "Castel Gabbiano",
    "lat": "45.46847",
    "lng": "9.71765"
  },
  {
    "country": "IT",
    "name": "Castel Frentano",
    "lat": "42.19875",
    "lng": "14.35643"
  },
  {
    "country": "IT",
    "name": "Castelfranco Veneto",
    "lat": "45.67146",
    "lng": "11.92755"
  },
  {
    "country": "IT",
    "name": "Castelfranco in Miscano",
    "lat": "41.30072",
    "lng": "15.08607"
  },
  {
    "country": "IT",
    "name": "Castelfranco Emilia",
    "lat": "44.59445",
    "lng": "11.04979"
  },
  {
    "country": "IT",
    "name": "Castelfranco di Sotto",
    "lat": "43.70368",
    "lng": "10.7463"
  },
  {
    "country": "IT",
    "name": "Castelfranco di Sopra",
    "lat": "43.62156",
    "lng": "11.55885"
  },
  {
    "country": "IT",
    "name": "Castelfranci",
    "lat": "40.93066",
    "lng": "15.04331"
  },
  {
    "country": "IT",
    "name": "Castelforte",
    "lat": "41.29392",
    "lng": "13.83061"
  },
  {
    "country": "IT",
    "name": "Castelfondo",
    "lat": "46.45623",
    "lng": "11.11785"
  },
  {
    "country": "IT",
    "name": "Castelfiorentino",
    "lat": "43.60963",
    "lng": "10.96772"
  },
  {
    "country": "IT",
    "name": "Castelfidardo",
    "lat": "43.45916",
    "lng": "13.55044"
  },
  {
    "country": "IT",
    "name": "Castel di Tora",
    "lat": "42.21392",
    "lng": "12.97073"
  },
  {
    "country": "IT",
    "name": "Castel di Sangro",
    "lat": "41.78392",
    "lng": "14.10653"
  },
  {
    "country": "IT",
    "name": "Castel di Ieri",
    "lat": "42.11353",
    "lng": "13.742"
  },
  {
    "country": "IT",
    "name": "Casteldidone",
    "lat": "45.07068",
    "lng": "10.40581"
  },
  {
    "country": "IT",
    "name": "Castel di Casio",
    "lat": "44.16276",
    "lng": "11.03505"
  },
  {
    "country": "IT",
    "name": "Castel del Rio",
    "lat": "44.21346",
    "lng": "11.50409"
  },
  {
    "country": "IT",
    "name": "Castel del Piano",
    "lat": "42.89228",
    "lng": "11.53903"
  },
  {
    "country": "IT",
    "name": "Castel del Monte",
    "lat": "42.36544",
    "lng": "13.72592"
  },
  {
    "country": "IT",
    "name": "Castel del Giudice",
    "lat": "41.85488",
    "lng": "14.23155"
  },
  {
    "country": "IT",
    "name": "Casteldelfino",
    "lat": "44.59002",
    "lng": "7.07026"
  },
  {
    "country": "IT",
    "name": "Castel d'Ario",
    "lat": "45.18798",
    "lng": "10.97449"
  },
  {
    "country": "IT",
    "name": "Castel d'Aiano",
    "lat": "44.27751",
    "lng": "11.00097"
  },
  {
    "country": "IT",
    "name": "Castelcucco",
    "lat": "45.83024",
    "lng": "11.88296"
  },
  {
    "country": "IT",
    "name": "Castel Condino",
    "lat": "45.91439",
    "lng": "10.60277"
  },
  {
    "country": "IT",
    "name": "Castelcivita",
    "lat": "40.49367",
    "lng": "15.23354"
  },
  {
    "country": "IT",
    "name": "Castel Chiodato",
    "lat": "42.05617",
    "lng": "12.69764"
  },
  {
    "country": "IT",
    "name": "Castel Campagnano",
    "lat": "41.1824",
    "lng": "14.453"
  },
  {
    "country": "IT",
    "name": "Castelbottaccio",
    "lat": "41.75329",
    "lng": "14.70616"
  },
  {
    "country": "IT",
    "name": "Castel Bolognese",
    "lat": "44.31981",
    "lng": "11.79903"
  },
  {
    "country": "IT",
    "name": "Castelbello-Ciardes - Kastelbell-Tschars",
    "lat": "46.62832",
    "lng": "10.90666"
  },
  {
    "country": "IT",
    "name": "Castelbellino",
    "lat": "43.48676",
    "lng": "13.14467"
  },
  {
    "country": "IT",
    "name": "Castel Baronia",
    "lat": "41.04832",
    "lng": "15.18884"
  },
  {
    "country": "IT",
    "name": "Castelbaldo",
    "lat": "45.12226",
    "lng": "11.45517"
  },
  {
    "country": "IT",
    "name": "Castegnato",
    "lat": "45.56129",
    "lng": "10.11449"
  },
  {
    "country": "IT",
    "name": "Casteggio",
    "lat": "45.01396",
    "lng": "9.12528"
  },
  {
    "country": "IT",
    "name": "Castano Primo",
    "lat": "45.55175",
    "lng": "8.77562"
  },
  {
    "country": "IT",
    "name": "Castagnole Monferrato",
    "lat": "44.95864",
    "lng": "8.30507"
  },
  {
    "country": "IT",
    "name": "Castagnole delle Lanze",
    "lat": "44.74988",
    "lng": "8.14966"
  },
  {
    "country": "IT",
    "name": "Castagnole",
    "lat": "45.68852",
    "lng": "12.1826"
  },
  {
    "country": "IT",
    "name": "Castagnito",
    "lat": "44.75472",
    "lng": "8.03195"
  },
  {
    "country": "IT",
    "name": "Castagneto Po",
    "lat": "45.15854",
    "lng": "7.88639"
  },
  {
    "country": "IT",
    "name": "Castagneto Carducci",
    "lat": "43.16073",
    "lng": "10.61092"
  },
  {
    "country": "IT",
    "name": "Castagnaro",
    "lat": "45.11795",
    "lng": "11.40911"
  },
  {
    "country": "IT",
    "name": "Cassolnovo",
    "lat": "45.36106",
    "lng": "8.8123"
  },
  {
    "country": "IT",
    "name": "Cassino",
    "lat": "41.48581",
    "lng": "13.82835"
  },
  {
    "country": "IT",
    "name": "Cassine",
    "lat": "44.75166",
    "lng": "8.52872"
  },
  {
    "country": "IT",
    "name": "Cassinasco",
    "lat": "44.68977",
    "lng": "8.30345"
  },
  {
    "country": "IT",
    "name": "Cassina de' Pecchi",
    "lat": "45.51637",
    "lng": "9.35975"
  },
  {
    "country": "IT",
    "name": "Cassiglio",
    "lat": "45.96679",
    "lng": "9.61215"
  },
  {
    "country": "IT",
    "name": "Cassano Spinola",
    "lat": "44.76557",
    "lng": "8.86228"
  },
  {
    "country": "IT",
    "name": "Cassano delle Murge",
    "lat": "40.89112",
    "lng": "16.76531"
  },
  {
    "country": "IT",
    "name": "Cassano d'Adda",
    "lat": "45.52637",
    "lng": "9.51528"
  },
  {
    "country": "IT",
    "name": "Cassacco",
    "lat": "46.17345",
    "lng": "13.19236"
  },
  {
    "country": "IT",
    "name": "Caspoggio",
    "lat": "46.26424",
    "lng": "9.86165"
  },
  {
    "country": "IT",
    "name": "Casperia",
    "lat": "42.33869",
    "lng": "12.67017"
  },
  {
    "country": "IT",
    "name": "Casorzo",
    "lat": "45.02165",
    "lng": "8.33843"
  },
  {
    "country": "IT",
    "name": "Casoria",
    "lat": "40.90751",
    "lng": "14.293"
  },
  {
    "country": "IT",
    "name": "Casorezzo",
    "lat": "45.52265",
    "lng": "8.90186"
  },
  {
    "country": "IT",
    "name": "Casorate Sempione",
    "lat": "45.67079",
    "lng": "8.74513"
  },
  {
    "country": "IT",
    "name": "Casorate Primo",
    "lat": "45.31142",
    "lng": "9.01703"
  },
  {
    "country": "IT",
    "name": "Casoni",
    "lat": "45.75943",
    "lng": "11.81045"
  },
  {
    "country": "IT",
    "name": "Casoli",
    "lat": "42.61723",
    "lng": "13.9791"
  },
  {
    "country": "IT",
    "name": "Casoli",
    "lat": "42.1138",
    "lng": "14.28995"
  },
  {
    "country": "IT",
    "name": "Casole d'Elsa",
    "lat": "43.34115",
    "lng": "11.04794"
  },
  {
    "country": "IT",
    "name": "Casola Valsenio",
    "lat": "44.22443",
    "lng": "11.62487"
  },
  {
    "country": "IT",
    "name": "Casola in Lunigiana",
    "lat": "44.20045",
    "lng": "10.17679"
  },
  {
    "country": "IT",
    "name": "Casola di Napoli",
    "lat": "40.6978",
    "lng": "14.53006"
  },
  {
    "country": "IT",
    "name": "Casnigo",
    "lat": "45.81307",
    "lng": "9.86878"
  },
  {
    "country": "IT",
    "name": "Casarile",
    "lat": "45.31683",
    "lng": "9.10383"
  },
  {
    "country": "IT",
    "name": "Casirate d'Adda",
    "lat": "45.49535",
    "lng": "9.56932"
  },
  {
    "country": "IT",
    "name": "Casine",
    "lat": "43.63165",
    "lng": "13.14425"
  },
  {
    "country": "IT",
    "name": "Casina",
    "lat": "44.50982",
    "lng": "10.49951"
  },
  {
    "country": "IT",
    "name": "Caserta",
    "lat": "41.07262",
    "lng": "14.33231"
  },
  {
    "country": "IT",
    "name": "Pieve al Toppo",
    "lat": "43.40761",
    "lng": "11.79686"
  },
  {
    "country": "IT",
    "name": "Caselle Torinese",
    "lat": "45.17458",
    "lng": "7.6429"
  },
  {
    "country": "IT",
    "name": "Caselle Lurani",
    "lat": "45.28044",
    "lng": "9.36016"
  },
  {
    "country": "IT",
    "name": "Caselle in Pittari",
    "lat": "40.17319",
    "lng": "15.54311"
  },
  {
    "country": "IT",
    "name": "Caselle",
    "lat": "45.74965",
    "lng": "11.98004"
  },
  {
    "country": "IT",
    "name": "Casella",
    "lat": "44.53523",
    "lng": "9.0008"
  },
  {
    "country": "IT",
    "name": "Caselette",
    "lat": "45.10975",
    "lng": "7.48582"
  },
  {
    "country": "IT",
    "name": "Casei",
    "lat": "45.00756",
    "lng": "8.92675"
  },
  {
    "country": "IT",
    "name": "Cascinette d'Ivrea",
    "lat": "45.48016",
    "lng": "7.90562"
  },
  {
    "country": "IT",
    "name": "Cascina",
    "lat": "43.67557",
    "lng": "10.55494"
  },
  {
    "country": "IT",
    "name": "Casciana Terme",
    "lat": "43.52668",
    "lng": "10.61812"
  },
  {
    "country": "IT",
    "name": "Cascia",
    "lat": "42.7179",
    "lng": "13.01697"
  },
  {
    "country": "IT",
    "name": "Cascano",
    "lat": "41.23232",
    "lng": "13.96927"
  },
  {
    "country": "IT",
    "name": "Casazza",
    "lat": "45.74855",
    "lng": "9.90627"
  },
  {
    "country": "IT",
    "name": "Casatisma",
    "lat": "45.04569",
    "lng": "9.13099"
  },
  {
    "country": "IT",
    "name": "Casatenovo",
    "lat": "45.69514",
    "lng": "9.31338"
  },
  {
    "country": "IT",
    "name": "Casasco",
    "lat": "44.82734",
    "lng": "9.00565"
  },
  {
    "country": "IT",
    "name": "Casarsa della Delizia",
    "lat": "45.95091",
    "lng": "12.8425"
  },
  {
    "country": "IT",
    "name": "Casargo",
    "lat": "46.0395",
    "lng": "9.38717"
  },
  {
    "country": "IT",
    "name": "Casapulla",
    "lat": "41.07665",
    "lng": "14.28927"
  },
  {
    "country": "IT",
    "name": "Casaprota",
    "lat": "42.25177",
    "lng": "12.80428"
  },
  {
    "country": "IT",
    "name": "Casape",
    "lat": "41.90702",
    "lng": "12.88579"
  },
  {
    "country": "IT",
    "name": "Casanova Elvo",
    "lat": "45.4002",
    "lng": "8.29413"
  },
  {
    "country": "IT",
    "name": "Casanova",
    "lat": "41.19254",
    "lng": "13.96344"
  },
  {
    "country": "IT",
    "name": "Casandrino",
    "lat": "40.92845",
    "lng": "14.24744"
  },
  {
    "country": "IT",
    "name": "Semonte-Casamorcia",
    "lat": "43.36826",
    "lng": "12.53064"
  },
  {
    "country": "IT",
    "name": "Casamassima",
    "lat": "40.95653",
    "lng": "16.92075"
  },
  {
    "country": "IT",
    "name": "Casamassella",
    "lat": "40.11424",
    "lng": "18.451"
  },
  {
    "country": "IT",
    "name": "Casamarciano",
    "lat": "40.93191",
    "lng": "14.55324"
  },
  {
    "country": "IT",
    "name": "Casalzuigno",
    "lat": "45.90508",
    "lng": "8.70883"
  },
  {
    "country": "IT",
    "name": "Casalvolone",
    "lat": "45.39966",
    "lng": "8.46472"
  },
  {
    "country": "IT",
    "name": "Casalvieri",
    "lat": "41.63329",
    "lng": "13.71363"
  },
  {
    "country": "IT",
    "name": "Casal Velino",
    "lat": "40.19034",
    "lng": "15.11137"
  },
  {
    "country": "IT",
    "name": "Casalvecchio di Puglia",
    "lat": "41.5947",
    "lng": "15.10999"
  },
  {
    "country": "IT",
    "name": "Casaluce",
    "lat": "40.99785",
    "lng": "14.19671"
  },
  {
    "country": "IT",
    "name": "Casalserugo",
    "lat": "45.31549",
    "lng": "11.91232"
  },
  {
    "country": "IT",
    "name": "Casalromano",
    "lat": "45.19808",
    "lng": "10.3664"
  },
  {
    "country": "IT",
    "name": "Casalpusterlengo",
    "lat": "45.17921",
    "lng": "9.64834"
  },
  {
    "country": "IT",
    "name": "Casaloldo",
    "lat": "45.25436",
    "lng": "10.47691"
  },
  {
    "country": "IT",
    "name": "Casalnuovo Monterotaro",
    "lat": "41.61942",
    "lng": "15.10411"
  },
  {
    "country": "IT",
    "name": "Casalnuovo di Napoli",
    "lat": "40.90969",
    "lng": "14.34205"
  },
  {
    "country": "IT",
    "name": "Casalnoceto",
    "lat": "44.91326",
    "lng": "8.98376"
  },
  {
    "country": "IT",
    "name": "Casalmoro",
    "lat": "45.26115",
    "lng": "10.41118"
  },
  {
    "country": "IT",
    "name": "Casalmorano",
    "lat": "45.28766",
    "lng": "9.8986"
  },
  {
    "country": "IT",
    "name": "Casalmaiocco",
    "lat": "45.35238",
    "lng": "9.37088"
  },
  {
    "country": "IT",
    "name": "Casalmaggiore",
    "lat": "44.98981",
    "lng": "10.42055"
  },
  {
    "country": "IT",
    "name": "Casalino",
    "lat": "45.35836",
    "lng": "8.52393"
  },
  {
    "country": "IT",
    "name": "Casalincontrada",
    "lat": "42.29744",
    "lng": "14.13511"
  },
  {
    "country": "IT",
    "name": "Casali",
    "lat": "41.37812",
    "lng": "13.75479"
  },
  {
    "country": "IT",
    "name": "Casalgrasso",
    "lat": "44.81834",
    "lng": "7.62498"
  },
  {
    "country": "IT",
    "name": "Casalgrande",
    "lat": "44.58466",
    "lng": "10.7355"
  },
  {
    "country": "IT",
    "name": "Casalfiumanese",
    "lat": "44.29686",
    "lng": "11.62402"
  },
  {
    "country": "IT",
    "name": "Casaletto Spartano",
    "lat": "40.15134",
    "lng": "15.62058"
  },
  {
    "country": "IT",
    "name": "Casaletto Ceredano",
    "lat": "45.31831",
    "lng": "9.61701"
  },
  {
    "country": "IT",
    "name": "Casale sul Sile",
    "lat": "45.59638",
    "lng": "12.32655"
  },
  {
    "country": "IT",
    "name": "Casaleone",
    "lat": "45.16821",
    "lng": "11.19401"
  },
  {
    "country": "IT",
    "name": "Casale Monferrato",
    "lat": "45.13338",
    "lng": "8.4525"
  },
  {
    "country": "IT",
    "name": "Casale Marittimo",
    "lat": "43.29727",
    "lng": "10.61658"
  },
  {
    "country": "IT",
    "name": "Casaleggio Novara",
    "lat": "45.48793",
    "lng": "8.49307"
  },
  {
    "country": "IT",
    "name": "Casale di Scodosia",
    "lat": "45.19225",
    "lng": "11.47442"
  },
  {
    "country": "IT",
    "name": "Casale Corte Cerro",
    "lat": "45.91545",
    "lng": "8.41407"
  },
  {
    "country": "IT",
    "name": "Casalecchio di Reno",
    "lat": "44.47563",
    "lng": "11.27495"
  },
  {
    "country": "IT",
    "name": "Casalduni",
    "lat": "41.2608",
    "lng": "14.69532"
  },
  {
    "country": "IT",
    "name": "Casal di Principe",
    "lat": "41.00996",
    "lng": "14.13013"
  },
  {
    "country": "IT",
    "name": "Casalciprano",
    "lat": "41.58037",
    "lng": "14.52835"
  },
  {
    "country": "IT",
    "name": "Casalbuttano",
    "lat": "45.25187",
    "lng": "9.96167"
  },
  {
    "country": "IT",
    "name": "Casalbuono",
    "lat": "40.21425",
    "lng": "15.68717"
  },
  {
    "country": "IT",
    "name": "Casalborgone",
    "lat": "45.13045",
    "lng": "7.94043"
  },
  {
    "country": "IT",
    "name": "Casalbore",
    "lat": "41.23373",
    "lng": "15.00752"
  },
  {
    "country": "IT",
    "name": "Casalbordino-Miracoli",
    "lat": "42.15354",
    "lng": "14.59912"
  },
  {
    "country": "IT",
    "name": "Casalattico",
    "lat": "41.62213",
    "lng": "13.72563"
  },
  {
    "country": "IT",
    "name": "Casalanguida",
    "lat": "42.03752",
    "lng": "14.49613"
  },
  {
    "country": "IT",
    "name": "Casacanditella",
    "lat": "42.24643",
    "lng": "14.2004"
  },
  {
    "country": "IT",
    "name": "Casacalenda",
    "lat": "41.73824",
    "lng": "14.84734"
  },
  {
    "country": "IT",
    "name": "Carzago Riviera",
    "lat": "45.5244",
    "lng": "10.46052"
  },
  {
    "country": "IT",
    "name": "Carvico",
    "lat": "45.70193",
    "lng": "9.4858"
  },
  {
    "country": "IT",
    "name": "Carunchio",
    "lat": "41.91761",
    "lng": "14.52683"
  },
  {
    "country": "IT",
    "name": "Carugate",
    "lat": "45.54983",
    "lng": "9.34044"
  },
  {
    "country": "IT",
    "name": "Cartignano",
    "lat": "44.47833",
    "lng": "7.28573"
  },
  {
    "country": "IT",
    "name": "Carsoli",
    "lat": "42.09882",
    "lng": "13.08856"
  },
  {
    "country": "IT",
    "name": "Carrù",
    "lat": "44.47967",
    "lng": "7.87236"
  },
  {
    "country": "IT",
    "name": "Carrosio",
    "lat": "44.65776",
    "lng": "8.83126"
  },
  {
    "country": "IT",
    "name": "Carro",
    "lat": "44.27215",
    "lng": "9.60888"
  },
  {
    "country": "IT",
    "name": "Carrara",
    "lat": "44.07926",
    "lng": "10.09789"
  },
  {
    "country": "IT",
    "name": "Carpinone",
    "lat": "41.59003",
    "lng": "14.32436"
  },
  {
    "country": "IT",
    "name": "Carpino",
    "lat": "41.8445",
    "lng": "15.85712"
  },
  {
    "country": "IT",
    "name": "Carpineto Sinello",
    "lat": "42.01044",
    "lng": "14.50418"
  },
  {
    "country": "IT",
    "name": "Carpineto Romano",
    "lat": "41.6047",
    "lng": "13.0841"
  },
  {
    "country": "IT",
    "name": "Carpineto della Nora",
    "lat": "42.33365",
    "lng": "13.86062"
  },
  {
    "country": "IT",
    "name": "Carpineti",
    "lat": "44.45574",
    "lng": "10.5178"
  },
  {
    "country": "IT",
    "name": "Carpignano Sesia",
    "lat": "45.53341",
    "lng": "8.41734"
  },
  {
    "country": "IT",
    "name": "Carpignano Salentino",
    "lat": "40.19537",
    "lng": "18.33826"
  },
  {
    "country": "IT",
    "name": "Carpiano",
    "lat": "45.34027",
    "lng": "9.27401"
  },
  {
    "country": "IT",
    "name": "Carpi Centro",
    "lat": "44.78237",
    "lng": "10.8777"
  },
  {
    "country": "IT",
    "name": "Carpesica",
    "lat": "45.95335",
    "lng": "12.29126"
  },
  {
    "country": "IT",
    "name": "Carpenedolo",
    "lat": "45.36169",
    "lng": "10.43124"
  },
  {
    "country": "IT",
    "name": "Carpegna",
    "lat": "43.7811",
    "lng": "12.33543"
  },
  {
    "country": "IT",
    "name": "Carpasio",
    "lat": "43.96024",
    "lng": "7.86631"
  },
  {
    "country": "IT",
    "name": "Carpaneto Piacentino",
    "lat": "44.91355",
    "lng": "9.78703"
  },
  {
    "country": "IT",
    "name": "Carovilli",
    "lat": "41.71348",
    "lng": "14.29403"
  },
  {
    "country": "IT",
    "name": "Carovigno",
    "lat": "40.70626",
    "lng": "17.65847"
  },
  {
    "country": "IT",
    "name": "Carosino",
    "lat": "40.46538",
    "lng": "17.39857"
  },
  {
    "country": "IT",
    "name": "Carona",
    "lat": "46.02149",
    "lng": "9.78494"
  },
  {
    "country": "IT",
    "name": "Carnate",
    "lat": "45.64843",
    "lng": "9.37813"
  },
  {
    "country": "IT",
    "name": "Carnago",
    "lat": "45.72207",
    "lng": "8.83423"
  },
  {
    "country": "IT",
    "name": "Carmignano di Brenta",
    "lat": "45.62578",
    "lng": "11.70599"
  },
  {
    "country": "IT",
    "name": "Carmignano",
    "lat": "43.81027",
    "lng": "11.01494"
  },
  {
    "country": "IT",
    "name": "Carmiano",
    "lat": "40.34404",
    "lng": "18.04195"
  },
  {
    "country": "IT",
    "name": "Carmagnola",
    "lat": "44.84963",
    "lng": "7.72032"
  },
  {
    "country": "IT",
    "name": "Carlino",
    "lat": "45.80321",
    "lng": "13.18874"
  },
  {
    "country": "IT",
    "name": "Carlazzo",
    "lat": "46.04222",
    "lng": "9.16498"
  },
  {
    "country": "IT",
    "name": "Carlantino",
    "lat": "41.59388",
    "lng": "14.97681"
  },
  {
    "country": "IT",
    "name": "Carisolo",
    "lat": "46.1688",
    "lng": "10.75887"
  },
  {
    "country": "IT",
    "name": "Carisio",
    "lat": "45.41017",
    "lng": "8.19962"
  },
  {
    "country": "IT",
    "name": "Carinola",
    "lat": "41.18775",
    "lng": "13.9824"
  },
  {
    "country": "IT",
    "name": "Carimate",
    "lat": "45.70659",
    "lng": "9.10751"
  },
  {
    "country": "IT",
    "name": "Carignano",
    "lat": "44.90599",
    "lng": "7.67253"
  },
  {
    "country": "IT",
    "name": "Carife",
    "lat": "41.02667",
    "lng": "15.21044"
  },
  {
    "country": "IT",
    "name": "Cargeghe",
    "lat": "40.66894",
    "lng": "8.61521"
  },
  {
    "country": "IT",
    "name": "Caresana",
    "lat": "45.22142",
    "lng": "8.5048"
  },
  {
    "country": "IT",
    "name": "Carenno",
    "lat": "45.80155",
    "lng": "9.46301"
  },
  {
    "country": "IT",
    "name": "Carema",
    "lat": "45.58401",
    "lng": "7.80879"
  },
  {
    "country": "IT",
    "name": "Corneno-Galliano-Carella Mariaga",
    "lat": "45.81667",
    "lng": "9.26667"
  },
  {
    "country": "IT",
    "name": "Cardito",
    "lat": "40.9459",
    "lng": "14.29952"
  },
  {
    "country": "IT",
    "name": "Cardano",
    "lat": "46.49336",
    "lng": "11.39295"
  },
  {
    "country": "IT",
    "name": "Carcoforo",
    "lat": "45.90858",
    "lng": "8.04967"
  },
  {
    "country": "IT",
    "name": "Carceri",
    "lat": "45.19508",
    "lng": "11.62115"
  },
  {
    "country": "IT",
    "name": "Carcare",
    "lat": "44.35465",
    "lng": "8.29039"
  },
  {
    "country": "IT",
    "name": "Carbonera",
    "lat": "45.69182",
    "lng": "12.28255"
  },
  {
    "country": "IT",
    "name": "Carbone",
    "lat": "40.14227",
    "lng": "16.08846"
  },
  {
    "country": "IT",
    "name": "Carbonara di Po",
    "lat": "45.03537",
    "lng": "11.22923"
  },
  {
    "country": "IT",
    "name": "Carbonara al Ticino",
    "lat": "45.16374",
    "lng": "9.0649"
  },
  {
    "country": "IT",
    "name": "Carbognano",
    "lat": "42.33024",
    "lng": "12.26457"
  },
  {
    "country": "IT",
    "name": "Caravonica",
    "lat": "43.99303",
    "lng": "7.95805"
  },
  {
    "country": "IT",
    "name": "Caravino",
    "lat": "45.3995",
    "lng": "7.9602"
  },
  {
    "country": "IT",
    "name": "Caravate",
    "lat": "45.87862",
    "lng": "8.65431"
  },
  {
    "country": "IT",
    "name": "Caravaggio",
    "lat": "45.49627",
    "lng": "9.64165"
  },
  {
    "country": "IT",
    "name": "Carate Brianza",
    "lat": "45.67574",
    "lng": "9.23723"
  },
  {
    "country": "IT",
    "name": "Carassai",
    "lat": "43.03303",
    "lng": "13.68761"
  },
  {
    "country": "IT",
    "name": "Carasco",
    "lat": "44.34975",
    "lng": "9.34567"
  },
  {
    "country": "IT",
    "name": "Carapelle Calvisio",
    "lat": "42.29908",
    "lng": "13.68643"
  },
  {
    "country": "IT",
    "name": "Carapelle",
    "lat": "41.36365",
    "lng": "15.69384"
  },
  {
    "country": "IT",
    "name": "Carano",
    "lat": "41.20526",
    "lng": "13.90972"
  },
  {
    "country": "IT",
    "name": "Caramanico Terme",
    "lat": "42.15593",
    "lng": "14.0048"
  },
  {
    "country": "IT",
    "name": "Caraglio",
    "lat": "44.41725",
    "lng": "7.43281"
  },
  {
    "country": "IT",
    "name": "Capurso",
    "lat": "41.04598",
    "lng": "16.92168"
  },
  {
    "country": "IT",
    "name": "Capua",
    "lat": "41.10519",
    "lng": "14.21269"
  },
  {
    "country": "IT",
    "name": "Capriolo",
    "lat": "45.63333",
    "lng": "9.93189"
  },
  {
    "country": "IT",
    "name": "Caprino Veronese",
    "lat": "45.60489",
    "lng": "10.79518"
  },
  {
    "country": "IT",
    "name": "Caprino",
    "lat": "45.74903",
    "lng": "9.49235"
  },
  {
    "country": "IT",
    "name": "Capriglia Irpina",
    "lat": "40.96032",
    "lng": "14.77724"
  },
  {
    "country": "IT",
    "name": "Caprie",
    "lat": "45.11944",
    "lng": "7.33294"
  },
  {
    "country": "IT",
    "name": "Capriati A Volturno",
    "lat": "41.46801",
    "lng": "14.14602"
  },
  {
    "country": "IT",
    "name": "Capriate San Gervasio",
    "lat": "45.61281",
    "lng": "9.52974"
  },
  {
    "country": "IT",
    "name": "Capriana",
    "lat": "46.26281",
    "lng": "11.33801"
  },
  {
    "country": "IT",
    "name": "Capri",
    "lat": "40.55073",
    "lng": "14.24263"
  },
  {
    "country": "IT",
    "name": "Caprese Michelangelo",
    "lat": "43.64031",
    "lng": "11.98546"
  },
  {
    "country": "IT",
    "name": "Caprarola",
    "lat": "42.32308",
    "lng": "12.23848"
  },
  {
    "country": "IT",
    "name": "Caprarica di Lecce",
    "lat": "40.2606",
    "lng": "18.24426"
  },
  {
    "country": "IT",
    "name": "Capranica Prenestina",
    "lat": "41.86285",
    "lng": "12.95077"
  },
  {
    "country": "IT",
    "name": "Capranica",
    "lat": "42.25849",
    "lng": "12.17278"
  },
  {
    "country": "IT",
    "name": "Capralba",
    "lat": "45.44352",
    "lng": "9.64417"
  },
  {
    "country": "IT",
    "name": "Capraia Isola",
    "lat": "43.05064",
    "lng": "9.84298"
  },
  {
    "country": "IT",
    "name": "Capracotta",
    "lat": "41.83326",
    "lng": "14.26581"
  },
  {
    "country": "IT",
    "name": "Cappelle sul Tavo",
    "lat": "42.47709",
    "lng": "14.10735"
  },
  {
    "country": "IT",
    "name": "Cappella Maggiore",
    "lat": "45.97222",
    "lng": "12.35855"
  },
  {
    "country": "IT",
    "name": "Cappella de' Picenardi",
    "lat": "45.15857",
    "lng": "10.22998"
  },
  {
    "country": "IT",
    "name": "Cappadocia",
    "lat": "42.00755",
    "lng": "13.27806"
  },
  {
    "country": "IT",
    "name": "Caposele",
    "lat": "40.81553",
    "lng": "15.22337"
  },
  {
    "country": "IT",
    "name": "Caporciano",
    "lat": "42.25001",
    "lng": "13.67455"
  },
  {
    "country": "IT",
    "name": "Capoliveri",
    "lat": "42.74569",
    "lng": "10.37753"
  },
  {
    "country": "IT",
    "name": "Capodrise",
    "lat": "41.04268",
    "lng": "14.30607"
  },
  {
    "country": "IT",
    "name": "Capo di Ponte",
    "lat": "46.03",
    "lng": "10.34283"
  },
  {
    "country": "IT",
    "name": "Capodimonte",
    "lat": "42.5478",
    "lng": "11.90657"
  },
  {
    "country": "IT",
    "name": "Capodarco",
    "lat": "43.18985",
    "lng": "13.75935"
  },
  {
    "country": "IT",
    "name": "Capitignano",
    "lat": "42.52041",
    "lng": "13.30122"
  },
  {
    "country": "IT",
    "name": "Capistrello",
    "lat": "41.97223",
    "lng": "13.39616"
  },
  {
    "country": "IT",
    "name": "Capestrano",
    "lat": "42.26807",
    "lng": "13.76779"
  },
  {
    "country": "IT",
    "name": "Capergnanica",
    "lat": "45.33869",
    "lng": "9.64475"
  },
  {
    "country": "IT",
    "name": "Capena",
    "lat": "42.14247",
    "lng": "12.54513"
  },
  {
    "country": "IT",
    "name": "Capannori",
    "lat": "43.84171",
    "lng": "10.57271"
  },
  {
    "country": "IT",
    "name": "Capannoli",
    "lat": "43.58856",
    "lng": "10.67328"
  },
  {
    "country": "IT",
    "name": "Capalbio",
    "lat": "42.45342",
    "lng": "11.42175"
  },
  {
    "country": "IT",
    "name": "Capaccio",
    "lat": "40.42435",
    "lng": "15.07981"
  },
  {
    "country": "IT",
    "name": "Caorso",
    "lat": "45.04911",
    "lng": "9.87457"
  },
  {
    "country": "IT",
    "name": "Caorle",
    "lat": "45.59656",
    "lng": "12.8758"
  },
  {
    "country": "IT",
    "name": "Canzo",
    "lat": "45.84867",
    "lng": "9.27063"
  },
  {
    "country": "IT",
    "name": "Canzano",
    "lat": "42.64564",
    "lng": "13.8041"
  },
  {
    "country": "IT",
    "name": "Cantù",
    "lat": "45.74096",
    "lng": "9.13084"
  },
  {
    "country": "IT",
    "name": "Cantoira",
    "lat": "45.34014",
    "lng": "7.3845"
  },
  {
    "country": "IT",
    "name": "Cantiano",
    "lat": "43.47082",
    "lng": "12.62868"
  },
  {
    "country": "IT",
    "name": "Cantalupo nel Sannio",
    "lat": "41.52182",
    "lng": "14.39292"
  },
  {
    "country": "IT",
    "name": "Cantalupo Ligure",
    "lat": "44.71811",
    "lng": "9.04575"
  },
  {
    "country": "IT",
    "name": "Cantalupo in Sabina",
    "lat": "42.30689",
    "lng": "12.64513"
  },
  {
    "country": "IT",
    "name": "Cantalice",
    "lat": "42.46458",
    "lng": "12.90461"
  },
  {
    "country": "IT",
    "name": "Cantagallo",
    "lat": "44.02205",
    "lng": "11.07971"
  },
  {
    "country": "IT",
    "name": "Cansano",
    "lat": "42.0035",
    "lng": "14.01341"
  },
  {
    "country": "IT",
    "name": "Olgiate Molgora",
    "lat": "45.73028",
    "lng": "9.40335"
  },
  {
    "country": "IT",
    "name": "Canosa Sannita",
    "lat": "42.29629",
    "lng": "14.30514"
  },
  {
    "country": "IT",
    "name": "Canosa di Puglia",
    "lat": "41.21954",
    "lng": "16.06768"
  },
  {
    "country": "IT",
    "name": "Cannole",
    "lat": "40.16592",
    "lng": "18.36456"
  },
  {
    "country": "IT",
    "name": "Cannobio",
    "lat": "46.06233",
    "lng": "8.69628"
  },
  {
    "country": "IT",
    "name": "Canneto sull'Oglio",
    "lat": "45.15163",
    "lng": "10.38282"
  },
  {
    "country": "IT",
    "name": "Canneto Pavese",
    "lat": "45.05046",
    "lng": "9.27876"
  },
  {
    "country": "IT",
    "name": "Cannero Riviera",
    "lat": "46.022",
    "lng": "8.67933"
  },
  {
    "country": "IT",
    "name": "Cannara",
    "lat": "42.9954",
    "lng": "12.58202"
  },
  {
    "country": "IT",
    "name": "Cannalonga",
    "lat": "40.24461",
    "lng": "15.29325"
  },
  {
    "country": "IT",
    "name": "Canna",
    "lat": "40.09484",
    "lng": "16.50378"
  },
  {
    "country": "IT",
    "name": "Canischio",
    "lat": "45.37485",
    "lng": "7.59621"
  },
  {
    "country": "IT",
    "name": "Canino",
    "lat": "42.46592",
    "lng": "11.75294"
  },
  {
    "country": "IT",
    "name": "Caneva",
    "lat": "45.97078",
    "lng": "12.45261"
  },
  {
    "country": "IT",
    "name": "Canepina",
    "lat": "42.38315",
    "lng": "12.23179"
  },
  {
    "country": "IT",
    "name": "Canelli",
    "lat": "44.72084",
    "lng": "8.29282"
  },
  {
    "country": "IT",
    "name": "Canegrate",
    "lat": "45.56825",
    "lng": "8.92689"
  },
  {
    "country": "IT",
    "name": "Candiolo",
    "lat": "44.95858",
    "lng": "7.59812"
  },
  {
    "country": "IT",
    "name": "Candide",
    "lat": "46.58913",
    "lng": "12.51476"
  },
  {
    "country": "IT",
    "name": "Candida",
    "lat": "40.94148",
    "lng": "14.8723"
  },
  {
    "country": "IT",
    "name": "Candiana",
    "lat": "45.22184",
    "lng": "11.99256"
  },
  {
    "country": "IT",
    "name": "Candia Lomellina",
    "lat": "45.1767",
    "lng": "8.5955"
  },
  {
    "country": "IT",
    "name": "Candia Canavese",
    "lat": "45.32734",
    "lng": "7.88429"
  },
  {
    "country": "IT",
    "name": "Candelo",
    "lat": "45.54093",
    "lng": "8.10659"
  },
  {
    "country": "IT",
    "name": "Candela",
    "lat": "41.13601",
    "lng": "15.51537"
  },
  {
    "country": "IT",
    "name": "Cancello-Arnone",
    "lat": "41.0734",
    "lng": "14.02542"
  },
  {
    "country": "IT",
    "name": "Cancellara",
    "lat": "40.73068",
    "lng": "15.9247"
  },
  {
    "country": "IT",
    "name": "Canazei",
    "lat": "46.47627",
    "lng": "11.76929"
  },
  {
    "country": "IT",
    "name": "Canaro",
    "lat": "44.93394",
    "lng": "11.67541"
  },
  {
    "country": "IT",
    "name": "Canal San Bovo",
    "lat": "46.15667",
    "lng": "11.72998"
  },
  {
    "country": "IT",
    "name": "Canale Monterano",
    "lat": "42.13598",
    "lng": "12.10284"
  },
  {
    "country": "IT",
    "name": "Canale d'Agordo",
    "lat": "46.35693",
    "lng": "11.91429"
  },
  {
    "country": "IT",
    "name": "Canale",
    "lat": "44.79532",
    "lng": "7.99373"
  },
  {
    "country": "IT",
    "name": "Camugnano",
    "lat": "44.1711",
    "lng": "11.08828"
  },
  {
    "country": "IT",
    "name": "Camucia-Monsigliolo",
    "lat": "43.25926",
    "lng": "11.97114"
  },
  {
    "country": "IT",
    "name": "Campo Tures",
    "lat": "46.90844",
    "lng": "11.96036"
  },
  {
    "country": "IT",
    "name": "Campotosto",
    "lat": "42.55884",
    "lng": "13.36799"
  },
  {
    "country": "IT",
    "name": "Campo Tizzoro",
    "lat": "44.03994",
    "lng": "10.85237"
  },
  {
    "country": "IT",
    "name": "Campospinoso",
    "lat": "45.09403",
    "lng": "9.24585"
  },
  {
    "country": "IT",
    "name": "Camposanto",
    "lat": "44.79009",
    "lng": "11.14049"
  },
  {
    "country": "IT",
    "name": "Camposano",
    "lat": "40.95242",
    "lng": "14.52991"
  },
  {
    "country": "IT",
    "name": "Campo San Martino",
    "lat": "45.54868",
    "lng": "11.82809"
  },
  {
    "country": "IT",
    "name": "Camposampiero",
    "lat": "45.56368",
    "lng": "11.93534"
  },
  {
    "country": "IT",
    "name": "Camporotondo di Fiastrone",
    "lat": "43.13203",
    "lng": "13.26632"
  },
  {
    "country": "IT",
    "name": "Camporosso",
    "lat": "43.8131",
    "lng": "7.62829"
  },
  {
    "country": "IT",
    "name": "Camporgiano",
    "lat": "44.15927",
    "lng": "10.333"
  },
  {
    "country": "IT",
    "name": "Campora",
    "lat": "40.30541",
    "lng": "15.29236"
  },
  {
    "country": "IT",
    "name": "Camponogara",
    "lat": "45.37954",
    "lng": "12.08638"
  },
  {
    "country": "IT",
    "name": "Campomorone",
    "lat": "44.50954",
    "lng": "8.88502"
  },
  {
    "country": "IT",
    "name": "Campomarino",
    "lat": "41.95692",
    "lng": "15.03546"
  },
  {
    "country": "IT",
    "name": "Campomaggiore",
    "lat": "40.5659",
    "lng": "16.0725"
  },
  {
    "country": "IT",
    "name": "Campolongo al Torre",
    "lat": "45.86389",
    "lng": "13.39667"
  },
  {
    "country": "IT",
    "name": "Campo Ligure",
    "lat": "44.53658",
    "lng": "8.69896"
  },
  {
    "country": "IT",
    "name": "Campolieto",
    "lat": "41.63336",
    "lng": "14.76694"
  },
  {
    "country": "IT",
    "name": "Campoli del Monte Taburno",
    "lat": "41.13074",
    "lng": "14.64649"
  },
  {
    "country": "IT",
    "name": "Campoli Appennino",
    "lat": "41.73539",
    "lng": "13.68326"
  },
  {
    "country": "IT",
    "name": "Campoleone",
    "lat": "41.6457",
    "lng": "12.64826"
  },
  {
    "country": "IT",
    "name": "Campolattaro",
    "lat": "41.28693",
    "lng": "14.73043"
  },
  {
    "country": "IT",
    "name": "Campo Jemini",
    "lat": "41.62716",
    "lng": "12.51258"
  },
  {
    "country": "IT",
    "name": "Campogalliano",
    "lat": "44.68874",
    "lng": "10.84705"
  },
  {
    "country": "IT",
    "name": "Campoformido",
    "lat": "46.01952",
    "lng": "13.1575"
  },
  {
    "country": "IT",
    "name": "Campofilone",
    "lat": "43.081",
    "lng": "13.82153"
  },
  {
    "country": "IT",
    "name": "Campodoro",
    "lat": "45.48947",
    "lng": "11.75268"
  },
  {
    "country": "IT",
    "name": "Campodolcino",
    "lat": "46.4029",
    "lng": "9.35185"
  },
  {
    "country": "IT",
    "name": "Campo di Trens",
    "lat": "46.87412",
    "lng": "11.48605"
  },
  {
    "country": "IT",
    "name": "Campodipietra",
    "lat": "41.5574",
    "lng": "14.74445"
  },
  {
    "country": "IT",
    "name": "Campo di Giove",
    "lat": "42.01013",
    "lng": "14.03941"
  },
  {
    "country": "IT",
    "name": "Campo di Carne",
    "lat": "41.55265",
    "lng": "12.64114"
  },
  {
    "country": "IT",
    "name": "Campodenno",
    "lat": "46.25791",
    "lng": "11.03317"
  },
  {
    "country": "IT",
    "name": "Campodarsego",
    "lat": "45.49815",
    "lng": "11.92194"
  },
  {
    "country": "IT",
    "name": "Campochiaro",
    "lat": "41.44827",
    "lng": "14.50828"
  },
  {
    "country": "IT",
    "name": "Campobasso",
    "lat": "41.55947",
    "lng": "14.66737"
  },
  {
    "country": "IT",
    "name": "Campli",
    "lat": "42.72679",
    "lng": "13.68692"
  },
  {
    "country": "IT",
    "name": "Campitello di Fassa",
    "lat": "46.47579",
    "lng": "11.7411"
  },
  {
    "country": "IT",
    "name": "Campitello",
    "lat": "45.0875",
    "lng": "10.60632"
  },
  {
    "country": "IT",
    "name": "Campi Salentina",
    "lat": "40.39747",
    "lng": "18.02141"
  },
  {
    "country": "IT",
    "name": "Campione",
    "lat": "45.96818",
    "lng": "8.97181"
  },
  {
    "country": "IT",
    "name": "Campiglia Marittima",
    "lat": "43.06001",
    "lng": "10.61453"
  },
  {
    "country": "IT",
    "name": "Campiglia dei Berici",
    "lat": "45.33546",
    "lng": "11.5421"
  },
  {
    "country": "IT",
    "name": "Campiglia Cervo",
    "lat": "45.6629",
    "lng": "7.99967"
  },
  {
    "country": "IT",
    "name": "Campi Bisenzio",
    "lat": "43.8245",
    "lng": "11.13027"
  },
  {
    "country": "IT",
    "name": "Campertogno",
    "lat": "45.79877",
    "lng": "8.03212"
  },
  {
    "country": "IT",
    "name": "Campello sul Clitunno",
    "lat": "42.82685",
    "lng": "12.76931"
  },
  {
    "country": "IT",
    "name": "Campegine",
    "lat": "44.78085",
    "lng": "10.52836"
  },
  {
    "country": "IT",
    "name": "Camparada",
    "lat": "45.65489",
    "lng": "9.32328"
  },
  {
    "country": "IT",
    "name": "Campanarello",
    "lat": "41.04717",
    "lng": "14.91418"
  },
  {
    "country": "IT",
    "name": "Campalto",
    "lat": "45.48062",
    "lng": "12.28747"
  },
  {
    "country": "IT",
    "name": "Campagnola Emilia",
    "lat": "44.83925",
    "lng": "10.76507"
  },
  {
    "country": "IT",
    "name": "Campagnola",
    "lat": "45.27866",
    "lng": "11.99902"
  },
  {
    "country": "IT",
    "name": "Campagnatico",
    "lat": "42.88283",
    "lng": "11.27394"
  },
  {
    "country": "IT",
    "name": "Campagnano di Roma",
    "lat": "42.1357",
    "lng": "12.37358"
  },
  {
    "country": "IT",
    "name": "Campagna Lupia",
    "lat": "45.35381",
    "lng": "12.09727"
  },
  {
    "country": "IT",
    "name": "Campagna",
    "lat": "40.66661",
    "lng": "15.10638"
  },
  {
    "country": "IT",
    "name": "Camogli",
    "lat": "44.34945",
    "lng": "9.15487"
  },
  {
    "country": "IT",
    "name": "Camisano Vicentino",
    "lat": "45.52156",
    "lng": "11.70817"
  },
  {
    "country": "IT",
    "name": "Camisano",
    "lat": "45.44484",
    "lng": "9.74526"
  },
  {
    "country": "IT",
    "name": "Camino",
    "lat": "45.15723",
    "lng": "8.29376"
  },
  {
    "country": "IT",
    "name": "Camigliano",
    "lat": "41.18116",
    "lng": "14.20978"
  },
  {
    "country": "IT",
    "name": "Camerota",
    "lat": "40.03262",
    "lng": "15.37048"
  },
  {
    "country": "IT",
    "name": "Camerino",
    "lat": "43.13866",
    "lng": "13.06785"
  },
  {
    "country": "IT",
    "name": "Cameri",
    "lat": "45.50159",
    "lng": "8.66245"
  },
  {
    "country": "IT",
    "name": "Camerata Picena",
    "lat": "43.57758",
    "lng": "13.35196"
  },
  {
    "country": "IT",
    "name": "Camerata Nuova",
    "lat": "42.018",
    "lng": "13.1097"
  },
  {
    "country": "IT",
    "name": "Camerata Cornello",
    "lat": "45.89956",
    "lng": "9.65569"
  },
  {
    "country": "IT",
    "name": "Camerano",
    "lat": "43.52774",
    "lng": "13.55257"
  },
  {
    "country": "IT",
    "name": "Camburzano",
    "lat": "45.54393",
    "lng": "8.00226"
  },
  {
    "country": "IT",
    "name": "Cambiano",
    "lat": "44.97113",
    "lng": "7.77447"
  },
  {
    "country": "IT",
    "name": "Cambiago",
    "lat": "45.58035",
    "lng": "9.43528"
  },
  {
    "country": "IT",
    "name": "Camalò",
    "lat": "45.75324",
    "lng": "12.17165"
  },
  {
    "country": "IT",
    "name": "Camairago",
    "lat": "45.20527",
    "lng": "9.72746"
  },
  {
    "country": "IT",
    "name": "Camaiore",
    "lat": "43.94265",
    "lng": "10.29754"
  },
  {
    "country": "IT",
    "name": "Calvizzano",
    "lat": "40.90782",
    "lng": "14.18581"
  },
  {
    "country": "IT",
    "name": "Calvisano",
    "lat": "45.34529",
    "lng": "10.34266"
  },
  {
    "country": "IT",
    "name": "Calvignano",
    "lat": "44.98306",
    "lng": "9.16876"
  },
  {
    "country": "IT",
    "name": "Calvi dell'Umbria",
    "lat": "42.40421",
    "lng": "12.56771"
  },
  {
    "country": "IT",
    "name": "Calvera",
    "lat": "40.14871",
    "lng": "16.14362"
  },
  {
    "country": "IT",
    "name": "Calvenzano",
    "lat": "45.49621",
    "lng": "9.59953"
  },
  {
    "country": "IT",
    "name": "Calvene",
    "lat": "45.76615",
    "lng": "11.51146"
  },
  {
    "country": "IT",
    "name": "Calvello",
    "lat": "40.47482",
    "lng": "15.85092"
  },
  {
    "country": "IT",
    "name": "Calvatone",
    "lat": "45.12697",
    "lng": "10.44057"
  },
  {
    "country": "IT",
    "name": "Calvanico",
    "lat": "40.77616",
    "lng": "14.82697"
  },
  {
    "country": "IT",
    "name": "Caluso",
    "lat": "45.30466",
    "lng": "7.89101"
  },
  {
    "country": "IT",
    "name": "Calusco d'Adda",
    "lat": "45.68841",
    "lng": "9.47109"
  },
  {
    "country": "IT",
    "name": "Caltrano",
    "lat": "45.77346",
    "lng": "11.4557"
  },
  {
    "country": "IT",
    "name": "Calto",
    "lat": "44.99072",
    "lng": "11.35854"
  },
  {
    "country": "IT",
    "name": "Caltignaga",
    "lat": "45.52088",
    "lng": "8.58616"
  },
  {
    "country": "IT",
    "name": "Caltana",
    "lat": "45.48278",
    "lng": "12.03002"
  },
  {
    "country": "IT",
    "name": "Calolziocorte",
    "lat": "45.79538",
    "lng": "9.43765"
  },
  {
    "country": "IT",
    "name": "Calò",
    "lat": "45.67908",
    "lng": "9.26309"
  },
  {
    "country": "IT",
    "name": "Calliano",
    "lat": "45.93299",
    "lng": "11.09503"
  },
  {
    "country": "IT",
    "name": "Calliano",
    "lat": "45.00798",
    "lng": "8.25661"
  },
  {
    "country": "IT",
    "name": "Calizzano",
    "lat": "44.23612",
    "lng": "8.11817"
  },
  {
    "country": "IT",
    "name": "Calitri",
    "lat": "40.92569",
    "lng": "15.40393"
  },
  {
    "country": "IT",
    "name": "Calimera",
    "lat": "40.24948",
    "lng": "18.27982"
  },
  {
    "country": "IT",
    "name": "Calice al Cornoviglio",
    "lat": "44.24326",
    "lng": "9.83671"
  },
  {
    "country": "IT",
    "name": "Calestano",
    "lat": "44.60224",
    "lng": "10.12363"
  },
  {
    "country": "IT",
    "name": "Calenzano",
    "lat": "43.85447",
    "lng": "11.16608"
  },
  {
    "country": "IT",
    "name": "Calendasco",
    "lat": "45.08659",
    "lng": "9.59647"
  },
  {
    "country": "IT",
    "name": "Caldonazzo",
    "lat": "45.99367",
    "lng": "11.26426"
  },
  {
    "country": "IT",
    "name": "Caldogno-Rettorgole-Cresole",
    "lat": "45.6078",
    "lng": "11.5028"
  },
  {
    "country": "IT",
    "name": "Caldes",
    "lat": "46.36686",
    "lng": "10.94037"
  },
  {
    "country": "IT",
    "name": "Calderara di Reno",
    "lat": "44.56307",
    "lng": "11.27111"
  },
  {
    "country": "IT",
    "name": "Caldarola",
    "lat": "43.14282",
    "lng": "13.22367"
  },
  {
    "country": "IT",
    "name": "Caldaro sulla Strada del Vino",
    "lat": "46.41326",
    "lng": "11.24616"
  },
  {
    "country": "IT",
    "name": "Calcio",
    "lat": "45.50826",
    "lng": "9.84902"
  },
  {
    "country": "IT",
    "name": "Calcinelli",
    "lat": "43.75398",
    "lng": "12.91959"
  },
  {
    "country": "IT",
    "name": "Calcinato",
    "lat": "45.45739",
    "lng": "10.40949"
  },
  {
    "country": "IT",
    "name": "Calcinate",
    "lat": "45.61975",
    "lng": "9.79843"
  },
  {
    "country": "IT",
    "name": "Calcinaia",
    "lat": "43.68352",
    "lng": "10.61653"
  },
  {
    "country": "IT",
    "name": "Calciano",
    "lat": "40.58802",
    "lng": "16.19238"
  },
  {
    "country": "IT",
    "name": "Calci",
    "lat": "43.72597",
    "lng": "10.51791"
  },
  {
    "country": "IT",
    "name": "Calcata Nuova",
    "lat": "42.21952",
    "lng": "12.42617"
  },
  {
    "country": "IT",
    "name": "Calcara",
    "lat": "44.54696",
    "lng": "11.13366"
  },
  {
    "country": "IT",
    "name": "Calavino",
    "lat": "46.04606",
    "lng": "10.98402"
  },
  {
    "country": "IT",
    "name": "Calascio",
    "lat": "42.32595",
    "lng": "13.69699"
  },
  {
    "country": "IT",
    "name": "Calangianus",
    "lat": "40.92027",
    "lng": "9.19343"
  },
  {
    "country": "IT",
    "name": "Calamandrana",
    "lat": "44.73767",
    "lng": "8.33726"
  },
  {
    "country": "IT",
    "name": "Calalzo di Cadore",
    "lat": "46.44643",
    "lng": "12.38176"
  },
  {
    "country": "IT",
    "name": "Cala Gonone",
    "lat": "40.28086",
    "lng": "9.62971"
  },
  {
    "country": "IT",
    "name": "Calabritto",
    "lat": "40.78342",
    "lng": "15.22285"
  },
  {
    "country": "IT",
    "name": "Caivano",
    "lat": "40.95753",
    "lng": "14.30591"
  },
  {
    "country": "IT",
    "name": "Cairo Montenotte",
    "lat": "44.3979",
    "lng": "8.27775"
  },
  {
    "country": "IT",
    "name": "Caira",
    "lat": "41.53333",
    "lng": "13.81667"
  },
  {
    "country": "IT",
    "name": "Cairate",
    "lat": "45.6875",
    "lng": "8.86807"
  },
  {
    "country": "IT",
    "name": "Cairano",
    "lat": "40.89552",
    "lng": "15.37069"
  },
  {
    "country": "IT",
    "name": "Caiazzo",
    "lat": "41.18435",
    "lng": "14.35946"
  },
  {
    "country": "IT",
    "name": "Caianello",
    "lat": "41.30509",
    "lng": "14.08516"
  },
  {
    "country": "IT",
    "name": "Cagnano Varano",
    "lat": "41.82832",
    "lng": "15.77203"
  },
  {
    "country": "IT",
    "name": "Caglio",
    "lat": "45.87146",
    "lng": "9.23719"
  },
  {
    "country": "IT",
    "name": "Cagli",
    "lat": "43.54771",
    "lng": "12.65229"
  },
  {
    "country": "IT",
    "name": "Caggiano",
    "lat": "40.5624",
    "lng": "15.49629"
  },
  {
    "country": "IT",
    "name": "Caerano di San Marco",
    "lat": "45.7816",
    "lng": "11.99851"
  },
  {
    "country": "IT",
    "name": "Cadoneghe",
    "lat": "45.44282",
    "lng": "11.92749"
  },
  {
    "country": "IT",
    "name": "Ca' di Sola",
    "lat": "44.52986",
    "lng": "10.95448"
  },
  {
    "country": "IT",
    "name": "Cadine",
    "lat": "46.0896",
    "lng": "11.06847"
  },
  {
    "country": "IT",
    "name": "Caderzone Terme",
    "lat": "46.12945",
    "lng": "10.75619"
  },
  {
    "country": "IT",
    "name": "Cadelbosco di Sotto",
    "lat": "44.80141",
    "lng": "10.61578"
  },
  {
    "country": "IT",
    "name": "Cadelbosco di Sopra",
    "lat": "44.76573",
    "lng": "10.59898"
  },
  {
    "country": "IT",
    "name": "Ca' degli Oppi",
    "lat": "45.2955",
    "lng": "11.13029"
  },
  {
    "country": "IT",
    "name": "Cadè-Gaida",
    "lat": "44.7385",
    "lng": "10.5158"
  },
  {
    "country": "IT",
    "name": "Cabella Ligure",
    "lat": "44.67491",
    "lng": "9.09607"
  },
  {
    "country": "IT",
    "name": "Buttrio",
    "lat": "46.01098",
    "lng": "13.33354"
  },
  {
    "country": "IT",
    "name": "Buttigliera Alta",
    "lat": "45.06836",
    "lng": "7.43254"
  },
  {
    "country": "IT",
    "name": "Buttapietra",
    "lat": "45.3411",
    "lng": "10.99915"
  },
  {
    "country": "IT",
    "name": "Buti",
    "lat": "43.72857",
    "lng": "10.5845"
  },
  {
    "country": "IT",
    "name": "Busto Garolfo",
    "lat": "45.54809",
    "lng": "8.88298"
  },
  {
    "country": "IT",
    "name": "Busto Arsizio",
    "lat": "45.61128",
    "lng": "8.84914"
  },
  {
    "country": "IT",
    "name": "Bussoleno",
    "lat": "45.1397",
    "lng": "7.14432"
  },
  {
    "country": "IT",
    "name": "Bussolengo",
    "lat": "45.46903",
    "lng": "10.85371"
  },
  {
    "country": "IT",
    "name": "Busso",
    "lat": "41.55413",
    "lng": "14.56103"
  },
  {
    "country": "IT",
    "name": "Bussi sul Tirino",
    "lat": "42.21321",
    "lng": "13.82511"
  },
  {
    "country": "IT",
    "name": "Busseto",
    "lat": "44.9794",
    "lng": "10.04331"
  },
  {
    "country": "IT",
    "name": "Buscoldo",
    "lat": "45.0943",
    "lng": "10.69581"
  },
  {
    "country": "IT",
    "name": "Buscate",
    "lat": "45.54353",
    "lng": "8.81297"
  },
  {
    "country": "IT",
    "name": "Busca",
    "lat": "44.51625",
    "lng": "7.47662"
  },
  {
    "country": "IT",
    "name": "Busano",
    "lat": "45.33137",
    "lng": "7.65727"
  },
  {
    "country": "IT",
    "name": "Busana",
    "lat": "44.36886",
    "lng": "10.32339"
  },
  {
    "country": "IT",
    "name": "Busalla",
    "lat": "44.5706",
    "lng": "8.94545"
  },
  {
    "country": "IT",
    "name": "Busachi",
    "lat": "40.03422",
    "lng": "8.88848"
  },
  {
    "country": "IT",
    "name": "Buronzo",
    "lat": "45.48018",
    "lng": "8.26628"
  },
  {
    "country": "IT",
    "name": "Burolo",
    "lat": "45.48116",
    "lng": "7.93392"
  },
  {
    "country": "IT",
    "name": "Buriasco",
    "lat": "44.87222",
    "lng": "7.412"
  },
  {
    "country": "IT",
    "name": "Burgos",
    "lat": "40.39081",
    "lng": "8.99558"
  },
  {
    "country": "IT",
    "name": "Burano",
    "lat": "45.48548",
    "lng": "12.41696"
  },
  {
    "country": "IT",
    "name": "Buonconvento",
    "lat": "43.13314",
    "lng": "11.48363"
  },
  {
    "country": "IT",
    "name": "Buonalbergo",
    "lat": "41.22236",
    "lng": "14.97799"
  },
  {
    "country": "IT",
    "name": "Buonabitacolo",
    "lat": "40.26855",
    "lng": "15.62119"
  },
  {
    "country": "IT",
    "name": "Bulzi",
    "lat": "40.84666",
    "lng": "8.83026"
  },
  {
    "country": "IT",
    "name": "Bultei",
    "lat": "40.4572",
    "lng": "9.06367"
  },
  {
    "country": "IT",
    "name": "Buia",
    "lat": "46.21222",
    "lng": "13.11691"
  },
  {
    "country": "IT",
    "name": "Buglio in Monte",
    "lat": "46.18336",
    "lng": "9.67542"
  },
  {
    "country": "IT",
    "name": "Budrio",
    "lat": "44.53745",
    "lng": "11.53439"
  },
  {
    "country": "IT",
    "name": "Budoia",
    "lat": "46.04453",
    "lng": "12.53429"
  },
  {
    "country": "IT",
    "name": "Buddusò",
    "lat": "40.57723",
    "lng": "9.25839"
  },
  {
    "country": "IT",
    "name": "Bucine",
    "lat": "43.47685",
    "lng": "11.61399"
  },
  {
    "country": "IT",
    "name": "Buccino",
    "lat": "40.6367",
    "lng": "15.38116"
  },
  {
    "country": "IT",
    "name": "Bucciano",
    "lat": "41.07756",
    "lng": "14.56898"
  },
  {
    "country": "IT",
    "name": "Bucchianico",
    "lat": "42.30368",
    "lng": "14.18377"
  },
  {
    "country": "IT",
    "name": "Bubbio",
    "lat": "44.66344",
    "lng": "8.29514"
  },
  {
    "country": "IT",
    "name": "Brusson",
    "lat": "45.75926",
    "lng": "7.72899"
  },
  {
    "country": "IT",
    "name": "Brusnengo",
    "lat": "45.59011",
    "lng": "8.25219"
  },
  {
    "country": "IT",
    "name": "Brusciano",
    "lat": "40.92237",
    "lng": "14.42386"
  },
  {
    "country": "IT",
    "name": "Brusasco",
    "lat": "45.15499",
    "lng": "8.06107"
  },
  {
    "country": "IT",
    "name": "Bruno",
    "lat": "44.79262",
    "lng": "8.43973"
  },
  {
    "country": "IT",
    "name": "Brunico",
    "lat": "46.79942",
    "lng": "11.93429"
  },
  {
    "country": "IT",
    "name": "Brunate",
    "lat": "45.82096",
    "lng": "9.09869"
  },
  {
    "country": "IT",
    "name": "Bruna",
    "lat": "42.82071",
    "lng": "12.68851"
  },
  {
    "country": "IT",
    "name": "Brumano",
    "lat": "45.85463",
    "lng": "9.50064"
  },
  {
    "country": "IT",
    "name": "Bruino",
    "lat": "45.01506",
    "lng": "7.47754"
  },
  {
    "country": "IT",
    "name": "Brugnera",
    "lat": "45.89947",
    "lng": "12.54178"
  },
  {
    "country": "IT",
    "name": "Brugnato",
    "lat": "44.23671",
    "lng": "9.72496"
  },
  {
    "country": "IT",
    "name": "Brugine",
    "lat": "45.29696",
    "lng": "11.992"
  },
  {
    "country": "IT",
    "name": "Brugherio",
    "lat": "45.55301",
    "lng": "9.29907"
  },
  {
    "country": "IT",
    "name": "Brosso",
    "lat": "45.4918",
    "lng": "7.80225"
  },
  {
    "country": "IT",
    "name": "Brossasco",
    "lat": "44.56778",
    "lng": "7.36454"
  },
  {
    "country": "IT",
    "name": "Bronzolo",
    "lat": "46.40346",
    "lng": "11.32078"
  },
  {
    "country": "IT",
    "name": "Broni",
    "lat": "45.06394",
    "lng": "9.25993"
  },
  {
    "country": "IT",
    "name": "Brivio",
    "lat": "45.73725",
    "lng": "9.44249"
  },
  {
    "country": "IT",
    "name": "Brittoli",
    "lat": "42.31518",
    "lng": "13.86026"
  },
  {
    "country": "IT",
    "name": "Grand Brissogne",
    "lat": "45.72566",
    "lng": "7.3926"
  },
  {
    "country": "IT",
    "name": "Brissago-Valtravaglia",
    "lat": "45.94921",
    "lng": "8.7459"
  },
  {
    "country": "IT",
    "name": "Brisighella",
    "lat": "44.22228",
    "lng": "11.77358"
  },
  {
    "country": "IT",
    "name": "Brinzio",
    "lat": "45.88914",
    "lng": "8.78683"
  },
  {
    "country": "IT",
    "name": "Brindisi Montagna",
    "lat": "40.60952",
    "lng": "15.93977"
  },
  {
    "country": "IT",
    "name": "Brindisi",
    "lat": "40.63215",
    "lng": "17.93607"
  },
  {
    "country": "IT",
    "name": "Brignano Gera d'Adda",
    "lat": "45.54324",
    "lng": "9.64424"
  },
  {
    "country": "IT",
    "name": "Brignano",
    "lat": "44.81457",
    "lng": "9.04005"
  },
  {
    "country": "IT",
    "name": "Briga Novarese",
    "lat": "45.72931",
    "lng": "8.45586"
  },
  {
    "country": "IT",
    "name": "Brienno",
    "lat": "45.91175",
    "lng": "9.13142"
  },
  {
    "country": "IT",
    "name": "Bricherasio",
    "lat": "44.82328",
    "lng": "7.303"
  },
  {
    "country": "IT",
    "name": "Brez",
    "lat": "46.4322",
    "lng": "11.10578"
  },
  {
    "country": "IT",
    "name": "Bresso",
    "lat": "45.53792",
    "lng": "9.18921"
  },
  {
    "country": "IT",
    "name": "Bressanvido",
    "lat": "45.64651",
    "lng": "11.63437"
  },
  {
    "country": "IT",
    "name": "Bressanone",
    "lat": "46.71503",
    "lng": "11.65598"
  },
  {
    "country": "IT",
    "name": "Bressana",
    "lat": "45.07807",
    "lng": "9.13119"
  },
  {
    "country": "IT",
    "name": "Brescia",
    "lat": "45.53558",
    "lng": "10.21472"
  },
  {
    "country": "IT",
    "name": "Brescello",
    "lat": "44.89531",
    "lng": "10.51269"
  },
  {
    "country": "IT",
    "name": "Brentonico",
    "lat": "45.8191",
    "lng": "10.95508"
  },
  {
    "country": "IT",
    "name": "Breno",
    "lat": "45.95889",
    "lng": "10.30648"
  },
  {
    "country": "IT",
    "name": "Brenna",
    "lat": "45.74338",
    "lng": "9.18657"
  },
  {
    "country": "IT",
    "name": "Brendola",
    "lat": "45.47849",
    "lng": "11.43947"
  },
  {
    "country": "IT",
    "name": "Breme",
    "lat": "45.12756",
    "lng": "8.62564"
  },
  {
    "country": "IT",
    "name": "Brembio",
    "lat": "45.21234",
    "lng": "9.57244"
  },
  {
    "country": "IT",
    "name": "Brembilla",
    "lat": "45.82154",
    "lng": "9.59679"
  },
  {
    "country": "IT",
    "name": "Brembate",
    "lat": "45.60468",
    "lng": "9.5548"
  },
  {
    "country": "IT",
    "name": "Breia",
    "lat": "45.76497",
    "lng": "8.30552"
  },
  {
    "country": "IT",
    "name": "Breguzzo",
    "lat": "46.00679",
    "lng": "10.69761"
  },
  {
    "country": "IT",
    "name": "Breganze",
    "lat": "45.70489",
    "lng": "11.56074"
  },
  {
    "country": "IT",
    "name": "Breda",
    "lat": "45.7225",
    "lng": "12.33083"
  },
  {
    "country": "IT",
    "name": "Brebbia",
    "lat": "45.82983",
    "lng": "8.65042"
  },
  {
    "country": "IT",
    "name": "Braone",
    "lat": "45.99011",
    "lng": "10.34178"
  },
  {
    "country": "IT",
    "name": "Brandizzo",
    "lat": "45.17706",
    "lng": "7.83581"
  },
  {
    "country": "IT",
    "name": "Pregola",
    "lat": "44.75069",
    "lng": "9.28223"
  },
  {
    "country": "IT",
    "name": "Bracigliano",
    "lat": "40.8188",
    "lng": "14.70772"
  },
  {
    "country": "IT",
    "name": "Bracciano",
    "lat": "42.10271",
    "lng": "12.16565"
  },
  {
    "country": "IT",
    "name": "Braccagni",
    "lat": "42.87285",
    "lng": "11.07266"
  },
  {
    "country": "IT",
    "name": "Bra",
    "lat": "44.69776",
    "lng": "7.85128"
  },
  {
    "country": "IT",
    "name": "Bozzolo",
    "lat": "45.10324",
    "lng": "10.47988"
  },
  {
    "country": "IT",
    "name": "Bozzole",
    "lat": "45.06934",
    "lng": "8.60561"
  },
  {
    "country": "IT",
    "name": "Bovolone",
    "lat": "45.26142",
    "lng": "11.11786"
  },
  {
    "country": "IT",
    "name": "Bovolenta",
    "lat": "45.26892",
    "lng": "11.93576"
  },
  {
    "country": "IT",
    "name": "Marchesino-Bovo",
    "lat": "45.36667",
    "lng": "11"
  },
  {
    "country": "IT",
    "name": "Bovisio-Masciago",
    "lat": "45.61019",
    "lng": "9.15301"
  },
  {
    "country": "IT",
    "name": "Bovino",
    "lat": "41.24916",
    "lng": "15.33948"
  },
  {
    "country": "IT",
    "name": "Boville Ernica",
    "lat": "41.64252",
    "lng": "13.4727"
  },
  {
    "country": "IT",
    "name": "Bovezzo",
    "lat": "45.58998",
    "lng": "10.24184"
  },
  {
    "country": "IT",
    "name": "Boves",
    "lat": "44.32985",
    "lng": "7.54733"
  },
  {
    "country": "IT",
    "name": "Bovegno",
    "lat": "45.79121",
    "lng": "10.27012"
  },
  {
    "country": "IT",
    "name": "Bottrighe",
    "lat": "45.02552",
    "lng": "12.08236"
  },
  {
    "country": "IT",
    "name": "Bottidda",
    "lat": "40.39242",
    "lng": "9.01039"
  },
  {
    "country": "IT",
    "name": "Botticino",
    "lat": "45.52972",
    "lng": "10.31085"
  },
  {
    "country": "IT",
    "name": "Bottanuco",
    "lat": "45.63931",
    "lng": "9.50903"
  },
  {
    "country": "IT",
    "name": "Botrugno",
    "lat": "40.06359",
    "lng": "18.32254"
  },
  {
    "country": "IT",
    "name": "Bossolasco",
    "lat": "44.52818",
    "lng": "8.04993"
  },
  {
    "country": "IT",
    "name": "Bosisio Parini",
    "lat": "45.80075",
    "lng": "9.29"
  },
  {
    "country": "IT",
    "name": "Bosentino-Migazzone",
    "lat": "46.0018",
    "lng": "11.22318"
  },
  {
    "country": "IT",
    "name": "Boscotrecase",
    "lat": "40.77296",
    "lng": "14.46185"
  },
  {
    "country": "IT",
    "name": "Boscoreale",
    "lat": "40.77274",
    "lng": "14.48118"
  },
  {
    "country": "IT",
    "name": "Bosconero",
    "lat": "45.2663",
    "lng": "7.76578"
  },
  {
    "country": "IT",
    "name": "Bosco Marengo",
    "lat": "44.82373",
    "lng": "8.68008"
  },
  {
    "country": "IT",
    "name": "Bosco Chiesanuova",
    "lat": "45.62103",
    "lng": "11.03224"
  },
  {
    "country": "IT",
    "name": "Bosco",
    "lat": "45.44337",
    "lng": "11.7953"
  },
  {
    "country": "IT",
    "name": "Bosco Mesola",
    "lat": "44.87639",
    "lng": "12.23139"
  },
  {
    "country": "IT",
    "name": "Boschetto",
    "lat": "45.16591",
    "lng": "10.02656"
  },
  {
    "country": "IT",
    "name": "Bosaro",
    "lat": "44.99878",
    "lng": "11.76471"
  },
  {
    "country": "IT",
    "name": "Bosa",
    "lat": "40.29927",
    "lng": "8.49827"
  },
  {
    "country": "IT",
    "name": "Borzonasca",
    "lat": "44.42002",
    "lng": "9.38851"
  },
  {
    "country": "IT",
    "name": "Borzano",
    "lat": "44.6036",
    "lng": "10.63675"
  },
  {
    "country": "IT",
    "name": "Borutta",
    "lat": "40.52236",
    "lng": "8.74352"
  },
  {
    "country": "IT",
    "name": "Bortigiadas",
    "lat": "40.89167",
    "lng": "9.04352"
  },
  {
    "country": "IT",
    "name": "Bortigali",
    "lat": "40.28268",
    "lng": "8.83946"
  },
  {
    "country": "IT",
    "name": "Borso del Grappa",
    "lat": "45.81025",
    "lng": "11.77367"
  },
  {
    "country": "IT",
    "name": "Borriana",
    "lat": "45.50781",
    "lng": "8.0386"
  },
  {
    "country": "IT",
    "name": "Borrello",
    "lat": "41.9173",
    "lng": "14.30535"
  },
  {
    "country": "IT",
    "name": "Borore",
    "lat": "40.21576",
    "lng": "8.80365"
  },
  {
    "country": "IT",
    "name": "Boroneddu",
    "lat": "40.11262",
    "lng": "8.87023"
  },
  {
    "country": "IT",
    "name": "Borno",
    "lat": "45.94748",
    "lng": "10.20243"
  },
  {
    "country": "IT",
    "name": "Bornasco",
    "lat": "45.26657",
    "lng": "9.21795"
  },
  {
    "country": "IT",
    "name": "Bormio",
    "lat": "46.46717",
    "lng": "10.37008"
  },
  {
    "country": "IT",
    "name": "Borgo Vercelli",
    "lat": "45.3568",
    "lng": "8.4646"
  },
  {
    "country": "IT",
    "name": "Borgo Velino",
    "lat": "42.40508",
    "lng": "13.0565"
  },
  {
    "country": "IT",
    "name": "Borgo Val di Taro",
    "lat": "44.48899",
    "lng": "9.76906"
  },
  {
    "country": "IT",
    "name": "Borgo Tossignano",
    "lat": "44.28233",
    "lng": "11.59659"
  },
  {
    "country": "IT",
    "name": "Borgo Ticino",
    "lat": "45.68931",
    "lng": "8.60448"
  },
  {
    "country": "IT",
    "name": "Borgosesia",
    "lat": "45.72045",
    "lng": "8.27466"
  },
  {
    "country": "IT",
    "name": "Borgosatollo",
    "lat": "45.4769",
    "lng": "10.2403"
  },
  {
    "country": "IT",
    "name": "Borgo Santa Maria",
    "lat": "43.87582",
    "lng": "12.80235"
  },
  {
    "country": "IT",
    "name": "Borgo San Martino",
    "lat": "45.09259",
    "lng": "8.52373"
  },
  {
    "country": "IT",
    "name": "Borgo San Lorenzo",
    "lat": "43.95548",
    "lng": "11.38561"
  },
  {
    "country": "IT",
    "name": "Borgo San Giacomo",
    "lat": "45.34798",
    "lng": "9.96817"
  },
  {
    "country": "IT",
    "name": "Borgo San Dalmazzo",
    "lat": "44.33785",
    "lng": "7.4931"
  },
  {
    "country": "IT",
    "name": "Borgo Sabotino-Foce Verde",
    "lat": "41.41667",
    "lng": "12.83333"
  },
  {
    "country": "IT",
    "name": "Borgorose",
    "lat": "42.19077",
    "lng": "13.23282"
  },
  {
    "country": "IT",
    "name": "Borgoricco-San Michele delle Badesse-Sant'Eufemia",
    "lat": "45.5352",
    "lng": "11.94111"
  },
  {
    "country": "IT",
    "name": "Borgoratto Mormorolo",
    "lat": "44.92889",
    "lng": "9.19402"
  },
  {
    "country": "IT",
    "name": "Borgoratto Alessandrino",
    "lat": "44.83625",
    "lng": "8.53854"
  },
  {
    "country": "IT",
    "name": "Borgo Priolo",
    "lat": "44.96632",
    "lng": "9.14835"
  },
  {
    "country": "IT",
    "name": "Borgo Podgora",
    "lat": "41.51462",
    "lng": "12.85383"
  },
  {
    "country": "IT",
    "name": "Borgo Pace",
    "lat": "43.65808",
    "lng": "12.29317"
  },
  {
    "country": "IT",
    "name": "Borgonuovo",
    "lat": "44.43557",
    "lng": "11.27069"
  },
  {
    "country": "IT",
    "name": "Borgonovo Valtidone",
    "lat": "45.01436",
    "lng": "9.44346"
  },
  {
    "country": "IT",
    "name": "Borgone Susa",
    "lat": "45.12334",
    "lng": "7.23641"
  },
  {
    "country": "IT",
    "name": "Borgomasino",
    "lat": "45.36205",
    "lng": "7.98811"
  },
  {
    "country": "IT",
    "name": "Borgomaro",
    "lat": "43.9753",
    "lng": "7.94408"
  },
  {
    "country": "IT",
    "name": "Borgomanero",
    "lat": "45.69873",
    "lng": "8.4623"
  },
  {
    "country": "IT",
    "name": "Borgomale",
    "lat": "44.62034",
    "lng": "8.13224"
  },
  {
    "country": "IT",
    "name": "Borgolavezzaro",
    "lat": "45.31918",
    "lng": "8.69931"
  },
  {
    "country": "IT",
    "name": "Borgo Grappa",
    "lat": "41.40212",
    "lng": "12.96053"
  },
  {
    "country": "IT",
    "name": "Borgofranco d'Ivrea",
    "lat": "45.51636",
    "lng": "7.85865"
  },
  {
    "country": "IT",
    "name": "Fosso Ghiaia",
    "lat": "44.35525",
    "lng": "12.2543"
  },
  {
    "country": "IT",
    "name": "Borgoforte",
    "lat": "45.05185",
    "lng": "10.75018"
  },
  {
    "country": "IT",
    "name": "Borgo di Terzo",
    "lat": "45.72078",
    "lng": "9.89096"
  },
  {
    "country": "IT",
    "name": "Borgo d'Ale",
    "lat": "45.34958",
    "lng": "8.05198"
  },
  {
    "country": "IT",
    "name": "Borgo a Mozzano",
    "lat": "43.97946",
    "lng": "10.54489"
  },
  {
    "country": "IT",
    "name": "Borgo a Buggiano",
    "lat": "43.87522",
    "lng": "10.73482"
  },
  {
    "country": "IT",
    "name": "Borgo",
    "lat": "46.05119",
    "lng": "11.45756"
  },
  {
    "country": "IT",
    "name": "Borgiallo",
    "lat": "45.41758",
    "lng": "7.66984"
  },
  {
    "country": "IT",
    "name": "Borghi",
    "lat": "44.03223",
    "lng": "12.35618"
  },
  {
    "country": "IT",
    "name": "Borghetto Santo Spirito",
    "lat": "44.11187",
    "lng": "8.24129"
  },
  {
    "country": "IT",
    "name": "Borghetto Lodigiano",
    "lat": "45.21326",
    "lng": "9.49946"
  },
  {
    "country": "IT",
    "name": "Borghetto di Vara",
    "lat": "44.22368",
    "lng": "9.72118"
  },
  {
    "country": "IT",
    "name": "Borghetto d'Arroscia",
    "lat": "44.05672",
    "lng": "7.98076"
  },
  {
    "country": "IT",
    "name": "Borghetto",
    "lat": "43.598",
    "lng": "13.29205"
  },
  {
    "country": "IT",
    "name": "Fornace Zarattini",
    "lat": "44.41667",
    "lng": "12.13333"
  },
  {
    "country": "IT",
    "name": "Borgaro Torinese",
    "lat": "45.15122",
    "lng": "7.65543"
  },
  {
    "country": "IT",
    "name": "Borgagne",
    "lat": "40.24108",
    "lng": "18.37661"
  },
  {
    "country": "IT",
    "name": "Boretto",
    "lat": "44.90157",
    "lng": "10.55147"
  },
  {
    "country": "IT",
    "name": "Borello",
    "lat": "44.05846",
    "lng": "12.17993"
  },
  {
    "country": "IT",
    "name": "Bore",
    "lat": "44.71866",
    "lng": "9.79207"
  },
  {
    "country": "IT",
    "name": "Bordolano",
    "lat": "45.2917",
    "lng": "9.98731"
  },
  {
    "country": "IT",
    "name": "Bordighera",
    "lat": "43.78064",
    "lng": "7.66451"
  },
  {
    "country": "IT",
    "name": "Borca",
    "lat": "46.43452",
    "lng": "12.2223"
  },
  {
    "country": "IT",
    "name": "Borbona",
    "lat": "42.50939",
    "lng": "13.13206"
  },
  {
    "country": "IT",
    "name": "Bonorva",
    "lat": "40.41839",
    "lng": "8.76831"
  },
  {
    "country": "IT",
    "name": "Bono",
    "lat": "40.41387",
    "lng": "9.03187"
  },
  {
    "country": "IT",
    "name": "Bonnanaro",
    "lat": "40.53265",
    "lng": "8.76389"
  },
  {
    "country": "IT",
    "name": "Bonito",
    "lat": "41.09857",
    "lng": "15.00071"
  },
  {
    "country": "IT",
    "name": "Bonferraro",
    "lat": "45.1838",
    "lng": "11.01201"
  },
  {
    "country": "IT",
    "name": "Bonefro",
    "lat": "41.70507",
    "lng": "14.93439"
  },
  {
    "country": "IT",
    "name": "Bonea",
    "lat": "41.07312",
    "lng": "14.61683"
  },
  {
    "country": "IT",
    "name": "Bondeno",
    "lat": "44.93569",
    "lng": "10.86035"
  },
  {
    "country": "IT",
    "name": "Bondeno",
    "lat": "44.88944",
    "lng": "11.41542"
  },
  {
    "country": "IT",
    "name": "Bonavigo",
    "lat": "45.25831",
    "lng": "11.27944"
  },
  {
    "country": "IT",
    "name": "Bonavicina",
    "lat": "45.24426",
    "lng": "11.18419"
  },
  {
    "country": "IT",
    "name": "Bonate Sopra",
    "lat": "45.68179",
    "lng": "9.55956"
  },
  {
    "country": "IT",
    "name": "Bonassola",
    "lat": "44.18323",
    "lng": "9.58422"
  },
  {
    "country": "IT",
    "name": "Bonarcado",
    "lat": "40.09836",
    "lng": "8.65534"
  },
  {
    "country": "IT",
    "name": "Santo Stefano-Bonaldo",
    "lat": "45.36718",
    "lng": "11.33199"
  },
  {
    "country": "IT",
    "name": "Bomporto",
    "lat": "44.73389",
    "lng": "11.03667"
  },
  {
    "country": "IT",
    "name": "Bomba",
    "lat": "42.03343",
    "lng": "14.36656"
  },
  {
    "country": "IT",
    "name": "Bomarzo",
    "lat": "42.48273",
    "lng": "12.25037"
  },
  {
    "country": "IT",
    "name": "Bolzano Vicentino",
    "lat": "45.60221",
    "lng": "11.62198"
  },
  {
    "country": "IT",
    "name": "Bolzano Novarese",
    "lat": "45.76266",
    "lng": "8.44248"
  },
  {
    "country": "IT",
    "name": "Bolzano",
    "lat": "46.49067",
    "lng": "11.33982"
  },
  {
    "country": "IT",
    "name": "Bolsena",
    "lat": "42.64326",
    "lng": "11.98514"
  },
  {
    "country": "IT",
    "name": "Bolotana",
    "lat": "40.3244",
    "lng": "8.96109"
  },
  {
    "country": "IT",
    "name": "Bolognola",
    "lat": "42.99319",
    "lng": "13.2268"
  },
  {
    "country": "IT",
    "name": "Bolognano",
    "lat": "42.21814",
    "lng": "13.96011"
  },
  {
    "country": "IT",
    "name": "Bologna",
    "lat": "44.49381",
    "lng": "11.33875"
  },
  {
    "country": "IT",
    "name": "Bollengo",
    "lat": "45.47162",
    "lng": "7.94133"
  },
  {
    "country": "IT",
    "name": "Bollate",
    "lat": "45.54647",
    "lng": "9.12054"
  },
  {
    "country": "IT",
    "name": "Bolano",
    "lat": "44.1877",
    "lng": "9.89488"
  },
  {
    "country": "IT",
    "name": "Bojano",
    "lat": "41.4853",
    "lng": "14.47075"
  },
  {
    "country": "IT",
    "name": "Bogliasco",
    "lat": "44.3807",
    "lng": "9.06926"
  },
  {
    "country": "IT",
    "name": "Boffalora Sopra Ticino",
    "lat": "45.46735",
    "lng": "8.83095"
  },
  {
    "country": "IT",
    "name": "Boffalora d'Adda",
    "lat": "45.35851",
    "lng": "9.49628"
  },
  {
    "country": "IT",
    "name": "Bocenago",
    "lat": "46.11858",
    "lng": "10.75884"
  },
  {
    "country": "IT",
    "name": "Boccioleto",
    "lat": "45.83047",
    "lng": "8.11282"
  },
  {
    "country": "IT",
    "name": "Bobbio Pellice",
    "lat": "44.80854",
    "lng": "7.11691"
  },
  {
    "country": "IT",
    "name": "Bobbio",
    "lat": "44.76832",
    "lng": "9.38415"
  },
  {
    "country": "IT",
    "name": "Darfo Boario Terme",
    "lat": "45.8915",
    "lng": "10.18879"
  },
  {
    "country": "IT",
    "name": "Blera",
    "lat": "42.27293",
    "lng": "12.03016"
  },
  {
    "country": "IT",
    "name": "Bitti",
    "lat": "40.47956",
    "lng": "9.38403"
  },
  {
    "country": "IT",
    "name": "Bitritto",
    "lat": "41.04336",
    "lng": "16.82682"
  },
  {
    "country": "IT",
    "name": "Bitonto",
    "lat": "41.11006",
    "lng": "16.69086"
  },
  {
    "country": "IT",
    "name": "Bitetto",
    "lat": "41.04146",
    "lng": "16.74806"
  },
  {
    "country": "IT",
    "name": "Bistagno",
    "lat": "44.66059",
    "lng": "8.37163"
  },
  {
    "country": "IT",
    "name": "Bisenti",
    "lat": "42.52883",
    "lng": "13.7995"
  },
  {
    "country": "IT",
    "name": "Bisegna",
    "lat": "41.92113",
    "lng": "13.7576"
  },
  {
    "country": "IT",
    "name": "Bisceglie",
    "lat": "41.24264",
    "lng": "16.50104"
  },
  {
    "country": "IT",
    "name": "Bisaccia",
    "lat": "41.00923",
    "lng": "15.37699"
  },
  {
    "country": "IT",
    "name": "Birori",
    "lat": "40.26593",
    "lng": "8.8157"
  },
  {
    "country": "IT",
    "name": "Bionaz",
    "lat": "45.87356",
    "lng": "7.4231"
  },
  {
    "country": "IT",
    "name": "Bioglio-Portula-Andrè",
    "lat": "45.61516",
    "lng": "8.13602"
  },
  {
    "country": "IT",
    "name": "Binasco",
    "lat": "45.33102",
    "lng": "9.0944"
  },
  {
    "country": "IT",
    "name": "Gabbioneta",
    "lat": "45.21627",
    "lng": "10.22027"
  },
  {
    "country": "IT",
    "name": "Bigolino",
    "lat": "45.86669",
    "lng": "12.01693"
  },
  {
    "country": "IT",
    "name": "Bientina",
    "lat": "43.70826",
    "lng": "10.62116"
  },
  {
    "country": "IT",
    "name": "Bienno",
    "lat": "45.93526",
    "lng": "10.29232"
  },
  {
    "country": "IT",
    "name": "Biella",
    "lat": "45.56304",
    "lng": "8.05796"
  },
  {
    "country": "IT",
    "name": "Bidonì",
    "lat": "40.11305",
    "lng": "8.93643"
  },
  {
    "country": "IT",
    "name": "Bicinicco",
    "lat": "45.93211",
    "lng": "13.253"
  },
  {
    "country": "IT",
    "name": "Biccari",
    "lat": "41.39736",
    "lng": "15.19644"
  },
  {
    "country": "IT",
    "name": "Bibione",
    "lat": "45.63565",
    "lng": "13.03616"
  },
  {
    "country": "IT",
    "name": "Bibbona",
    "lat": "43.26822",
    "lng": "10.5951"
  },
  {
    "country": "IT",
    "name": "Bibbiena",
    "lat": "43.69876",
    "lng": "11.81474"
  },
  {
    "country": "IT",
    "name": "Bibbiano",
    "lat": "44.66292",
    "lng": "10.47391"
  },
  {
    "country": "IT",
    "name": "Bibano",
    "lat": "45.90751",
    "lng": "12.43266"
  },
  {
    "country": "IT",
    "name": "Biassono",
    "lat": "45.62864",
    "lng": "9.27124"
  },
  {
    "country": "IT",
    "name": "Bianzone",
    "lat": "46.18665",
    "lng": "10.10934"
  },
  {
    "country": "IT",
    "name": "Bianzè",
    "lat": "45.30751",
    "lng": "8.12202"
  },
  {
    "country": "IT",
    "name": "Biandronno",
    "lat": "45.81281",
    "lng": "8.70882"
  },
  {
    "country": "IT",
    "name": "Biandrate",
    "lat": "45.45271",
    "lng": "8.46402"
  },
  {
    "country": "IT",
    "name": "Bevilacqua",
    "lat": "45.23249",
    "lng": "11.39496"
  },
  {
    "country": "IT",
    "name": "Bevagna",
    "lat": "42.93748",
    "lng": "12.61488"
  },
  {
    "country": "IT",
    "name": "Beura",
    "lat": "46.07964",
    "lng": "8.29826"
  },
  {
    "country": "IT",
    "name": "Bettona",
    "lat": "43.01124",
    "lng": "12.48698"
  },
  {
    "country": "IT",
    "name": "Bettolle",
    "lat": "43.20676",
    "lng": "11.80365"
  },
  {
    "country": "IT",
    "name": "Bettola",
    "lat": "44.77826",
    "lng": "9.60857"
  },
  {
    "country": "IT",
    "name": "Bessude",
    "lat": "40.55449",
    "lng": "8.72753"
  },
  {
    "country": "IT",
    "name": "Besozzo",
    "lat": "45.84889",
    "lng": "8.66517"
  },
  {
    "country": "IT",
    "name": "Besnate",
    "lat": "45.69858",
    "lng": "8.76734"
  },
  {
    "country": "IT",
    "name": "Besenzone",
    "lat": "44.98689",
    "lng": "9.95604"
  },
  {
    "country": "IT",
    "name": "Besenello",
    "lat": "45.94356",
    "lng": "11.10908"
  },
  {
    "country": "IT",
    "name": "Besate",
    "lat": "45.31296",
    "lng": "8.96964"
  },
  {
    "country": "IT",
    "name": "Besano",
    "lat": "45.88949",
    "lng": "8.89068"
  },
  {
    "country": "IT",
    "name": "Besana in Brianza",
    "lat": "45.70235",
    "lng": "9.2947"
  },
  {
    "country": "IT",
    "name": "Berzo Inferiore",
    "lat": "45.93027",
    "lng": "10.27696"
  },
  {
    "country": "IT",
    "name": "Berzo",
    "lat": "46.09287",
    "lng": "10.33303"
  },
  {
    "country": "IT",
    "name": "Berzano di San Pietro",
    "lat": "45.09418",
    "lng": "7.95352"
  },
  {
    "country": "IT",
    "name": "Bertonico",
    "lat": "45.23307",
    "lng": "9.66806"
  },
  {
    "country": "IT",
    "name": "Bertiolo",
    "lat": "45.94463",
    "lng": "13.05606"
  },
  {
    "country": "IT",
    "name": "Bertinoro",
    "lat": "44.14874",
    "lng": "12.1365"
  },
  {
    "country": "IT",
    "name": "Bersezio",
    "lat": "44.38031",
    "lng": "6.96885"
  },
  {
    "country": "IT",
    "name": "Berra",
    "lat": "44.97656",
    "lng": "11.97727"
  },
  {
    "country": "IT",
    "name": "Bernate Ticino",
    "lat": "45.47873",
    "lng": "8.81834"
  },
  {
    "country": "IT",
    "name": "Bernalda",
    "lat": "40.41261",
    "lng": "16.68919"
  },
  {
    "country": "IT",
    "name": "Berlingo",
    "lat": "45.50281",
    "lng": "10.03436"
  },
  {
    "country": "IT",
    "name": "Bergeggi",
    "lat": "44.24833",
    "lng": "8.44402"
  },
  {
    "country": "IT",
    "name": "Bergantino",
    "lat": "45.06145",
    "lng": "11.25237"
  },
  {
    "country": "IT",
    "name": "Bergamo",
    "lat": "45.69601",
    "lng": "9.66721"
  },
  {
    "country": "IT",
    "name": "Bereguardo",
    "lat": "45.25706",
    "lng": "9.02735"
  },
  {
    "country": "IT",
    "name": "Berchidda",
    "lat": "40.78476",
    "lng": "9.1651"
  },
  {
    "country": "IT",
    "name": "Berceto",
    "lat": "44.50899",
    "lng": "9.99104"
  },
  {
    "country": "IT",
    "name": "Berbenno di Valtellina",
    "lat": "46.16641",
    "lng": "9.74734"
  },
  {
    "country": "IT",
    "name": "Bentivoglio",
    "lat": "44.6369",
    "lng": "11.41737"
  },
  {
    "country": "IT",
    "name": "Benna",
    "lat": "45.51528",
    "lng": "8.12409"
  },
  {
    "country": "IT",
    "name": "Benevento",
    "lat": "41.1307",
    "lng": "14.77816"
  },
  {
    "country": "IT",
    "name": "Benevello",
    "lat": "44.62981",
    "lng": "8.10507"
  },
  {
    "country": "IT",
    "name": "Bene Vagienna",
    "lat": "44.54268",
    "lng": "7.82726"
  },
  {
    "country": "IT",
    "name": "Benetutti",
    "lat": "40.45689",
    "lng": "9.16754"
  },
  {
    "country": "IT",
    "name": "Belvedere Ostrense",
    "lat": "43.57896",
    "lng": "13.16724"
  },
  {
    "country": "IT",
    "name": "Belvedere Langhe",
    "lat": "44.49361",
    "lng": "7.97387"
  },
  {
    "country": "IT",
    "name": "Beltiglio-San Giovanni",
    "lat": "41.06239",
    "lng": "14.75273"
  },
  {
    "country": "IT",
    "name": "Belmonte Piceno",
    "lat": "43.09175",
    "lng": "13.53938"
  },
  {
    "country": "IT",
    "name": "Belmonte in Sabina",
    "lat": "42.31482",
    "lng": "12.89178"
  },
  {
    "country": "IT",
    "name": "Belmonte del Sannio",
    "lat": "41.82352",
    "lng": "14.42333"
  },
  {
    "country": "IT",
    "name": "Belmonte Castello",
    "lat": "41.57742",
    "lng": "13.81581"
  },
  {
    "country": "IT",
    "name": "Belluno",
    "lat": "46.14262",
    "lng": "12.2156"
  },
  {
    "country": "IT",
    "name": "Bellosguardo",
    "lat": "40.42222",
    "lng": "15.31219"
  },
  {
    "country": "IT",
    "name": "Bellona",
    "lat": "41.16052",
    "lng": "14.23313"
  },
  {
    "country": "IT",
    "name": "Bellocchi",
    "lat": "43.79564",
    "lng": "13.00565"
  },
  {
    "country": "IT",
    "name": "Bellinzago Novarese",
    "lat": "45.56877",
    "lng": "8.64323"
  },
  {
    "country": "IT",
    "name": "Bellegra",
    "lat": "41.88166",
    "lng": "13.02861"
  },
  {
    "country": "IT",
    "name": "Bellante",
    "lat": "42.74421",
    "lng": "13.80234"
  },
  {
    "country": "IT",
    "name": "Bellano",
    "lat": "46.04426",
    "lng": "9.30734"
  },
  {
    "country": "IT",
    "name": "Bellagio",
    "lat": "45.98772",
    "lng": "9.26182"
  },
  {
    "country": "IT",
    "name": "Bella Farnia",
    "lat": "41.3678",
    "lng": "12.97602"
  },
  {
    "country": "IT",
    "name": "Bella",
    "lat": "40.76059",
    "lng": "15.54101"
  },
  {
    "country": "IT",
    "name": "Belgirate",
    "lat": "45.84123",
    "lng": "8.57064"
  },
  {
    "country": "IT",
    "name": "Belgioioso",
    "lat": "45.15933",
    "lng": "9.31347"
  },
  {
    "country": "IT",
    "name": "Belforte del Chienti",
    "lat": "43.16426",
    "lng": "13.24323"
  },
  {
    "country": "IT",
    "name": "Belforte",
    "lat": "43.71676",
    "lng": "12.37575"
  },
  {
    "country": "IT",
    "name": "Belfiore",
    "lat": "45.38189",
    "lng": "11.21085"
  },
  {
    "country": "IT",
    "name": "Beinette",
    "lat": "44.36394",
    "lng": "7.64464"
  },
  {
    "country": "IT",
    "name": "Beinasco",
    "lat": "45.02472",
    "lng": "7.58564"
  },
  {
    "country": "IT",
    "name": "Begliano",
    "lat": "45.81984",
    "lng": "13.46586"
  },
  {
    "country": "IT",
    "name": "Bedonia",
    "lat": "44.504",
    "lng": "9.63489"
  },
  {
    "country": "IT",
    "name": "Bazzano",
    "lat": "44.50176",
    "lng": "11.08675"
  },
  {
    "country": "IT",
    "name": "Progetto Case Bazzano",
    "lat": "42.33643",
    "lng": "13.4441"
  },
  {
    "country": "IT",
    "name": "Baveno",
    "lat": "45.90818",
    "lng": "8.50033"
  },
  {
    "country": "IT",
    "name": "Baunei",
    "lat": "40.03132",
    "lng": "9.66374"
  },
  {
    "country": "IT",
    "name": "Bauladu",
    "lat": "40.02055",
    "lng": "8.67192"
  },
  {
    "country": "IT",
    "name": "Battipaglia",
    "lat": "40.60861",
    "lng": "14.98209"
  },
  {
    "country": "IT",
    "name": "Battaglia Terme",
    "lat": "45.28531",
    "lng": "11.78375"
  },
  {
    "country": "IT",
    "name": "Bastiglia",
    "lat": "44.72697",
    "lng": "10.9986"
  },
  {
    "country": "IT",
    "name": "Bastida de' Dossi",
    "lat": "45.03976",
    "lng": "8.92155"
  },
  {
    "country": "IT",
    "name": "Bastia umbra",
    "lat": "43.06425",
    "lng": "12.54612"
  },
  {
    "country": "IT",
    "name": "Bassignana",
    "lat": "45.0011",
    "lng": "8.73291"
  },
  {
    "country": "IT",
    "name": "Bassiano",
    "lat": "41.55154",
    "lng": "13.02732"
  },
  {
    "country": "IT",
    "name": "Bassano Romano",
    "lat": "42.22228",
    "lng": "12.18785"
  },
  {
    "country": "IT",
    "name": "Bassano in Teverina",
    "lat": "42.46444",
    "lng": "12.30752"
  },
  {
    "country": "IT",
    "name": "Bassano del Grappa",
    "lat": "45.76656",
    "lng": "11.72739"
  },
  {
    "country": "IT",
    "name": "Bassano Bresciano",
    "lat": "45.32827",
    "lng": "10.12869"
  },
  {
    "country": "IT",
    "name": "Basilicanova",
    "lat": "44.69804",
    "lng": "10.35231"
  },
  {
    "country": "IT",
    "name": "Basiliano",
    "lat": "46.01417",
    "lng": "13.07"
  },
  {
    "country": "IT",
    "name": "Baselice",
    "lat": "41.39296",
    "lng": "14.97363"
  },
  {
    "country": "IT",
    "name": "Baselga di Pinè",
    "lat": "46.1325",
    "lng": "11.24648"
  },
  {
    "country": "IT",
    "name": "Basciano",
    "lat": "42.59639",
    "lng": "13.73561"
  },
  {
    "country": "IT",
    "name": "Baschi",
    "lat": "42.67324",
    "lng": "12.21762"
  },
  {
    "country": "IT",
    "name": "Bascapè",
    "lat": "45.30598",
    "lng": "9.31397"
  },
  {
    "country": "IT",
    "name": "Barzanò",
    "lat": "45.73257",
    "lng": "9.3136"
  },
  {
    "country": "IT",
    "name": "Barzana",
    "lat": "45.7334",
    "lng": "9.56842"
  },
  {
    "country": "IT",
    "name": "Giacciano con Baruchella",
    "lat": "45.06718",
    "lng": "11.4504"
  },
  {
    "country": "IT",
    "name": "Barrea",
    "lat": "41.75543",
    "lng": "13.99095"
  },
  {
    "country": "IT",
    "name": "Baronissi",
    "lat": "40.74817",
    "lng": "14.7738"
  },
  {
    "country": "IT",
    "name": "Barni",
    "lat": "45.91111",
    "lng": "9.26592"
  },
  {
    "country": "IT",
    "name": "Barletta",
    "lat": "41.31429",
    "lng": "16.28165"
  },
  {
    "country": "IT",
    "name": "Barlassina",
    "lat": "45.65558",
    "lng": "9.12878"
  },
  {
    "country": "IT",
    "name": "Barisciano",
    "lat": "42.32465",
    "lng": "13.59036"
  },
  {
    "country": "IT",
    "name": "Barile",
    "lat": "40.94327",
    "lng": "15.67167"
  },
  {
    "country": "IT",
    "name": "Baricella",
    "lat": "44.6482",
    "lng": "11.538"
  },
  {
    "country": "IT",
    "name": "Bari",
    "lat": "41.11148",
    "lng": "16.8554"
  },
  {
    "country": "IT",
    "name": "Barghe",
    "lat": "45.67833",
    "lng": "10.40775"
  },
  {
    "country": "IT",
    "name": "Barge",
    "lat": "44.72786",
    "lng": "7.32283"
  },
  {
    "country": "IT",
    "name": "Bargagli",
    "lat": "44.4475",
    "lng": "9.09372"
  },
  {
    "country": "IT",
    "name": "Barga",
    "lat": "44.0731",
    "lng": "10.47789"
  },
  {
    "country": "IT",
    "name": "Barete",
    "lat": "42.45009",
    "lng": "13.28061"
  },
  {
    "country": "IT",
    "name": "Bareggio",
    "lat": "45.47927",
    "lng": "8.99789"
  },
  {
    "country": "IT",
    "name": "Bardonecchia",
    "lat": "45.07462",
    "lng": "6.69888"
  },
  {
    "country": "IT",
    "name": "Bardolino",
    "lat": "45.54114",
    "lng": "10.73298"
  },
  {
    "country": "IT",
    "name": "Bardineto",
    "lat": "44.18972",
    "lng": "8.13529"
  },
  {
    "country": "IT",
    "name": "Bardi",
    "lat": "44.63138",
    "lng": "9.72907"
  },
  {
    "country": "IT",
    "name": "Bard",
    "lat": "45.60936",
    "lng": "7.74491"
  },
  {
    "country": "IT",
    "name": "Barco",
    "lat": "44.68833",
    "lng": "10.49582"
  },
  {
    "country": "IT",
    "name": "Barcis",
    "lat": "46.19071",
    "lng": "12.56068"
  },
  {
    "country": "IT",
    "name": "Barbona",
    "lat": "45.10339",
    "lng": "11.70486"
  },
  {
    "country": "IT",
    "name": "Barbianello",
    "lat": "45.07571",
    "lng": "9.20602"
  },
  {
    "country": "IT",
    "name": "Barberino Val d'Elsa",
    "lat": "43.53987",
    "lng": "11.17178"
  },
  {
    "country": "IT",
    "name": "Barberino di Mugello",
    "lat": "43.9993",
    "lng": "11.23676"
  },
  {
    "country": "IT",
    "name": "Barbarasco",
    "lat": "44.2415",
    "lng": "9.94571"
  },
  {
    "country": "IT",
    "name": "Barbarano Vicentino",
    "lat": "45.40912",
    "lng": "11.54342"
  },
  {
    "country": "IT",
    "name": "Barbarano Romano",
    "lat": "42.24908",
    "lng": "12.06774"
  },
  {
    "country": "IT",
    "name": "Barbania",
    "lat": "45.29143",
    "lng": "7.6345"
  },
  {
    "country": "IT",
    "name": "Baranzate",
    "lat": "45.52717",
    "lng": "9.11724"
  },
  {
    "country": "IT",
    "name": "Barano d'Ischia",
    "lat": "40.71472",
    "lng": "13.92522"
  },
  {
    "country": "IT",
    "name": "Baranello",
    "lat": "41.52722",
    "lng": "14.558"
  },
  {
    "country": "IT",
    "name": "Baragiano",
    "lat": "40.68001",
    "lng": "15.59398"
  },
  {
    "country": "IT",
    "name": "Baone",
    "lat": "45.24174",
    "lng": "11.68463"
  },
  {
    "country": "IT",
    "name": "Banzi",
    "lat": "40.86063",
    "lng": "16.00976"
  },
  {
    "country": "IT",
    "name": "Banari",
    "lat": "40.57056",
    "lng": "8.70052"
  },
  {
    "country": "IT",
    "name": "Balzola",
    "lat": "45.18358",
    "lng": "8.40277"
  },
  {
    "country": "IT",
    "name": "Balzo",
    "lat": "42.84199",
    "lng": "13.33234"
  },
  {
    "country": "IT",
    "name": "Balvano",
    "lat": "40.64953",
    "lng": "15.51345"
  },
  {
    "country": "IT",
    "name": "Balsorano Nuovo",
    "lat": "41.80881",
    "lng": "13.56069"
  },
  {
    "country": "IT",
    "name": "Balocco",
    "lat": "45.45589",
    "lng": "8.28068"
  },
  {
    "country": "IT",
    "name": "Balmuccia",
    "lat": "45.81878",
    "lng": "8.1408"
  },
  {
    "country": "IT",
    "name": "Balme",
    "lat": "45.30192",
    "lng": "7.21937"
  },
  {
    "country": "IT",
    "name": "Ballabio",
    "lat": "45.89629",
    "lng": "9.42294"
  },
  {
    "country": "IT",
    "name": "Balestrino",
    "lat": "44.12426",
    "lng": "8.17064"
  },
  {
    "country": "IT",
    "name": "Baldissero Torinese",
    "lat": "45.06837",
    "lng": "7.81274"
  },
  {
    "country": "IT",
    "name": "Baldichieri d'Asti",
    "lat": "44.90595",
    "lng": "8.09163"
  },
  {
    "country": "IT",
    "name": "Balangero",
    "lat": "45.26988",
    "lng": "7.51884"
  },
  {
    "country": "IT",
    "name": "Baiso",
    "lat": "44.49668",
    "lng": "10.60083"
  },
  {
    "country": "IT",
    "name": "Baiano",
    "lat": "40.95142",
    "lng": "14.6165"
  },
  {
    "country": "IT",
    "name": "Baia",
    "lat": "41.30366",
    "lng": "14.25016"
  },
  {
    "country": "IT",
    "name": "Bagolino",
    "lat": "45.82519",
    "lng": "10.46183"
  },
  {
    "country": "IT",
    "name": "Bagno Roselle",
    "lat": "42.81114",
    "lng": "11.13859"
  },
  {
    "country": "IT",
    "name": "Bagnoregio",
    "lat": "42.62845",
    "lng": "12.08969"
  },
  {
    "country": "IT",
    "name": "Bagnone",
    "lat": "44.31494",
    "lng": "9.99507"
  },
  {
    "country": "IT",
    "name": "Bagnolo San Vito",
    "lat": "45.08892",
    "lng": "10.87747"
  },
  {
    "country": "IT",
    "name": "Bagnolo Piemonte",
    "lat": "44.76034",
    "lng": "7.31392"
  },
  {
    "country": "IT",
    "name": "Bagnolo Mella",
    "lat": "45.42765",
    "lng": "10.18638"
  },
  {
    "country": "IT",
    "name": "Bagnolo in Piano",
    "lat": "44.76437",
    "lng": "10.67358"
  },
  {
    "country": "IT",
    "name": "Bagnolo del Salento",
    "lat": "40.14908",
    "lng": "18.35208"
  },
  {
    "country": "IT",
    "name": "Bagnolo Cremasco",
    "lat": "45.36117",
    "lng": "9.61296"
  },
  {
    "country": "IT",
    "name": "Bagnolo",
    "lat": "45.27238",
    "lng": "10.89081"
  },
  {
    "country": "IT",
    "name": "Bagnoli Irpino",
    "lat": "40.83103",
    "lng": "15.07173"
  },
  {
    "country": "IT",
    "name": "Bagnoli di Sopra",
    "lat": "45.18667",
    "lng": "11.88433"
  },
  {
    "country": "IT",
    "name": "Bagnoli del Trigno",
    "lat": "41.70217",
    "lng": "14.45861"
  },
  {
    "country": "IT",
    "name": "Bagnoli",
    "lat": "40.81322",
    "lng": "14.16807"
  },
  {
    "country": "IT",
    "name": "Bagno a Ripoli",
    "lat": "43.75115",
    "lng": "11.32252"
  },
  {
    "country": "IT",
    "name": "Bagni di Tivoli",
    "lat": "41.95",
    "lng": "12.71667"
  },
  {
    "country": "IT",
    "name": "Rabbi Fonti",
    "lat": "46.39886",
    "lng": "10.84951"
  },
  {
    "country": "IT",
    "name": "Bagni di Lucca",
    "lat": "44.00513",
    "lng": "10.5531"
  },
  {
    "country": "IT",
    "name": "Bagnasco",
    "lat": "44.30412",
    "lng": "8.04522"
  },
  {
    "country": "IT",
    "name": "Bagnarola",
    "lat": "45.8669",
    "lng": "12.85886"
  },
  {
    "country": "IT",
    "name": "Bagnara di Romagna",
    "lat": "44.3893",
    "lng": "11.82726"
  },
  {
    "country": "IT",
    "name": "Bagnacavallo",
    "lat": "44.41402",
    "lng": "11.97813"
  },
  {
    "country": "IT",
    "name": "Badia Tedalda",
    "lat": "43.70887",
    "lng": "12.18425"
  },
  {
    "country": "IT",
    "name": "Badia Polesine",
    "lat": "45.09508",
    "lng": "11.49443"
  },
  {
    "country": "IT",
    "name": "Badia Pavese",
    "lat": "45.12087",
    "lng": "9.46866"
  },
  {
    "country": "IT",
    "name": "Badia Calavena",
    "lat": "45.56463",
    "lng": "11.15197"
  },
  {
    "country": "IT",
    "name": "Badia",
    "lat": "46.60816",
    "lng": "11.8963"
  },
  {
    "country": "IT",
    "name": "Badesi",
    "lat": "40.9646",
    "lng": "8.88235"
  },
  {
    "country": "IT",
    "name": "Badalucco",
    "lat": "43.91683",
    "lng": "7.84584"
  },
  {
    "country": "IT",
    "name": "Bacoli",
    "lat": "40.79672",
    "lng": "14.07349"
  },
  {
    "country": "IT",
    "name": "Baceno",
    "lat": "46.26062",
    "lng": "8.31874"
  },
  {
    "country": "IT",
    "name": "Azzone",
    "lat": "45.97903",
    "lng": "10.11284"
  },
  {
    "country": "IT",
    "name": "Azzate",
    "lat": "45.77803",
    "lng": "8.79414"
  },
  {
    "country": "IT",
    "name": "Azzano Decimo",
    "lat": "45.90937",
    "lng": "12.6642"
  },
  {
    "country": "IT",
    "name": "Azzanello",
    "lat": "45.31312",
    "lng": "9.91973"
  },
  {
    "country": "IT",
    "name": "Azeglio",
    "lat": "45.42283",
    "lng": "7.99222"
  },
  {
    "country": "IT",
    "name": "Aymavilles",
    "lat": "45.7013",
    "lng": "7.24683"
  },
  {
    "country": "IT",
    "name": "Avio",
    "lat": "45.73396",
    "lng": "10.93938"
  },
  {
    "country": "IT",
    "name": "Avigliano Umbro",
    "lat": "42.65303",
    "lng": "12.42571"
  },
  {
    "country": "IT",
    "name": "Avigliano",
    "lat": "40.73291",
    "lng": "15.72004"
  },
  {
    "country": "IT",
    "name": "Avigliana",
    "lat": "45.07978",
    "lng": "7.39647"
  },
  {
    "country": "IT",
    "name": "Aviano",
    "lat": "46.07056",
    "lng": "12.59472"
  },
  {
    "country": "IT",
    "name": "Avezzano",
    "lat": "42.02896",
    "lng": "13.42641"
  },
  {
    "country": "IT",
    "name": "Avetrana",
    "lat": "40.3507",
    "lng": "17.7326"
  },
  {
    "country": "IT",
    "name": "Aversa",
    "lat": "40.97259",
    "lng": "14.20745"
  },
  {
    "country": "IT",
    "name": "Averara",
    "lat": "45.98847",
    "lng": "9.6316"
  },
  {
    "country": "IT",
    "name": "Avellino",
    "lat": "40.91494",
    "lng": "14.79103"
  },
  {
    "country": "IT",
    "name": "Avella",
    "lat": "40.95995",
    "lng": "14.60087"
  },
  {
    "country": "IT",
    "name": "Avelengo",
    "lat": "46.64557",
    "lng": "11.22419"
  },
  {
    "country": "IT",
    "name": "Austis",
    "lat": "40.07122",
    "lng": "9.08878"
  },
  {
    "country": "IT",
    "name": "Ausonia",
    "lat": "41.35808",
    "lng": "13.74983"
  },
  {
    "country": "IT",
    "name": "Auronzo",
    "lat": "46.5592",
    "lng": "12.42456"
  },
  {
    "country": "IT",
    "name": "Aurisina",
    "lat": "45.74968",
    "lng": "13.67345"
  },
  {
    "country": "IT",
    "name": "Aurigo",
    "lat": "43.98281",
    "lng": "7.92342"
  },
  {
    "country": "IT",
    "name": "Aurelia",
    "lat": "42.1391",
    "lng": "11.78713"
  },
  {
    "country": "IT",
    "name": "Aulla",
    "lat": "44.20632",
    "lng": "9.97853"
  },
  {
    "country": "IT",
    "name": "Auletta",
    "lat": "40.56116",
    "lng": "15.42313"
  },
  {
    "country": "IT",
    "name": "Auditore",
    "lat": "43.82124",
    "lng": "12.57165"
  },
  {
    "country": "IT",
    "name": "Attimis",
    "lat": "46.19022",
    "lng": "13.31127"
  },
  {
    "country": "IT",
    "name": "Attigliano",
    "lat": "42.51505",
    "lng": "12.29455"
  },
  {
    "country": "IT",
    "name": "Atripalda",
    "lat": "40.91867",
    "lng": "14.82721"
  },
  {
    "country": "IT",
    "name": "Atri",
    "lat": "42.57642",
    "lng": "13.98899"
  },
  {
    "country": "IT",
    "name": "Atrani",
    "lat": "40.63617",
    "lng": "14.60933"
  },
  {
    "country": "IT",
    "name": "Atina",
    "lat": "41.62004",
    "lng": "13.79905"
  },
  {
    "country": "IT",
    "name": "Atessa",
    "lat": "42.07018",
    "lng": "14.45049"
  },
  {
    "country": "IT",
    "name": "Atena Lucana",
    "lat": "40.45464",
    "lng": "15.55633"
  },
  {
    "country": "IT",
    "name": "Atella",
    "lat": "40.87855",
    "lng": "15.65226"
  },
  {
    "country": "IT",
    "name": "Ateleta",
    "lat": "41.85435",
    "lng": "14.19806"
  },
  {
    "country": "IT",
    "name": "Asti",
    "lat": "44.90162",
    "lng": "8.20751"
  },
  {
    "country": "IT",
    "name": "Asso",
    "lat": "45.86061",
    "lng": "9.2673"
  },
  {
    "country": "IT",
    "name": "Assisi",
    "lat": "43.06671",
    "lng": "12.62109"
  },
  {
    "country": "IT",
    "name": "Asolo",
    "lat": "45.78854",
    "lng": "11.91701"
  },
  {
    "country": "IT",
    "name": "Asola",
    "lat": "45.22018",
    "lng": "10.41214"
  },
  {
    "country": "IT",
    "name": "Asiago",
    "lat": "45.87588",
    "lng": "11.51223"
  },
  {
    "country": "IT",
    "name": "Ascrea",
    "lat": "42.19763",
    "lng": "12.99457"
  },
  {
    "country": "IT",
    "name": "Ascoli Satriano",
    "lat": "41.20365",
    "lng": "15.56646"
  },
  {
    "country": "IT",
    "name": "Ascoli Piceno",
    "lat": "42.85351",
    "lng": "13.57395"
  },
  {
    "country": "IT",
    "name": "Asciano",
    "lat": "43.23232",
    "lng": "11.56655"
  },
  {
    "country": "IT",
    "name": "Ascea",
    "lat": "40.14082",
    "lng": "15.18583"
  },
  {
    "country": "IT",
    "name": "Arzignano",
    "lat": "45.52027",
    "lng": "11.33446"
  },
  {
    "country": "IT",
    "name": "Arzergrande",
    "lat": "45.27278",
    "lng": "12.0484"
  },
  {
    "country": "IT",
    "name": "Arzene",
    "lat": "45.99965",
    "lng": "12.85034"
  },
  {
    "country": "IT",
    "name": "Arzano",
    "lat": "40.90959",
    "lng": "14.26519"
  },
  {
    "country": "IT",
    "name": "Arzachena",
    "lat": "41.0762",
    "lng": "9.39055"
  },
  {
    "country": "IT",
    "name": "Arvier",
    "lat": "45.70205",
    "lng": "7.16267"
  },
  {
    "country": "IT",
    "name": "Artogne",
    "lat": "45.85437",
    "lng": "10.16646"
  },
  {
    "country": "IT",
    "name": "Artena",
    "lat": "41.74126",
    "lng": "12.90667"
  },
  {
    "country": "IT",
    "name": "Artegna",
    "lat": "46.23929",
    "lng": "13.15399"
  },
  {
    "country": "IT",
    "name": "Arta Terme",
    "lat": "46.48021",
    "lng": "13.0204"
  },
  {
    "country": "IT",
    "name": "Arsoli",
    "lat": "42.04158",
    "lng": "13.01606"
  },
  {
    "country": "IT",
    "name": "Arsita",
    "lat": "42.50266",
    "lng": "13.78516"
  },
  {
    "country": "IT",
    "name": "Arsiero",
    "lat": "45.80422",
    "lng": "11.35582"
  },
  {
    "country": "IT",
    "name": "Arsiè",
    "lat": "45.98211",
    "lng": "11.75794"
  },
  {
    "country": "IT",
    "name": "Arsago Seprio",
    "lat": "45.68764",
    "lng": "8.73509"
  },
  {
    "country": "IT",
    "name": "Arrone",
    "lat": "42.58266",
    "lng": "12.76714"
  },
  {
    "country": "IT",
    "name": "Arre",
    "lat": "45.21748",
    "lng": "11.92858"
  },
  {
    "country": "IT",
    "name": "Arquata Scrivia",
    "lat": "44.6883",
    "lng": "8.88682"
  },
  {
    "country": "IT",
    "name": "Arquata del Tronto",
    "lat": "42.7717",
    "lng": "13.29389"
  },
  {
    "country": "IT",
    "name": "Arquà Petrarca",
    "lat": "45.26911",
    "lng": "11.72045"
  },
  {
    "country": "IT",
    "name": "Arpino",
    "lat": "41.64705",
    "lng": "13.61155"
  },
  {
    "country": "IT",
    "name": "Arpaise",
    "lat": "41.02977",
    "lng": "14.74387"
  },
  {
    "country": "IT",
    "name": "Arpaia",
    "lat": "41.03678",
    "lng": "14.55175"
  },
  {
    "country": "IT",
    "name": "Arosio",
    "lat": "45.71933",
    "lng": "9.20816"
  },
  {
    "country": "IT",
    "name": "Arona",
    "lat": "45.7589",
    "lng": "8.55715"
  },
  {
    "country": "IT",
    "name": "Arola",
    "lat": "45.80867",
    "lng": "8.35808"
  },
  {
    "country": "IT",
    "name": "Arola-Preazzano",
    "lat": "40.63333",
    "lng": "14.43333"
  },
  {
    "country": "IT",
    "name": "Arnesano",
    "lat": "40.33679",
    "lng": "18.09145"
  },
  {
    "country": "IT",
    "name": "Arnara",
    "lat": "41.58452",
    "lng": "13.3884"
  },
  {
    "country": "IT",
    "name": "Armento",
    "lat": "40.3066",
    "lng": "16.0655"
  },
  {
    "country": "IT",
    "name": "Armeno",
    "lat": "45.82078",
    "lng": "8.44557"
  },
  {
    "country": "IT",
    "name": "Arluno",
    "lat": "45.50344",
    "lng": "8.94222"
  },
  {
    "country": "IT",
    "name": "Arlena di Castro",
    "lat": "42.46559",
    "lng": "11.8209"
  },
  {
    "country": "IT",
    "name": "Arignano",
    "lat": "45.03966",
    "lng": "7.90189"
  },
  {
    "country": "IT",
    "name": "Arienzo",
    "lat": "41.02734",
    "lng": "14.4977"
  },
  {
    "country": "IT",
    "name": "Arielli",
    "lat": "42.26003",
    "lng": "14.31004"
  },
  {
    "country": "IT",
    "name": "Ariccia",
    "lat": "41.72063",
    "lng": "12.6723"
  },
  {
    "country": "IT",
    "name": "Ariano",
    "lat": "44.94604",
    "lng": "12.12448"
  },
  {
    "country": "IT",
    "name": "Ariano Irpino-Martiri",
    "lat": "41.16024",
    "lng": "15.10625"
  },
  {
    "country": "IT",
    "name": "Ari",
    "lat": "42.28967",
    "lng": "14.25856"
  },
  {
    "country": "IT",
    "name": "Argenta",
    "lat": "44.61397",
    "lng": "11.83547"
  },
  {
    "country": "IT",
    "name": "Argelato",
    "lat": "44.64009",
    "lng": "11.34359"
  },
  {
    "country": "IT",
    "name": "Argegno",
    "lat": "45.94218",
    "lng": "9.12635"
  },
  {
    "country": "IT",
    "name": "Arezzo",
    "lat": "43.46276",
    "lng": "11.88068"
  },
  {
    "country": "IT",
    "name": "Arese",
    "lat": "45.55048",
    "lng": "9.07741"
  },
  {
    "country": "IT",
    "name": "Arenzano",
    "lat": "44.40521",
    "lng": "8.68315"
  },
  {
    "country": "IT",
    "name": "Arena Po",
    "lat": "45.09427",
    "lng": "9.36312"
  },
  {
    "country": "IT",
    "name": "Ardesio",
    "lat": "45.93613",
    "lng": "9.9295"
  },
  {
    "country": "IT",
    "name": "Ardenno",
    "lat": "46.16714",
    "lng": "9.64729"
  },
  {
    "country": "IT",
    "name": "Ardea",
    "lat": "41.60742",
    "lng": "12.54158"
  },
  {
    "country": "IT",
    "name": "Ardauli",
    "lat": "40.08436",
    "lng": "8.91228"
  },
  {
    "country": "IT",
    "name": "Ardara",
    "lat": "40.6214",
    "lng": "8.80987"
  },
  {
    "country": "IT",
    "name": "Arcugnano-Torri",
    "lat": "45.49579",
    "lng": "11.5477"
  },
  {
    "country": "IT",
    "name": "Arcore",
    "lat": "45.62675",
    "lng": "9.32454"
  },
  {
    "country": "IT",
    "name": "Arconate",
    "lat": "45.54134",
    "lng": "8.84891"
  },
  {
    "country": "IT",
    "name": "Arcole",
    "lat": "45.36125",
    "lng": "11.2875"
  },
  {
    "country": "IT",
    "name": "Arcola",
    "lat": "44.11778",
    "lng": "9.91175"
  },
  {
    "country": "IT",
    "name": "Arco",
    "lat": "45.91772",
    "lng": "10.88672"
  },
  {
    "country": "IT",
    "name": "Arcidosso",
    "lat": "42.87162",
    "lng": "11.53599"
  },
  {
    "country": "IT",
    "name": "Archi",
    "lat": "42.09135",
    "lng": "14.3827"
  },
  {
    "country": "IT",
    "name": "Arcevia",
    "lat": "43.50177",
    "lng": "12.945"
  },
  {
    "country": "IT",
    "name": "Arceto",
    "lat": "44.61762",
    "lng": "10.72461"
  },
  {
    "country": "IT",
    "name": "Arcene",
    "lat": "45.57717",
    "lng": "9.61461"
  },
  {
    "country": "IT",
    "name": "Arce",
    "lat": "41.57787",
    "lng": "13.58571"
  },
  {
    "country": "IT",
    "name": "Arcade",
    "lat": "45.78428",
    "lng": "12.21972"
  },
  {
    "country": "IT",
    "name": "Arborio",
    "lat": "45.49586",
    "lng": "8.38755"
  },
  {
    "country": "IT",
    "name": "Arba",
    "lat": "46.14611",
    "lng": "12.79009"
  },
  {
    "country": "IT",
    "name": "Aradeo",
    "lat": "40.12921",
    "lng": "18.12951"
  },
  {
    "country": "IT",
    "name": "Aquino",
    "lat": "41.49388",
    "lng": "13.7052"
  },
  {
    "country": "IT",
    "name": "Aquilonia",
    "lat": "40.98688",
    "lng": "15.4751"
  },
  {
    "country": "IT",
    "name": "Aquileia",
    "lat": "45.7683",
    "lng": "13.36779"
  },
  {
    "country": "IT",
    "name": "Aquara",
    "lat": "40.44391",
    "lng": "15.25386"
  },
  {
    "country": "IT",
    "name": "Aprilia",
    "lat": "41.59452",
    "lng": "12.65419"
  },
  {
    "country": "IT",
    "name": "Apricena",
    "lat": "41.78629",
    "lng": "15.44394"
  },
  {
    "country": "IT",
    "name": "Apricale",
    "lat": "43.88033",
    "lng": "7.65993"
  },
  {
    "country": "IT",
    "name": "Aprica",
    "lat": "46.1522",
    "lng": "10.14884"
  },
  {
    "country": "IT",
    "name": "Appignano del Tronto",
    "lat": "42.89805",
    "lng": "13.6622"
  },
  {
    "country": "IT",
    "name": "Appignano",
    "lat": "43.36276",
    "lng": "13.34768"
  },
  {
    "country": "IT",
    "name": "Appiano Gentile",
    "lat": "45.73499",
    "lng": "8.98103"
  },
  {
    "country": "IT",
    "name": "San Michele",
    "lat": "46.45472",
    "lng": "11.26178"
  },
  {
    "country": "IT",
    "name": "Apollosa",
    "lat": "41.09156",
    "lng": "14.69625"
  },
  {
    "country": "IT",
    "name": "Apiro",
    "lat": "43.3929",
    "lng": "13.13045"
  },
  {
    "country": "IT",
    "name": "Apice Vecchio",
    "lat": "41.12012",
    "lng": "14.93104"
  },
  {
    "country": "IT",
    "name": "Apecchio",
    "lat": "43.55914",
    "lng": "12.42163"
  },
  {
    "country": "IT",
    "name": "Aosta",
    "lat": "45.73764",
    "lng": "7.31722"
  },
  {
    "country": "IT",
    "name": "Anzola d'Ossola",
    "lat": "45.98897",
    "lng": "8.34531"
  },
  {
    "country": "IT",
    "name": "Anzola dell'Emilia",
    "lat": "44.54197",
    "lng": "11.20548"
  },
  {
    "country": "IT",
    "name": "Anzio",
    "lat": "41.45263",
    "lng": "12.62157"
  },
  {
    "country": "IT",
    "name": "Bannio",
    "lat": "45.98397",
    "lng": "8.14611"
  },
  {
    "country": "IT",
    "name": "Anzi",
    "lat": "40.51662",
    "lng": "15.92457"
  },
  {
    "country": "IT",
    "name": "Anzano di Puglia",
    "lat": "41.12162",
    "lng": "15.28688"
  },
  {
    "country": "IT",
    "name": "Anzano del Parco",
    "lat": "45.77006",
    "lng": "9.19752"
  },
  {
    "country": "IT",
    "name": "Anversa degli Abruzzi",
    "lat": "41.99478",
    "lng": "13.80379"
  },
  {
    "country": "IT",
    "name": "Antronapiana",
    "lat": "46.06091",
    "lng": "8.11519"
  },
  {
    "country": "IT",
    "name": "Antrodoco",
    "lat": "42.41498",
    "lng": "13.07673"
  },
  {
    "country": "IT",
    "name": "Anticoli Corrado",
    "lat": "42.00801",
    "lng": "12.99049"
  },
  {
    "country": "IT",
    "name": "Antey-Saint-Andrè",
    "lat": "45.80603",
    "lng": "7.58666"
  },
  {
    "country": "IT",
    "name": "Anterivo",
    "lat": "46.2781",
    "lng": "11.36665"
  },
  {
    "country": "IT",
    "name": "Antella",
    "lat": "43.72774",
    "lng": "11.32233"
  },
  {
    "country": "IT",
    "name": "Antegnate",
    "lat": "45.48648",
    "lng": "9.79146"
  },
  {
    "country": "IT",
    "name": "Annone Veneto",
    "lat": "45.78965",
    "lng": "12.68646"
  },
  {
    "country": "IT",
    "name": "Annone di Brianza",
    "lat": "45.80216",
    "lng": "9.33119"
  },
  {
    "country": "IT",
    "name": "Annicco",
    "lat": "45.24344",
    "lng": "9.87905"
  },
  {
    "country": "IT",
    "name": "Anitrella-Chiaiamari",
    "lat": "41.63825",
    "lng": "13.54835"
  },
  {
    "country": "IT",
    "name": "Anguillara Veneta",
    "lat": "45.14249",
    "lng": "11.88461"
  },
  {
    "country": "IT",
    "name": "Anguillara Sabazia",
    "lat": "42.0792",
    "lng": "12.28368"
  },
  {
    "country": "IT",
    "name": "Angri",
    "lat": "40.73815",
    "lng": "14.5707"
  },
  {
    "country": "IT",
    "name": "Angolo Terme",
    "lat": "45.89168",
    "lng": "10.14963"
  },
  {
    "country": "IT",
    "name": "Anghiari",
    "lat": "43.54104",
    "lng": "12.05832"
  },
  {
    "country": "IT",
    "name": "Angera",
    "lat": "45.77555",
    "lng": "8.57861"
  },
  {
    "country": "IT",
    "name": "Anfo",
    "lat": "45.76575",
    "lng": "10.49382"
  },
  {
    "country": "IT",
    "name": "Anela",
    "lat": "40.44176",
    "lng": "9.05743"
  },
  {
    "country": "IT",
    "name": "Anduins",
    "lat": "46.23311",
    "lng": "12.95829"
  },
  {
    "country": "IT",
    "name": "Andria",
    "lat": "41.23117",
    "lng": "16.29797"
  },
  {
    "country": "IT",
    "name": "Andretta-Mattinella",
    "lat": "40.93742",
    "lng": "15.32485"
  },
  {
    "country": "IT",
    "name": "Andreis",
    "lat": "46.20146",
    "lng": "12.61448"
  },
  {
    "country": "IT",
    "name": "Andrate",
    "lat": "45.52633",
    "lng": "7.88145"
  },
  {
    "country": "IT",
    "name": "Andorno Cacciorna",
    "lat": "45.61054",
    "lng": "8.05589"
  },
  {
    "country": "IT",
    "name": "Andezeno",
    "lat": "45.03376",
    "lng": "7.86607"
  },
  {
    "country": "IT",
    "name": "Andalo",
    "lat": "46.16649",
    "lng": "11.00432"
  },
  {
    "country": "IT",
    "name": "Ancona",
    "lat": "43.5942",
    "lng": "13.50337"
  },
  {
    "country": "IT",
    "name": "Anchione",
    "lat": "43.82612",
    "lng": "10.75844"
  },
  {
    "country": "IT",
    "name": "Ancarano",
    "lat": "42.83767",
    "lng": "13.74662"
  },
  {
    "country": "IT",
    "name": "Anagni",
    "lat": "41.7435",
    "lng": "13.15542"
  },
  {
    "country": "IT",
    "name": "Anacapri",
    "lat": "40.5517",
    "lng": "14.21225"
  },
  {
    "country": "IT",
    "name": "Ampezzo",
    "lat": "46.41459",
    "lng": "12.79634"
  },
  {
    "country": "IT",
    "name": "Amorosi",
    "lat": "41.20273",
    "lng": "14.46598"
  },
  {
    "country": "IT",
    "name": "Ameno",
    "lat": "45.78897",
    "lng": "8.44"
  },
  {
    "country": "IT",
    "name": "Amelia",
    "lat": "42.55177",
    "lng": "12.42076"
  },
  {
    "country": "IT",
    "name": "Ameglia",
    "lat": "44.07089",
    "lng": "9.966"
  },
  {
    "country": "IT",
    "name": "Ambra",
    "lat": "43.41465",
    "lng": "11.60291"
  },
  {
    "country": "IT",
    "name": "Amatrice",
    "lat": "42.62664",
    "lng": "13.29509"
  },
  {
    "country": "IT",
    "name": "Amaseno",
    "lat": "41.46705",
    "lng": "13.33457"
  },
  {
    "country": "IT",
    "name": "Amaro",
    "lat": "46.37367",
    "lng": "13.09368"
  },
  {
    "country": "IT",
    "name": "Amandola",
    "lat": "42.97826",
    "lng": "13.35453"
  },
  {
    "country": "IT",
    "name": "Amalfi",
    "lat": "40.6349",
    "lng": "14.60238"
  },
  {
    "country": "IT",
    "name": "Alzano Lombardo",
    "lat": "45.73681",
    "lng": "9.72638"
  },
  {
    "country": "IT",
    "name": "Alvito",
    "lat": "41.69002",
    "lng": "13.74795"
  },
  {
    "country": "IT",
    "name": "Alvignano",
    "lat": "41.24427",
    "lng": "14.33671"
  },
  {
    "country": "IT",
    "name": "Alviano",
    "lat": "42.59084",
    "lng": "12.29775"
  },
  {
    "country": "IT",
    "name": "Altopascio",
    "lat": "43.81618",
    "lng": "10.67668"
  },
  {
    "country": "IT",
    "name": "Altino",
    "lat": "42.09954",
    "lng": "14.33267"
  },
  {
    "country": "IT",
    "name": "Altidona",
    "lat": "43.10787",
    "lng": "13.79617"
  },
  {
    "country": "IT",
    "name": "Altedo",
    "lat": "44.67057",
    "lng": "11.49019"
  },
  {
    "country": "IT",
    "name": "Altavilla Vicentina",
    "lat": "45.51329",
    "lng": "11.46877"
  },
  {
    "country": "IT",
    "name": "Altavilla Silentina",
    "lat": "40.53012",
    "lng": "15.13153"
  },
  {
    "country": "IT",
    "name": "Altavilla Irpina",
    "lat": "41.00619",
    "lng": "14.78093"
  },
  {
    "country": "IT",
    "name": "Altare",
    "lat": "44.33566",
    "lng": "8.33411"
  },
  {
    "country": "IT",
    "name": "Altamura",
    "lat": "40.82664",
    "lng": "16.54952"
  },
  {
    "country": "IT",
    "name": "Alseno",
    "lat": "44.89759",
    "lng": "9.96405"
  },
  {
    "country": "IT",
    "name": "Alpignano",
    "lat": "45.09346",
    "lng": "7.52392"
  },
  {
    "country": "IT",
    "name": "Alpette",
    "lat": "45.40917",
    "lng": "7.57795"
  },
  {
    "country": "IT",
    "name": "Almese-Rivera",
    "lat": "45.11915",
    "lng": "7.40111"
  },
  {
    "country": "IT",
    "name": "Almenno San Salvatore",
    "lat": "45.74971",
    "lng": "9.59699"
  },
  {
    "country": "IT",
    "name": "Almenno San Bartolomeo",
    "lat": "45.73912",
    "lng": "9.58082"
  },
  {
    "country": "IT",
    "name": "Almè",
    "lat": "45.73883",
    "lng": "9.61558"
  },
  {
    "country": "IT",
    "name": "Allumiere",
    "lat": "42.15751",
    "lng": "11.90361"
  },
  {
    "country": "IT",
    "name": "Allerona",
    "lat": "42.81174",
    "lng": "11.97451"
  },
  {
    "country": "IT",
    "name": "Alleghe",
    "lat": "46.40718",
    "lng": "12.02336"
  },
  {
    "country": "IT",
    "name": "Alife",
    "lat": "41.32612",
    "lng": "14.33403"
  },
  {
    "country": "IT",
    "name": "Alice Superiore",
    "lat": "45.46066",
    "lng": "7.77922"
  },
  {
    "country": "IT",
    "name": "Alice Castello",
    "lat": "45.3686",
    "lng": "8.0732"
  },
  {
    "country": "IT",
    "name": "Aliano",
    "lat": "40.31359",
    "lng": "16.22984"
  },
  {
    "country": "IT",
    "name": "Alghero",
    "lat": "40.55969",
    "lng": "8.31953"
  },
  {
    "country": "IT",
    "name": "Alfonsine",
    "lat": "44.50768",
    "lng": "12.03743"
  },
  {
    "country": "IT",
    "name": "Alfiano Natta",
    "lat": "45.0486",
    "lng": "8.2073"
  },
  {
    "country": "IT",
    "name": "Alfedena",
    "lat": "41.73545",
    "lng": "14.035"
  },
  {
    "country": "IT",
    "name": "Alfano",
    "lat": "40.17687",
    "lng": "15.4245"
  },
  {
    "country": "IT",
    "name": "Alezio",
    "lat": "40.06226",
    "lng": "18.05712"
  },
  {
    "country": "IT",
    "name": "Alessandria",
    "lat": "44.90924",
    "lng": "8.61007"
  },
  {
    "country": "IT",
    "name": "Aldeno",
    "lat": "45.97758",
    "lng": "11.09276"
  },
  {
    "country": "IT",
    "name": "Albuzzano",
    "lat": "45.18719",
    "lng": "9.27383"
  },
  {
    "country": "IT",
    "name": "Albonese",
    "lat": "45.29285",
    "lng": "8.70615"
  },
  {
    "country": "IT",
    "name": "Albizzate",
    "lat": "45.72698",
    "lng": "8.80312"
  },
  {
    "country": "IT",
    "name": "Albisola Marina",
    "lat": "44.33079",
    "lng": "8.5096"
  },
  {
    "country": "IT",
    "name": "Albino",
    "lat": "45.76444",
    "lng": "9.79904"
  },
  {
    "country": "IT",
    "name": "Albinea",
    "lat": "44.62859",
    "lng": "10.61024"
  },
  {
    "country": "IT",
    "name": "Albignasego",
    "lat": "45.34705",
    "lng": "11.86781"
  },
  {
    "country": "IT",
    "name": "Albignano",
    "lat": "45.50054",
    "lng": "9.49299"
  },
  {
    "country": "IT",
    "name": "Albiate",
    "lat": "45.65537",
    "lng": "9.25035"
  },
  {
    "country": "IT",
    "name": "Albiano d'Ivrea",
    "lat": "45.43424",
    "lng": "7.94789"
  },
  {
    "country": "IT",
    "name": "Albiano",
    "lat": "46.14451",
    "lng": "11.19459"
  },
  {
    "country": "IT",
    "name": "Albiano Magra",
    "lat": "44.17574",
    "lng": "9.91619"
  },
  {
    "country": "IT",
    "name": "Albettone",
    "lat": "45.35811",
    "lng": "11.5843"
  },
  {
    "country": "IT",
    "name": "Alberona",
    "lat": "41.43225",
    "lng": "15.12304"
  },
  {
    "country": "IT",
    "name": "Alberobello",
    "lat": "40.78448",
    "lng": "17.23618"
  },
  {
    "country": "IT",
    "name": "Albareto",
    "lat": "44.44692",
    "lng": "9.70228"
  },
  {
    "country": "IT",
    "name": "Albenga",
    "lat": "44.04997",
    "lng": "8.21829"
  },
  {
    "country": "IT",
    "name": "Albaredo",
    "lat": "46.10293",
    "lng": "9.59046"
  },
  {
    "country": "IT",
    "name": "Albaredo d'Adige",
    "lat": "45.31859",
    "lng": "11.27843"
  },
  {
    "country": "IT",
    "name": "Albaredo",
    "lat": "45.66725",
    "lng": "12.01095"
  },
  {
    "country": "IT",
    "name": "Albano Vercellese",
    "lat": "45.42616",
    "lng": "8.38093"
  },
  {
    "country": "IT",
    "name": "Albano Sant'Alessandro",
    "lat": "45.68762",
    "lng": "9.76651"
  },
  {
    "country": "IT",
    "name": "Albano Laziale",
    "lat": "41.72748",
    "lng": "12.659"
  },
  {
    "country": "IT",
    "name": "Albano di Lucania",
    "lat": "40.58614",
    "lng": "16.03712"
  },
  {
    "country": "IT",
    "name": "Albanella",
    "lat": "40.47943",
    "lng": "15.11454"
  },
  {
    "country": "IT",
    "name": "Alba",
    "lat": "44.6999",
    "lng": "8.0347"
  },
  {
    "country": "IT",
    "name": "Alatri",
    "lat": "41.73187",
    "lng": "13.3412"
  },
  {
    "country": "IT",
    "name": "Alassio",
    "lat": "44.00393",
    "lng": "8.16713"
  },
  {
    "country": "IT",
    "name": "Alanno",
    "lat": "42.29552",
    "lng": "13.97084"
  },
  {
    "country": "IT",
    "name": "Alagna Valsesia",
    "lat": "45.85182",
    "lng": "7.93752"
  },
  {
    "country": "IT",
    "name": "Alagna",
    "lat": "45.16917",
    "lng": "8.88947"
  },
  {
    "country": "IT",
    "name": "Ala di Stura",
    "lat": "45.31492",
    "lng": "7.30345"
  },
  {
    "country": "IT",
    "name": "Alà dei Sardi",
    "lat": "40.65007",
    "lng": "9.32783"
  },
  {
    "country": "IT",
    "name": "Ala",
    "lat": "45.76072",
    "lng": "11.00458"
  },
  {
    "country": "IT",
    "name": "Airuno",
    "lat": "45.75352",
    "lng": "9.42765"
  },
  {
    "country": "IT",
    "name": "Airole",
    "lat": "43.87092",
    "lng": "7.55414"
  },
  {
    "country": "IT",
    "name": "Airola",
    "lat": "41.05871",
    "lng": "14.55924"
  },
  {
    "country": "IT",
    "name": "Airasca",
    "lat": "44.91719",
    "lng": "7.48322"
  },
  {
    "country": "IT",
    "name": "Ailoche",
    "lat": "45.69812",
    "lng": "8.22133"
  },
  {
    "country": "IT",
    "name": "Ailano",
    "lat": "41.39001",
    "lng": "14.20536"
  },
  {
    "country": "IT",
    "name": "Aiello del Sabato",
    "lat": "40.88847",
    "lng": "14.82123"
  },
  {
    "country": "IT",
    "name": "Aiello del Friuli",
    "lat": "45.87276",
    "lng": "13.36038"
  },
  {
    "country": "IT",
    "name": "Aielli",
    "lat": "42.08146",
    "lng": "13.59113"
  },
  {
    "country": "IT",
    "name": "Aidomaggiore",
    "lat": "40.17147",
    "lng": "8.85679"
  },
  {
    "country": "IT",
    "name": "Agugliaro",
    "lat": "45.3251",
    "lng": "11.58496"
  },
  {
    "country": "IT",
    "name": "Agugliano",
    "lat": "43.54368",
    "lng": "13.38574"
  },
  {
    "country": "IT",
    "name": "Agropoli",
    "lat": "40.34923",
    "lng": "14.99067"
  },
  {
    "country": "IT",
    "name": "Agrate Brianza",
    "lat": "45.57431",
    "lng": "9.34793"
  },
  {
    "country": "IT",
    "name": "Agosta",
    "lat": "41.98133",
    "lng": "13.03499"
  },
  {
    "country": "IT",
    "name": "Agordo",
    "lat": "46.28201",
    "lng": "12.03608"
  },
  {
    "country": "IT",
    "name": "Agnone",
    "lat": "41.81043",
    "lng": "14.37524"
  },
  {
    "country": "IT",
    "name": "Agnadello",
    "lat": "45.44516",
    "lng": "9.55408"
  },
  {
    "country": "IT",
    "name": "Agna",
    "lat": "45.17051",
    "lng": "11.95625"
  },
  {
    "country": "IT",
    "name": "Agliè",
    "lat": "45.368",
    "lng": "7.768"
  },
  {
    "country": "IT",
    "name": "Agliana",
    "lat": "43.90246",
    "lng": "11.00531"
  },
  {
    "country": "IT",
    "name": "Aggius",
    "lat": "40.92995",
    "lng": "9.06517"
  },
  {
    "country": "IT",
    "name": "Agerola",
    "lat": "40.63771",
    "lng": "14.53884"
  },
  {
    "country": "IT",
    "name": "Agazzano",
    "lat": "44.94726",
    "lng": "9.51875"
  },
  {
    "country": "IT",
    "name": "Afragola",
    "lat": "40.92298",
    "lng": "14.30935"
  },
  {
    "country": "IT",
    "name": "Affile",
    "lat": "41.88435",
    "lng": "13.09853"
  },
  {
    "country": "IT",
    "name": "Affi",
    "lat": "45.55297",
    "lng": "10.7864"
  },
  {
    "country": "IT",
    "name": "Adro",
    "lat": "45.62059",
    "lng": "9.96159"
  },
  {
    "country": "IT",
    "name": "Adria",
    "lat": "45.05445",
    "lng": "12.05599"
  },
  {
    "country": "IT",
    "name": "Adelfia",
    "lat": "41.0033",
    "lng": "16.87208"
  },
  {
    "country": "IT",
    "name": "Acuto",
    "lat": "41.79107",
    "lng": "13.17446"
  },
  {
    "country": "IT",
    "name": "Acqui Terme",
    "lat": "44.67552",
    "lng": "8.46934"
  },
  {
    "country": "IT",
    "name": "Acquaviva Picena",
    "lat": "42.94037",
    "lng": "13.82227"
  },
  {
    "country": "IT",
    "name": "Acquaviva d'Isernia",
    "lat": "41.67132",
    "lng": "14.1477"
  },
  {
    "country": "IT",
    "name": "Acquaviva delle Fonti",
    "lat": "40.89704",
    "lng": "16.8433"
  },
  {
    "country": "IT",
    "name": "Acquaviva Collecroce",
    "lat": "41.86624",
    "lng": "14.74733"
  },
  {
    "country": "IT",
    "name": "Acquaviva",
    "lat": "43.11566",
    "lng": "11.86249"
  },
  {
    "country": "IT",
    "name": "Acquasparta",
    "lat": "42.68915",
    "lng": "12.54275"
  },
  {
    "country": "IT",
    "name": "Acquasanta Terme",
    "lat": "42.77084",
    "lng": "13.41418"
  },
  {
    "country": "IT",
    "name": "Acquapendente",
    "lat": "42.74259",
    "lng": "11.86827"
  },
  {
    "country": "IT",
    "name": "Acquanegra sul Chiese",
    "lat": "45.16404",
    "lng": "10.43323"
  },
  {
    "country": "IT",
    "name": "Acquanegra Cremonese",
    "lat": "45.16864",
    "lng": "9.89074"
  },
  {
    "country": "IT",
    "name": "Acqualagna",
    "lat": "43.62606",
    "lng": "12.67596"
  },
  {
    "country": "IT",
    "name": "Acquafredda",
    "lat": "45.30697",
    "lng": "10.41343"
  },
  {
    "country": "IT",
    "name": "Acquafondata",
    "lat": "41.54282",
    "lng": "13.95281"
  },
  {
    "country": "IT",
    "name": "Acilia-Castel Fusano-Ostia Antica",
    "lat": "41.76337",
    "lng": "12.33078"
  },
  {
    "country": "IT",
    "name": "Acerra",
    "lat": "40.94477",
    "lng": "14.3714"
  },
  {
    "country": "IT",
    "name": "Acerno",
    "lat": "40.73771",
    "lng": "15.05695"
  },
  {
    "country": "IT",
    "name": "Acerenza",
    "lat": "40.79386",
    "lng": "15.93808"
  },
  {
    "country": "IT",
    "name": "Accumoli",
    "lat": "42.69476",
    "lng": "13.24761"
  },
  {
    "country": "IT",
    "name": "Acciano",
    "lat": "42.17677",
    "lng": "13.71783"
  },
  {
    "country": "IT",
    "name": "Accettura",
    "lat": "40.49102",
    "lng": "16.15798"
  },
  {
    "country": "IT",
    "name": "Acceglio",
    "lat": "44.47463",
    "lng": "6.99092"
  },
  {
    "country": "IT",
    "name": "Accadia",
    "lat": "41.15768",
    "lng": "15.331"
  },
  {
    "country": "IT",
    "name": "Abriola",
    "lat": "40.50748",
    "lng": "15.8131"
  },
  {
    "country": "IT",
    "name": "Abetone",
    "lat": "44.14595",
    "lng": "10.66407"
  },
  {
    "country": "IT",
    "name": "Abbiategrasso",
    "lat": "45.39821",
    "lng": "8.91678"
  },
  {
    "country": "IT",
    "name": "Abbazia Pisani",
    "lat": "45.6127",
    "lng": "11.85429"
  },
  {
    "country": "IT",
    "name": "Abbateggio",
    "lat": "42.22421",
    "lng": "14.01001"
  },
  {
    "country": "IT",
    "name": "Abbasanta",
    "lat": "40.12812",
    "lng": "8.8176"
  },
  {
    "country": "IT",
    "name": "Abbadia San Salvatore",
    "lat": "42.8812",
    "lng": "11.6722"
  },
  {
    "country": "IT",
    "name": "Abbadia Lariana",
    "lat": "45.89947",
    "lng": "9.33518"
  },
  {
    "country": "IT",
    "name": "Abano Terme",
    "lat": "45.35753",
    "lng": "11.78725"
  },
  {
    "country": "IT",
    "name": "Li Punti-San Giovanni",
    "lat": "40.76338",
    "lng": "8.489"
  },
  {
    "country": "IT",
    "name": "Tergu",
    "lat": "40.86652",
    "lng": "8.71467"
  },
  {
    "country": "IT",
    "name": "San Martino dei Mulini",
    "lat": "44.03182",
    "lng": "12.46396"
  },
  {
    "country": "IT",
    "name": "Gatteo-Sant'Angelo",
    "lat": "44.11194",
    "lng": "12.39139"
  },
  {
    "country": "IT",
    "name": "San Mauro a Mare",
    "lat": "44.16367",
    "lng": "12.44631"
  },
  {
    "country": "IT",
    "name": "Gatteo a Mare",
    "lat": "44.17069",
    "lng": "12.43549"
  },
  {
    "country": "IT",
    "name": "Sala",
    "lat": "44.15638",
    "lng": "12.3834"
  },
  {
    "country": "IT",
    "name": "Bagnarola",
    "lat": "44.16232",
    "lng": "12.3428"
  },
  {
    "country": "IT",
    "name": "Pisignano",
    "lat": "44.23787",
    "lng": "12.26841"
  },
  {
    "country": "IT",
    "name": "Rivazzurra",
    "lat": "44.04186",
    "lng": "12.60894"
  },
  {
    "country": "IT",
    "name": "Lido Adriano",
    "lat": "44.41673",
    "lng": "12.30552"
  },
  {
    "country": "IT",
    "name": "Marina Romea",
    "lat": "44.51494",
    "lng": "12.27113"
  },
  {
    "country": "IT",
    "name": "Santo Stefano-Carraie",
    "lat": "44.31525",
    "lng": "12.18573"
  },
  {
    "country": "IT",
    "name": "Glorie",
    "lat": "44.46994",
    "lng": "12.07707"
  },
  {
    "country": "IT",
    "name": "Lido degli Estensi",
    "lat": "44.66639",
    "lng": "12.25"
  },
  {
    "country": "IT",
    "name": "Lido di Pomposa-Lido degli Scacchi",
    "lat": "44.70667",
    "lng": "12.23611"
  },
  {
    "country": "IT",
    "name": "Serravalle",
    "lat": "44.96532",
    "lng": "12.04664"
  },
  {
    "country": "IT",
    "name": "Scardovari",
    "lat": "44.89765",
    "lng": "12.45462"
  },
  {
    "country": "IT",
    "name": "Aurisina Cave",
    "lat": "45.75398",
    "lng": "13.65931"
  },
  {
    "country": "IT",
    "name": "Capriva del Friuli",
    "lat": "45.94093",
    "lng": "13.51422"
  },
  {
    "country": "IT",
    "name": "San Lorenzo Isontino",
    "lat": "45.9302",
    "lng": "13.52517"
  },
  {
    "country": "IT",
    "name": "Ruda",
    "lat": "45.83986",
    "lng": "13.40177"
  },
  {
    "country": "IT",
    "name": "Visco",
    "lat": "45.89194",
    "lng": "13.34861"
  },
  {
    "country": "IT",
    "name": "Sevegliano",
    "lat": "45.88749",
    "lng": "13.30541"
  },
  {
    "country": "IT",
    "name": "San Vito al Torre",
    "lat": "45.89587",
    "lng": "13.37588"
  },
  {
    "country": "IT",
    "name": "Medea",
    "lat": "45.91751",
    "lng": "13.42444"
  },
  {
    "country": "IT",
    "name": "Chiopris",
    "lat": "45.92667",
    "lng": "13.40417"
  },
  {
    "country": "IT",
    "name": "Terzo d'Aquileia",
    "lat": "45.79994",
    "lng": "13.34177"
  },
  {
    "country": "IT",
    "name": "San Canzian d'Isonzo",
    "lat": "45.7975",
    "lng": "13.46639"
  },
  {
    "country": "IT",
    "name": "Pavia di Udine",
    "lat": "45.99502",
    "lng": "13.30367"
  },
  {
    "country": "IT",
    "name": "Bagnaria Arsa",
    "lat": "45.88383",
    "lng": "13.28562"
  },
  {
    "country": "IT",
    "name": "Pertegada",
    "lat": "45.72179",
    "lng": "13.04379"
  },
  {
    "country": "IT",
    "name": "Camino al Tagliamento",
    "lat": "45.92767",
    "lng": "12.94489"
  },
  {
    "country": "IT",
    "name": "Puia-Villanova",
    "lat": "45.86222",
    "lng": "12.57139"
  },
  {
    "country": "IT",
    "name": "Prata di Sotto",
    "lat": "45.89073",
    "lng": "12.59591"
  },
  {
    "country": "IT",
    "name": "Meduna di Livenza",
    "lat": "45.8172",
    "lng": "12.62828"
  },
  {
    "country": "IT",
    "name": "Gorgo al Monticano",
    "lat": "45.79139",
    "lng": "12.55"
  },
  {
    "country": "IT",
    "name": "Piavon",
    "lat": "45.76429",
    "lng": "12.52673"
  },
  {
    "country": "IT",
    "name": "Corbolone",
    "lat": "45.74962",
    "lng": "12.66969"
  },
  {
    "country": "IT",
    "name": "Pramaggiore Blessaglia",
    "lat": "45.80528",
    "lng": "12.725"
  },
  {
    "country": "IT",
    "name": "Pramaggiore",
    "lat": "45.815",
    "lng": "12.73889"
  },
  {
    "country": "IT",
    "name": "Gruaro-Bagnara",
    "lat": "45.84167",
    "lng": "12.85111"
  },
  {
    "country": "IT",
    "name": "Summaga",
    "lat": "45.77406",
    "lng": "12.79792"
  },
  {
    "country": "IT",
    "name": "San Giorgio al Tagliamento-Pozzi",
    "lat": "45.79639",
    "lng": "12.96361"
  },
  {
    "country": "IT",
    "name": "Crepaldo",
    "lat": "45.59495",
    "lng": "12.69655"
  },
  {
    "country": "IT",
    "name": "Pero",
    "lat": "45.70635",
    "lng": "12.34867"
  },
  {
    "country": "IT",
    "name": "Candelù",
    "lat": "45.73499",
    "lng": "12.37224"
  },
  {
    "country": "IT",
    "name": "Ormelle",
    "lat": "45.7778",
    "lng": "12.42429"
  },
  {
    "country": "IT",
    "name": "San Polo di Piave",
    "lat": "45.78969",
    "lng": "12.39287"
  },
  {
    "country": "IT",
    "name": "Lutrano",
    "lat": "45.81415",
    "lng": "12.47316"
  },
  {
    "country": "IT",
    "name": "Maserada sul Piave",
    "lat": "45.75195",
    "lng": "12.31773"
  },
  {
    "country": "IT",
    "name": "Santa Maria",
    "lat": "45.99115",
    "lng": "12.22992"
  },
  {
    "country": "IT",
    "name": "Covolo-Levada",
    "lat": "45.84828",
    "lng": "12.00515"
  },
  {
    "country": "IT",
    "name": "Santa Lucia di Piave",
    "lat": "45.86159",
    "lng": "12.2939"
  },
  {
    "country": "IT",
    "name": "Mareno di Piave",
    "lat": "45.84572",
    "lng": "12.33703"
  },
  {
    "country": "IT",
    "name": "Francenigo",
    "lat": "45.90799",
    "lng": "12.50347"
  },
  {
    "country": "IT",
    "name": "Colle Umberto",
    "lat": "45.94238",
    "lng": "12.34228"
  },
  {
    "country": "IT",
    "name": "Cosniga-Zoppè",
    "lat": "45.8875",
    "lng": "12.36028"
  },
  {
    "country": "IT",
    "name": "Orsago",
    "lat": "45.92965",
    "lng": "12.42712"
  },
  {
    "country": "IT",
    "name": "Ciano",
    "lat": "45.82389",
    "lng": "12.05417"
  },
  {
    "country": "IT",
    "name": "Selva del Montello",
    "lat": "45.78835",
    "lng": "12.1435"
  },
  {
    "country": "IT",
    "name": "Povegliano",
    "lat": "45.75947",
    "lng": "12.20944"
  },
  {
    "country": "IT",
    "name": "Falzè-Signoressa",
    "lat": "45.75028",
    "lng": "12.10722"
  },
  {
    "country": "IT",
    "name": "Falze",
    "lat": "45.74381",
    "lng": "12.0926"
  },
  {
    "country": "IT",
    "name": "Ponzano",
    "lat": "45.71541",
    "lng": "12.20444"
  },
  {
    "country": "IT",
    "name": "Mignagola",
    "lat": "45.68868",
    "lng": "12.32154"
  },
  {
    "country": "IT",
    "name": "Casacorba",
    "lat": "45.65944",
    "lng": "12.03889"
  },
  {
    "country": "IT",
    "name": "Padernello",
    "lat": "45.68152",
    "lng": "12.12685"
  },
  {
    "country": "IT",
    "name": "Fossò",
    "lat": "45.3858",
    "lng": "12.04627"
  },
  {
    "country": "IT",
    "name": "Fiesso d'Artico",
    "lat": "45.42139",
    "lng": "12.02944"
  },
  {
    "country": "IT",
    "name": "Marano",
    "lat": "45.46345",
    "lng": "12.11715"
  },
  {
    "country": "IT",
    "name": "Dese",
    "lat": "45.52962",
    "lng": "12.30363"
  },
  {
    "country": "IT",
    "name": "San Liberale",
    "lat": "45.54778",
    "lng": "12.34139"
  },
  {
    "country": "IT",
    "name": "Trivignano",
    "lat": "45.53197",
    "lng": "12.18687"
  },
  {
    "country": "IT",
    "name": "Peseggia-Gardigiano",
    "lat": "45.56167",
    "lng": "12.17944"
  },
  {
    "country": "IT",
    "name": "Torreselle",
    "lat": "45.63026",
    "lng": "12.0225"
  },
  {
    "country": "IT",
    "name": "Badoere",
    "lat": "45.6342",
    "lng": "12.08518"
  },
  {
    "country": "IT",
    "name": "Sant'Alberto",
    "lat": "45.61306",
    "lng": "12.13472"
  },
  {
    "country": "IT",
    "name": "Lughignano",
    "lat": "45.62533",
    "lng": "12.32478"
  },
  {
    "country": "IT",
    "name": "Casier",
    "lat": "45.64229",
    "lng": "12.29328"
  },
  {
    "country": "IT",
    "name": "Biancade",
    "lat": "45.64867",
    "lng": "12.35753"
  },
  {
    "country": "IT",
    "name": "Stigliano",
    "lat": "45.52362",
    "lng": "12.04377"
  },
  {
    "country": "IT",
    "name": "Veternigo",
    "lat": "45.51765",
    "lng": "12.05793"
  },
  {
    "country": "IT",
    "name": "Caselle",
    "lat": "45.48628",
    "lng": "12.00608"
  },
  {
    "country": "IT",
    "name": "Spinea-Orgnano",
    "lat": "45.49107",
    "lng": "12.155"
  },
  {
    "country": "IT",
    "name": "Sambruson",
    "lat": "45.41039",
    "lng": "12.10311"
  },
  {
    "country": "IT",
    "name": "Campolongo Maggiore Liettoli",
    "lat": "45.33944",
    "lng": "12.02417"
  },
  {
    "country": "IT",
    "name": "Vallonga",
    "lat": "45.27248",
    "lng": "12.0786"
  },
  {
    "country": "IT",
    "name": "Cercivento",
    "lat": "46.52745",
    "lng": "12.99219"
  },
  {
    "country": "IT",
    "name": "Sutrio",
    "lat": "46.51206",
    "lng": "12.99325"
  },
  {
    "country": "IT",
    "name": "Pieria-Prato Carnico",
    "lat": "46.52037",
    "lng": "12.80328"
  },
  {
    "country": "IT",
    "name": "Granvilla",
    "lat": "46.56755",
    "lng": "12.68933"
  },
  {
    "country": "IT",
    "name": "Sant'Anna",
    "lat": "45.1661",
    "lng": "12.27355"
  },
  {
    "country": "IT",
    "name": "Bortolot",
    "lat": "46.38608",
    "lng": "12.17371"
  },
  {
    "country": "IT",
    "name": "Castion",
    "lat": "46.12147",
    "lng": "12.23507"
  },
  {
    "country": "IT",
    "name": "Trichiana",
    "lat": "46.0813",
    "lng": "12.14091"
  },
  {
    "country": "IT",
    "name": "Limana",
    "lat": "46.10039",
    "lng": "12.18552"
  },
  {
    "country": "IT",
    "name": "Lamosano",
    "lat": "46.17276",
    "lng": "12.38691"
  },
  {
    "country": "IT",
    "name": "Soccher-Paiane-Casan-Arsie",
    "lat": "46.1812",
    "lng": "12.31001"
  },
  {
    "country": "IT",
    "name": "Valle di Cadore",
    "lat": "46.41806",
    "lng": "12.33431"
  },
  {
    "country": "IT",
    "name": "Col San Martino",
    "lat": "45.9002",
    "lng": "12.11575"
  },
  {
    "country": "IT",
    "name": "Savogna",
    "lat": "46.15846",
    "lng": "13.53089"
  },
  {
    "country": "IT",
    "name": "Clodig",
    "lat": "46.1562",
    "lng": "13.59399"
  },
  {
    "country": "IT",
    "name": "Merso di Sopra",
    "lat": "46.12389",
    "lng": "13.52806"
  },
  {
    "country": "IT",
    "name": "Prepotto",
    "lat": "46.04522",
    "lng": "13.47921"
  },
  {
    "country": "IT",
    "name": "Dolegna del Collio",
    "lat": "46.03094",
    "lng": "13.47885"
  },
  {
    "country": "IT",
    "name": "Orsaria",
    "lat": "46.03862",
    "lng": "13.38247"
  },
  {
    "country": "IT",
    "name": "Pradamano",
    "lat": "46.03391",
    "lng": "13.30223"
  },
  {
    "country": "IT",
    "name": "Basaldella",
    "lat": "46.02527",
    "lng": "13.21718"
  },
  {
    "country": "IT",
    "name": "Reana del Roiale",
    "lat": "46.13733",
    "lng": "13.2232"
  },
  {
    "country": "IT",
    "name": "Basiliano-Vissandone",
    "lat": "46.02278",
    "lng": "13.09306"
  },
  {
    "country": "IT",
    "name": "Bressa",
    "lat": "46.03446",
    "lng": "13.14724"
  },
  {
    "country": "IT",
    "name": "Passons",
    "lat": "46.06889",
    "lng": "13.18917"
  },
  {
    "country": "IT",
    "name": "Colugna",
    "lat": "46.091",
    "lng": "13.20282"
  },
  {
    "country": "IT",
    "name": "Pagnacco",
    "lat": "46.11462",
    "lng": "13.18377"
  },
  {
    "country": "IT",
    "name": "Colloredo di Monte Albano",
    "lat": "46.16472",
    "lng": "13.13861"
  },
  {
    "country": "IT",
    "name": "Colloredo di Monte Albano-Lauzzana",
    "lat": "46.15861",
    "lng": "13.12278"
  },
  {
    "country": "IT",
    "name": "Montenars",
    "lat": "46.25111",
    "lng": "13.16944"
  },
  {
    "country": "IT",
    "name": "Isola",
    "lat": "46.25573",
    "lng": "13.17906"
  },
  {
    "country": "IT",
    "name": "Bordano",
    "lat": "46.31528",
    "lng": "13.10529"
  },
  {
    "country": "IT",
    "name": "Chiaulis",
    "lat": "46.38877",
    "lng": "12.99155"
  },
  {
    "country": "IT",
    "name": "Preone",
    "lat": "46.39411",
    "lng": "12.86645"
  },
  {
    "country": "IT",
    "name": "Forgaria nel Friuli",
    "lat": "46.22036",
    "lng": "12.9747"
  },
  {
    "country": "IT",
    "name": "San Giacomo",
    "lat": "46.17311",
    "lng": "12.98344"
  },
  {
    "country": "IT",
    "name": "Tramonti di Sotto",
    "lat": "46.28475",
    "lng": "12.79644"
  },
  {
    "country": "IT",
    "name": "Marsure",
    "lat": "46.09403",
    "lng": "12.59528"
  },
  {
    "country": "IT",
    "name": "San Martino al Tagliamento",
    "lat": "46.01697",
    "lng": "12.86989"
  },
  {
    "country": "IT",
    "name": "Ramuscello",
    "lat": "45.88105",
    "lng": "12.8846"
  },
  {
    "country": "IT",
    "name": "Claut",
    "lat": "46.26855",
    "lng": "12.5144"
  },
  {
    "country": "IT",
    "name": "Bocco",
    "lat": "44.35111",
    "lng": "9.30333"
  },
  {
    "country": "IT",
    "name": "Leivi",
    "lat": "44.35344",
    "lng": "9.31074"
  },
  {
    "country": "IT",
    "name": "San Salvatore",
    "lat": "44.33098",
    "lng": "9.35479"
  },
  {
    "country": "IT",
    "name": "Cogorno",
    "lat": "44.32074",
    "lng": "9.37117"
  },
  {
    "country": "IT",
    "name": "Moraro",
    "lat": "45.92971",
    "lng": "13.49575"
  },
  {
    "country": "IT",
    "name": "Campolongo al Torre-Cavenzano",
    "lat": "45.86306",
    "lng": "13.38944"
  },
  {
    "country": "IT",
    "name": "Sottoselva",
    "lat": "45.91134",
    "lng": "13.32416"
  },
  {
    "country": "IT",
    "name": "Motta Camastra",
    "lat": "37.89431",
    "lng": "15.17008"
  },
  {
    "country": "IT",
    "name": "Brusaporto",
    "lat": "45.6714",
    "lng": "9.76041"
  },
  {
    "country": "IT",
    "name": "Viganella",
    "lat": "46.05173",
    "lng": "8.19374"
  },
  {
    "country": "IT",
    "name": "Fratte Rosa",
    "lat": "43.63346",
    "lng": "12.90236"
  },
  {
    "country": "IT",
    "name": "San Bartolomeo al Mare",
    "lat": "43.92312",
    "lng": "8.10482"
  },
  {
    "country": "IT",
    "name": "Cloz",
    "lat": "46.4162",
    "lng": "11.08589"
  },
  {
    "country": "IT",
    "name": "Verbania",
    "lat": "45.92136",
    "lng": "8.55183"
  },
  {
    "country": "IT",
    "name": "Vacchereccia",
    "lat": "43.56099",
    "lng": "11.50131"
  },
  {
    "country": "IT",
    "name": "Pieve Emanuele",
    "lat": "45.35052",
    "lng": "9.20268"
  },
  {
    "country": "IT",
    "name": "Osio Sotto",
    "lat": "45.61608",
    "lng": "9.58905"
  },
  {
    "country": "IT",
    "name": "Scanzo-Rosciate",
    "lat": "45.71078",
    "lng": "9.73505"
  },
  {
    "country": "IT",
    "name": "Bedizzole",
    "lat": "45.51038",
    "lng": "10.42327"
  },
  {
    "country": "IT",
    "name": "Lumezzane",
    "lat": "45.64789",
    "lng": "10.26487"
  },
  {
    "country": "IT",
    "name": "Mazzano",
    "lat": "45.52008",
    "lng": "10.35387"
  },
  {
    "country": "IT",
    "name": "Beccacivetta-Azzano",
    "lat": "45.37435",
    "lng": "10.96133"
  },
  {
    "country": "IT",
    "name": "Noventa",
    "lat": "45.41429",
    "lng": "11.95101"
  },
  {
    "country": "IT",
    "name": "Castelnuovo del Garda",
    "lat": "45.43878",
    "lng": "10.75978"
  },
  {
    "country": "IT",
    "name": "Romano d'Ezzelino",
    "lat": "45.77902",
    "lng": "11.76657"
  },
  {
    "country": "IT",
    "name": "Saonara",
    "lat": "45.36529",
    "lng": "11.98481"
  },
  {
    "country": "IT",
    "name": "Mediglia",
    "lat": "45.39537",
    "lng": "9.33165"
  },
  {
    "country": "IT",
    "name": "Buccinasco",
    "lat": "45.40703",
    "lng": "9.1083"
  },
  {
    "country": "IT",
    "name": "Monte Argentario",
    "lat": "42.43452",
    "lng": "11.11954"
  },
  {
    "country": "IT",
    "name": "Guidonia Montecelio",
    "lat": "41.99362",
    "lng": "12.72238"
  },
  {
    "country": "IT",
    "name": "Cervinara",
    "lat": "41.02042",
    "lng": "14.61444"
  },
  {
    "country": "IT",
    "name": "Montoro Superiore",
    "lat": "40.81699",
    "lng": "14.79841"
  },
  {
    "country": "IT",
    "name": "Lamezia Terme",
    "lat": "38.96255",
    "lng": "16.30938"
  },
  {
    "country": "IT",
    "name": "Cardano al Campo",
    "lat": "45.64887",
    "lng": "8.76933"
  },
  {
    "country": "IT",
    "name": "Caronno Pertusella",
    "lat": "45.59777",
    "lng": "9.04634"
  },
  {
    "country": "IT",
    "name": "Cassano Magnago",
    "lat": "45.67206",
    "lng": "8.82691"
  },
  {
    "country": "IT",
    "name": "Gerenzano",
    "lat": "45.63967",
    "lng": "9.00104"
  },
  {
    "country": "IT",
    "name": "Uboldo",
    "lat": "45.61527",
    "lng": "9.00394"
  },
  {
    "country": "IT",
    "name": "Pero",
    "lat": "45.51017",
    "lng": "9.08704"
  },
  {
    "country": "IT",
    "name": "Pessano Con Bornago",
    "lat": "45.54937",
    "lng": "9.38145"
  },
  {
    "country": "IT",
    "name": "Settimo Milanese",
    "lat": "45.47771",
    "lng": "9.05574"
  },
  {
    "country": "IT",
    "name": "Cassola",
    "lat": "45.7336",
    "lng": "11.7994"
  },
  {
    "country": "IT",
    "name": "Pieve a Nievole",
    "lat": "43.88119",
    "lng": "10.7999"
  },
  {
    "country": "IT",
    "name": "Albisola Superiore",
    "lat": "44.33889",
    "lng": "8.51046"
  },
  {
    "country": "IT",
    "name": "Arcisate",
    "lat": "45.85578",
    "lng": "8.86823"
  },
  {
    "country": "IT",
    "name": "Basiglio",
    "lat": "45.35917",
    "lng": "9.15855"
  },
  {
    "country": "IT",
    "name": "Bussero",
    "lat": "45.53407",
    "lng": "9.37205"
  },
  {
    "country": "IT",
    "name": "Verano Brianza",
    "lat": "45.68868",
    "lng": "9.22454"
  },
  {
    "country": "IT",
    "name": "Treviolo",
    "lat": "45.67368",
    "lng": "9.61195"
  },
  {
    "country": "IT",
    "name": "Concesio",
    "lat": "45.60518",
    "lng": "10.21697"
  },
  {
    "country": "IT",
    "name": "Pino Torinese",
    "lat": "45.03955",
    "lng": "7.77712"
  },
  {
    "country": "IT",
    "name": "San Cipriano d'Aversa",
    "lat": "40.99881",
    "lng": "14.13173"
  },
  {
    "country": "IT",
    "name": "San Felice A Cancello",
    "lat": "41.01702",
    "lng": "14.48736"
  },
  {
    "country": "IT",
    "name": "San Nicola la Strada",
    "lat": "41.05237",
    "lng": "14.33334"
  },
  {
    "country": "IT",
    "name": "Crispano",
    "lat": "40.95251",
    "lng": "14.28993"
  },
  {
    "country": "IT",
    "name": "Pollena Trocchia",
    "lat": "40.85134",
    "lng": "14.37911"
  },
  {
    "country": "IT",
    "name": "Quarto",
    "lat": "40.87822",
    "lng": "14.14352"
  },
  {
    "country": "IT",
    "name": "Tremestieri Etneo",
    "lat": "37.56494",
    "lng": "15.07863"
  },
  {
    "country": "IT",
    "name": "Santena",
    "lat": "44.94624",
    "lng": "7.77303"
  },
  {
    "country": "IT",
    "name": "Vinovo",
    "lat": "44.94674",
    "lng": "7.63252"
  },
  {
    "country": "IT",
    "name": "San Pietro in Cariano",
    "lat": "45.51751",
    "lng": "10.88624"
  },
  {
    "country": "IT",
    "name": "Ozzano dell'Emilia",
    "lat": "44.44427",
    "lng": "11.47552"
  },
  {
    "country": "IT",
    "name": "Casagiove",
    "lat": "41.07124",
    "lng": "14.31163"
  },
  {
    "country": "IT",
    "name": "Frignano",
    "lat": "40.99811",
    "lng": "14.17913"
  },
  {
    "country": "IT",
    "name": "Orta di Atella",
    "lat": "40.96441",
    "lng": "14.26854"
  },
  {
    "country": "IT",
    "name": "San Marcellino",
    "lat": "40.99001",
    "lng": "14.17583"
  },
  {
    "country": "IT",
    "name": "Teverola",
    "lat": "40.99561",
    "lng": "14.20763"
  },
  {
    "country": "IT",
    "name": "Casavatore",
    "lat": "40.89921",
    "lng": "14.27663"
  },
  {
    "country": "IT",
    "name": "Volla",
    "lat": "40.87363",
    "lng": "14.34085"
  },
  {
    "country": "IT",
    "name": "Santa Maria La Carità",
    "lat": "40.71611",
    "lng": "14.50984"
  },
  {
    "country": "IT",
    "name": "Trecase",
    "lat": "40.76941",
    "lng": "14.43773"
  },
  {
    "country": "IT",
    "name": "Sant'Egidio del Monte Albino",
    "lat": "40.73871",
    "lng": "14.59454"
  },
  {
    "country": "IT",
    "name": "Bellizzi",
    "lat": "40.61981",
    "lng": "14.94685"
  },
  {
    "country": "IT",
    "name": "Alba Adriatica",
    "lat": "42.83176",
    "lng": "13.9259"
  },
  {
    "country": "IT",
    "name": "Valderice",
    "lat": "38.04005",
    "lng": "12.61505"
  },
  {
    "country": "IT",
    "name": "Gravina di Catania",
    "lat": "37.56085",
    "lng": "15.06292"
  },
  {
    "country": "IT",
    "name": "Sant'Agata Li Battiati",
    "lat": "37.55745",
    "lng": "15.07999"
  },
  {
    "country": "IT",
    "name": "Lusciano",
    "lat": "40.97001",
    "lng": "14.19043"
  },
  {
    "country": "IT",
    "name": "Parete",
    "lat": "40.95891",
    "lng": "14.16193"
  },
  {
    "country": "IT",
    "name": "Piedimonte Matese",
    "lat": "41.35082",
    "lng": "14.36803"
  },
  {
    "country": "IT",
    "name": "Cesano Boscone",
    "lat": "45.44207",
    "lng": "9.09445"
  },
  {
    "country": "IT",
    "name": "Cesate",
    "lat": "45.59587",
    "lng": "9.07574"
  },
  {
    "country": "IT",
    "name": "Carrara San Giorgio",
    "lat": "45.29259",
    "lng": "11.81841"
  },
  {
    "country": "IT",
    "name": "Porto Viro",
    "lat": "45.02678",
    "lng": "12.21754"
  },
  {
    "country": "IT",
    "name": "Tor Lupara",
    "lat": "41.99771",
    "lng": "12.61814"
  },
  {
    "country": "IT",
    "name": "Bernareggio",
    "lat": "45.64778",
    "lng": "9.40505"
  },
  {
    "country": "IT",
    "name": "Brozolo",
    "lat": "45.11695",
    "lng": "8.07193"
  },
  {
    "country": "IT",
    "name": "Campiglione",
    "lat": "44.80284",
    "lng": "7.32422"
  },
  {
    "country": "IT",
    "name": "Magliano Alfieri",
    "lat": "44.76924",
    "lng": "8.07014"
  },
  {
    "country": "IT",
    "name": "Moiola",
    "lat": "44.32113",
    "lng": "7.38973"
  },
  {
    "country": "IT",
    "name": "Mombarcaro",
    "lat": "44.46764",
    "lng": "8.08824"
  },
  {
    "country": "IT",
    "name": "Mombasiglio",
    "lat": "44.36663",
    "lng": "7.96794"
  },
  {
    "country": "IT",
    "name": "Monasterolo Casotto",
    "lat": "44.32823",
    "lng": "7.94324"
  },
  {
    "country": "IT",
    "name": "Montaldo di Mondovì",
    "lat": "44.32173",
    "lng": "7.86714"
  },
  {
    "country": "IT",
    "name": "Rocca De' Baldi",
    "lat": "44.42363",
    "lng": "7.76114"
  },
  {
    "country": "IT",
    "name": "Coassolo Torinese",
    "lat": "45.29775",
    "lng": "7.46041"
  },
  {
    "country": "IT",
    "name": "Inverso Pinasca",
    "lat": "44.94564",
    "lng": "7.21841"
  },
  {
    "country": "IT",
    "name": "Priero",
    "lat": "44.37604",
    "lng": "8.09334"
  },
  {
    "country": "IT",
    "name": "Roascio",
    "lat": "44.41714",
    "lng": "8.02234"
  },
  {
    "country": "IT",
    "name": "Rocchetta Belbo",
    "lat": "44.63604",
    "lng": "8.17534"
  },
  {
    "country": "IT",
    "name": "Roddi",
    "lat": "44.67964",
    "lng": "7.97544"
  },
  {
    "country": "IT",
    "name": "Roddino",
    "lat": "44.57384",
    "lng": "8.01914"
  },
  {
    "country": "IT",
    "name": "Rodello",
    "lat": "44.62854",
    "lng": "8.05684"
  },
  {
    "country": "IT",
    "name": "Sale delle Langhe",
    "lat": "44.39523",
    "lng": "8.08014"
  },
  {
    "country": "IT",
    "name": "San Benedetto Belbo",
    "lat": "44.49014",
    "lng": "8.05784"
  },
  {
    "country": "IT",
    "name": "Sinio",
    "lat": "44.60034",
    "lng": "8.01994"
  },
  {
    "country": "IT",
    "name": "Mompantero",
    "lat": "45.14744",
    "lng": "7.04301"
  },
  {
    "country": "IT",
    "name": "Pinasca-Dubbione",
    "lat": "44.94264",
    "lng": "7.22912"
  },
  {
    "country": "IT",
    "name": "Pramollo",
    "lat": "44.90814",
    "lng": "7.19071"
  },
  {
    "country": "IT",
    "name": "Prarostino",
    "lat": "44.86634",
    "lng": "7.26762"
  },
  {
    "country": "IT",
    "name": "Belveglio",
    "lat": "44.83012",
    "lng": "8.32864"
  },
  {
    "country": "IT",
    "name": "Cantarana",
    "lat": "44.90245",
    "lng": "8.02753"
  },
  {
    "country": "IT",
    "name": "Capriglio",
    "lat": "45.00355",
    "lng": "8.00893"
  },
  {
    "country": "IT",
    "name": "Castel Boglione",
    "lat": "44.72195",
    "lng": "8.37994"
  },
  {
    "country": "IT",
    "name": "Castellero",
    "lat": "44.92535",
    "lng": "8.07383"
  },
  {
    "country": "IT",
    "name": "Castelletto Molina",
    "lat": "44.75125",
    "lng": "8.43324"
  },
  {
    "country": "IT",
    "name": "Cellarengo",
    "lat": "44.86435",
    "lng": "7.94533"
  },
  {
    "country": "IT",
    "name": "Roure",
    "lat": "45.00214",
    "lng": "7.13161"
  },
  {
    "country": "IT",
    "name": "Salza di Pinerolo",
    "lat": "44.94004",
    "lng": "7.05241"
  },
  {
    "country": "IT",
    "name": "San Raffaele Cimena",
    "lat": "45.14665",
    "lng": "7.84932"
  },
  {
    "country": "IT",
    "name": "Traves",
    "lat": "45.26795",
    "lng": "7.43081"
  },
  {
    "country": "IT",
    "name": "Val della Torre",
    "lat": "45.15515",
    "lng": "7.44501"
  },
  {
    "country": "IT",
    "name": "Cinaglio",
    "lat": "44.97525",
    "lng": "8.10003"
  },
  {
    "country": "IT",
    "name": "Coazzolo",
    "lat": "44.72824",
    "lng": "8.14514"
  },
  {
    "country": "IT",
    "name": "Corsione",
    "lat": "45.00095",
    "lng": "8.14523"
  },
  {
    "country": "IT",
    "name": "Ferrere",
    "lat": "44.87605",
    "lng": "7.99421"
  },
  {
    "country": "IT",
    "name": "Maranzana",
    "lat": "44.76035",
    "lng": "8.47845"
  },
  {
    "country": "IT",
    "name": "Maretto",
    "lat": "44.94485",
    "lng": "8.03413"
  },
  {
    "country": "IT",
    "name": "Mombaruzzo",
    "lat": "44.77145",
    "lng": "8.44824"
  },
  {
    "country": "IT",
    "name": "Mombercelli",
    "lat": "44.81785",
    "lng": "8.29474"
  },
  {
    "country": "IT",
    "name": "Monale",
    "lat": "44.93755",
    "lng": "8.07243"
  },
  {
    "country": "IT",
    "name": "Monastero Bormida",
    "lat": "44.64854",
    "lng": "8.32664"
  },
  {
    "country": "IT",
    "name": "Verrua Savoia",
    "lat": "45.15675",
    "lng": "8.09223"
  },
  {
    "country": "IT",
    "name": "Montabone",
    "lat": "44.69875",
    "lng": "8.39064"
  },
  {
    "country": "IT",
    "name": "Montafia",
    "lat": "44.98925",
    "lng": "8.02463"
  },
  {
    "country": "IT",
    "name": "Montaldo Scarampi",
    "lat": "44.83035",
    "lng": "8.25904"
  },
  {
    "country": "IT",
    "name": "Piovà Massaia",
    "lat": "45.05515",
    "lng": "8.05013"
  },
  {
    "country": "IT",
    "name": "Quaranti",
    "lat": "44.75095",
    "lng": "8.44914"
  },
  {
    "country": "IT",
    "name": "Refrancore",
    "lat": "44.93635",
    "lng": "8.34084"
  },
  {
    "country": "IT",
    "name": "Roatto",
    "lat": "44.95205",
    "lng": "8.02693"
  },
  {
    "country": "IT",
    "name": "Robella",
    "lat": "45.10165",
    "lng": "8.10193"
  },
  {
    "country": "IT",
    "name": "Rocca d'Arazzo",
    "lat": "44.87205",
    "lng": "8.28464"
  },
  {
    "country": "IT",
    "name": "Agrate Conturbia",
    "lat": "45.67547",
    "lng": "8.55973"
  },
  {
    "country": "IT",
    "name": "Castelspina",
    "lat": "44.80615",
    "lng": "8.58315"
  },
  {
    "country": "IT",
    "name": "Cella Monte",
    "lat": "45.07405",
    "lng": "8.39154"
  },
  {
    "country": "IT",
    "name": "Conzano",
    "lat": "45.02009",
    "lng": "8.45554"
  },
  {
    "country": "IT",
    "name": "Oviglio",
    "lat": "44.86125",
    "lng": "8.48774"
  },
  {
    "country": "IT",
    "name": "Pleyne",
    "lat": "44.58063",
    "lng": "7.01712"
  },
  {
    "country": "IT",
    "name": "Briaglia",
    "lat": "44.39583",
    "lng": "7.87574"
  },
  {
    "country": "IT",
    "name": "Briga Alta",
    "lat": "44.08273",
    "lng": "7.74944"
  },
  {
    "country": "IT",
    "name": "Camerana",
    "lat": "44.42404",
    "lng": "8.14144"
  },
  {
    "country": "IT",
    "name": "Caprauna",
    "lat": "44.11603",
    "lng": "7.95495"
  },
  {
    "country": "IT",
    "name": "Chiesa di Macra",
    "lat": "44.48283",
    "lng": "7.18062"
  },
  {
    "country": "IT",
    "name": "Saint-Denis",
    "lat": "45.75256",
    "lng": "7.55531"
  },
  {
    "country": "IT",
    "name": "Verrayes",
    "lat": "45.76326",
    "lng": "7.5346"
  },
  {
    "country": "IT",
    "name": "Aquila di Arroscia",
    "lat": "44.08593",
    "lng": "8.00525"
  },
  {
    "country": "IT",
    "name": "Monastero di Vasco",
    "lat": "44.34033",
    "lng": "7.82264"
  },
  {
    "country": "IT",
    "name": "Cosio di Arroscia",
    "lat": "44.07743",
    "lng": "7.83244"
  },
  {
    "country": "IT",
    "name": "Diano Arentino",
    "lat": "43.94962",
    "lng": "8.04155"
  },
  {
    "country": "IT",
    "name": "Mendatica",
    "lat": "44.07713",
    "lng": "7.80564"
  },
  {
    "country": "IT",
    "name": "Montezemolo",
    "lat": "44.37703",
    "lng": "8.14114"
  },
  {
    "country": "IT",
    "name": "Monticello d'Alba",
    "lat": "44.71894",
    "lng": "7.94263"
  },
  {
    "country": "IT",
    "name": "Niella Tanaro",
    "lat": "44.40573",
    "lng": "7.92794"
  },
  {
    "country": "IT",
    "name": "Ostana",
    "lat": "44.69263",
    "lng": "7.18942"
  },
  {
    "country": "IT",
    "name": "Perlo",
    "lat": "44.33183",
    "lng": "8.08554"
  },
  {
    "country": "IT",
    "name": "Pontechianale",
    "lat": "44.62123",
    "lng": "7.03002"
  },
  {
    "country": "IT",
    "name": "Rittana",
    "lat": "44.35103",
    "lng": "7.39843"
  },
  {
    "country": "IT",
    "name": "Roccabruna",
    "lat": "44.47453",
    "lng": "7.34373"
  },
  {
    "country": "IT",
    "name": "Cosseria",
    "lat": "44.36774",
    "lng": "8.23485"
  },
  {
    "country": "IT",
    "name": "Giusvalla",
    "lat": "44.44794",
    "lng": "8.39415"
  },
  {
    "country": "IT",
    "name": "Magliolo",
    "lat": "44.19253",
    "lng": "8.24935"
  },
  {
    "country": "IT",
    "name": "Mallare",
    "lat": "44.28934",
    "lng": "8.29695"
  },
  {
    "country": "IT",
    "name": "Scagnello",
    "lat": "44.33333",
    "lng": "7.98644"
  },
  {
    "country": "IT",
    "name": "Torre Mondovì",
    "lat": "44.35283",
    "lng": "7.89964"
  },
  {
    "country": "IT",
    "name": "Valloriate",
    "lat": "44.33763",
    "lng": "7.37393"
  },
  {
    "country": "IT",
    "name": "Agliano Terme",
    "lat": "44.79025",
    "lng": "8.25044"
  },
  {
    "country": "IT",
    "name": "Mioglia",
    "lat": "44.49214",
    "lng": "8.41435"
  },
  {
    "country": "IT",
    "name": "Plodio",
    "lat": "44.35394",
    "lng": "8.24725"
  },
  {
    "country": "IT",
    "name": "Rialto",
    "lat": "44.22653",
    "lng": "8.26135"
  },
  {
    "country": "IT",
    "name": "Casarza Ligure",
    "lat": "44.27188",
    "lng": "9.44704"
  },
  {
    "country": "IT",
    "name": "Davagna",
    "lat": "44.46585",
    "lng": "9.08666"
  },
  {
    "country": "IT",
    "name": "Orero",
    "lat": "44.40835",
    "lng": "9.26707"
  },
  {
    "country": "IT",
    "name": "Beverino",
    "lat": "44.19766",
    "lng": "9.78537"
  },
  {
    "country": "IT",
    "name": "Camerano Casasco",
    "lat": "44.99165",
    "lng": "8.09103"
  },
  {
    "country": "IT",
    "name": "Incisa Scapaccino",
    "lat": "44.80805",
    "lng": "8.37584"
  },
  {
    "country": "IT",
    "name": "Isola d'Asti",
    "lat": "44.83315",
    "lng": "8.18024"
  },
  {
    "country": "IT",
    "name": "Passerano Marmorito",
    "lat": "45.05585",
    "lng": "8.01873"
  },
  {
    "country": "IT",
    "name": "Rondanina",
    "lat": "44.56325",
    "lng": "9.21806"
  },
  {
    "country": "IT",
    "name": "Rovegno",
    "lat": "44.57675",
    "lng": "9.27917"
  },
  {
    "country": "IT",
    "name": "Carezzano Maggiore",
    "lat": "44.80705",
    "lng": "8.90055"
  },
  {
    "country": "IT",
    "name": "Cassinelle-Concentrico",
    "lat": "44.60154",
    "lng": "8.56345"
  },
  {
    "country": "IT",
    "name": "Castelletto Merli",
    "lat": "45.07395",
    "lng": "8.24013"
  },
  {
    "country": "IT",
    "name": "Cerrina",
    "lat": "45.12135",
    "lng": "8.21383"
  },
  {
    "country": "IT",
    "name": "Coniolo Bricco",
    "lat": "45.14816",
    "lng": "8.37093"
  },
  {
    "country": "IT",
    "name": "Lozza",
    "lat": "45.77567",
    "lng": "8.85773"
  },
  {
    "country": "IT",
    "name": "Malgesso",
    "lat": "45.82787",
    "lng": "8.67553"
  },
  {
    "country": "IT",
    "name": "Masciago Primo",
    "lat": "45.91778",
    "lng": "8.78113"
  },
  {
    "country": "IT",
    "name": "Mesenzana",
    "lat": "45.95158",
    "lng": "8.76453"
  },
  {
    "country": "IT",
    "name": "Montegrino Valtravaglia",
    "lat": "45.97398",
    "lng": "8.76743"
  },
  {
    "country": "IT",
    "name": "Orino",
    "lat": "45.88148",
    "lng": "8.71563"
  },
  {
    "country": "IT",
    "name": "Saltrio",
    "lat": "45.87347",
    "lng": "8.92436"
  },
  {
    "country": "IT",
    "name": "Morbello",
    "lat": "44.60504",
    "lng": "8.51075"
  },
  {
    "country": "IT",
    "name": "Odalengo Piccolo",
    "lat": "45.07165",
    "lng": "8.20603"
  },
  {
    "country": "IT",
    "name": "Pozzol Groppo",
    "lat": "44.87806",
    "lng": "9.02985"
  },
  {
    "country": "IT",
    "name": "San Giorgio Monferrato",
    "lat": "45.10735",
    "lng": "8.41614"
  },
  {
    "country": "IT",
    "name": "Bizzarone",
    "lat": "45.83428",
    "lng": "8.94274"
  },
  {
    "country": "IT",
    "name": "Blessagno",
    "lat": "45.95908",
    "lng": "9.09754"
  },
  {
    "country": "IT",
    "name": "Blevio",
    "lat": "45.84218",
    "lng": "9.10514"
  },
  {
    "country": "IT",
    "name": "Bulgarograsso",
    "lat": "45.74708",
    "lng": "9.00644"
  },
  {
    "country": "IT",
    "name": "Cadorago-Caslino al Piano",
    "lat": "45.72728",
    "lng": "9.03784"
  },
  {
    "country": "IT",
    "name": "Carate Urio",
    "lat": "45.87178",
    "lng": "9.12214"
  },
  {
    "country": "IT",
    "name": "Carbonate",
    "lat": "45.68507",
    "lng": "8.93814"
  },
  {
    "country": "IT",
    "name": "Caslino d'Erba",
    "lat": "45.83899",
    "lng": "9.22554"
  },
  {
    "country": "IT",
    "name": "Casnate Con Bernate",
    "lat": "45.75628",
    "lng": "9.07264"
  },
  {
    "country": "IT",
    "name": "Castelnuovo Bozzente",
    "lat": "45.76458",
    "lng": "8.94354"
  },
  {
    "country": "IT",
    "name": "Ayas",
    "lat": "45.81506",
    "lng": "7.68911"
  },
  {
    "country": "IT",
    "name": "Challand-Saint-Anselme",
    "lat": "45.71456",
    "lng": "7.73451"
  },
  {
    "country": "IT",
    "name": "Challand-Saint-Victor",
    "lat": "45.69046",
    "lng": "7.70471"
  },
  {
    "country": "IT",
    "name": "Chamois",
    "lat": "45.83886",
    "lng": "7.61871"
  },
  {
    "country": "IT",
    "name": "Champorcher",
    "lat": "45.62376",
    "lng": "7.62151"
  },
  {
    "country": "IT",
    "name": "Petit Fenis",
    "lat": "45.75115",
    "lng": "7.46391"
  },
  {
    "country": "IT",
    "name": "Introd",
    "lat": "45.69306",
    "lng": "7.1824"
  },
  {
    "country": "IT",
    "name": "Merone",
    "lat": "45.78718",
    "lng": "9.24404"
  },
  {
    "country": "IT",
    "name": "Moltrasio",
    "lat": "45.85998",
    "lng": "9.09844"
  },
  {
    "country": "IT",
    "name": "Montorfano",
    "lat": "45.78638",
    "lng": "9.14374"
  },
  {
    "country": "IT",
    "name": "Nesso",
    "lat": "45.91238",
    "lng": "9.15674"
  },
  {
    "country": "IT",
    "name": "Prelà Castello",
    "lat": "43.94006",
    "lng": "7.94409"
  },
  {
    "country": "IT",
    "name": "Borgo di Ranzo",
    "lat": "44.05963",
    "lng": "8.01495"
  },
  {
    "country": "IT",
    "name": "Andora",
    "lat": "43.95514",
    "lng": "8.14121"
  },
  {
    "country": "IT",
    "name": "Arnasco",
    "lat": "44.07823",
    "lng": "8.10745"
  },
  {
    "country": "IT",
    "name": "Borgio",
    "lat": "44.15906",
    "lng": "8.30832"
  },
  {
    "country": "IT",
    "name": "Bormida",
    "lat": "44.27813",
    "lng": "8.23235"
  },
  {
    "country": "IT",
    "name": "San Siro",
    "lat": "46.06573",
    "lng": "9.26877"
  },
  {
    "country": "IT",
    "name": "Moconesi",
    "lat": "44.42065",
    "lng": "9.20977"
  },
  {
    "country": "IT",
    "name": "Pieve di Zignago",
    "lat": "44.2779",
    "lng": "9.74573"
  },
  {
    "country": "IT",
    "name": "Bodio Lomnago",
    "lat": "45.78867",
    "lng": "8.75083"
  },
  {
    "country": "IT",
    "name": "Brezzo di Bedero",
    "lat": "45.97838",
    "lng": "8.71743"
  },
  {
    "country": "IT",
    "name": "Cadegliano-Viconago",
    "lat": "45.95948",
    "lng": "8.84343"
  },
  {
    "country": "IT",
    "name": "Castelveccana",
    "lat": "45.94798",
    "lng": "8.66633"
  },
  {
    "country": "IT",
    "name": "Novedrate",
    "lat": "45.69808",
    "lng": "9.12074"
  },
  {
    "country": "IT",
    "name": "Ossuccio",
    "lat": "45.96958",
    "lng": "9.17974"
  },
  {
    "country": "IT",
    "name": "Parè",
    "lat": "45.81088",
    "lng": "9.00874"
  },
  {
    "country": "IT",
    "name": "Peglio",
    "lat": "46.16039",
    "lng": "9.29474"
  },
  {
    "country": "IT",
    "name": "Plesio",
    "lat": "46.04742",
    "lng": "9.22882"
  },
  {
    "country": "IT",
    "name": "Sala Comacina",
    "lat": "45.96418",
    "lng": "9.16604"
  },
  {
    "country": "IT",
    "name": "San Bartolomeo Val Cavargna",
    "lat": "46.08349",
    "lng": "9.14913"
  },
  {
    "country": "IT",
    "name": "San Fermo della Battaglia",
    "lat": "45.80868",
    "lng": "9.04744"
  },
  {
    "country": "IT",
    "name": "San Nazzaro Val Cavargna",
    "lat": "46.08939",
    "lng": "9.12743"
  },
  {
    "country": "IT",
    "name": "Solbiate",
    "lat": "45.78968",
    "lng": "8.93314"
  },
  {
    "country": "IT",
    "name": "Stazzona",
    "lat": "46.13879",
    "lng": "9.27524"
  },
  {
    "country": "IT",
    "name": "Veniano",
    "lat": "45.71629",
    "lng": "8.98501"
  },
  {
    "country": "IT",
    "name": "Gornate Olona",
    "lat": "45.74157",
    "lng": "8.85994"
  },
  {
    "country": "IT",
    "name": "Oggiona-Santo Stefano",
    "lat": "45.70427",
    "lng": "8.81653"
  },
  {
    "country": "IT",
    "name": "Bema",
    "lat": "46.10819",
    "lng": "9.56414"
  },
  {
    "country": "IT",
    "name": "Cino",
    "lat": "46.15843",
    "lng": "9.48534"
  },
  {
    "country": "IT",
    "name": "Sernio",
    "lat": "46.2242",
    "lng": "10.20526"
  },
  {
    "country": "IT",
    "name": "Tresivio",
    "lat": "46.17569",
    "lng": "9.94255"
  },
  {
    "country": "IT",
    "name": "Veddasca",
    "lat": "46.07058",
    "lng": "8.79873"
  },
  {
    "country": "IT",
    "name": "Albavilla",
    "lat": "45.80038",
    "lng": "9.18504"
  },
  {
    "country": "IT",
    "name": "Beregazzo con Figliaro",
    "lat": "45.78068",
    "lng": "8.94414"
  },
  {
    "country": "IT",
    "name": "Bregnano",
    "lat": "45.69778",
    "lng": "9.05934"
  },
  {
    "country": "IT",
    "name": "Casasco Intelvi",
    "lat": "45.94368",
    "lng": "9.07574"
  },
  {
    "country": "IT",
    "name": "Assago",
    "lat": "45.40887",
    "lng": "9.12565"
  },
  {
    "country": "IT",
    "name": "Basiano",
    "lat": "45.58248",
    "lng": "9.46325"
  },
  {
    "country": "IT",
    "name": "Bellusco",
    "lat": "45.61958",
    "lng": "9.41905"
  },
  {
    "country": "IT",
    "name": "Consiglio di Rumo",
    "lat": "46.14299",
    "lng": "9.29334"
  },
  {
    "country": "IT",
    "name": "Cremia",
    "lat": "46.08649",
    "lng": "9.27114"
  },
  {
    "country": "IT",
    "name": "Faggeto Lario",
    "lat": "45.85878",
    "lng": "9.15894"
  },
  {
    "country": "IT",
    "name": "Faloppio",
    "lat": "45.80968",
    "lng": "8.96434"
  },
  {
    "country": "IT",
    "name": "Gironico al Piano",
    "lat": "45.80138",
    "lng": "9.00314"
  },
  {
    "country": "IT",
    "name": "Grandola ed Uniti",
    "lat": "46.02488",
    "lng": "9.21274"
  },
  {
    "country": "IT",
    "name": "Mezzegra",
    "lat": "45.98168",
    "lng": "9.20514"
  },
  {
    "country": "IT",
    "name": "Nobile-Monguzzo",
    "lat": "45.78018",
    "lng": "9.23024"
  },
  {
    "country": "IT",
    "name": "Montemezzo",
    "lat": "46.17879",
    "lng": "9.37094"
  },
  {
    "country": "IT",
    "name": "Pellio Intelvi",
    "lat": "45.97988",
    "lng": "9.05864"
  },
  {
    "country": "IT",
    "name": "Pianello del Lario",
    "lat": "46.10279",
    "lng": "9.27694"
  },
  {
    "country": "IT",
    "name": "Schignano",
    "lat": "45.92978",
    "lng": "9.10214"
  },
  {
    "country": "IT",
    "name": "Trezzone",
    "lat": "46.17159",
    "lng": "9.35184"
  },
  {
    "country": "IT",
    "name": "Valbrona",
    "lat": "45.87738",
    "lng": "9.29884"
  },
  {
    "country": "IT",
    "name": "Val Rezzo",
    "lat": "46.07268",
    "lng": "9.11183"
  },
  {
    "country": "IT",
    "name": "Castione Andevenno",
    "lat": "46.17279",
    "lng": "9.80025"
  },
  {
    "country": "IT",
    "name": "Pozzo d'Adda",
    "lat": "45.57258",
    "lng": "9.50295"
  },
  {
    "country": "IT",
    "name": "Pozzuolo Martesana",
    "lat": "45.51398",
    "lng": "9.45625"
  },
  {
    "country": "IT",
    "name": "Renate",
    "lat": "45.72438",
    "lng": "9.27994"
  },
  {
    "country": "IT",
    "name": "Roncello",
    "lat": "45.60238",
    "lng": "9.45495"
  },
  {
    "country": "IT",
    "name": "Bedulita",
    "lat": "45.79138",
    "lng": "9.55165"
  },
  {
    "country": "IT",
    "name": "Canonica d'Adda",
    "lat": "45.57568",
    "lng": "9.54165"
  },
  {
    "country": "IT",
    "name": "Carobbio degli Angeli",
    "lat": "45.66518",
    "lng": "9.82916"
  },
  {
    "country": "IT",
    "name": "Cenate Sopra",
    "lat": "45.71298",
    "lng": "9.82216"
  },
  {
    "country": "IT",
    "name": "Cenate di Sotto",
    "lat": "45.69898",
    "lng": "9.82636"
  },
  {
    "country": "IT",
    "name": "Moio de' Calvi",
    "lat": "45.95179",
    "lng": "9.70075"
  },
  {
    "country": "IT",
    "name": "Mozzo",
    "lat": "45.69868",
    "lng": "9.60865"
  },
  {
    "country": "IT",
    "name": "Palazzago",
    "lat": "45.75298",
    "lng": "9.53365"
  },
  {
    "country": "IT",
    "name": "Pedrengo",
    "lat": "45.69598",
    "lng": "9.73495"
  },
  {
    "country": "IT",
    "name": "Peia",
    "lat": "45.79949",
    "lng": "9.89926"
  },
  {
    "country": "IT",
    "name": "Pianico",
    "lat": "45.80989",
    "lng": "10.04306"
  },
  {
    "country": "IT",
    "name": "Piario",
    "lat": "45.89649",
    "lng": "9.92726"
  },
  {
    "country": "IT",
    "name": "Piazzolo",
    "lat": "45.97979",
    "lng": "9.67055"
  },
  {
    "country": "IT",
    "name": "Pognano",
    "lat": "45.58638",
    "lng": "9.63996"
  },
  {
    "country": "IT",
    "name": "Ponteranica",
    "lat": "45.73248",
    "lng": "9.65175"
  },
  {
    "country": "IT",
    "name": "Fara Olivana",
    "lat": "45.49508",
    "lng": "9.74906"
  },
  {
    "country": "IT",
    "name": "Foresto Sparso",
    "lat": "45.69088",
    "lng": "9.92006"
  },
  {
    "country": "IT",
    "name": "Isola di Fondra",
    "lat": "45.97859",
    "lng": "9.74735"
  },
  {
    "country": "IT",
    "name": "Locatello",
    "lat": "45.83518",
    "lng": "9.53405"
  },
  {
    "country": "IT",
    "name": "Oltressenda Alta",
    "lat": "45.91519",
    "lng": "9.94486"
  },
  {
    "country": "IT",
    "name": "San Paolo d'Argon",
    "lat": "45.68838",
    "lng": "9.80226"
  },
  {
    "country": "IT",
    "name": "Spinone al Lago",
    "lat": "45.76476",
    "lng": "9.92157"
  },
  {
    "country": "IT",
    "name": "Rota d'Imagna",
    "lat": "45.83088",
    "lng": "9.51225"
  },
  {
    "country": "IT",
    "name": "Sant'Omobono Terme",
    "lat": "45.80838",
    "lng": "9.53625"
  },
  {
    "country": "IT",
    "name": "Taleggio",
    "lat": "45.89339",
    "lng": "9.56485"
  },
  {
    "country": "IT",
    "name": "Ubiale Clanezzo",
    "lat": "45.78368",
    "lng": "9.61935"
  },
  {
    "country": "IT",
    "name": "Scano al Brembo",
    "lat": "45.71858",
    "lng": "9.60905"
  },
  {
    "country": "IT",
    "name": "Valgoglio",
    "lat": "45.97489",
    "lng": "9.91355"
  },
  {
    "country": "IT",
    "name": "Torre de' Roveri",
    "lat": "45.69718",
    "lng": "9.76326"
  },
  {
    "country": "IT",
    "name": "Valleve",
    "lat": "46.02819",
    "lng": "9.74375"
  },
  {
    "country": "IT",
    "name": "Vilminore di Scalve",
    "lat": "45.99819",
    "lng": "10.09376"
  },
  {
    "country": "IT",
    "name": "Bione",
    "lat": "45.67279",
    "lng": "10.33887"
  },
  {
    "country": "IT",
    "name": "Brione",
    "lat": "45.64228",
    "lng": "10.14846"
  },
  {
    "country": "IT",
    "name": "Verdellino",
    "lat": "45.60108",
    "lng": "9.60805"
  },
  {
    "country": "IT",
    "name": "Viadanica",
    "lat": "45.68468",
    "lng": "9.96146"
  },
  {
    "country": "IT",
    "name": "Vigano San Martino",
    "lat": "45.72608",
    "lng": "9.89616"
  },
  {
    "country": "IT",
    "name": "Costa di Serina",
    "lat": "45.83268",
    "lng": "9.74165"
  },
  {
    "country": "IT",
    "name": "Algua",
    "lat": "45.82584",
    "lng": "9.72225"
  },
  {
    "country": "IT",
    "name": "Agnosine",
    "lat": "45.64969",
    "lng": "10.35267"
  },
  {
    "country": "IT",
    "name": "Alfianello",
    "lat": "45.26698",
    "lng": "10.14817"
  },
  {
    "country": "IT",
    "name": "Idro",
    "lat": "45.73609",
    "lng": "10.47337"
  },
  {
    "country": "IT",
    "name": "Lodrino",
    "lat": "45.71969",
    "lng": "10.27767"
  },
  {
    "country": "IT",
    "name": "Lozio",
    "lat": "45.98569",
    "lng": "10.26096"
  },
  {
    "country": "IT",
    "name": "Manerba del Garda",
    "lat": "45.54988",
    "lng": "10.55228"
  },
  {
    "country": "IT",
    "name": "Corvino San Quirico",
    "lat": "45.01086",
    "lng": "9.16245"
  },
  {
    "country": "IT",
    "name": "Inverno e Monteleone",
    "lat": "45.19787",
    "lng": "9.38526"
  },
  {
    "country": "IT",
    "name": "Montecalvo Versiggia",
    "lat": "44.97206",
    "lng": "9.28536"
  },
  {
    "country": "IT",
    "name": "Mornico Losana",
    "lat": "45.01016",
    "lng": "9.20616"
  },
  {
    "country": "IT",
    "name": "Collebeato",
    "lat": "45.58118",
    "lng": "10.21017"
  },
  {
    "country": "IT",
    "name": "Corteno Golgi",
    "lat": "46.1662",
    "lng": "10.24346"
  },
  {
    "country": "IT",
    "name": "Erbusco",
    "lat": "45.59868",
    "lng": "9.97186"
  },
  {
    "country": "IT",
    "name": "Incudine",
    "lat": "46.2203",
    "lng": "10.35876"
  },
  {
    "country": "IT",
    "name": "Irma",
    "lat": "45.77129",
    "lng": "10.28457"
  },
  {
    "country": "IT",
    "name": "Santa Margherita di Staffora",
    "lat": "44.77154",
    "lng": "9.24006"
  },
  {
    "country": "IT",
    "name": "Casa Ponte",
    "lat": "44.87777",
    "lng": "9.16509"
  },
  {
    "country": "IT",
    "name": "Mombelli",
    "lat": "44.86866",
    "lng": "9.23436"
  },
  {
    "country": "IT",
    "name": "Longhena",
    "lat": "45.43768",
    "lng": "10.05967"
  },
  {
    "country": "IT",
    "name": "Losine",
    "lat": "45.98349",
    "lng": "10.31616"
  },
  {
    "country": "IT",
    "name": "Malegno",
    "lat": "45.95079",
    "lng": "10.27406"
  },
  {
    "country": "IT",
    "name": "Milzano",
    "lat": "45.27358",
    "lng": "10.19927"
  },
  {
    "country": "IT",
    "name": "Ome",
    "lat": "45.62728",
    "lng": "10.12137"
  },
  {
    "country": "IT",
    "name": "Cappella Cantone",
    "lat": "45.24657",
    "lng": "9.83826"
  },
  {
    "country": "IT",
    "name": "Casale Cremasco",
    "lat": "45.43187",
    "lng": "9.71416"
  },
  {
    "country": "IT",
    "name": "Corte de' Cortesi con Cignone",
    "lat": "45.27317",
    "lng": "10.00787"
  },
  {
    "country": "IT",
    "name": "Gadesco-Pieve Delmona",
    "lat": "45.15767",
    "lng": "10.11567"
  },
  {
    "country": "IT",
    "name": "Polpenazze del Garda",
    "lat": "45.55118",
    "lng": "10.50488"
  },
  {
    "country": "IT",
    "name": "Prevalle",
    "lat": "45.55138",
    "lng": "10.42207"
  },
  {
    "country": "IT",
    "name": "Persico Dosimo",
    "lat": "45.18587",
    "lng": "10.10517"
  },
  {
    "country": "IT",
    "name": "Urago d'Oglio",
    "lat": "45.51598",
    "lng": "9.86966"
  },
  {
    "country": "IT",
    "name": "Bagnaria",
    "lat": "44.82726",
    "lng": "9.12256"
  },
  {
    "country": "IT",
    "name": "Montescano",
    "lat": "45.03196",
    "lng": "9.28366"
  },
  {
    "country": "IT",
    "name": "Mottella",
    "lat": "45.16382",
    "lng": "10.84436"
  },
  {
    "country": "IT",
    "name": "Bastida Pancarana",
    "lat": "45.08606",
    "lng": "9.08515"
  },
  {
    "country": "IT",
    "name": "La Valle - Wengen",
    "lat": "46.65763",
    "lng": "11.92399"
  },
  {
    "country": "IT",
    "name": "Bleggio Superiore",
    "lat": "46.0248",
    "lng": "10.83837"
  },
  {
    "country": "IT",
    "name": "Bresimo",
    "lat": "46.41181",
    "lng": "10.96817"
  },
  {
    "country": "IT",
    "name": "Cimoneri",
    "lat": "45.98426",
    "lng": "11.07155"
  },
  {
    "country": "IT",
    "name": "Commezzadura",
    "lat": "46.32171",
    "lng": "10.83957"
  },
  {
    "country": "IT",
    "name": "Fierozzo",
    "lat": "46.11131",
    "lng": "11.31848"
  },
  {
    "country": "IT",
    "name": "Garniga Nuova",
    "lat": "46.0031",
    "lng": "11.08738"
  },
  {
    "country": "IT",
    "name": "Giovo",
    "lat": "46.15581",
    "lng": "11.15278"
  },
  {
    "country": "IT",
    "name": "Lona-Lases",
    "lat": "46.14421",
    "lng": "11.21958"
  },
  {
    "country": "IT",
    "name": "Montagne",
    "lat": "46.0585",
    "lng": "10.75127"
  },
  {
    "country": "IT",
    "name": "Redavalle",
    "lat": "45.03796",
    "lng": "9.20225"
  },
  {
    "country": "IT",
    "name": "Robecco Pavese",
    "lat": "45.04836",
    "lng": "9.15015"
  },
  {
    "country": "IT",
    "name": "Roncaro",
    "lat": "45.22817",
    "lng": "9.27545"
  },
  {
    "country": "IT",
    "name": "Rovescala",
    "lat": "45.00696",
    "lng": "9.34586"
  },
  {
    "country": "IT",
    "name": "Sant'Alessio Con Vialone",
    "lat": "45.22237",
    "lng": "9.22605"
  },
  {
    "country": "IT",
    "name": "Santa Maria della Versa",
    "lat": "44.98757",
    "lng": "9.29976"
  },
  {
    "country": "IT",
    "name": "Pieve di Bono",
    "lat": "45.9422",
    "lng": "10.64027"
  },
  {
    "country": "IT",
    "name": "Rumo",
    "lat": "46.44141",
    "lng": "11.01857"
  },
  {
    "country": "IT",
    "name": "Sagron Mis",
    "lat": "46.19471",
    "lng": "11.9432"
  },
  {
    "country": "IT",
    "name": "Sant'Orsola Terme",
    "lat": "46.10881",
    "lng": "11.30238"
  },
  {
    "country": "IT",
    "name": "Terragnolo",
    "lat": "45.8783",
    "lng": "11.15468"
  },
  {
    "country": "IT",
    "name": "Vigo di Ton",
    "lat": "46.26531",
    "lng": "11.08798"
  },
  {
    "country": "IT",
    "name": "Trambileno",
    "lat": "45.8689",
    "lng": "11.07338"
  },
  {
    "country": "IT",
    "name": "Torre de' Negri",
    "lat": "45.14966",
    "lng": "9.33456"
  },
  {
    "country": "IT",
    "name": "Torricella Verzate",
    "lat": "45.01996",
    "lng": "9.17356"
  },
  {
    "country": "IT",
    "name": "Valfloriana",
    "lat": "46.24971",
    "lng": "11.34308"
  },
  {
    "country": "IT",
    "name": "Vallarsa",
    "lat": "45.7828",
    "lng": "11.11788"
  },
  {
    "country": "IT",
    "name": "Villa-Agnedo",
    "lat": "46.05421",
    "lng": "11.52839"
  },
  {
    "country": "IT",
    "name": "Brentino Belluno",
    "lat": "45.65689",
    "lng": "10.89368"
  },
  {
    "country": "IT",
    "name": "Brenzone",
    "lat": "45.69989",
    "lng": "10.76058"
  },
  {
    "country": "IT",
    "name": "Lavagno",
    "lat": "45.43869",
    "lng": "11.13409"
  },
  {
    "country": "IT",
    "name": "Travacò Siccomario",
    "lat": "45.14906",
    "lng": "9.15965"
  },
  {
    "country": "IT",
    "name": "Velezzo Lomellina",
    "lat": "45.16336",
    "lng": "8.73724"
  },
  {
    "country": "IT",
    "name": "Verretto",
    "lat": "45.03976",
    "lng": "9.11315"
  },
  {
    "country": "IT",
    "name": "Verrua Po",
    "lat": "45.10686",
    "lng": "9.17535"
  },
  {
    "country": "IT",
    "name": "Gerre de' Caprioli",
    "lat": "45.09042",
    "lng": "10.05085"
  },
  {
    "country": "IT",
    "name": "Zeccone",
    "lat": "45.25787",
    "lng": "9.20115"
  },
  {
    "country": "IT",
    "name": "Zenevredo",
    "lat": "45.05391",
    "lng": "9.32667"
  },
  {
    "country": "IT",
    "name": "Pedemonte",
    "lat": "45.9084",
    "lng": "11.30859"
  },
  {
    "country": "IT",
    "name": "Ripalta Arpina",
    "lat": "45.30187",
    "lng": "9.72896"
  },
  {
    "country": "IT",
    "name": "Ripalta Guerina",
    "lat": "45.30607",
    "lng": "9.70396"
  },
  {
    "country": "IT",
    "name": "San Daniele Po",
    "lat": "45.06727",
    "lng": "10.17637"
  },
  {
    "country": "IT",
    "name": "San Pietro Valdastico",
    "lat": "45.8867",
    "lng": "11.36159"
  },
  {
    "country": "IT",
    "name": "Velo d'Astico",
    "lat": "45.7884",
    "lng": "11.36769"
  },
  {
    "country": "IT",
    "name": "Pieve di Coriano",
    "lat": "45.03388",
    "lng": "11.1078"
  },
  {
    "country": "IT",
    "name": "Ponti sul Mincio",
    "lat": "45.41208",
    "lng": "10.68508"
  },
  {
    "country": "IT",
    "name": "Redondesco",
    "lat": "45.16638",
    "lng": "10.51228"
  },
  {
    "country": "IT",
    "name": "Serravalle a Po",
    "lat": "45.06638",
    "lng": "11.0818"
  },
  {
    "country": "IT",
    "name": "Bersone",
    "lat": "45.9444",
    "lng": "10.63317"
  },
  {
    "country": "IT",
    "name": "Bolbeno",
    "lat": "46.0326",
    "lng": "10.73787"
  },
  {
    "country": "IT",
    "name": "Brione",
    "lat": "45.89488",
    "lng": "10.58975"
  },
  {
    "country": "IT",
    "name": "Massanzago-Ca' Baglioni-San Dono",
    "lat": "45.5563",
    "lng": "12.00731"
  },
  {
    "country": "IT",
    "name": "Megliadino San Fidenzio",
    "lat": "45.21739",
    "lng": "11.516"
  },
  {
    "country": "IT",
    "name": "Cagnò",
    "lat": "46.39431",
    "lng": "11.04117"
  },
  {
    "country": "IT",
    "name": "Villanova",
    "lat": "45.4889",
    "lng": "11.97471"
  },
  {
    "country": "IT",
    "name": "Vò",
    "lat": "45.32829",
    "lng": "11.6415"
  },
  {
    "country": "IT",
    "name": "Papozze",
    "lat": "44.98578",
    "lng": "12.03092"
  },
  {
    "country": "IT",
    "name": "Lisignago",
    "lat": "46.16061",
    "lng": "11.18768"
  },
  {
    "country": "IT",
    "name": "Malosco",
    "lat": "46.43611",
    "lng": "11.14627"
  },
  {
    "country": "IT",
    "name": "Nanno",
    "lat": "46.31481",
    "lng": "11.04747"
  },
  {
    "country": "IT",
    "name": "Nogaredo",
    "lat": "45.913",
    "lng": "11.02388"
  },
  {
    "country": "IT",
    "name": "Ossana",
    "lat": "46.30651",
    "lng": "10.73757"
  },
  {
    "country": "IT",
    "name": "Ronzo-Chienis",
    "lat": "45.8896",
    "lng": "10.95008"
  },
  {
    "country": "IT",
    "name": "Pelugo",
    "lat": "46.0885",
    "lng": "10.72387"
  },
  {
    "country": "IT",
    "name": "Fiumicello",
    "lat": "45.79202",
    "lng": "13.40964"
  },
  {
    "country": "IT",
    "name": "Sarnonico",
    "lat": "46.41941",
    "lng": "11.14177"
  },
  {
    "country": "IT",
    "name": "Segonzano",
    "lat": "46.19021",
    "lng": "11.25988"
  },
  {
    "country": "IT",
    "name": "Sfruz",
    "lat": "46.33961",
    "lng": "11.12377"
  },
  {
    "country": "IT",
    "name": "Smarano",
    "lat": "46.34311",
    "lng": "11.10977"
  },
  {
    "country": "IT",
    "name": "Reana del Rojale",
    "lat": "46.14322",
    "lng": "13.24653"
  },
  {
    "country": "IT",
    "name": "Soraga",
    "lat": "46.39462",
    "lng": "11.66619"
  },
  {
    "country": "IT",
    "name": "Sover",
    "lat": "46.22171",
    "lng": "11.31568"
  },
  {
    "country": "IT",
    "name": "Tenna",
    "lat": "46.0157",
    "lng": "11.26428"
  },
  {
    "country": "IT",
    "name": "Terzolas",
    "lat": "46.36111",
    "lng": "10.92587"
  },
  {
    "country": "IT",
    "name": "Torcegno",
    "lat": "46.07431",
    "lng": "11.44979"
  },
  {
    "country": "IT",
    "name": "Varena",
    "lat": "46.30671",
    "lng": "11.45828"
  },
  {
    "country": "IT",
    "name": "Zuclo",
    "lat": "46.0343",
    "lng": "10.75107"
  },
  {
    "country": "IT",
    "name": "Angiari",
    "lat": "45.22318",
    "lng": "11.2768"
  },
  {
    "country": "IT",
    "name": "Boschi Sant'Anna",
    "lat": "45.21768",
    "lng": "11.3562"
  },
  {
    "country": "IT",
    "name": "Cerro Veronese",
    "lat": "45.57449",
    "lng": "11.04159"
  },
  {
    "country": "IT",
    "name": "Colognola ai Colli",
    "lat": "45.43369",
    "lng": "11.18429"
  },
  {
    "country": "IT",
    "name": "Grancona",
    "lat": "45.42189",
    "lng": "11.4516"
  },
  {
    "country": "IT",
    "name": "Roveredo di Guà",
    "lat": "45.27309",
    "lng": "11.4442"
  },
  {
    "country": "IT",
    "name": "Roverè Veronese",
    "lat": "45.59329",
    "lng": "11.06999"
  },
  {
    "country": "IT",
    "name": "Stazione Valmozzola",
    "lat": "44.57879",
    "lng": "9.9429"
  },
  {
    "country": "IT",
    "name": "Lugo di Vicenza",
    "lat": "45.7455",
    "lng": "11.52869"
  },
  {
    "country": "IT",
    "name": "San Gregorio nelle Alpi",
    "lat": "46.10391",
    "lng": "12.0267"
  },
  {
    "country": "IT",
    "name": "San Nicolò Comelico",
    "lat": "46.58253",
    "lng": "12.5273"
  },
  {
    "country": "IT",
    "name": "Monfumo",
    "lat": "45.8308",
    "lng": "11.9203"
  },
  {
    "country": "IT",
    "name": "Portico e San Benedetto",
    "lat": "44.02646",
    "lng": "11.78153"
  },
  {
    "country": "IT",
    "name": "Villagrande",
    "lat": "43.84136",
    "lng": "12.35994"
  },
  {
    "country": "IT",
    "name": "Monte Grimano Terme",
    "lat": "43.86766",
    "lng": "12.47125"
  },
  {
    "country": "IT",
    "name": "Terrassa Padovana",
    "lat": "45.24409",
    "lng": "11.90271"
  },
  {
    "country": "IT",
    "name": "Valle e Castello",
    "lat": "43.0374",
    "lng": "13.08742"
  },
  {
    "country": "IT",
    "name": "Fluminata",
    "lat": "42.94383",
    "lng": "13.1348"
  },
  {
    "country": "IT",
    "name": "Castel di Lama",
    "lat": "42.86435",
    "lng": "13.71929"
  },
  {
    "country": "IT",
    "name": "Cortino",
    "lat": "42.62186",
    "lng": "13.50774"
  },
  {
    "country": "IT",
    "name": "Zeri",
    "lat": "44.35375",
    "lng": "9.76318"
  },
  {
    "country": "IT",
    "name": "San Romano in Garfagnana",
    "lat": "44.16945",
    "lng": "10.3469"
  },
  {
    "country": "IT",
    "name": "Caminata",
    "lat": "44.91036",
    "lng": "9.30816"
  },
  {
    "country": "IT",
    "name": "Cerignale",
    "lat": "44.67785",
    "lng": "9.35077"
  },
  {
    "country": "IT",
    "name": "Sambuca Pistoiese",
    "lat": "44.10435",
    "lng": "10.99961"
  },
  {
    "country": "IT",
    "name": "Capraia e Limite",
    "lat": "43.74535",
    "lng": "10.98342"
  },
  {
    "country": "IT",
    "name": "Tavarnelle Val di Pesa",
    "lat": "43.56184",
    "lng": "11.17152"
  },
  {
    "country": "IT",
    "name": "Gazzola",
    "lat": "44.96006",
    "lng": "9.54896"
  },
  {
    "country": "IT",
    "name": "Frazione Chiesa",
    "lat": "45.69405",
    "lng": "8.21228"
  },
  {
    "country": "IT",
    "name": "Callabiana - Chiesa",
    "lat": "45.63137",
    "lng": "8.09722"
  },
  {
    "country": "IT",
    "name": "Montegioco",
    "lat": "44.84205",
    "lng": "8.96275"
  },
  {
    "country": "IT",
    "name": "Calvignasco",
    "lat": "45.32597",
    "lng": "9.02775"
  },
  {
    "country": "IT",
    "name": "Sardigliano",
    "lat": "44.7524",
    "lng": "8.89575"
  },
  {
    "country": "IT",
    "name": "Nibionno",
    "lat": "45.74648",
    "lng": "9.26894"
  },
  {
    "country": "IT",
    "name": "Palazzo Pignano",
    "lat": "45.39007",
    "lng": "9.56956"
  },
  {
    "country": "IT",
    "name": "Terranova dei Passerini",
    "lat": "45.21527",
    "lng": "9.66186"
  },
  {
    "country": "IT",
    "name": "Capriata d'Orba",
    "lat": "44.72785",
    "lng": "8.69085"
  },
  {
    "country": "IT",
    "name": "Campo nell'Elba",
    "lat": "42.74802",
    "lng": "10.23332"
  },
  {
    "country": "IT",
    "name": "Montemignaio",
    "lat": "43.73985",
    "lng": "11.61883"
  },
  {
    "country": "IT",
    "name": "Isola del Giglio",
    "lat": "42.35791",
    "lng": "10.90724"
  },
  {
    "country": "IT",
    "name": "Tresana",
    "lat": "44.25425",
    "lng": "9.91288"
  },
  {
    "country": "IT",
    "name": "Pontey",
    "lat": "45.73886",
    "lng": "7.58831"
  },
  {
    "country": "IT",
    "name": "Rhemes-Saint-Georges",
    "lat": "45.65226",
    "lng": "7.1544"
  },
  {
    "country": "IT",
    "name": "Castelbianco",
    "lat": "44.11423",
    "lng": "8.07515"
  },
  {
    "country": "IT",
    "name": "Giustenice",
    "lat": "44.17293",
    "lng": "8.24305"
  },
  {
    "country": "IT",
    "name": "Larciano",
    "lat": "43.83365",
    "lng": "10.89001"
  },
  {
    "country": "IT",
    "name": "Onzo",
    "lat": "44.07013",
    "lng": "8.05225"
  },
  {
    "country": "IT",
    "name": "Orco Feglino",
    "lat": "44.22023",
    "lng": "8.32455"
  },
  {
    "country": "IT",
    "name": "Roccavignale",
    "lat": "44.36124",
    "lng": "8.19055"
  },
  {
    "country": "IT",
    "name": "Osteria dei Cacciatori-Stella",
    "lat": "44.43044",
    "lng": "8.4712"
  },
  {
    "country": "IT",
    "name": "Broccostella",
    "lat": "41.69972",
    "lng": "13.63531"
  },
  {
    "country": "IT",
    "name": "Vendone",
    "lat": "44.07693",
    "lng": "8.07115"
  },
  {
    "country": "IT",
    "name": "Vezzi Portio",
    "lat": "44.22933",
    "lng": "8.36505"
  },
  {
    "country": "IT",
    "name": "Avegno",
    "lat": "44.38285",
    "lng": "9.15797"
  },
  {
    "country": "IT",
    "name": "Tribogna",
    "lat": "44.41655",
    "lng": "9.19557"
  },
  {
    "country": "IT",
    "name": "Molino Vecchio-Scapitola-Baio",
    "lat": "44.55555",
    "lng": "9.06816"
  },
  {
    "country": "IT",
    "name": "Carrodano",
    "lat": "44.24155",
    "lng": "9.65578"
  },
  {
    "country": "IT",
    "name": "Cosio Valtellino",
    "lat": "46.13509",
    "lng": "9.55164"
  },
  {
    "country": "IT",
    "name": "Forcola",
    "lat": "46.15859",
    "lng": "9.66034"
  },
  {
    "country": "IT",
    "name": "Menarola",
    "lat": "46.29929",
    "lng": "9.36124"
  },
  {
    "country": "IT",
    "name": "Castel di Sasso",
    "lat": "41.19242",
    "lng": "14.27773"
  },
  {
    "country": "IT",
    "name": "Castel Morrone",
    "lat": "41.12102",
    "lng": "14.35473"
  },
  {
    "country": "IT",
    "name": "Samolaco",
    "lat": "46.24249",
    "lng": "9.39404"
  },
  {
    "country": "IT",
    "name": "Isolaccia",
    "lat": "46.48901",
    "lng": "10.29405"
  },
  {
    "country": "IT",
    "name": "Valdisotto",
    "lat": "46.43441",
    "lng": "10.35695"
  },
  {
    "country": "IT",
    "name": "Val Masino",
    "lat": "46.21519",
    "lng": "9.63804"
  },
  {
    "country": "IT",
    "name": "Marmentino",
    "lat": "45.75499",
    "lng": "10.28467"
  },
  {
    "country": "IT",
    "name": "Monticelli Brusati",
    "lat": "45.63478",
    "lng": "10.10026"
  },
  {
    "country": "IT",
    "name": "Muscoline",
    "lat": "45.56249",
    "lng": "10.46187"
  },
  {
    "country": "IT",
    "name": "Ossimo Superiore",
    "lat": "45.94619",
    "lng": "10.23056"
  },
  {
    "country": "IT",
    "name": "Paisco Loveno",
    "lat": "46.0791",
    "lng": "10.29256"
  },
  {
    "country": "IT",
    "name": "Pertica Alta",
    "lat": "45.74239",
    "lng": "10.34417"
  },
  {
    "country": "IT",
    "name": "Pertica Bassa",
    "lat": "45.75339",
    "lng": "10.37247"
  },
  {
    "country": "IT",
    "name": "Pezzaze",
    "lat": "45.77629",
    "lng": "10.23597"
  },
  {
    "country": "IT",
    "name": "Preseglie",
    "lat": "45.66829",
    "lng": "10.39677"
  },
  {
    "country": "IT",
    "name": "Provaglio d'Iseo",
    "lat": "45.63538",
    "lng": "10.04466"
  },
  {
    "country": "IT",
    "name": "Provaglio Val Sabbia",
    "lat": "45.68879",
    "lng": "10.43397"
  },
  {
    "country": "IT",
    "name": "Puegnago sul Garda",
    "lat": "45.56679",
    "lng": "10.50977"
  },
  {
    "country": "IT",
    "name": "Remedello",
    "lat": "45.27838",
    "lng": "10.37198"
  },
  {
    "country": "IT",
    "name": "Rodengo-Saiano",
    "lat": "45.59958",
    "lng": "10.10717"
  },
  {
    "country": "IT",
    "name": "Gardola",
    "lat": "45.7418",
    "lng": "10.71871"
  },
  {
    "country": "IT",
    "name": "Trebbio",
    "lat": "45.71289",
    "lng": "10.46137"
  },
  {
    "country": "IT",
    "name": "Vallio Terme",
    "lat": "45.60979",
    "lng": "10.39737"
  },
  {
    "country": "IT",
    "name": "Valvestino",
    "lat": "45.76069",
    "lng": "10.59547"
  },
  {
    "country": "IT",
    "name": "Albaredo Arnaboldi",
    "lat": "45.10666",
    "lng": "9.24296"
  },
  {
    "country": "IT",
    "name": "Castelletto di Branduzzo",
    "lat": "45.06936",
    "lng": "9.09845"
  },
  {
    "country": "IT",
    "name": "Lettere",
    "lat": "40.70491",
    "lng": "14.54494"
  },
  {
    "country": "IT",
    "name": "Sovramonte",
    "lat": "46.05861",
    "lng": "11.7866"
  },
  {
    "country": "IT",
    "name": "Paderno del Grappa",
    "lat": "45.8286",
    "lng": "11.8577"
  },
  {
    "country": "IT",
    "name": "Saint-Christophe",
    "lat": "45.75406",
    "lng": "7.3472"
  },
  {
    "country": "IT",
    "name": "Saint Marcel",
    "lat": "45.73146",
    "lng": "7.4482"
  },
  {
    "country": "IT",
    "name": "Saint-Nicolas",
    "lat": "45.71656",
    "lng": "7.1667"
  },
  {
    "country": "IT",
    "name": "Ville Sur Sarre",
    "lat": "45.73339",
    "lng": "7.25857"
  },
  {
    "country": "IT",
    "name": "Valsavarenche",
    "lat": "45.59186",
    "lng": "7.21"
  },
  {
    "country": "IT",
    "name": "Valtournenche",
    "lat": "45.87607",
    "lng": "7.6243"
  },
  {
    "country": "IT",
    "name": "Bajardo",
    "lat": "43.90402",
    "lng": "7.72534"
  },
  {
    "country": "IT",
    "name": "Ceranesi",
    "lat": "44.50563",
    "lng": "8.89343"
  },
  {
    "country": "IT",
    "name": "Roè Volciano",
    "lat": "45.61199",
    "lng": "10.48857"
  },
  {
    "country": "IT",
    "name": "Soiano",
    "lat": "45.52778",
    "lng": "10.51267"
  },
  {
    "country": "IT",
    "name": "Aldino",
    "lat": "46.36581",
    "lng": "11.35508"
  },
  {
    "country": "IT",
    "name": "Andriano",
    "lat": "46.51762",
    "lng": "11.23137"
  },
  {
    "country": "IT",
    "name": "Venticano",
    "lat": "41.04722",
    "lng": "14.91194"
  },
  {
    "country": "IT",
    "name": "Barbiano - Barbian",
    "lat": "46.60332",
    "lng": "11.52138"
  },
  {
    "country": "IT",
    "name": "Braies",
    "lat": "46.72023",
    "lng": "12.13339"
  },
  {
    "country": "IT",
    "name": "Brennero - Brenner",
    "lat": "46.93813",
    "lng": "11.44247"
  },
  {
    "country": "IT",
    "name": "Caines - Kuens",
    "lat": "46.70002",
    "lng": "11.16987"
  },
  {
    "country": "IT",
    "name": "Cornedo All'Isarco",
    "lat": "46.4899",
    "lng": "11.40647"
  },
  {
    "country": "IT",
    "name": "Cortina sulla Strada del Vino",
    "lat": "46.26941",
    "lng": "11.22188"
  },
  {
    "country": "IT",
    "name": "Funes - Villnoess",
    "lat": "46.64282",
    "lng": "11.67828"
  },
  {
    "country": "IT",
    "name": "Magrè sulla Strada del Vino",
    "lat": "46.28791",
    "lng": "11.21068"
  },
  {
    "country": "IT",
    "name": "Proves - Proveis",
    "lat": "46.47661",
    "lng": "11.02247"
  },
  {
    "country": "IT",
    "name": "Racines - Ratschings",
    "lat": "46.88183",
    "lng": "11.37827"
  },
  {
    "country": "IT",
    "name": "Rasun Anterselva - Rasen-Antholz",
    "lat": "46.77853",
    "lng": "12.04729"
  },
  {
    "country": "IT",
    "name": "Renon - Ritten",
    "lat": "46.54152",
    "lng": "11.45728"
  },
  {
    "country": "IT",
    "name": "Rodengo - Rodeneck",
    "lat": "46.77953",
    "lng": "11.69048"
  },
  {
    "country": "IT",
    "name": "San Martino in Badia",
    "lat": "46.68153",
    "lng": "11.89809"
  },
  {
    "country": "IT",
    "name": "Senales",
    "lat": "46.70602",
    "lng": "10.90846"
  },
  {
    "country": "IT",
    "name": "Tirolo",
    "lat": "46.69102",
    "lng": "11.15427"
  },
  {
    "country": "IT",
    "name": "Ultimo - Ulten",
    "lat": "46.54832",
    "lng": "11.00417"
  },
  {
    "country": "IT",
    "name": "Prati",
    "lat": "46.90003",
    "lng": "11.46507"
  },
  {
    "country": "IT",
    "name": "Valle Aurina - Ahrntal",
    "lat": "46.99623",
    "lng": "11.97988"
  },
  {
    "country": "IT",
    "name": "Valle di Casies - Gsies",
    "lat": "46.76833",
    "lng": "12.17939"
  },
  {
    "country": "IT",
    "name": "Vandoies - Vintl",
    "lat": "46.81513",
    "lng": "11.72068"
  },
  {
    "country": "IT",
    "name": "Verano - Voeran",
    "lat": "46.60472",
    "lng": "11.22607"
  },
  {
    "country": "IT",
    "name": "Villandro - Villanders",
    "lat": "46.63082",
    "lng": "11.53708"
  },
  {
    "country": "IT",
    "name": "Vallada Agordina",
    "lat": "46.36442",
    "lng": "11.93399"
  },
  {
    "country": "IT",
    "name": "Cavaso del Tomba",
    "lat": "45.86071",
    "lng": "11.8984"
  },
  {
    "country": "IT",
    "name": "Capitignano",
    "lat": "40.71851",
    "lng": "14.90465"
  },
  {
    "country": "IT",
    "name": "Montecorvino Pugliano",
    "lat": "40.67921",
    "lng": "14.94475"
  },
  {
    "country": "IT",
    "name": "Balsorano",
    "lat": "41.80982",
    "lng": "13.5598"
  },
  {
    "country": "IT",
    "name": "Lucoli",
    "lat": "42.29093",
    "lng": "13.33799"
  },
  {
    "country": "IT",
    "name": "Villagrande",
    "lat": "42.29533",
    "lng": "13.29999"
  },
  {
    "country": "IT",
    "name": "Imposte",
    "lat": "42.68634",
    "lng": "13.52829"
  },
  {
    "country": "IT",
    "name": "Isole Tremiti",
    "lat": "42.12085",
    "lng": "15.50424"
  },
  {
    "country": "IT",
    "name": "Calvisi",
    "lat": "39.12739",
    "lng": "16.3059"
  },
  {
    "country": "IT",
    "name": "Conflenti",
    "lat": "39.07169",
    "lng": "16.2845"
  },
  {
    "country": "IT",
    "name": "Africo Nuovo",
    "lat": "38.05067",
    "lng": "16.1332"
  },
  {
    "country": "IT",
    "name": "Fiumara",
    "lat": "38.21267",
    "lng": "15.69369"
  },
  {
    "country": "IT",
    "name": "Roghudi",
    "lat": "37.92499",
    "lng": "15.76537"
  },
  {
    "country": "IT",
    "name": "Fondachelli-Fantina",
    "lat": "37.98476",
    "lng": "15.17519"
  },
  {
    "country": "IT",
    "name": "Terme",
    "lat": "38.13586",
    "lng": "15.15658"
  },
  {
    "country": "IT",
    "name": "Maniace",
    "lat": "37.88306",
    "lng": "14.79808"
  },
  {
    "country": "IT",
    "name": "Valledoria",
    "lat": "40.92867",
    "lng": "8.82321"
  },
  {
    "country": "IT",
    "name": "Camandona",
    "lat": "45.64417",
    "lng": "8.09972"
  },
  {
    "country": "IT",
    "name": "Cerreto Castello",
    "lat": "45.56446",
    "lng": "8.16082"
  },
  {
    "country": "IT",
    "name": "Curino",
    "lat": "45.62717",
    "lng": "8.23622"
  },
  {
    "country": "IT",
    "name": "Mezzana Mortigliengo",
    "lat": "45.62657",
    "lng": "8.18952"
  },
  {
    "country": "IT",
    "name": "Selve Marcone",
    "lat": "45.61976",
    "lng": "8.08742"
  },
  {
    "country": "IT",
    "name": "Soprana",
    "lat": "45.63947",
    "lng": "8.19892"
  },
  {
    "country": "IT",
    "name": "Vallanzengo",
    "lat": "45.60327",
    "lng": "8.15042"
  },
  {
    "country": "IT",
    "name": "Veglio",
    "lat": "45.64057",
    "lng": "8.11412"
  },
  {
    "country": "IT",
    "name": "Castello di Brianza",
    "lat": "45.75928",
    "lng": "9.34535"
  },
  {
    "country": "IT",
    "name": "Colle Brianza",
    "lat": "45.76238",
    "lng": "9.36435"
  },
  {
    "country": "IT",
    "name": "Garbagnate Monastero",
    "lat": "45.77338",
    "lng": "9.30144"
  },
  {
    "country": "IT",
    "name": "Monticello Brianza",
    "lat": "45.70948",
    "lng": "9.31564"
  },
  {
    "country": "IT",
    "name": "Castiraga Vidardo",
    "lat": "45.25727",
    "lng": "9.40456"
  },
  {
    "country": "IT",
    "name": "Jonadi",
    "lat": "38.62988",
    "lng": "16.061"
  },
  {
    "country": "IT",
    "name": "Antrona Schieranco",
    "lat": "46.06038",
    "lng": "8.11461"
  },
  {
    "country": "IT",
    "name": "Brovello-Carpugnino",
    "lat": "45.84247",
    "lng": "8.53173"
  },
  {
    "country": "IT",
    "name": "Calasca-Castiglione",
    "lat": "46.02081",
    "lng": "8.21451"
  },
  {
    "country": "IT",
    "name": "Cavaglio-Spoccia",
    "lat": "46.07108",
    "lng": "8.63072"
  },
  {
    "country": "IT",
    "name": "Madonna del Sasso",
    "lat": "45.79217",
    "lng": "8.36952"
  },
  {
    "country": "IT",
    "name": "Montescheno",
    "lat": "46.06658",
    "lng": "8.23192"
  },
  {
    "country": "IT",
    "name": "Oggebbio",
    "lat": "45.99088",
    "lng": "8.64663"
  },
  {
    "country": "IT",
    "name": "San Bernardino Verbano",
    "lat": "45.95638",
    "lng": "8.51922"
  },
  {
    "country": "IT",
    "name": "Valstrona",
    "lat": "45.90767",
    "lng": "8.34322"
  },
  {
    "country": "IT",
    "name": "Montemale di Cuneo",
    "lat": "44.43743",
    "lng": "7.37533"
  },
  {
    "country": "IT",
    "name": "Monterosso Grana",
    "lat": "44.40823",
    "lng": "7.32293"
  },
  {
    "country": "IT",
    "name": "Murello",
    "lat": "44.75214",
    "lng": "7.60093"
  },
  {
    "country": "IT",
    "name": "Paroldo",
    "lat": "44.43204",
    "lng": "8.07244"
  },
  {
    "country": "IT",
    "name": "Perletto",
    "lat": "44.59934",
    "lng": "8.21304"
  },
  {
    "country": "IT",
    "name": "Pianfei",
    "lat": "44.37203",
    "lng": "7.71143"
  },
  {
    "country": "IT",
    "name": "Pocapaglia",
    "lat": "44.71524",
    "lng": "7.88293"
  },
  {
    "country": "IT",
    "name": "Polonghera",
    "lat": "44.80234",
    "lng": "7.59572"
  },
  {
    "country": "IT",
    "name": "Torre Bormida",
    "lat": "44.56274",
    "lng": "8.15444"
  },
  {
    "country": "IT",
    "name": "Torre San Giorgio",
    "lat": "44.73574",
    "lng": "7.52813"
  },
  {
    "country": "IT",
    "name": "Verduno",
    "lat": "44.66614",
    "lng": "7.93074"
  },
  {
    "country": "IT",
    "name": "Vezza d'Alba",
    "lat": "44.76274",
    "lng": "8.00793"
  },
  {
    "country": "IT",
    "name": "Villar San Costanzo",
    "lat": "44.48473",
    "lng": "7.38223"
  },
  {
    "country": "IT",
    "name": "Albugnano",
    "lat": "45.07755",
    "lng": "7.97113"
  },
  {
    "country": "IT",
    "name": "Antignano",
    "lat": "44.84535",
    "lng": "8.13494"
  },
  {
    "country": "IT",
    "name": "San Martino Alfieri",
    "lat": "44.81795",
    "lng": "8.10994"
  },
  {
    "country": "IT",
    "name": "San Paolo Solbrito",
    "lat": "44.95065",
    "lng": "7.97073"
  },
  {
    "country": "IT",
    "name": "Soglio",
    "lat": "44.99625",
    "lng": "8.07843"
  },
  {
    "country": "IT",
    "name": "Tigliole",
    "lat": "44.88625",
    "lng": "8.07663"
  },
  {
    "country": "IT",
    "name": "Vaglio Serra",
    "lat": "44.79635",
    "lng": "8.33894"
  },
  {
    "country": "IT",
    "name": "Viarigi",
    "lat": "44.98055",
    "lng": "8.35714"
  },
  {
    "country": "IT",
    "name": "Vinchio",
    "lat": "44.81095",
    "lng": "8.32094"
  },
  {
    "country": "IT",
    "name": "Alice Bel Colle",
    "lat": "44.72605",
    "lng": "8.45074"
  },
  {
    "country": "IT",
    "name": "Altavilla Monferrato",
    "lat": "44.99355",
    "lng": "8.37594"
  },
  {
    "country": "IT",
    "name": "Avolasca",
    "lat": "44.80315",
    "lng": "8.96545"
  },
  {
    "country": "IT",
    "name": "Belforte Monferrato",
    "lat": "44.62505",
    "lng": "8.66125"
  },
  {
    "country": "IT",
    "name": "Bergamasco",
    "lat": "44.82725",
    "lng": "8.45474"
  },
  {
    "country": "IT",
    "name": "Berzano di Tortona",
    "lat": "44.87666",
    "lng": "8.95108"
  },
  {
    "country": "IT",
    "name": "Borghetto di Borbera",
    "lat": "44.72945",
    "lng": "8.94346"
  },
  {
    "country": "IT",
    "name": "Bosio",
    "lat": "44.64975",
    "lng": "8.79285"
  },
  {
    "country": "IT",
    "name": "Carpeneto",
    "lat": "44.67835",
    "lng": "8.60555"
  },
  {
    "country": "IT",
    "name": "Casal Cermelli",
    "lat": "44.83495",
    "lng": "8.62495"
  },
  {
    "country": "IT",
    "name": "Casaleggio Boiro",
    "lat": "44.63355",
    "lng": "8.73045"
  },
  {
    "country": "IT",
    "name": "Costa Vescovato",
    "lat": "44.81615",
    "lng": "8.92695"
  },
  {
    "country": "IT",
    "name": "Cuccaro Monferrato",
    "lat": "44.99365",
    "lng": "8.45754"
  },
  {
    "country": "IT",
    "name": "Fraconalto",
    "lat": "44.59105",
    "lng": "8.87846"
  },
  {
    "country": "IT",
    "name": "Francavilla Bisio",
    "lat": "44.73465",
    "lng": "8.73125"
  },
  {
    "country": "IT",
    "name": "Fresonara",
    "lat": "44.78295",
    "lng": "8.68615"
  },
  {
    "country": "IT",
    "name": "Gavazzana",
    "lat": "44.77585",
    "lng": "8.88595"
  },
  {
    "country": "IT",
    "name": "Grondona",
    "lat": "44.69645",
    "lng": "8.96546"
  },
  {
    "country": "IT",
    "name": "Masio",
    "lat": "44.86965",
    "lng": "8.40774"
  },
  {
    "country": "IT",
    "name": "Molino dei Torti",
    "lat": "45.02426",
    "lng": "8.89365"
  },
  {
    "country": "IT",
    "name": "Mombello Monferrato",
    "lat": "45.13285",
    "lng": "8.25033"
  },
  {
    "country": "IT",
    "name": "Momperone",
    "lat": "44.83845",
    "lng": "9.03425"
  },
  {
    "country": "IT",
    "name": "Moncestino",
    "lat": "45.15465",
    "lng": "8.16143"
  },
  {
    "country": "IT",
    "name": "Montacuto",
    "lat": "44.76645",
    "lng": "9.10496"
  },
  {
    "country": "IT",
    "name": "Montaldeo",
    "lat": "44.66715",
    "lng": "8.73015"
  },
  {
    "country": "IT",
    "name": "Montechiaro d'Acqui",
    "lat": "44.59444",
    "lng": "8.37865"
  },
  {
    "country": "IT",
    "name": "Montemarzino",
    "lat": "44.84835",
    "lng": "8.99365"
  },
  {
    "country": "IT",
    "name": "Morsasco",
    "lat": "44.66535",
    "lng": "8.55085"
  },
  {
    "country": "IT",
    "name": "Odalengo Grande",
    "lat": "45.10922",
    "lng": "8.16748"
  },
  {
    "country": "IT",
    "name": "Olivola",
    "lat": "45.03725",
    "lng": "8.36784"
  },
  {
    "country": "IT",
    "name": "Orsara Bormida",
    "lat": "44.69015",
    "lng": "8.56275"
  },
  {
    "country": "IT",
    "name": "Pietra Marazzi",
    "lat": "44.94265",
    "lng": "8.66854"
  },
  {
    "country": "IT",
    "name": "Piovera",
    "lat": "44.95845",
    "lng": "8.73595"
  },
  {
    "country": "IT",
    "name": "Ponzano Monferrato",
    "lat": "45.08485",
    "lng": "8.26553"
  },
  {
    "country": "IT",
    "name": "Ricaldone",
    "lat": "44.73235",
    "lng": "8.46814"
  },
  {
    "country": "IT",
    "name": "Rosignano Monferrato",
    "lat": "45.08055",
    "lng": "8.39974"
  },
  {
    "country": "IT",
    "name": "Sant'Agata Fossili",
    "lat": "44.78475",
    "lng": "8.92115"
  },
  {
    "country": "IT",
    "name": "Sezzadio",
    "lat": "44.78485",
    "lng": "8.57255"
  },
  {
    "country": "IT",
    "name": "Solonghello",
    "lat": "45.12905",
    "lng": "8.28323"
  },
  {
    "country": "IT",
    "name": "Treville",
    "lat": "45.09685",
    "lng": "8.35954"
  },
  {
    "country": "IT",
    "name": "Arnad",
    "lat": "45.64726",
    "lng": "7.71701"
  },
  {
    "country": "IT",
    "name": "Fontainemore",
    "lat": "45.64746",
    "lng": "7.85952"
  },
  {
    "country": "IT",
    "name": "Hone",
    "lat": "45.61356",
    "lng": "7.73851"
  },
  {
    "country": "IT",
    "name": "Agra",
    "lat": "46.03668",
    "lng": "8.76833"
  },
  {
    "country": "IT",
    "name": "Azzio",
    "lat": "45.88468",
    "lng": "8.70853"
  },
  {
    "country": "IT",
    "name": "Barasso",
    "lat": "45.84048",
    "lng": "8.75683"
  },
  {
    "country": "IT",
    "name": "Bedero Valcuvia",
    "lat": "45.91088",
    "lng": "8.79553"
  },
  {
    "country": "IT",
    "name": "Brenta",
    "lat": "45.89418",
    "lng": "8.68373"
  },
  {
    "country": "IT",
    "name": "Brusimpiano",
    "lat": "45.94468",
    "lng": "8.88953"
  },
  {
    "country": "IT",
    "name": "Caronno Varesino",
    "lat": "45.73577",
    "lng": "8.83173"
  },
  {
    "country": "IT",
    "name": "Castello Cabiaglio",
    "lat": "45.89358",
    "lng": "8.75763"
  },
  {
    "country": "IT",
    "name": "Clivio",
    "lat": "45.86278",
    "lng": "8.93083"
  },
  {
    "country": "IT",
    "name": "Cuasso al Monte",
    "lat": "45.91478",
    "lng": "8.87923"
  },
  {
    "country": "IT",
    "name": "Cugliate-Fabiasco",
    "lat": "45.94568",
    "lng": "8.81863"
  },
  {
    "country": "IT",
    "name": "Cunardo",
    "lat": "45.93428",
    "lng": "8.80773"
  },
  {
    "country": "IT",
    "name": "Daverio",
    "lat": "45.77797",
    "lng": "8.77343"
  },
  {
    "country": "IT",
    "name": "Duno",
    "lat": "45.91398",
    "lng": "8.73763"
  },
  {
    "country": "IT",
    "name": "Gorla Minore",
    "lat": "45.64117",
    "lng": "8.90264"
  },
  {
    "country": "IT",
    "name": "Jerago Con Orago",
    "lat": "45.70467",
    "lng": "8.79593"
  },
  {
    "country": "IT",
    "name": "Leggiuno",
    "lat": "45.87588",
    "lng": "8.62063"
  },
  {
    "country": "IT",
    "name": "Varano Borghi",
    "lat": "45.77407",
    "lng": "8.70403"
  },
  {
    "country": "IT",
    "name": "Albese Con Cassano",
    "lat": "45.79488",
    "lng": "9.16364"
  },
  {
    "country": "IT",
    "name": "Alserio",
    "lat": "45.77888",
    "lng": "9.20014"
  },
  {
    "country": "IT",
    "name": "Cavallasca",
    "lat": "45.80958",
    "lng": "9.03284"
  },
  {
    "country": "IT",
    "name": "Corrido",
    "lat": "46.04758",
    "lng": "9.13554"
  },
  {
    "country": "IT",
    "name": "Fenegrò",
    "lat": "45.70157",
    "lng": "8.99964"
  },
  {
    "country": "IT",
    "name": "Laino",
    "lat": "45.98448",
    "lng": "9.07544"
  },
  {
    "country": "IT",
    "name": "Lasnigo",
    "lat": "45.88198",
    "lng": "9.26644"
  },
  {
    "country": "IT",
    "name": "Albosaggia",
    "lat": "46.14749",
    "lng": "9.85405"
  },
  {
    "country": "IT",
    "name": "Briosco",
    "lat": "45.71008",
    "lng": "9.24064"
  },
  {
    "country": "IT",
    "name": "Cassinetta di Lugagnano",
    "lat": "45.42247",
    "lng": "8.90604"
  },
  {
    "country": "IT",
    "name": "Cogliate",
    "lat": "45.64597",
    "lng": "9.07884"
  },
  {
    "country": "IT",
    "name": "Correzzana",
    "lat": "45.66658",
    "lng": "9.30755"
  },
  {
    "country": "IT",
    "name": "Dresano",
    "lat": "45.37297",
    "lng": "9.35785"
  },
  {
    "country": "IT",
    "name": "Gessate",
    "lat": "45.54838",
    "lng": "9.43775"
  },
  {
    "country": "IT",
    "name": "Gudo Visconti",
    "lat": "45.37407",
    "lng": "9.00014"
  },
  {
    "country": "IT",
    "name": "Lazzate",
    "lat": "45.67207",
    "lng": "9.08424"
  },
  {
    "country": "IT",
    "name": "Lesmo",
    "lat": "45.64858",
    "lng": "9.30735"
  },
  {
    "country": "IT",
    "name": "Macherio",
    "lat": "45.63974",
    "lng": "9.27394"
  },
  {
    "country": "IT",
    "name": "Masate",
    "lat": "45.56708",
    "lng": "9.46415"
  },
  {
    "country": "IT",
    "name": "Mesero",
    "lat": "45.50227",
    "lng": "8.85544"
  },
  {
    "country": "IT",
    "name": "Mezzago",
    "lat": "45.62898",
    "lng": "9.44485"
  },
  {
    "country": "IT",
    "name": "San Vittore Olona",
    "lat": "45.58577",
    "lng": "8.94134"
  },
  {
    "country": "IT",
    "name": "Sulbiate",
    "lat": "45.64047",
    "lng": "9.42762"
  },
  {
    "country": "IT",
    "name": "Veduggio Con Colzano",
    "lat": "45.73388",
    "lng": "9.27024"
  },
  {
    "country": "IT",
    "name": "Vizzolo Predabissi",
    "lat": "45.35587",
    "lng": "9.34815"
  },
  {
    "country": "IT",
    "name": "Adrara San Rocco",
    "lat": "45.71578",
    "lng": "9.95906"
  },
  {
    "country": "IT",
    "name": "Ambivere",
    "lat": "45.71958",
    "lng": "9.55015"
  },
  {
    "country": "IT",
    "name": "Aviatico",
    "lat": "45.79758",
    "lng": "9.77145"
  },
  {
    "country": "IT",
    "name": "Barbata",
    "lat": "45.47498",
    "lng": "9.77736"
  },
  {
    "country": "IT",
    "name": "Bianzano",
    "lat": "45.77309",
    "lng": "9.91816"
  },
  {
    "country": "IT",
    "name": "Boltiere",
    "lat": "45.60088",
    "lng": "9.57845"
  },
  {
    "country": "IT",
    "name": "Bonate Sotto",
    "lat": "45.66818",
    "lng": "9.55865"
  },
  {
    "country": "IT",
    "name": "Bossico",
    "lat": "45.82839",
    "lng": "10.04506"
  },
  {
    "country": "IT",
    "name": "Chignolo d'Isola",
    "lat": "45.66758",
    "lng": "9.52765"
  },
  {
    "country": "IT",
    "name": "Colzate",
    "lat": "45.81719",
    "lng": "9.85615"
  },
  {
    "country": "IT",
    "name": "Corna Imagna",
    "lat": "45.83068",
    "lng": "9.54485"
  },
  {
    "country": "IT",
    "name": "Entratico",
    "lat": "45.70778",
    "lng": "9.87316"
  },
  {
    "country": "IT",
    "name": "Filago",
    "lat": "45.63758",
    "lng": "9.55635"
  },
  {
    "country": "IT",
    "name": "Fiorano al Serio",
    "lat": "45.80018",
    "lng": "9.84276"
  },
  {
    "country": "IT",
    "name": "Fonteno",
    "lat": "45.75859",
    "lng": "10.01856"
  },
  {
    "country": "IT",
    "name": "Fuipiano Valle Imagna",
    "lat": "45.85428",
    "lng": "9.52845"
  },
  {
    "country": "IT",
    "name": "Gandellino",
    "lat": "45.99109",
    "lng": "9.94615"
  },
  {
    "country": "IT",
    "name": "Gaverina Terme",
    "lat": "45.75578",
    "lng": "9.88666"
  },
  {
    "country": "IT",
    "name": "Gorlago",
    "lat": "45.67408",
    "lng": "9.82296"
  },
  {
    "country": "IT",
    "name": "Madone",
    "lat": "45.65028",
    "lng": "9.55015"
  },
  {
    "country": "IT",
    "name": "Premolo",
    "lat": "45.87019",
    "lng": "9.87466"
  },
  {
    "country": "IT",
    "name": "Presezzo",
    "lat": "45.69208",
    "lng": "9.57035"
  },
  {
    "country": "IT",
    "name": "Riva di Solto",
    "lat": "45.77418",
    "lng": "10.03941"
  },
  {
    "country": "IT",
    "name": "Castelcovati",
    "lat": "45.50198",
    "lng": "9.94596"
  },
  {
    "country": "IT",
    "name": "Borgo San Siro",
    "lat": "45.23506",
    "lng": "8.91334"
  },
  {
    "country": "IT",
    "name": "Castana",
    "lat": "45.02676",
    "lng": "9.27246"
  },
  {
    "country": "IT",
    "name": "Chignolo Po",
    "lat": "45.14817",
    "lng": "9.48156"
  },
  {
    "country": "IT",
    "name": "Costa de' Nobili",
    "lat": "45.13217",
    "lng": "9.37886"
  },
  {
    "country": "IT",
    "name": "Frascarolo",
    "lat": "45.04666",
    "lng": "8.68204"
  },
  {
    "country": "IT",
    "name": "Golferenzo",
    "lat": "44.96106",
    "lng": "9.30596"
  },
  {
    "country": "IT",
    "name": "Magherno",
    "lat": "45.22357",
    "lng": "9.32935"
  },
  {
    "country": "IT",
    "name": "Marcignago",
    "lat": "45.25306",
    "lng": "9.07935"
  },
  {
    "country": "IT",
    "name": "Marzano",
    "lat": "45.24797",
    "lng": "9.29505"
  },
  {
    "country": "IT",
    "name": "Campagnola Cremasca",
    "lat": "45.39847",
    "lng": "9.66946"
  },
  {
    "country": "IT",
    "name": "Casaletto Vaprio",
    "lat": "45.40817",
    "lng": "9.62876"
  },
  {
    "country": "IT",
    "name": "Cella Dati",
    "lat": "45.09527",
    "lng": "10.22148"
  },
  {
    "country": "IT",
    "name": "Derovere",
    "lat": "45.10997",
    "lng": "10.24798"
  },
  {
    "country": "IT",
    "name": "Drizzona",
    "lat": "45.14217",
    "lng": "10.35028"
  },
  {
    "country": "IT",
    "name": "Malagnino",
    "lat": "45.13477",
    "lng": "10.11477"
  },
  {
    "country": "IT",
    "name": "Spinadesco",
    "lat": "45.14917",
    "lng": "9.92637"
  },
  {
    "country": "IT",
    "name": "Castelbelforte",
    "lat": "45.21208",
    "lng": "10.89249"
  },
  {
    "country": "IT",
    "name": "Motteggiana",
    "lat": "45.03307",
    "lng": "10.76269"
  },
  {
    "country": "IT",
    "name": "Cunevo",
    "lat": "46.28641",
    "lng": "11.03457"
  },
  {
    "country": "IT",
    "name": "Daiano",
    "lat": "46.30161",
    "lng": "11.44908"
  },
  {
    "country": "IT",
    "name": "Dorsino",
    "lat": "46.0727",
    "lng": "10.89737"
  },
  {
    "country": "IT",
    "name": "Isera",
    "lat": "45.8876",
    "lng": "11.00918"
  },
  {
    "country": "IT",
    "name": "Ronchi Valsugana",
    "lat": "46.06841",
    "lng": "11.43519"
  },
  {
    "country": "IT",
    "name": "Rivoli Veronese",
    "lat": "45.57249",
    "lng": "10.81178"
  },
  {
    "country": "IT",
    "name": "Selva di Progno",
    "lat": "45.61139",
    "lng": "11.13799"
  },
  {
    "country": "IT",
    "name": "Alonte",
    "lat": "45.36589",
    "lng": "11.4271"
  },
  {
    "country": "IT",
    "name": "Altissimo",
    "lat": "45.61429",
    "lng": "11.25189"
  },
  {
    "country": "IT",
    "name": "Asigliano Veneto",
    "lat": "45.30469",
    "lng": "11.4464"
  },
  {
    "country": "IT",
    "name": "Brogliano",
    "lat": "45.58919",
    "lng": "11.36549"
  },
  {
    "country": "IT",
    "name": "Campolongo sul Brenta",
    "lat": "45.8271",
    "lng": "11.7008"
  },
  {
    "country": "IT",
    "name": "Carrè",
    "lat": "45.7488",
    "lng": "11.45779"
  },
  {
    "country": "IT",
    "name": "Enego",
    "lat": "45.94161",
    "lng": "11.7055"
  },
  {
    "country": "IT",
    "name": "Mason Vicentino",
    "lat": "45.7186",
    "lng": "11.6068"
  },
  {
    "country": "IT",
    "name": "Montecchio Precalcino",
    "lat": "45.6657",
    "lng": "11.5636"
  },
  {
    "country": "IT",
    "name": "Montegalda",
    "lat": "45.44609",
    "lng": "11.675"
  },
  {
    "country": "IT",
    "name": "Mossano",
    "lat": "45.41951",
    "lng": "11.55382"
  },
  {
    "country": "IT",
    "name": "Mussolente",
    "lat": "45.7792",
    "lng": "11.8062"
  },
  {
    "country": "IT",
    "name": "Pove del Grappa",
    "lat": "45.7982",
    "lng": "11.7299"
  },
  {
    "country": "IT",
    "name": "Sarego",
    "lat": "45.40769",
    "lng": "11.4019"
  },
  {
    "country": "IT",
    "name": "Alano di Piave",
    "lat": "45.90681",
    "lng": "11.9084"
  },
  {
    "country": "IT",
    "name": "Altivole",
    "lat": "45.7537",
    "lng": "11.9562"
  },
  {
    "country": "IT",
    "name": "Segusino",
    "lat": "45.91701",
    "lng": "11.9556"
  },
  {
    "country": "IT",
    "name": "Cartura",
    "lat": "45.26839",
    "lng": "11.85681"
  },
  {
    "country": "IT",
    "name": "Urbana",
    "lat": "45.19278",
    "lng": "11.4449"
  },
  {
    "country": "IT",
    "name": "Vighizzolo d'Este",
    "lat": "45.17629",
    "lng": "11.62471"
  },
  {
    "country": "IT",
    "name": "Villafranca Padovana",
    "lat": "45.49189",
    "lng": "11.7935"
  },
  {
    "country": "IT",
    "name": "Arquà Polesine",
    "lat": "45.01008",
    "lng": "11.73981"
  },
  {
    "country": "IT",
    "name": "Castelnovo Bariano",
    "lat": "45.02738",
    "lng": "11.2876"
  },
  {
    "country": "IT",
    "name": "Frassinelle Polesine",
    "lat": "44.99518",
    "lng": "11.69881"
  },
  {
    "country": "IT",
    "name": "Solignano",
    "lat": "44.61306",
    "lng": "9.97548"
  },
  {
    "country": "IT",
    "name": "Capolona",
    "lat": "43.56685",
    "lng": "11.86374"
  },
  {
    "country": "IT",
    "name": "Montecreto",
    "lat": "44.24596",
    "lng": "10.7176"
  },
  {
    "country": "IT",
    "name": "San Prospero",
    "lat": "44.78967",
    "lng": "11.0221"
  },
  {
    "country": "IT",
    "name": "Voghiera",
    "lat": "44.75558",
    "lng": "11.75182"
  },
  {
    "country": "IT",
    "name": "Ragoli",
    "lat": "46.05423",
    "lng": "10.77855"
  },
  {
    "country": "IT",
    "name": "Barchi",
    "lat": "43.6728",
    "lng": "12.92823"
  },
  {
    "country": "IT",
    "name": "Casteldelci",
    "lat": "43.79116",
    "lng": "12.15514"
  },
  {
    "country": "IT",
    "name": "Montefelcino",
    "lat": "43.73476",
    "lng": "12.83396"
  },
  {
    "country": "IT",
    "name": "Gualdo",
    "lat": "43.06585",
    "lng": "13.34328"
  },
  {
    "country": "IT",
    "name": "Maltignano",
    "lat": "42.83225",
    "lng": "13.68799"
  },
  {
    "country": "IT",
    "name": "Monte Vidon Combatte",
    "lat": "43.04895",
    "lng": "13.63119"
  },
  {
    "country": "IT",
    "name": "Smerillo",
    "lat": "43.00515",
    "lng": "13.44498"
  },
  {
    "country": "IT",
    "name": "Comano",
    "lat": "44.29335",
    "lng": "10.13109"
  },
  {
    "country": "IT",
    "name": "Giuncugnano",
    "lat": "44.21055",
    "lng": "10.24719"
  },
  {
    "country": "IT",
    "name": "Montescudaio",
    "lat": "43.32603",
    "lng": "10.62602"
  },
  {
    "country": "IT",
    "name": "Valtopina",
    "lat": "43.05674",
    "lng": "12.75307"
  },
  {
    "country": "IT",
    "name": "Arcinazzo Romano",
    "lat": "41.87972",
    "lng": "13.11439"
  },
  {
    "country": "IT",
    "name": "Canterano",
    "lat": "41.94322",
    "lng": "13.03809"
  },
  {
    "country": "IT",
    "name": "Jenne",
    "lat": "41.88882",
    "lng": "13.16959"
  },
  {
    "country": "IT",
    "name": "Montelibretti",
    "lat": "42.13553",
    "lng": "12.73868"
  },
  {
    "country": "IT",
    "name": "Ponzano Romano",
    "lat": "42.25693",
    "lng": "12.57047"
  },
  {
    "country": "IT",
    "name": "Rocca Canterano",
    "lat": "41.95652",
    "lng": "13.02179"
  },
  {
    "country": "IT",
    "name": "Rocca Santo Stefano",
    "lat": "41.91052",
    "lng": "13.02379"
  },
  {
    "country": "IT",
    "name": "Roccagorga",
    "lat": "41.52511",
    "lng": "13.1551"
  },
  {
    "country": "IT",
    "name": "Coreno Ausonio",
    "lat": "41.34735",
    "lng": "13.77648"
  },
  {
    "country": "IT",
    "name": "Bairo",
    "lat": "45.38606",
    "lng": "7.75532"
  },
  {
    "country": "IT",
    "name": "Baldissero Canavese",
    "lat": "45.41026",
    "lng": "7.74422"
  },
  {
    "country": "IT",
    "name": "Angrogna",
    "lat": "44.84354",
    "lng": "7.22422"
  },
  {
    "country": "IT",
    "name": "Rivalta Bormida",
    "lat": "44.70975",
    "lng": "8.55175"
  },
  {
    "country": "IT",
    "name": "Rivarone",
    "lat": "44.97686",
    "lng": "8.71565"
  },
  {
    "country": "IT",
    "name": "Rocca Grimalda",
    "lat": "44.67145",
    "lng": "8.64845"
  },
  {
    "country": "IT",
    "name": "Spineto Scrivia",
    "lat": "44.83735",
    "lng": "8.87375"
  },
  {
    "country": "IT",
    "name": "Tagliolo Monferrato",
    "lat": "44.63835",
    "lng": "8.66585"
  },
  {
    "country": "IT",
    "name": "Tassarolo",
    "lat": "44.72811",
    "lng": "8.77164"
  },
  {
    "country": "IT",
    "name": "Terzo",
    "lat": "44.67045",
    "lng": "8.42164"
  },
  {
    "country": "IT",
    "name": "Vignole Borbera",
    "lat": "44.70819",
    "lng": "8.89026"
  },
  {
    "country": "IT",
    "name": "Villadeati",
    "lat": "45.07225",
    "lng": "8.16793"
  },
  {
    "country": "IT",
    "name": "Villamiroglio",
    "lat": "45.13455",
    "lng": "8.17103"
  },
  {
    "country": "IT",
    "name": "Villaromagnano",
    "lat": "44.84965",
    "lng": "8.88775"
  },
  {
    "country": "IT",
    "name": "Visone",
    "lat": "44.66184",
    "lng": "8.50075"
  },
  {
    "country": "IT",
    "name": "Volpeglino",
    "lat": "44.89296",
    "lng": "8.95945"
  },
  {
    "country": "IT",
    "name": "Allein",
    "lat": "45.80723",
    "lng": "7.27262"
  },
  {
    "country": "IT",
    "name": "Avise",
    "lat": "45.70886",
    "lng": "7.1399"
  },
  {
    "country": "IT",
    "name": "Donnas",
    "lat": "45.60286",
    "lng": "7.77491"
  },
  {
    "country": "IT",
    "name": "Doues",
    "lat": "45.81916",
    "lng": "7.306"
  },
  {
    "country": "IT",
    "name": "Gignod",
    "lat": "45.77996",
    "lng": "7.2964"
  },
  {
    "country": "IT",
    "name": "Jovencan",
    "lat": "45.71486",
    "lng": "7.2726"
  },
  {
    "country": "IT",
    "name": "Nus",
    "lat": "45.74026",
    "lng": "7.4666"
  },
  {
    "country": "IT",
    "name": "Ollomont",
    "lat": "45.84976",
    "lng": "7.3106"
  },
  {
    "country": "IT",
    "name": "Perloz",
    "lat": "45.61386",
    "lng": "7.80811"
  },
  {
    "country": "IT",
    "name": "Pont-Bozet",
    "lat": "45.60726",
    "lng": "7.68641"
  },
  {
    "country": "IT",
    "name": "Valgrisenche",
    "lat": "45.63036",
    "lng": "7.064"
  },
  {
    "country": "IT",
    "name": "Villeneuve",
    "lat": "45.70201",
    "lng": "7.20682"
  },
  {
    "country": "IT",
    "name": "Armo",
    "lat": "44.08773",
    "lng": "7.91545"
  },
  {
    "country": "IT",
    "name": "Boissano",
    "lat": "44.13583",
    "lng": "8.22155"
  },
  {
    "country": "IT",
    "name": "Calice Ligure",
    "lat": "44.20493",
    "lng": "8.29535"
  },
  {
    "country": "IT",
    "name": "Casanova Lerrone",
    "lat": "44.03213",
    "lng": "8.04715"
  },
  {
    "country": "IT",
    "name": "Castelvecchio di Rocca Barbena",
    "lat": "44.12983",
    "lng": "8.11665"
  },
  {
    "country": "IT",
    "name": "Massimino",
    "lat": "44.29953",
    "lng": "8.07134"
  },
  {
    "country": "IT",
    "name": "Tovo San Giacomo",
    "lat": "44.17593",
    "lng": "8.27045"
  },
  {
    "country": "IT",
    "name": "Mele",
    "lat": "44.44573",
    "lng": "8.74889"
  },
  {
    "country": "IT",
    "name": "Savignone",
    "lat": "44.56435",
    "lng": "8.98726"
  },
  {
    "country": "IT",
    "name": "Bardello",
    "lat": "45.83597",
    "lng": "8.69683"
  },
  {
    "country": "IT",
    "name": "Bisuschio",
    "lat": "45.87148",
    "lng": "8.86843"
  },
  {
    "country": "IT",
    "name": "Bregano",
    "lat": "45.82578",
    "lng": "8.68773"
  },
  {
    "country": "IT",
    "name": "Brunello",
    "lat": "45.76497",
    "lng": "8.79533"
  },
  {
    "country": "IT",
    "name": "Buguggiate",
    "lat": "45.78227",
    "lng": "8.81063"
  },
  {
    "country": "IT",
    "name": "Cadrezzate",
    "lat": "45.79927",
    "lng": "8.64333"
  },
  {
    "country": "IT",
    "name": "Cantello",
    "lat": "45.82248",
    "lng": "8.89593"
  },
  {
    "country": "IT",
    "name": "Casale Litta",
    "lat": "45.76787",
    "lng": "8.74133"
  },
  {
    "country": "IT",
    "name": "Cazzago Brabbia",
    "lat": "45.79588",
    "lng": "8.73483"
  },
  {
    "country": "IT",
    "name": "Cremenaga",
    "lat": "45.98938",
    "lng": "8.80333"
  },
  {
    "country": "IT",
    "name": "Crosio della Valle",
    "lat": "45.75997",
    "lng": "8.77043"
  },
  {
    "country": "IT",
    "name": "Cuveglio",
    "lat": "45.90608",
    "lng": "8.73333"
  },
  {
    "country": "IT",
    "name": "Cuvio",
    "lat": "45.89618",
    "lng": "8.73413"
  },
  {
    "country": "IT",
    "name": "Ferrera di Varese",
    "lat": "45.93278",
    "lng": "8.78913"
  },
  {
    "country": "IT",
    "name": "Galliate Lombardo",
    "lat": "45.78487",
    "lng": "8.77043"
  },
  {
    "country": "IT",
    "name": "Germignaga",
    "lat": "45.99128",
    "lng": "8.72403"
  },
  {
    "country": "IT",
    "name": "Grantola",
    "lat": "45.94918",
    "lng": "8.77433"
  },
  {
    "country": "IT",
    "name": "Inarzo",
    "lat": "45.78578",
    "lng": "8.73563"
  },
  {
    "country": "IT",
    "name": "Luvinate",
    "lat": "45.83958",
    "lng": "8.77193"
  },
  {
    "country": "IT",
    "name": "Marchirolo",
    "lat": "45.94788",
    "lng": "8.83343"
  },
  {
    "country": "IT",
    "name": "Monvalle",
    "lat": "45.8581",
    "lng": "8.63088"
  },
  {
    "country": "IT",
    "name": "Morazzone",
    "lat": "45.76447",
    "lng": "8.82813"
  },
  {
    "country": "IT",
    "name": "Sangiano",
    "lat": "45.87508",
    "lng": "8.63333"
  },
  {
    "country": "IT",
    "name": "Albiolo",
    "lat": "45.80558",
    "lng": "8.93924"
  },
  {
    "country": "IT",
    "name": "Alzate Brianza",
    "lat": "45.76978",
    "lng": "9.18204"
  },
  {
    "country": "IT",
    "name": "Capiago-Intimiano-Olmeda",
    "lat": "45.76898",
    "lng": "9.12764"
  },
  {
    "country": "IT",
    "name": "Carugo",
    "lat": "45.70848",
    "lng": "9.19684"
  },
  {
    "country": "IT",
    "name": "Cassina Rizzardi",
    "lat": "45.75228",
    "lng": "9.02454"
  },
  {
    "country": "IT",
    "name": "Castelmarte",
    "lat": "45.83238",
    "lng": "9.23304"
  },
  {
    "country": "IT",
    "name": "Cerano d'Intelvi",
    "lat": "45.94447",
    "lng": "9.08767"
  },
  {
    "country": "IT",
    "name": "Colonno",
    "lat": "45.95768",
    "lng": "9.15294"
  },
  {
    "country": "IT",
    "name": "Cucciago",
    "lat": "45.73928",
    "lng": "9.09294"
  },
  {
    "country": "IT",
    "name": "Cusino",
    "lat": "46.07489",
    "lng": "9.15264"
  },
  {
    "country": "IT",
    "name": "Dosso del Liro",
    "lat": "46.16399",
    "lng": "9.27294"
  },
  {
    "country": "IT",
    "name": "Figino Serenza",
    "lat": "45.71048",
    "lng": "9.13114"
  },
  {
    "country": "IT",
    "name": "Guanzate",
    "lat": "45.72758",
    "lng": "9.01984"
  },
  {
    "country": "IT",
    "name": "Lambrugo",
    "lat": "45.75878",
    "lng": "9.23954"
  },
  {
    "country": "IT",
    "name": "Limido Comasco",
    "lat": "45.68917",
    "lng": "8.97984"
  },
  {
    "country": "IT",
    "name": "Lipomo",
    "lat": "45.79288",
    "lng": "9.12024"
  },
  {
    "country": "IT",
    "name": "Longone al Segrino",
    "lat": "45.81428",
    "lng": "9.25144"
  },
  {
    "country": "IT",
    "name": "Luisago",
    "lat": "45.76288",
    "lng": "9.03544"
  },
  {
    "country": "IT",
    "name": "Magreglio",
    "lat": "45.92098",
    "lng": "9.26264"
  },
  {
    "country": "IT",
    "name": "Proserpio",
    "lat": "45.82828",
    "lng": "9.24554"
  },
  {
    "country": "IT",
    "name": "Mantello",
    "lat": "46.15249",
    "lng": "9.48894"
  },
  {
    "country": "IT",
    "name": "Montagna in Valtellina",
    "lat": "46.17849",
    "lng": "9.90295"
  },
  {
    "country": "IT",
    "name": "Ponte in Valtellina",
    "lat": "46.175",
    "lng": "9.97785"
  },
  {
    "country": "IT",
    "name": "San Giacomo Filippo",
    "lat": "46.33769",
    "lng": "9.37124"
  },
  {
    "country": "IT",
    "name": "Spriana",
    "lat": "46.2203",
    "lng": "9.86425"
  },
  {
    "country": "IT",
    "name": "Talamona",
    "lat": "46.13849",
    "lng": "9.61294"
  },
  {
    "country": "IT",
    "name": "Tartano",
    "lat": "46.10554",
    "lng": "9.67864"
  },
  {
    "country": "IT",
    "name": "Tovo di Sant'Agata",
    "lat": "46.24505",
    "lng": "10.2467"
  },
  {
    "country": "IT",
    "name": "Vervio",
    "lat": "46.25285",
    "lng": "10.24056"
  },
  {
    "country": "IT",
    "name": "Aicurzio",
    "lat": "45.63998",
    "lng": "9.41495"
  },
  {
    "country": "IT",
    "name": "Albairate",
    "lat": "45.41957",
    "lng": "8.93744"
  },
  {
    "country": "IT",
    "name": "Bellinzago Lombardo",
    "lat": "45.54207",
    "lng": "9.44595"
  },
  {
    "country": "IT",
    "name": "Bubbiano",
    "lat": "45.32727",
    "lng": "9.01455"
  },
  {
    "country": "IT",
    "name": "Burago di Molgora",
    "lat": "45.59648",
    "lng": "9.38165"
  },
  {
    "country": "IT",
    "name": "Busnago",
    "lat": "45.61648",
    "lng": "9.46375"
  },
  {
    "country": "IT",
    "name": "Grezzago",
    "lat": "45.59108",
    "lng": "9.49725"
  },
  {
    "country": "IT",
    "name": "Ronco Briantino",
    "lat": "45.66628",
    "lng": "9.40535"
  },
  {
    "country": "IT",
    "name": "San Giorgio Su Legnano",
    "lat": "45.57377",
    "lng": "8.91374"
  },
  {
    "country": "IT",
    "name": "Settala",
    "lat": "45.45357",
    "lng": "9.38715"
  },
  {
    "country": "IT",
    "name": "Sovico",
    "lat": "45.64598",
    "lng": "9.26275"
  },
  {
    "country": "IT",
    "name": "Vedano al Lambro",
    "lat": "45.60878",
    "lng": "9.26785"
  },
  {
    "country": "IT",
    "name": "Zelo Surrigone",
    "lat": "45.38767",
    "lng": "8.98504"
  },
  {
    "country": "IT",
    "name": "Adrara San Martino",
    "lat": "45.70228",
    "lng": "9.94896"
  },
  {
    "country": "IT",
    "name": "Arzago d'Adda",
    "lat": "45.48137",
    "lng": "9.56415"
  },
  {
    "country": "IT",
    "name": "Azzano San Paolo",
    "lat": "45.65798",
    "lng": "9.67305"
  },
  {
    "country": "IT",
    "name": "Bagnatica",
    "lat": "45.66088",
    "lng": "9.78106"
  },
  {
    "country": "IT",
    "name": "Bariano",
    "lat": "45.51258",
    "lng": "9.70366"
  },
  {
    "country": "IT",
    "name": "Berbenno",
    "lat": "45.81478",
    "lng": "9.57105"
  },
  {
    "country": "IT",
    "name": "Berzo San Fermo",
    "lat": "45.71938",
    "lng": "9.90316"
  },
  {
    "country": "IT",
    "name": "Bolgare",
    "lat": "45.63242",
    "lng": "9.81412"
  },
  {
    "country": "IT",
    "name": "Cavernago",
    "lat": "45.62528",
    "lng": "9.76556"
  },
  {
    "country": "IT",
    "name": "Chiuduno",
    "lat": "45.65068",
    "lng": "9.84946"
  },
  {
    "country": "IT",
    "name": "Cortenuova",
    "lat": "45.53898",
    "lng": "9.78786"
  },
  {
    "country": "IT",
    "name": "Credaro",
    "lat": "45.66058",
    "lng": "9.93106"
  },
  {
    "country": "IT",
    "name": "Dossena",
    "lat": "45.88029",
    "lng": "9.69675"
  },
  {
    "country": "IT",
    "name": "Fino del Monte",
    "lat": "45.89269",
    "lng": "9.99406"
  },
  {
    "country": "IT",
    "name": "Gandosso",
    "lat": "45.65888",
    "lng": "9.88886"
  },
  {
    "country": "IT",
    "name": "Grassobbio",
    "lat": "45.65688",
    "lng": "9.72565"
  },
  {
    "country": "IT",
    "name": "Grone",
    "lat": "45.72722",
    "lng": "9.90885"
  },
  {
    "country": "IT",
    "name": "Isso",
    "lat": "45.47678",
    "lng": "9.75866"
  },
  {
    "country": "IT",
    "name": "Levate",
    "lat": "45.62518",
    "lng": "9.62415"
  },
  {
    "country": "IT",
    "name": "Lurano",
    "lat": "45.56568",
    "lng": "9.64016"
  },
  {
    "country": "IT",
    "name": "Montello",
    "lat": "45.67208",
    "lng": "9.80566"
  },
  {
    "country": "IT",
    "name": "Morengo",
    "lat": "45.53148",
    "lng": "9.70586"
  },
  {
    "country": "IT",
    "name": "Mornico al Serio",
    "lat": "45.59138",
    "lng": "9.80926"
  },
  {
    "country": "IT",
    "name": "Ranzanico",
    "lat": "45.78839",
    "lng": "9.93506"
  },
  {
    "country": "IT",
    "name": "Rogno",
    "lat": "45.85659",
    "lng": "10.13216"
  },
  {
    "country": "IT",
    "name": "Roncobello",
    "lat": "45.95569",
    "lng": "9.75235"
  },
  {
    "country": "IT",
    "name": "Roncola",
    "lat": "45.76868",
    "lng": "9.56065"
  },
  {
    "country": "IT",
    "name": "Songavazzo",
    "lat": "45.87949",
    "lng": "9.98956"
  },
  {
    "country": "IT",
    "name": "Suisio",
    "lat": "45.65708",
    "lng": "9.50225"
  },
  {
    "country": "IT",
    "name": "Terno d'Isola",
    "lat": "45.68548",
    "lng": "9.53095"
  },
  {
    "country": "IT",
    "name": "Villa d'Adda",
    "lat": "45.71398",
    "lng": "9.46165"
  },
  {
    "country": "IT",
    "name": "Villa d'Ogna",
    "lat": "45.90469",
    "lng": "9.93085"
  },
  {
    "country": "IT",
    "name": "Barbariga",
    "lat": "45.40508",
    "lng": "10.05437"
  },
  {
    "country": "IT",
    "name": "Brandico",
    "lat": "45.45418",
    "lng": "10.05267"
  },
  {
    "country": "IT",
    "name": "Caino",
    "lat": "45.60939",
    "lng": "10.31317"
  },
  {
    "country": "IT",
    "name": "Calvagese della Riviera",
    "lat": "45.53922",
    "lng": "10.44605"
  },
  {
    "country": "IT",
    "name": "Capovalle",
    "lat": "45.75339",
    "lng": "10.54447"
  },
  {
    "country": "IT",
    "name": "Capriano del Colle",
    "lat": "45.47478",
    "lng": "10.13227"
  },
  {
    "country": "IT",
    "name": "Castrezzato",
    "lat": "45.51128",
    "lng": "9.98086"
  },
  {
    "country": "IT",
    "name": "Cellatica",
    "lat": "45.58198",
    "lng": "10.18017"
  },
  {
    "country": "IT",
    "name": "Corzano",
    "lat": "45.44378",
    "lng": "10.00737"
  },
  {
    "country": "IT",
    "name": "Gianico",
    "lat": "45.86559",
    "lng": "10.17486"
  },
  {
    "country": "IT",
    "name": "Maclodio",
    "lat": "45.47778",
    "lng": "10.04217"
  },
  {
    "country": "IT",
    "name": "Montirone",
    "lat": "45.44638",
    "lng": "10.22877"
  },
  {
    "country": "IT",
    "name": "Niardo",
    "lat": "45.97599",
    "lng": "10.33326"
  },
  {
    "country": "IT",
    "name": "Nuvolera",
    "lat": "45.53218",
    "lng": "10.36917"
  },
  {
    "country": "IT",
    "name": "Polaveno",
    "lat": "45.66148",
    "lng": "10.12396"
  },
  {
    "country": "IT",
    "name": "Pontoglio",
    "lat": "45.56938",
    "lng": "9.85346"
  },
  {
    "country": "IT",
    "name": "Roncadelle",
    "lat": "45.52718",
    "lng": "10.15407"
  },
  {
    "country": "IT",
    "name": "San Zeno Naviglio",
    "lat": "45.49258",
    "lng": "10.21847"
  },
  {
    "country": "IT",
    "name": "Trenzano",
    "lat": "45.47728",
    "lng": "10.01066"
  },
  {
    "country": "IT",
    "name": "Zone",
    "lat": "45.76339",
    "lng": "10.11586"
  },
  {
    "country": "IT",
    "name": "Battuda",
    "lat": "45.27466",
    "lng": "9.07805"
  },
  {
    "country": "IT",
    "name": "Borgarello",
    "lat": "45.24066",
    "lng": "9.14055"
  },
  {
    "country": "IT",
    "name": "Bosnasco",
    "lat": "45.064",
    "lng": "9.35692"
  },
  {
    "country": "IT",
    "name": "Casanova Lonati",
    "lat": "45.09446",
    "lng": "9.21345"
  },
  {
    "country": "IT",
    "name": "Castello d'Agogna",
    "lat": "45.23456",
    "lng": "8.68714"
  },
  {
    "country": "IT",
    "name": "Linarolo",
    "lat": "45.16236",
    "lng": "9.26995"
  },
  {
    "country": "IT",
    "name": "Lirio",
    "lat": "44.99446",
    "lng": "9.25656"
  },
  {
    "country": "IT",
    "name": "Monticelli Pavese",
    "lat": "45.11107",
    "lng": "9.51276"
  },
  {
    "country": "IT",
    "name": "Nicorvo",
    "lat": "45.28566",
    "lng": "8.66794"
  },
  {
    "country": "IT",
    "name": "Oliva Gessi",
    "lat": "45.00597",
    "lng": "9.17317"
  },
  {
    "country": "IT",
    "name": "Pinarolo Po",
    "lat": "45.06986",
    "lng": "9.16725"
  },
  {
    "country": "IT",
    "name": "Sommo",
    "lat": "45.13316",
    "lng": "9.08655"
  },
  {
    "country": "IT",
    "name": "Spessa",
    "lat": "45.11356",
    "lng": "9.34856"
  },
  {
    "country": "IT",
    "name": "Torre d'Arese",
    "lat": "45.24277",
    "lng": "9.31735"
  },
  {
    "country": "IT",
    "name": "Torrevecchia Pia",
    "lat": "45.28197",
    "lng": "9.29635"
  },
  {
    "country": "IT",
    "name": "Trivolzio",
    "lat": "45.25846",
    "lng": "9.04275"
  },
  {
    "country": "IT",
    "name": "Valle Salimbene",
    "lat": "45.17196",
    "lng": "9.23445"
  },
  {
    "country": "IT",
    "name": "Villa Biscossi",
    "lat": "45.09066",
    "lng": "8.78715"
  },
  {
    "country": "IT",
    "name": "Vistarino",
    "lat": "45.21077",
    "lng": "9.30825"
  },
  {
    "country": "IT",
    "name": "Bonemerse",
    "lat": "45.11367",
    "lng": "10.07747"
  },
  {
    "country": "IT",
    "name": "Ca' d'Andrea",
    "lat": "45.11957",
    "lng": "10.27748"
  },
  {
    "country": "IT",
    "name": "Casaletto di Sopra",
    "lat": "45.41918",
    "lng": "9.78256"
  },
  {
    "country": "IT",
    "name": "Castelvisconti",
    "lat": "45.30537",
    "lng": "9.94107"
  },
  {
    "country": "IT",
    "name": "Chieve",
    "lat": "45.34047",
    "lng": "9.61646"
  },
  {
    "country": "IT",
    "name": "Corte de' Frati",
    "lat": "45.21847",
    "lng": "10.10187"
  },
  {
    "country": "IT",
    "name": "Cremosano",
    "lat": "45.39467",
    "lng": "9.63826"
  },
  {
    "country": "IT",
    "name": "Fiesco",
    "lat": "45.33737",
    "lng": "9.77786"
  },
  {
    "country": "IT",
    "name": "Gombito",
    "lat": "45.26187",
    "lng": "9.72856"
  },
  {
    "country": "IT",
    "name": "Martignana di Po",
    "lat": "45.01107",
    "lng": "10.37978"
  },
  {
    "country": "IT",
    "name": "Monte Cremasco",
    "lat": "45.37224",
    "lng": "9.57288"
  },
  {
    "country": "IT",
    "name": "Pianengo",
    "lat": "45.40217",
    "lng": "9.69476"
  },
  {
    "country": "IT",
    "name": "Pieranica",
    "lat": "45.42617",
    "lng": "9.61026"
  },
  {
    "country": "IT",
    "name": "Quintano",
    "lat": "45.42047",
    "lng": "9.61856"
  },
  {
    "country": "IT",
    "name": "Ricengo",
    "lat": "45.40567",
    "lng": "9.72396"
  },
  {
    "country": "IT",
    "name": "Borgofranco sul Po",
    "lat": "45.04658",
    "lng": "11.2093"
  },
  {
    "country": "IT",
    "name": "Felonica",
    "lat": "44.97898",
    "lng": "11.3537"
  },
  {
    "country": "IT",
    "name": "Mariana Mantovana",
    "lat": "45.19288",
    "lng": "10.48688"
  },
  {
    "country": "IT",
    "name": "Schivenoglia",
    "lat": "44.99498",
    "lng": "11.073"
  },
  {
    "country": "IT",
    "name": "Villa Poma",
    "lat": "45.00238",
    "lng": "11.1145"
  },
  {
    "country": "IT",
    "name": "Amblar",
    "lat": "46.39541",
    "lng": "11.14677"
  },
  {
    "country": "IT",
    "name": "Bieno",
    "lat": "46.08151",
    "lng": "11.55609"
  },
  {
    "country": "IT",
    "name": "Bondo",
    "lat": "46.0003",
    "lng": "10.69197"
  },
  {
    "country": "IT",
    "name": "Bondone",
    "lat": "45.80649",
    "lng": "10.55027"
  },
  {
    "country": "IT",
    "name": "Calceranica al Lago",
    "lat": "46.0046",
    "lng": "11.24368"
  },
  {
    "country": "IT",
    "name": "Carano",
    "lat": "46.29151",
    "lng": "11.43978"
  },
  {
    "country": "IT",
    "name": "Carzano",
    "lat": "46.07091",
    "lng": "11.49379"
  },
  {
    "country": "IT",
    "name": "Cavedine",
    "lat": "45.9952",
    "lng": "10.97358"
  },
  {
    "country": "IT",
    "name": "Cavizzana",
    "lat": "46.36721",
    "lng": "10.95817"
  },
  {
    "country": "IT",
    "name": "Cis",
    "lat": "46.39841",
    "lng": "11.00327"
  },
  {
    "country": "IT",
    "name": "Don",
    "lat": "46.38931",
    "lng": "11.13647"
  },
  {
    "country": "IT",
    "name": "Faedo",
    "lat": "46.19241",
    "lng": "11.16128"
  },
  {
    "country": "IT",
    "name": "Faver",
    "lat": "46.18131",
    "lng": "11.23728"
  },
  {
    "country": "IT",
    "name": "Fornace",
    "lat": "46.11805",
    "lng": "11.20751"
  },
  {
    "country": "IT",
    "name": "Frassilongo",
    "lat": "46.08991",
    "lng": "11.29718"
  },
  {
    "country": "IT",
    "name": "Giustino",
    "lat": "46.1513",
    "lng": "10.76777"
  },
  {
    "country": "IT",
    "name": "Cantalupa",
    "lat": "44.94594",
    "lng": "7.33032"
  },
  {
    "country": "IT",
    "name": "Cercenasco",
    "lat": "44.86204",
    "lng": "7.49822"
  },
  {
    "country": "IT",
    "name": "Chiesanuova",
    "lat": "45.41745",
    "lng": "7.65552"
  },
  {
    "country": "IT",
    "name": "Chiusa di San Michele",
    "lat": "45.10424",
    "lng": "7.32711"
  },
  {
    "country": "IT",
    "name": "Ciconio",
    "lat": "45.33025",
    "lng": "7.75852"
  },
  {
    "country": "IT",
    "name": "Colleretto Castelnuovo",
    "lat": "45.42236",
    "lng": "7.67981"
  },
  {
    "country": "IT",
    "name": "Colleretto Giacosa",
    "lat": "45.43286",
    "lng": "7.79852"
  },
  {
    "country": "IT",
    "name": "Cossano Canavese",
    "lat": "45.38776",
    "lng": "7.99152"
  },
  {
    "country": "IT",
    "name": "Fiorano Canavese",
    "lat": "45.46776",
    "lng": "7.83372"
  },
  {
    "country": "IT",
    "name": "Givoletto",
    "lat": "45.16225",
    "lng": "7.49642"
  },
  {
    "country": "IT",
    "name": "Grosso",
    "lat": "45.25645",
    "lng": "7.55732"
  },
  {
    "country": "IT",
    "name": "Pratiglione",
    "lat": "45.35275",
    "lng": "7.59602"
  },
  {
    "country": "IT",
    "name": "Ribordone",
    "lat": "45.43255",
    "lng": "7.50231"
  },
  {
    "country": "IT",
    "name": "Salerano Canavese",
    "lat": "45.45806",
    "lng": "7.85112"
  },
  {
    "country": "IT",
    "name": "San Didero",
    "lat": "45.13544",
    "lng": "7.21301"
  },
  {
    "country": "IT",
    "name": "San Germano Chisone",
    "lat": "44.90204",
    "lng": "7.23662"
  },
  {
    "country": "IT",
    "name": "Pila",
    "lat": "45.76997",
    "lng": "8.08122"
  },
  {
    "country": "IT",
    "name": "Rossa",
    "lat": "45.83327",
    "lng": "8.12432"
  },
  {
    "country": "IT",
    "name": "Salasco",
    "lat": "45.32556",
    "lng": "8.26423"
  },
  {
    "country": "IT",
    "name": "Bogogno",
    "lat": "45.66307",
    "lng": "8.53473"
  },
  {
    "country": "IT",
    "name": "Briona",
    "lat": "45.54247",
    "lng": "8.47973"
  },
  {
    "country": "IT",
    "name": "Colazza",
    "lat": "45.79257",
    "lng": "8.50033"
  },
  {
    "country": "IT",
    "name": "Comignago",
    "lat": "45.71487",
    "lng": "8.56403"
  },
  {
    "country": "IT",
    "name": "Soriso",
    "lat": "45.74037",
    "lng": "8.40953"
  },
  {
    "country": "IT",
    "name": "Veruno",
    "lat": "45.68887",
    "lng": "8.52863"
  },
  {
    "country": "IT",
    "name": "Aisone",
    "lat": "44.31392",
    "lng": "7.21963"
  },
  {
    "country": "IT",
    "name": "Albaretto della Torre",
    "lat": "44.59624",
    "lng": "8.06464"
  },
  {
    "country": "IT",
    "name": "Succivo",
    "lat": "40.96801",
    "lng": "14.25563"
  },
  {
    "country": "IT",
    "name": "Pietraroja",
    "lat": "41.34782",
    "lng": "14.54963"
  },
  {
    "country": "IT",
    "name": "Sant'Angelo A Cupolo",
    "lat": "41.06912",
    "lng": "14.80374"
  },
  {
    "country": "IT",
    "name": "Casamicciola Terme",
    "lat": "40.74661",
    "lng": "13.91202"
  },
  {
    "country": "IT",
    "name": "Castello di Cisterna",
    "lat": "40.91594",
    "lng": "14.41117"
  },
  {
    "country": "IT",
    "name": "San Vitaliano",
    "lat": "40.92442",
    "lng": "14.47463"
  },
  {
    "country": "IT",
    "name": "Scisciano",
    "lat": "40.90663",
    "lng": "14.47451"
  },
  {
    "country": "IT",
    "name": "Cassano Irpino",
    "lat": "40.87042",
    "lng": "15.02595"
  },
  {
    "country": "IT",
    "name": "Cesinali",
    "lat": "40.89711",
    "lng": "14.82774"
  },
  {
    "country": "IT",
    "name": "Moschiano",
    "lat": "40.87311",
    "lng": "14.65594"
  },
  {
    "country": "IT",
    "name": "Sant'Angelo All'Esca",
    "lat": "41.00662",
    "lng": "14.99305"
  },
  {
    "country": "IT",
    "name": "Sperone",
    "lat": "40.95251",
    "lng": "14.60524"
  },
  {
    "country": "IT",
    "name": "Cagnano Amiterno",
    "lat": "42.45744",
    "lng": "13.22789"
  },
  {
    "country": "IT",
    "name": "Villa Sant'Angelo",
    "lat": "42.27043",
    "lng": "13.5371"
  },
  {
    "country": "IT",
    "name": "Liscia",
    "lat": "41.95524",
    "lng": "14.55532"
  },
  {
    "country": "IT",
    "name": "Tufara",
    "lat": "41.48203",
    "lng": "14.94654"
  },
  {
    "country": "IT",
    "name": "Castelluccio dei Sauri",
    "lat": "41.3046",
    "lng": "15.47561"
  },
  {
    "country": "IT",
    "name": "Binetto",
    "lat": "41.02343",
    "lng": "16.70988"
  },
  {
    "country": "IT",
    "name": "Poggiorsini",
    "lat": "40.91403",
    "lng": "16.25605"
  },
  {
    "country": "IT",
    "name": "Brienza",
    "lat": "40.47751",
    "lng": "15.62927"
  },
  {
    "country": "IT",
    "name": "Figline Vegliaturo",
    "lat": "39.22519",
    "lng": "16.3303"
  },
  {
    "country": "IT",
    "name": "Santa Maria del Cedro",
    "lat": "39.7462",
    "lng": "15.83638"
  },
  {
    "country": "IT",
    "name": "Amato",
    "lat": "38.94179",
    "lng": "16.4622"
  },
  {
    "country": "IT",
    "name": "Belcastro",
    "lat": "39.01799",
    "lng": "16.78641"
  },
  {
    "country": "IT",
    "name": "Feroleto Antico",
    "lat": "38.96239",
    "lng": "16.3878"
  },
  {
    "country": "IT",
    "name": "Jacurso",
    "lat": "38.84649",
    "lng": "16.3798"
  },
  {
    "country": "IT",
    "name": "Sellia Marina",
    "lat": "38.88599",
    "lng": "16.74931"
  },
  {
    "country": "IT",
    "name": "Bova",
    "lat": "37.99507",
    "lng": "15.9319"
  },
  {
    "country": "IT",
    "name": "Furnari",
    "lat": "38.10436",
    "lng": "15.12358"
  },
  {
    "country": "IT",
    "name": "Gualtieri Sicaminò",
    "lat": "38.16267",
    "lng": "15.31699"
  },
  {
    "country": "IT",
    "name": "Motta d'Affermo",
    "lat": "37.98096",
    "lng": "14.30337"
  },
  {
    "country": "IT",
    "name": "Roccafiorita",
    "lat": "37.93086",
    "lng": "15.26739"
  },
  {
    "country": "IT",
    "name": "Savoca",
    "lat": "37.95326",
    "lng": "15.34009"
  },
  {
    "country": "IT",
    "name": "Camporotondo Etneo",
    "lat": "37.56565",
    "lng": "15.00319"
  },
  {
    "country": "IT",
    "name": "San Pietro Clarenza",
    "lat": "37.56885",
    "lng": "15.02289"
  },
  {
    "country": "IT",
    "name": "Valverde",
    "lat": "37.57695",
    "lng": "15.12419"
  },
  {
    "country": "IT",
    "name": "Mazzarrone",
    "lat": "37.08834",
    "lng": "14.56128"
  },
  {
    "country": "IT",
    "name": "Ragalna",
    "lat": "37.63455",
    "lng": "14.94698"
  },
  {
    "country": "IT",
    "name": "Desulo",
    "lat": "40.01462",
    "lng": "9.23061"
  },
  {
    "country": "IT",
    "name": "Villaperuccio",
    "lat": "39.11183",
    "lng": "8.67004"
  },
  {
    "country": "IT",
    "name": "Villa Sant'Antonio",
    "lat": "39.85915",
    "lng": "8.90153"
  },
  {
    "country": "IT",
    "name": "Donato",
    "lat": "45.52626",
    "lng": "7.90962"
  },
  {
    "country": "IT",
    "name": "Magnano",
    "lat": "45.46336",
    "lng": "8.00302"
  },
  {
    "country": "IT",
    "name": "Piatto",
    "lat": "45.58986",
    "lng": "8.13532"
  },
  {
    "country": "IT",
    "name": "Ronco Biellese",
    "lat": "45.57846",
    "lng": "8.09072"
  },
  {
    "country": "IT",
    "name": "Sagliano Micca",
    "lat": "45.62576",
    "lng": "8.04332"
  },
  {
    "country": "IT",
    "name": "Sostegno",
    "lat": "45.65287",
    "lng": "8.26982"
  },
  {
    "country": "IT",
    "name": "Tavigliano",
    "lat": "45.62206",
    "lng": "8.05172"
  },
  {
    "country": "IT",
    "name": "Valdengo",
    "lat": "45.56706",
    "lng": "8.13832"
  },
  {
    "country": "IT",
    "name": "Villanova Biellese",
    "lat": "45.48156",
    "lng": "8.19432"
  },
  {
    "country": "IT",
    "name": "Bulciago",
    "lat": "45.75058",
    "lng": "9.28534"
  },
  {
    "country": "IT",
    "name": "Calco",
    "lat": "45.72418",
    "lng": "9.41255"
  },
  {
    "country": "IT",
    "name": "Cassago Brianza",
    "lat": "45.73808",
    "lng": "9.29344"
  },
  {
    "country": "IT",
    "name": "Civate",
    "lat": "45.82808",
    "lng": "9.34294"
  },
  {
    "country": "IT",
    "name": "Cortenova",
    "lat": "46.00029",
    "lng": "9.38454"
  },
  {
    "country": "IT",
    "name": "Costa Masnaga",
    "lat": "45.76963",
    "lng": "9.27632"
  },
  {
    "country": "IT",
    "name": "Erve",
    "lat": "45.82158",
    "lng": "9.45285"
  },
  {
    "country": "IT",
    "name": "Garlate",
    "lat": "45.81208",
    "lng": "9.39964"
  },
  {
    "country": "IT",
    "name": "Imbersago",
    "lat": "45.70588",
    "lng": "9.44445"
  },
  {
    "country": "IT",
    "name": "Parlasco",
    "lat": "46.01789",
    "lng": "9.34494"
  },
  {
    "country": "IT",
    "name": "Pasturo",
    "lat": "45.95168",
    "lng": "9.44414"
  },
  {
    "country": "IT",
    "name": "Perego",
    "lat": "45.73758",
    "lng": "9.36295"
  },
  {
    "country": "IT",
    "name": "Perledo",
    "lat": "46.01529",
    "lng": "9.2956"
  },
  {
    "country": "IT",
    "name": "Pescate",
    "lat": "45.83348",
    "lng": "9.39395"
  },
  {
    "country": "IT",
    "name": "Rogeno",
    "lat": "45.78238",
    "lng": "9.27404"
  },
  {
    "country": "IT",
    "name": "Santa Maria Hoè",
    "lat": "45.74428",
    "lng": "9.37445"
  },
  {
    "country": "IT",
    "name": "Sirtori",
    "lat": "45.73658",
    "lng": "9.33085"
  },
  {
    "country": "IT",
    "name": "Suello",
    "lat": "45.81678",
    "lng": "9.31154"
  },
  {
    "country": "IT",
    "name": "Valgreghentino",
    "lat": "45.77928",
    "lng": "9.41345"
  },
  {
    "country": "IT",
    "name": "Verderio Inferiore",
    "lat": "45.66558",
    "lng": "9.43345"
  },
  {
    "country": "IT",
    "name": "Verderio Superiore",
    "lat": "45.66778",
    "lng": "9.44035"
  },
  {
    "country": "IT",
    "name": "Casaletto Lodigiano",
    "lat": "45.29337",
    "lng": "9.36194"
  },
  {
    "country": "IT",
    "name": "Cervignano d'Adda",
    "lat": "45.37387",
    "lng": "9.42405"
  },
  {
    "country": "IT",
    "name": "Graffignana",
    "lat": "45.20647",
    "lng": "9.45436"
  },
  {
    "country": "IT",
    "name": "Mairago",
    "lat": "45.25177",
    "lng": "9.57836"
  },
  {
    "country": "IT",
    "name": "Ospedaletto Lodigiano",
    "lat": "45.16877",
    "lng": "9.57866"
  },
  {
    "country": "IT",
    "name": "Pieve Fissiraga",
    "lat": "45.26327",
    "lng": "9.45836"
  },
  {
    "country": "IT",
    "name": "San Martino in Strada",
    "lat": "45.27497",
    "lng": "9.52636"
  },
  {
    "country": "IT",
    "name": "Sordio",
    "lat": "45.34217",
    "lng": "9.36385"
  },
  {
    "country": "IT",
    "name": "Valera Fratta",
    "lat": "45.25717",
    "lng": "9.33615"
  },
  {
    "country": "IT",
    "name": "Villanova del Sillaro",
    "lat": "45.23797",
    "lng": "9.48186"
  },
  {
    "country": "IT",
    "name": "Montegridolfo",
    "lat": "43.85826",
    "lng": "12.68995"
  },
  {
    "country": "IT",
    "name": "Castelsilano",
    "lat": "39.2691",
    "lng": "16.76741"
  },
  {
    "country": "IT",
    "name": "Filandari",
    "lat": "38.61508",
    "lng": "16.0314"
  },
  {
    "country": "IT",
    "name": "Stefanaconi",
    "lat": "38.67788",
    "lng": "16.1242"
  },
  {
    "country": "IT",
    "name": "Arizzano",
    "lat": "45.95738",
    "lng": "8.58292"
  },
  {
    "country": "IT",
    "name": "Aurano",
    "lat": "46.00038",
    "lng": "8.58822"
  },
  {
    "country": "IT",
    "name": "Cambiasca",
    "lat": "45.96238",
    "lng": "8.54462"
  },
  {
    "country": "IT",
    "name": "Quarna Sotto",
    "lat": "45.86917",
    "lng": "8.36332"
  },
  {
    "country": "IT",
    "name": "Seppiana",
    "lat": "46.05828",
    "lng": "8.21661"
  },
  {
    "country": "IT",
    "name": "Vignone",
    "lat": "45.96118",
    "lng": "8.56372"
  },
  {
    "country": "IT",
    "name": "Villette",
    "lat": "46.13188",
    "lng": "8.53422"
  },
  {
    "country": "IT",
    "name": "Bibiana",
    "lat": "44.79894",
    "lng": "7.28822"
  },
  {
    "country": "IT",
    "name": "Bruzolo",
    "lat": "45.14093",
    "lng": "7.19463"
  },
  {
    "country": "IT",
    "name": "Cafasse",
    "lat": "45.24865",
    "lng": "7.51882"
  },
  {
    "country": "IT",
    "name": "Castagnole Piemonte",
    "lat": "44.89814",
    "lng": "7.56612"
  },
  {
    "country": "IT",
    "name": "Castiglione Torinese",
    "lat": "45.11905",
    "lng": "7.80712"
  },
  {
    "country": "IT",
    "name": "Chianocco",
    "lat": "45.14854",
    "lng": "7.16981"
  },
  {
    "country": "IT",
    "name": "Chiaverano",
    "lat": "45.49886",
    "lng": "7.90262"
  },
  {
    "country": "IT",
    "name": "Frossasco",
    "lat": "44.92176",
    "lng": "7.37125"
  },
  {
    "country": "IT",
    "name": "Garzigliana",
    "lat": "44.83724",
    "lng": "7.37442"
  },
  {
    "country": "IT",
    "name": "Giaglione",
    "lat": "45.13919",
    "lng": "7.01534"
  },
  {
    "country": "IT",
    "name": "Gravere",
    "lat": "45.12534",
    "lng": "7.01751"
  },
  {
    "country": "IT",
    "name": "Isolabella",
    "lat": "44.90645",
    "lng": "7.90903"
  },
  {
    "country": "IT",
    "name": "Issiglio",
    "lat": "45.44626",
    "lng": "7.75322"
  },
  {
    "country": "IT",
    "name": "La Cassa",
    "lat": "45.18035",
    "lng": "7.51632"
  },
  {
    "country": "IT",
    "name": "Levone",
    "lat": "45.31665",
    "lng": "7.60632"
  },
  {
    "country": "IT",
    "name": "Lugnacco",
    "lat": "45.44506",
    "lng": "7.78212"
  },
  {
    "country": "IT",
    "name": "Lusigliè",
    "lat": "45.31845",
    "lng": "7.76462"
  },
  {
    "country": "IT",
    "name": "Macello",
    "lat": "44.85114",
    "lng": "7.39802"
  },
  {
    "country": "IT",
    "name": "Mattie",
    "lat": "45.11814",
    "lng": "7.11511"
  },
  {
    "country": "IT",
    "name": "Meugliano",
    "lat": "45.49026",
    "lng": "7.77942"
  },
  {
    "country": "IT",
    "name": "Mombello di Torino",
    "lat": "45.04575",
    "lng": "7.92083"
  },
  {
    "country": "IT",
    "name": "Monastero di Lanzo",
    "lat": "45.30185",
    "lng": "7.43971"
  },
  {
    "country": "IT",
    "name": "Moncenisio",
    "lat": "45.20404",
    "lng": "6.98461"
  },
  {
    "country": "IT",
    "name": "Montaldo Torinese",
    "lat": "45.06535",
    "lng": "7.85023"
  },
  {
    "country": "IT",
    "name": "Pecco",
    "lat": "45.45206",
    "lng": "7.77742"
  },
  {
    "country": "IT",
    "name": "Perosa Canavese",
    "lat": "45.39706",
    "lng": "7.83082"
  },
  {
    "country": "IT",
    "name": "Pertusio",
    "lat": "45.35565",
    "lng": "7.64152"
  },
  {
    "country": "IT",
    "name": "Piobesi Torinese",
    "lat": "44.93294",
    "lng": "7.61012"
  },
  {
    "country": "IT",
    "name": "Piscina",
    "lat": "44.91874",
    "lng": "7.42532"
  },
  {
    "country": "IT",
    "name": "Piverone",
    "lat": "45.44557",
    "lng": "8.00745"
  },
  {
    "country": "IT",
    "name": "Porte",
    "lat": "44.88714",
    "lng": "7.26982"
  },
  {
    "country": "IT",
    "name": "Rivarossa",
    "lat": "45.24954",
    "lng": "7.71953"
  },
  {
    "country": "IT",
    "name": "Roletto",
    "lat": "44.92444",
    "lng": "7.33232"
  },
  {
    "country": "IT",
    "name": "Rorà",
    "lat": "44.79214",
    "lng": "7.19902"
  },
  {
    "country": "IT",
    "name": "Rosta",
    "lat": "45.06795",
    "lng": "7.46512"
  },
  {
    "country": "IT",
    "name": "Rueglio",
    "lat": "45.46826",
    "lng": "7.75462"
  },
  {
    "country": "IT",
    "name": "San Carlo Canavese",
    "lat": "45.24455",
    "lng": "7.60572"
  },
  {
    "country": "IT",
    "name": "San Colombano Belmonte",
    "lat": "45.38225",
    "lng": "7.62101"
  },
  {
    "country": "IT",
    "name": "Strambinello",
    "lat": "45.42306",
    "lng": "7.76992"
  },
  {
    "country": "IT",
    "name": "Usseaux",
    "lat": "45.04894",
    "lng": "7.02851"
  },
  {
    "country": "IT",
    "name": "Vallo Torinese",
    "lat": "45.22355",
    "lng": "7.49632"
  },
  {
    "country": "IT",
    "name": "Villanova Canavese",
    "lat": "45.24355",
    "lng": "7.55212"
  },
  {
    "country": "IT",
    "name": "Vische",
    "lat": "45.33566",
    "lng": "7.94482"
  },
  {
    "country": "IT",
    "name": "Asigliano Vercellese",
    "lat": "45.26146",
    "lng": "8.40853"
  },
  {
    "country": "IT",
    "name": "Caresanablot",
    "lat": "45.35736",
    "lng": "8.39203"
  },
  {
    "country": "IT",
    "name": "San Giacomo Vercellese",
    "lat": "45.49816",
    "lng": "8.32673"
  },
  {
    "country": "IT",
    "name": "Cervatto",
    "lat": "45.88297",
    "lng": "8.16232"
  },
  {
    "country": "IT",
    "name": "Rassa",
    "lat": "45.76821",
    "lng": "8.01208"
  },
  {
    "country": "IT",
    "name": "Riva Valdobbia",
    "lat": "45.83097",
    "lng": "7.95661"
  },
  {
    "country": "IT",
    "name": "Scopa",
    "lat": "45.79297",
    "lng": "8.11402"
  },
  {
    "country": "IT",
    "name": "Vocca",
    "lat": "45.83269",
    "lng": "8.1958"
  },
  {
    "country": "IT",
    "name": "Barengo",
    "lat": "45.57597",
    "lng": "8.51403"
  },
  {
    "country": "IT",
    "name": "Boca",
    "lat": "45.67897",
    "lng": "8.40873"
  },
  {
    "country": "IT",
    "name": "Casalbeltrame",
    "lat": "45.43806",
    "lng": "8.46653"
  },
  {
    "country": "IT",
    "name": "Cavaglietto",
    "lat": "45.60217",
    "lng": "8.50213"
  },
  {
    "country": "IT",
    "name": "Cavaglio D'Agogna",
    "lat": "45.61317",
    "lng": "8.48613"
  },
  {
    "country": "IT",
    "name": "Cureggio",
    "lat": "45.67487",
    "lng": "8.45973"
  },
  {
    "country": "IT",
    "name": "Dormelletto",
    "lat": "45.73627",
    "lng": "8.56663"
  },
  {
    "country": "IT",
    "name": "Gargallo",
    "lat": "45.72877",
    "lng": "8.42533"
  },
  {
    "country": "IT",
    "name": "Maggiora",
    "lat": "45.68937",
    "lng": "8.42233"
  },
  {
    "country": "IT",
    "name": "Mandello Vitta",
    "lat": "45.49567",
    "lng": "8.45983"
  },
  {
    "country": "IT",
    "name": "Miasino",
    "lat": "45.80197",
    "lng": "8.42972"
  },
  {
    "country": "IT",
    "name": "Nibbiola",
    "lat": "45.37236",
    "lng": "8.65674"
  },
  {
    "country": "IT",
    "name": "Pisano",
    "lat": "45.79567",
    "lng": "8.51487"
  },
  {
    "country": "IT",
    "name": "Alto",
    "lat": "44.10863",
    "lng": "8.00215"
  },
  {
    "country": "IT",
    "name": "Baldissero d'Alba",
    "lat": "44.76184",
    "lng": "7.90863"
  },
  {
    "country": "IT",
    "name": "Barolo",
    "lat": "44.61094",
    "lng": "7.94284"
  },
  {
    "country": "IT",
    "name": "Battifollo",
    "lat": "44.31983",
    "lng": "8.01094"
  },
  {
    "country": "IT",
    "name": "Canosio",
    "lat": "44.45583",
    "lng": "7.08272"
  },
  {
    "country": "IT",
    "name": "Castelletto Stura",
    "lat": "44.44383",
    "lng": "7.63923"
  },
  {
    "country": "IT",
    "name": "Castelnuovo di Ceva",
    "lat": "44.35363",
    "lng": "8.12894"
  },
  {
    "country": "IT",
    "name": "Cavallerleone",
    "lat": "44.74014",
    "lng": "7.66393"
  },
  {
    "country": "IT",
    "name": "Cerreto Langhe",
    "lat": "44.57484",
    "lng": "8.09794"
  },
  {
    "country": "IT",
    "name": "Cervasca",
    "lat": "44.38093",
    "lng": "7.47123"
  },
  {
    "country": "IT",
    "name": "Clavesana",
    "lat": "44.48334",
    "lng": "7.91084"
  },
  {
    "country": "IT",
    "name": "Cossano Belbo",
    "lat": "44.66884",
    "lng": "8.19864"
  },
  {
    "country": "IT",
    "name": "Farigliano",
    "lat": "44.51204",
    "lng": "7.91424"
  },
  {
    "country": "IT",
    "name": "Frabosa Sottana",
    "lat": "44.30233",
    "lng": "7.79754"
  },
  {
    "country": "IT",
    "name": "Guarene",
    "lat": "44.74004",
    "lng": "8.03514"
  },
  {
    "country": "IT",
    "name": "Igliano",
    "lat": "44.44294",
    "lng": "8.01334"
  },
  {
    "country": "IT",
    "name": "Lagnasco",
    "lat": "44.62504",
    "lng": "7.55483"
  },
  {
    "country": "IT",
    "name": "Lequio Berria",
    "lat": "44.60584",
    "lng": "8.09814"
  },
  {
    "country": "IT",
    "name": "Macra",
    "lat": "44.50013",
    "lng": "7.17952"
  },
  {
    "country": "IT",
    "name": "Marmora",
    "lat": "44.45833",
    "lng": "7.09402"
  },
  {
    "country": "IT",
    "name": "Marsaglia",
    "lat": "44.45284",
    "lng": "7.97994"
  },
  {
    "country": "IT",
    "name": "Monasterolo di Savigliano",
    "lat": "44.68634",
    "lng": "7.61953"
  },
  {
    "country": "IT",
    "name": "Montaldo Roero",
    "lat": "44.76834",
    "lng": "7.92483"
  },
  {
    "country": "IT",
    "name": "Montanera",
    "lat": "44.46223",
    "lng": "7.66563"
  },
  {
    "country": "IT",
    "name": "Neviglie",
    "lat": "44.69194",
    "lng": "8.11684"
  },
  {
    "country": "IT",
    "name": "Oncino",
    "lat": "44.67683",
    "lng": "7.19032"
  },
  {
    "country": "IT",
    "name": "Pagno",
    "lat": "44.61173",
    "lng": "7.42572"
  },
  {
    "country": "IT",
    "name": "Pezzolo Valle Uzzone",
    "lat": "44.53874",
    "lng": "8.19394"
  },
  {
    "country": "IT",
    "name": "Piozzo",
    "lat": "44.51384",
    "lng": "7.89254"
  },
  {
    "country": "IT",
    "name": "Priocca",
    "lat": "44.78624",
    "lng": "8.06424"
  },
  {
    "country": "IT",
    "name": "Prunetto",
    "lat": "44.48894",
    "lng": "8.14374"
  },
  {
    "country": "IT",
    "name": "Rifreddo",
    "lat": "44.65073",
    "lng": "7.34642"
  },
  {
    "country": "IT",
    "name": "Roaschia",
    "lat": "44.27023",
    "lng": "7.45573"
  },
  {
    "country": "IT",
    "name": "Roburent",
    "lat": "44.30633",
    "lng": "7.89224"
  },
  {
    "country": "IT",
    "name": "Rocca Cigliè",
    "lat": "44.44523",
    "lng": "7.95094"
  },
  {
    "country": "IT",
    "name": "Roccasparvera",
    "lat": "44.34213",
    "lng": "7.44153"
  },
  {
    "country": "IT",
    "name": "Sale San Giovanni",
    "lat": "44.39914",
    "lng": "8.07794"
  },
  {
    "country": "IT",
    "name": "Santo Stefano Roero",
    "lat": "44.78844",
    "lng": "7.94093"
  },
  {
    "country": "IT",
    "name": "Serralunga d'Alba",
    "lat": "44.61004",
    "lng": "7.99944"
  },
  {
    "country": "IT",
    "name": "Somano",
    "lat": "44.53534",
    "lng": "8.00784"
  },
  {
    "country": "IT",
    "name": "Torresina",
    "lat": "44.43364",
    "lng": "8.03674"
  },
  {
    "country": "IT",
    "name": "Treiso",
    "lat": "44.68974",
    "lng": "8.08814"
  },
  {
    "country": "IT",
    "name": "Trezzo Tinella",
    "lat": "44.67704",
    "lng": "8.10754"
  },
  {
    "country": "IT",
    "name": "Valmala",
    "lat": "44.54423",
    "lng": "7.34603"
  },
  {
    "country": "IT",
    "name": "Vicoforte",
    "lat": "44.36393",
    "lng": "7.86264"
  },
  {
    "country": "IT",
    "name": "Villanova Solaro",
    "lat": "44.72994",
    "lng": "7.57443"
  },
  {
    "country": "IT",
    "name": "Vottignasco",
    "lat": "44.56413",
    "lng": "7.57913"
  },
  {
    "country": "IT",
    "name": "Aramengo",
    "lat": "45.10085",
    "lng": "8.00003"
  },
  {
    "country": "IT",
    "name": "Azzano d'Asti",
    "lat": "44.87345",
    "lng": "8.26684"
  },
  {
    "country": "IT",
    "name": "Buttigliera d'Asti",
    "lat": "45.02175",
    "lng": "7.95103"
  },
  {
    "country": "IT",
    "name": "Calosso",
    "lat": "44.73994",
    "lng": "8.22714"
  },
  {
    "country": "IT",
    "name": "Castelnuovo Belbo",
    "lat": "44.8011",
    "lng": "8.41236"
  },
  {
    "country": "IT",
    "name": "Castel Rocchero",
    "lat": "44.71835",
    "lng": "8.41534"
  },
  {
    "country": "IT",
    "name": "Celle Enomondo",
    "lat": "44.85685",
    "lng": "8.12373"
  },
  {
    "country": "IT",
    "name": "Cerreto d'Asti",
    "lat": "45.05215",
    "lng": "8.03513"
  },
  {
    "country": "IT",
    "name": "Cerro Tanaro",
    "lat": "44.87335",
    "lng": "8.35874"
  },
  {
    "country": "IT",
    "name": "Chiusano d'Asti",
    "lat": "44.98665",
    "lng": "8.11853"
  },
  {
    "country": "IT",
    "name": "Frinco",
    "lat": "45.00405",
    "lng": "8.17193"
  },
  {
    "country": "IT",
    "name": "Grana",
    "lat": "44.99835",
    "lng": "8.29944"
  },
  {
    "country": "IT",
    "name": "Loazzolo",
    "lat": "44.66904",
    "lng": "8.25844"
  },
  {
    "country": "IT",
    "name": "Moasca",
    "lat": "44.76355",
    "lng": "8.27834"
  },
  {
    "country": "IT",
    "name": "Moransengo",
    "lat": "45.11485",
    "lng": "8.02523"
  },
  {
    "country": "IT",
    "name": "Olmo Gentile",
    "lat": "44.58574",
    "lng": "8.24694"
  },
  {
    "country": "IT",
    "name": "Penango",
    "lat": "45.03295",
    "lng": "8.25174"
  },
  {
    "country": "IT",
    "name": "Pino d'Asti",
    "lat": "45.05745",
    "lng": "7.98623"
  },
  {
    "country": "IT",
    "name": "Portacomaro",
    "lat": "44.95665",
    "lng": "8.25804"
  },
  {
    "country": "IT",
    "name": "Revigliasco d'Asti",
    "lat": "44.85755",
    "lng": "8.16044"
  },
  {
    "country": "IT",
    "name": "Roccaverano",
    "lat": "44.59224",
    "lng": "8.27214"
  },
  {
    "country": "IT",
    "name": "Rocchetta Palafea",
    "lat": "44.70744",
    "lng": "8.34534"
  },
  {
    "country": "IT",
    "name": "Rocchetta Tanaro",
    "lat": "44.85865",
    "lng": "8.34564"
  },
  {
    "country": "IT",
    "name": "San Giorgio Scarampi",
    "lat": "44.61094",
    "lng": "8.24244"
  },
  {
    "country": "IT",
    "name": "San Marzano Oliveto",
    "lat": "44.75445",
    "lng": "8.29534"
  },
  {
    "country": "IT",
    "name": "Scurzolengo",
    "lat": "44.96485",
    "lng": "8.27914"
  },
  {
    "country": "IT",
    "name": "Sessame",
    "lat": "44.67064",
    "lng": "8.33684"
  },
  {
    "country": "IT",
    "name": "Settime",
    "lat": "44.96175",
    "lng": "8.11433"
  },
  {
    "country": "IT",
    "name": "Tonengo",
    "lat": "45.11765",
    "lng": "8.00213"
  },
  {
    "country": "IT",
    "name": "Viale",
    "lat": "45.00015",
    "lng": "8.04993"
  },
  {
    "country": "IT",
    "name": "Vigliano d'Asti",
    "lat": "44.83405",
    "lng": "8.22914"
  },
  {
    "country": "IT",
    "name": "Albera Ligure",
    "lat": "44.70159",
    "lng": "9.0672"
  },
  {
    "country": "IT",
    "name": "Alzano Scrivia",
    "lat": "45.01806",
    "lng": "8.88065"
  },
  {
    "country": "IT",
    "name": "Basaluzzo",
    "lat": "44.76885",
    "lng": "8.70485"
  },
  {
    "country": "IT",
    "name": "Camagna Monferrato",
    "lat": "45.01765",
    "lng": "8.42974"
  },
  {
    "country": "IT",
    "name": "Carbonara Scrivia",
    "lat": "44.84915",
    "lng": "8.86975"
  },
  {
    "country": "IT",
    "name": "Carentino",
    "lat": "44.82885",
    "lng": "8.47134"
  },
  {
    "country": "IT",
    "name": "Carrega Ligure",
    "lat": "44.61879",
    "lng": "9.17564"
  },
  {
    "country": "IT",
    "name": "Cartosio",
    "lat": "44.59024",
    "lng": "8.42065"
  },
  {
    "country": "IT",
    "name": "Castellania",
    "lat": "44.79845",
    "lng": "8.93035"
  },
  {
    "country": "IT",
    "name": "Castelletto d'Erro",
    "lat": "44.62597",
    "lng": "8.39442"
  },
  {
    "country": "IT",
    "name": "Castelletto d'Orba",
    "lat": "44.68455",
    "lng": "8.70395"
  },
  {
    "country": "IT",
    "name": "Castelletto Monferrato",
    "lat": "44.98115",
    "lng": "8.56454"
  },
  {
    "country": "IT",
    "name": "Cavatore",
    "lat": "44.63099",
    "lng": "8.45276"
  },
  {
    "country": "IT",
    "name": "Cerreto Grue",
    "lat": "44.84255",
    "lng": "8.93035"
  },
  {
    "country": "IT",
    "name": "Denice",
    "lat": "44.59884",
    "lng": "8.33315"
  },
  {
    "country": "IT",
    "name": "Dernice",
    "lat": "44.7666",
    "lng": "9.05001"
  },
  {
    "country": "IT",
    "name": "Garbagna",
    "lat": "44.78045",
    "lng": "8.99786"
  },
  {
    "country": "IT",
    "name": "Gremiasco",
    "lat": "44.79625",
    "lng": "9.10686"
  },
  {
    "country": "IT",
    "name": "Grognardo",
    "lat": "44.63034",
    "lng": "8.49265"
  },
  {
    "country": "IT",
    "name": "Melazzo",
    "lat": "44.64394",
    "lng": "8.42495"
  },
  {
    "country": "IT",
    "name": "Merana",
    "lat": "44.51884",
    "lng": "8.29824"
  },
  {
    "country": "IT",
    "name": "Monleale",
    "lat": "44.88435",
    "lng": "8.97395"
  },
  {
    "country": "IT",
    "name": "Montaldo Bormida",
    "lat": "44.68265",
    "lng": "8.58785"
  },
  {
    "country": "IT",
    "name": "Montecastello",
    "lat": "44.94945",
    "lng": "8.68575"
  },
  {
    "country": "IT",
    "name": "Mornese",
    "lat": "44.63925",
    "lng": "8.75615"
  },
  {
    "country": "IT",
    "name": "Ispani",
    "lat": "40.0873",
    "lng": "15.55827"
  },
  {
    "country": "IT",
    "name": "Pareto",
    "lat": "44.51644",
    "lng": "8.38185"
  },
  {
    "country": "IT",
    "name": "Parodi Ligure",
    "lat": "44.66975",
    "lng": "8.75865"
  },
  {
    "country": "IT",
    "name": "Pasturana",
    "lat": "44.75085",
    "lng": "8.74925"
  },
  {
    "country": "IT",
    "name": "Prasco",
    "lat": "44.63938",
    "lng": "8.55167"
  },
  {
    "country": "IT",
    "name": "Crevoladossola",
    "lat": "46.14858",
    "lng": "8.29742"
  },
  {
    "country": "IT",
    "name": "Germagno",
    "lat": "45.89257",
    "lng": "8.38772"
  },
  {
    "country": "IT",
    "name": "Loreglia",
    "lat": "45.90687",
    "lng": "8.37132"
  },
  {
    "country": "IT",
    "name": "Romallo",
    "lat": "46.39721",
    "lng": "11.06617"
  },
  {
    "country": "IT",
    "name": "Samone",
    "lat": "46.08161",
    "lng": "11.52259"
  },
  {
    "country": "IT",
    "name": "San Lorenzo in Banale",
    "lat": "46.0766",
    "lng": "10.90847"
  },
  {
    "country": "IT",
    "name": "Scurelle",
    "lat": "46.06451",
    "lng": "11.50569"
  },
  {
    "country": "IT",
    "name": "Spera",
    "lat": "46.07031",
    "lng": "11.50899"
  },
  {
    "country": "IT",
    "name": "Spiazzo",
    "lat": "46.1036",
    "lng": "10.73937"
  },
  {
    "country": "IT",
    "name": "Strembo",
    "lat": "46.1203",
    "lng": "10.75087"
  },
  {
    "country": "IT",
    "name": "Telve di Sopra",
    "lat": "46.07131",
    "lng": "11.47179"
  },
  {
    "country": "IT",
    "name": "Terres",
    "lat": "46.30991",
    "lng": "11.02307"
  },
  {
    "country": "IT",
    "name": "Valda",
    "lat": "46.20721",
    "lng": "11.26488"
  },
  {
    "country": "IT",
    "name": "Villa Rendena",
    "lat": "46.0627",
    "lng": "10.7125"
  },
  {
    "country": "IT",
    "name": "Caldiero",
    "lat": "45.41439",
    "lng": "11.17739"
  },
  {
    "country": "IT",
    "name": "Cazzano di Tramigna",
    "lat": "45.47309",
    "lng": "11.20289"
  },
  {
    "country": "IT",
    "name": "Isola Rizza",
    "lat": "45.29228",
    "lng": "11.199"
  },
  {
    "country": "IT",
    "name": "Mezzane di Sotto",
    "lat": "45.48199",
    "lng": "11.12729"
  },
  {
    "country": "IT",
    "name": "Roverchiara",
    "lat": "45.26799",
    "lng": "11.2451"
  },
  {
    "country": "IT",
    "name": "San Pietro di Morubio",
    "lat": "45.24248",
    "lng": "11.227"
  },
  {
    "country": "IT",
    "name": "Sorgà",
    "lat": "45.21328",
    "lng": "10.97989"
  },
  {
    "country": "IT",
    "name": "Velo Veronese",
    "lat": "45.60669",
    "lng": "11.09519"
  },
  {
    "country": "IT",
    "name": "Cartigliano",
    "lat": "45.713",
    "lng": "11.6956"
  },
  {
    "country": "IT",
    "name": "Gambellara",
    "lat": "45.45979",
    "lng": "11.34009"
  },
  {
    "country": "IT",
    "name": "Gambugliano",
    "lat": "45.58799",
    "lng": "11.43859"
  },
  {
    "country": "IT",
    "name": "Laghi",
    "lat": "45.8245",
    "lng": "11.27249"
  },
  {
    "country": "IT",
    "name": "Nogarole Vicentino",
    "lat": "45.56019",
    "lng": "11.28829"
  },
  {
    "country": "IT",
    "name": "Rotzo",
    "lat": "45.8619",
    "lng": "11.39619"
  },
  {
    "country": "IT",
    "name": "San Germano dei Berici",
    "lat": "45.40179",
    "lng": "11.4713"
  },
  {
    "country": "IT",
    "name": "Sovizzo",
    "lat": "45.52669",
    "lng": "11.4461"
  },
  {
    "country": "IT",
    "name": "Zugliano",
    "lat": "45.7298",
    "lng": "11.52399"
  },
  {
    "country": "IT",
    "name": "Rocca Pietore",
    "lat": "46.43392",
    "lng": "11.97679"
  },
  {
    "country": "IT",
    "name": "Tambre",
    "lat": "46.12632",
    "lng": "12.41941"
  },
  {
    "country": "IT",
    "name": "Boara Pisani",
    "lat": "45.10809",
    "lng": "11.78271"
  },
  {
    "country": "IT",
    "name": "Cervarese Santa Croce",
    "lat": "45.42439",
    "lng": "11.6879"
  },
  {
    "country": "IT",
    "name": "Masi",
    "lat": "45.10888",
    "lng": "11.48921"
  },
  {
    "country": "IT",
    "name": "San Giorgio delle Pertiche",
    "lat": "45.541",
    "lng": "11.89401"
  },
  {
    "country": "IT",
    "name": "Bagnolo di Po",
    "lat": "45.01548",
    "lng": "11.50091"
  },
  {
    "country": "IT",
    "name": "Canda",
    "lat": "45.03608",
    "lng": "11.50331"
  },
  {
    "country": "IT",
    "name": "Majano",
    "lat": "46.18752",
    "lng": "13.06162"
  },
  {
    "country": "IT",
    "name": "Treppo Carnico",
    "lat": "46.53323",
    "lng": "13.04292"
  },
  {
    "country": "IT",
    "name": "Farra d'Isonzo",
    "lat": "45.90802",
    "lng": "13.51654"
  },
  {
    "country": "IT",
    "name": "San Pietro in Cerro",
    "lat": "45.02137",
    "lng": "9.94987"
  },
  {
    "country": "IT",
    "name": "Zerba",
    "lat": "44.66551",
    "lng": "9.28795"
  },
  {
    "country": "IT",
    "name": "San Possidonio",
    "lat": "44.87402",
    "lng": "10.98087"
  },
  {
    "country": "IT",
    "name": "Predappio",
    "lat": "44.10316",
    "lng": "11.98413"
  },
  {
    "country": "IT",
    "name": "Cartoceto",
    "lat": "43.76566",
    "lng": "12.88346"
  },
  {
    "country": "IT",
    "name": "Mercatino Conca",
    "lat": "43.87016",
    "lng": "12.49115"
  },
  {
    "country": "IT",
    "name": "Monte Porzio",
    "lat": "43.69116",
    "lng": "13.04686"
  },
  {
    "country": "IT",
    "name": "Serrungarina",
    "lat": "43.74666",
    "lng": "12.87486"
  },
  {
    "country": "IT",
    "name": "Barbara",
    "lat": "43.58036",
    "lng": "13.02736"
  },
  {
    "country": "IT",
    "name": "Castelleone di Suasa",
    "lat": "43.60816",
    "lng": "12.97796"
  },
  {
    "country": "IT",
    "name": "Poggio San Marcello",
    "lat": "43.51116",
    "lng": "13.07367"
  },
  {
    "country": "IT",
    "name": "Force",
    "lat": "42.96095",
    "lng": "13.48768"
  },
  {
    "country": "IT",
    "name": "Monteleone di Fermo",
    "lat": "43.04785",
    "lng": "13.52948"
  },
  {
    "country": "IT",
    "name": "Filattiera",
    "lat": "44.33005",
    "lng": "9.93308"
  },
  {
    "country": "IT",
    "name": "Careggine",
    "lat": "44.11995",
    "lng": "10.3254"
  },
  {
    "country": "IT",
    "name": "Fosciandora",
    "lat": "44.11495",
    "lng": "10.4585"
  },
  {
    "country": "IT",
    "name": "Villa Collemandina",
    "lat": "44.15855",
    "lng": "10.3976"
  },
  {
    "country": "IT",
    "name": "Orciano Pisano",
    "lat": "43.49444",
    "lng": "10.51151"
  },
  {
    "country": "IT",
    "name": "Semproniano",
    "lat": "42.72923",
    "lng": "11.54134"
  },
  {
    "country": "IT",
    "name": "Lisciano Niccone",
    "lat": "43.24684",
    "lng": "12.14305"
  },
  {
    "country": "IT",
    "name": "Villa San Giovanni in Tuscia",
    "lat": "42.27882",
    "lng": "12.05346"
  },
  {
    "country": "IT",
    "name": "Montenero Sabino",
    "lat": "42.28123",
    "lng": "12.81358"
  },
  {
    "country": "IT",
    "name": "Campodimele",
    "lat": "41.38822",
    "lng": "13.53081"
  },
  {
    "country": "IT",
    "name": "Torre Caietani",
    "lat": "41.78672",
    "lng": "13.2652"
  },
  {
    "country": "IT",
    "name": "Trivigliano",
    "lat": "41.77572",
    "lng": "13.2723"
  },
  {
    "country": "IT",
    "name": "Carinaro",
    "lat": "40.98291",
    "lng": "14.21963"
  },
  {
    "country": "IT",
    "name": "Castello del Matese",
    "lat": "41.36672",
    "lng": "14.37773"
  },
  {
    "country": "IT",
    "name": "Curti",
    "lat": "41.07616",
    "lng": "14.28039"
  },
  {
    "country": "IT",
    "name": "Piana di Monte Verna",
    "lat": "41.16712",
    "lng": "14.33373"
  },
  {
    "country": "IT",
    "name": "Villa di Briano",
    "lat": "41.00001",
    "lng": "14.16073"
  },
  {
    "country": "IT",
    "name": "Falciano del Massico",
    "lat": "41.16271",
    "lng": "13.94812"
  },
  {
    "country": "IT",
    "name": "Casapesenna",
    "lat": "40.99151",
    "lng": "14.13613"
  },
  {
    "country": "IT",
    "name": "Calvi",
    "lat": "41.07162",
    "lng": "14.86524"
  },
  {
    "country": "IT",
    "name": "San Nazzaro",
    "lat": "41.05172",
    "lng": "14.85724"
  },
  {
    "country": "IT",
    "name": "San Nicola Manfredi",
    "lat": "41.0751",
    "lng": "14.8243"
  },
  {
    "country": "IT",
    "name": "Carbonara di Nola",
    "lat": "40.87441",
    "lng": "14.57884"
  },
  {
    "country": "IT",
    "name": "Massa di Somma",
    "lat": "40.84551",
    "lng": "14.37513"
  },
  {
    "country": "IT",
    "name": "Montella",
    "lat": "40.84372",
    "lng": "15.01785"
  },
  {
    "country": "IT",
    "name": "Pago del Vallo di Lauro",
    "lat": "40.89721",
    "lng": "14.60764"
  },
  {
    "country": "IT",
    "name": "Roccabascerana",
    "lat": "41.01842",
    "lng": "14.71684"
  },
  {
    "country": "IT",
    "name": "Tufo",
    "lat": "41.01262",
    "lng": "14.81784"
  },
  {
    "country": "IT",
    "name": "Vallesaccarda",
    "lat": "41.06312",
    "lng": "15.25205"
  },
  {
    "country": "IT",
    "name": "Felitto",
    "lat": "40.37351",
    "lng": "15.24306"
  },
  {
    "country": "IT",
    "name": "Bugnara",
    "lat": "42.02383",
    "lng": "13.86141"
  },
  {
    "country": "IT",
    "name": "Morino",
    "lat": "41.86442",
    "lng": "13.457"
  },
  {
    "country": "IT",
    "name": "Rivisondoli",
    "lat": "41.87023",
    "lng": "14.06671"
  },
  {
    "country": "IT",
    "name": "Castel Castagna",
    "lat": "42.54294",
    "lng": "13.7164"
  },
  {
    "country": "IT",
    "name": "Roccamorice",
    "lat": "42.21274",
    "lng": "14.02531"
  },
  {
    "country": "IT",
    "name": "Palmoli",
    "lat": "41.93944",
    "lng": "14.58142"
  },
  {
    "country": "IT",
    "name": "Rocca San Giovanni",
    "lat": "42.24604",
    "lng": "14.46162"
  },
  {
    "country": "IT",
    "name": "Castro",
    "lat": "40.00702",
    "lng": "18.42573"
  },
  {
    "country": "IT",
    "name": "Gagliato",
    "lat": "38.67578",
    "lng": "16.46061"
  },
  {
    "country": "IT",
    "name": "Settingiano",
    "lat": "38.91139",
    "lng": "16.5139"
  },
  {
    "country": "IT",
    "name": "Campo Calabro",
    "lat": "38.21607",
    "lng": "15.65919"
  },
  {
    "country": "IT",
    "name": "Maropati",
    "lat": "38.44178",
    "lng": "16.0975"
  },
  {
    "country": "IT",
    "name": "Oppido Mamertina",
    "lat": "38.29337",
    "lng": "15.9839"
  },
  {
    "country": "IT",
    "name": "Riace",
    "lat": "38.41828",
    "lng": "16.48121"
  },
  {
    "country": "IT",
    "name": "San Pietro di Caridà",
    "lat": "38.52368",
    "lng": "16.1353"
  },
  {
    "country": "IT",
    "name": "Sant'Agata del Bianco",
    "lat": "38.09242",
    "lng": "16.08251"
  },
  {
    "country": "IT",
    "name": "Buseto Palizzolo",
    "lat": "38.00339",
    "lng": "12.70911"
  },
  {
    "country": "IT",
    "name": "Trappeto",
    "lat": "38.06875",
    "lng": "13.03794"
  },
  {
    "country": "IT",
    "name": "Blufi",
    "lat": "37.75205",
    "lng": "14.07296"
  },
  {
    "country": "IT",
    "name": "Alì Terme",
    "lat": "38.00506",
    "lng": "15.42269"
  },
  {
    "country": "IT",
    "name": "Graniti",
    "lat": "37.88986",
    "lng": "15.22459"
  },
  {
    "country": "IT",
    "name": "Limina",
    "lat": "37.94076",
    "lng": "15.27119"
  },
  {
    "country": "IT",
    "name": "Pace del Mela",
    "lat": "38.17997",
    "lng": "15.30629"
  },
  {
    "country": "IT",
    "name": "Rometta",
    "lat": "38.17007",
    "lng": "15.41429"
  },
  {
    "country": "IT",
    "name": "Esporlatu",
    "lat": "40.38456",
    "lng": "8.98983"
  },
  {
    "country": "IT",
    "name": "Viddalba",
    "lat": "40.91259",
    "lng": "8.89009"
  },
  {
    "country": "IT",
    "name": "Golfo Aranci",
    "lat": "41.00648",
    "lng": "9.61453"
  },
  {
    "country": "IT",
    "name": "Budoni",
    "lat": "40.70467",
    "lng": "9.70384"
  },
  {
    "country": "IT",
    "name": "Villanova Tulo",
    "lat": "39.77995",
    "lng": "9.21424"
  },
  {
    "country": "IT",
    "name": "Ollastra",
    "lat": "39.95095",
    "lng": "8.73423"
  },
  {
    "country": "IT",
    "name": "Casapinta",
    "lat": "45.61566",
    "lng": "8.19592"
  },
  {
    "country": "IT",
    "name": "Castelletto Cervo",
    "lat": "45.52136",
    "lng": "8.22542"
  },
  {
    "country": "IT",
    "name": "Dorzano",
    "lat": "45.42606",
    "lng": "8.09852"
  },
  {
    "country": "IT",
    "name": "Gifflenga",
    "lat": "45.49306",
    "lng": "8.23223"
  },
  {
    "country": "IT",
    "name": "Miagliano",
    "lat": "45.61346",
    "lng": "8.04472"
  },
  {
    "country": "IT",
    "name": "Muzzano",
    "lat": "45.56076",
    "lng": "7.98892"
  },
  {
    "country": "IT",
    "name": "Ponderano",
    "lat": "45.53846",
    "lng": "8.05592"
  },
  {
    "country": "IT",
    "name": "Quaregna",
    "lat": "45.58116",
    "lng": "8.16372"
  },
  {
    "country": "IT",
    "name": "Roppolo",
    "lat": "45.42056",
    "lng": "8.06972"
  },
  {
    "country": "IT",
    "name": "Rosazza",
    "lat": "45.67576",
    "lng": "7.97712"
  },
  {
    "country": "IT",
    "name": "Ternengo",
    "lat": "45.58896",
    "lng": "8.11372"
  },
  {
    "country": "IT",
    "name": "Viverone",
    "lat": "45.42726",
    "lng": "8.04942"
  },
  {
    "country": "IT",
    "name": "Zubiena",
    "lat": "45.49266",
    "lng": "7.99552"
  },
  {
    "country": "IT",
    "name": "Zumaglia",
    "lat": "45.59386",
    "lng": "8.08942"
  },
  {
    "country": "IT",
    "name": "Barzago",
    "lat": "45.75548",
    "lng": "9.31424"
  },
  {
    "country": "IT",
    "name": "Barzio",
    "lat": "45.94349",
    "lng": "9.46694"
  },
  {
    "country": "IT",
    "name": "Cassina Valsassina",
    "lat": "45.93209",
    "lng": "9.47894"
  },
  {
    "country": "IT",
    "name": "Cernusco Lombardone",
    "lat": "45.69088",
    "lng": "9.39925"
  },
  {
    "country": "IT",
    "name": "Cesana Brianza",
    "lat": "45.81678",
    "lng": "9.29954"
  },
  {
    "country": "IT",
    "name": "Crandola Valsassina",
    "lat": "46.02329",
    "lng": "9.37914"
  },
  {
    "country": "IT",
    "name": "Cremella",
    "lat": "45.73858",
    "lng": "9.30064"
  },
  {
    "country": "IT",
    "name": "Dolzago",
    "lat": "45.76698",
    "lng": "9.33934"
  },
  {
    "country": "IT",
    "name": "Ello",
    "lat": "45.78568",
    "lng": "9.36534"
  },
  {
    "country": "IT",
    "name": "Introzzo",
    "lat": "46.08119",
    "lng": "9.34094"
  },
  {
    "country": "IT",
    "name": "Margno",
    "lat": "46.03099",
    "lng": "9.38164"
  },
  {
    "country": "IT",
    "name": "Montevecchia",
    "lat": "45.70548",
    "lng": "9.38085"
  },
  {
    "country": "IT",
    "name": "Primaluna",
    "lat": "45.98379",
    "lng": "9.43764"
  },
  {
    "country": "IT",
    "name": "Sirone",
    "lat": "45.77268",
    "lng": "9.32214"
  },
  {
    "country": "IT",
    "name": "Vendrogno",
    "lat": "46.03439",
    "lng": "9.32944"
  },
  {
    "country": "IT",
    "name": "Vestreno",
    "lat": "46.08329",
    "lng": "9.32484"
  },
  {
    "country": "IT",
    "name": "Viganò",
    "lat": "45.72468",
    "lng": "9.32494"
  },
  {
    "country": "IT",
    "name": "Abbadia Cerreto",
    "lat": "45.31217",
    "lng": "9.59416"
  },
  {
    "country": "IT",
    "name": "Borgo San Giovanni",
    "lat": "45.27787",
    "lng": "9.43496"
  },
  {
    "country": "IT",
    "name": "Caselle Landi",
    "lat": "45.10257",
    "lng": "9.79557"
  },
  {
    "country": "IT",
    "name": "Cornovecchio",
    "lat": "45.13667",
    "lng": "9.79937"
  },
  {
    "country": "IT",
    "name": "Galgagnano",
    "lat": "45.35797",
    "lng": "9.44535"
  },
  {
    "country": "IT",
    "name": "Livraga",
    "lat": "45.19227",
    "lng": "9.54646"
  },
  {
    "country": "IT",
    "name": "Maccastorna",
    "lat": "45.14667",
    "lng": "9.85457"
  },
  {
    "country": "IT",
    "name": "Marudo",
    "lat": "45.25297",
    "lng": "9.37716"
  },
  {
    "country": "IT",
    "name": "Massalengo-Motta Vigana",
    "lat": "45.26497",
    "lng": "9.49016"
  },
  {
    "country": "IT",
    "name": "Merlino",
    "lat": "45.43337",
    "lng": "9.42985"
  },
  {
    "country": "IT",
    "name": "Mulazzano",
    "lat": "45.37237",
    "lng": "9.39765"
  },
  {
    "country": "IT",
    "name": "Salerano sul Lambro",
    "lat": "45.29657",
    "lng": "9.38515"
  },
  {
    "country": "IT",
    "name": "San Rocco al Porto",
    "lat": "45.08197",
    "lng": "9.69717"
  },
  {
    "country": "IT",
    "name": "Santo Stefano Lodigiano",
    "lat": "45.11857",
    "lng": "9.73527"
  },
  {
    "country": "IT",
    "name": "Somaglia",
    "lat": "45.14947",
    "lng": "9.63346"
  },
  {
    "country": "IT",
    "name": "Mondaino",
    "lat": "43.85796",
    "lng": "12.66845"
  },
  {
    "country": "IT",
    "name": "Monte Colombo",
    "lat": "43.92016",
    "lng": "12.55235"
  },
  {
    "country": "IT",
    "name": "Brognaturo",
    "lat": "38.60128",
    "lng": "16.3414"
  },
  {
    "country": "IT",
    "name": "Joppolo",
    "lat": "38.58338",
    "lng": "15.89709"
  },
  {
    "country": "IT",
    "name": "Zungri",
    "lat": "38.65668",
    "lng": "15.98409"
  },
  {
    "country": "IT",
    "name": "Bee",
    "lat": "45.96328",
    "lng": "8.57542"
  },
  {
    "country": "IT",
    "name": "Caprezzo",
    "lat": "45.98198",
    "lng": "8.56282"
  },
  {
    "country": "IT",
    "name": "Ceppo Morelli",
    "lat": "45.97114",
    "lng": "8.06688"
  },
  {
    "country": "IT",
    "name": "Cossogno",
    "lat": "45.96408",
    "lng": "8.50962"
  },
  {
    "country": "IT",
    "name": "Gurro",
    "lat": "46.08498",
    "lng": "8.56772"
  },
  {
    "country": "IT",
    "name": "Intragna",
    "lat": "45.99468",
    "lng": "8.57392"
  },
  {
    "country": "IT",
    "name": "Massiola",
    "lat": "45.91247",
    "lng": "8.32012"
  },
  {
    "country": "IT",
    "name": "Montecrestese",
    "lat": "46.16448",
    "lng": "8.32621"
  },
  {
    "country": "IT",
    "name": "Nonio",
    "lat": "45.84577",
    "lng": "8.37752"
  },
  {
    "country": "IT",
    "name": "Premia",
    "lat": "46.26807",
    "lng": "8.3383"
  },
  {
    "country": "IT",
    "name": "Toceno",
    "lat": "46.14468",
    "lng": "8.46902"
  },
  {
    "country": "IT",
    "name": "Trasquera",
    "lat": "46.21338",
    "lng": "8.21271"
  },
  {
    "country": "IT",
    "name": "Trontano",
    "lat": "46.12248",
    "lng": "8.33322"
  },
  {
    "country": "IT",
    "name": "Zuni",
    "lat": "41.21722",
    "lng": "14.13082"
  },
  {
    "country": "IT",
    "name": "Letino",
    "lat": "41.45302",
    "lng": "14.25542"
  },
  {
    "country": "IT",
    "name": "Pastorano",
    "lat": "41.18082",
    "lng": "14.19823"
  },
  {
    "country": "IT",
    "name": "Coreglia Ligure",
    "lat": "44.38775",
    "lng": "9.26097"
  },
  {
    "country": "IT",
    "name": "Casciago",
    "lat": "45.83248",
    "lng": "8.78333"
  },
  {
    "country": "IT",
    "name": "Cassano Valcuvia",
    "lat": "45.93238",
    "lng": "8.76843"
  },
  {
    "country": "IT",
    "name": "Bene Lario",
    "lat": "46.02898",
    "lng": "9.18414"
  },
  {
    "country": "IT",
    "name": "Binago",
    "lat": "45.78218",
    "lng": "8.92234"
  },
  {
    "country": "IT",
    "name": "Cabiate",
    "lat": "45.67418",
    "lng": "9.17374"
  },
  {
    "country": "IT",
    "name": "Cagno",
    "lat": "45.81108",
    "lng": "8.91733"
  },
  {
    "country": "IT",
    "name": "Ramponio Verna",
    "lat": "45.99698",
    "lng": "9.06633"
  },
  {
    "country": "IT",
    "name": "Rodero",
    "lat": "45.82398",
    "lng": "8.91523"
  },
  {
    "country": "IT",
    "name": "Ronago",
    "lat": "45.83228",
    "lng": "8.98364"
  },
  {
    "country": "IT",
    "name": "San Fedele Intelvi",
    "lat": "45.96768",
    "lng": "9.08074"
  },
  {
    "country": "IT",
    "name": "Senna Comasco",
    "lat": "45.76298",
    "lng": "9.11104"
  },
  {
    "country": "IT",
    "name": "Sorico",
    "lat": "46.17259",
    "lng": "9.38404"
  },
  {
    "country": "IT",
    "name": "Tavernerio",
    "lat": "45.80068",
    "lng": "9.14054"
  },
  {
    "country": "IT",
    "name": "Turate",
    "lat": "45.65727",
    "lng": "9.00424"
  },
  {
    "country": "IT",
    "name": "Valmorea",
    "lat": "45.81518",
    "lng": "8.93064"
  },
  {
    "country": "IT",
    "name": "Vercana",
    "lat": "46.15949",
    "lng": "9.33514"
  },
  {
    "country": "IT",
    "name": "Zelbio",
    "lat": "45.90458",
    "lng": "9.18054"
  },
  {
    "country": "IT",
    "name": "Andalo Valtellino",
    "lat": "46.13599",
    "lng": "9.47384"
  },
  {
    "country": "IT",
    "name": "Caiolo",
    "lat": "46.14999",
    "lng": "9.81455"
  },
  {
    "country": "IT",
    "name": "Colorina",
    "lat": "46.15369",
    "lng": "9.72935"
  },
  {
    "country": "IT",
    "name": "Lanzada",
    "lat": "46.2693",
    "lng": "9.86925"
  },
  {
    "country": "IT",
    "name": "Lovero",
    "lat": "46.2314",
    "lng": "10.22856"
  },
  {
    "country": "IT",
    "name": "Noviglio",
    "lat": "45.35907",
    "lng": "9.05215"
  },
  {
    "country": "IT",
    "name": "Caponago",
    "lat": "45.56647",
    "lng": "9.37585"
  },
  {
    "country": "IT",
    "name": "Cerro al Lambro",
    "lat": "45.32997",
    "lng": "9.33905"
  },
  {
    "country": "IT",
    "name": "Cusago",
    "lat": "45.44997",
    "lng": "9.03744"
  },
  {
    "country": "IT",
    "name": "Blello",
    "lat": "45.83778",
    "lng": "9.57105"
  },
  {
    "country": "IT",
    "name": "Pregnana Milanese",
    "lat": "45.51597",
    "lng": "9.00704"
  },
  {
    "country": "IT",
    "name": "Bracca",
    "lat": "45.82267",
    "lng": "9.70784"
  },
  {
    "country": "IT",
    "name": "Branzi",
    "lat": "46.00249",
    "lng": "9.75935"
  },
  {
    "country": "IT",
    "name": "Brembate di Sopra",
    "lat": "45.71668",
    "lng": "9.57945"
  },
  {
    "country": "IT",
    "name": "Castel Rozzone",
    "lat": "45.55228",
    "lng": "9.61985"
  },
  {
    "country": "IT",
    "name": "Torre Pallavicina",
    "lat": "45.44638",
    "lng": "9.87706"
  },
  {
    "country": "IT",
    "name": "Onore",
    "lat": "45.89159",
    "lng": "10.01076"
  },
  {
    "country": "IT",
    "name": "Osio Sopra",
    "lat": "45.62908",
    "lng": "9.58465"
  },
  {
    "country": "IT",
    "name": "Pagazzano",
    "lat": "45.53428",
    "lng": "9.67116"
  },
  {
    "country": "IT",
    "name": "Paladina",
    "lat": "45.73068",
    "lng": "9.60585"
  },
  {
    "country": "IT",
    "name": "Pontirolo Nuovo",
    "lat": "45.56918",
    "lng": "9.56935"
  },
  {
    "country": "IT",
    "name": "Pradalunga",
    "lat": "45.74588",
    "lng": "9.78225"
  },
  {
    "country": "IT",
    "name": "Ranica",
    "lat": "45.72328",
    "lng": "9.71335"
  },
  {
    "country": "IT",
    "name": "Solza",
    "lat": "45.67868",
    "lng": "9.49075"
  },
  {
    "country": "IT",
    "name": "Azzano Mella",
    "lat": "45.45458",
    "lng": "10.11717"
  },
  {
    "country": "IT",
    "name": "Ono San Pietro",
    "lat": "46.01689",
    "lng": "10.32836"
  },
  {
    "country": "IT",
    "name": "Paitone",
    "lat": "45.55208",
    "lng": "10.40227"
  },
  {
    "country": "IT",
    "name": "Cecima",
    "lat": "44.85066",
    "lng": "9.08036"
  },
  {
    "country": "IT",
    "name": "Ceranova",
    "lat": "45.26027",
    "lng": "9.24315"
  },
  {
    "country": "IT",
    "name": "Ceretto Lomellina",
    "lat": "45.24496",
    "lng": "8.67244"
  },
  {
    "country": "IT",
    "name": "Cigognola",
    "lat": "45.03276",
    "lng": "9.24486"
  },
  {
    "country": "IT",
    "name": "Cura Carpignano",
    "lat": "45.21247",
    "lng": "9.25565"
  },
  {
    "country": "IT",
    "name": "Galliavola",
    "lat": "45.09756",
    "lng": "8.81885"
  },
  {
    "country": "IT",
    "name": "Ruino",
    "lat": "44.91145",
    "lng": "9.27553"
  },
  {
    "country": "IT",
    "name": "Pizzale",
    "lat": "45.03856",
    "lng": "9.04995"
  },
  {
    "country": "IT",
    "name": "Rea",
    "lat": "45.11336",
    "lng": "9.15465"
  },
  {
    "country": "IT",
    "name": "Imer",
    "lat": "46.14931",
    "lng": "11.78919"
  },
  {
    "country": "IT",
    "name": "Nave San Rocco",
    "lat": "46.16771",
    "lng": "11.10508"
  },
  {
    "country": "IT",
    "name": "Pieve di Ledro",
    "lat": "45.88848",
    "lng": "10.73124"
  },
  {
    "country": "IT",
    "name": "Pomarolo",
    "lat": "45.9281",
    "lng": "11.04308"
  },
  {
    "country": "IT",
    "name": "Praso",
    "lat": "45.95",
    "lng": "10.63627"
  },
  {
    "country": "IT",
    "name": "Prezzo",
    "lat": "45.9347",
    "lng": "10.63297"
  },
  {
    "country": "IT",
    "name": "Banchette",
    "lat": "45.45356",
    "lng": "7.85632"
  },
  {
    "country": "IT",
    "name": "Barone Canavese",
    "lat": "45.32576",
    "lng": "7.87342"
  },
  {
    "country": "IT",
    "name": "Lombriasco",
    "lat": "44.84094",
    "lng": "7.63593"
  },
  {
    "country": "IT",
    "name": "Lusernetta",
    "lat": "44.80314",
    "lng": "7.24672"
  },
  {
    "country": "IT",
    "name": "Maglione",
    "lat": "45.34666",
    "lng": "8.01332"
  },
  {
    "country": "IT",
    "name": "Marentino",
    "lat": "45.05368",
    "lng": "7.87609"
  },
  {
    "country": "IT",
    "name": "Meana di Susa",
    "lat": "45.12204",
    "lng": "7.06471"
  },
  {
    "country": "IT",
    "name": "Mezzenile",
    "lat": "45.29485",
    "lng": "7.39561"
  },
  {
    "country": "IT",
    "name": "Osasco",
    "lat": "44.84944",
    "lng": "7.34302"
  },
  {
    "country": "IT",
    "name": "Osasio",
    "lat": "44.87144",
    "lng": "7.60802"
  },
  {
    "country": "IT",
    "name": "San Pietro Val Lemina",
    "lat": "44.90654",
    "lng": "7.31092"
  },
  {
    "country": "IT",
    "name": "San Sebastiano da Po",
    "lat": "45.16755",
    "lng": "7.95723"
  },
  {
    "country": "IT",
    "name": "San Secondo di Pinerolo",
    "lat": "44.86644",
    "lng": "7.29842"
  },
  {
    "country": "IT",
    "name": "Torrazza Piemonte",
    "lat": "45.21535",
    "lng": "7.97673"
  },
  {
    "country": "IT",
    "name": "Torre Canavese",
    "lat": "45.39206",
    "lng": "7.75982"
  },
  {
    "country": "IT",
    "name": "Trausella",
    "lat": "45.48996",
    "lng": "7.76312"
  },
  {
    "country": "IT",
    "name": "Vaie",
    "lat": "45.10234",
    "lng": "7.28941"
  },
  {
    "country": "IT",
    "name": "Varisella",
    "lat": "45.20835",
    "lng": "7.48381"
  },
  {
    "country": "IT",
    "name": "Vialfrè",
    "lat": "45.38076",
    "lng": "7.81822"
  },
  {
    "country": "IT",
    "name": "Vidracco",
    "lat": "45.43066",
    "lng": "7.75742"
  },
  {
    "country": "IT",
    "name": "Villarbasse",
    "lat": "45.04514",
    "lng": "7.46842"
  },
  {
    "country": "IT",
    "name": "Villar Dora",
    "lat": "45.11465",
    "lng": "7.38352"
  },
  {
    "country": "IT",
    "name": "Civiasco",
    "lat": "45.80786",
    "lng": "8.29386"
  },
  {
    "country": "IT",
    "name": "Guardabosone",
    "lat": "45.70187",
    "lng": "8.24932"
  },
  {
    "country": "IT",
    "name": "Moncrivello",
    "lat": "45.33236",
    "lng": "7.99552"
  },
  {
    "country": "IT",
    "name": "Garbagna Novarese",
    "lat": "45.38876",
    "lng": "8.66124"
  },
  {
    "country": "IT",
    "name": "Gattico",
    "lat": "45.70717",
    "lng": "8.52003"
  },
  {
    "country": "IT",
    "name": "Massino Visconti",
    "lat": "45.82417",
    "lng": "8.54133"
  },
  {
    "country": "IT",
    "name": "Nebbiuno",
    "lat": "45.80774",
    "lng": "8.52593"
  },
  {
    "country": "IT",
    "name": "Oleggio Castello",
    "lat": "45.74887",
    "lng": "8.52713"
  },
  {
    "country": "IT",
    "name": "Pettenasco",
    "lat": "45.81657",
    "lng": "8.40702"
  },
  {
    "country": "IT",
    "name": "Arguello",
    "lat": "44.58274",
    "lng": "8.11084"
  },
  {
    "country": "IT",
    "name": "Barbaresco",
    "lat": "44.72324",
    "lng": "8.08194"
  },
  {
    "country": "IT",
    "name": "Bastia Mondovì",
    "lat": "44.44194",
    "lng": "7.89444"
  },
  {
    "country": "IT",
    "name": "Bergolo",
    "lat": "44.54784",
    "lng": "8.18314"
  },
  {
    "country": "IT",
    "name": "Bernezzo",
    "lat": "44.38533",
    "lng": "7.43633"
  },
  {
    "country": "IT",
    "name": "Bonvicino",
    "lat": "44.50354",
    "lng": "8.01754"
  },
  {
    "country": "IT",
    "name": "Bosia",
    "lat": "44.60244",
    "lng": "8.14734"
  },
  {
    "country": "IT",
    "name": "Brondello",
    "lat": "44.60073",
    "lng": "7.40592"
  },
  {
    "country": "IT",
    "name": "Camo",
    "lat": "44.69504",
    "lng": "8.19434"
  },
  {
    "country": "IT",
    "name": "Caramagna Piemonte",
    "lat": "44.78224",
    "lng": "7.73943"
  },
  {
    "country": "IT",
    "name": "Cardè",
    "lat": "44.74444",
    "lng": "7.47762"
  },
  {
    "country": "IT",
    "name": "Castellar",
    "lat": "44.62123",
    "lng": "7.43743"
  },
  {
    "country": "IT",
    "name": "Castellinaldo",
    "lat": "44.77484",
    "lng": "8.02974"
  },
  {
    "country": "IT",
    "name": "Castellino Tanaro",
    "lat": "44.42784",
    "lng": "7.98124"
  },
  {
    "country": "IT",
    "name": "Castiglione Falletto",
    "lat": "44.62254",
    "lng": "7.97534"
  },
  {
    "country": "IT",
    "name": "Castiglione Tinella",
    "lat": "44.72534",
    "lng": "8.19014"
  },
  {
    "country": "IT",
    "name": "Grinzane Cavour",
    "lat": "44.65334",
    "lng": "7.99504"
  },
  {
    "country": "IT",
    "name": "Ceresole Alba",
    "lat": "44.79974",
    "lng": "7.82243"
  },
  {
    "country": "IT",
    "name": "Cigliè",
    "lat": "44.43653",
    "lng": "7.92654"
  },
  {
    "country": "IT",
    "name": "Cissone",
    "lat": "44.56314",
    "lng": "8.03044"
  },
  {
    "country": "IT",
    "name": "Corneliano d'Alba",
    "lat": "44.73614",
    "lng": "7.95723"
  },
  {
    "country": "IT",
    "name": "Faule",
    "lat": "44.80624",
    "lng": "7.58512"
  },
  {
    "country": "IT",
    "name": "Feisoglio",
    "lat": "44.54374",
    "lng": "8.10494"
  },
  {
    "country": "IT",
    "name": "Gottasecca",
    "lat": "44.46014",
    "lng": "8.16754"
  },
  {
    "country": "IT",
    "name": "Govone",
    "lat": "44.80445",
    "lng": "8.09404"
  },
  {
    "country": "IT",
    "name": "Isasca",
    "lat": "44.58763",
    "lng": "7.38162"
  },
  {
    "country": "IT",
    "name": "Lequio Tanaro",
    "lat": "44.55994",
    "lng": "7.88214"
  },
  {
    "country": "IT",
    "name": "Lisio",
    "lat": "44.30713",
    "lng": "7.97874"
  },
  {
    "country": "IT",
    "name": "Mosso",
    "lat": "45.65007",
    "lng": "8.13762"
  },
  {
    "country": "IT",
    "name": "Spadola",
    "lat": "38.60378",
    "lng": "16.337"
  },
  {
    "country": "IT",
    "name": "Cavagnolo",
    "lat": "45.15175",
    "lng": "8.04903"
  },
  {
    "country": "IT",
    "name": "Scena - Schenna",
    "lat": "46.69012",
    "lng": "11.18627"
  },
  {
    "country": "IT",
    "name": "Albinia",
    "lat": "42.50278",
    "lng": "11.21027"
  },
  {
    "country": "IT",
    "name": "Cantagrillo-Casalguidi",
    "lat": "43.86937",
    "lng": "10.91386"
  },
  {
    "country": "IT",
    "name": "Sambuca",
    "lat": "43.57344",
    "lng": "11.21407"
  },
  {
    "country": "IT",
    "name": "Luco Mugello",
    "lat": "44.00032",
    "lng": "11.39611"
  },
  {
    "country": "IT",
    "name": "Castellina Scalo",
    "lat": "43.40476",
    "lng": "11.20908"
  },
  {
    "country": "IT",
    "name": "Mercatale",
    "lat": "43.63677",
    "lng": "11.2279"
  },
  {
    "country": "IT",
    "name": "Porto Cervo",
    "lat": "41.14063",
    "lng": "9.53267"
  },
  {
    "country": "IT",
    "name": "Fulgatore-Torretta",
    "lat": "37.94977",
    "lng": "12.69303"
  },
  {
    "country": "IT",
    "name": "La California",
    "lat": "43.26938",
    "lng": "10.54313"
  },
  {
    "country": "IT",
    "name": "Stiava",
    "lat": "43.8972",
    "lng": "10.31798"
  },
  {
    "country": "IT",
    "name": "Chiassa-Tregozzano",
    "lat": "43.51251",
    "lng": "11.89134"
  },
  {
    "country": "IT",
    "name": "Orentano",
    "lat": "43.77907",
    "lng": "10.65939"
  },
  {
    "country": "IT",
    "name": "Aci Trezza",
    "lat": "37.56385",
    "lng": "15.16136"
  },
  {
    "country": "IT",
    "name": "Torre San Giovanni",
    "lat": "39.89001",
    "lng": "18.11159"
  },
  {
    "country": "IT",
    "name": "Tortoreto Lido",
    "lat": "42.79956",
    "lng": "13.94205"
  },
  {
    "country": "IT",
    "name": "Tonnarella",
    "lat": "38.12539",
    "lng": "15.11348"
  },
  {
    "country": "IT",
    "name": "Povo",
    "lat": "46.06698",
    "lng": "11.15503"
  },
  {
    "country": "IT",
    "name": "Torvaianica",
    "lat": "41.62112",
    "lng": "12.46197"
  },
  {
    "country": "IT",
    "name": "Ospedaletto",
    "lat": "45.50462",
    "lng": "10.84212"
  },
  {
    "country": "IT",
    "name": "Castromediano",
    "lat": "40.32803",
    "lng": "18.17877"
  },
  {
    "country": "IT",
    "name": "Giorgilorio",
    "lat": "40.38683",
    "lng": "18.14873"
  },
  {
    "country": "IT",
    "name": "Sieci",
    "lat": "43.78847",
    "lng": "11.39445"
  },
  {
    "country": "IT",
    "name": "Monticelli Terme",
    "lat": "44.72881",
    "lng": "10.39444"
  },
  {
    "country": "IT",
    "name": "Montemerlo",
    "lat": "45.38033",
    "lng": "11.70815"
  },
  {
    "country": "IT",
    "name": "Vambolieri",
    "lat": "37.57417",
    "lng": "15.16019"
  },
  {
    "country": "IT",
    "name": "Rastignano-Carteria di Sesto",
    "lat": "44.43623",
    "lng": "11.35695"
  },
  {
    "country": "IT",
    "name": "Trebbo",
    "lat": "44.55629",
    "lng": "11.31901"
  },
  {
    "country": "IT",
    "name": "Cazzago-Ex Polo",
    "lat": "45.44159",
    "lng": "12.07406"
  },
  {
    "country": "IT",
    "name": "Cadenabbia",
    "lat": "45.98861",
    "lng": "9.23615"
  },
  {
    "country": "IT",
    "name": "Trinità d'Agultu",
    "lat": "40.98589",
    "lng": "8.91377"
  },
  {
    "country": "IT",
    "name": "Oscano",
    "lat": "43.15863",
    "lng": "12.33776"
  },
  {
    "country": "IT",
    "name": "Corrubbio",
    "lat": "45.48685",
    "lng": "10.90359"
  },
  {
    "country": "IT",
    "name": "Civesio",
    "lat": "45.39556",
    "lng": "9.2668"
  },
  {
    "country": "IT",
    "name": "Noverasco-Sporting Mirasole",
    "lat": "45.39544",
    "lng": "9.21427"
  },
  {
    "country": "IT",
    "name": "Fizzonasco",
    "lat": "45.37241",
    "lng": "9.19066"
  },
  {
    "country": "IT",
    "name": "Chiaravalle",
    "lat": "45.41731",
    "lng": "9.23985"
  },
  {
    "country": "IT",
    "name": "Caleppio",
    "lat": "45.43436",
    "lng": "9.3825"
  },
  {
    "country": "IT",
    "name": "Vigonzone",
    "lat": "45.2735",
    "lng": "9.3098"
  },
  {
    "country": "IT",
    "name": "Novegro-Tregarezzo-San Felice",
    "lat": "45.46778",
    "lng": "9.28122"
  },
  {
    "country": "IT",
    "name": "Lisanza",
    "lat": "45.73926",
    "lng": "8.59852"
  },
  {
    "country": "IT",
    "name": "Focene",
    "lat": "41.81367",
    "lng": "12.21354"
  },
  {
    "country": "IT",
    "name": "Passoscuro",
    "lat": "41.90209",
    "lng": "12.15723"
  },
  {
    "country": "IT",
    "name": "Marina San Nicola",
    "lat": "41.93102",
    "lng": "12.12024"
  },
  {
    "country": "IT",
    "name": "Marina di Cerveteri",
    "lat": "41.97997",
    "lng": "12.05295"
  },
  {
    "country": "IT",
    "name": "Granarolo",
    "lat": "44.35859",
    "lng": "11.93459"
  },
  {
    "country": "IT",
    "name": "Ara Nova",
    "lat": "41.933",
    "lng": "12.2398"
  },
  {
    "country": "IT",
    "name": "Calerno",
    "lat": "44.74875",
    "lng": "10.48603"
  },
  {
    "country": "IT",
    "name": "Vitinia",
    "lat": "41.79124",
    "lng": "12.4081"
  },
  {
    "country": "IT",
    "name": "Avane",
    "lat": "43.79049",
    "lng": "10.40982"
  },
  {
    "country": "IT",
    "name": "Donoratico",
    "lat": "43.16927",
    "lng": "10.56744"
  },
  {
    "country": "IT",
    "name": "Lodrone-Darzo",
    "lat": "45.82962",
    "lng": "10.5356"
  },
  {
    "country": "IT",
    "name": "Acitrezza",
    "lat": "37.5596",
    "lng": "15.1599"
  },
  {
    "country": "IT",
    "name": "Caselle",
    "lat": "45.4134",
    "lng": "10.8957"
  },
  {
    "country": "IT",
    "name": "Pianello Vallesina",
    "lat": "43.48817",
    "lng": "13.16188"
  },
  {
    "country": "IT",
    "name": "Nova Siri Scalo",
    "lat": "40.13177",
    "lng": "16.63593"
  },
  {
    "country": "IT",
    "name": "Carruba",
    "lat": "37.69062",
    "lng": "15.18815"
  },
  {
    "country": "IT",
    "name": "Marcelli",
    "lat": "43.49204",
    "lng": "13.62545"
  },
  {
    "country": "IT",
    "name": "Monti",
    "lat": "44.24864",
    "lng": "10.00854"
  },
  {
    "country": "IT",
    "name": "Lu Bagnu",
    "lat": "40.90184",
    "lng": "8.68555"
  },
  {
    "country": "IT",
    "name": "Montalbano",
    "lat": "40.77827",
    "lng": "17.48157"
  },
  {
    "country": "IT",
    "name": "Valgatara",
    "lat": "45.53467",
    "lng": "10.91191"
  },
  {
    "country": "IT",
    "name": "Fratta Terme",
    "lat": "44.14157",
    "lng": "12.10213"
  },
  {
    "country": "IT",
    "name": "Triscina",
    "lat": "37.58717",
    "lng": "12.78912"
  },
  {
    "country": "IT",
    "name": "Sant'Angelo",
    "lat": "40.69841",
    "lng": "13.89316"
  },
  {
    "country": "IT",
    "name": "Marina di Vasto",
    "lat": "42.09373",
    "lng": "14.72683"
  },
  {
    "country": "IT",
    "name": "Lavinio",
    "lat": "41.5035",
    "lng": "12.58973"
  },
  {
    "country": "IT",
    "name": "Lisiera",
    "lat": "45.57848",
    "lng": "11.61178"
  },
  {
    "country": "IT",
    "name": "Sandrà",
    "lat": "45.46067",
    "lng": "10.78686"
  },
  {
    "country": "IT",
    "name": "Villa Adriana",
    "lat": "41.95499",
    "lng": "12.77216"
  },
  {
    "country": "IT",
    "name": "Trodica",
    "lat": "43.27458",
    "lng": "13.59369"
  },
  {
    "country": "IT",
    "name": "Valle Santa",
    "lat": "41.94532",
    "lng": "12.31971"
  },
  {
    "country": "IT",
    "name": "Riscone",
    "lat": "46.77685",
    "lng": "11.95149"
  },
  {
    "country": "IT",
    "name": "San Teodoro",
    "lat": "44.41458",
    "lng": "8.91"
  },
  {
    "country": "IT",
    "name": "Ried",
    "lat": "46.92993",
    "lng": "11.52414"
  },
  {
    "country": "IT",
    "name": "Monasterolo",
    "lat": "45.23549",
    "lng": "7.50821"
  },
  {
    "country": "IT",
    "name": "Tuturano",
    "lat": "40.54474",
    "lng": "17.94754"
  },
  {
    "country": "IT",
    "name": "Baggiovara",
    "lat": "44.60416",
    "lng": "10.86256"
  },
  {
    "country": "IT",
    "name": "Bastardo",
    "lat": "42.87144",
    "lng": "12.55943"
  },
  {
    "country": "IT",
    "name": "Ponte San Marco",
    "lat": "45.47686",
    "lng": "10.41315"
  },
  {
    "country": "IT",
    "name": "Vidalengo",
    "lat": "45.52235",
    "lng": "9.64128"
  },
  {
    "country": "IT",
    "name": "Musestre",
    "lat": "45.58864",
    "lng": "12.37249"
  },
  {
    "country": "IT",
    "name": "Pianoconte",
    "lat": "38.47432",
    "lng": "14.92857"
  },
  {
    "country": "IT",
    "name": "Bornato",
    "lat": "45.59368",
    "lng": "10.0409"
  },
  {
    "country": "IT",
    "name": "Caulonia Marina",
    "lat": "38.34679",
    "lng": "16.46353"
  },
  {
    "country": "IT",
    "name": "Cavalcaselle",
    "lat": "45.43695",
    "lng": "10.72652"
  },
  {
    "country": "IT",
    "name": "Arbizzano-Santa Maria",
    "lat": "45.49489",
    "lng": "10.93831"
  },
  {
    "country": "IT",
    "name": "Massa Finalese",
    "lat": "44.8524",
    "lng": "11.21429"
  },
  {
    "country": "IT",
    "name": "Roncanova",
    "lat": "45.14318",
    "lng": "11.10349"
  },
  {
    "country": "IT",
    "name": "Santa Lucia",
    "lat": "41.30409",
    "lng": "14.07937"
  },
  {
    "country": "IT",
    "name": "Grottola",
    "lat": "41.31708",
    "lng": "14.04121"
  },
  {
    "country": "IT",
    "name": "Torchiati",
    "lat": "40.81837",
    "lng": "14.80165"
  },
  {
    "country": "IT",
    "name": "Castelletto",
    "lat": "44.44015",
    "lng": "11.06478"
  },
  {
    "country": "IT",
    "name": "Praticello di Gattatico",
    "lat": "44.80486",
    "lng": "10.47461"
  },
  {
    "country": "IT",
    "name": "Casale di Mezzani",
    "lat": "44.91534",
    "lng": "10.43015"
  },
  {
    "country": "IT",
    "name": "Calderino",
    "lat": "44.45774",
    "lng": "11.19927"
  },
  {
    "country": "IT",
    "name": "San Polo",
    "lat": "44.88957",
    "lng": "10.35685"
  },
  {
    "country": "IT",
    "name": "Santo Stefano",
    "lat": "46.20865",
    "lng": "13.12626"
  },
  {
    "country": "IT",
    "name": "Cras",
    "lat": "46.17403",
    "lng": "13.62287"
  },
  {
    "country": "IT",
    "name": "Vico",
    "lat": "46.42419",
    "lng": "12.58398"
  },
  {
    "country": "IT",
    "name": "Caseo",
    "lat": "44.94369",
    "lng": "9.27504"
  },
  {
    "country": "IT",
    "name": "Tagliuno",
    "lat": "45.64255",
    "lng": "9.90864"
  },
  {
    "country": "IT",
    "name": "Terraverde-Corte Palasio",
    "lat": "45.31552",
    "lng": "9.56162"
  },
  {
    "country": "IT",
    "name": "Villa Fornace",
    "lat": "44.97194",
    "lng": "9.25215"
  },
  {
    "country": "IT",
    "name": "Miola di Pinè",
    "lat": "46.12668",
    "lng": "11.2485"
  },
  {
    "country": "IT",
    "name": "Roata Rossi",
    "lat": "44.44383",
    "lng": "7.52572"
  },
  {
    "country": "IT",
    "name": "Cancello ed Arnone",
    "lat": "41.07301",
    "lng": "14.02714"
  },
  {
    "country": "IT",
    "name": "Castrocaro Terme e Terra del Sole",
    "lat": "44.18676",
    "lng": "11.96068"
  },
  {
    "country": "IT",
    "name": "Bellaria-Igea Marina",
    "lat": "44.14255",
    "lng": "12.47154"
  },
  {
    "country": "IT",
    "name": "Ca' Savio",
    "lat": "45.45375",
    "lng": "12.45729"
  },
  {
    "country": "IT",
    "name": "Marconia",
    "lat": "40.36355",
    "lng": "16.68823"
  },
  {
    "country": "IT",
    "name": "Corpo Reno",
    "lat": "44.75591",
    "lng": "11.30794"
  },
  {
    "country": "IT",
    "name": "Montepaone Lido",
    "lat": "38.72951",
    "lng": "16.54241"
  },
  {
    "country": "IT",
    "name": "Priula-Colfosco",
    "lat": "45.81998",
    "lng": "12.25847"
  },
  {
    "country": "IT",
    "name": "Sambuceto",
    "lat": "42.42168",
    "lng": "14.18747"
  },
  {
    "country": "IT",
    "name": "Villanova",
    "lat": "41.96357",
    "lng": "12.75633"
  },
  {
    "country": "IT",
    "name": "Arcavacata",
    "lat": "39.35846",
    "lng": "16.20844"
  },
  {
    "country": "IT",
    "name": "Cona",
    "lat": "44.80583",
    "lng": "11.7069"
  },
  {
    "country": "IT",
    "name": "Basilicagoiano",
    "lat": "44.70545",
    "lng": "10.40457"
  },
  {
    "country": "IT",
    "name": "Ponte Felcino",
    "lat": "43.13049",
    "lng": "12.44914"
  },
  {
    "country": "IT",
    "name": "Margine Coperta-Traversagna",
    "lat": "43.87977",
    "lng": "10.75733"
  },
  {
    "country": "IT",
    "name": "Marina di Ardea-Tor San Lorenzo",
    "lat": "41.55439",
    "lng": "12.54115"
  },
  {
    "country": "IT",
    "name": "Trestina",
    "lat": "43.36597",
    "lng": "12.23701"
  },
  {
    "country": "IT",
    "name": "Villalba",
    "lat": "41.95387",
    "lng": "12.72938"
  },
  {
    "country": "IT",
    "name": "Marco Simone",
    "lat": "41.95544",
    "lng": "12.64775"
  },
  {
    "country": "IT",
    "name": "Rablà",
    "lat": "46.67044",
    "lng": "11.06458"
  },
  {
    "country": "IT",
    "name": "Latina Scalo",
    "lat": "41.53157",
    "lng": "12.94567"
  },
  {
    "country": "IT",
    "name": "San Mamete",
    "lat": "46.02505",
    "lng": "9.05364"
  },
  {
    "country": "IT",
    "name": "San Bernardo",
    "lat": "46.40088",
    "lng": "10.84445"
  },
  {
    "country": "IT",
    "name": "Tornimparte",
    "lat": "42.29007",
    "lng": "13.30092"
  },
  {
    "country": "IT",
    "name": "Villa Pigna",
    "lat": "42.83324",
    "lng": "13.63446"
  },
  {
    "country": "IT",
    "name": "Piane di Morro",
    "lat": "42.82317",
    "lng": "13.653"
  },
  {
    "country": "IT",
    "name": "Villaseta",
    "lat": "37.29877",
    "lng": "13.55919"
  },
  {
    "country": "IT",
    "name": "Osteno",
    "lat": "46.00668",
    "lng": "9.08385"
  },
  {
    "country": "IT",
    "name": "Osteria Nuova",
    "lat": "42.03721",
    "lng": "12.30924"
  },
  {
    "country": "IT",
    "name": "Sezze Scalo",
    "lat": "41.49701",
    "lng": "13.04257"
  },
  {
    "country": "IT",
    "name": "San Giacomo",
    "lat": "46.16019",
    "lng": "10.02532"
  },
  {
    "country": "IT",
    "name": "Centobuchi",
    "lat": "42.89521",
    "lng": "13.84809"
  },
  {
    "country": "IT",
    "name": "Mantignano-Ugnano",
    "lat": "43.782",
    "lng": "11.16958"
  },
  {
    "country": "IT",
    "name": "Cortoghiana",
    "lat": "39.21177",
    "lng": "8.46548"
  },
  {
    "country": "IT",
    "name": "Cerbara",
    "lat": "43.49913",
    "lng": "12.21113"
  },
  {
    "country": "IT",
    "name": "Lesna",
    "lat": "45.05418",
    "lng": "7.62031"
  },
  {
    "country": "IT",
    "name": "Pedemonte",
    "lat": "45.50302",
    "lng": "10.91865"
  },
  {
    "country": "IT",
    "name": "San Nicolò",
    "lat": "45.05685",
    "lng": "9.6054"
  },
  {
    "country": "IT",
    "name": "Tre Fontane",
    "lat": "37.56989",
    "lng": "12.72423"
  },
  {
    "country": "IT",
    "name": "Lido dei Pini",
    "lat": "41.5366",
    "lng": "12.58976"
  },
  {
    "country": "IT",
    "name": "Corsanico-Bargecchia",
    "lat": "43.90828",
    "lng": "10.30621"
  },
  {
    "country": "IT",
    "name": "Bassone",
    "lat": "45.4511",
    "lng": "10.89449"
  },
  {
    "country": "IT",
    "name": "Carraia",
    "lat": "43.89534",
    "lng": "11.1819"
  },
  {
    "country": "IT",
    "name": "Poggetto",
    "lat": "43.8279",
    "lng": "11.03847"
  },
  {
    "country": "IT",
    "name": "Catena",
    "lat": "43.84254",
    "lng": "11.01658"
  },
  {
    "country": "IT",
    "name": "Santa Lucia",
    "lat": "41.9824",
    "lng": "12.65625"
  },
  {
    "country": "IT",
    "name": "Fossoli",
    "lat": "44.8216",
    "lng": "10.88977"
  },
  {
    "country": "IT",
    "name": "San Bartolomeo",
    "lat": "44.67402",
    "lng": "10.53941"
  },
  {
    "country": "IT",
    "name": "San Marco",
    "lat": "40.2674",
    "lng": "14.93897"
  },
  {
    "country": "IT",
    "name": "San Vigilio",
    "lat": "46.69884",
    "lng": "11.93104"
  },
  {
    "country": "IT",
    "name": "Marina di Casal Velino",
    "lat": "40.17665",
    "lng": "15.12218"
  },
  {
    "country": "IT",
    "name": "Scarlino Scalo",
    "lat": "42.93992",
    "lng": "10.83766"
  },
  {
    "country": "IT",
    "name": "Ponte Pattoli",
    "lat": "43.17807",
    "lng": "12.42842"
  },
  {
    "country": "IT",
    "name": "Cologna Spiaggia",
    "lat": "42.72152",
    "lng": "13.98311"
  },
  {
    "country": "IT",
    "name": "Santa Maria Apparente",
    "lat": "43.29661",
    "lng": "13.69223"
  },
  {
    "country": "IT",
    "name": "Sant'Andrea Ionio Marina",
    "lat": "38.62001",
    "lng": "16.54927"
  },
  {
    "country": "IT",
    "name": "Mezzate",
    "lat": "45.44385",
    "lng": "9.29452"
  },
  {
    "country": "IT",
    "name": "San Bovio-San Felice",
    "lat": "45.46282",
    "lng": "9.31263"
  },
  {
    "country": "IT",
    "name": "Fontana delle Monache",
    "lat": "44.11386",
    "lng": "10.27943"
  },
  {
    "country": "IT",
    "name": "Montignano-Marzocca",
    "lat": "43.67451",
    "lng": "13.29093"
  },
  {
    "country": "IT",
    "name": "Centinarola",
    "lat": "43.83117",
    "lng": "12.98962"
  },
  {
    "country": "IT",
    "name": "Fenile",
    "lat": "43.84126",
    "lng": "12.96747"
  },
  {
    "country": "IT",
    "name": "Weather Station",
    "lat": "37.96136",
    "lng": "16.0997"
  },
  {
    "country": "IT",
    "name": "Cavallino",
    "lat": "45.47456",
    "lng": "12.54855"
  },
  {
    "country": "IT",
    "name": "Cropani Marina",
    "lat": "38.92376",
    "lng": "16.8108"
  },
  {
    "country": "IT",
    "name": "Roccelletta",
    "lat": "38.81126",
    "lng": "16.5982"
  },
  {
    "country": "IT",
    "name": "San Paolo",
    "lat": "41.12476",
    "lng": "16.79258"
  },
  {
    "country": "IT",
    "name": "Monterusciello",
    "lat": "40.86874",
    "lng": "14.08276"
  },
  {
    "country": "IT",
    "name": "Romano Banco",
    "lat": "45.42309",
    "lng": "9.10707"
  },
  {
    "country": "IT",
    "name": "Casa Santa",
    "lat": "38.02514",
    "lng": "12.5484"
  },
  {
    "country": "IT",
    "name": "Arpino",
    "lat": "40.88882",
    "lng": "14.32015"
  },
  {
    "country": "IT",
    "name": "Paolo VI",
    "lat": "40.52218",
    "lng": "17.27401"
  },
  {
    "country": "IT",
    "name": "Breo",
    "lat": "44.39865",
    "lng": "7.81903"
  },
  {
    "country": "IT",
    "name": "Progresso",
    "lat": "44.56892",
    "lng": "11.3642"
  },
  {
    "country": "IT",
    "name": "Mejaniga",
    "lat": "45.45768",
    "lng": "11.90644"
  },
  {
    "country": "IT",
    "name": "La Massimina-Casal Lumbroso",
    "lat": "41.87332",
    "lng": "12.35694"
  },
  {
    "country": "IT",
    "name": "Chiugiana-La Commenda",
    "lat": "43.09823",
    "lng": "12.30818"
  },
  {
    "country": "IT",
    "name": "San Zeno-San Giuseppe",
    "lat": "45.75727",
    "lng": "11.76208"
  },
  {
    "country": "IT",
    "name": "Piazza",
    "lat": "45.50933",
    "lng": "10.42408"
  },
  {
    "country": "IT",
    "name": "Spicchio-Sovigliana",
    "lat": "43.73016",
    "lng": "10.93921"
  },
  {
    "country": "IT",
    "name": "Ponte Cingoli",
    "lat": "45.59751",
    "lng": "10.10687"
  },
  {
    "country": "IT",
    "name": "Piattoni-Villa Sant'Antonio",
    "lat": "42.8663",
    "lng": "13.7112"
  },
  {
    "country": "IT",
    "name": "Fiesso",
    "lat": "45.41954",
    "lng": "12.03378"
  },
  {
    "country": "IT",
    "name": "Canalicchio",
    "lat": "37.54097",
    "lng": "15.09645"
  },
  {
    "country": "IT",
    "name": "Colombiera-Molicciara",
    "lat": "44.0875",
    "lng": "10.01037"
  },
  {
    "country": "IT",
    "name": "Belvedere",
    "lat": "45.69001",
    "lng": "11.7718"
  },
  {
    "country": "IT",
    "name": "Selcetta",
    "lat": "41.76529",
    "lng": "12.47533"
  },
  {
    "country": "IT",
    "name": "Andreotta",
    "lat": "39.3075",
    "lng": "16.2177"
  },
  {
    "country": "IT",
    "name": "Casano-Dogana-Isola",
    "lat": "44.07565",
    "lng": "10.03381"
  },
  {
    "country": "IT",
    "name": "Ciaculli",
    "lat": "38.0753",
    "lng": "13.40719"
  },
  {
    "country": "IT",
    "name": "Vill'Albese",
    "lat": "45.79684",
    "lng": "9.18859"
  },
  {
    "country": "IT",
    "name": "Sala",
    "lat": "40.85536",
    "lng": "14.87343"
  },
  {
    "country": "IT",
    "name": "Villatora",
    "lat": "45.38768",
    "lng": "11.96736"
  },
  {
    "country": "IT",
    "name": "Pontasserchio",
    "lat": "43.77953",
    "lng": "10.41673"
  },
  {
    "country": "IT",
    "name": "Veggia-Villalunga",
    "lat": "44.5607",
    "lng": "10.75621"
  },
  {
    "country": "IT",
    "name": "Quadrivio",
    "lat": "40.62494",
    "lng": "15.10353"
  },
  {
    "country": "IT",
    "name": "Mandriola-Sant'Agostino",
    "lat": "45.36926",
    "lng": "11.85101"
  },
  {
    "country": "IT",
    "name": "Gerbole",
    "lat": "45.00115",
    "lng": "7.5067"
  },
  {
    "country": "IT",
    "name": "Lancusi-Penta-Bolano",
    "lat": "40.76125",
    "lng": "14.78524"
  },
  {
    "country": "IT",
    "name": "Pedemonte",
    "lat": "44.50307",
    "lng": "8.92614"
  },
  {
    "country": "IT",
    "name": "Frescada",
    "lat": "45.62878",
    "lng": "12.23671"
  },
  {
    "country": "IT",
    "name": "San Donnino",
    "lat": "43.79547",
    "lng": "11.14654"
  },
  {
    "country": "IT",
    "name": "Caselle",
    "lat": "45.41129",
    "lng": "11.81663"
  },
  {
    "country": "IT",
    "name": "Piazza del Galdo-Sant'Angelo",
    "lat": "40.7739",
    "lng": "14.71696"
  },
  {
    "country": "IT",
    "name": "Lanzara",
    "lat": "40.77473",
    "lng": "14.67619"
  },
  {
    "country": "IT",
    "name": "Airali",
    "lat": "44.8167",
    "lng": "7.25157"
  },
  {
    "country": "IT",
    "name": "Vado Centro",
    "lat": "44.26857",
    "lng": "8.43225"
  },
  {
    "country": "IT",
    "name": "Eremo",
    "lat": "45.13119",
    "lng": "10.74271"
  },
  {
    "country": "IT",
    "name": "San Nicolò a Tordino",
    "lat": "42.69648",
    "lng": "13.79708"
  },
  {
    "country": "IT",
    "name": "Villa Raspa",
    "lat": "42.45542",
    "lng": "14.18457"
  },
  {
    "country": "IT",
    "name": "Canova-San Zeno",
    "lat": "45.72116",
    "lng": "9.4003"
  },
  {
    "country": "IT",
    "name": "Santa Margherita",
    "lat": "45.63391",
    "lng": "9.23013"
  },
  {
    "country": "IT",
    "name": "Setteville",
    "lat": "41.94375",
    "lng": "12.65122"
  },
  {
    "country": "IT",
    "name": "Pagliare",
    "lat": "42.86906",
    "lng": "13.76906"
  },
  {
    "country": "IT",
    "name": "Rometta Marea",
    "lat": "38.23264",
    "lng": "15.40955"
  },
  {
    "country": "IT",
    "name": "Piazzola",
    "lat": "40.87265",
    "lng": "14.50016"
  },
  {
    "country": "IT",
    "name": "Roveleto",
    "lat": "44.96332",
    "lng": "9.8539"
  },
  {
    "country": "IT",
    "name": "Colle Verde",
    "lat": "41.97694",
    "lng": "12.61855"
  },
  {
    "country": "IT",
    "name": "San Martino Bassa",
    "lat": "42.51827",
    "lng": "14.13045"
  },
  {
    "country": "IT",
    "name": "Regoledo",
    "lat": "46.13319",
    "lng": "9.54597"
  },
  {
    "country": "IT",
    "name": "Ciconia",
    "lat": "42.73356",
    "lng": "12.134"
  },
  {
    "country": "IT",
    "name": "Strà-Montanara-Pieve",
    "lat": "45.42367",
    "lng": "11.15749"
  },
  {
    "country": "IT",
    "name": "Valle Martella",
    "lat": "41.87827",
    "lng": "12.74677"
  },
  {
    "country": "IT",
    "name": "Sant'Antonio",
    "lat": "40.63626",
    "lng": "14.89845"
  },
  {
    "country": "IT",
    "name": "Torretta-Scalzapecora",
    "lat": "40.91015",
    "lng": "14.13456"
  },
  {
    "country": "IT",
    "name": "Tivolille Pasquali-Merenzata",
    "lat": "39.27953",
    "lng": "16.20738"
  },
  {
    "country": "IT",
    "name": "Torelli-Torrette",
    "lat": "40.90777",
    "lng": "14.75184"
  },
  {
    "country": "IT",
    "name": "Piazza-Tralia-Pendolo",
    "lat": "40.67351",
    "lng": "14.50455"
  },
  {
    "country": "IT",
    "name": "San Rocco",
    "lat": "43.82316",
    "lng": "10.86121"
  },
  {
    "country": "IT",
    "name": "Villa Rosa",
    "lat": "42.85059",
    "lng": "13.92015"
  },
  {
    "country": "IT",
    "name": "Rogoredo-Valaperta-Rimoldo",
    "lat": "45.67695",
    "lng": "9.33277"
  },
  {
    "country": "IT",
    "name": "Su Planu",
    "lat": "39.25487",
    "lng": "9.1066"
  },
  {
    "country": "IT",
    "name": "Genio Civile",
    "lat": "41.54807",
    "lng": "12.69161"
  },
  {
    "country": "IT",
    "name": "Carobbio",
    "lat": "45.66424",
    "lng": "9.83027"
  },
  {
    "country": "IT",
    "name": "Borgo Stazione",
    "lat": "43.28461",
    "lng": "13.6442"
  },
  {
    "country": "IT",
    "name": "Capaccio Scalo",
    "lat": "40.45531",
    "lng": "15.00891"
  },
  {
    "country": "IT",
    "name": "Piazza Roma",
    "lat": "40.70434",
    "lng": "14.543"
  },
  {
    "country": "IT",
    "name": "Npp 23 (Parco Leonardo)",
    "lat": "41.80035",
    "lng": "12.30028"
  },
  {
    "country": "IT",
    "name": "Toscanella",
    "lat": "44.38248",
    "lng": "11.63965"
  },
  {
    "country": "IT",
    "name": "Lunetta-Frassino",
    "lat": "45.16016",
    "lng": "10.82059"
  },
  {
    "country": "IT",
    "name": "Vighignolo",
    "lat": "45.49542",
    "lng": "9.04308"
  },
  {
    "country": "IT",
    "name": "Santa Teresa",
    "lat": "42.42753",
    "lng": "14.15816"
  },
  {
    "country": "IT",
    "name": "Osteria Grande",
    "lat": "44.42845",
    "lng": "11.5218"
  },
  {
    "country": "IT",
    "name": "Roè",
    "lat": "45.62576",
    "lng": "10.4996"
  },
  {
    "country": "IT",
    "name": "Laghetto",
    "lat": "41.96734",
    "lng": "12.65609"
  },
  {
    "country": "IT",
    "name": "Chianchitta-Trappitello",
    "lat": "37.82984",
    "lng": "15.25077"
  },
  {
    "country": "IT",
    "name": "Onè",
    "lat": "45.78374",
    "lng": "11.87404"
  },
  {
    "country": "IT",
    "name": "Santa Lucia",
    "lat": "43.88296",
    "lng": "10.70307"
  },
  {
    "country": "IT",
    "name": "San Brancato",
    "lat": "40.25822",
    "lng": "16.25661"
  },
  {
    "country": "IT",
    "name": "Bojon-Lova",
    "lat": "45.33981",
    "lng": "12.08282"
  },
  {
    "country": "IT",
    "name": "Grunuovo-Campomaggiore San Luca",
    "lat": "41.27228",
    "lng": "13.80684"
  },
  {
    "country": "IT",
    "name": "Mercatale-San Quirico",
    "lat": "44.04426",
    "lng": "11.15163"
  },
  {
    "country": "IT",
    "name": "Bolladello-Peveranza",
    "lat": "45.68649",
    "lng": "8.84517"
  },
  {
    "country": "IT",
    "name": "Castelnuovo Vomano",
    "lat": "42.62933",
    "lng": "13.85003"
  },
  {
    "country": "IT",
    "name": "Valcanneto",
    "lat": "41.95078",
    "lng": "12.15734"
  },
  {
    "country": "IT",
    "name": "San Floriano-Olmi",
    "lat": "45.67349",
    "lng": "12.33039"
  },
  {
    "country": "IT",
    "name": "Fossignano",
    "lat": "41.59226",
    "lng": "12.56333"
  },
  {
    "country": "IT",
    "name": "Parco Scizzo-Parchitello",
    "lat": "41.07457",
    "lng": "16.99329"
  },
  {
    "country": "IT",
    "name": "Budrio",
    "lat": "44.09916",
    "lng": "12.34033"
  },
  {
    "country": "IT",
    "name": "Manoppello Scalo",
    "lat": "42.30762",
    "lng": "14.05363"
  },
  {
    "country": "IT",
    "name": "Solarolo",
    "lat": "45.55047",
    "lng": "10.55489"
  },
  {
    "country": "IT",
    "name": "Garino",
    "lat": "44.97325",
    "lng": "7.61728"
  },
  {
    "country": "IT",
    "name": "Annunziata",
    "lat": "41.121",
    "lng": "14.36518"
  },
  {
    "country": "IT",
    "name": "Villa d'Agri",
    "lat": "40.35426",
    "lng": "15.8277"
  },
  {
    "country": "IT",
    "name": "Torre Caracciolo",
    "lat": "40.87551",
    "lng": "14.17859"
  },
  {
    "country": "IT",
    "name": "Piazza Caduti",
    "lat": "45.70513",
    "lng": "9.50251"
  },
  {
    "country": "IT",
    "name": "Campo Limpido-Favale",
    "lat": "41.96732",
    "lng": "12.77016"
  },
  {
    "country": "IT",
    "name": "Marina di Davoli",
    "lat": "38.66361",
    "lng": "16.54825"
  },
  {
    "country": "IT",
    "name": "Crocetta-Nogarè",
    "lat": "45.82707",
    "lng": "12.03013"
  },
  {
    "country": "IT",
    "name": "Mombretto",
    "lat": "45.4239",
    "lng": "9.36506"
  },
  {
    "country": "IT",
    "name": "Antessano",
    "lat": "40.73293",
    "lng": "14.77744"
  },
  {
    "country": "IT",
    "name": "Bormida-Genepro",
    "lat": "44.39051",
    "lng": "8.19952"
  },
  {
    "country": "IT",
    "name": "San Giacomo",
    "lat": "46.45624",
    "lng": "11.33365"
  },
  {
    "country": "IT",
    "name": "Bellante Stazione",
    "lat": "42.7065",
    "lng": "13.83953"
  },
  {
    "country": "IT",
    "name": "San Vigilio",
    "lat": "45.60808",
    "lng": "10.19442"
  },
  {
    "country": "IT",
    "name": "Levata",
    "lat": "45.12518",
    "lng": "10.76794"
  },
  {
    "country": "IT",
    "name": "Lido di Fermo",
    "lat": "43.20556",
    "lng": "13.78467"
  },
  {
    "country": "IT",
    "name": "Parmezzana Calzana",
    "lat": "45.6335",
    "lng": "10.0954"
  },
  {
    "country": "IT",
    "name": "Cascine-La Croce",
    "lat": "43.72885",
    "lng": "10.61471"
  },
  {
    "country": "IT",
    "name": "Casette d'Ete",
    "lat": "43.25385",
    "lng": "13.68319"
  },
  {
    "country": "IT",
    "name": "Taverna",
    "lat": "39.4304",
    "lng": "16.2309"
  },
  {
    "country": "IT",
    "name": "Pieve",
    "lat": "45.53924",
    "lng": "11.8293"
  },
  {
    "country": "IT",
    "name": "Vigliano-Bettolino",
    "lat": "45.43272",
    "lng": "9.34422"
  },
  {
    "country": "IT",
    "name": "Prato Perillo",
    "lat": "40.3969",
    "lng": "15.52503"
  },
  {
    "country": "IT",
    "name": "Castelnovo",
    "lat": "45.61557",
    "lng": "11.45938"
  },
  {
    "country": "IT",
    "name": "Cava-Cuculera Nobile",
    "lat": "38.89383",
    "lng": "16.62226"
  },
  {
    "country": "IT",
    "name": "Colombella",
    "lat": "43.15262",
    "lng": "12.48239"
  },
  {
    "country": "IT",
    "name": "Roteglia",
    "lat": "44.48417",
    "lng": "10.68832"
  },
  {
    "country": "IT",
    "name": "Carrubazza-Motta",
    "lat": "37.55323",
    "lng": "15.10819"
  },
  {
    "country": "IT",
    "name": "San Bartolomeo",
    "lat": "41.48265",
    "lng": "13.85747"
  },
  {
    "country": "IT",
    "name": "S.P. in Palazzi",
    "lat": "43.32776",
    "lng": "10.50881"
  },
  {
    "country": "IT",
    "name": "Starza Vecchia",
    "lat": "40.89035",
    "lng": "14.40138"
  },
  {
    "country": "IT",
    "name": "Cerza",
    "lat": "37.54297",
    "lng": "15.1051"
  },
  {
    "country": "IT",
    "name": "Ravina",
    "lat": "46.03944",
    "lng": "11.11215"
  },
  {
    "country": "IT",
    "name": "Valleggia",
    "lat": "44.2808",
    "lng": "8.42967"
  },
  {
    "country": "IT",
    "name": "Monticello",
    "lat": "45.71244",
    "lng": "9.31481"
  },
  {
    "country": "IT",
    "name": "Chiesa",
    "lat": "45.69011",
    "lng": "9.91282"
  },
  {
    "country": "IT",
    "name": "Capezzano-Cologna",
    "lat": "40.71518",
    "lng": "14.77364"
  },
  {
    "country": "IT",
    "name": "Ceresane-Curanuova",
    "lat": "45.52435",
    "lng": "8.00708"
  },
  {
    "country": "IT",
    "name": "Marzanello",
    "lat": "41.31447",
    "lng": "14.11611"
  },
  {
    "country": "IT",
    "name": "Limidi",
    "lat": "44.76427",
    "lng": "10.92002"
  },
  {
    "country": "IT",
    "name": "Stazione-Fornola",
    "lat": "44.12984",
    "lng": "9.89159"
  },
  {
    "country": "IT",
    "name": "Stella",
    "lat": "42.88698",
    "lng": "13.80948"
  },
  {
    "country": "IT",
    "name": "Pratole",
    "lat": "40.6258",
    "lng": "14.92565"
  },
  {
    "country": "IT",
    "name": "San Pietro",
    "lat": "40.82398",
    "lng": "14.78476"
  },
  {
    "country": "IT",
    "name": "Ponticella",
    "lat": "44.45446",
    "lng": "11.37851"
  },
  {
    "country": "IT",
    "name": "Le Rughe",
    "lat": "42.06885",
    "lng": "12.37624"
  },
  {
    "country": "IT",
    "name": "Pascarola",
    "lat": "40.97643",
    "lng": "14.305"
  },
  {
    "country": "IT",
    "name": "Ferriera",
    "lat": "45.08382",
    "lng": "7.43017"
  },
  {
    "country": "IT",
    "name": "San Damaso",
    "lat": "44.60102",
    "lng": "10.97373"
  },
  {
    "country": "IT",
    "name": "Laghetto",
    "lat": "41.85628",
    "lng": "12.72498"
  },
  {
    "country": "IT",
    "name": "Chef-Lieu",
    "lat": "45.75091",
    "lng": "7.35372"
  },
  {
    "country": "IT",
    "name": "San Francesco",
    "lat": "43.77483",
    "lng": "11.44842"
  },
  {
    "country": "IT",
    "name": "Torchione-Moia",
    "lat": "46.15486",
    "lng": "9.85996"
  },
  {
    "country": "IT",
    "name": "Vighizzolo",
    "lat": "45.43524",
    "lng": "10.35507"
  },
  {
    "country": "IT",
    "name": "Brognoligo-Costalunga",
    "lat": "45.44869",
    "lng": "11.29379"
  },
  {
    "country": "IT",
    "name": "Coperchia",
    "lat": "40.72005",
    "lng": "14.76654"
  },
  {
    "country": "IT",
    "name": "Casali-San Potito",
    "lat": "40.7639",
    "lng": "14.67501"
  },
  {
    "country": "IT",
    "name": "Bolognano-Vignole",
    "lat": "45.91196",
    "lng": "10.90497"
  },
  {
    "country": "IT",
    "name": "Taggì",
    "lat": "45.4607",
    "lng": "11.81865"
  },
  {
    "country": "IT",
    "name": "Grignano Polesine",
    "lat": "45.0435",
    "lng": "11.74682"
  },
  {
    "country": "IT",
    "name": "Trecella",
    "lat": "45.51498",
    "lng": "9.47905"
  },
  {
    "country": "IT",
    "name": "Praticello",
    "lat": "44.80436",
    "lng": "10.4731"
  },
  {
    "country": "IT",
    "name": "Passirana",
    "lat": "45.54792",
    "lng": "9.04412"
  },
  {
    "country": "IT",
    "name": "Lamie di Olimpie-Selva",
    "lat": "40.81714",
    "lng": "17.33478"
  },
  {
    "country": "IT",
    "name": "Moiano",
    "lat": "40.65172",
    "lng": "14.46601"
  },
  {
    "country": "IT",
    "name": "Cantalupo",
    "lat": "45.57813",
    "lng": "8.98261"
  },
  {
    "country": "IT",
    "name": "San Pietro",
    "lat": "45.44209",
    "lng": "11.12968"
  },
  {
    "country": "IT",
    "name": "Albuccione",
    "lat": "41.95245",
    "lng": "12.69873"
  },
  {
    "country": "IT",
    "name": "Sinigo",
    "lat": "46.63488",
    "lng": "11.17926"
  },
  {
    "country": "IT",
    "name": "Mussotto",
    "lat": "44.71766",
    "lng": "8.03404"
  },
  {
    "country": "IT",
    "name": "Robegano",
    "lat": "45.54253",
    "lng": "12.11924"
  },
  {
    "country": "IT",
    "name": "Cintolese",
    "lat": "43.84606",
    "lng": "10.82644"
  },
  {
    "country": "IT",
    "name": "Settimo",
    "lat": "39.39158",
    "lng": "16.23998"
  },
  {
    "country": "IT",
    "name": "Fogliano",
    "lat": "44.64751",
    "lng": "10.64505"
  },
  {
    "country": "IT",
    "name": "Talponada",
    "lat": "45.70351",
    "lng": "12.49053"
  },
  {
    "country": "IT",
    "name": "Rilievo",
    "lat": "37.91638",
    "lng": "12.54058"
  },
  {
    "country": "IT",
    "name": "Gallo-Tre Re-Mezzana Corti",
    "lat": "45.12563",
    "lng": "9.12227"
  },
  {
    "country": "IT",
    "name": "Osigo",
    "lat": "45.87532",
    "lng": "9.29559"
  },
  {
    "country": "IT",
    "name": "Romito Magra",
    "lat": "44.09838",
    "lng": "9.9318"
  },
  {
    "country": "IT",
    "name": "Casarea",
    "lat": "40.88828",
    "lng": "14.36349"
  },
  {
    "country": "IT",
    "name": "Castelminio",
    "lat": "45.64493",
    "lng": "11.98734"
  },
  {
    "country": "IT",
    "name": "Gaggino",
    "lat": "45.80787",
    "lng": "8.96427"
  },
  {
    "country": "IT",
    "name": "Riozzo",
    "lat": "45.34622",
    "lng": "9.32168"
  },
  {
    "country": "IT",
    "name": "Fornaci",
    "lat": "45.02816",
    "lng": "7.59869"
  },
  {
    "country": "IT",
    "name": "Vidardo",
    "lat": "45.25667",
    "lng": "9.40241"
  },
  {
    "country": "IT",
    "name": "Borgo Santa Maria Immacolata",
    "lat": "42.61172",
    "lng": "14.04553"
  },
  {
    "country": "IT",
    "name": "Cappone",
    "lat": "43.83071",
    "lng": "12.74458"
  },
  {
    "country": "IT",
    "name": "Meledo",
    "lat": "45.43821",
    "lng": "11.4156"
  },
  {
    "country": "IT",
    "name": "Zona 179",
    "lat": "41.00313",
    "lng": "15.61868"
  },
  {
    "country": "IT",
    "name": "Pionca",
    "lat": "45.46591",
    "lng": "11.96232"
  },
  {
    "country": "IT",
    "name": "Stazione",
    "lat": "43.50046",
    "lng": "13.15149"
  },
  {
    "country": "IT",
    "name": "Poggio dei Pini",
    "lat": "39.14717",
    "lng": "8.97139"
  },
  {
    "country": "IT",
    "name": "Lucino",
    "lat": "45.7835",
    "lng": "9.0434"
  },
  {
    "country": "IT",
    "name": "Pezzano-Filetta",
    "lat": "40.69773",
    "lng": "14.86971"
  },
  {
    "country": "IT",
    "name": "Piano dei Geli",
    "lat": "38.09919",
    "lng": "13.27478"
  },
  {
    "country": "IT",
    "name": "Scannabue-Cascine Capri",
    "lat": "45.39306",
    "lng": "9.59302"
  },
  {
    "country": "IT",
    "name": "Monte Migliore-La Selvotta",
    "lat": "41.7206",
    "lng": "12.50206"
  },
  {
    "country": "IT",
    "name": "Caldine",
    "lat": "43.82834",
    "lng": "11.30442"
  },
  {
    "country": "IT",
    "name": "Manesseno",
    "lat": "44.47816",
    "lng": "8.92784"
  },
  {
    "country": "IT",
    "name": "Giammoro",
    "lat": "38.20372",
    "lng": "15.30666"
  },
  {
    "country": "IT",
    "name": "Piediripa",
    "lat": "43.27751",
    "lng": "13.48712"
  },
  {
    "country": "IT",
    "name": "Asciano",
    "lat": "43.75159",
    "lng": "10.46506"
  },
  {
    "country": "IT",
    "name": "Santa Maria di Non",
    "lat": "45.51322",
    "lng": "11.85364"
  },
  {
    "country": "IT",
    "name": "Guardavalle Marina",
    "lat": "38.47957",
    "lng": "16.57656"
  },
  {
    "country": "IT",
    "name": "Osteria Nuova",
    "lat": "44.58457",
    "lng": "11.23739"
  },
  {
    "country": "IT",
    "name": "Gerbido",
    "lat": "45.04449",
    "lng": "7.61408"
  },
  {
    "country": "IT",
    "name": "Selino Basso",
    "lat": "45.81029",
    "lng": "9.53495"
  },
  {
    "country": "IT",
    "name": "Longara",
    "lat": "44.5711",
    "lng": "11.30386"
  },
  {
    "country": "IT",
    "name": "San Gregorio",
    "lat": "45.34286",
    "lng": "11.29933"
  },
  {
    "country": "IT",
    "name": "Capriano",
    "lat": "45.72298",
    "lng": "9.25526"
  },
  {
    "country": "IT",
    "name": "Galta",
    "lat": "45.39095",
    "lng": "12.0234"
  },
  {
    "country": "IT",
    "name": "Montan-Angelin-Arensod",
    "lat": "45.7282",
    "lng": "7.27647"
  },
  {
    "country": "IT",
    "name": "Maugeri",
    "lat": "37.58608",
    "lng": "15.11785"
  },
  {
    "country": "IT",
    "name": "Montedecoro",
    "lat": "41.02772",
    "lng": "14.41774"
  },
  {
    "country": "IT",
    "name": "Dodici Morelli",
    "lat": "44.79234",
    "lng": "11.29124"
  },
  {
    "country": "IT",
    "name": "Carchitti",
    "lat": "41.78688",
    "lng": "12.82955"
  },
  {
    "country": "IT",
    "name": "Carrara-Pontenuovo",
    "lat": "41.54045",
    "lng": "12.95468"
  },
  {
    "country": "IT",
    "name": "Area Produttiva",
    "lat": "41.68211",
    "lng": "12.50697"
  },
  {
    "country": "IT",
    "name": "Formica",
    "lat": "44.46838",
    "lng": "11.01337"
  },
  {
    "country": "IT",
    "name": "Baganzola",
    "lat": "44.85513",
    "lng": "10.30706"
  },
  {
    "country": "IT",
    "name": "Villa Raverio",
    "lat": "45.69189",
    "lng": "9.26239"
  },
  {
    "country": "IT",
    "name": "Saint Maurice",
    "lat": "45.71771",
    "lng": "7.25547"
  },
  {
    "country": "IT",
    "name": "Fabrizio",
    "lat": "39.63939",
    "lng": "16.55666"
  },
  {
    "country": "IT",
    "name": "Pizzano",
    "lat": "44.355",
    "lng": "11.41499"
  },
  {
    "country": "IT",
    "name": "Bandito",
    "lat": "44.72282",
    "lng": "7.82403"
  },
  {
    "country": "IT",
    "name": "Villa Musone",
    "lat": "43.44624",
    "lng": "13.60312"
  },
  {
    "country": "IT",
    "name": "Bivio Santa Cecilia",
    "lat": "40.52224",
    "lng": "15.00018"
  },
  {
    "country": "IT",
    "name": "Penitro",
    "lat": "41.27328",
    "lng": "13.69262"
  },
  {
    "country": "IT",
    "name": "Zoccorino-Vergo",
    "lat": "45.69735",
    "lng": "9.25377"
  },
  {
    "country": "IT",
    "name": "Pedalino",
    "lat": "37.0232",
    "lng": "14.58116"
  },
  {
    "country": "IT",
    "name": "Alpo",
    "lat": "45.37687",
    "lng": "10.91979"
  },
  {
    "country": "IT",
    "name": "Banzano",
    "lat": "40.84338",
    "lng": "14.80182"
  },
  {
    "country": "IT",
    "name": "Millepini",
    "lat": "45.46967",
    "lng": "9.33763"
  },
  {
    "country": "IT",
    "name": "Tagliaferro",
    "lat": "44.9785",
    "lng": "7.6643"
  },
  {
    "country": "IT",
    "name": "Mulino",
    "lat": "44.49257",
    "lng": "11.04667"
  },
  {
    "country": "IT",
    "name": "Città Giardino",
    "lat": "37.10444",
    "lng": "15.21172"
  },
  {
    "country": "IT",
    "name": "Piano Maglio-Blandino",
    "lat": "38.05793",
    "lng": "13.30909"
  },
  {
    "country": "IT",
    "name": "Bodio",
    "lat": "45.78989",
    "lng": "8.75146"
  },
  {
    "country": "IT",
    "name": "Arino",
    "lat": "45.43854",
    "lng": "12.05443"
  },
  {
    "country": "IT",
    "name": "Sant'Angelo in Villa-Giglio",
    "lat": "41.66217",
    "lng": "13.42871"
  },
  {
    "country": "IT",
    "name": "Sant'Agata Martesana",
    "lat": "45.5222",
    "lng": "9.38382"
  },
  {
    "country": "IT",
    "name": "Santa Monica-Cella",
    "lat": "43.95765",
    "lng": "12.68846"
  },
  {
    "country": "IT",
    "name": "Gallo",
    "lat": "43.78636",
    "lng": "12.71334"
  },
  {
    "country": "IT",
    "name": "Pomaretto",
    "lat": "45.15194",
    "lng": "8.04661"
  },
  {
    "country": "IT",
    "name": "Villa San Giuseppe",
    "lat": "42.86862",
    "lng": "13.74481"
  },
  {
    "country": "IT",
    "name": "Geromina",
    "lat": "45.53645",
    "lng": "9.5754"
  },
  {
    "country": "IT",
    "name": "Roreto",
    "lat": "44.66932",
    "lng": "7.83423"
  },
  {
    "country": "IT",
    "name": "Amodio-Massariola",
    "lat": "40.88872",
    "lng": "14.09091"
  },
  {
    "country": "IT",
    "name": "Faella",
    "lat": "43.62652",
    "lng": "11.51844"
  },
  {
    "country": "IT",
    "name": "San Tommaso Tre Archi",
    "lat": "43.22771",
    "lng": "13.77503"
  },
  {
    "country": "IT",
    "name": "Capezzano Inferiore",
    "lat": "40.70067",
    "lng": "14.77301"
  },
  {
    "country": "IT",
    "name": "Marcellina",
    "lat": "39.76578",
    "lng": "15.82311"
  },
  {
    "country": "IT",
    "name": "Fornase",
    "lat": "45.47586",
    "lng": "12.16273"
  },
  {
    "country": "IT",
    "name": "Nocera Scalo",
    "lat": "39.01576",
    "lng": "16.1204"
  },
  {
    "country": "IT",
    "name": "Tonengo-Casale",
    "lat": "45.28609",
    "lng": "7.93964"
  },
  {
    "country": "IT",
    "name": "Onigo",
    "lat": "45.85701",
    "lng": "11.99073"
  },
  {
    "country": "IT",
    "name": "Mairano",
    "lat": "45.31019",
    "lng": "9.35907"
  },
  {
    "country": "IT",
    "name": "Sferracavallo",
    "lat": "42.72631",
    "lng": "12.09569"
  },
  {
    "country": "IT",
    "name": "Villa Ceccolini",
    "lat": "43.86481",
    "lng": "12.83605"
  },
  {
    "country": "IT",
    "name": "Pasta",
    "lat": "45.01131",
    "lng": "7.55243"
  },
  {
    "country": "IT",
    "name": "Villaggio del Pino-Le Ginestre",
    "lat": "37.58292",
    "lng": "15.00377"
  },
  {
    "country": "IT",
    "name": "San Cipriano-S.Barbara-Centinale",
    "lat": "43.56863",
    "lng": "11.48467"
  },
  {
    "country": "IT",
    "name": "Piana San Raffaele",
    "lat": "45.1529",
    "lng": "7.85013"
  },
  {
    "country": "IT",
    "name": "San Michele Tiorre",
    "lat": "44.6853",
    "lng": "10.26317"
  },
  {
    "country": "IT",
    "name": "Piano di Conca",
    "lat": "43.89413",
    "lng": "10.29493"
  },
  {
    "country": "IT",
    "name": "Montelera",
    "lat": "45.15429",
    "lng": "7.4429"
  },
  {
    "country": "IT",
    "name": "Casco",
    "lat": "45.71078",
    "lng": "9.82483"
  },
  {
    "country": "IT",
    "name": "Gello",
    "lat": "43.75402",
    "lng": "10.42386"
  },
  {
    "country": "IT",
    "name": "Drubiaglio-Grangia",
    "lat": "45.09552",
    "lng": "7.4194"
  },
  {
    "country": "IT",
    "name": "Stazione",
    "lat": "43.9146",
    "lng": "11.01414"
  },
  {
    "country": "IT",
    "name": "Colle Campano-Scrima",
    "lat": "41.62364",
    "lng": "13.46336"
  },
  {
    "country": "IT",
    "name": "Barbisano",
    "lat": "45.88224",
    "lng": "12.18632"
  },
  {
    "country": "IT",
    "name": "Malavicina",
    "lat": "45.29912",
    "lng": "10.78677"
  },
  {
    "country": "IT",
    "name": "Colli di Enea",
    "lat": "41.65554",
    "lng": "12.49035"
  },
  {
    "country": "IT",
    "name": "Tregasio",
    "lat": "45.67771",
    "lng": "9.28806"
  },
  {
    "country": "IT",
    "name": "Macchia",
    "lat": "40.65353",
    "lng": "14.97879"
  },
  {
    "country": "IT",
    "name": "Moniego",
    "lat": "45.56126",
    "lng": "12.08705"
  },
  {
    "country": "IT",
    "name": "Gabbio-Cereda-Ramate",
    "lat": "45.90959",
    "lng": "8.42113"
  },
  {
    "country": "IT",
    "name": "Buffalora-Bettole",
    "lat": "45.49681",
    "lng": "10.27518"
  },
  {
    "country": "IT",
    "name": "Materdomini",
    "lat": "40.65571",
    "lng": "17.95949"
  },
  {
    "country": "IT",
    "name": "Macine-Borgo Loreto",
    "lat": "43.48611",
    "lng": "13.08725"
  },
  {
    "country": "IT",
    "name": "Ottava",
    "lat": "40.78525",
    "lng": "8.47543"
  },
  {
    "country": "IT",
    "name": "San Vincenzo",
    "lat": "44.73878",
    "lng": "11.43668"
  },
  {
    "country": "IT",
    "name": "Villa Ciambra",
    "lat": "38.06129",
    "lng": "13.32"
  },
  {
    "country": "IT",
    "name": "Baratte",
    "lat": "45.1116",
    "lng": "7.23643"
  },
  {
    "country": "IT",
    "name": "Metato",
    "lat": "43.77352",
    "lng": "10.37106"
  },
  {
    "country": "IT",
    "name": "Acconia",
    "lat": "38.83585",
    "lng": "16.2653"
  },
  {
    "country": "IT",
    "name": "Quattro Strade",
    "lat": "45.6955",
    "lng": "9.37681"
  },
  {
    "country": "IT",
    "name": "Bottega",
    "lat": "43.84523",
    "lng": "12.74999"
  },
  {
    "country": "IT",
    "name": "Valenzatico",
    "lat": "43.8668",
    "lng": "10.96497"
  },
  {
    "country": "IT",
    "name": "Savonera",
    "lat": "45.11368",
    "lng": "7.61506"
  },
  {
    "country": "IT",
    "name": "Matinella",
    "lat": "40.50158",
    "lng": "15.06692"
  },
  {
    "country": "IT",
    "name": "Castello",
    "lat": "45.9498",
    "lng": "8.67566"
  },
  {
    "country": "IT",
    "name": "Montano",
    "lat": "45.79423",
    "lng": "9.02218"
  },
  {
    "country": "IT",
    "name": "San Pierino",
    "lat": "43.71423",
    "lng": "10.81374"
  },
  {
    "country": "IT",
    "name": "Borghetto-Melara",
    "lat": "44.09852",
    "lng": "9.99073"
  },
  {
    "country": "IT",
    "name": "San Biagio",
    "lat": "45.37518",
    "lng": "11.73713"
  },
  {
    "country": "IT",
    "name": "Domio",
    "lat": "45.61049",
    "lng": "13.83103"
  },
  {
    "country": "IT",
    "name": "Canonica",
    "lat": "45.65587",
    "lng": "9.28749"
  },
  {
    "country": "IT",
    "name": "Savarna-Conventello",
    "lat": "44.50717",
    "lng": "12.10621"
  },
  {
    "country": "IT",
    "name": "Sala al Barro",
    "lat": "45.82057",
    "lng": "9.3622"
  },
  {
    "country": "IT",
    "name": "Cà Dè Fabbri",
    "lat": "44.61962",
    "lng": "11.45503"
  },
  {
    "country": "IT",
    "name": "Litta Parodi-Cascinagrossa",
    "lat": "44.87336",
    "lng": "8.71246"
  },
  {
    "country": "IT",
    "name": "Bertipaglia",
    "lat": "45.31594",
    "lng": "11.88547"
  },
  {
    "country": "IT",
    "name": "San Donato",
    "lat": "43.70298",
    "lng": "10.78754"
  },
  {
    "country": "IT",
    "name": "Padiglione",
    "lat": "43.8518",
    "lng": "12.72129"
  },
  {
    "country": "IT",
    "name": "Villair-Amerique",
    "lat": "45.74793",
    "lng": "7.38982"
  },
  {
    "country": "IT",
    "name": "Brenno Useria",
    "lat": "45.86148",
    "lng": "8.87801"
  },
  {
    "country": "IT",
    "name": "Torrion Quartara",
    "lat": "45.41819",
    "lng": "8.61472"
  },
  {
    "country": "IT",
    "name": "Campagnola",
    "lat": "45.35833",
    "lng": "11.04956"
  },
  {
    "country": "IT",
    "name": "Bastia",
    "lat": "45.38609",
    "lng": "11.65196"
  },
  {
    "country": "IT",
    "name": "Borgo Melano",
    "lat": "45.01578",
    "lng": "7.57656"
  },
  {
    "country": "IT",
    "name": "Santo Stefano",
    "lat": "39.34734",
    "lng": "16.19898"
  },
  {
    "country": "IT",
    "name": "Albareto",
    "lat": "44.68964",
    "lng": "10.96713"
  },
  {
    "country": "IT",
    "name": "San Giovanni",
    "lat": "37.73538",
    "lng": "15.15887"
  },
  {
    "country": "IT",
    "name": "San Giovanni-San Bernardino",
    "lat": "44.79297",
    "lng": "9.60871"
  },
  {
    "country": "IT",
    "name": "Caniezza",
    "lat": "45.85274",
    "lng": "11.899"
  },
  {
    "country": "IT",
    "name": "Dragonea",
    "lat": "40.67917",
    "lng": "14.71094"
  },
  {
    "country": "IT",
    "name": "Bivio di Capanelle",
    "lat": "42.11962",
    "lng": "12.59395"
  },
  {
    "country": "IT",
    "name": "San Biagio",
    "lat": "45.09942",
    "lng": "10.84728"
  },
  {
    "country": "IT",
    "name": "La Rotta",
    "lat": "43.6585",
    "lng": "10.67837"
  },
  {
    "country": "IT",
    "name": "Sesto Cremonese",
    "lat": "45.17568",
    "lng": "9.9144"
  },
  {
    "country": "IT",
    "name": "Maresso",
    "lat": "45.68755",
    "lng": "9.35593"
  },
  {
    "country": "IT",
    "name": "Campanella-Gianforma",
    "lat": "36.9263",
    "lng": "14.8336"
  },
  {
    "country": "IT",
    "name": "Fonte Umano-San Martino Alta",
    "lat": "42.52084",
    "lng": "14.1076"
  },
  {
    "country": "IT",
    "name": "Ponton dell'Elce",
    "lat": "42.0227",
    "lng": "12.23505"
  },
  {
    "country": "IT",
    "name": "Pagliarone",
    "lat": "40.63006",
    "lng": "14.91325"
  },
  {
    "country": "IT",
    "name": "Guidomandri Marina",
    "lat": "38.04528",
    "lng": "15.46303"
  },
  {
    "country": "IT",
    "name": "Sciarborasca",
    "lat": "44.40182",
    "lng": "8.61541"
  },
  {
    "country": "IT",
    "name": "Cavallina",
    "lat": "43.98353",
    "lng": "11.23147"
  },
  {
    "country": "IT",
    "name": "Sasi",
    "lat": "37.90217",
    "lng": "12.88788"
  },
  {
    "country": "IT",
    "name": "Cuasso al Piano",
    "lat": "45.89454",
    "lng": "8.87951"
  },
  {
    "country": "IT",
    "name": "Salvo Marina",
    "lat": "42.07037",
    "lng": "14.76597"
  },
  {
    "country": "IT",
    "name": "Battaglione-Bagnara",
    "lat": "45.11638",
    "lng": "10.06726"
  },
  {
    "country": "IT",
    "name": "Ca' Rainati",
    "lat": "45.75764",
    "lng": "11.85113"
  },
  {
    "country": "IT",
    "name": "Tabiago-Cibrone",
    "lat": "45.75639",
    "lng": "9.26684"
  },
  {
    "country": "IT",
    "name": "Bagno",
    "lat": "44.65545",
    "lng": "10.75881"
  },
  {
    "country": "IT",
    "name": "Gavarno-Tribulina",
    "lat": "45.71734",
    "lng": "9.77512"
  },
  {
    "country": "IT",
    "name": "Stazione Montalto-Coretto",
    "lat": "39.4072",
    "lng": "16.24313"
  },
  {
    "country": "IT",
    "name": "Tronca",
    "lat": "39.24617",
    "lng": "17.10582"
  },
  {
    "country": "IT",
    "name": "Ariano",
    "lat": "40.65668",
    "lng": "15.02481"
  },
  {
    "country": "IT",
    "name": "Grignano",
    "lat": "45.61819",
    "lng": "9.54235"
  },
  {
    "country": "IT",
    "name": "Velasca",
    "lat": "45.63165",
    "lng": "9.35519"
  },
  {
    "country": "IT",
    "name": "Cavino",
    "lat": "45.51709",
    "lng": "11.88466"
  },
  {
    "country": "IT",
    "name": "Asparetto",
    "lat": "45.21991",
    "lng": "11.18263"
  },
  {
    "country": "IT",
    "name": "Locara",
    "lat": "45.41207",
    "lng": "11.33262"
  },
  {
    "country": "IT",
    "name": "Zorlesco",
    "lat": "45.20035",
    "lng": "9.61603"
  },
  {
    "country": "IT",
    "name": "Oltre Brenta",
    "lat": "45.41207",
    "lng": "11.99803"
  },
  {
    "country": "IT",
    "name": "Cepina",
    "lat": "46.43609",
    "lng": "10.35713"
  },
  {
    "country": "IT",
    "name": "Lamie",
    "lat": "41.03364",
    "lng": "16.87559"
  },
  {
    "country": "IT",
    "name": "Pineta",
    "lat": "46.43994",
    "lng": "11.34727"
  },
  {
    "country": "IT",
    "name": "Fénis",
    "lat": "45.73469",
    "lng": "7.49544"
  },
  {
    "country": "IT",
    "name": "Casette Verdini",
    "lat": "43.25104",
    "lng": "13.40156"
  },
  {
    "country": "IT",
    "name": "Pozzale-Case Nuove",
    "lat": "43.69584",
    "lng": "10.95651"
  },
  {
    "country": "IT",
    "name": "San Giuseppe le Prata-Cotropagno",
    "lat": "41.67788",
    "lng": "13.39664"
  },
  {
    "country": "IT",
    "name": "San Biagio",
    "lat": "43.51597",
    "lng": "13.49643"
  },
  {
    "country": "IT",
    "name": "San Michele dei Mucchietti",
    "lat": "44.50847",
    "lng": "10.74726"
  },
  {
    "country": "IT",
    "name": "Casola",
    "lat": "41.09513",
    "lng": "14.38172"
  },
  {
    "country": "IT",
    "name": "Pagliare",
    "lat": "42.64372",
    "lng": "13.95171"
  },
  {
    "country": "IT",
    "name": "Laura",
    "lat": "40.4322",
    "lng": "14.98886"
  },
  {
    "country": "IT",
    "name": "Case Campoli-Panetta",
    "lat": "41.67296",
    "lng": "13.4717"
  },
  {
    "country": "IT",
    "name": "Pontegradella",
    "lat": "44.83813",
    "lng": "11.6628"
  },
  {
    "country": "IT",
    "name": "Montesolaro",
    "lat": "45.721",
    "lng": "9.1176"
  },
  {
    "country": "IT",
    "name": "Quaderni",
    "lat": "45.32915",
    "lng": "10.78951"
  },
  {
    "country": "IT",
    "name": "Gorgo della Chiesa",
    "lat": "45.78747",
    "lng": "12.5627"
  },
  {
    "country": "IT",
    "name": "Castelceriolo",
    "lat": "44.91723",
    "lng": "8.69384"
  },
  {
    "country": "IT",
    "name": "San Martino",
    "lat": "45.90807",
    "lng": "12.34132"
  },
  {
    "country": "IT",
    "name": "Girardi-Bellavista-Terrazze",
    "lat": "42.10266",
    "lng": "12.5796"
  },
  {
    "country": "IT",
    "name": "Venegazzù",
    "lat": "45.77934",
    "lng": "12.09148"
  },
  {
    "country": "IT",
    "name": "Saletto",
    "lat": "45.474",
    "lng": "11.86042"
  },
  {
    "country": "IT",
    "name": "Palazzolo",
    "lat": "37.56224",
    "lng": "14.92987"
  },
  {
    "country": "IT",
    "name": "Vergnasco",
    "lat": "45.48803",
    "lng": "8.08553"
  },
  {
    "country": "IT",
    "name": "San Nicola",
    "lat": "40.61055",
    "lng": "8.98841"
  },
  {
    "country": "IT",
    "name": "Selva",
    "lat": "42.11442",
    "lng": "14.34425"
  },
  {
    "country": "IT",
    "name": "Cologna-Caraverio",
    "lat": "45.75611",
    "lng": "9.34579"
  },
  {
    "country": "IT",
    "name": "Pratissolo",
    "lat": "44.60416",
    "lng": "10.674"
  },
  {
    "country": "IT",
    "name": "San Fedele-Lusignano",
    "lat": "44.04559",
    "lng": "8.18078"
  },
  {
    "country": "IT",
    "name": "Premenugo",
    "lat": "45.4679",
    "lng": "9.38458"
  },
  {
    "country": "IT",
    "name": "San Martino in Trignano",
    "lat": "42.74125",
    "lng": "12.66836"
  },
  {
    "country": "IT",
    "name": "Figino",
    "lat": "45.49261",
    "lng": "9.07779"
  },
  {
    "country": "IT",
    "name": "Abbazia",
    "lat": "45.748",
    "lng": "9.84205"
  },
  {
    "country": "IT",
    "name": "Belvedere-Piano Tavola",
    "lat": "37.52955",
    "lng": "14.98786"
  },
  {
    "country": "IT",
    "name": "Cinzano",
    "lat": "44.69307",
    "lng": "7.92103"
  },
  {
    "country": "IT",
    "name": "Manzolino",
    "lat": "44.59577",
    "lng": "11.09982"
  },
  {
    "country": "IT",
    "name": "Fraviano",
    "lat": "46.29691",
    "lng": "10.69197"
  },
  {
    "country": "IT",
    "name": "Baraggia",
    "lat": "45.85516",
    "lng": "8.90885"
  },
  {
    "country": "IT",
    "name": "Cavoni-Ginestreto",
    "lat": "39.45212",
    "lng": "16.26267"
  },
  {
    "country": "IT",
    "name": "Piangaiano",
    "lat": "45.78877",
    "lng": "9.99461"
  },
  {
    "country": "IT",
    "name": "Pulce",
    "lat": "44.44909",
    "lng": "11.41153"
  },
  {
    "country": "IT",
    "name": "Castelletto",
    "lat": "45.3315",
    "lng": "10.23335"
  },
  {
    "country": "IT",
    "name": "Villaguattera",
    "lat": "45.44409",
    "lng": "11.81767"
  },
  {
    "country": "IT",
    "name": "La Botte",
    "lat": "41.98176",
    "lng": "12.76775"
  },
  {
    "country": "IT",
    "name": "Niviano",
    "lat": "44.94027",
    "lng": "9.62878"
  },
  {
    "country": "IT",
    "name": "Strada",
    "lat": "43.40337",
    "lng": "13.22077"
  },
  {
    "country": "IT",
    "name": "Mandrogne",
    "lat": "44.86308",
    "lng": "8.74676"
  },
  {
    "country": "IT",
    "name": "Bellavista",
    "lat": "43.44197",
    "lng": "11.16051"
  },
  {
    "country": "IT",
    "name": "Carifi-Torello-Priscoli",
    "lat": "40.79136",
    "lng": "14.73212"
  },
  {
    "country": "IT",
    "name": "San Jacopo al Girone",
    "lat": "43.76956",
    "lng": "11.34032"
  },
  {
    "country": "IT",
    "name": "Folzano",
    "lat": "45.49587",
    "lng": "10.2065"
  },
  {
    "country": "IT",
    "name": "Piegolelle-San Bartolomeo",
    "lat": "40.68583",
    "lng": "14.82312"
  },
  {
    "country": "IT",
    "name": "Cavazzona",
    "lat": "44.57326",
    "lng": "11.11903"
  },
  {
    "country": "IT",
    "name": "Villanova",
    "lat": "43.73926",
    "lng": "12.93529"
  },
  {
    "country": "IT",
    "name": "Via Lippia",
    "lat": "43.08611",
    "lng": "12.48106"
  },
  {
    "country": "IT",
    "name": "Torre Colonna-Sperone",
    "lat": "38.02986",
    "lng": "13.57377"
  },
  {
    "country": "IT",
    "name": "La Forma",
    "lat": "41.83449",
    "lng": "13.09092"
  },
  {
    "country": "IT",
    "name": "Ronco",
    "lat": "45.59611",
    "lng": "10.13531"
  },
  {
    "country": "IT",
    "name": "Campocavallo",
    "lat": "43.4612",
    "lng": "13.49679"
  },
  {
    "country": "IT",
    "name": "Camnago-Boscone",
    "lat": "45.80472",
    "lng": "8.97934"
  },
  {
    "country": "IT",
    "name": "San Pietro Belvedere",
    "lat": "43.57011",
    "lng": "10.66604"
  },
  {
    "country": "IT",
    "name": "Piane",
    "lat": "43.09703",
    "lng": "13.49502"
  },
  {
    "country": "IT",
    "name": "Prato di Coppola",
    "lat": "41.4175",
    "lng": "12.88157"
  },
  {
    "country": "IT",
    "name": "Ramiola",
    "lat": "44.70055",
    "lng": "10.0911"
  },
  {
    "country": "IT",
    "name": "Casalazzara",
    "lat": "41.62299",
    "lng": "12.57634"
  },
  {
    "country": "IT",
    "name": "Villanova",
    "lat": "42.38251",
    "lng": "14.12338"
  },
  {
    "country": "IT",
    "name": "Riva",
    "lat": "44.89252",
    "lng": "7.38189"
  },
  {
    "country": "IT",
    "name": "Piazza",
    "lat": "44.38597",
    "lng": "7.83163"
  },
  {
    "country": "IT",
    "name": "San Bartolomeo",
    "lat": "41.81409",
    "lng": "12.91745"
  },
  {
    "country": "IT",
    "name": "Moncucco",
    "lat": "45.31032",
    "lng": "9.0392"
  },
  {
    "country": "IT",
    "name": "Raffa",
    "lat": "45.57047",
    "lng": "10.52962"
  },
  {
    "country": "IT",
    "name": "Mantegazza",
    "lat": "45.50946",
    "lng": "8.97321"
  },
  {
    "country": "IT",
    "name": "Felina",
    "lat": "44.45478",
    "lng": "10.46067"
  },
  {
    "country": "IT",
    "name": "Zona Industriale",
    "lat": "43.26155",
    "lng": "13.48834"
  },
  {
    "country": "IT",
    "name": "Villaggio del Sole",
    "lat": "45.61398",
    "lng": "9.10725"
  },
  {
    "country": "IT",
    "name": "San Paolo",
    "lat": "46.47207",
    "lng": "11.26021"
  },
  {
    "country": "IT",
    "name": "Arlate",
    "lat": "45.72363",
    "lng": "9.44242"
  },
  {
    "country": "IT",
    "name": "Madonna Dell'Albero",
    "lat": "44.38115",
    "lng": "12.20044"
  },
  {
    "country": "IT",
    "name": "Country Park",
    "lat": "40.88234",
    "lng": "14.07786"
  },
  {
    "country": "IT",
    "name": "Cereda-Cozza Cornedo",
    "lat": "45.60181",
    "lng": "11.3674"
  },
  {
    "country": "IT",
    "name": "Pianura Vomano",
    "lat": "42.63028",
    "lng": "13.91548"
  },
  {
    "country": "IT",
    "name": "Ponterio-Pian di Porto",
    "lat": "42.80769",
    "lng": "12.41024"
  },
  {
    "country": "IT",
    "name": "Sam Marino",
    "lat": "44.80738",
    "lng": "10.91438"
  },
  {
    "country": "IT",
    "name": "Gorzano",
    "lat": "44.51626",
    "lng": "10.87983"
  },
  {
    "country": "IT",
    "name": "Agliandroni-Paternella",
    "lat": "38.1328",
    "lng": "13.06884"
  },
  {
    "country": "IT",
    "name": "Villanova",
    "lat": "45.64027",
    "lng": "9.39187"
  },
  {
    "country": "IT",
    "name": "Villa Fontana",
    "lat": "44.49455",
    "lng": "11.60885"
  },
  {
    "country": "IT",
    "name": "Figliaro",
    "lat": "45.77992",
    "lng": "8.94466"
  },
  {
    "country": "IT",
    "name": "Monte Caminetto",
    "lat": "42.0665",
    "lng": "12.47358"
  },
  {
    "country": "IT",
    "name": "Bubano",
    "lat": "44.41341",
    "lng": "11.78231"
  },
  {
    "country": "IT",
    "name": "Costaroni",
    "lat": "42.07819",
    "lng": "12.53712"
  },
  {
    "country": "IT",
    "name": "Colleranesco",
    "lat": "42.72112",
    "lng": "13.93732"
  },
  {
    "country": "IT",
    "name": "Ballò",
    "lat": "45.45581",
    "lng": "12.07124"
  },
  {
    "country": "IT",
    "name": "Negrone",
    "lat": "45.71028",
    "lng": "9.75811"
  },
  {
    "country": "IT",
    "name": "Rio Salso-Case Bernardi",
    "lat": "43.83439",
    "lng": "12.69031"
  },
  {
    "country": "IT",
    "name": "Rivotorto",
    "lat": "43.04406",
    "lng": "12.62069"
  },
  {
    "country": "IT",
    "name": "Rettifilo-Vannullo",
    "lat": "40.45125",
    "lng": "15.02794"
  },
  {
    "country": "IT",
    "name": "Villa d'Asolo",
    "lat": "45.77193",
    "lng": "11.89981"
  },
  {
    "country": "IT",
    "name": "Osteria del Gatto",
    "lat": "43.28504",
    "lng": "12.74504"
  },
  {
    "country": "IT",
    "name": "Musci",
    "lat": "40.87861",
    "lng": "14.366"
  },
  {
    "country": "IT",
    "name": "Monti d'Arena-Bosco Caggione",
    "lat": "40.3551",
    "lng": "17.36432"
  },
  {
    "country": "IT",
    "name": "Lodetto",
    "lat": "45.55099",
    "lng": "10.03175"
  },
  {
    "country": "IT",
    "name": "Cunettone-Villa",
    "lat": "45.58789",
    "lng": "10.51756"
  },
  {
    "country": "IT",
    "name": "Monticello di Fara",
    "lat": "45.42896",
    "lng": "11.39042"
  },
  {
    "country": "IT",
    "name": "Valle di Vado",
    "lat": "44.26183",
    "lng": "8.41397"
  },
  {
    "country": "IT",
    "name": "Lavinaio-Monterosso",
    "lat": "37.64097",
    "lng": "15.10462"
  },
  {
    "country": "IT",
    "name": "Sant'Apollinare",
    "lat": "45.04115",
    "lng": "11.82533"
  },
  {
    "country": "IT",
    "name": "Valmadonna",
    "lat": "44.97444",
    "lng": "8.61146"
  },
  {
    "country": "IT",
    "name": "Carrozziere",
    "lat": "37.0376",
    "lng": "15.27195"
  },
  {
    "country": "IT",
    "name": "Montebonello",
    "lat": "43.83027",
    "lng": "11.48655"
  },
  {
    "country": "IT",
    "name": "Monte San Giovanni",
    "lat": "44.42014",
    "lng": "11.1717"
  },
  {
    "country": "IT",
    "name": "Nigoline-Bonomelli",
    "lat": "45.62908",
    "lng": "9.98682"
  },
  {
    "country": "IT",
    "name": "San Vito al Mantico",
    "lat": "45.47163",
    "lng": "10.89243"
  },
  {
    "country": "IT",
    "name": "Sabbionara",
    "lat": "45.74152",
    "lng": "10.9574"
  },
  {
    "country": "IT",
    "name": "Riccò",
    "lat": "44.7005",
    "lng": "10.12095"
  },
  {
    "country": "IT",
    "name": "Uggia-Pazzera-Bizzarrino",
    "lat": "43.83434",
    "lng": "10.83154"
  },
  {
    "country": "IT",
    "name": "Castelmassimo",
    "lat": "41.66389",
    "lng": "13.38063"
  },
  {
    "country": "IT",
    "name": "Tavernelle",
    "lat": "45.51498",
    "lng": "11.4486"
  },
  {
    "country": "IT",
    "name": "Villapinta",
    "lat": "46.17508",
    "lng": "9.6795"
  },
  {
    "country": "IT",
    "name": "Poianella",
    "lat": "45.63041",
    "lng": "11.62853"
  },
  {
    "country": "IT",
    "name": "Casale",
    "lat": "41.21972",
    "lng": "14.00231"
  },
  {
    "country": "IT",
    "name": "Tetti Neirotti",
    "lat": "45.05338",
    "lng": "7.54077"
  },
  {
    "country": "IT",
    "name": "Borgo",
    "lat": "40.84022",
    "lng": "14.78364"
  },
  {
    "country": "IT",
    "name": "Caprara",
    "lat": "44.77521",
    "lng": "10.51158"
  },
  {
    "country": "IT",
    "name": "Cerello-Battuello",
    "lat": "45.44716",
    "lng": "8.93105"
  },
  {
    "country": "IT",
    "name": "Bancali",
    "lat": "40.73549",
    "lng": "8.46328"
  },
  {
    "country": "IT",
    "name": "Sambughe",
    "lat": "45.59401",
    "lng": "12.21824"
  },
  {
    "country": "IT",
    "name": "Fossa",
    "lat": "44.92304",
    "lng": "11.02356"
  },
  {
    "country": "IT",
    "name": "Ghiare-Madonna",
    "lat": "44.8077",
    "lng": "8.37404"
  },
  {
    "country": "IT",
    "name": "Vigardolo",
    "lat": "45.60599",
    "lng": "11.58856"
  },
  {
    "country": "IT",
    "name": "Manera",
    "lat": "45.67346",
    "lng": "9.04058"
  },
  {
    "country": "IT",
    "name": "Quattro Strade",
    "lat": "43.70936",
    "lng": "10.65824"
  },
  {
    "country": "IT",
    "name": "Roggione",
    "lat": "45.18378",
    "lng": "9.80739"
  },
  {
    "country": "IT",
    "name": "Giovenzano",
    "lat": "45.27322",
    "lng": "9.11605"
  },
  {
    "country": "IT",
    "name": "Vadue",
    "lat": "39.2806",
    "lng": "16.22875"
  },
  {
    "country": "IT",
    "name": "Campiglione",
    "lat": "43.1763",
    "lng": "13.67043"
  },
  {
    "country": "IT",
    "name": "San Michele",
    "lat": "43.66218",
    "lng": "12.99797"
  },
  {
    "country": "IT",
    "name": "Casa del Diavolo",
    "lat": "43.18762",
    "lng": "12.44923"
  },
  {
    "country": "IT",
    "name": "Villanova",
    "lat": "44.68893",
    "lng": "10.91743"
  },
  {
    "country": "IT",
    "name": "Forche",
    "lat": "44.63646",
    "lng": "10.57316"
  },
  {
    "country": "IT",
    "name": "Barbiano",
    "lat": "44.3895",
    "lng": "11.8865"
  },
  {
    "country": "IT",
    "name": "Novagli",
    "lat": "45.38688",
    "lng": "10.43874"
  },
  {
    "country": "IT",
    "name": "Boscochiaro",
    "lat": "45.13658",
    "lng": "12.12182"
  },
  {
    "country": "IT",
    "name": "Villaggio Residenziale",
    "lat": "45.52826",
    "lng": "9.46737"
  },
  {
    "country": "IT",
    "name": "Costa-Barco",
    "lat": "45.58337",
    "lng": "10.03907"
  },
  {
    "country": "IT",
    "name": "Franche",
    "lat": "40.67175",
    "lng": "14.52139"
  },
  {
    "country": "IT",
    "name": "Berzantina",
    "lat": "44.15786",
    "lng": "10.98083"
  },
  {
    "country": "IT",
    "name": "Fanano",
    "lat": "43.94296",
    "lng": "12.74828"
  },
  {
    "country": "IT",
    "name": "La Rosa",
    "lat": "40.60674",
    "lng": "17.95207"
  },
  {
    "country": "IT",
    "name": "San Vito-Cerreto",
    "lat": "44.023",
    "lng": "10.17212"
  },
  {
    "country": "IT",
    "name": "Guinzano",
    "lat": "45.25678",
    "lng": "9.15869"
  },
  {
    "country": "IT",
    "name": "Fornole",
    "lat": "42.54218",
    "lng": "12.45576"
  },
  {
    "country": "IT",
    "name": "Campofiorenzo-California",
    "lat": "45.66768",
    "lng": "9.31708"
  },
  {
    "country": "IT",
    "name": "Montelarco",
    "lat": "42.16339",
    "lng": "12.48398"
  },
  {
    "country": "IT",
    "name": "Borgo Massano",
    "lat": "43.82495",
    "lng": "12.67961"
  },
  {
    "country": "IT",
    "name": "Sfaranda",
    "lat": "38.05815",
    "lng": "14.83147"
  },
  {
    "country": "IT",
    "name": "Valle San Bartolomeo",
    "lat": "44.95017",
    "lng": "8.6404"
  },
  {
    "country": "IT",
    "name": "Sacca",
    "lat": "45.89953",
    "lng": "10.22008"
  },
  {
    "country": "IT",
    "name": "Cannizzaro-Favara",
    "lat": "38.06163",
    "lng": "13.27167"
  },
  {
    "country": "IT",
    "name": "Regolelli",
    "lat": "42.29315",
    "lng": "12.35131"
  },
  {
    "country": "IT",
    "name": "Rotta",
    "lat": "45.16242",
    "lng": "9.14564"
  },
  {
    "country": "IT",
    "name": "Squillace Lido",
    "lat": "38.77781",
    "lng": "16.57007"
  },
  {
    "country": "IT",
    "name": "Mazara II",
    "lat": "37.68146",
    "lng": "12.60074"
  },
  {
    "country": "IT",
    "name": "Le Forna",
    "lat": "40.92475",
    "lng": "12.96896"
  },
  {
    "country": "IT",
    "name": "Mimosa-Poggio Verde-Nuova Comunità",
    "lat": "41.53871",
    "lng": "14.66879"
  },
  {
    "country": "IT",
    "name": "Capriglia",
    "lat": "40.73216",
    "lng": "14.76035"
  },
  {
    "country": "IT",
    "name": "Sant'Andrea",
    "lat": "44.03328",
    "lng": "12.41893"
  },
  {
    "country": "IT",
    "name": "Fantasina",
    "lat": "45.57325",
    "lng": "10.1779"
  },
  {
    "country": "IT",
    "name": "Monte San Marino",
    "lat": "41.712",
    "lng": "13.31199"
  },
  {
    "country": "IT",
    "name": "Marina",
    "lat": "39.93857",
    "lng": "16.60585"
  },
  {
    "country": "IT",
    "name": "Giacalone",
    "lat": "38.03276",
    "lng": "13.23695"
  },
  {
    "country": "IT",
    "name": "Spinimbecco",
    "lat": "45.14398",
    "lng": "11.37202"
  },
  {
    "country": "IT",
    "name": "Monte",
    "lat": "45.71489",
    "lng": "8.82222"
  },
  {
    "country": "IT",
    "name": "Tombelle",
    "lat": "45.39845",
    "lng": "11.98213"
  },
  {
    "country": "IT",
    "name": "Pievedizio",
    "lat": "45.46062",
    "lng": "10.08771"
  },
  {
    "country": "IT",
    "name": "Fuorni",
    "lat": "40.64063",
    "lng": "14.84925"
  },
  {
    "country": "IT",
    "name": "Barberi",
    "lat": "42.44072",
    "lng": "14.04268"
  },
  {
    "country": "IT",
    "name": "Sant'Antonio",
    "lat": "44.36586",
    "lng": "10.83646"
  },
  {
    "country": "IT",
    "name": "Bosco Ex Parmigiano",
    "lat": "45.10697",
    "lng": "10.0387"
  },
  {
    "country": "IT",
    "name": "Campochiesa",
    "lat": "44.07069",
    "lng": "8.19712"
  },
  {
    "country": "IT",
    "name": "Pietre",
    "lat": "40.70048",
    "lng": "14.61993"
  },
  {
    "country": "IT",
    "name": "Quattro Strade",
    "lat": "43.74148",
    "lng": "11.0807"
  },
  {
    "country": "IT",
    "name": "Masseria Vecchia Ovest",
    "lat": "40.88966",
    "lng": "14.06573"
  },
  {
    "country": "IT",
    "name": "Rosegaferro",
    "lat": "45.34361",
    "lng": "10.80854"
  },
  {
    "country": "IT",
    "name": "Colle Mainello",
    "lat": "41.86975",
    "lng": "12.78767"
  },
  {
    "country": "IT",
    "name": "Sant'Albino",
    "lat": "43.07098",
    "lng": "11.80684"
  },
  {
    "country": "IT",
    "name": "Lido",
    "lat": "40.19128",
    "lng": "16.70692"
  },
  {
    "country": "IT",
    "name": "Cantinella",
    "lat": "39.66458",
    "lng": "16.44912"
  },
  {
    "country": "IT",
    "name": "Casone",
    "lat": "45.49818",
    "lng": "8.87635"
  },
  {
    "country": "IT",
    "name": "Sant'Antonio",
    "lat": "44.75887",
    "lng": "8.06996"
  },
  {
    "country": "IT",
    "name": "Prata Centro",
    "lat": "46.30847",
    "lng": "9.39625"
  },
  {
    "country": "IT",
    "name": "Martelli-Laganosa",
    "lat": "38.6793",
    "lng": "16.53549"
  },
  {
    "country": "IT",
    "name": "Chiesino-Collodi",
    "lat": "43.67954",
    "lng": "10.61106"
  },
  {
    "country": "IT",
    "name": "Ricca",
    "lat": "44.66127",
    "lng": "8.04527"
  },
  {
    "country": "IT",
    "name": "Prato",
    "lat": "44.71589",
    "lng": "10.74797"
  },
  {
    "country": "IT",
    "name": "Foresta",
    "lat": "39.09939",
    "lng": "16.81287"
  },
  {
    "country": "IT",
    "name": "Solara",
    "lat": "44.77163",
    "lng": "11.09287"
  },
  {
    "country": "IT",
    "name": "Villa",
    "lat": "44.74606",
    "lng": "7.90066"
  },
  {
    "country": "IT",
    "name": "Cellore",
    "lat": "45.48646",
    "lng": "11.17831"
  },
  {
    "country": "IT",
    "name": "San Rocco",
    "lat": "44.39653",
    "lng": "7.4723"
  },
  {
    "country": "IT",
    "name": "Isca Marina",
    "lat": "38.60341",
    "lng": "16.55733"
  },
  {
    "country": "IT",
    "name": "Lacugnano",
    "lat": "43.09475",
    "lng": "12.3315"
  },
  {
    "country": "IT",
    "name": "Il Romito",
    "lat": "43.64908",
    "lng": "10.64538"
  },
  {
    "country": "IT",
    "name": "Gabella",
    "lat": "43.7236",
    "lng": "10.49726"
  },
  {
    "country": "IT",
    "name": "Colubro",
    "lat": "41.73506",
    "lng": "12.86726"
  },
  {
    "country": "IT",
    "name": "Borgo",
    "lat": "44.70887",
    "lng": "7.96222"
  },
  {
    "country": "IT",
    "name": "Petrosino",
    "lat": "37.88392",
    "lng": "14.79912"
  },
  {
    "country": "IT",
    "name": "Badile",
    "lat": "45.35061",
    "lng": "9.12705"
  },
  {
    "country": "IT",
    "name": "Belverde",
    "lat": "43.3482",
    "lng": "11.30763"
  },
  {
    "country": "IT",
    "name": "Furato",
    "lat": "45.51468",
    "lng": "8.88063"
  },
  {
    "country": "IT",
    "name": "Gliaca",
    "lat": "38.16317",
    "lng": "14.84768"
  },
  {
    "country": "IT",
    "name": "Bivio San Polo",
    "lat": "41.97418",
    "lng": "12.82993"
  },
  {
    "country": "IT",
    "name": "Borgo Fornari-Pieve",
    "lat": "44.58933",
    "lng": "8.93671"
  },
  {
    "country": "IT",
    "name": "Marocchi",
    "lat": "44.94201",
    "lng": "7.81888"
  },
  {
    "country": "IT",
    "name": "Pian di Mugnone",
    "lat": "43.8181",
    "lng": "11.29585"
  },
  {
    "country": "IT",
    "name": "Spartimento",
    "lat": "40.89105",
    "lng": "14.47236"
  },
  {
    "country": "IT",
    "name": "Montalbano",
    "lat": "43.95879",
    "lng": "12.71646"
  },
  {
    "country": "IT",
    "name": "Garbagnate",
    "lat": "45.77027",
    "lng": "9.29848"
  },
  {
    "country": "IT",
    "name": "Villafranca",
    "lat": "44.03297",
    "lng": "8.10525"
  },
  {
    "country": "IT",
    "name": "Campo",
    "lat": "43.70811",
    "lng": "10.47703"
  },
  {
    "country": "IT",
    "name": "Brongio",
    "lat": "45.76535",
    "lng": "9.31251"
  },
  {
    "country": "IT",
    "name": "Armetta",
    "lat": "41.8128",
    "lng": "12.68782"
  },
  {
    "country": "IT",
    "name": "Provezze",
    "lat": "45.63139",
    "lng": "10.07287"
  },
  {
    "country": "IT",
    "name": "Gavarno Rinnovata",
    "lat": "45.72454",
    "lng": "9.76318"
  },
  {
    "country": "IT",
    "name": "Sant'Andrea",
    "lat": "45.64664",
    "lng": "11.89639"
  },
  {
    "country": "IT",
    "name": "Viadana",
    "lat": "45.37189",
    "lng": "10.33632"
  },
  {
    "country": "IT",
    "name": "Casate",
    "lat": "45.49203",
    "lng": "8.82776"
  },
  {
    "country": "IT",
    "name": "Ludriano",
    "lat": "45.44846",
    "lng": "9.93276"
  },
  {
    "country": "IT",
    "name": "Triginto",
    "lat": "45.40223",
    "lng": "9.32512"
  },
  {
    "country": "IT",
    "name": "Argine",
    "lat": "44.77494",
    "lng": "10.63432"
  },
  {
    "country": "IT",
    "name": "Val di Cava",
    "lat": "43.63832",
    "lng": "10.64896"
  },
  {
    "country": "IT",
    "name": "Costa Lambro",
    "lat": "45.68531",
    "lng": "9.24728"
  },
  {
    "country": "IT",
    "name": "Cartiera-Stazione",
    "lat": "41.65642",
    "lng": "13.24086"
  },
  {
    "country": "IT",
    "name": "Osteria",
    "lat": "43.5495",
    "lng": "13.02188"
  },
  {
    "country": "IT",
    "name": "Malche-Santa Croce-Serroni",
    "lat": "40.70925",
    "lng": "14.90668"
  },
  {
    "country": "IT",
    "name": "Pradelle",
    "lat": "45.28315",
    "lng": "10.87083"
  },
  {
    "country": "IT",
    "name": "Valli",
    "lat": "45.22342",
    "lng": "12.1899"
  },
  {
    "country": "IT",
    "name": "Pennisi",
    "lat": "37.64945",
    "lng": "15.12385"
  },
  {
    "country": "IT",
    "name": "Campese",
    "lat": "45.8058",
    "lng": "11.71289"
  },
  {
    "country": "IT",
    "name": "Moggio di Sotto",
    "lat": "46.40651",
    "lng": "13.19507"
  },
  {
    "country": "IT",
    "name": "San Pietro in Volta",
    "lat": "45.31542",
    "lng": "12.31518"
  },
  {
    "country": "IT",
    "name": "Lambrinia",
    "lat": "45.15831",
    "lng": "9.5275"
  },
  {
    "country": "IT",
    "name": "Novoledo",
    "lat": "45.64647",
    "lng": "11.50952"
  },
  {
    "country": "IT",
    "name": "Ozzano Taro",
    "lat": "44.70969",
    "lng": "10.14086"
  },
  {
    "country": "IT",
    "name": "Mantiglia di Ardea",
    "lat": "41.67685",
    "lng": "12.61453"
  },
  {
    "country": "IT",
    "name": "Stazione Masotti",
    "lat": "43.90984",
    "lng": "10.85386"
  },
  {
    "country": "IT",
    "name": "Badia al Pino",
    "lat": "43.40424",
    "lng": "11.77228"
  },
  {
    "country": "IT",
    "name": "Caldierino-Rota",
    "lat": "45.41616",
    "lng": "11.15696"
  },
  {
    "country": "IT",
    "name": "Crispi Cavour",
    "lat": "45.5819",
    "lng": "11.50113"
  },
  {
    "country": "IT",
    "name": "Puginate",
    "lat": "45.71095",
    "lng": "9.05772"
  },
  {
    "country": "IT",
    "name": "Rosario",
    "lat": "39.29104",
    "lng": "16.23125"
  },
  {
    "country": "IT",
    "name": "Ardole San Marino",
    "lat": "45.15633",
    "lng": "10.10546"
  },
  {
    "country": "IT",
    "name": "Terradura",
    "lat": "45.3229",
    "lng": "11.82425"
  },
  {
    "country": "IT",
    "name": "Pezzan",
    "lat": "45.69341",
    "lng": "12.09616"
  },
  {
    "country": "IT",
    "name": "Ronco",
    "lat": "45.52668",
    "lng": "9.35921"
  },
  {
    "country": "IT",
    "name": "Bora Bassa",
    "lat": "44.04636",
    "lng": "12.18066"
  },
  {
    "country": "IT",
    "name": "San Defendente",
    "lat": "44.39088",
    "lng": "7.49091"
  },
  {
    "country": "IT",
    "name": "Madrano-Canzolino",
    "lat": "46.0844",
    "lng": "11.21736"
  },
  {
    "country": "IT",
    "name": "Fane",
    "lat": "45.57904",
    "lng": "10.96425"
  },
  {
    "country": "IT",
    "name": "Alberi",
    "lat": "44.74837",
    "lng": "10.33045"
  },
  {
    "country": "IT",
    "name": "Capitan Loreto",
    "lat": "43.01731",
    "lng": "12.6475"
  },
  {
    "country": "IT",
    "name": "Nosadello",
    "lat": "45.40268",
    "lng": "9.53047"
  },
  {
    "country": "IT",
    "name": "Stazione di Allerona",
    "lat": "42.7855",
    "lng": "12.03726"
  },
  {
    "country": "IT",
    "name": "Padiglione",
    "lat": "43.469",
    "lng": "13.46261"
  },
  {
    "country": "IT",
    "name": "Passaggio",
    "lat": "43.02239",
    "lng": "12.50781"
  },
  {
    "country": "IT",
    "name": "Salino",
    "lat": "42.78571",
    "lng": "13.914"
  },
  {
    "country": "IT",
    "name": "Vaccheria",
    "lat": "44.727",
    "lng": "8.04295"
  },
  {
    "country": "IT",
    "name": "Villassio",
    "lat": "45.86313",
    "lng": "9.84466"
  },
  {
    "country": "IT",
    "name": "Camilleri-Vallelata",
    "lat": "41.59848",
    "lng": "12.61738"
  },
  {
    "country": "IT",
    "name": "Vigliatore 2",
    "lat": "38.12221",
    "lng": "15.13066"
  },
  {
    "country": "IT",
    "name": "Santa Corinna",
    "lat": "45.34018",
    "lng": "9.08878"
  },
  {
    "country": "IT",
    "name": "Isoverde",
    "lat": "44.52941",
    "lng": "8.86049"
  },
  {
    "country": "IT",
    "name": "Capirro",
    "lat": "41.25403",
    "lng": "16.42242"
  },
  {
    "country": "IT",
    "name": "Pilastro",
    "lat": "44.68254",
    "lng": "10.28879"
  },
  {
    "country": "IT",
    "name": "Molella",
    "lat": "41.26009",
    "lng": "13.06221"
  },
  {
    "country": "IT",
    "name": "Cascinare",
    "lat": "43.26434",
    "lng": "13.71181"
  },
  {
    "country": "IT",
    "name": "Bargano",
    "lat": "45.24031",
    "lng": "9.44689"
  },
  {
    "country": "IT",
    "name": "Molino-Mozzi-Bittarelli",
    "lat": "45.61254",
    "lng": "11.235"
  },
  {
    "country": "IT",
    "name": "San Vito",
    "lat": "45.41875",
    "lng": "11.96211"
  },
  {
    "country": "IT",
    "name": "San Giovanni-Patoni",
    "lat": "41.77223",
    "lng": "13.2751"
  },
  {
    "country": "IT",
    "name": "Amato",
    "lat": "38.37355",
    "lng": "15.96097"
  },
  {
    "country": "IT",
    "name": "Cerquotti-Madonna del Piano",
    "lat": "41.64194",
    "lng": "13.21316"
  },
  {
    "country": "IT",
    "name": "Pasteria-Lapide",
    "lat": "37.81012",
    "lng": "15.22818"
  },
  {
    "country": "IT",
    "name": "Badalasco",
    "lat": "45.54217",
    "lng": "9.55494"
  },
  {
    "country": "IT",
    "name": "San Lorenzo",
    "lat": "40.75405",
    "lng": "14.58974"
  },
  {
    "country": "IT",
    "name": "Barone",
    "lat": "38.85225",
    "lng": "16.63927"
  },
  {
    "country": "IT",
    "name": "Duomo",
    "lat": "45.5324",
    "lng": "10.02118"
  },
  {
    "country": "IT",
    "name": "Prepezzano",
    "lat": "40.72754",
    "lng": "14.89123"
  },
  {
    "country": "IT",
    "name": "Gaiano",
    "lat": "44.72391",
    "lng": "10.17267"
  },
  {
    "country": "IT",
    "name": "Sassacci",
    "lat": "42.32342",
    "lng": "12.44108"
  },
  {
    "country": "IT",
    "name": "Tavo",
    "lat": "45.50066",
    "lng": "11.86079"
  },
  {
    "country": "IT",
    "name": "Canavaccio",
    "lat": "43.69376",
    "lng": "12.69863"
  },
  {
    "country": "IT",
    "name": "Cendon",
    "lat": "45.63804",
    "lng": "12.32505"
  },
  {
    "country": "IT",
    "name": "Favari-Avatanei",
    "lat": "44.91235",
    "lng": "7.7995"
  },
  {
    "country": "IT",
    "name": "Stradella",
    "lat": "45.17245",
    "lng": "10.87327"
  },
  {
    "country": "IT",
    "name": "Santa Croce Scuole",
    "lat": "44.76281",
    "lng": "10.84944"
  },
  {
    "country": "IT",
    "name": "Forette",
    "lat": "45.34221",
    "lng": "10.9446"
  },
  {
    "country": "IT",
    "name": "Buso",
    "lat": "45.06491",
    "lng": "11.84772"
  },
  {
    "country": "IT",
    "name": "Poggio Ellera",
    "lat": "42.1138",
    "lng": "12.37174"
  },
  {
    "country": "IT",
    "name": "San Zeno",
    "lat": "45.63381",
    "lng": "10.73046"
  },
  {
    "country": "IT",
    "name": "Belforte",
    "lat": "45.08097",
    "lng": "10.56156"
  },
  {
    "country": "IT",
    "name": "Faraldo-Nocelleto",
    "lat": "40.77992",
    "lng": "14.76363"
  },
  {
    "country": "IT",
    "name": "Montalto",
    "lat": "43.49912",
    "lng": "11.6638"
  },
  {
    "country": "IT",
    "name": "Casalini",
    "lat": "40.73777",
    "lng": "17.47062"
  },
  {
    "country": "IT",
    "name": "Bettola",
    "lat": "45.33173",
    "lng": "9.0208"
  },
  {
    "country": "IT",
    "name": "Porto d'Adda",
    "lat": "45.66241",
    "lng": "9.47563"
  },
  {
    "country": "IT",
    "name": "Villa San Filippo",
    "lat": "43.25981",
    "lng": "13.59337"
  },
  {
    "country": "IT",
    "name": "Cimbro",
    "lat": "45.7357",
    "lng": "8.7205"
  },
  {
    "country": "IT",
    "name": "Cassino d'Alberi",
    "lat": "45.39208",
    "lng": "9.3909"
  },
  {
    "country": "IT",
    "name": "Torrazza dei Mandelli",
    "lat": "45.56629",
    "lng": "9.39921"
  },
  {
    "country": "IT",
    "name": "Bulgorello",
    "lat": "45.72433",
    "lng": "9.05524"
  },
  {
    "country": "IT",
    "name": "Cascina Elisa",
    "lat": "45.60425",
    "lng": "8.79978"
  },
  {
    "country": "IT",
    "name": "Villaggio Montegrappa",
    "lat": "45.54643",
    "lng": "11.61428"
  },
  {
    "country": "IT",
    "name": "Brozzo",
    "lat": "45.72019",
    "lng": "10.23092"
  },
  {
    "country": "IT",
    "name": "Leone-Santa Elisabetta",
    "lat": "46.73166",
    "lng": "11.64944"
  },
  {
    "country": "IT",
    "name": "Brezza",
    "lat": "41.11073",
    "lng": "14.11201"
  },
  {
    "country": "IT",
    "name": "Borgo Lotti",
    "lat": "41.76414",
    "lng": "12.555"
  },
  {
    "country": "IT",
    "name": "Pugliano",
    "lat": "40.67876",
    "lng": "14.94543"
  },
  {
    "country": "IT",
    "name": "Strada",
    "lat": "43.74452",
    "lng": "11.71007"
  },
  {
    "country": "IT",
    "name": "Ronchi di Campanile",
    "lat": "45.4579",
    "lng": "11.77483"
  },
  {
    "country": "IT",
    "name": "Agrate",
    "lat": "45.6754",
    "lng": "8.56065"
  },
  {
    "country": "IT",
    "name": "San Giacomo",
    "lat": "45.59379",
    "lng": "10.47689"
  },
  {
    "country": "IT",
    "name": "Cipolleto",
    "lat": "43.32393",
    "lng": "12.57688"
  },
  {
    "country": "IT",
    "name": "Pontelangorino",
    "lat": "44.86087",
    "lng": "12.14864"
  },
  {
    "country": "IT",
    "name": "San Maurizio",
    "lat": "45.60349",
    "lng": "8.28695"
  },
  {
    "country": "IT",
    "name": "Laxolo",
    "lat": "45.80871",
    "lng": "9.59983"
  },
  {
    "country": "IT",
    "name": "Calozzo",
    "lat": "46.10055",
    "lng": "9.27531"
  },
  {
    "country": "IT",
    "name": "Stravignino",
    "lat": "45.77469",
    "lng": "10.23838"
  },
  {
    "country": "IT",
    "name": "La Place",
    "lat": "45.65414",
    "lng": "7.68414"
  },
  {
    "country": "IT",
    "name": "San Nico",
    "lat": "39.66906",
    "lng": "16.43182"
  },
  {
    "country": "IT",
    "name": "Arci-Empolitana",
    "lat": "41.94766",
    "lng": "12.82502"
  },
  {
    "country": "IT",
    "name": "Orzignano",
    "lat": "43.77408",
    "lng": "10.42382"
  },
  {
    "country": "IT",
    "name": "Colle del Pino",
    "lat": "41.74246",
    "lng": "12.49644"
  },
  {
    "country": "IT",
    "name": "Fellegara",
    "lat": "44.61052",
    "lng": "10.697"
  },
  {
    "country": "IT",
    "name": "Colle Spina",
    "lat": "41.78205",
    "lng": "12.84723"
  },
  {
    "country": "IT",
    "name": "Azzano",
    "lat": "45.98096",
    "lng": "9.20284"
  },
  {
    "country": "IT",
    "name": "Giavenale",
    "lat": "45.70006",
    "lng": "11.40002"
  },
  {
    "country": "IT",
    "name": "Pianello",
    "lat": "43.6262",
    "lng": "13.13068"
  },
  {
    "country": "IT",
    "name": "Arlesega",
    "lat": "45.46126",
    "lng": "11.71942"
  },
  {
    "country": "IT",
    "name": "Santa Fiora",
    "lat": "43.55989",
    "lng": "12.11271"
  },
  {
    "country": "IT",
    "name": "Calmasino",
    "lat": "45.52099",
    "lng": "10.75206"
  },
  {
    "country": "IT",
    "name": "Pitelli",
    "lat": "44.09458",
    "lng": "9.8849"
  },
  {
    "country": "IT",
    "name": "San Prospero",
    "lat": "44.77628",
    "lng": "10.40097"
  },
  {
    "country": "IT",
    "name": "Cominio",
    "lat": "42.31248",
    "lng": "13.4325"
  },
  {
    "country": "IT",
    "name": "Case Nuove",
    "lat": "45.60998",
    "lng": "10.39416"
  },
  {
    "country": "IT",
    "name": "Beregazzo",
    "lat": "45.77019",
    "lng": "8.95869"
  },
  {
    "country": "IT",
    "name": "Navedano",
    "lat": "45.75524",
    "lng": "9.0947"
  },
  {
    "country": "IT",
    "name": "Maccoli-Perrillo",
    "lat": "41.08762",
    "lng": "14.80585"
  },
  {
    "country": "IT",
    "name": "Tonnara di Bonagia",
    "lat": "38.06309",
    "lng": "12.59434"
  },
  {
    "country": "IT",
    "name": "Sant'Antonio",
    "lat": "45.40434",
    "lng": "10.35557"
  },
  {
    "country": "IT",
    "name": "Prosto",
    "lat": "46.32946",
    "lng": "9.42094"
  },
  {
    "country": "IT",
    "name": "Paquier",
    "lat": "45.87879",
    "lng": "7.62575"
  },
  {
    "country": "IT",
    "name": "Casale",
    "lat": "44.91665",
    "lng": "10.43169"
  },
  {
    "country": "IT",
    "name": "Rifiano",
    "lat": "46.70287",
    "lng": "11.18057"
  },
  {
    "country": "IT",
    "name": "Nava",
    "lat": "45.76219",
    "lng": "9.36308"
  },
  {
    "country": "IT",
    "name": "Tettorosso",
    "lat": "44.47284",
    "lng": "7.34291"
  },
  {
    "country": "IT",
    "name": "Livera",
    "lat": "45.61239",
    "lng": "8.10571"
  },
  {
    "country": "IT",
    "name": "Chiesa",
    "lat": "45.5636",
    "lng": "10.46202"
  },
  {
    "country": "IT",
    "name": "Braglia",
    "lat": "44.98446",
    "lng": "12.03377"
  },
  {
    "country": "IT",
    "name": "Agliano",
    "lat": "44.79164",
    "lng": "8.25124"
  },
  {
    "country": "IT",
    "name": "Codogna-Cardano",
    "lat": "46.02769",
    "lng": "9.20992"
  },
  {
    "country": "IT",
    "name": "Era",
    "lat": "46.24422",
    "lng": "9.39515"
  },
  {
    "country": "IT",
    "name": "Sottocastello",
    "lat": "45.6672",
    "lng": "10.39416"
  },
  {
    "country": "IT",
    "name": "Occagno",
    "lat": "45.92901",
    "lng": "9.0987"
  },
  {
    "country": "IT",
    "name": "Calchera-Frontale",
    "lat": "45.83415",
    "lng": "9.51155"
  },
  {
    "country": "IT",
    "name": "Vescovado",
    "lat": "43.16953",
    "lng": "11.39198"
  },
  {
    "country": "IT",
    "name": "Villa",
    "lat": "46.74591",
    "lng": "11.76243"
  },
  {
    "country": "IT",
    "name": "Verla",
    "lat": "46.15793",
    "lng": "11.15331"
  },
  {
    "country": "IT",
    "name": "Villandro",
    "lat": "46.63086",
    "lng": "11.53808"
  },
  {
    "country": "IT",
    "name": "Pederiva",
    "lat": "45.42254",
    "lng": "11.46568"
  },
  {
    "country": "IT",
    "name": "Sant'Elena Irpina",
    "lat": "41.03741",
    "lng": "14.88931"
  },
  {
    "country": "IT",
    "name": "Castione",
    "lat": "46.17287",
    "lng": "9.80032"
  },
  {
    "country": "IT",
    "name": "San Nicola",
    "lat": "38.21199",
    "lng": "15.69381"
  },
  {
    "country": "IT",
    "name": "Barbiano",
    "lat": "46.60412",
    "lng": "11.5212"
  },
  {
    "country": "IT",
    "name": "Camoneone",
    "lat": "45.78547",
    "lng": "9.5691"
  },
  {
    "country": "IT",
    "name": "Castelletto Po",
    "lat": "45.06903",
    "lng": "9.10056"
  },
  {
    "country": "IT",
    "name": "Crava",
    "lat": "44.43001",
    "lng": "7.74493"
  },
  {
    "country": "IT",
    "name": "Capriglia",
    "lat": "40.95972",
    "lng": "14.7782"
  },
  {
    "country": "IT",
    "name": "Bedero",
    "lat": "45.97776",
    "lng": "8.71852"
  },
  {
    "country": "IT",
    "name": "Rocchetta Nuova",
    "lat": "41.62375",
    "lng": "14.08574"
  },
  {
    "country": "IT",
    "name": "Fornaci",
    "lat": "45.19872",
    "lng": "9.67794"
  },
  {
    "country": "IT",
    "name": "Lassolaz",
    "lat": "45.73851",
    "lng": "7.58883"
  },
  {
    "country": "IT",
    "name": "San Giorgio",
    "lat": "45.10778",
    "lng": "8.41421"
  },
  {
    "country": "IT",
    "name": "Berriat",
    "lat": "45.70729",
    "lng": "7.67617"
  },
  {
    "country": "IT",
    "name": "Feglino",
    "lat": "44.21849",
    "lng": "8.32436"
  },
  {
    "country": "IT",
    "name": "Bivio Mortola",
    "lat": "41.39557",
    "lng": "13.89663"
  },
  {
    "country": "IT",
    "name": "Mure",
    "lat": "45.73419",
    "lng": "11.61065"
  },
  {
    "country": "IT",
    "name": "Valzemola",
    "lat": "44.36393",
    "lng": "8.17376"
  },
  {
    "country": "IT",
    "name": "Villa",
    "lat": "46.77977",
    "lng": "11.69047"
  },
  {
    "country": "IT",
    "name": "Borgo",
    "lat": "44.40527",
    "lng": "7.93839"
  },
  {
    "country": "IT",
    "name": "Prati",
    "lat": "44.3829",
    "lng": "9.37567"
  },
  {
    "country": "IT",
    "name": "Evangelisti-Rubino",
    "lat": "37.98412",
    "lng": "15.17324"
  },
  {
    "country": "IT",
    "name": "Lases",
    "lat": "46.1456",
    "lng": "11.21932"
  },
  {
    "country": "IT",
    "name": "Rivalta",
    "lat": "45.65714",
    "lng": "10.89336"
  },
  {
    "country": "IT",
    "name": "Monasterolo",
    "lat": "45.76327",
    "lng": "9.93138"
  },
  {
    "country": "IT",
    "name": "Montale",
    "lat": "44.20619",
    "lng": "9.9447"
  },
  {
    "country": "IT",
    "name": "Colla-Muggiasca",
    "lat": "45.98343",
    "lng": "9.62277"
  },
  {
    "country": "IT",
    "name": "Centro Urbano",
    "lat": "40.81986",
    "lng": "15.31953"
  },
  {
    "country": "IT",
    "name": "Vignola",
    "lat": "46.08815",
    "lng": "9.27456"
  },
  {
    "country": "IT",
    "name": "San Michele",
    "lat": "40.62023",
    "lng": "14.55018"
  },
  {
    "country": "IT",
    "name": "Dosso-Ville",
    "lat": "45.75251",
    "lng": "10.27397"
  },
  {
    "country": "IT",
    "name": "Gonte",
    "lat": "45.99519",
    "lng": "8.64982"
  },
  {
    "country": "IT",
    "name": "Villanuova",
    "lat": "45.44245",
    "lng": "9.8669"
  },
  {
    "country": "IT",
    "name": "Cadipietra",
    "lat": "46.99576",
    "lng": "11.98026"
  },
  {
    "country": "IT",
    "name": "Fontanella-Ozino",
    "lat": "45.61963",
    "lng": "8.16927"
  },
  {
    "country": "IT",
    "name": "Plan d'Introd",
    "lat": "45.69203",
    "lng": "7.18328"
  },
  {
    "country": "IT",
    "name": "Covelo",
    "lat": "45.97919",
    "lng": "11.06971"
  },
  {
    "country": "IT",
    "name": "Sirta",
    "lat": "46.15823",
    "lng": "9.66109"
  },
  {
    "country": "IT",
    "name": "San Zenone",
    "lat": "45.64169",
    "lng": "10.14685"
  },
  {
    "country": "IT",
    "name": "Sachet",
    "lat": "46.36982",
    "lng": "11.93129"
  },
  {
    "country": "IT",
    "name": "La Villa",
    "lat": "45.26713",
    "lng": "7.43109"
  },
  {
    "country": "IT",
    "name": "Canneto",
    "lat": "45.05116",
    "lng": "9.28101"
  },
  {
    "country": "IT",
    "name": "Piano",
    "lat": "44.3168",
    "lng": "8.16639"
  },
  {
    "country": "IT",
    "name": "San Genesio",
    "lat": "46.658",
    "lng": "11.92456"
  },
  {
    "country": "IT",
    "name": "Melia",
    "lat": "37.90384",
    "lng": "15.27499"
  },
  {
    "country": "IT",
    "name": "San Lorenzo",
    "lat": "44.17302",
    "lng": "8.24424"
  },
  {
    "country": "IT",
    "name": "Rossi",
    "lat": "44.00029",
    "lng": "8.05884"
  },
  {
    "country": "IT",
    "name": "Mornico",
    "lat": "45.01062",
    "lng": "9.20926"
  },
  {
    "country": "IT",
    "name": "San Giuseppe",
    "lat": "45.14701",
    "lng": "7.04271"
  },
  {
    "country": "IT",
    "name": "Coassolo",
    "lat": "45.29838",
    "lng": "7.46136"
  },
  {
    "country": "IT",
    "name": "Santa Maria dei Sabbioni",
    "lat": "45.24386",
    "lng": "9.83927"
  },
  {
    "country": "IT",
    "name": "Fleccia-Chianavasso",
    "lat": "44.9467",
    "lng": "7.21474"
  },
  {
    "country": "IT",
    "name": "Piccarello",
    "lat": "44.48392",
    "lng": "8.96595"
  },
  {
    "country": "IT",
    "name": "Moscheri",
    "lat": "45.86875",
    "lng": "11.07383"
  },
  {
    "country": "IT",
    "name": "Lanvario",
    "lat": "45.6397",
    "lng": "8.19856"
  },
  {
    "country": "IT",
    "name": "San Giovanni",
    "lat": "44.39367",
    "lng": "8.49701"
  },
  {
    "country": "IT",
    "name": "Gallo",
    "lat": "41.46499",
    "lng": "14.22519"
  },
  {
    "country": "IT",
    "name": "Santino",
    "lat": "45.95606",
    "lng": "8.51914"
  },
  {
    "country": "IT",
    "name": "Camerano",
    "lat": "44.99118",
    "lng": "8.08965"
  },
  {
    "country": "IT",
    "name": "Chiesa Nuova",
    "lat": "44.36976",
    "lng": "9.31161"
  },
  {
    "country": "IT",
    "name": "Villa d'Oneta",
    "lat": "45.87074",
    "lng": "9.81929"
  },
  {
    "country": "IT",
    "name": "Lemna",
    "lat": "45.85808",
    "lng": "9.15986"
  },
  {
    "country": "IT",
    "name": "Villa-Nabian",
    "lat": "45.6897",
    "lng": "7.7047"
  },
  {
    "country": "IT",
    "name": "Casavecchia",
    "lat": "44.52756",
    "lng": "8.62157"
  },
  {
    "country": "IT",
    "name": "Quincod",
    "lat": "45.71513",
    "lng": "7.73495"
  },
  {
    "country": "IT",
    "name": "Caines",
    "lat": "46.69794",
    "lng": "11.17122"
  },
  {
    "country": "IT",
    "name": "Santa Marta",
    "lat": "44.50401",
    "lng": "8.89268"
  },
  {
    "country": "IT",
    "name": "Zoppè di Cadore",
    "lat": "46.38583",
    "lng": "12.17368"
  },
  {
    "country": "IT",
    "name": "San Rocco",
    "lat": "45.00945",
    "lng": "9.16191"
  },
  {
    "country": "IT",
    "name": "Ariola",
    "lat": "40.62795",
    "lng": "15.43453"
  },
  {
    "country": "IT",
    "name": "Cedessano",
    "lat": "45.68858",
    "lng": "10.43395"
  },
  {
    "country": "IT",
    "name": "Meiern",
    "lat": "46.56503",
    "lng": "10.7827"
  },
  {
    "country": "IT",
    "name": "Roapiana",
    "lat": "44.34079",
    "lng": "7.82329"
  },
  {
    "country": "IT",
    "name": "Antagnod",
    "lat": "45.81484",
    "lng": "7.68931"
  },
  {
    "country": "IT",
    "name": "Fontanafredda",
    "lat": "45.29159",
    "lng": "11.66172"
  },
  {
    "country": "IT",
    "name": "Molino-Pera",
    "lat": "44.48803",
    "lng": "8.30899"
  },
  {
    "country": "IT",
    "name": "Valentino",
    "lat": "45.15558",
    "lng": "8.09391"
  },
  {
    "country": "IT",
    "name": "Don",
    "lat": "46.22144",
    "lng": "11.95598"
  },
  {
    "country": "IT",
    "name": "Aurogna",
    "lat": "46.17147",
    "lng": "9.35536"
  },
  {
    "country": "IT",
    "name": "Servo",
    "lat": "46.05844",
    "lng": "11.78657"
  },
  {
    "country": "IT",
    "name": "Chiesa",
    "lat": "44.07787",
    "lng": "8.10891"
  },
  {
    "country": "IT",
    "name": "Longhi",
    "lat": "45.90744",
    "lng": "11.31132"
  },
  {
    "country": "IT",
    "name": "Borgo",
    "lat": "45.63882",
    "lng": "8.11508"
  },
  {
    "country": "IT",
    "name": "Mongnod",
    "lat": "45.80549",
    "lng": "7.56806"
  },
  {
    "country": "IT",
    "name": "La Pieve-Molino",
    "lat": "43.73725",
    "lng": "11.62033"
  },
  {
    "country": "IT",
    "name": "Brovello",
    "lat": "45.84246",
    "lng": "8.53189"
  },
  {
    "country": "IT",
    "name": "Pontestazzemese",
    "lat": "43.99665",
    "lng": "10.29439"
  },
  {
    "country": "IT",
    "name": "Centrale",
    "lat": "46.16118",
    "lng": "11.30293"
  },
  {
    "country": "IT",
    "name": "Barquedo",
    "lat": "45.74283",
    "lng": "8.4963"
  },
  {
    "country": "IT",
    "name": "Montariolo",
    "lat": "44.99575",
    "lng": "8.77539"
  },
  {
    "country": "IT",
    "name": "Ferriere",
    "lat": "44.44302",
    "lng": "9.13675"
  },
  {
    "country": "IT",
    "name": "Serone",
    "lat": "46.15627",
    "lng": "9.58171"
  },
  {
    "country": "IT",
    "name": "Saint-Rhémy",
    "lat": "45.83553",
    "lng": "7.18393"
  },
  {
    "country": "IT",
    "name": "Corigliano Scalo",
    "lat": "39.62713",
    "lng": "16.51368"
  },
  {
    "country": "IT",
    "name": "Ghiaie",
    "lat": "45.68205",
    "lng": "9.58121"
  },
  {
    "country": "IT",
    "name": "Sciaves",
    "lat": "46.76859",
    "lng": "11.66607"
  },
  {
    "country": "IT",
    "name": "Voltago",
    "lat": "46.27252",
    "lng": "12.0064"
  },
  {
    "country": "IT",
    "name": "Verano",
    "lat": "46.60442",
    "lng": "11.22565"
  },
  {
    "country": "IT",
    "name": "Sant'Orsola",
    "lat": "46.10901",
    "lng": "11.30201"
  },
  {
    "country": "IT",
    "name": "Grizzana",
    "lat": "44.25806",
    "lng": "11.15557"
  },
  {
    "country": "IT",
    "name": "San Romano",
    "lat": "44.17044",
    "lng": "10.34618"
  },
  {
    "country": "IT",
    "name": "Villa",
    "lat": "44.71895",
    "lng": "7.94139"
  },
  {
    "country": "IT",
    "name": "Campolongo Maggiore",
    "lat": "45.32352",
    "lng": "12.04391"
  },
  {
    "country": "IT",
    "name": "Atina Inferiore",
    "lat": "41.62705",
    "lng": "13.79258"
  },
  {
    "country": "IT",
    "name": "Passo Ripe",
    "lat": "43.65567",
    "lng": "13.12196"
  },
  {
    "country": "IT",
    "name": "Ponte di Nanto",
    "lat": "45.42427",
    "lng": "11.594"
  },
  {
    "country": "IT",
    "name": "San Lorenzo di Rovetta",
    "lat": "45.87971",
    "lng": "9.97537"
  },
  {
    "country": "IT",
    "name": "Santa Caterina dello Ionio Marina",
    "lat": "38.52736",
    "lng": "16.57071"
  },
  {
    "country": "IT",
    "name": "Loreto Stazione",
    "lat": "43.44792",
    "lng": "13.62016"
  },
  {
    "country": "IT",
    "name": "Progetto Case Coppito 3",
    "lat": "42.36981",
    "lng": "13.31973"
  },
  {
    "country": "IT",
    "name": "Canove di Roana",
    "lat": "45.8635",
    "lng": "11.4735"
  },
  {
    "country": "IT",
    "name": "Natile Nuovo",
    "lat": "38.18583",
    "lng": "16.08527"
  },
  {
    "country": "IT",
    "name": "Piazzolla",
    "lat": "40.88964",
    "lng": "14.51579"
  },
  {
    "country": "IT",
    "name": "Progetto Case Sassa Nsi",
    "lat": "42.3656",
    "lng": "13.31509"
  },
  {
    "country": "IT",
    "name": "Scalo di Baragiano",
    "lat": "40.695",
    "lng": "15.57508"
  },
  {
    "country": "IT",
    "name": "Poggiridenti Piano",
    "lat": "46.16991",
    "lng": "9.92671"
  },
  {
    "country": "IT",
    "name": "Pie' Falcade",
    "lat": "46.3566",
    "lng": "11.87207"
  },
  {
    "country": "IT",
    "name": "Marina",
    "lat": "39.4633",
    "lng": "15.98122"
  },
  {
    "country": "IT",
    "name": "Taverna Ravindola",
    "lat": "41.52283",
    "lng": "14.12591"
  },
  {
    "country": "IT",
    "name": "Borgata Marina",
    "lat": "39.97136",
    "lng": "16.62091"
  },
  {
    "country": "IT",
    "name": "Baruchella",
    "lat": "45.06601",
    "lng": "11.45208"
  },
  {
    "country": "IT",
    "name": "Spigno Saturnia Inferiore",
    "lat": "41.31146",
    "lng": "13.73685"
  },
  {
    "country": "IT",
    "name": "Castelbello",
    "lat": "46.62885",
    "lng": "10.90719"
  },
  {
    "country": "IT",
    "name": "Vauda Canavese Superiore",
    "lat": "45.27947",
    "lng": "7.61945"
  },
  {
    "country": "IT",
    "name": "Pozzaglio",
    "lat": "45.19999",
    "lng": "10.05345"
  },
  {
    "country": "IT",
    "name": "Marciano",
    "lat": "43.30651",
    "lng": "11.79171"
  },
  {
    "country": "IT",
    "name": "Ubiale",
    "lat": "45.7835",
    "lng": "9.6165"
  },
  {
    "country": "IT",
    "name": "Villa",
    "lat": "46.33059",
    "lng": "9.48426"
  },
  {
    "country": "IT",
    "name": "Paderno",
    "lat": "45.82791",
    "lng": "11.85605"
  },
  {
    "country": "IT",
    "name": "Botta",
    "lat": "45.83222",
    "lng": "9.53257"
  },
  {
    "country": "IT",
    "name": "Velo",
    "lat": "45.78983",
    "lng": "11.36725"
  },
  {
    "country": "IT",
    "name": "Villa-Borgo",
    "lat": "44.69865",
    "lng": "7.93486"
  },
  {
    "country": "IT",
    "name": "Canistro Inferiore",
    "lat": "41.94101",
    "lng": "13.41194"
  },
  {
    "country": "IT",
    "name": "Vilminore",
    "lat": "45.99795",
    "lng": "10.09531"
  },
  {
    "country": "IT",
    "name": "Prignano",
    "lat": "44.4379",
    "lng": "10.69118"
  },
  {
    "country": "IT",
    "name": "San Fidenzio",
    "lat": "45.21622",
    "lng": "11.51802"
  },
  {
    "country": "IT",
    "name": "Ponte di Castegnero",
    "lat": "45.43672",
    "lng": "11.60069"
  },
  {
    "country": "IT",
    "name": "Piano di Mommio",
    "lat": "43.90954",
    "lng": "10.27435"
  },
  {
    "country": "IT",
    "name": "Padule-San Marco",
    "lat": "43.3288",
    "lng": "12.60942"
  },
  {
    "country": "IT",
    "name": "Orvieto Scalo",
    "lat": "42.72088",
    "lng": "12.13402"
  },
  {
    "country": "IT",
    "name": "Chianchitta-Pallio",
    "lat": "37.82108",
    "lng": "15.25317"
  },
  {
    "country": "IT",
    "name": "Marina di Altidona",
    "lat": "43.10602",
    "lng": "13.83454"
  },
  {
    "country": "IT",
    "name": "Meano",
    "lat": "46.12457",
    "lng": "11.11761"
  },
  {
    "country": "IT",
    "name": "Villapiana Lido",
    "lat": "39.81203",
    "lng": "16.4882"
  },
  {
    "country": "IT",
    "name": "Preara-Moraro-Levà Nord",
    "lat": "45.67996",
    "lng": "11.54286"
  },
  {
    "country": "IT",
    "name": "Codiverno",
    "lat": "45.47583",
    "lng": "11.94556"
  },
  {
    "country": "IT",
    "name": "Rocca Imperiale Marina",
    "lat": "40.09962",
    "lng": "16.61336"
  },
  {
    "country": "IT",
    "name": "Bisaccia Nuova",
    "lat": "41.0096",
    "lng": "15.35546"
  },
  {
    "country": "IT",
    "name": "Neive-Borgonovo",
    "lat": "44.72397",
    "lng": "8.1178"
  },
  {
    "country": "IT",
    "name": "Piedimonte San Germano Alta",
    "lat": "41.50446",
    "lng": "13.74909"
  },
  {
    "country": "IT",
    "name": "Falerna Scalo",
    "lat": "38.97285",
    "lng": "16.15294"
  },
  {
    "country": "IT",
    "name": "San Venanzio",
    "lat": "44.74517",
    "lng": "11.43727"
  },
  {
    "country": "IT",
    "name": "Gazzolo-Volpino",
    "lat": "45.37536",
    "lng": "11.31319"
  },
  {
    "country": "IT",
    "name": "Fabro Scalo",
    "lat": "42.87605",
    "lng": "12.04624"
  },
  {
    "country": "IT",
    "name": "Villanova del Ghebbo Canton",
    "lat": "45.05933",
    "lng": "11.64314"
  },
  {
    "country": "IT",
    "name": "Saponara Marittima",
    "lat": "38.23121",
    "lng": "15.42621"
  },
  {
    "country": "IT",
    "name": "Arbia",
    "lat": "43.29342",
    "lng": "11.40978"
  },
  {
    "country": "IT",
    "name": "Piane di Montegiorgio",
    "lat": "43.11587",
    "lng": "13.56669"
  },
  {
    "country": "IT",
    "name": "Orbetello Scalo",
    "lat": "42.44866",
    "lng": "11.24936"
  },
  {
    "country": "IT",
    "name": "Molinetto",
    "lat": "45.49409",
    "lng": "10.35888"
  },
  {
    "country": "IT",
    "name": "Marotta",
    "lat": "43.79893",
    "lng": "13.09452"
  },
  {
    "country": "IT",
    "name": "Calvi Risorta",
    "lat": "41.21598",
    "lng": "14.13092"
  },
  {
    "country": "IT",
    "name": "Leporano Marina",
    "lat": "40.3786",
    "lng": "17.3096"
  },
  {
    "country": "IT",
    "name": "Tortora Marina",
    "lat": "39.92293",
    "lng": "15.76943"
  },
  {
    "country": "IT",
    "name": "Santa Maria la Stella",
    "lat": "37.62349",
    "lng": "15.12071"
  },
  {
    "country": "IT",
    "name": "Colleverde II",
    "lat": "41.97533",
    "lng": "12.63191"
  },
  {
    "country": "IT",
    "name": "Chiusi Scalo",
    "lat": "42.99613",
    "lng": "11.95412"
  },
  {
    "country": "IT",
    "name": "Cetraro Marina",
    "lat": "39.51701",
    "lng": "15.9346"
  },
  {
    "country": "IT",
    "name": "Venetico Marina",
    "lat": "38.21928",
    "lng": "15.36648"
  },
  {
    "country": "IT",
    "name": "Orte Scalo",
    "lat": "42.43483",
    "lng": "12.40783"
  },
  {
    "country": "IT",
    "name": "Corcagnano",
    "lat": "44.72103",
    "lng": "10.30271"
  },
  {
    "country": "IT",
    "name": "Due Carrare",
    "lat": "45.29151",
    "lng": "11.82402"
  },
  {
    "country": "IT",
    "name": "Licinella-Torre di Paestum",
    "lat": "40.40656",
    "lng": "14.99764"
  },
  {
    "country": "IT",
    "name": "Torvaianica Alta",
    "lat": "41.63162",
    "lng": "12.49765"
  },
  {
    "country": "IT",
    "name": "Gerbole-Zucche",
    "lat": "44.98605",
    "lng": "7.51671"
  },
  {
    "country": "IT",
    "name": "Nucleo Industriale di Bazzano",
    "lat": "42.33623",
    "lng": "13.46755"
  },
  {
    "country": "IT",
    "name": "Ponte a Poppi",
    "lat": "43.73171",
    "lng": "11.76663"
  },
  {
    "country": "IT",
    "name": "Muzza di Cornegliano Laudense",
    "lat": "45.28462",
    "lng": "9.47166"
  },
  {
    "country": "IT",
    "name": "Poasco-Sorigherio",
    "lat": "45.4031",
    "lng": "9.23092"
  },
  {
    "country": "IT",
    "name": "Vago",
    "lat": "45.41986",
    "lng": "11.1302"
  },
  {
    "country": "IT",
    "name": "Ca' Morosini",
    "lat": "45.11266",
    "lng": "11.6189"
  },
  {
    "country": "IT",
    "name": "Dimaro-Folgarida",
    "lat": "46.33176",
    "lng": "10.872"
  },
  {
    "country": "IT",
    "name": "Mappano",
    "lat": "45.14833",
    "lng": "7.70778"
  },
  {
    "country": "JE",
    "name": "Saint Helier",
    "lat": "49.18804",
    "lng": "-2.10491"
  },
  {
    "country": "JE",
    "name": "Le Hocq",
    "lat": "49.16823",
    "lng": "-2.06178"
  },
  {
    "country": "JM",
    "name": "Yallahs",
    "lat": "17.8748",
    "lng": "-76.56245"
  },
  {
    "country": "JM",
    "name": "Williamsfield",
    "lat": "18.06667",
    "lng": "-77.46667"
  },
  {
    "country": "JM",
    "name": "Wakefield",
    "lat": "18.41211",
    "lng": "-77.72183"
  },
  {
    "country": "JM",
    "name": "Ulster Spring",
    "lat": "18.31482",
    "lng": "-77.52067"
  },
  {
    "country": "JM",
    "name": "Trinity Ville",
    "lat": "17.96076",
    "lng": "-76.51427"
  },
  {
    "country": "JM",
    "name": "Stony Hill",
    "lat": "18.07916",
    "lng": "-76.78473"
  },
  {
    "country": "JM",
    "name": "Spanish Town",
    "lat": "17.99107",
    "lng": "-76.95742"
  },
  {
    "country": "JM",
    "name": "Southfield",
    "lat": "17.8878",
    "lng": "-77.66713"
  },
  {
    "country": "JM",
    "name": "Siloah",
    "lat": "18.16709",
    "lng": "-77.70348"
  },
  {
    "country": "JM",
    "name": "Seaforth",
    "lat": "17.93578",
    "lng": "-76.4573"
  },
  {
    "country": "JM",
    "name": "Savanna-la-Mar",
    "lat": "18.21895",
    "lng": "-78.1332"
  },
  {
    "country": "JM",
    "name": "Santa Cruz",
    "lat": "18.05336",
    "lng": "-77.69836"
  },
  {
    "country": "JM",
    "name": "Sandy Bay",
    "lat": "18.44854",
    "lng": "-78.07321"
  },
  {
    "country": "JM",
    "name": "Saint Ann’s Bay",
    "lat": "18.43581",
    "lng": "-77.20098"
  },
  {
    "country": "JM",
    "name": "Runaway Bay",
    "lat": "18.45962",
    "lng": "-77.3357"
  },
  {
    "country": "JM",
    "name": "Rocky Point",
    "lat": "17.774",
    "lng": "-77.26107"
  },
  {
    "country": "JM",
    "name": "Rock Spring",
    "lat": "18.30123",
    "lng": "-77.55259"
  },
  {
    "country": "JM",
    "name": "Riversdale",
    "lat": "18.16586",
    "lng": "-76.96417"
  },
  {
    "country": "JM",
    "name": "Richmond",
    "lat": "18.25478",
    "lng": "-76.88799"
  },
  {
    "country": "JM",
    "name": "Race Course",
    "lat": "17.84019",
    "lng": "-77.28223"
  },
  {
    "country": "JM",
    "name": "Porus",
    "lat": "18.03535",
    "lng": "-77.41166"
  },
  {
    "country": "JM",
    "name": "Port Royal",
    "lat": "17.93738",
    "lng": "-76.84062"
  },
  {
    "country": "JM",
    "name": "Portmore",
    "lat": "17.95032",
    "lng": "-76.88215"
  },
  {
    "country": "JM",
    "name": "Port Maria",
    "lat": "18.36849",
    "lng": "-76.88946"
  },
  {
    "country": "JM",
    "name": "Port Antonio",
    "lat": "18.17615",
    "lng": "-76.4509"
  },
  {
    "country": "JM",
    "name": "Point Hill",
    "lat": "18.08988",
    "lng": "-77.10759"
  },
  {
    "country": "JM",
    "name": "Petersfield",
    "lat": "18.26158",
    "lng": "-78.07117"
  },
  {
    "country": "JM",
    "name": "Oracabessa",
    "lat": "18.40319",
    "lng": "-76.94641"
  },
  {
    "country": "JM",
    "name": "Old Harbour Bay",
    "lat": "17.90918",
    "lng": "-77.09718"
  },
  {
    "country": "JM",
    "name": "Old Harbour",
    "lat": "17.94144",
    "lng": "-77.10898"
  },
  {
    "country": "JM",
    "name": "Ocho Rios",
    "lat": "18.4025",
    "lng": "-77.1048"
  },
  {
    "country": "JM",
    "name": "New Kingston",
    "lat": "18.00747",
    "lng": "-76.78319"
  },
  {
    "country": "JM",
    "name": "Negril",
    "lat": "18.26844",
    "lng": "-78.3481"
  },
  {
    "country": "JM",
    "name": "Nain",
    "lat": "17.96526",
    "lng": "-77.60528"
  },
  {
    "country": "JM",
    "name": "Morant Bay",
    "lat": "17.88145",
    "lng": "-76.40927"
  },
  {
    "country": "JM",
    "name": "Moore Town",
    "lat": "18.07767",
    "lng": "-76.42577"
  },
  {
    "country": "JM",
    "name": "Montego Bay",
    "lat": "18.47116",
    "lng": "-77.91883"
  },
  {
    "country": "JM",
    "name": "Moneague",
    "lat": "18.27556",
    "lng": "-77.11177"
  },
  {
    "country": "JM",
    "name": "Mona Heights",
    "lat": "18.01375",
    "lng": "-76.75186"
  },
  {
    "country": "JM",
    "name": "Mocho",
    "lat": "18.04",
    "lng": "-77.33"
  },
  {
    "country": "JM",
    "name": "May Pen",
    "lat": "17.96454",
    "lng": "-77.24515"
  },
  {
    "country": "JM",
    "name": "Mavis Bank",
    "lat": "18.03333",
    "lng": "-76.66667"
  },
  {
    "country": "JM",
    "name": "Maroon Town",
    "lat": "18.34464",
    "lng": "-77.79544"
  },
  {
    "country": "JM",
    "name": "Mandeville",
    "lat": "18.04168",
    "lng": "-77.50714"
  },
  {
    "country": "JM",
    "name": "Manchioneal",
    "lat": "18.04444",
    "lng": "-76.27735"
  },
  {
    "country": "JM",
    "name": "Malvern",
    "lat": "17.96667",
    "lng": "-77.7"
  },
  {
    "country": "JM",
    "name": "Maggotty",
    "lat": "18.16069",
    "lng": "-77.76349"
  },
  {
    "country": "JM",
    "name": "Lucea",
    "lat": "18.45095",
    "lng": "-78.17356"
  },
  {
    "country": "JM",
    "name": "Lluidas Vale",
    "lat": "18.12587",
    "lng": "-77.14823"
  },
  {
    "country": "JM",
    "name": "Lionel Town",
    "lat": "17.81007",
    "lng": "-77.24061"
  },
  {
    "country": "JM",
    "name": "Linstead",
    "lat": "18.13683",
    "lng": "-77.03171"
  },
  {
    "country": "JM",
    "name": "Lacovia",
    "lat": "18.0721",
    "lng": "-77.75059"
  },
  {
    "country": "JM",
    "name": "Kingston",
    "lat": "17.99702",
    "lng": "-76.79358"
  },
  {
    "country": "JM",
    "name": "Kellits",
    "lat": "18.16184",
    "lng": "-77.27049"
  },
  {
    "country": "JM",
    "name": "Islington",
    "lat": "18.30922",
    "lng": "-76.85482"
  },
  {
    "country": "JM",
    "name": "Hope Bay",
    "lat": "18.19882",
    "lng": "-76.56539"
  },
  {
    "country": "JM",
    "name": "Hayes",
    "lat": "17.87569",
    "lng": "-77.23711"
  },
  {
    "country": "JM",
    "name": "Half Way Tree",
    "lat": "18.01248",
    "lng": "-76.79928"
  },
  {
    "country": "JM",
    "name": "Gordon Town",
    "lat": "18.03578",
    "lng": "-76.71783"
  },
  {
    "country": "JM",
    "name": "Golden Grove",
    "lat": "17.93361",
    "lng": "-76.27254"
  },
  {
    "country": "JM",
    "name": "Gayle",
    "lat": "18.32642",
    "lng": "-77.00971"
  },
  {
    "country": "JM",
    "name": "Falmouth",
    "lat": "18.49358",
    "lng": "-77.65587"
  },
  {
    "country": "JM",
    "name": "Ewarton",
    "lat": "18.18333",
    "lng": "-77.08536"
  },
  {
    "country": "JM",
    "name": "Easington",
    "lat": "17.92397",
    "lng": "-76.58824"
  },
  {
    "country": "JM",
    "name": "Duncans",
    "lat": "18.468",
    "lng": "-77.53633"
  },
  {
    "country": "JM",
    "name": "Discovery Bay",
    "lat": "18.45873",
    "lng": "-77.39997"
  },
  {
    "country": "JM",
    "name": "Darliston",
    "lat": "18.23731",
    "lng": "-77.97626"
  },
  {
    "country": "JM",
    "name": "Dalvey",
    "lat": "17.91184",
    "lng": "-76.24864"
  },
  {
    "country": "JM",
    "name": "Constant Spring",
    "lat": "18.05078",
    "lng": "-76.79372"
  },
  {
    "country": "JM",
    "name": "Coleyville",
    "lat": "18.20783",
    "lng": "-77.50754"
  },
  {
    "country": "JM",
    "name": "Chapelton",
    "lat": "18.08333",
    "lng": "-77.26667"
  },
  {
    "country": "JM",
    "name": "Cascade",
    "lat": "18.39747",
    "lng": "-78.10337"
  },
  {
    "country": "JM",
    "name": "Cambridge",
    "lat": "18.31326",
    "lng": "-77.90252"
  },
  {
    "country": "JM",
    "name": "Bull Savanna",
    "lat": "17.88678",
    "lng": "-77.59022"
  },
  {
    "country": "JM",
    "name": "Buff Bay",
    "lat": "18.23287",
    "lng": "-76.66118"
  },
  {
    "country": "JM",
    "name": "Bog Walk",
    "lat": "18.10205",
    "lng": "-77.00541"
  },
  {
    "country": "JM",
    "name": "Bluefields",
    "lat": "18.16602",
    "lng": "-78.02702"
  },
  {
    "country": "JM",
    "name": "Black River",
    "lat": "18.02636",
    "lng": "-77.84873"
  },
  {
    "country": "JM",
    "name": "Bethel Town",
    "lat": "18.29503",
    "lng": "-77.95112"
  },
  {
    "country": "JM",
    "name": "Bath",
    "lat": "17.9482",
    "lng": "-76.34916"
  },
  {
    "country": "JM",
    "name": "Bamboo",
    "lat": "18.39216",
    "lng": "-77.26429"
  },
  {
    "country": "JM",
    "name": "Balaclava",
    "lat": "18.17228",
    "lng": "-77.64375"
  },
  {
    "country": "JM",
    "name": "Mt Peto",
    "lat": "18.3637",
    "lng": "-78.03736"
  },
  {
    "country": "JM",
    "name": "Annotto Bay",
    "lat": "18.2717",
    "lng": "-76.76523"
  },
  {
    "country": "JM",
    "name": "Anchovy",
    "lat": "18.4103",
    "lng": "-77.93166"
  },
  {
    "country": "JM",
    "name": "Alligator Pond",
    "lat": "17.86932",
    "lng": "-77.56769"
  },
  {
    "country": "JM",
    "name": "Alexandria",
    "lat": "18.30768",
    "lng": "-77.35335"
  },
  {
    "country": "JM",
    "name": "Albert Town",
    "lat": "18.29434",
    "lng": "-77.54239"
  },
  {
    "country": "JM",
    "name": "Limit",
    "lat": "18.15287",
    "lng": "-77.47121"
  },
  {
    "country": "JM",
    "name": "Quickstep",
    "lat": "18.2624",
    "lng": "-77.64586"
  },
  {
    "country": "JO",
    "name": "Zaḩar",
    "lat": "32.5667",
    "lng": "35.77811"
  },
  {
    "country": "JO",
    "name": "Yarqā",
    "lat": "31.97583",
    "lng": "35.69638"
  },
  {
    "country": "JO",
    "name": "Waqqāş",
    "lat": "32.54214",
    "lng": "35.60508"
  },
  {
    "country": "JO",
    "name": "Petra",
    "lat": "30.32096",
    "lng": "35.47895"
  },
  {
    "country": "JO",
    "name": "Wādī as Sīr",
    "lat": "31.9545",
    "lng": "35.81831"
  },
  {
    "country": "JO",
    "name": "Umm Qays",
    "lat": "32.65348",
    "lng": "35.68457"
  },
  {
    "country": "JO",
    "name": "Umm as Summāq",
    "lat": "31.88542",
    "lng": "35.8543"
  },
  {
    "country": "JO",
    "name": "Umm ar Raşāş",
    "lat": "31.51225",
    "lng": "35.91837"
  },
  {
    "country": "JO",
    "name": "Umm al Qiţţayn",
    "lat": "32.31449",
    "lng": "36.62826"
  },
  {
    "country": "JO",
    "name": "Umm al Jimāl",
    "lat": "32.32863",
    "lng": "36.36788"
  },
  {
    "country": "JO",
    "name": "Umm al Basātīn",
    "lat": "31.82454",
    "lng": "35.87795"
  },
  {
    "country": "JO",
    "name": "Adhruḩ",
    "lat": "30.3307",
    "lng": "35.59659"
  },
  {
    "country": "JO",
    "name": "Tibnah",
    "lat": "32.47521",
    "lng": "35.73056"
  },
  {
    "country": "JO",
    "name": "Sūf",
    "lat": "32.31372",
    "lng": "35.83713"
  },
  {
    "country": "JO",
    "name": "Ash Shūnah al Janūbīyah",
    "lat": "31.8915",
    "lng": "35.6178"
  },
  {
    "country": "JO",
    "name": "Sammā ar Rawsān",
    "lat": "32.63794",
    "lng": "35.82661"
  },
  {
    "country": "JO",
    "name": "Şammā",
    "lat": "32.57102",
    "lng": "35.68984"
  },
  {
    "country": "JO",
    "name": "Samā as Sirḩān",
    "lat": "32.46859",
    "lng": "36.24363"
  },
  {
    "country": "JO",
    "name": "Sāl",
    "lat": "32.56897",
    "lng": "35.91185"
  },
  {
    "country": "JO",
    "name": "Sakib",
    "lat": "32.28431",
    "lng": "35.80909"
  },
  {
    "country": "JO",
    "name": "Şakhrah",
    "lat": "32.37087",
    "lng": "35.84267"
  },
  {
    "country": "JO",
    "name": "Saḩam al Kaffārāt",
    "lat": "32.69848",
    "lng": "35.77438"
  },
  {
    "country": "JO",
    "name": "Saḩāb",
    "lat": "31.87032",
    "lng": "36.00479"
  },
  {
    "country": "JO",
    "name": "Şabḩā",
    "lat": "32.32696",
    "lng": "36.50159"
  },
  {
    "country": "JO",
    "name": "Rujm ash Shāmī al Gharbī",
    "lat": "31.83693",
    "lng": "36.00492"
  },
  {
    "country": "JO",
    "name": "Rehab",
    "lat": "32.32341",
    "lng": "36.09087"
  },
  {
    "country": "JO",
    "name": "Raymūn",
    "lat": "32.28202",
    "lng": "35.82779"
  },
  {
    "country": "JO",
    "name": "Qumaym",
    "lat": "32.57174",
    "lng": "35.73452"
  },
  {
    "country": "JO",
    "name": "Qafqafā",
    "lat": "32.34851",
    "lng": "35.93864"
  },
  {
    "country": "JO",
    "name": "Nā‘ūr",
    "lat": "31.87436",
    "lng": "35.82467"
  },
  {
    "country": "JO",
    "name": "Mulayḩ",
    "lat": "31.58517",
    "lng": "35.80716"
  },
  {
    "country": "JO",
    "name": "Al Mughayyir",
    "lat": "31.40634",
    "lng": "35.77083"
  },
  {
    "country": "JO",
    "name": "Malkā",
    "lat": "32.67645",
    "lng": "35.74851"
  },
  {
    "country": "JO",
    "name": "Mā‘īn",
    "lat": "31.68002",
    "lng": "35.732"
  },
  {
    "country": "JO",
    "name": "Mādabā",
    "lat": "31.71599",
    "lng": "35.79392"
  },
  {
    "country": "JO",
    "name": "Ma'an",
    "lat": "30.19624",
    "lng": "35.73405"
  },
  {
    "country": "JO",
    "name": "Kurayyimah",
    "lat": "32.27639",
    "lng": "35.59938"
  },
  {
    "country": "JO",
    "name": "Kufrinjah",
    "lat": "32.29755",
    "lng": "35.70212"
  },
  {
    "country": "JO",
    "name": "Al Fayşalīyah",
    "lat": "31.74909",
    "lng": "35.76922"
  },
  {
    "country": "JO",
    "name": "Kitim",
    "lat": "32.43834",
    "lng": "35.89677"
  },
  {
    "country": "JO",
    "name": "Bīrayn",
    "lat": "32.09943",
    "lng": "35.95783"
  },
  {
    "country": "JO",
    "name": "Al Murayghah",
    "lat": "30.09526",
    "lng": "35.52314"
  },
  {
    "country": "JO",
    "name": "Kharjā",
    "lat": "32.65988",
    "lng": "35.88782"
  },
  {
    "country": "JO",
    "name": "Kafr Sawm",
    "lat": "32.68527",
    "lng": "35.80102"
  },
  {
    "country": "JO",
    "name": "Kafr Asad",
    "lat": "32.598",
    "lng": "35.71266"
  },
  {
    "country": "JO",
    "name": "Kafr Abīl",
    "lat": "32.41752",
    "lng": "35.66305"
  },
  {
    "country": "JO",
    "name": "Juraynah",
    "lat": "31.76",
    "lng": "35.79466"
  },
  {
    "country": "JO",
    "name": "Judita",
    "lat": "32.40792",
    "lng": "35.70802"
  },
  {
    "country": "JO",
    "name": "Jāwā",
    "lat": "31.85247",
    "lng": "35.93928"
  },
  {
    "country": "JO",
    "name": "Jarash",
    "lat": "32.28082",
    "lng": "35.89929"
  },
  {
    "country": "JO",
    "name": "‘Izrā",
    "lat": "31.15889",
    "lng": "35.69278"
  },
  {
    "country": "JO",
    "name": "‘Irjān",
    "lat": "32.39447",
    "lng": "35.73345"
  },
  {
    "country": "JO",
    "name": "Irbid",
    "lat": "32.55556",
    "lng": "35.85"
  },
  {
    "country": "JO",
    "name": "Ḩisbān",
    "lat": "31.79819",
    "lng": "35.80986"
  },
  {
    "country": "JO",
    "name": "Ḩawshā",
    "lat": "32.45144",
    "lng": "36.09903"
  },
  {
    "country": "JO",
    "name": "Ḩātim",
    "lat": "32.64492",
    "lng": "35.77771"
  },
  {
    "country": "JO",
    "name": "Ḩalāwah",
    "lat": "32.38433",
    "lng": "35.66167"
  },
  {
    "country": "JO",
    "name": "Ḩakamā",
    "lat": "32.59354",
    "lng": "35.8832"
  },
  {
    "country": "JO",
    "name": "Fuqū‘",
    "lat": "31.36805",
    "lng": "35.7022"
  },
  {
    "country": "JO",
    "name": "Dhībān",
    "lat": "31.49889",
    "lng": "35.78287"
  },
  {
    "country": "JO",
    "name": "Dayr Yūsuf",
    "lat": "32.48701",
    "lng": "35.79635"
  },
  {
    "country": "JO",
    "name": "Dayr ‘Allā",
    "lat": "32.19571",
    "lng": "35.62161"
  },
  {
    "country": "JO",
    "name": "Dayr Abū Sa‘īd",
    "lat": "32.49816",
    "lng": "35.68671"
  },
  {
    "country": "JO",
    "name": "Buşayrā",
    "lat": "30.73256",
    "lng": "35.60943"
  },
  {
    "country": "JO",
    "name": "Burmā",
    "lat": "32.2193",
    "lng": "35.78507"
  },
  {
    "country": "JO",
    "name": "Bayt Yāfā",
    "lat": "32.52253",
    "lng": "35.78618"
  },
  {
    "country": "JO",
    "name": "Bayt Īdis",
    "lat": "32.43775",
    "lng": "35.69765"
  },
  {
    "country": "JO",
    "name": "Balīlā",
    "lat": "32.39109",
    "lng": "35.93832"
  },
  {
    "country": "JO",
    "name": "Bal‘amā",
    "lat": "32.23649",
    "lng": "36.08811"
  },
  {
    "country": "JO",
    "name": "Zarqa",
    "lat": "32.07275",
    "lng": "36.08796"
  },
  {
    "country": "JO",
    "name": "Muthallath al Azraq",
    "lat": "31.83269",
    "lng": "36.81487"
  },
  {
    "country": "JO",
    "name": "Al Azraq ash Shamālī",
    "lat": "31.88209",
    "lng": "36.83017"
  },
  {
    "country": "JO",
    "name": "‘Ayy",
    "lat": "31.13371",
    "lng": "35.64375"
  },
  {
    "country": "JO",
    "name": "‘Ayn Jannah",
    "lat": "32.33466",
    "lng": "35.7637"
  },
  {
    "country": "JO",
    "name": "‘Ayn al Bāshā",
    "lat": "32.05726",
    "lng": "35.83109"
  },
  {
    "country": "JO",
    "name": "Ayl",
    "lat": "30.20588",
    "lng": "35.53627"
  },
  {
    "country": "JO",
    "name": "Aydūn",
    "lat": "32.50528",
    "lng": "35.85809"
  },
  {
    "country": "JO",
    "name": "Aţ Ţurrah",
    "lat": "32.63979",
    "lng": "35.98943"
  },
  {
    "country": "JO",
    "name": "Aţ Ţayyibah",
    "lat": "32.54304",
    "lng": "35.71756"
  },
  {
    "country": "JO",
    "name": "Al Khinzīrah",
    "lat": "31.05056",
    "lng": "35.60606"
  },
  {
    "country": "JO",
    "name": "Aţ Ţayyibah",
    "lat": "30.25125",
    "lng": "35.4657"
  },
  {
    "country": "JO",
    "name": "Aţ Ţafīlah",
    "lat": "30.83752",
    "lng": "35.60442"
  },
  {
    "country": "JO",
    "name": "Aş Şubayḩī",
    "lat": "32.14844",
    "lng": "35.70535"
  },
  {
    "country": "JO",
    "name": "As Salţ",
    "lat": "32.03917",
    "lng": "35.72722"
  },
  {
    "country": "JO",
    "name": "Safi",
    "lat": "31.03608",
    "lng": "35.46544"
  },
  {
    "country": "JO",
    "name": "Ash Shūnah ash Shamālīyah",
    "lat": "32.62023",
    "lng": "35.61451"
  },
  {
    "country": "JO",
    "name": "Ash Shawbak",
    "lat": "30.52134",
    "lng": "35.57135"
  },
  {
    "country": "JO",
    "name": "Ash Shajarah",
    "lat": "32.64391",
    "lng": "35.94175"
  },
  {
    "country": "JO",
    "name": "Ar Ruwayshid",
    "lat": "32.50152",
    "lng": "38.20405"
  },
  {
    "country": "JO",
    "name": "Ar Ruşayfah",
    "lat": "32.01727",
    "lng": "36.03271"
  },
  {
    "country": "JO",
    "name": "Ar Ramthā",
    "lat": "32.55873",
    "lng": "36.00816"
  },
  {
    "country": "JO",
    "name": "Ar Rabbah",
    "lat": "31.26923",
    "lng": "35.73829"
  },
  {
    "country": "JO",
    "name": "‘Anjarah",
    "lat": "32.3063",
    "lng": "35.75653"
  },
  {
    "country": "JO",
    "name": "Amman",
    "lat": "31.95522",
    "lng": "35.94503"
  },
  {
    "country": "JO",
    "name": "Ḩayy al Quwaysimah",
    "lat": "31.91037",
    "lng": "35.94975"
  },
  {
    "country": "JO",
    "name": "Al Quwayrah",
    "lat": "29.80045",
    "lng": "35.3116"
  },
  {
    "country": "JO",
    "name": "Al Qaţrānah",
    "lat": "31.25083",
    "lng": "36.04932"
  },
  {
    "country": "JO",
    "name": "Al Qaşr",
    "lat": "31.31407",
    "lng": "35.74393"
  },
  {
    "country": "JO",
    "name": "Ghawr al Mazra‘ah",
    "lat": "31.26586",
    "lng": "35.51674"
  },
  {
    "country": "JO",
    "name": "Al Mazār ash Shamālī",
    "lat": "32.47041",
    "lng": "35.79693"
  },
  {
    "country": "JO",
    "name": "Al Mazār al Janūbī",
    "lat": "31.06722",
    "lng": "35.69486"
  },
  {
    "country": "JO",
    "name": "Al Maşţabah",
    "lat": "32.18434",
    "lng": "35.85588"
  },
  {
    "country": "JO",
    "name": "Manshīyat Banī Ḩasan",
    "lat": "32.37066",
    "lng": "36.07933"
  },
  {
    "country": "JO",
    "name": "Mafraq",
    "lat": "32.34289",
    "lng": "36.20804"
  },
  {
    "country": "JO",
    "name": "‘Allān",
    "lat": "32.11815",
    "lng": "35.74351"
  },
  {
    "country": "JO",
    "name": "Al Kittah",
    "lat": "32.27685",
    "lng": "35.84114"
  },
  {
    "country": "JO",
    "name": "Al Karāmah",
    "lat": "31.95439",
    "lng": "35.58033"
  },
  {
    "country": "JO",
    "name": "Qīr Moāv",
    "lat": "31.18248",
    "lng": "35.69999"
  },
  {
    "country": "JO",
    "name": "Al Juwayyidah",
    "lat": "31.88715",
    "lng": "35.93144"
  },
  {
    "country": "JO",
    "name": "Al Jubayhah",
    "lat": "32.01071",
    "lng": "35.89802"
  },
  {
    "country": "JO",
    "name": "Al Jīzah",
    "lat": "31.69893",
    "lng": "35.9553"
  },
  {
    "country": "JO",
    "name": "Al Jafr",
    "lat": "30.3184",
    "lng": "36.17775"
  },
  {
    "country": "JO",
    "name": "Al Ḩusaynīyah",
    "lat": "31.02606",
    "lng": "35.72294"
  },
  {
    "country": "JO",
    "name": "Al Ḩişn",
    "lat": "32.48454",
    "lng": "35.88406"
  },
  {
    "country": "JO",
    "name": "Al Hāshimīyah",
    "lat": "32.12901",
    "lng": "36.1213"
  },
  {
    "country": "JO",
    "name": "Al Ḩasā",
    "lat": "30.82131",
    "lng": "35.97499"
  },
  {
    "country": "JO",
    "name": "Al Ḩamrā’",
    "lat": "32.44017",
    "lng": "36.15265"
  },
  {
    "country": "JO",
    "name": "Al Fuḩayş",
    "lat": "32.00468",
    "lng": "35.78088"
  },
  {
    "country": "JO",
    "name": "Ḩayy al Bunayyāt",
    "lat": "31.89603",
    "lng": "35.88465"
  },
  {
    "country": "JO",
    "name": "Al ‘Arīḑ",
    "lat": "31.55839",
    "lng": "35.65736"
  },
  {
    "country": "JO",
    "name": "Aqaba",
    "lat": "29.52667",
    "lng": "35.00778"
  },
  {
    "country": "JO",
    "name": "‘Ajlūn",
    "lat": "32.33326",
    "lng": "35.75279"
  },
  {
    "country": "JO",
    "name": "Adir",
    "lat": "31.20217",
    "lng": "35.76155"
  },
  {
    "country": "JO",
    "name": "Al Khālidīyah",
    "lat": "32.179",
    "lng": "36.30326"
  },
  {
    "country": "JO",
    "name": "Ar Rīshah",
    "lat": "30.22435",
    "lng": "35.21671"
  },
  {
    "country": "JO",
    "name": "Al Muwaqqar",
    "lat": "31.81473",
    "lng": "36.10879"
  },
  {
    "country": "JO",
    "name": "Karak City",
    "lat": "31.16368",
    "lng": "35.76204"
  },
  {
    "country": "JO",
    "name": "Al Ḩusaynīyah",
    "lat": "30.59545",
    "lng": "35.79701"
  },
  {
    "country": "JO",
    "name": "Ad Dīsah",
    "lat": "29.65284",
    "lng": "35.51123"
  },
  {
    "country": "JO",
    "name": "Russeifa",
    "lat": "32.01778",
    "lng": "36.04639"
  },
  {
    "country": "JO",
    "name": "Muthallath Şabḩā",
    "lat": "32.26011",
    "lng": "36.4678"
  },
  {
    "country": "JO",
    "name": "Tala Bay",
    "lat": "29.40842",
    "lng": "34.97918"
  },
  {
    "country": "JO",
    "name": "Muthallath Jāmi‘at Āl al Bayt",
    "lat": "32.34592",
    "lng": "36.23352"
  },
  {
    "country": "JO",
    "name": "Az̧ Z̧ulayl",
    "lat": "32.1208",
    "lng": "36.28008"
  },
  {
    "country": "JO",
    "name": "Al ‘Abdallī",
    "lat": "31.96501",
    "lng": "35.90821"
  },
  {
    "country": "JO",
    "name": "Dayr al Kahf",
    "lat": "32.27535",
    "lng": "36.83949"
  },
  {
    "country": "JO",
    "name": "Rukban",
    "lat": "33.31405",
    "lng": "38.70342"
  },
  {
    "country": "JP",
    "name": "Shingū",
    "lat": "33.73333",
    "lng": "135.98333"
  },
  {
    "country": "JP",
    "name": "Atsugi",
    "lat": "35.44272",
    "lng": "139.36931"
  },
  {
    "country": "JP",
    "name": "Akashi",
    "lat": "34.65524",
    "lng": "135.00687"
  },
  {
    "country": "JP",
    "name": "Zushi",
    "lat": "35.29483",
    "lng": "139.57812"
  },
  {
    "country": "JP",
    "name": "Zentsujichó",
    "lat": "34.22699",
    "lng": "133.77791"
  },
  {
    "country": "JP",
    "name": "Zama",
    "lat": "35.4879",
    "lng": "139.39101"
  },
  {
    "country": "JP",
    "name": "Yuza",
    "lat": "39.01573",
    "lng": "139.92909"
  },
  {
    "country": "JP",
    "name": "Gero",
    "lat": "35.8",
    "lng": "137.23333"
  },
  {
    "country": "JP",
    "name": "Yukuhashi",
    "lat": "33.72873",
    "lng": "130.983"
  },
  {
    "country": "JP",
    "name": "Yūki",
    "lat": "36.3",
    "lng": "139.88333"
  },
  {
    "country": "JP",
    "name": "Yugawara",
    "lat": "35.15",
    "lng": "139.06667"
  },
  {
    "country": "JP",
    "name": "Yudomari",
    "lat": "30.2347",
    "lng": "130.47942"
  },
  {
    "country": "JP",
    "name": "Yoshino-chō",
    "lat": "34.39611",
    "lng": "135.85768"
  },
  {
    "country": "JP",
    "name": "Yoshikawa",
    "lat": "35.89232",
    "lng": "139.84184"
  },
  {
    "country": "JP",
    "name": "Yoshii",
    "lat": "36.25",
    "lng": "138.98333"
  },
  {
    "country": "JP",
    "name": "Yoshida-kasugachō",
    "lat": "37.68333",
    "lng": "138.88333"
  },
  {
    "country": "JP",
    "name": "Yorii",
    "lat": "36.11567",
    "lng": "139.19429"
  },
  {
    "country": "JP",
    "name": "Yono",
    "lat": "35.88333",
    "lng": "139.63333"
  },
  {
    "country": "JP",
    "name": "Yonakuni",
    "lat": "24.46667",
    "lng": "123"
  },
  {
    "country": "JP",
    "name": "Yonago",
    "lat": "35.43333",
    "lng": "133.33333"
  },
  {
    "country": "JP",
    "name": "Yokosuka",
    "lat": "35.28361",
    "lng": "139.66722"
  },
  {
    "country": "JP",
    "name": "Yokohama",
    "lat": "35.43333",
    "lng": "139.65"
  },
  {
    "country": "JP",
    "name": "Yokkaichi",
    "lat": "34.96667",
    "lng": "136.61667"
  },
  {
    "country": "JP",
    "name": "Youkaichi",
    "lat": "35.11626",
    "lng": "136.19768"
  },
  {
    "country": "JP",
    "name": "Yawata",
    "lat": "34.87009",
    "lng": "135.7027"
  },
  {
    "country": "JP",
    "name": "Honmachi",
    "lat": "32.50439",
    "lng": "130.59952"
  },
  {
    "country": "JP",
    "name": "Yatsuomachi-higashikumisaka",
    "lat": "36.56667",
    "lng": "137.13333"
  },
  {
    "country": "JP",
    "name": "Yasugichō",
    "lat": "35.42146",
    "lng": "133.24224"
  },
  {
    "country": "JP",
    "name": "Yashiro",
    "lat": "34.91667",
    "lng": "134.96667"
  },
  {
    "country": "JP",
    "name": "Yashio",
    "lat": "35.82255",
    "lng": "139.83905"
  },
  {
    "country": "JP",
    "name": "Yao",
    "lat": "34.61667",
    "lng": "135.6"
  },
  {
    "country": "JP",
    "name": "Yanai",
    "lat": "33.96667",
    "lng": "132.11667"
  },
  {
    "country": "JP",
    "name": "Yanagawa",
    "lat": "33.16667",
    "lng": "130.4"
  },
  {
    "country": "JP",
    "name": "Yamato-Takada",
    "lat": "34.51667",
    "lng": "135.75"
  },
  {
    "country": "JP",
    "name": "Yamazakichō-nakabirose",
    "lat": "35",
    "lng": "134.55"
  },
  {
    "country": "JP",
    "name": "Yamakita",
    "lat": "35.36344",
    "lng": "139.07975"
  },
  {
    "country": "JP",
    "name": "Yamaguchi",
    "lat": "34.18333",
    "lng": "131.46667"
  },
  {
    "country": "JP",
    "name": "Yamaga",
    "lat": "33.01667",
    "lng": "130.68911"
  },
  {
    "country": "JP",
    "name": "Yaizu",
    "lat": "34.86877",
    "lng": "138.31952"
  },
  {
    "country": "JP",
    "name": "Yaita",
    "lat": "36.8",
    "lng": "139.93333"
  },
  {
    "country": "JP",
    "name": "Yabu",
    "lat": "35.40304",
    "lng": "134.77118"
  },
  {
    "country": "JP",
    "name": "Wakimachi",
    "lat": "34.06667",
    "lng": "134.15"
  },
  {
    "country": "JP",
    "name": "Wajima",
    "lat": "37.40458",
    "lng": "136.89912"
  },
  {
    "country": "JP",
    "name": "Utsunomiya",
    "lat": "36.56667",
    "lng": "139.88333"
  },
  {
    "country": "JP",
    "name": "Uto",
    "lat": "32.68333",
    "lng": "130.66667"
  },
  {
    "country": "JP",
    "name": "Usuki",
    "lat": "33.12342",
    "lng": "131.80401"
  },
  {
    "country": "JP",
    "name": "Ushibukamachi",
    "lat": "32.20142",
    "lng": "130.02171"
  },
  {
    "country": "JP",
    "name": "Ureshinomachi-shimojuku",
    "lat": "33.11358",
    "lng": "130.00292"
  },
  {
    "country": "JP",
    "name": "Urayasu",
    "lat": "35.67056",
    "lng": "139.88861"
  },
  {
    "country": "JP",
    "name": "Uozu",
    "lat": "36.8",
    "lng": "137.4"
  },
  {
    "country": "JP",
    "name": "Umi",
    "lat": "33.56826",
    "lng": "130.51009"
  },
  {
    "country": "JP",
    "name": "Ujiie",
    "lat": "36.68333",
    "lng": "139.96667"
  },
  {
    "country": "JP",
    "name": "Uji",
    "lat": "34.89044",
    "lng": "135.80325"
  },
  {
    "country": "JP",
    "name": "Uenohara",
    "lat": "35.61667",
    "lng": "139.11667"
  },
  {
    "country": "JP",
    "name": "Ueno-ebisumachi",
    "lat": "34.75856",
    "lng": "136.13108"
  },
  {
    "country": "JP",
    "name": "Uekimachi-mōno",
    "lat": "32.89964",
    "lng": "130.68898"
  },
  {
    "country": "JP",
    "name": "Ueda",
    "lat": "36.40265",
    "lng": "138.28161"
  },
  {
    "country": "JP",
    "name": "Ube",
    "lat": "33.94306",
    "lng": "131.25111"
  },
  {
    "country": "JP",
    "name": "Tsuyama",
    "lat": "35.05215",
    "lng": "133.99885"
  },
  {
    "country": "JP",
    "name": "Tsushima",
    "lat": "35.16667",
    "lng": "136.71667"
  },
  {
    "country": "JP",
    "name": "Tsurusaki",
    "lat": "33.24528",
    "lng": "131.69165"
  },
  {
    "country": "JP",
    "name": "Tsuruoka",
    "lat": "38.72167",
    "lng": "139.82167"
  },
  {
    "country": "JP",
    "name": "Tsurugi-asahimachi",
    "lat": "36.45",
    "lng": "136.63333"
  },
  {
    "country": "JP",
    "name": "Tsuruga",
    "lat": "35.64547",
    "lng": "136.0558"
  },
  {
    "country": "JP",
    "name": "Tsuma",
    "lat": "32.1",
    "lng": "131.4"
  },
  {
    "country": "JP",
    "name": "Tsukumiura",
    "lat": "33.07539",
    "lng": "131.86907"
  },
  {
    "country": "JP",
    "name": "Tsukawaki",
    "lat": "33.27668",
    "lng": "131.15628"
  },
  {
    "country": "JP",
    "name": "Tsuiki",
    "lat": "33.67307",
    "lng": "131.03776"
  },
  {
    "country": "JP",
    "name": "Tsubata",
    "lat": "36.67012",
    "lng": "136.7403"
  },
  {
    "country": "JP",
    "name": "Tsubame",
    "lat": "37.6645",
    "lng": "138.92518"
  },
  {
    "country": "JP",
    "name": "Tsu",
    "lat": "34.73333",
    "lng": "136.51667"
  },
  {
    "country": "JP",
    "name": "Toyota",
    "lat": "35.08333",
    "lng": "137.15"
  },
  {
    "country": "JP",
    "name": "Toyoshina",
    "lat": "36.29991",
    "lng": "137.90108"
  },
  {
    "country": "JP",
    "name": "Toyooka",
    "lat": "35.54008",
    "lng": "134.82038"
  },
  {
    "country": "JP",
    "name": "Toyonaka",
    "lat": "34.78244",
    "lng": "135.46932"
  },
  {
    "country": "JP",
    "name": "Toyokawa",
    "lat": "34.81667",
    "lng": "137.4"
  },
  {
    "country": "JP",
    "name": "Toyohashi",
    "lat": "34.76667",
    "lng": "137.38333"
  },
  {
    "country": "JP",
    "name": "Toyohama",
    "lat": "34.70933",
    "lng": "136.93425"
  },
  {
    "country": "JP",
    "name": "Toyama",
    "lat": "36.7",
    "lng": "137.21667"
  },
  {
    "country": "JP",
    "name": "Tottori",
    "lat": "35.5",
    "lng": "134.23333"
  },
  {
    "country": "JP",
    "name": "Tosu",
    "lat": "33.36667",
    "lng": "130.51667"
  },
  {
    "country": "JP",
    "name": "Tonoshō",
    "lat": "34.48047",
    "lng": "134.17017"
  },
  {
    "country": "JP",
    "name": "Tondabayashichō",
    "lat": "34.50065",
    "lng": "135.60211"
  },
  {
    "country": "JP",
    "name": "Tomioka",
    "lat": "36.25411",
    "lng": "138.89813"
  },
  {
    "country": "JP",
    "name": "Tomigusuku",
    "lat": "26.18583",
    "lng": "127.68192"
  },
  {
    "country": "JP",
    "name": "Tokyo",
    "lat": "35.6895",
    "lng": "139.69171"
  },
  {
    "country": "JP",
    "name": "Tokuyama",
    "lat": "34.05",
    "lng": "131.81667"
  },
  {
    "country": "JP",
    "name": "Tokushima",
    "lat": "34.06667",
    "lng": "134.56667"
  },
  {
    "country": "JP",
    "name": "Tokorozawa",
    "lat": "35.79916",
    "lng": "139.46903"
  },
  {
    "country": "JP",
    "name": "Tokoname",
    "lat": "34.88333",
    "lng": "136.85"
  },
  {
    "country": "JP",
    "name": "Toki",
    "lat": "35.35",
    "lng": "137.18333"
  },
  {
    "country": "JP",
    "name": "Tōkamachi",
    "lat": "37.13333",
    "lng": "138.76667"
  },
  {
    "country": "JP",
    "name": "Togitsu",
    "lat": "32.83333",
    "lng": "129.85"
  },
  {
    "country": "JP",
    "name": "Tochio-honchō",
    "lat": "37.47642",
    "lng": "138.99513"
  },
  {
    "country": "JP",
    "name": "Tochigi",
    "lat": "36.38333",
    "lng": "139.73333"
  },
  {
    "country": "JP",
    "name": "Toba",
    "lat": "34.4833",
    "lng": "136.84186"
  },
  {
    "country": "JP",
    "name": "Tenri",
    "lat": "34.58333",
    "lng": "135.83333"
  },
  {
    "country": "JP",
    "name": "Tennō",
    "lat": "39.9",
    "lng": "139.96667"
  },
  {
    "country": "JP",
    "name": "Tawaramoto",
    "lat": "34.5542",
    "lng": "135.79297"
  },
  {
    "country": "JP",
    "name": "Tatsuno",
    "lat": "35.98426",
    "lng": "137.99721"
  },
  {
    "country": "JP",
    "name": "Tatsunochō-tominaga",
    "lat": "34.86437",
    "lng": "134.552"
  },
  {
    "country": "JP",
    "name": "Tateyama",
    "lat": "34.98333",
    "lng": "139.86667"
  },
  {
    "country": "JP",
    "name": "Tatebayashi",
    "lat": "36.25",
    "lng": "139.53333"
  },
  {
    "country": "JP",
    "name": "Tarumizu",
    "lat": "31.48333",
    "lng": "130.7"
  },
  {
    "country": "JP",
    "name": "Tarui",
    "lat": "35.36667",
    "lng": "136.53333"
  },
  {
    "country": "JP",
    "name": "Tanushimarumachi-toyoki",
    "lat": "33.35",
    "lng": "130.68333"
  },
  {
    "country": "JP",
    "name": "Tanuma",
    "lat": "36.36667",
    "lng": "139.58333"
  },
  {
    "country": "JP",
    "name": "Nishi-Tokyo-shi",
    "lat": "35.72526",
    "lng": "139.5383"
  },
  {
    "country": "JP",
    "name": "Tanashichō",
    "lat": "35.72922",
    "lng": "139.53813"
  },
  {
    "country": "JP",
    "name": "Tanabe",
    "lat": "34.82242",
    "lng": "135.76604"
  },
  {
    "country": "JP",
    "name": "Tanabe",
    "lat": "33.73333",
    "lng": "135.36667"
  },
  {
    "country": "JP",
    "name": "Tamano",
    "lat": "34.51745",
    "lng": "133.94574"
  },
  {
    "country": "JP",
    "name": "Tamana",
    "lat": "32.94716",
    "lng": "130.57446"
  },
  {
    "country": "JP",
    "name": "Tamamura",
    "lat": "36.3",
    "lng": "139.11667"
  },
  {
    "country": "JP",
    "name": "Taketoyo",
    "lat": "34.85",
    "lng": "136.91667"
  },
  {
    "country": "JP",
    "name": "Takeochō-takeo",
    "lat": "33.19009",
    "lng": "130.02084"
  },
  {
    "country": "JP",
    "name": "Takehara",
    "lat": "34.33833",
    "lng": "132.91667"
  },
  {
    "country": "JP",
    "name": "Takefu",
    "lat": "35.90393",
    "lng": "136.16687"
  },
  {
    "country": "JP",
    "name": "Takedamachi",
    "lat": "32.96667",
    "lng": "131.4"
  },
  {
    "country": "JP",
    "name": "Takayama",
    "lat": "36.13333",
    "lng": "137.25"
  },
  {
    "country": "JP",
    "name": "Takatsuki",
    "lat": "34.84833",
    "lng": "135.61678"
  },
  {
    "country": "JP",
    "name": "Takasaki",
    "lat": "36.33333",
    "lng": "139.01667"
  },
  {
    "country": "JP",
    "name": "Takarazuka",
    "lat": "34.79936",
    "lng": "135.35697"
  },
  {
    "country": "JP",
    "name": "Takaoka",
    "lat": "36.75",
    "lng": "137.01667"
  },
  {
    "country": "JP",
    "name": "Takanabe",
    "lat": "32.13333",
    "lng": "131.5"
  },
  {
    "country": "JP",
    "name": "Takamatsu",
    "lat": "34.33333",
    "lng": "134.05"
  },
  {
    "country": "JP",
    "name": "Takaishi",
    "lat": "34.51667",
    "lng": "135.43333"
  },
  {
    "country": "JP",
    "name": "Takahashi",
    "lat": "34.78333",
    "lng": "133.61667"
  },
  {
    "country": "JP",
    "name": "Takahama",
    "lat": "34.91667",
    "lng": "136.98333"
  },
  {
    "country": "JP",
    "name": "Bungo-Takada-shi",
    "lat": "33.5567",
    "lng": "131.44506"
  },
  {
    "country": "JP",
    "name": "Tajimi",
    "lat": "35.31667",
    "lng": "137.13333"
  },
  {
    "country": "JP",
    "name": "Tahara",
    "lat": "34.66667",
    "lng": "137.26667"
  },
  {
    "country": "JP",
    "name": "Tagawa",
    "lat": "33.63333",
    "lng": "130.8"
  },
  {
    "country": "JP",
    "name": "Tadotsu",
    "lat": "34.275",
    "lng": "133.75"
  },
  {
    "country": "JP",
    "name": "Suzuka",
    "lat": "34.88333",
    "lng": "136.58333"
  },
  {
    "country": "JP",
    "name": "Suzaka",
    "lat": "36.65",
    "lng": "138.31667"
  },
  {
    "country": "JP",
    "name": "Suwa",
    "lat": "36.03799",
    "lng": "138.11308"
  },
  {
    "country": "JP",
    "name": "Susaki",
    "lat": "33.39471",
    "lng": "133.29128"
  },
  {
    "country": "JP",
    "name": "Sumoto",
    "lat": "34.34322",
    "lng": "134.88911"
  },
  {
    "country": "JP",
    "name": "Sukumo",
    "lat": "32.93333",
    "lng": "132.73333"
  },
  {
    "country": "JP",
    "name": "Suita",
    "lat": "34.76143",
    "lng": "135.51567"
  },
  {
    "country": "JP",
    "name": "Suibara",
    "lat": "37.84608",
    "lng": "139.23039"
  },
  {
    "country": "JP",
    "name": "Sugito",
    "lat": "36.03107",
    "lng": "139.72636"
  },
  {
    "country": "JP",
    "name": "Sueyoshichō-ninokata",
    "lat": "31.65",
    "lng": "131.01667"
  },
  {
    "country": "JP",
    "name": "Sōka",
    "lat": "35.83643",
    "lng": "139.79957"
  },
  {
    "country": "JP",
    "name": "Sōja",
    "lat": "34.67534",
    "lng": "133.75091"
  },
  {
    "country": "JP",
    "name": "Sobue",
    "lat": "35.25",
    "lng": "136.71667"
  },
  {
    "country": "JP",
    "name": "Shōbu",
    "lat": "36.06667",
    "lng": "139.6"
  },
  {
    "country": "JP",
    "name": "Shōbara",
    "lat": "34.85",
    "lng": "133.01667"
  },
  {
    "country": "JP",
    "name": "Shizuoka",
    "lat": "34.98333",
    "lng": "138.38333"
  },
  {
    "country": "JP",
    "name": "Shirone",
    "lat": "37.76354",
    "lng": "139.02199"
  },
  {
    "country": "JP",
    "name": "Shiraoka",
    "lat": "36.01839",
    "lng": "139.66034"
  },
  {
    "country": "JP",
    "name": "Shirahamachō-usazakiminami",
    "lat": "34.78333",
    "lng": "134.71667"
  },
  {
    "country": "JP",
    "name": "Shiozawa",
    "lat": "37.03757",
    "lng": "138.84867"
  },
  {
    "country": "JP",
    "name": "Shiojiri",
    "lat": "36.1",
    "lng": "137.96667"
  },
  {
    "country": "JP",
    "name": "Shinshiro",
    "lat": "34.9",
    "lng": "137.5"
  },
  {
    "country": "JP",
    "name": "Shin’ichi",
    "lat": "34.55543",
    "lng": "133.27297"
  },
  {
    "country": "JP",
    "name": "Shingū",
    "lat": "33.71399",
    "lng": "130.4313"
  },
  {
    "country": "JP",
    "name": "Shimo-tsuma",
    "lat": "36.18333",
    "lng": "139.96667"
  },
  {
    "country": "JP",
    "name": "Shimonoseki",
    "lat": "33.95",
    "lng": "130.95"
  },
  {
    "country": "JP",
    "name": "Shimodate",
    "lat": "36.3",
    "lng": "139.98333"
  },
  {
    "country": "JP",
    "name": "Shimoda",
    "lat": "34.67652",
    "lng": "138.94456"
  },
  {
    "country": "JP",
    "name": "Minato",
    "lat": "34.2152",
    "lng": "135.1501"
  },
  {
    "country": "JP",
    "name": "Nishishinminato",
    "lat": "36.77957",
    "lng": "137.07576"
  },
  {
    "country": "JP",
    "name": "Shimada",
    "lat": "34.81667",
    "lng": "138.18333"
  },
  {
    "country": "JP",
    "name": "Shimabara",
    "lat": "32.78333",
    "lng": "130.36667"
  },
  {
    "country": "JP",
    "name": "Shima",
    "lat": "34.33333",
    "lng": "136.83333"
  },
  {
    "country": "JP",
    "name": "Shiki",
    "lat": "35.83333",
    "lng": "139.58333"
  },
  {
    "country": "JP",
    "name": "Shiida",
    "lat": "33.65341",
    "lng": "131.05797"
  },
  {
    "country": "JP",
    "name": "Shido",
    "lat": "34.32333",
    "lng": "134.17333"
  },
  {
    "country": "JP",
    "name": "Shibushi",
    "lat": "31.476",
    "lng": "131.10114"
  },
  {
    "country": "JP",
    "name": "Shibukawa",
    "lat": "36.48333",
    "lng": "139"
  },
  {
    "country": "JP",
    "name": "Shibata",
    "lat": "37.95",
    "lng": "139.33333"
  },
  {
    "country": "JP",
    "name": "Settsu",
    "lat": "34.77819",
    "lng": "135.59512"
  },
  {
    "country": "JP",
    "name": "Seto",
    "lat": "35.23333",
    "lng": "137.1"
  },
  {
    "country": "JP",
    "name": "Setakamachi-takayanagi",
    "lat": "33.14858",
    "lng": "130.46548"
  },
  {
    "country": "JP",
    "name": "Satsumasendai",
    "lat": "31.81667",
    "lng": "130.3"
  },
  {
    "country": "JP",
    "name": "Sekimachi",
    "lat": "35.48333",
    "lng": "136.91667"
  },
  {
    "country": "JP",
    "name": "Satte",
    "lat": "36.07254",
    "lng": "139.72615"
  },
  {
    "country": "JP",
    "name": "Sasebo",
    "lat": "33.16834",
    "lng": "129.72502"
  },
  {
    "country": "JP",
    "name": "Sasayama",
    "lat": "35.06667",
    "lng": "135.21667"
  },
  {
    "country": "JP",
    "name": "Sasaguri",
    "lat": "33.61561",
    "lng": "130.55105"
  },
  {
    "country": "JP",
    "name": "Sano",
    "lat": "36.31667",
    "lng": "139.58333"
  },
  {
    "country": "JP",
    "name": "Sanjō",
    "lat": "37.61667",
    "lng": "138.95"
  },
  {
    "country": "JP",
    "name": "Sandachō",
    "lat": "34.88444",
    "lng": "135.22694"
  },
  {
    "country": "JP",
    "name": "Sakurai",
    "lat": "34.5",
    "lng": "135.85"
  },
  {
    "country": "JP",
    "name": "Saku",
    "lat": "36.21667",
    "lng": "138.48333"
  },
  {
    "country": "JP",
    "name": "Sakata",
    "lat": "38.91667",
    "lng": "139.855"
  },
  {
    "country": "JP",
    "name": "Sakaiminato",
    "lat": "35.53774",
    "lng": "133.23094"
  },
  {
    "country": "JP",
    "name": "Sakaidechō",
    "lat": "34.32278",
    "lng": "133.8356"
  },
  {
    "country": "JP",
    "name": "Sakai-nakajima",
    "lat": "36.26667",
    "lng": "139.25"
  },
  {
    "country": "JP",
    "name": "Sakai",
    "lat": "36.1",
    "lng": "139.8"
  },
  {
    "country": "JP",
    "name": "Sakai",
    "lat": "34.58333",
    "lng": "135.46667"
  },
  {
    "country": "JP",
    "name": "Sakado",
    "lat": "35.95694",
    "lng": "139.38889"
  },
  {
    "country": "JP",
    "name": "Saiki",
    "lat": "32.95",
    "lng": "131.9"
  },
  {
    "country": "JP",
    "name": "Sagara",
    "lat": "34.68503",
    "lng": "138.20461"
  },
  {
    "country": "JP",
    "name": "Saga",
    "lat": "33.23333",
    "lng": "130.3"
  },
  {
    "country": "JP",
    "name": "Sabae",
    "lat": "35.94647",
    "lng": "136.18498"
  },
  {
    "country": "JP",
    "name": "Ryūō",
    "lat": "35.65",
    "lng": "138.5"
  },
  {
    "country": "JP",
    "name": "Ryōtsu-minato",
    "lat": "38.07817",
    "lng": "138.43939"
  },
  {
    "country": "JP",
    "name": "Ōzu",
    "lat": "32.8804",
    "lng": "130.87161"
  },
  {
    "country": "JP",
    "name": "Oyama",
    "lat": "36.3",
    "lng": "139.8"
  },
  {
    "country": "JP",
    "name": "Ōyama",
    "lat": "34.60359",
    "lng": "138.21719"
  },
  {
    "country": "JP",
    "name": "Owase",
    "lat": "34.06667",
    "lng": "136.2"
  },
  {
    "country": "JP",
    "name": "Ōuda",
    "lat": "34.46667",
    "lng": "135.93333"
  },
  {
    "country": "JP",
    "name": "Ōtsuki",
    "lat": "35.61851",
    "lng": "138.97396"
  },
  {
    "country": "JP",
    "name": "Ōtsu",
    "lat": "35",
    "lng": "135.86667"
  },
  {
    "country": "JP",
    "name": "Ōtake",
    "lat": "34.20754",
    "lng": "132.22063"
  },
  {
    "country": "JP",
    "name": "Ōta",
    "lat": "36.3",
    "lng": "139.36667"
  },
  {
    "country": "JP",
    "name": "Osaka",
    "lat": "34.69374",
    "lng": "135.50218"
  },
  {
    "country": "JP",
    "name": "Onomichi",
    "lat": "34.41667",
    "lng": "133.2"
  },
  {
    "country": "JP",
    "name": "Onoda",
    "lat": "34.00139",
    "lng": "131.18361"
  },
  {
    "country": "JP",
    "name": "Ono",
    "lat": "35.98106",
    "lng": "136.48727"
  },
  {
    "country": "JP",
    "name": "Ono",
    "lat": "34.85",
    "lng": "134.93333"
  },
  {
    "country": "JP",
    "name": "Ōno-hara",
    "lat": "34.28333",
    "lng": "132.26667"
  },
  {
    "country": "JP",
    "name": "Ōmuta",
    "lat": "33.03333",
    "lng": "130.45"
  },
  {
    "country": "JP",
    "name": "Ōmura",
    "lat": "32.92139",
    "lng": "129.95389"
  },
  {
    "country": "JP",
    "name": "Ōme",
    "lat": "35.78389",
    "lng": "139.24306"
  },
  {
    "country": "JP",
    "name": "Ōmamachō-ōmama",
    "lat": "36.43181",
    "lng": "139.27534"
  },
  {
    "country": "JP",
    "name": "Ōmachi",
    "lat": "36.5",
    "lng": "137.86667"
  },
  {
    "country": "JP",
    "name": "Ōkuchi-shinohara",
    "lat": "32.06779",
    "lng": "130.62439"
  },
  {
    "country": "JP",
    "name": "Okegawa",
    "lat": "36",
    "lng": "139.55722"
  },
  {
    "country": "JP",
    "name": "Okazaki",
    "lat": "34.95",
    "lng": "137.16667"
  },
  {
    "country": "JP",
    "name": "Okayama",
    "lat": "34.65",
    "lng": "133.93333"
  },
  {
    "country": "JP",
    "name": "Okaya",
    "lat": "36.05659",
    "lng": "138.0451"
  },
  {
    "country": "JP",
    "name": "Ōkawa",
    "lat": "33.20566",
    "lng": "130.37527"
  },
  {
    "country": "JP",
    "name": "Ojiya",
    "lat": "37.3",
    "lng": "138.8"
  },
  {
    "country": "JP",
    "name": "Ōita",
    "lat": "33.23333",
    "lng": "131.6"
  },
  {
    "country": "JP",
    "name": "Ōiso",
    "lat": "35.31558",
    "lng": "139.31625"
  },
  {
    "country": "JP",
    "name": "Ōi",
    "lat": "35.85091",
    "lng": "139.51998"
  },
  {
    "country": "JP",
    "name": "Ogōri-shimogō",
    "lat": "34.1",
    "lng": "131.4"
  },
  {
    "country": "JP",
    "name": "Ogawa",
    "lat": "36.05342",
    "lng": "139.26612"
  },
  {
    "country": "JP",
    "name": "Ōgaki",
    "lat": "35.35",
    "lng": "136.61667"
  },
  {
    "country": "JP",
    "name": "Odawara",
    "lat": "35.25556",
    "lng": "139.15972"
  },
  {
    "country": "JP",
    "name": "Ōdachō-ōda",
    "lat": "35.19025",
    "lng": "132.50846"
  },
  {
    "country": "JP",
    "name": "Ōbu",
    "lat": "35.01756",
    "lng": "136.94947"
  },
  {
    "country": "JP",
    "name": "Obita",
    "lat": "32.81667",
    "lng": "129.88333"
  },
  {
    "country": "JP",
    "name": "Obama",
    "lat": "35.49576",
    "lng": "135.74604"
  },
  {
    "country": "JP",
    "name": "Nyūzen",
    "lat": "36.93744",
    "lng": "137.50059"
  },
  {
    "country": "JP",
    "name": "Numazu",
    "lat": "35.1",
    "lng": "138.86667"
  },
  {
    "country": "JP",
    "name": "Numata",
    "lat": "36.63333",
    "lng": "139.05"
  },
  {
    "country": "JP",
    "name": "Nonoichi",
    "lat": "36.53333",
    "lng": "136.61667"
  },
  {
    "country": "JP",
    "name": "Nōgata",
    "lat": "33.74051",
    "lng": "130.72263"
  },
  {
    "country": "JP",
    "name": "Noda",
    "lat": "35.94897",
    "lng": "139.86793"
  },
  {
    "country": "JP",
    "name": "Nobeoka",
    "lat": "32.58333",
    "lng": "131.66667"
  },
  {
    "country": "JP",
    "name": "Nishiwaki",
    "lat": "34.98419",
    "lng": "134.97407"
  },
  {
    "country": "JP",
    "name": "Nishio",
    "lat": "34.86667",
    "lng": "137.05"
  },
  {
    "country": "JP",
    "name": "Nishinoomote",
    "lat": "30.73333",
    "lng": "131"
  },
  {
    "country": "JP",
    "name": "Nishinomiya-hama",
    "lat": "34.71562",
    "lng": "135.33199"
  },
  {
    "country": "JP",
    "name": "Nirasaki",
    "lat": "35.7",
    "lng": "138.45"
  },
  {
    "country": "JP",
    "name": "Ninomiya",
    "lat": "35.3015",
    "lng": "139.25581"
  },
  {
    "country": "JP",
    "name": "Nikkō",
    "lat": "36.75",
    "lng": "139.61667"
  },
  {
    "country": "JP",
    "name": "Niitsu-honchō",
    "lat": "37.80024",
    "lng": "139.1224"
  },
  {
    "country": "JP",
    "name": "Niimi",
    "lat": "34.98333",
    "lng": "133.46667"
  },
  {
    "country": "JP",
    "name": "Niihama",
    "lat": "33.96047",
    "lng": "133.30522"
  },
  {
    "country": "JP",
    "name": "Niigata",
    "lat": "37.88637",
    "lng": "139.00589"
  },
  {
    "country": "JP",
    "name": "Nichinan",
    "lat": "31.6",
    "lng": "131.36667"
  },
  {
    "country": "JP",
    "name": "Naze",
    "lat": "28.36667",
    "lng": "129.48333"
  },
  {
    "country": "JP",
    "name": "Narutochō-mitsuishi",
    "lat": "34.19933",
    "lng": "134.60932"
  },
  {
    "country": "JP",
    "name": "Nara-shi",
    "lat": "34.68505",
    "lng": "135.80485"
  },
  {
    "country": "JP",
    "name": "Nanao",
    "lat": "37.05",
    "lng": "136.96667"
  },
  {
    "country": "JP",
    "name": "Namerikawa",
    "lat": "36.75965",
    "lng": "137.36215"
  },
  {
    "country": "JP",
    "name": "Nakatsugawa",
    "lat": "35.48333",
    "lng": "137.5"
  },
  {
    "country": "JP",
    "name": "Nakatsu",
    "lat": "33.59811",
    "lng": "131.1883"
  },
  {
    "country": "JP",
    "name": "Nakanojōmachi",
    "lat": "36.58717",
    "lng": "138.84083"
  },
  {
    "country": "JP",
    "name": "Nakano",
    "lat": "36.75",
    "lng": "138.36667"
  },
  {
    "country": "JP",
    "name": "Nakamura",
    "lat": "32.98333",
    "lng": "132.93333"
  },
  {
    "country": "JP",
    "name": "Nakama",
    "lat": "33.81688",
    "lng": "130.70962"
  },
  {
    "country": "JP",
    "name": "Naha",
    "lat": "26.21667",
    "lng": "127.68333"
  },
  {
    "country": "JP",
    "name": "Nagoya",
    "lat": "35.18147",
    "lng": "136.90641"
  },
  {
    "country": "JP",
    "name": "Nago",
    "lat": "26.61502",
    "lng": "127.98543"
  },
  {
    "country": "JP",
    "name": "Nagata",
    "lat": "30.39516",
    "lng": "130.42548"
  },
  {
    "country": "JP",
    "name": "Nagasaki",
    "lat": "32.75",
    "lng": "129.88333"
  },
  {
    "country": "JP",
    "name": "Nagareyama",
    "lat": "35.8563",
    "lng": "139.90266"
  },
  {
    "country": "JP",
    "name": "Nagaoka",
    "lat": "37.45",
    "lng": "138.85"
  },
  {
    "country": "JP",
    "name": "Nagano",
    "lat": "36.65",
    "lng": "138.18333"
  },
  {
    "country": "JP",
    "name": "Nagahama",
    "lat": "35.38333",
    "lng": "136.26667"
  },
  {
    "country": "JP",
    "name": "Nabari",
    "lat": "34.61667",
    "lng": "136.08333"
  },
  {
    "country": "JP",
    "name": "Musashino",
    "lat": "35.70611",
    "lng": "139.55944"
  },
  {
    "country": "JP",
    "name": "Muroto-misakicho",
    "lat": "33.28662",
    "lng": "134.16832"
  },
  {
    "country": "JP",
    "name": "Muramatsu",
    "lat": "37.69257",
    "lng": "139.17127"
  },
  {
    "country": "JP",
    "name": "Murakami",
    "lat": "38.23333",
    "lng": "139.48333"
  },
  {
    "country": "JP",
    "name": "Mukō",
    "lat": "34.96545",
    "lng": "135.70415"
  },
  {
    "country": "JP",
    "name": "Muikamachi",
    "lat": "37.06667",
    "lng": "138.88333"
  },
  {
    "country": "JP",
    "name": "Morohongō",
    "lat": "35.93556",
    "lng": "139.30444"
  },
  {
    "country": "JP",
    "name": "Moriyama",
    "lat": "35.06667",
    "lng": "135.98333"
  },
  {
    "country": "JP",
    "name": "Moriguchi",
    "lat": "34.73333",
    "lng": "135.56667"
  },
  {
    "country": "JP",
    "name": "Mori",
    "lat": "34.83333",
    "lng": "137.93333"
  },
  {
    "country": "JP",
    "name": "Mizunami",
    "lat": "35.36667",
    "lng": "137.25"
  },
  {
    "country": "JP",
    "name": "Miyoshi",
    "lat": "34.8",
    "lng": "132.85"
  },
  {
    "country": "JP",
    "name": "Miyazu",
    "lat": "35.53333",
    "lng": "135.18333"
  },
  {
    "country": "JP",
    "name": "Miyazaki",
    "lat": "31.91667",
    "lng": "131.41667"
  },
  {
    "country": "JP",
    "name": "Miyanoura",
    "lat": "30.4269",
    "lng": "130.57151"
  },
  {
    "country": "JP",
    "name": "Miyakonojō",
    "lat": "31.73333",
    "lng": "131.06667"
  },
  {
    "country": "JP",
    "name": "Miyajima",
    "lat": "34.29907",
    "lng": "132.32186"
  },
  {
    "country": "JP",
    "name": "Miyata",
    "lat": "33.70811",
    "lng": "130.65297"
  },
  {
    "country": "JP",
    "name": "Mitsuke",
    "lat": "37.53333",
    "lng": "138.93333"
  },
  {
    "country": "JP",
    "name": "Mitsukaidō",
    "lat": "36.01667",
    "lng": "139.98333"
  },
  {
    "country": "JP",
    "name": "Mitake",
    "lat": "35.41667",
    "lng": "137.13333"
  },
  {
    "country": "JP",
    "name": "Mishima",
    "lat": "35.11667",
    "lng": "138.91667"
  },
  {
    "country": "JP",
    "name": "Mino",
    "lat": "34.82691",
    "lng": "135.47057"
  },
  {
    "country": "JP",
    "name": "Mino",
    "lat": "35.53333",
    "lng": "136.91667"
  },
  {
    "country": "JP",
    "name": "Minamirinkan",
    "lat": "35.49527",
    "lng": "139.44279"
  },
  {
    "country": "JP",
    "name": "Minamata",
    "lat": "32.21667",
    "lng": "130.4"
  },
  {
    "country": "JP",
    "name": "Minakuchichō-matoba",
    "lat": "34.96667",
    "lng": "136.16667"
  },
  {
    "country": "JP",
    "name": "Mikuni",
    "lat": "36.21706",
    "lng": "136.15185"
  },
  {
    "country": "JP",
    "name": "Miki",
    "lat": "34.8",
    "lng": "134.98333"
  },
  {
    "country": "JP",
    "name": "Mihara",
    "lat": "34.4",
    "lng": "133.08333"
  },
  {
    "country": "JP",
    "name": "Mibu",
    "lat": "36.41667",
    "lng": "139.8"
  },
  {
    "country": "JP",
    "name": "Menuma",
    "lat": "36.22245",
    "lng": "139.38205"
  },
  {
    "country": "JP",
    "name": "Matsutō",
    "lat": "36.51667",
    "lng": "136.56667"
  },
  {
    "country": "JP",
    "name": "Matsumoto",
    "lat": "36.23333",
    "lng": "137.96667"
  },
  {
    "country": "JP",
    "name": "Matsue",
    "lat": "35.48333",
    "lng": "133.05"
  },
  {
    "country": "JP",
    "name": "Matsudo",
    "lat": "35.77995",
    "lng": "139.90144"
  },
  {
    "country": "JP",
    "name": "Matsubase",
    "lat": "32.65",
    "lng": "130.66667"
  },
  {
    "country": "JP",
    "name": "Matsubara",
    "lat": "34.56667",
    "lng": "135.55"
  },
  {
    "country": "JP",
    "name": "Masuda",
    "lat": "34.66667",
    "lng": "131.85"
  },
  {
    "country": "JP",
    "name": "Maruoka",
    "lat": "36.1534",
    "lng": "136.27029"
  },
  {
    "country": "JP",
    "name": "Kamimaruko",
    "lat": "36.31865",
    "lng": "138.27329"
  },
  {
    "country": "JP",
    "name": "Marugame",
    "lat": "34.28333",
    "lng": "133.78333"
  },
  {
    "country": "JP",
    "name": "Makurazaki",
    "lat": "31.26667",
    "lng": "130.31667"
  },
  {
    "country": "JP",
    "name": "Makinohara",
    "lat": "34.77437",
    "lng": "138.14831"
  },
  {
    "country": "JP",
    "name": "Maki",
    "lat": "37.75",
    "lng": "138.88333"
  },
  {
    "country": "JP",
    "name": "Maizuru",
    "lat": "35.45",
    "lng": "135.33333"
  },
  {
    "country": "JP",
    "name": "Maibara",
    "lat": "35.31667",
    "lng": "136.28333"
  },
  {
    "country": "JP",
    "name": "Maebashi",
    "lat": "36.4",
    "lng": "139.08333"
  },
  {
    "country": "JP",
    "name": "Maebaru-chūō",
    "lat": "33.55916",
    "lng": "130.20148"
  },
  {
    "country": "JP",
    "name": "Machida",
    "lat": "35.54028",
    "lng": "139.45083"
  },
  {
    "country": "JP",
    "name": "Kyoto",
    "lat": "35.02107",
    "lng": "135.75385"
  },
  {
    "country": "JP",
    "name": "Kushikino",
    "lat": "31.71667",
    "lng": "130.26667"
  },
  {
    "country": "JP",
    "name": "Kusatsu",
    "lat": "35.01667",
    "lng": "135.96667"
  },
  {
    "country": "JP",
    "name": "Kurume",
    "lat": "33.31667",
    "lng": "130.51667"
  },
  {
    "country": "JP",
    "name": "Kuroda",
    "lat": "35.35",
    "lng": "136.78333"
  },
  {
    "country": "JP",
    "name": "Kurio",
    "lat": "30.27123",
    "lng": "130.4236"
  },
  {
    "country": "JP",
    "name": "Kurihashi",
    "lat": "36.13333",
    "lng": "139.7"
  },
  {
    "country": "JP",
    "name": "Kure",
    "lat": "34.23222",
    "lng": "132.56658"
  },
  {
    "country": "JP",
    "name": "Kurayoshi",
    "lat": "35.43333",
    "lng": "133.81667"
  },
  {
    "country": "JP",
    "name": "Kurashiki",
    "lat": "34.58333",
    "lng": "133.76667"
  },
  {
    "country": "JP",
    "name": "Kumamoto",
    "lat": "32.80589",
    "lng": "130.69181"
  },
  {
    "country": "JP",
    "name": "Kumagaya",
    "lat": "36.13497",
    "lng": "139.39004"
  },
  {
    "country": "JP",
    "name": "Kukichūō",
    "lat": "36.06739",
    "lng": "139.67498"
  },
  {
    "country": "JP",
    "name": "Kudamatsu",
    "lat": "34",
    "lng": "131.86667"
  },
  {
    "country": "JP",
    "name": "Kozakai-chō",
    "lat": "34.8",
    "lng": "137.35889"
  },
  {
    "country": "JP",
    "name": "Koshima",
    "lat": "30.23461",
    "lng": "130.53517"
  },
  {
    "country": "JP",
    "name": "Koshigaya",
    "lat": "35.89035",
    "lng": "139.78916"
  },
  {
    "country": "JP",
    "name": "Koseda",
    "lat": "30.38796",
    "lng": "130.64924"
  },
  {
    "country": "JP",
    "name": "Kōnosu",
    "lat": "36.06868",
    "lng": "139.51684"
  },
  {
    "country": "JP",
    "name": "Kōnan",
    "lat": "35.33165",
    "lng": "136.87042"
  },
  {
    "country": "JP",
    "name": "Komoro",
    "lat": "36.31667",
    "lng": "138.43333"
  },
  {
    "country": "JP",
    "name": "Komono",
    "lat": "35",
    "lng": "136.51667"
  },
  {
    "country": "JP",
    "name": "Komatsushimachō",
    "lat": "34",
    "lng": "134.58333"
  },
  {
    "country": "JP",
    "name": "Komatsu",
    "lat": "36.40263",
    "lng": "136.45088"
  },
  {
    "country": "JP",
    "name": "Komaki",
    "lat": "35.28333",
    "lng": "136.91667"
  },
  {
    "country": "JP",
    "name": "Kokubunji",
    "lat": "35.70222",
    "lng": "139.47556"
  },
  {
    "country": "JP",
    "name": "Kokubu-matsuki",
    "lat": "31.73333",
    "lng": "130.76667"
  },
  {
    "country": "JP",
    "name": "Koga",
    "lat": "36.18333",
    "lng": "139.71667"
  },
  {
    "country": "JP",
    "name": "Koga",
    "lat": "33.73333",
    "lng": "130.46667"
  },
  {
    "country": "JP",
    "name": "Kōfu",
    "lat": "35.66667",
    "lng": "138.56667"
  },
  {
    "country": "JP",
    "name": "Kodamachō-kodamaminami",
    "lat": "36.18497",
    "lng": "139.13191"
  },
  {
    "country": "JP",
    "name": "Kochi",
    "lat": "33.55",
    "lng": "133.53333"
  },
  {
    "country": "JP",
    "name": "Kobe",
    "lat": "34.6913",
    "lng": "135.183"
  },
  {
    "country": "JP",
    "name": "Kobayashi",
    "lat": "31.98333",
    "lng": "130.98333"
  },
  {
    "country": "JP",
    "name": "Kiyosu",
    "lat": "35.21667",
    "lng": "136.83333"
  },
  {
    "country": "JP",
    "name": "Kitsuki",
    "lat": "33.41998",
    "lng": "131.61837"
  },
  {
    "country": "JP",
    "name": "Kitakyushu",
    "lat": "33.85181",
    "lng": "130.85034"
  },
  {
    "country": "JP",
    "name": "Kitakata",
    "lat": "37.65",
    "lng": "139.86667"
  },
  {
    "country": "JP",
    "name": "Kitahama",
    "lat": "35.16667",
    "lng": "135.91667"
  },
  {
    "country": "JP",
    "name": "Kishiwada",
    "lat": "34.46667",
    "lng": "135.36667"
  },
  {
    "country": "JP",
    "name": "Kisarazu",
    "lat": "35.38329",
    "lng": "139.93254"
  },
  {
    "country": "JP",
    "name": "Kisai",
    "lat": "36.1",
    "lng": "139.58333"
  },
  {
    "country": "JP",
    "name": "Kiryū",
    "lat": "36.4",
    "lng": "139.33333"
  },
  {
    "country": "JP",
    "name": "Kikuchi",
    "lat": "32.98333",
    "lng": "130.81667"
  },
  {
    "country": "JP",
    "name": "Kazo",
    "lat": "36.11667",
    "lng": "139.6"
  },
  {
    "country": "JP",
    "name": "Kawasaki",
    "lat": "35.52056",
    "lng": "139.71722"
  },
  {
    "country": "JP",
    "name": "Kawasaki",
    "lat": "33.59993",
    "lng": "130.81495"
  },
  {
    "country": "JP",
    "name": "Kawanishi",
    "lat": "34.81667",
    "lng": "135.41667"
  },
  {
    "country": "JP",
    "name": "Kawaguchi",
    "lat": "35.80521",
    "lng": "139.71072"
  },
  {
    "country": "JP",
    "name": "Kawagoe",
    "lat": "35.90861",
    "lng": "139.48528"
  },
  {
    "country": "JP",
    "name": "Katsuyama",
    "lat": "36.06173",
    "lng": "136.50101"
  },
  {
    "country": "JP",
    "name": "Kasukabe",
    "lat": "35.98308",
    "lng": "139.74966"
  },
  {
    "country": "JP",
    "name": "Kasugai",
    "lat": "35.24762",
    "lng": "136.97229"
  },
  {
    "country": "JP",
    "name": "Kashiwazaki",
    "lat": "37.36667",
    "lng": "138.55"
  },
  {
    "country": "JP",
    "name": "Kashiwa",
    "lat": "35.86224",
    "lng": "139.97732"
  },
  {
    "country": "JP",
    "name": "Kashima",
    "lat": "33.10611",
    "lng": "130.09056"
  },
  {
    "country": "JP",
    "name": "Kashihara-shi",
    "lat": "34.50896",
    "lng": "135.7929"
  },
  {
    "country": "JP",
    "name": "Kashihara",
    "lat": "34.58333",
    "lng": "135.61667"
  },
  {
    "country": "JP",
    "name": "Kaseda-shirakame",
    "lat": "31.41667",
    "lng": "130.31667"
  },
  {
    "country": "JP",
    "name": "Kasaoka",
    "lat": "34.50597",
    "lng": "133.50391"
  },
  {
    "country": "JP",
    "name": "Kasamatsuchō",
    "lat": "35.36667",
    "lng": "136.76667"
  },
  {
    "country": "JP",
    "name": "Kariya",
    "lat": "34.98333",
    "lng": "136.98333"
  },
  {
    "country": "JP",
    "name": "Karatsu",
    "lat": "33.4425",
    "lng": "129.96972"
  },
  {
    "country": "JP",
    "name": "Kanzakimachi-kanzaki",
    "lat": "33.30895",
    "lng": "130.37383"
  },
  {
    "country": "JP",
    "name": "Kanuma",
    "lat": "36.55",
    "lng": "139.73333"
  },
  {
    "country": "JP",
    "name": "Kanoya",
    "lat": "31.38333",
    "lng": "130.85"
  },
  {
    "country": "JP",
    "name": "Kan’onjichō",
    "lat": "34.1276",
    "lng": "133.64598"
  },
  {
    "country": "JP",
    "name": "Kannabechō-yahiro",
    "lat": "34.55808",
    "lng": "133.41796"
  },
  {
    "country": "JP",
    "name": "Kanie",
    "lat": "35.13333",
    "lng": "136.8"
  },
  {
    "country": "JP",
    "name": "Kanekomachi",
    "lat": "36.41097",
    "lng": "138.99621"
  },
  {
    "country": "JP",
    "name": "Kanda",
    "lat": "33.78333",
    "lng": "130.98333"
  },
  {
    "country": "JP",
    "name": "Kanazawa",
    "lat": "36.6",
    "lng": "136.61667"
  },
  {
    "country": "JP",
    "name": "Kanaya",
    "lat": "34.82022",
    "lng": "138.12775"
  },
  {
    "country": "JP",
    "name": "Kamojimachō-jōgejima",
    "lat": "34.06803",
    "lng": "134.35033"
  },
  {
    "country": "JP",
    "name": "Kamogatachō-kamogata",
    "lat": "34.53745",
    "lng": "133.58967"
  },
  {
    "country": "JP",
    "name": "Kamo",
    "lat": "37.66442",
    "lng": "139.03502"
  },
  {
    "country": "JP",
    "name": "Kamirenjaku",
    "lat": "35.69423",
    "lng": "139.55495"
  },
  {
    "country": "JP",
    "name": "Kaminokawa",
    "lat": "36.43333",
    "lng": "139.91667"
  },
  {
    "country": "JP",
    "name": "Kamiichi",
    "lat": "36.7",
    "lng": "137.36667"
  },
  {
    "country": "JP",
    "name": "Kameyama",
    "lat": "34.85",
    "lng": "136.45"
  },
  {
    "country": "JP",
    "name": "Kameoka",
    "lat": "35",
    "lng": "135.58333"
  },
  {
    "country": "JP",
    "name": "Kameda-honchō",
    "lat": "37.87214",
    "lng": "139.1099"
  },
  {
    "country": "JP",
    "name": "Kamakura",
    "lat": "35.30889",
    "lng": "139.55028"
  },
  {
    "country": "JP",
    "name": "Kakogawachō-honmachi",
    "lat": "34.76943",
    "lng": "134.82905"
  },
  {
    "country": "JP",
    "name": "Kakegawa",
    "lat": "34.76667",
    "lng": "138.01667"
  },
  {
    "country": "JP",
    "name": "Kakamigahara",
    "lat": "35.41667",
    "lng": "136.86667"
  },
  {
    "country": "JP",
    "name": "Kashima-shi",
    "lat": "35.96536",
    "lng": "140.64474"
  },
  {
    "country": "JP",
    "name": "Kajiki",
    "lat": "31.73333",
    "lng": "130.66667"
  },
  {
    "country": "JP",
    "name": "Kaizuka",
    "lat": "34.45",
    "lng": "135.35"
  },
  {
    "country": "JP",
    "name": "Kainan",
    "lat": "34.15166",
    "lng": "135.21398"
  },
  {
    "country": "JP",
    "name": "Kagoshima",
    "lat": "31.56667",
    "lng": "130.55"
  },
  {
    "country": "JP",
    "name": "Kadoma",
    "lat": "34.7381",
    "lng": "135.57442"
  },
  {
    "country": "JP",
    "name": "Izumo",
    "lat": "35.36667",
    "lng": "132.76667"
  },
  {
    "country": "JP",
    "name": "Izumisano",
    "lat": "34.41667",
    "lng": "135.31667"
  },
  {
    "country": "JP",
    "name": "Izumiōtsu",
    "lat": "34.5",
    "lng": "135.4"
  },
  {
    "country": "JP",
    "name": "Izumi",
    "lat": "34.48333",
    "lng": "135.43333"
  },
  {
    "country": "JP",
    "name": "Izumi",
    "lat": "32.08333",
    "lng": "130.36667"
  },
  {
    "country": "JP",
    "name": "Iwatsuki",
    "lat": "35.96474",
    "lng": "139.69644"
  },
  {
    "country": "JP",
    "name": "Iwata",
    "lat": "34.7",
    "lng": "137.85"
  },
  {
    "country": "JP",
    "name": "Iwakura",
    "lat": "35.28333",
    "lng": "136.86667"
  },
  {
    "country": "JP",
    "name": "Iwakuni",
    "lat": "34.16297",
    "lng": "132.22"
  },
  {
    "country": "JP",
    "name": "Iwai",
    "lat": "36.05",
    "lng": "139.9"
  },
  {
    "country": "JP",
    "name": "Iwade",
    "lat": "34.25",
    "lng": "135.31667"
  },
  {
    "country": "JP",
    "name": "Itsukaichi",
    "lat": "35.72528",
    "lng": "139.21778"
  },
  {
    "country": "JP",
    "name": "Itoman",
    "lat": "26.12647",
    "lng": "127.66918"
  },
  {
    "country": "JP",
    "name": "Itoigawa",
    "lat": "37.03333",
    "lng": "137.85"
  },
  {
    "country": "JP",
    "name": "Itō",
    "lat": "34.96667",
    "lng": "139.08333"
  },
  {
    "country": "JP",
    "name": "Itami",
    "lat": "34.78427",
    "lng": "135.40126"
  },
  {
    "country": "JP",
    "name": "Ishiki",
    "lat": "34.8",
    "lng": "137.01667"
  },
  {
    "country": "JP",
    "name": "Ishikawa",
    "lat": "26.42333",
    "lng": "127.82139"
  },
  {
    "country": "JP",
    "name": "Ishii",
    "lat": "34.06752",
    "lng": "134.44208"
  },
  {
    "country": "JP",
    "name": "Ishige",
    "lat": "36.11667",
    "lng": "139.96667"
  },
  {
    "country": "JP",
    "name": "Ishigaki",
    "lat": "24.34478",
    "lng": "124.15717"
  },
  {
    "country": "JP",
    "name": "Isesaki",
    "lat": "36.31667",
    "lng": "139.2"
  },
  {
    "country": "JP",
    "name": "Isehara",
    "lat": "35.39932",
    "lng": "139.31019"
  },
  {
    "country": "JP",
    "name": "Ise",
    "lat": "34.48333",
    "lng": "136.7"
  },
  {
    "country": "JP",
    "name": "Isawa",
    "lat": "35.65",
    "lng": "138.63333"
  },
  {
    "country": "JP",
    "name": "Isahaya",
    "lat": "32.84111",
    "lng": "130.04306"
  },
  {
    "country": "JP",
    "name": "Inuyama",
    "lat": "35.37995",
    "lng": "136.94295"
  },
  {
    "country": "JP",
    "name": "Ino",
    "lat": "33.55",
    "lng": "133.43333"
  },
  {
    "country": "JP",
    "name": "Innoshima",
    "lat": "34.28333",
    "lng": "133.18333"
  },
  {
    "country": "JP",
    "name": "Inazawa",
    "lat": "35.25",
    "lng": "136.78333"
  },
  {
    "country": "JP",
    "name": "Ina",
    "lat": "35.82756",
    "lng": "137.95378"
  },
  {
    "country": "JP",
    "name": "Imarichō-kō",
    "lat": "33.27362",
    "lng": "129.87877"
  },
  {
    "country": "JP",
    "name": "Imaichi",
    "lat": "36.71667",
    "lng": "139.68333"
  },
  {
    "country": "JP",
    "name": "Ikoma",
    "lat": "34.68333",
    "lng": "135.7"
  },
  {
    "country": "JP",
    "name": "Ikeda",
    "lat": "34.82208",
    "lng": "135.4298"
  },
  {
    "country": "JP",
    "name": "Ikedachō",
    "lat": "34.02849",
    "lng": "133.80616"
  },
  {
    "country": "JP",
    "name": "Ijūin",
    "lat": "31.61667",
    "lng": "130.4"
  },
  {
    "country": "JP",
    "name": "Iizuka",
    "lat": "33.63654",
    "lng": "130.68678"
  },
  {
    "country": "JP",
    "name": "Iiyama",
    "lat": "36.85",
    "lng": "138.36667"
  },
  {
    "country": "JP",
    "name": "Iida",
    "lat": "35.51965",
    "lng": "137.82074"
  },
  {
    "country": "JP",
    "name": "Ichinomiya",
    "lat": "35.3",
    "lng": "136.8"
  },
  {
    "country": "JP",
    "name": "Ibusuki",
    "lat": "31.23333",
    "lng": "130.65"
  },
  {
    "country": "JP",
    "name": "Ibaraki",
    "lat": "34.81641",
    "lng": "135.56828"
  },
  {
    "country": "JP",
    "name": "Ibara",
    "lat": "34.6",
    "lng": "133.46667"
  },
  {
    "country": "JP",
    "name": "Hotaka",
    "lat": "36.3396",
    "lng": "137.88254"
  },
  {
    "country": "JP",
    "name": "Hōryūji",
    "lat": "34.61234",
    "lng": "135.73754"
  },
  {
    "country": "JP",
    "name": "Honjō",
    "lat": "36.2378",
    "lng": "139.19023"
  },
  {
    "country": "JP",
    "name": "Hondomachi-hondo",
    "lat": "32.45993",
    "lng": "130.16713"
  },
  {
    "country": "JP",
    "name": "Hōfu",
    "lat": "34.05",
    "lng": "131.56667"
  },
  {
    "country": "JP",
    "name": "Hitoyoshi",
    "lat": "32.21667",
    "lng": "130.75"
  },
  {
    "country": "JP",
    "name": "Hita",
    "lat": "33.3213",
    "lng": "130.94098"
  },
  {
    "country": "JP",
    "name": "Hisai-motomachi",
    "lat": "34.66667",
    "lng": "136.46667"
  },
  {
    "country": "JP",
    "name": "Hiroshima",
    "lat": "34.4",
    "lng": "132.45"
  },
  {
    "country": "JP",
    "name": "Hiratsuka",
    "lat": "35.32785",
    "lng": "139.33735"
  },
  {
    "country": "JP",
    "name": "Hiratachō",
    "lat": "35.43333",
    "lng": "132.81667"
  },
  {
    "country": "JP",
    "name": "Hirara",
    "lat": "24.80379",
    "lng": "125.30222"
  },
  {
    "country": "JP",
    "name": "Hirakata",
    "lat": "34.81352",
    "lng": "135.64914"
  },
  {
    "country": "JP",
    "name": "Hirado",
    "lat": "33.36853",
    "lng": "129.55247"
  },
  {
    "country": "JP",
    "name": "Hioki",
    "lat": "31.58333",
    "lng": "130.35"
  },
  {
    "country": "JP",
    "name": "Hino",
    "lat": "35.67306",
    "lng": "139.40028"
  },
  {
    "country": "JP",
    "name": "Hino",
    "lat": "35",
    "lng": "136.25"
  },
  {
    "country": "JP",
    "name": "Himimachi",
    "lat": "36.85609",
    "lng": "136.9885"
  },
  {
    "country": "JP",
    "name": "Himeji",
    "lat": "34.81667",
    "lng": "134.7"
  },
  {
    "country": "JP",
    "name": "Hikone",
    "lat": "35.25",
    "lng": "136.25"
  },
  {
    "country": "JP",
    "name": "Hiji",
    "lat": "33.37081",
    "lng": "131.53025"
  },
  {
    "country": "JP",
    "name": "Higashi-ōsaka",
    "lat": "34.66667",
    "lng": "135.58333"
  },
  {
    "country": "JP",
    "name": "Hekinan",
    "lat": "34.88333",
    "lng": "136.98333"
  },
  {
    "country": "JP",
    "name": "Heda",
    "lat": "34.96277",
    "lng": "138.78543"
  },
  {
    "country": "JP",
    "name": "Hayama",
    "lat": "35.27651",
    "lng": "139.57733"
  },
  {
    "country": "JP",
    "name": "Hatsukaichi",
    "lat": "34.35",
    "lng": "132.33333"
  },
  {
    "country": "JP",
    "name": "Hatogaya-honchō",
    "lat": "35.83314",
    "lng": "139.7425"
  },
  {
    "country": "JP",
    "name": "Hashimoto",
    "lat": "34.31667",
    "lng": "135.61667"
  },
  {
    "country": "JP",
    "name": "Hanyū",
    "lat": "36.16667",
    "lng": "139.53333"
  },
  {
    "country": "JP",
    "name": "Hannō",
    "lat": "35.85194",
    "lng": "139.31806"
  },
  {
    "country": "JP",
    "name": "Handa",
    "lat": "34.88333",
    "lng": "136.93333"
  },
  {
    "country": "JP",
    "name": "Hamanoichi",
    "lat": "31.71667",
    "lng": "130.73333"
  },
  {
    "country": "JP",
    "name": "Hamamatsu",
    "lat": "34.7",
    "lng": "137.73333"
  },
  {
    "country": "JP",
    "name": "Hamakita",
    "lat": "34.8",
    "lng": "137.78333"
  },
  {
    "country": "JP",
    "name": "Hamada",
    "lat": "34.88333",
    "lng": "132.08333"
  },
  {
    "country": "JP",
    "name": "Hakui",
    "lat": "36.88333",
    "lng": "136.78333"
  },
  {
    "country": "JP",
    "name": "Hakone",
    "lat": "35.18945",
    "lng": "139.02649"
  },
  {
    "country": "JP",
    "name": "Haibara-akanedai",
    "lat": "34.53333",
    "lng": "135.95"
  },
  {
    "country": "JP",
    "name": "Hagi",
    "lat": "34.4",
    "lng": "131.41667"
  },
  {
    "country": "JP",
    "name": "Katsuren-haebaru",
    "lat": "26.33294",
    "lng": "127.87403"
  },
  {
    "country": "JP",
    "name": "Hadano",
    "lat": "35.37111",
    "lng": "139.22361"
  },
  {
    "country": "JP",
    "name": "Hachiōji",
    "lat": "35.65583",
    "lng": "139.32389"
  },
  {
    "country": "JP",
    "name": "Ōmihachiman",
    "lat": "35.12861",
    "lng": "136.0976"
  },
  {
    "country": "JP",
    "name": "Gyōda",
    "lat": "36.14074",
    "lng": "139.46011"
  },
  {
    "country": "JP",
    "name": "Gushikawa",
    "lat": "26.35937",
    "lng": "127.86735"
  },
  {
    "country": "JP",
    "name": "Gōtsuchō",
    "lat": "35.00856",
    "lng": "132.2257"
  },
  {
    "country": "JP",
    "name": "Gotenba",
    "lat": "35.31859",
    "lng": "138.94343"
  },
  {
    "country": "JP",
    "name": "Gosen",
    "lat": "37.73333",
    "lng": "139.16667"
  },
  {
    "country": "JP",
    "name": "Gose",
    "lat": "34.45",
    "lng": "135.73333"
  },
  {
    "country": "JP",
    "name": "Gojō",
    "lat": "34.35",
    "lng": "135.7"
  },
  {
    "country": "JP",
    "name": "Gōdo",
    "lat": "35.41667",
    "lng": "136.6"
  },
  {
    "country": "JP",
    "name": "Gobō",
    "lat": "33.88153",
    "lng": "135.1696"
  },
  {
    "country": "JP",
    "name": "Ginowan",
    "lat": "26.26265",
    "lng": "127.76147"
  },
  {
    "country": "JP",
    "name": "Gifu-shi",
    "lat": "35.42291",
    "lng": "136.76039"
  },
  {
    "country": "JP",
    "name": "Gamagōri",
    "lat": "34.83333",
    "lng": "137.23333"
  },
  {
    "country": "JP",
    "name": "Futtsu",
    "lat": "35.3108",
    "lng": "139.81877"
  },
  {
    "country": "JP",
    "name": "Honchō",
    "lat": "35.70129",
    "lng": "139.98648"
  },
  {
    "country": "JP",
    "name": "Fukuyama",
    "lat": "34.48333",
    "lng": "133.36667"
  },
  {
    "country": "JP",
    "name": "Fukuroi",
    "lat": "34.75",
    "lng": "137.91667"
  },
  {
    "country": "JP",
    "name": "Fukura",
    "lat": "34.25765",
    "lng": "134.71535"
  },
  {
    "country": "JP",
    "name": "Fukuoka",
    "lat": "33.6",
    "lng": "130.41667"
  },
  {
    "country": "JP",
    "name": "Fukumitsu",
    "lat": "36.55751",
    "lng": "136.86945"
  },
  {
    "country": "JP",
    "name": "Nishifukuma",
    "lat": "33.76627",
    "lng": "130.47461"
  },
  {
    "country": "JP",
    "name": "Fukui-shi",
    "lat": "36.06443",
    "lng": "136.22257"
  },
  {
    "country": "JP",
    "name": "Fukuechō",
    "lat": "32.69732",
    "lng": "128.84561"
  },
  {
    "country": "JP",
    "name": "Fukuchiyama",
    "lat": "35.3",
    "lng": "135.11667"
  },
  {
    "country": "JP",
    "name": "Fukiage-fujimi",
    "lat": "36.1",
    "lng": "139.45"
  },
  {
    "country": "JP",
    "name": "Fukayachō",
    "lat": "36.2",
    "lng": "139.28333"
  },
  {
    "country": "JP",
    "name": "Fujisawa",
    "lat": "35.34926",
    "lng": "139.47666"
  },
  {
    "country": "JP",
    "name": "Fujioka",
    "lat": "36.25",
    "lng": "139.65"
  },
  {
    "country": "JP",
    "name": "Fujioka",
    "lat": "36.24624",
    "lng": "139.07204"
  },
  {
    "country": "JP",
    "name": "Fujinomiya",
    "lat": "35.21667",
    "lng": "138.61667"
  },
  {
    "country": "JP",
    "name": "Fujieda",
    "lat": "34.86667",
    "lng": "138.26667"
  },
  {
    "country": "JP",
    "name": "Fuji",
    "lat": "35.16667",
    "lng": "138.68333"
  },
  {
    "country": "JP",
    "name": "Fuchūchō",
    "lat": "34.5735",
    "lng": "133.23513"
  },
  {
    "country": "JP",
    "name": "Enzan",
    "lat": "35.7",
    "lng": "138.73333"
  },
  {
    "country": "JP",
    "name": "Daitōchō",
    "lat": "34.71378",
    "lng": "135.62033"
  },
  {
    "country": "JP",
    "name": "Chōfu",
    "lat": "35.65924",
    "lng": "139.54837"
  },
  {
    "country": "JP",
    "name": "Chiryū",
    "lat": "35",
    "lng": "137.03333"
  },
  {
    "country": "JP",
    "name": "Chino",
    "lat": "35.9944",
    "lng": "138.15428"
  },
  {
    "country": "JP",
    "name": "Chikushino-shi",
    "lat": "33.49631",
    "lng": "130.5156"
  },
  {
    "country": "JP",
    "name": "Chigasaki",
    "lat": "35.33638",
    "lng": "139.40434"
  },
  {
    "country": "JP",
    "name": "Chichibu",
    "lat": "35.99028",
    "lng": "139.07639"
  },
  {
    "country": "JP",
    "name": "Chatan",
    "lat": "26.30948",
    "lng": "127.77024"
  },
  {
    "country": "JP",
    "name": "Beppu",
    "lat": "33.27945",
    "lng": "131.49751"
  },
  {
    "country": "JP",
    "name": "Ayabe",
    "lat": "35.3",
    "lng": "135.25"
  },
  {
    "country": "JP",
    "name": "Awara",
    "lat": "36.22309",
    "lng": "136.19236"
  },
  {
    "country": "JP",
    "name": "Atami",
    "lat": "35.08834",
    "lng": "139.05325"
  },
  {
    "country": "JP",
    "name": "Ashiya",
    "lat": "34.72807",
    "lng": "135.30264"
  },
  {
    "country": "JP",
    "name": "Ashikaga",
    "lat": "36.33333",
    "lng": "139.45"
  },
  {
    "country": "JP",
    "name": "Arai",
    "lat": "37.00059",
    "lng": "138.2259"
  },
  {
    "country": "JP",
    "name": "Annaka",
    "lat": "36.33011",
    "lng": "138.89585"
  },
  {
    "country": "JP",
    "name": "Anjō",
    "lat": "34.95828",
    "lng": "137.08054"
  },
  {
    "country": "JP",
    "name": "Anan",
    "lat": "33.91667",
    "lng": "134.65"
  },
  {
    "country": "JP",
    "name": "Amagi",
    "lat": "33.41804",
    "lng": "130.65413"
  },
  {
    "country": "JP",
    "name": "Amagasaki",
    "lat": "34.71667",
    "lng": "135.41667"
  },
  {
    "country": "JP",
    "name": "Akune",
    "lat": "32.01667",
    "lng": "130.2"
  },
  {
    "country": "JP",
    "name": "Kariya",
    "lat": "34.75136",
    "lng": "134.38734"
  },
  {
    "country": "JP",
    "name": "Aki",
    "lat": "33.5",
    "lng": "133.9"
  },
  {
    "country": "JP",
    "name": "Aioi",
    "lat": "34.80361",
    "lng": "134.46806"
  },
  {
    "country": "JP",
    "name": "Ageoshimo",
    "lat": "35.97145",
    "lng": "139.61382"
  },
  {
    "country": "JP",
    "name": "Okinawa",
    "lat": "26.33583",
    "lng": "127.80139"
  },
  {
    "country": "JP",
    "name": "Kushima",
    "lat": "31.48621",
    "lng": "131.2421"
  },
  {
    "country": "JP",
    "name": "Hikari",
    "lat": "33.955",
    "lng": "131.95"
  },
  {
    "country": "JP",
    "name": "Nagato",
    "lat": "34.38333",
    "lng": "131.2"
  },
  {
    "country": "JP",
    "name": "Hasuda",
    "lat": "35.97113",
    "lng": "139.6491"
  },
  {
    "country": "JP",
    "name": "Kamifukuoka",
    "lat": "35.87266",
    "lng": "139.51369"
  },
  {
    "country": "JP",
    "name": "Sayama",
    "lat": "35.85295",
    "lng": "139.41212"
  },
  {
    "country": "JP",
    "name": "Fussa",
    "lat": "35.73667",
    "lng": "139.32361"
  },
  {
    "country": "JP",
    "name": "Asaka",
    "lat": "35.80472",
    "lng": "139.60194"
  },
  {
    "country": "JP",
    "name": "Wako",
    "lat": "35.78944",
    "lng": "139.62333"
  },
  {
    "country": "JP",
    "name": "Shimotoda",
    "lat": "35.815",
    "lng": "139.6853"
  },
  {
    "country": "JP",
    "name": "Kimitsu",
    "lat": "35.35043",
    "lng": "139.87029"
  },
  {
    "country": "JP",
    "name": "Miura",
    "lat": "35.14",
    "lng": "139.61917"
  },
  {
    "country": "JP",
    "name": "Wakayama",
    "lat": "34.23333",
    "lng": "135.16667"
  },
  {
    "country": "JP",
    "name": "Iyo",
    "lat": "33.75139",
    "lng": "132.70139"
  },
  {
    "country": "JP",
    "name": "Uwajima",
    "lat": "33.22375",
    "lng": "132.56001"
  },
  {
    "country": "JP",
    "name": "Saijō",
    "lat": "33.91667",
    "lng": "133.18333"
  },
  {
    "country": "JP",
    "name": "Ōzu",
    "lat": "33.5",
    "lng": "132.55"
  },
  {
    "country": "JP",
    "name": "Matsuyama",
    "lat": "33.83916",
    "lng": "132.76574"
  },
  {
    "country": "JP",
    "name": "Masaki-chō",
    "lat": "33.78757",
    "lng": "132.71124"
  },
  {
    "country": "JP",
    "name": "Kawanoechō",
    "lat": "34.01654",
    "lng": "133.57844"
  },
  {
    "country": "JP",
    "name": "Imabari-shi",
    "lat": "34.07001",
    "lng": "133.00023"
  },
  {
    "country": "JP",
    "name": "Hōjō",
    "lat": "33.97661",
    "lng": "132.77767"
  },
  {
    "country": "JP",
    "name": "Yuzawa",
    "lat": "39.16667",
    "lng": "140.5"
  },
  {
    "country": "JP",
    "name": "Yotsukaidō",
    "lat": "35.65",
    "lng": "140.16667"
  },
  {
    "country": "JP",
    "name": "Yonezawa",
    "lat": "37.91",
    "lng": "140.11667"
  },
  {
    "country": "JP",
    "name": "Yokote",
    "lat": "39.31691",
    "lng": "140.55034"
  },
  {
    "country": "JP",
    "name": "Yōkaichiba",
    "lat": "35.7",
    "lng": "140.55"
  },
  {
    "country": "JP",
    "name": "Yanagawamachi-saiwaichō",
    "lat": "37.85",
    "lng": "140.6"
  },
  {
    "country": "JP",
    "name": "Yamoto",
    "lat": "38.42738",
    "lng": "141.21487"
  },
  {
    "country": "JP",
    "name": "Yamagata",
    "lat": "38.23333",
    "lng": "140.36667"
  },
  {
    "country": "JP",
    "name": "Yamada",
    "lat": "39.46667",
    "lng": "141.95"
  },
  {
    "country": "JP",
    "name": "Yachimata",
    "lat": "35.65",
    "lng": "140.31667"
  },
  {
    "country": "JP",
    "name": "Watari",
    "lat": "38.035",
    "lng": "140.85111"
  },
  {
    "country": "JP",
    "name": "Wakuya",
    "lat": "38.54465",
    "lng": "141.13461"
  },
  {
    "country": "JP",
    "name": "Ushiku",
    "lat": "35.96667",
    "lng": "140.13333"
  },
  {
    "country": "JP",
    "name": "Tsukuba",
    "lat": "36.2",
    "lng": "140.1"
  },
  {
    "country": "JP",
    "name": "Toride",
    "lat": "35.9",
    "lng": "140.08333"
  },
  {
    "country": "JP",
    "name": "Tōno",
    "lat": "39.31667",
    "lng": "141.53333"
  },
  {
    "country": "JP",
    "name": "Tomobe",
    "lat": "36.35",
    "lng": "140.3"
  },
  {
    "country": "JP",
    "name": "Tomiya",
    "lat": "38.39306",
    "lng": "140.88611"
  },
  {
    "country": "JP",
    "name": "Tōgane",
    "lat": "35.55",
    "lng": "140.36667"
  },
  {
    "country": "JP",
    "name": "Tendō",
    "lat": "38.35361",
    "lng": "140.36972"
  },
  {
    "country": "JP",
    "name": "Takahata",
    "lat": "38.0025",
    "lng": "140.19111"
  },
  {
    "country": "JP",
    "name": "Takahagi",
    "lat": "36.71667",
    "lng": "140.71667"
  },
  {
    "country": "JP",
    "name": "Tagajō-shi",
    "lat": "38.3",
    "lng": "141"
  },
  {
    "country": "JP",
    "name": "Sukagawa",
    "lat": "37.28333",
    "lng": "140.38333"
  },
  {
    "country": "JP",
    "name": "Shizukuishi",
    "lat": "39.69414",
    "lng": "140.98442"
  },
  {
    "country": "JP",
    "name": "Shisui",
    "lat": "35.71667",
    "lng": "140.26667"
  },
  {
    "country": "JP",
    "name": "Shiroishi",
    "lat": "38.00333",
    "lng": "140.61833"
  },
  {
    "country": "JP",
    "name": "Shiroi",
    "lat": "35.8",
    "lng": "140.06667"
  },
  {
    "country": "JP",
    "name": "Shiogama",
    "lat": "38.31667",
    "lng": "141.03333"
  },
  {
    "country": "JP",
    "name": "Shinjō",
    "lat": "38.75861",
    "lng": "140.30083"
  },
  {
    "country": "JP",
    "name": "Sendai",
    "lat": "38.26667",
    "lng": "140.86667"
  },
  {
    "country": "JP",
    "name": "Sawara",
    "lat": "35.88333",
    "lng": "140.5"
  },
  {
    "country": "JP",
    "name": "Sakura",
    "lat": "35.71667",
    "lng": "140.23333"
  },
  {
    "country": "JP",
    "name": "Sagae",
    "lat": "38.3725",
    "lng": "140.2725"
  },
  {
    "country": "JP",
    "name": "Ryūgasaki",
    "lat": "35.9",
    "lng": "140.18333"
  },
  {
    "country": "JP",
    "name": "Rifu",
    "lat": "38.33092",
    "lng": "140.97691"
  },
  {
    "country": "JP",
    "name": "Ōtsuchi",
    "lat": "39.36667",
    "lng": "141.9"
  },
  {
    "country": "JP",
    "name": "Ōtawara",
    "lat": "36.86667",
    "lng": "140.03333"
  },
  {
    "country": "JP",
    "name": "Onagawa Chō",
    "lat": "38.4466",
    "lng": "141.44794"
  },
  {
    "country": "JP",
    "name": "Ōmiya",
    "lat": "36.55",
    "lng": "140.41667"
  },
  {
    "country": "JP",
    "name": "Omigawa",
    "lat": "35.85",
    "lng": "140.61667"
  },
  {
    "country": "JP",
    "name": "Ōmagari",
    "lat": "39.45",
    "lng": "140.48333"
  },
  {
    "country": "JP",
    "name": "Okunoya",
    "lat": "36.28333",
    "lng": "140.41667"
  },
  {
    "country": "JP",
    "name": "Ōkawara",
    "lat": "38.05",
    "lng": "140.73361"
  },
  {
    "country": "JP",
    "name": "Ōhara",
    "lat": "35.24761",
    "lng": "140.39289"
  },
  {
    "country": "JP",
    "name": "Ōfunato",
    "lat": "39.07167",
    "lng": "141.71667"
  },
  {
    "country": "JP",
    "name": "Obanazawa",
    "lat": "38.60333",
    "lng": "140.40194"
  },
  {
    "country": "JP",
    "name": "Ōarai",
    "lat": "36.31409",
    "lng": "140.58389"
  },
  {
    "country": "JP",
    "name": "Ōami",
    "lat": "35.51667",
    "lng": "140.31667"
  },
  {
    "country": "JP",
    "name": "Nihommatsu",
    "lat": "37.58333",
    "lng": "140.43333"
  },
  {
    "country": "JP",
    "name": "Natori-shi",
    "lat": "38.16667",
    "lng": "140.88333"
  },
  {
    "country": "JP",
    "name": "Narutō",
    "lat": "35.6",
    "lng": "140.41667"
  },
  {
    "country": "JP",
    "name": "Narita",
    "lat": "35.78333",
    "lng": "140.31667"
  },
  {
    "country": "JP",
    "name": "Namie",
    "lat": "37.48333",
    "lng": "141"
  },
  {
    "country": "JP",
    "name": "Naka",
    "lat": "36.05",
    "lng": "140.16667"
  },
  {
    "country": "JP",
    "name": "Nagai",
    "lat": "38.10361",
    "lng": "140.035"
  },
  {
    "country": "JP",
    "name": "Motomiya",
    "lat": "37.51391",
    "lng": "140.40063"
  },
  {
    "country": "JP",
    "name": "Motegi",
    "lat": "36.51667",
    "lng": "140.18333"
  },
  {
    "country": "JP",
    "name": "Moriya",
    "lat": "35.93333",
    "lng": "140"
  },
  {
    "country": "JP",
    "name": "Morioka",
    "lat": "39.7",
    "lng": "141.15"
  },
  {
    "country": "JP",
    "name": "Mooka",
    "lat": "36.43333",
    "lng": "140.01667"
  },
  {
    "country": "JP",
    "name": "Mobara",
    "lat": "35.42583",
    "lng": "140.29608"
  },
  {
    "country": "JP",
    "name": "Mizusawa",
    "lat": "39.13333",
    "lng": "141.13333"
  },
  {
    "country": "JP",
    "name": "Miyako",
    "lat": "39.64691",
    "lng": "141.94057"
  },
  {
    "country": "JP",
    "name": "Mito",
    "lat": "36.35",
    "lng": "140.45"
  },
  {
    "country": "JP",
    "name": "Miharu",
    "lat": "37.43333",
    "lng": "140.48333"
  },
  {
    "country": "JP",
    "name": "Matsushima",
    "lat": "38.37357",
    "lng": "141.06105"
  },
  {
    "country": "JP",
    "name": "Mashiko",
    "lat": "36.46667",
    "lng": "140.1"
  },
  {
    "country": "JP",
    "name": "Marumori",
    "lat": "37.91667",
    "lng": "140.76667"
  },
  {
    "country": "JP",
    "name": "Makabe",
    "lat": "36.26667",
    "lng": "140.1"
  },
  {
    "country": "JP",
    "name": "Kuroiso",
    "lat": "36.96667",
    "lng": "140.05"
  },
  {
    "country": "JP",
    "name": "Kōriyama",
    "lat": "37.4",
    "lng": "140.38333"
  },
  {
    "country": "JP",
    "name": "Kogota",
    "lat": "38.55",
    "lng": "141.05"
  },
  {
    "country": "JP",
    "name": "Kitakami",
    "lat": "39.28333",
    "lng": "141.11667"
  },
  {
    "country": "JP",
    "name": "Kitaibaraki",
    "lat": "36.78671",
    "lng": "140.74901"
  },
  {
    "country": "JP",
    "name": "Kesennuma",
    "lat": "38.90112",
    "lng": "141.57746"
  },
  {
    "country": "JP",
    "name": "Kamogawa",
    "lat": "35.0969",
    "lng": "140.1003"
  },
  {
    "country": "JP",
    "name": "Katsuura",
    "lat": "35.14621",
    "lng": "140.31507"
  },
  {
    "country": "JP",
    "name": "Katsuta",
    "lat": "36.38333",
    "lng": "140.53333"
  },
  {
    "country": "JP",
    "name": "Katori-shi",
    "lat": "35.89767",
    "lng": "140.49943"
  },
  {
    "country": "JP",
    "name": "Kasama",
    "lat": "36.38333",
    "lng": "140.26667"
  },
  {
    "country": "JP",
    "name": "Karasuyama",
    "lat": "36.65",
    "lng": "140.15"
  },
  {
    "country": "JP",
    "name": "Kaminoyama",
    "lat": "38.15389",
    "lng": "140.27361"
  },
  {
    "country": "JP",
    "name": "Kamaishi",
    "lat": "39.27694",
    "lng": "141.86801"
  },
  {
    "country": "JP",
    "name": "Kakunodatemachi",
    "lat": "39.58926",
    "lng": "140.56724"
  },
  {
    "country": "JP",
    "name": "Kakuda",
    "lat": "37.97451",
    "lng": "140.77202"
  },
  {
    "country": "JP",
    "name": "Iwase",
    "lat": "36.35",
    "lng": "140.1"
  },
  {
    "country": "JP",
    "name": "Iwanuma",
    "lat": "38.10472",
    "lng": "140.85944"
  },
  {
    "country": "JP",
    "name": "Iwaki",
    "lat": "37.05",
    "lng": "140.88333"
  },
  {
    "country": "JP",
    "name": "Itako",
    "lat": "35.93333",
    "lng": "140.55"
  },
  {
    "country": "JP",
    "name": "Ishioka",
    "lat": "36.18333",
    "lng": "140.26667"
  },
  {
    "country": "JP",
    "name": "Ishinomaki",
    "lat": "38.41667",
    "lng": "141.3"
  },
  {
    "country": "JP",
    "name": "Ishikawa",
    "lat": "37.15",
    "lng": "140.45"
  },
  {
    "country": "JP",
    "name": "Inawashiro",
    "lat": "37.56667",
    "lng": "140.11667"
  },
  {
    "country": "JP",
    "name": "Ichinoseki",
    "lat": "38.91667",
    "lng": "141.13333"
  },
  {
    "country": "JP",
    "name": "Ichihara",
    "lat": "35.51667",
    "lng": "140.08333"
  },
  {
    "country": "JP",
    "name": "Hokota",
    "lat": "36.15",
    "lng": "140.51667"
  },
  {
    "country": "JP",
    "name": "Hobaramachi",
    "lat": "37.81667",
    "lng": "140.55"
  },
  {
    "country": "JP",
    "name": "Hitachi",
    "lat": "36.6",
    "lng": "140.65"
  },
  {
    "country": "JP",
    "name": "Higashine",
    "lat": "38.43889",
    "lng": "140.40056"
  },
  {
    "country": "JP",
    "name": "Hasaki",
    "lat": "35.73333",
    "lng": "140.83333"
  },
  {
    "country": "JP",
    "name": "Hanamaki",
    "lat": "39.38333",
    "lng": "141.11667"
  },
  {
    "country": "JP",
    "name": "Furukawa",
    "lat": "38.57167",
    "lng": "140.95556"
  },
  {
    "country": "JP",
    "name": "Funehikimachi-funehiki",
    "lat": "37.44722",
    "lng": "140.5771"
  },
  {
    "country": "JP",
    "name": "Funaishikawa",
    "lat": "36.46667",
    "lng": "140.56667"
  },
  {
    "country": "JP",
    "name": "Fukushima",
    "lat": "37.75",
    "lng": "140.46667"
  },
  {
    "country": "JP",
    "name": "Fujishiro",
    "lat": "35.91667",
    "lng": "140.11667"
  },
  {
    "country": "JP",
    "name": "Edosaki",
    "lat": "35.95",
    "lng": "140.31667"
  },
  {
    "country": "JP",
    "name": "Date",
    "lat": "37.81667",
    "lng": "140.5"
  },
  {
    "country": "JP",
    "name": "Daigo",
    "lat": "36.76667",
    "lng": "140.35"
  },
  {
    "country": "JP",
    "name": "Choshi",
    "lat": "35.73333",
    "lng": "140.83333"
  },
  {
    "country": "JP",
    "name": "Chiba",
    "lat": "35.6",
    "lng": "140.11667"
  },
  {
    "country": "JP",
    "name": "Asahi",
    "lat": "35.71667",
    "lng": "140.65"
  },
  {
    "country": "JP",
    "name": "Ami",
    "lat": "36.03333",
    "lng": "140.2"
  },
  {
    "country": "JP",
    "name": "Akita",
    "lat": "39.71667",
    "lng": "140.11667"
  },
  {
    "country": "JP",
    "name": "Abiko",
    "lat": "35.86667",
    "lng": "140.01667"
  },
  {
    "country": "JP",
    "name": "Motomachi",
    "lat": "43.82634",
    "lng": "144.09638"
  },
  {
    "country": "JP",
    "name": "Yūbari",
    "lat": "43.03778",
    "lng": "141.95778"
  },
  {
    "country": "JP",
    "name": "Wakkanai",
    "lat": "45.40944",
    "lng": "141.67389"
  },
  {
    "country": "JP",
    "name": "Utashinai",
    "lat": "43.51667",
    "lng": "142.05"
  },
  {
    "country": "JP",
    "name": "Tomakomai",
    "lat": "42.63694",
    "lng": "141.60333"
  },
  {
    "country": "JP",
    "name": "Tōbetsu",
    "lat": "43.21694",
    "lng": "141.51694"
  },
  {
    "country": "JP",
    "name": "Mutsu",
    "lat": "41.28944",
    "lng": "141.21694"
  },
  {
    "country": "JP",
    "name": "Takikawa",
    "lat": "43.55278",
    "lng": "141.90639"
  },
  {
    "country": "JP",
    "name": "Takanosu",
    "lat": "40.22268",
    "lng": "140.36611"
  },
  {
    "country": "JP",
    "name": "Sunagawa",
    "lat": "43.48639",
    "lng": "141.90556"
  },
  {
    "country": "JP",
    "name": "Shizunai-furukawachō",
    "lat": "42.33389",
    "lng": "142.36694"
  },
  {
    "country": "JP",
    "name": "Shiraoi",
    "lat": "42.55",
    "lng": "141.35"
  },
  {
    "country": "JP",
    "name": "Shimo-furano",
    "lat": "43.35",
    "lng": "142.38333"
  },
  {
    "country": "JP",
    "name": "Shibetsu",
    "lat": "43.65899",
    "lng": "145.13197"
  },
  {
    "country": "JP",
    "name": "Sapporo",
    "lat": "43.06667",
    "lng": "141.35"
  },
  {
    "country": "JP",
    "name": "Rumoi",
    "lat": "43.93444",
    "lng": "141.64278"
  },
  {
    "country": "JP",
    "name": "Otofuke",
    "lat": "42.99167",
    "lng": "143.20028"
  },
  {
    "country": "JP",
    "name": "Otaru",
    "lat": "43.18944",
    "lng": "141.00222"
  },
  {
    "country": "JP",
    "name": "Ōdate",
    "lat": "40.27178",
    "lng": "140.55756"
  },
  {
    "country": "JP",
    "name": "Obihiro",
    "lat": "42.91722",
    "lng": "143.20444"
  },
  {
    "country": "JP",
    "name": "Noshiro",
    "lat": "40.20838",
    "lng": "140.0274"
  },
  {
    "country": "JP",
    "name": "Noboribetsu",
    "lat": "42.45215",
    "lng": "141.17914"
  },
  {
    "country": "JP",
    "name": "Nemuro",
    "lat": "43.32361",
    "lng": "145.575"
  },
  {
    "country": "JP",
    "name": "Nayoro",
    "lat": "44.35056",
    "lng": "142.45778"
  },
  {
    "country": "JP",
    "name": "Honchō",
    "lat": "41.8944",
    "lng": "140.69386"
  },
  {
    "country": "JP",
    "name": "Namioka",
    "lat": "40.71069",
    "lng": "140.59048"
  },
  {
    "country": "JP",
    "name": "Mobetsu",
    "lat": "44.27096",
    "lng": "143.36025"
  },
  {
    "country": "JP",
    "name": "Muroran",
    "lat": "42.31722",
    "lng": "140.98806"
  },
  {
    "country": "JP",
    "name": "Mombetsu",
    "lat": "44.3525",
    "lng": "143.3525"
  },
  {
    "country": "JP",
    "name": "Misawa",
    "lat": "40.68682",
    "lng": "141.38969"
  },
  {
    "country": "JP",
    "name": "Yoichi",
    "lat": "43.20389",
    "lng": "140.77028"
  },
  {
    "country": "JP",
    "name": "Mikasa",
    "lat": "43.25581",
    "lng": "141.88818"
  },
  {
    "country": "JP",
    "name": "Makubetsu",
    "lat": "45.37139",
    "lng": "141.82111"
  },
  {
    "country": "JP",
    "name": "Kushiro",
    "lat": "42.975",
    "lng": "144.37472"
  },
  {
    "country": "JP",
    "name": "Kuroishi",
    "lat": "40.64581",
    "lng": "140.58354"
  },
  {
    "country": "JP",
    "name": "Kuji",
    "lat": "40.18778",
    "lng": "141.76889"
  },
  {
    "country": "JP",
    "name": "Shimokizukuri",
    "lat": "40.81609",
    "lng": "140.37539"
  },
  {
    "country": "JP",
    "name": "Kitami",
    "lat": "43.80306",
    "lng": "143.89083"
  },
  {
    "country": "JP",
    "name": "Kamikawa",
    "lat": "43.84",
    "lng": "142.77111"
  },
  {
    "country": "JP",
    "name": "Kamiiso",
    "lat": "41.82013",
    "lng": "140.64482"
  },
  {
    "country": "JP",
    "name": "Iwanai",
    "lat": "42.97444",
    "lng": "140.50889"
  },
  {
    "country": "JP",
    "name": "Iwamizawa",
    "lat": "43.20028",
    "lng": "141.75972"
  },
  {
    "country": "JP",
    "name": "Ishikari",
    "lat": "43.23972",
    "lng": "141.35389"
  },
  {
    "country": "JP",
    "name": "Ichinohe",
    "lat": "40.21965",
    "lng": "141.28986"
  },
  {
    "country": "JP",
    "name": "Kitahiroshima",
    "lat": "42.97583",
    "lng": "141.56722"
  },
  {
    "country": "JP",
    "name": "Hirosaki",
    "lat": "40.59306",
    "lng": "140.4725"
  },
  {
    "country": "JP",
    "name": "Hanawa",
    "lat": "40.18361",
    "lng": "140.78722"
  },
  {
    "country": "JP",
    "name": "Hakodate",
    "lat": "41.77583",
    "lng": "140.73667"
  },
  {
    "country": "JP",
    "name": "Hachinohe",
    "lat": "40.5",
    "lng": "141.5"
  },
  {
    "country": "JP",
    "name": "Furano",
    "lat": "43.35",
    "lng": "142.38333"
  },
  {
    "country": "JP",
    "name": "Fukagawa",
    "lat": "43.70806",
    "lng": "142.03917"
  },
  {
    "country": "JP",
    "name": "Ebetsu",
    "lat": "43.10806",
    "lng": "141.55056"
  },
  {
    "country": "JP",
    "name": "Date",
    "lat": "42.46806",
    "lng": "140.86806"
  },
  {
    "country": "JP",
    "name": "Chitose",
    "lat": "42.81944",
    "lng": "141.65222"
  },
  {
    "country": "JP",
    "name": "Bibai",
    "lat": "43.32472",
    "lng": "141.85861"
  },
  {
    "country": "JP",
    "name": "Ashibetsu",
    "lat": "43.50972",
    "lng": "142.18556"
  },
  {
    "country": "JP",
    "name": "Asahikawa",
    "lat": "43.77063",
    "lng": "142.36489"
  },
  {
    "country": "JP",
    "name": "Aomori",
    "lat": "40.81667",
    "lng": "140.73333"
  },
  {
    "country": "JP",
    "name": "Akabira",
    "lat": "43.55139",
    "lng": "142.05306"
  },
  {
    "country": "JP",
    "name": "Abashiri",
    "lat": "44.02127",
    "lng": "144.26971"
  },
  {
    "country": "JP",
    "name": "Goshogawara",
    "lat": "40.80444",
    "lng": "140.44139"
  },
  {
    "country": "JP",
    "name": "Aso",
    "lat": "32.93726",
    "lng": "131.08008"
  },
  {
    "country": "JP",
    "name": "Kōya",
    "lat": "34.21294",
    "lng": "135.62244"
  },
  {
    "country": "JP",
    "name": "Kihoku-chō",
    "lat": "33.25592",
    "lng": "132.68343"
  },
  {
    "country": "JP",
    "name": "Nanto-shi",
    "lat": "36.56922",
    "lng": "136.91162"
  },
  {
    "country": "JP",
    "name": "Kawage",
    "lat": "34.80447",
    "lng": "136.54645"
  },
  {
    "country": "JP",
    "name": "Asahi",
    "lat": "35.97259",
    "lng": "136.12455"
  },
  {
    "country": "JP",
    "name": "Neyagawa",
    "lat": "34.76615",
    "lng": "135.62759"
  },
  {
    "country": "JP",
    "name": "Hitachi-Naka",
    "lat": "36.39659",
    "lng": "140.53479"
  },
  {
    "country": "JP",
    "name": "Chikusei",
    "lat": "36.316",
    "lng": "139.98238"
  },
  {
    "country": "JP",
    "name": "Kasumigaura",
    "lat": "36.15326",
    "lng": "140.24635"
  },
  {
    "country": "JP",
    "name": "Tsuchiura",
    "lat": "36.09047",
    "lng": "140.21047"
  },
  {
    "country": "JP",
    "name": "Tsukubamirai",
    "lat": "35.98411",
    "lng": "140.00929"
  },
  {
    "country": "JP",
    "name": "Omitama",
    "lat": "36.25449",
    "lng": "140.37962"
  },
  {
    "country": "JP",
    "name": "Hitachiomiya",
    "lat": "36.56447",
    "lng": "140.40269"
  },
  {
    "country": "JP",
    "name": "Kamisu",
    "lat": "35.89685",
    "lng": "140.66666"
  },
  {
    "country": "JP",
    "name": "Namegata",
    "lat": "36.00705",
    "lng": "140.49623"
  },
  {
    "country": "JP",
    "name": "Sakuragawa",
    "lat": "36.25052",
    "lng": "140.11565"
  },
  {
    "country": "JP",
    "name": "Bandō",
    "lat": "36.06997",
    "lng": "139.86705"
  },
  {
    "country": "JP",
    "name": "Hitachi-ota",
    "lat": "36.5513",
    "lng": "140.52821"
  },
  {
    "country": "JP",
    "name": "Inashiki",
    "lat": "35.95633",
    "lng": "140.32356"
  },
  {
    "country": "JP",
    "name": "Azumino",
    "lat": "36.28815",
    "lng": "137.88705"
  },
  {
    "country": "JP",
    "name": "Chikuma",
    "lat": "36.52715",
    "lng": "138.08943"
  },
  {
    "country": "JP",
    "name": "Murayama",
    "lat": "38.46972",
    "lng": "140.41441"
  },
  {
    "country": "JP",
    "name": "Minamiashigara",
    "lat": "35.31947",
    "lng": "139.1096"
  },
  {
    "country": "JP",
    "name": "Rittō",
    "lat": "35.02745",
    "lng": "135.99971"
  },
  {
    "country": "JP",
    "name": "Takashima",
    "lat": "35.41347",
    "lng": "136.01612"
  },
  {
    "country": "JP",
    "name": "Kōka",
    "lat": "34.9802",
    "lng": "136.15752"
  },
  {
    "country": "JP",
    "name": "Katsuragi",
    "lat": "34.48562",
    "lng": "135.69698"
  },
  {
    "country": "JP",
    "name": "Kashiba",
    "lat": "34.53472",
    "lng": "135.70925"
  },
  {
    "country": "JP",
    "name": "Nanto",
    "lat": "36.51274",
    "lng": "136.89352"
  },
  {
    "country": "JP",
    "name": "Oyabe",
    "lat": "36.66667",
    "lng": "136.85"
  },
  {
    "country": "JP",
    "name": "Imizu",
    "lat": "36.76835",
    "lng": "137.12572"
  },
  {
    "country": "JP",
    "name": "Kurobe-shi",
    "lat": "36.90123",
    "lng": "137.44955"
  },
  {
    "country": "JP",
    "name": "Tama",
    "lat": "35.6436",
    "lng": "139.46844"
  },
  {
    "country": "JP",
    "name": "Musashimurayama",
    "lat": "35.74242",
    "lng": "139.42635"
  },
  {
    "country": "JP",
    "name": "Akishima",
    "lat": "35.72085",
    "lng": "139.37999"
  },
  {
    "country": "JP",
    "name": "Higashiyamato",
    "lat": "35.76298",
    "lng": "139.44575"
  },
  {
    "country": "JP",
    "name": "Misato",
    "lat": "35.84373",
    "lng": "139.88347"
  },
  {
    "country": "JP",
    "name": "Niiza",
    "lat": "35.82088",
    "lng": "139.55791"
  },
  {
    "country": "JP",
    "name": "Tonami",
    "lat": "36.62047",
    "lng": "136.94321"
  },
  {
    "country": "JP",
    "name": "Kahoku",
    "lat": "36.75758",
    "lng": "136.71162"
  },
  {
    "country": "JP",
    "name": "Kaga",
    "lat": "36.3",
    "lng": "136.33333"
  },
  {
    "country": "JP",
    "name": "Suzu",
    "lat": "37.43459",
    "lng": "137.26009"
  },
  {
    "country": "JP",
    "name": "Matsuura",
    "lat": "33.34058",
    "lng": "129.69504"
  },
  {
    "country": "JP",
    "name": "Ōnojō",
    "lat": "33.53567",
    "lng": "130.47861"
  },
  {
    "country": "JP",
    "name": "Kasuga",
    "lat": "33.52594",
    "lng": "130.4611"
  },
  {
    "country": "JP",
    "name": "Aizu-Wakamatsu",
    "lat": "37.49142",
    "lng": "139.94546"
  },
  {
    "country": "JP",
    "name": "Minami-Sōma",
    "lat": "37.62908",
    "lng": "140.97868"
  },
  {
    "country": "JP",
    "name": "Urasoe",
    "lat": "26.25902",
    "lng": "127.73012"
  },
  {
    "country": "JP",
    "name": "Uruma",
    "lat": "26.37609",
    "lng": "127.85908"
  },
  {
    "country": "JP",
    "name": "Jōsō",
    "lat": "36.03553",
    "lng": "139.96143"
  },
  {
    "country": "JP",
    "name": "Midori",
    "lat": "36.44492",
    "lng": "139.28448"
  },
  {
    "country": "JP",
    "name": "Miyakojima",
    "lat": "24.79016",
    "lng": "125.31109"
  },
  {
    "country": "JP",
    "name": "Hidaka",
    "lat": "35.91664",
    "lng": "139.36233"
  },
  {
    "country": "JP",
    "name": "Higashi-Matsuyama",
    "lat": "36.03333",
    "lng": "139.41667"
  },
  {
    "country": "JP",
    "name": "Iruma",
    "lat": "35.818",
    "lng": "139.368"
  },
  {
    "country": "JP",
    "name": "Kitamoto",
    "lat": "36.03322",
    "lng": "139.53775"
  },
  {
    "country": "JP",
    "name": "Tsurugashima",
    "lat": "35.95996",
    "lng": "139.40283"
  },
  {
    "country": "JP",
    "name": "Sōsa",
    "lat": "35.71541",
    "lng": "140.55309"
  },
  {
    "country": "JP",
    "name": "Sanmu",
    "lat": "35.62756",
    "lng": "140.41762"
  },
  {
    "country": "JP",
    "name": "Sōma",
    "lat": "37.79283",
    "lng": "140.92941"
  },
  {
    "country": "JP",
    "name": "Tamura",
    "lat": "37.43055",
    "lng": "140.60335"
  },
  {
    "country": "JP",
    "name": "Kinokawa",
    "lat": "34.26973",
    "lng": "135.41045"
  },
  {
    "country": "JP",
    "name": "Kumano",
    "lat": "33.90389",
    "lng": "136.12214"
  },
  {
    "country": "JP",
    "name": "Inabe",
    "lat": "35.11344",
    "lng": "136.57205"
  },
  {
    "country": "JP",
    "name": "Shimotsuke",
    "lat": "36.41323",
    "lng": "139.86622"
  },
  {
    "country": "JP",
    "name": "Nasukarasuyama",
    "lat": "36.65233",
    "lng": "140.16084"
  },
  {
    "country": "JP",
    "name": "Tōmi",
    "lat": "36.35582",
    "lng": "138.36093"
  },
  {
    "country": "JP",
    "name": "Komagane",
    "lat": "35.71657",
    "lng": "137.93745"
  },
  {
    "country": "JP",
    "name": "Inzai",
    "lat": "35.83479",
    "lng": "140.16361"
  },
  {
    "country": "JP",
    "name": "Isumi",
    "lat": "35.23005",
    "lng": "140.40492"
  },
  {
    "country": "JP",
    "name": "Yachiyo",
    "lat": "35.73531",
    "lng": "140.12445"
  },
  {
    "country": "JP",
    "name": "Tomisato",
    "lat": "35.74483",
    "lng": "140.40386"
  },
  {
    "country": "JP",
    "name": "Ōshū",
    "lat": "39.13927",
    "lng": "141.1685"
  },
  {
    "country": "JP",
    "name": "Hachimantai",
    "lat": "39.89979",
    "lng": "141.12989"
  },
  {
    "country": "JP",
    "name": "Ninohe",
    "lat": "40.29081",
    "lng": "141.31334"
  },
  {
    "country": "JP",
    "name": "Ōsaki",
    "lat": "38.58866",
    "lng": "140.973"
  },
  {
    "country": "JP",
    "name": "Higashimatsushima",
    "lat": "38.40886",
    "lng": "141.17901"
  },
  {
    "country": "JP",
    "name": "Kurihara",
    "lat": "38.75",
    "lng": "141"
  },
  {
    "country": "JP",
    "name": "Izunokuni",
    "lat": "35.03907",
    "lng": "138.95143"
  },
  {
    "country": "JP",
    "name": "Izu",
    "lat": "34.97159",
    "lng": "138.94643"
  },
  {
    "country": "JP",
    "name": "Kikugawa",
    "lat": "34.70291",
    "lng": "138.11978"
  },
  {
    "country": "JP",
    "name": "Kosai",
    "lat": "34.70053",
    "lng": "137.52253"
  },
  {
    "country": "JP",
    "name": "Susono",
    "lat": "35.17388",
    "lng": "138.90691"
  },
  {
    "country": "JP",
    "name": "Omaezaki",
    "lat": "34.59882",
    "lng": "138.21934"
  },
  {
    "country": "JP",
    "name": "Nikaho",
    "lat": "39.27077",
    "lng": "139.93949"
  },
  {
    "country": "JP",
    "name": "Daisen",
    "lat": "39.44116",
    "lng": "140.48961"
  },
  {
    "country": "JP",
    "name": "Oga",
    "lat": "39.871",
    "lng": "139.84926"
  },
  {
    "country": "JP",
    "name": "Yurihonjō",
    "lat": "39.3895",
    "lng": "140.05813"
  },
  {
    "country": "JP",
    "name": "Katagami",
    "lat": "39.87869",
    "lng": "139.99767"
  },
  {
    "country": "JP",
    "name": "Kita-Akita",
    "lat": "40.19956",
    "lng": "140.39388"
  },
  {
    "country": "JP",
    "name": "Tsugaru",
    "lat": "40.80357",
    "lng": "140.40299"
  },
  {
    "country": "JP",
    "name": "Hirakawa",
    "lat": "40.58728",
    "lng": "140.57107"
  },
  {
    "country": "JP",
    "name": "Towada",
    "lat": "40.62049",
    "lng": "141.21067"
  },
  {
    "country": "JP",
    "name": "Kitanagoya",
    "lat": "35.24702",
    "lng": "136.87832"
  },
  {
    "country": "JP",
    "name": "Nisshin",
    "lat": "35.13676",
    "lng": "137.05238"
  },
  {
    "country": "JP",
    "name": "Toyoake",
    "lat": "35.038",
    "lng": "136.99931"
  },
  {
    "country": "JP",
    "name": "Chita",
    "lat": "35.00267",
    "lng": "136.8642"
  },
  {
    "country": "JP",
    "name": "Aisai",
    "lat": "35.16349",
    "lng": "136.73222"
  },
  {
    "country": "JP",
    "name": "Hashima",
    "lat": "35.329",
    "lng": "136.68051"
  },
  {
    "country": "JP",
    "name": "Kaizu",
    "lat": "35.20169",
    "lng": "136.63505"
  },
  {
    "country": "JP",
    "name": "Kani",
    "lat": "35.40435",
    "lng": "137.05595"
  },
  {
    "country": "JP",
    "name": "Minokamo",
    "lat": "35.48199",
    "lng": "137.02166"
  },
  {
    "country": "JP",
    "name": "Motosu",
    "lat": "35.48384",
    "lng": "136.67443"
  },
  {
    "country": "JP",
    "name": "Gujō",
    "lat": "35.73691",
    "lng": "136.95852"
  },
  {
    "country": "JP",
    "name": "Ena",
    "lat": "35.44722",
    "lng": "137.38332"
  },
  {
    "country": "JP",
    "name": "Nanjō",
    "lat": "26.14447",
    "lng": "127.76697"
  },
  {
    "country": "JP",
    "name": "Agano",
    "lat": "37.77392",
    "lng": "139.22192"
  },
  {
    "country": "JP",
    "name": "Jōetsu",
    "lat": "37.14828",
    "lng": "138.23642"
  },
  {
    "country": "JP",
    "name": "Minamiuonuma",
    "lat": "37.08259",
    "lng": "138.87413"
  },
  {
    "country": "JP",
    "name": "Myoko",
    "lat": "37.01497",
    "lng": "138.27324"
  },
  {
    "country": "JP",
    "name": "Sado",
    "lat": "38.02496",
    "lng": "138.35931"
  },
  {
    "country": "JP",
    "name": "Tainai",
    "lat": "38.06646",
    "lng": "139.37436"
  },
  {
    "country": "JP",
    "name": "Uonuma",
    "lat": "37.24488",
    "lng": "138.96234"
  },
  {
    "country": "JP",
    "name": "Fujiidera",
    "lat": "34.5676",
    "lng": "135.5974"
  },
  {
    "country": "JP",
    "name": "Habikino",
    "lat": "34.55276",
    "lng": "135.59097"
  },
  {
    "country": "JP",
    "name": "Hannan",
    "lat": "34.33333",
    "lng": "135.25"
  },
  {
    "country": "JP",
    "name": "Kawachi-Nagano",
    "lat": "34.44108",
    "lng": "135.58283"
  },
  {
    "country": "JP",
    "name": "Sennan",
    "lat": "34.34835",
    "lng": "135.26842"
  },
  {
    "country": "JP",
    "name": "Shijōnawate",
    "lat": "34.73333",
    "lng": "135.68333"
  },
  {
    "country": "JP",
    "name": "Hokuto",
    "lat": "41.81626",
    "lng": "140.63472"
  },
  {
    "country": "JP",
    "name": "Saitama",
    "lat": "35.90807",
    "lng": "139.65657"
  },
  {
    "country": "JP",
    "name": "Niseko Town",
    "lat": "42.77871",
    "lng": "140.66903"
  },
  {
    "country": "JP",
    "name": "Higashimurayama",
    "lat": "35.75459",
    "lng": "139.46852"
  },
  {
    "country": "JP",
    "name": "Fujikawaguchiko",
    "lat": "35.48933",
    "lng": "138.68832"
  },
  {
    "country": "JP",
    "name": "Yawatahama",
    "lat": "33.45737",
    "lng": "132.4328"
  },
  {
    "country": "JP",
    "name": "Kirishima",
    "lat": "31.74087",
    "lng": "130.76288"
  },
  {
    "country": "JP",
    "name": "Amami",
    "lat": "28.3769",
    "lng": "129.49379"
  },
  {
    "country": "JP",
    "name": "Rishiri Town",
    "lat": "45.15928",
    "lng": "141.19629"
  },
  {
    "country": "JP",
    "name": "Arashiyama",
    "lat": "35.01481",
    "lng": "135.67755"
  },
  {
    "country": "JP",
    "name": "Oda",
    "lat": "35.20103",
    "lng": "132.49967"
  },
  {
    "country": "JP",
    "name": "Dazaifu",
    "lat": "33.51278",
    "lng": "130.52389"
  },
  {
    "country": "JP",
    "name": "Amakusa",
    "lat": "32.45861",
    "lng": "130.19306"
  },
  {
    "country": "JP",
    "name": "Kamigyō-ku",
    "lat": "35.02954",
    "lng": "135.75666"
  },
  {
    "country": "JP",
    "name": "Buzen",
    "lat": "33.61153",
    "lng": "131.13002"
  },
  {
    "country": "JP",
    "name": "Yoshitomi",
    "lat": "33.60247",
    "lng": "131.17599"
  },
  {
    "country": "JP",
    "name": "Ikata-chō",
    "lat": "33.48833",
    "lng": "132.35417"
  },
  {
    "country": "JP",
    "name": "Inuotose",
    "lat": "40.60176",
    "lng": "141.32662"
  },
  {
    "country": "JP",
    "name": "Furudate",
    "lat": "40.52934",
    "lng": "141.30553"
  },
  {
    "country": "JP",
    "name": "Hakuba",
    "lat": "36.69818",
    "lng": "137.86185"
  },
  {
    "country": "JP",
    "name": "Nagaoka",
    "lat": "34.93097",
    "lng": "135.69203"
  },
  {
    "country": "JP",
    "name": "Kofu",
    "lat": "35.69763",
    "lng": "138.58819"
  },
  {
    "country": "JP",
    "name": "Fujiyoshida",
    "lat": "35.44032",
    "lng": "138.79586"
  },
  {
    "country": "JP",
    "name": "Tsushima",
    "lat": "34.20634",
    "lng": "129.29076"
  },
  {
    "country": "JP",
    "name": "Kuroishi",
    "lat": "40.61545",
    "lng": "140.70362"
  },
  {
    "country": "JP",
    "name": "Ichikawa-minami",
    "lat": "35.72634",
    "lng": "139.90392"
  },
  {
    "country": "JP",
    "name": "Eniwa",
    "lat": "42.89357",
    "lng": "141.576"
  },
  {
    "country": "JP",
    "name": "Minami-Alps",
    "lat": "35.616",
    "lng": "138.46344"
  },
  {
    "country": "JP",
    "name": "Arao",
    "lat": "32.97888",
    "lng": "130.44572"
  },
  {
    "country": "JP",
    "name": "Ukiha",
    "lat": "33.35634",
    "lng": "130.74966"
  },
  {
    "country": "JP",
    "name": "Iga",
    "lat": "34.75797",
    "lng": "136.13468"
  },
  {
    "country": "JP",
    "name": "Kihoku",
    "lat": "34.21052",
    "lng": "136.33475"
  },
  {
    "country": "JP",
    "name": "Kuwana",
    "lat": "35.05192",
    "lng": "136.66958"
  },
  {
    "country": "JP",
    "name": "Matsusaka",
    "lat": "34.57895",
    "lng": "136.53706"
  },
  {
    "country": "JP",
    "name": "Minamiise",
    "lat": "34.34967",
    "lng": "136.69945"
  },
  {
    "country": "JP",
    "name": "Yonedacho Sendo",
    "lat": "34.7756",
    "lng": "134.82551"
  },
  {
    "country": "JP",
    "name": "Hokuto",
    "lat": "35.83458",
    "lng": "138.39606"
  },
  {
    "country": "JP",
    "name": "Fujimino",
    "lat": "35.86142",
    "lng": "139.51532"
  },
  {
    "country": "JP",
    "name": "Himi",
    "lat": "36.84666",
    "lng": "136.98355"
  },
  {
    "country": "JP",
    "name": "Takizawa",
    "lat": "39.8028",
    "lng": "141.13466"
  },
  {
    "country": "JP",
    "name": "Tōon",
    "lat": "33.79427",
    "lng": "132.89011"
  },
  {
    "country": "JP",
    "name": "Yasu",
    "lat": "35.10053",
    "lng": "136.01778"
  },
  {
    "country": "JP",
    "name": "Yame",
    "lat": "33.22792",
    "lng": "130.64873"
  },
  {
    "country": "JP",
    "name": "Yamatokōriyama",
    "lat": "34.60658",
    "lng": "135.77033"
  },
  {
    "country": "JP",
    "name": "Yamato",
    "lat": "35.47276",
    "lng": "139.45101"
  },
  {
    "country": "JP",
    "name": "Yamanashi",
    "lat": "35.67152",
    "lng": "138.69827"
  },
  {
    "country": "JP",
    "name": "Urayasu",
    "lat": "35.64188",
    "lng": "139.90402"
  },
  {
    "country": "JP",
    "name": "Tosashimizu",
    "lat": "32.78396",
    "lng": "132.96324"
  },
  {
    "country": "JP",
    "name": "Toda",
    "lat": "35.81447",
    "lng": "139.66018"
  },
  {
    "country": "JP",
    "name": "Taku",
    "lat": "33.27709",
    "lng": "130.10928"
  },
  {
    "country": "JP",
    "name": "Taketa",
    "lat": "32.95935",
    "lng": "131.3673"
  },
  {
    "country": "JP",
    "name": "Takeo",
    "lat": "33.19187",
    "lng": "130.01281"
  },
  {
    "country": "JP",
    "name": "Takasago",
    "lat": "34.76298",
    "lng": "134.79229"
  },
  {
    "country": "JP",
    "name": "Tachikawa",
    "lat": "35.7091",
    "lng": "139.41891"
  },
  {
    "country": "JP",
    "name": "Shimonoseki",
    "lat": "34.16736",
    "lng": "131.00012"
  },
  {
    "country": "JP",
    "name": "Saito",
    "lat": "32.08199",
    "lng": "131.39957"
  },
  {
    "country": "JP",
    "name": "Sagamihara",
    "lat": "35.56707",
    "lng": "139.24167"
  },
  {
    "country": "JP",
    "name": "Ogōri",
    "lat": "33.38738",
    "lng": "130.54865"
  },
  {
    "country": "JP",
    "name": "Ogi",
    "lat": "33.28028",
    "lng": "130.19503"
  },
  {
    "country": "JP",
    "name": "Nagakute",
    "lat": "35.17325",
    "lng": "137.05667"
  },
  {
    "country": "JP",
    "name": "Munakata",
    "lat": "33.7957",
    "lng": "130.55895"
  },
  {
    "country": "JP",
    "name": "Mitoyo",
    "lat": "34.21052",
    "lng": "133.6746"
  },
  {
    "country": "JP",
    "name": "Mimasaka",
    "lat": "35.04138",
    "lng": "134.22443"
  },
  {
    "country": "JP",
    "name": "Kunitachi",
    "lat": "35.6833",
    "lng": "139.43848"
  },
  {
    "country": "JP",
    "name": "Miyake",
    "lat": "34.08991",
    "lng": "139.5195"
  },
  {
    "country": "JP",
    "name": "Hachijō",
    "lat": "33.10276",
    "lng": "139.7788"
  },
  {
    "country": "JP",
    "name": "Ōshima",
    "lat": "34.74824",
    "lng": "139.36243"
  },
  {
    "country": "JP",
    "name": "Ogasawara",
    "lat": "27.09688",
    "lng": "142.20377"
  },
  {
    "country": "JP",
    "name": "Kizugawa",
    "lat": "34.73668",
    "lng": "135.83994"
  },
  {
    "country": "JP",
    "name": "Kawanishi",
    "lat": "34.88114",
    "lng": "135.3986"
  },
  {
    "country": "JP",
    "name": "Katano",
    "lat": "34.79329",
    "lng": "135.68596"
  },
  {
    "country": "JP",
    "name": "Hyūga",
    "lat": "32.42272",
    "lng": "131.64093"
  },
  {
    "country": "JP",
    "name": "Sakai",
    "lat": "36.1473",
    "lng": "136.19408"
  },
  {
    "country": "JP",
    "name": "Higashihiroshima",
    "lat": "34.40861",
    "lng": "132.73682"
  },
  {
    "country": "JP",
    "name": "Higashikurume",
    "lat": "35.75202",
    "lng": "139.51169"
  },
  {
    "country": "JP",
    "name": "Hamura",
    "lat": "35.76232",
    "lng": "139.31952"
  },
  {
    "country": "JP",
    "name": "Funabashi",
    "lat": "35.72045",
    "lng": "140.01148"
  },
  {
    "country": "JP",
    "name": "Fuji-yoshida",
    "lat": "35.48486",
    "lng": "138.81123"
  },
  {
    "country": "JP",
    "name": "Fuchū",
    "lat": "35.67452",
    "lng": "139.48216"
  },
  {
    "country": "JP",
    "name": "Fujimi",
    "lat": "35.84815",
    "lng": "139.55521"
  },
  {
    "country": "JP",
    "name": "Chikugo",
    "lat": "33.20537",
    "lng": "130.49183"
  },
  {
    "country": "JP",
    "name": "Sanuki",
    "lat": "34.26686",
    "lng": "134.22958"
  },
  {
    "country": "JP",
    "name": "Ayase",
    "lat": "35.43515",
    "lng": "139.4256"
  },
  {
    "country": "JP",
    "name": "Arida",
    "lat": "34.08089",
    "lng": "135.11905"
  },
  {
    "country": "JP",
    "name": "Aira",
    "lat": "31.77429",
    "lng": "130.59208"
  },
  {
    "country": "JP",
    "name": "Ama",
    "lat": "35.18307",
    "lng": "136.7997"
  },
  {
    "country": "JP",
    "name": "Fukaya",
    "lat": "36.1771",
    "lng": "139.26029"
  },
  {
    "country": "JP",
    "name": "Kodaira",
    "lat": "35.72603",
    "lng": "139.48508"
  },
  {
    "country": "JP",
    "name": "Nishitōkyō",
    "lat": "35.73355",
    "lng": "139.54761"
  },
  {
    "country": "JP",
    "name": "Nanyō",
    "lat": "38.04322",
    "lng": "140.11276"
  },
  {
    "country": "JP",
    "name": "Kakogawa",
    "lat": "34.75064",
    "lng": "134.86954"
  },
  {
    "country": "JP",
    "name": "Kan’onji",
    "lat": "34.06972",
    "lng": "133.64902"
  },
  {
    "country": "JP",
    "name": "Katō",
    "lat": "34.92422",
    "lng": "135.02609"
  },
  {
    "country": "JP",
    "name": "Mine",
    "lat": "34.18681",
    "lng": "131.21624"
  },
  {
    "country": "JP",
    "name": "Hida",
    "lat": "36.24483",
    "lng": "137.17323"
  },
  {
    "country": "JP",
    "name": "Kiyose",
    "lat": "35.77952",
    "lng": "139.53014"
  },
  {
    "country": "JP",
    "name": "Jōyō",
    "lat": "34.84396",
    "lng": "135.80561"
  },
  {
    "country": "JP",
    "name": "Yatomi",
    "lat": "35.1053",
    "lng": "136.73378"
  },
  {
    "country": "JP",
    "name": "Tome",
    "lat": "38.70882",
    "lng": "141.15578"
  },
  {
    "country": "JP",
    "name": "Kamagaya",
    "lat": "35.76971",
    "lng": "140.00238"
  },
  {
    "country": "JP",
    "name": "Ebino",
    "lat": "32.04766",
    "lng": "130.84442"
  },
  {
    "country": "JP",
    "name": "Isa",
    "lat": "32.06716",
    "lng": "130.61182"
  },
  {
    "country": "JP",
    "name": "Ako",
    "lat": "34.75967",
    "lng": "134.37035"
  },
  {
    "country": "JP",
    "name": "Bizen",
    "lat": "34.78674",
    "lng": "134.23542"
  },
  {
    "country": "JP",
    "name": "Higashiōmi",
    "lat": "35.1039",
    "lng": "136.26274"
  },
  {
    "country": "JP",
    "name": "Nakatsu",
    "lat": "33.46238",
    "lng": "131.14174"
  },
  {
    "country": "JP",
    "name": "Usa",
    "lat": "33.43946",
    "lng": "131.33675"
  },
  {
    "country": "JP",
    "name": "Etajima",
    "lat": "34.23863",
    "lng": "132.47967"
  },
  {
    "country": "JP",
    "name": "Shimanto",
    "lat": "33.07831",
    "lng": "132.85234"
  },
  {
    "country": "JP",
    "name": "Tatsuno",
    "lat": "34.83184",
    "lng": "134.54338"
  },
  {
    "country": "JP",
    "name": "Iki",
    "lat": "33.78286",
    "lng": "129.7209"
  },
  {
    "country": "JP",
    "name": "Tosa",
    "lat": "33.50476",
    "lng": "133.44475"
  },
  {
    "country": "JP",
    "name": "Tsuru",
    "lat": "35.54731",
    "lng": "138.90959"
  },
  {
    "country": "JP",
    "name": "Nankoku",
    "lat": "33.56943",
    "lng": "133.64937"
  },
  {
    "country": "JP",
    "name": "Aki-takata",
    "lat": "34.67416",
    "lng": "132.68188"
  },
  {
    "country": "JP",
    "name": "Seiyo",
    "lat": "33.38817",
    "lng": "132.63176"
  },
  {
    "country": "JP",
    "name": "Awa",
    "lat": "34.09205",
    "lng": "134.28452"
  },
  {
    "country": "JP",
    "name": "Yatsushiro",
    "lat": "32.55723",
    "lng": "130.65285"
  },
  {
    "country": "JP",
    "name": "Kai",
    "lat": "35.68463",
    "lng": "138.50979"
  },
  {
    "country": "JP",
    "name": "Sakura",
    "lat": "36.72072",
    "lng": "139.98779"
  },
  {
    "country": "JP",
    "name": "Awaji",
    "lat": "34.47769",
    "lng": "134.93065"
  },
  {
    "country": "JP",
    "name": "Warabi",
    "lat": "35.82188",
    "lng": "139.68545"
  },
  {
    "country": "JP",
    "name": "Miyoshi",
    "lat": "35.08971",
    "lng": "137.08998"
  },
  {
    "country": "JP",
    "name": "Itoshima",
    "lat": "33.54225",
    "lng": "130.18421"
  },
  {
    "country": "JP",
    "name": "Yufu",
    "lat": "33.1956",
    "lng": "131.37829"
  },
  {
    "country": "JP",
    "name": "Akiruno",
    "lat": "35.72854",
    "lng": "139.2318"
  },
  {
    "country": "JP",
    "name": "Shikokuchūō",
    "lat": "33.9754",
    "lng": "133.54895"
  },
  {
    "country": "JP",
    "name": "Ureshino",
    "lat": "33.13525",
    "lng": "130.05718"
  },
  {
    "country": "JP",
    "name": "Narashino",
    "lat": "35.68184",
    "lng": "140.04152"
  },
  {
    "country": "JP",
    "name": "Minamibōsō",
    "lat": "35.03126",
    "lng": "139.92651"
  },
  {
    "country": "JP",
    "name": "Ōamishirasato",
    "lat": "35.51183",
    "lng": "140.35257"
  },
  {
    "country": "JP",
    "name": "Sodegaura",
    "lat": "35.41368",
    "lng": "140.02135"
  },
  {
    "country": "JP",
    "name": "Echizen",
    "lat": "35.88571",
    "lng": "136.17073"
  },
  {
    "country": "JP",
    "name": "Kama",
    "lat": "33.53488",
    "lng": "130.74228"
  },
  {
    "country": "JP",
    "name": "Miyama",
    "lat": "33.12102",
    "lng": "130.50007"
  },
  {
    "country": "JP",
    "name": "Miyawaka",
    "lat": "33.71706",
    "lng": "130.64117"
  },
  {
    "country": "JP",
    "name": "Shirakawa",
    "lat": "37.11954",
    "lng": "140.26211"
  },
  {
    "country": "JP",
    "name": "Mizuho",
    "lat": "35.3943",
    "lng": "136.66898"
  },
  {
    "country": "JP",
    "name": "Motosu",
    "lat": "35.65534",
    "lng": "136.61018"
  },
  {
    "country": "JP",
    "name": "Yamagata",
    "lat": "35.58306",
    "lng": "136.7585"
  },
  {
    "country": "JP",
    "name": "Shibetsu",
    "lat": "44.17137",
    "lng": "142.39517"
  },
  {
    "country": "JP",
    "name": "Asago",
    "lat": "35.25908",
    "lng": "134.81392"
  },
  {
    "country": "JP",
    "name": "Kasai",
    "lat": "34.92633",
    "lng": "134.84533"
  },
  {
    "country": "JP",
    "name": "Minamiawaji",
    "lat": "34.27396",
    "lng": "134.77512"
  },
  {
    "country": "JP",
    "name": "Sanda",
    "lat": "34.94716",
    "lng": "135.21389"
  },
  {
    "country": "JP",
    "name": "Shisō",
    "lat": "34.98107",
    "lng": "134.56398"
  },
  {
    "country": "JP",
    "name": "Tanba",
    "lat": "35.16034",
    "lng": "135.03914"
  },
  {
    "country": "JP",
    "name": "Nomi",
    "lat": "36.42902",
    "lng": "136.54564"
  },
  {
    "country": "JP",
    "name": "Tōkai",
    "lat": "35.02269",
    "lng": "136.90887"
  },
  {
    "country": "JP",
    "name": "Higashikagawa",
    "lat": "34.21024",
    "lng": "134.33653"
  },
  {
    "country": "JP",
    "name": "Minamikyushu",
    "lat": "31.34689",
    "lng": "130.45612"
  },
  {
    "country": "JP",
    "name": "Minamisatsuma",
    "lat": "31.38999",
    "lng": "130.28343"
  },
  {
    "country": "JP",
    "name": "Soo",
    "lat": "31.64637",
    "lng": "130.99068"
  },
  {
    "country": "JP",
    "name": "Ebina",
    "lat": "35.43417",
    "lng": "139.39419"
  },
  {
    "country": "JP",
    "name": "Kami",
    "lat": "33.68407",
    "lng": "133.84369"
  },
  {
    "country": "JP",
    "name": "Kōnan",
    "lat": "33.58345",
    "lng": "133.78189"
  },
  {
    "country": "JP",
    "name": "Muroto",
    "lat": "33.33282",
    "lng": "134.14169"
  },
  {
    "country": "JP",
    "name": "Kōshi",
    "lat": "32.89271",
    "lng": "130.77567"
  },
  {
    "country": "JP",
    "name": "Uki",
    "lat": "32.62217",
    "lng": "130.66177"
  },
  {
    "country": "JP",
    "name": "Kyōtanabe",
    "lat": "34.8045",
    "lng": "135.76681"
  },
  {
    "country": "JP",
    "name": "Kyōtango",
    "lat": "35.60623",
    "lng": "135.04429"
  },
  {
    "country": "JP",
    "name": "Nantan",
    "lat": "35.1098",
    "lng": "135.49164"
  },
  {
    "country": "JP",
    "name": "Gotō",
    "lat": "32.68418",
    "lng": "128.8068"
  },
  {
    "country": "JP",
    "name": "Minamishimabara",
    "lat": "32.67334",
    "lng": "130.26747"
  },
  {
    "country": "JP",
    "name": "Saikai",
    "lat": "32.9839",
    "lng": "129.6809"
  },
  {
    "country": "JP",
    "name": "Unzen",
    "lat": "32.77111",
    "lng": "130.24841"
  },
  {
    "country": "JP",
    "name": "Bungo-ōno",
    "lat": "32.97152",
    "lng": "131.52832"
  },
  {
    "country": "JP",
    "name": "Akaiwa",
    "lat": "34.80986",
    "lng": "134.02153"
  },
  {
    "country": "JP",
    "name": "Maniwa",
    "lat": "35.10643",
    "lng": "133.72009"
  },
  {
    "country": "JP",
    "name": "Setouchi",
    "lat": "34.65919",
    "lng": "134.14238"
  },
  {
    "country": "JP",
    "name": "Izumisano",
    "lat": "34.379",
    "lng": "135.31981"
  },
  {
    "country": "JP",
    "name": "Ōsaka-sayama",
    "lat": "34.49524",
    "lng": "135.55069"
  },
  {
    "country": "JP",
    "name": "Imari",
    "lat": "33.29036",
    "lng": "129.88998"
  },
  {
    "country": "JP",
    "name": "Kanzaki",
    "lat": "33.32393",
    "lng": "130.34051"
  },
  {
    "country": "JP",
    "name": "Konan",
    "lat": "34.99921",
    "lng": "136.09674"
  },
  {
    "country": "JP",
    "name": "Yasugi",
    "lat": "35.33613",
    "lng": "133.18382"
  },
  {
    "country": "JP",
    "name": "Nasushiobara",
    "lat": "36.97952",
    "lng": "139.99466"
  },
  {
    "country": "JP",
    "name": "Mima",
    "lat": "34.05493",
    "lng": "134.13963"
  },
  {
    "country": "JP",
    "name": "Miyoshi",
    "lat": "33.92541",
    "lng": "133.85674"
  },
  {
    "country": "JP",
    "name": "Yoshinogawa",
    "lat": "34.03858",
    "lng": "134.29207"
  },
  {
    "country": "JP",
    "name": "Inagi",
    "lat": "35.63295",
    "lng": "139.49967"
  },
  {
    "country": "JP",
    "name": "Koganei",
    "lat": "35.70014",
    "lng": "139.51109"
  },
  {
    "country": "JP",
    "name": "Komae",
    "lat": "35.63424",
    "lng": "139.57546"
  },
  {
    "country": "JP",
    "name": "Sanyōonoda",
    "lat": "34.03246",
    "lng": "131.16028"
  },
  {
    "country": "JP",
    "name": "Shūnan",
    "lat": "34.08053",
    "lng": "131.82564"
  },
  {
    "country": "JP",
    "name": "Chūō",
    "lat": "35.59465",
    "lng": "138.50275"
  },
  {
    "country": "JP",
    "name": "Fuefuki",
    "lat": "35.63526",
    "lng": "138.63853"
  },
  {
    "country": "JP",
    "name": "Kōshū",
    "lat": "35.72422",
    "lng": "138.77106"
  },
  {
    "country": "JP",
    "name": "Higashiyamato",
    "lat": "35.75052",
    "lng": "139.42959"
  },
  {
    "country": "JP",
    "name": "Kazuno",
    "lat": "40.20825",
    "lng": "140.78327"
  },
  {
    "country": "JP",
    "name": "Unnan",
    "lat": "35.2431",
    "lng": "132.89989"
  },
  {
    "country": "JP",
    "name": "Kunisaki",
    "lat": "33.5547",
    "lng": "131.72796"
  },
  {
    "country": "JP",
    "name": "Ichikikushikino",
    "lat": "31.72934",
    "lng": "130.29305"
  },
  {
    "country": "JP",
    "name": "Asakuchi",
    "lat": "34.53484",
    "lng": "133.60302"
  },
  {
    "country": "JP",
    "name": "Fukutsu",
    "lat": "33.783",
    "lng": "130.49114"
  },
  {
    "country": "JP",
    "name": "Asakura",
    "lat": "33.41439",
    "lng": "130.71877"
  },
  {
    "country": "JP",
    "name": "Kamiamakusa",
    "lat": "32.4892",
    "lng": "130.39433"
  },
  {
    "country": "JP",
    "name": "Rikuzentakata",
    "lat": "39.03759",
    "lng": "141.60004"
  },
  {
    "country": "JP",
    "name": "Hakusan",
    "lat": "36.48204",
    "lng": "136.58684"
  },
  {
    "country": "JP",
    "name": "Semboku",
    "lat": "39.7093",
    "lng": "140.74654"
  },
  {
    "country": "JP",
    "name": "Tajiri",
    "lat": "34.42695",
    "lng": "135.24552"
  },
  {
    "country": "JP",
    "name": "Mitaka",
    "lat": "35.68361",
    "lng": "139.56002"
  },
  {
    "country": "JP",
    "name": "Kasado",
    "lat": "34.89141",
    "lng": "136.53049"
  },
  {
    "country": "KE",
    "name": "Yala",
    "lat": "0.09438",
    "lng": "34.53602"
  },
  {
    "country": "KE",
    "name": "Wundanyi",
    "lat": "-3.39642",
    "lng": "38.35729"
  },
  {
    "country": "KE",
    "name": "Wote",
    "lat": "-1.78079",
    "lng": "37.62882"
  },
  {
    "country": "KE",
    "name": "Witu",
    "lat": "-2.38892",
    "lng": "40.43827"
  },
  {
    "country": "KE",
    "name": "Webuye",
    "lat": "0.6004",
    "lng": "34.77119"
  },
  {
    "country": "KE",
    "name": "Wajir",
    "lat": "1.7471",
    "lng": "40.05732"
  },
  {
    "country": "KE",
    "name": "Voi",
    "lat": "-3.39605",
    "lng": "38.55609"
  },
  {
    "country": "KE",
    "name": "Thika",
    "lat": "-1.03326",
    "lng": "37.06933"
  },
  {
    "country": "KE",
    "name": "Taveta",
    "lat": "-3.39879",
    "lng": "37.68336"
  },
  {
    "country": "KE",
    "name": "Takaungu",
    "lat": "-3.6835",
    "lng": "39.85687"
  },
  {
    "country": "KE",
    "name": "Sotik",
    "lat": "-0.68333",
    "lng": "35.11871"
  },
  {
    "country": "KE",
    "name": "Shimoni",
    "lat": "-4.64756",
    "lng": "39.38175"
  },
  {
    "country": "KE",
    "name": "Sawa Sawa",
    "lat": "-4.47166",
    "lng": "39.48463"
  },
  {
    "country": "KE",
    "name": "Sagana",
    "lat": "-0.66806",
    "lng": "37.20875"
  },
  {
    "country": "KE",
    "name": "Rumuruti",
    "lat": "0.2725",
    "lng": "36.53806"
  },
  {
    "country": "KE",
    "name": "Rongai",
    "lat": "-0.17333",
    "lng": "35.86382"
  },
  {
    "country": "KE",
    "name": "Pumwani",
    "lat": "-1.28333",
    "lng": "36.85"
  },
  {
    "country": "KE",
    "name": "Oyugis",
    "lat": "-0.50898",
    "lng": "34.73583"
  },
  {
    "country": "KE",
    "name": "Othaya",
    "lat": "-0.54655",
    "lng": "36.93178"
  },
  {
    "country": "KE",
    "name": "Ogembo",
    "lat": "-0.79839",
    "lng": "34.72531"
  },
  {
    "country": "KE",
    "name": "Nyeri",
    "lat": "-0.42013",
    "lng": "36.94759"
  },
  {
    "country": "KE",
    "name": "Nyamira",
    "lat": "-0.56333",
    "lng": "34.93583"
  },
  {
    "country": "KE",
    "name": "Nyahururu",
    "lat": "0.03813",
    "lng": "36.36339"
  },
  {
    "country": "KE",
    "name": "Ngong",
    "lat": "-1.3527",
    "lng": "36.6699"
  },
  {
    "country": "KE",
    "name": "Naro Moru",
    "lat": "-0.16357",
    "lng": "37.01773"
  },
  {
    "country": "KE",
    "name": "Narok",
    "lat": "-1.08083",
    "lng": "35.87111"
  },
  {
    "country": "KE",
    "name": "Nanyuki",
    "lat": "0.00624",
    "lng": "37.07398"
  },
  {
    "country": "KE",
    "name": "Nandi Hills",
    "lat": "0.10366",
    "lng": "35.18426"
  },
  {
    "country": "KE",
    "name": "Nambare",
    "lat": "0.45813",
    "lng": "34.25353"
  },
  {
    "country": "KE",
    "name": "Nakuru",
    "lat": "-0.30719",
    "lng": "36.07225"
  },
  {
    "country": "KE",
    "name": "Naivasha",
    "lat": "-0.71383",
    "lng": "36.43261"
  },
  {
    "country": "KE",
    "name": "Nairobi",
    "lat": "-1.28333",
    "lng": "36.81667"
  },
  {
    "country": "KE",
    "name": "Mwingi",
    "lat": "-0.93435",
    "lng": "38.06005"
  },
  {
    "country": "KE",
    "name": "Mwatate",
    "lat": "-3.505",
    "lng": "38.37722"
  },
  {
    "country": "KE",
    "name": "Murang’a",
    "lat": "-0.72104",
    "lng": "37.15259"
  },
  {
    "country": "KE",
    "name": "Mumias",
    "lat": "0.33474",
    "lng": "34.48796"
  },
  {
    "country": "KE",
    "name": "Muhoroni",
    "lat": "-0.15406",
    "lng": "35.19878"
  },
  {
    "country": "KE",
    "name": "Mtito Andei",
    "lat": "-2.68987",
    "lng": "38.16687"
  },
  {
    "country": "KE",
    "name": "Moyale",
    "lat": "3.5216",
    "lng": "39.05472"
  },
  {
    "country": "KE",
    "name": "Mombasa",
    "lat": "-4.05466",
    "lng": "39.66359"
  },
  {
    "country": "KE",
    "name": "Molo",
    "lat": "-0.2479",
    "lng": "35.73743"
  },
  {
    "country": "KE",
    "name": "Migori",
    "lat": "-1.06343",
    "lng": "34.47313"
  },
  {
    "country": "KE",
    "name": "Meru",
    "lat": "0.04626",
    "lng": "37.65587"
  },
  {
    "country": "KE",
    "name": "Mbale",
    "lat": "0.08213",
    "lng": "34.72139"
  },
  {
    "country": "KE",
    "name": "Maua",
    "lat": "0.2332",
    "lng": "37.94086"
  },
  {
    "country": "KE",
    "name": "Marsabit",
    "lat": "2.33468",
    "lng": "37.99086"
  },
  {
    "country": "KE",
    "name": "Mariakani",
    "lat": "-3.86261",
    "lng": "39.47458"
  },
  {
    "country": "KE",
    "name": "Maralal",
    "lat": "1.09667",
    "lng": "36.69806"
  },
  {
    "country": "KE",
    "name": "Maragua",
    "lat": "-0.79602",
    "lng": "37.13292"
  },
  {
    "country": "KE",
    "name": "Mandera",
    "lat": "3.93726",
    "lng": "41.85688"
  },
  {
    "country": "KE",
    "name": "Malindi",
    "lat": "-3.21799",
    "lng": "40.11692"
  },
  {
    "country": "KE",
    "name": "Malikisi",
    "lat": "0.67694",
    "lng": "34.42167"
  },
  {
    "country": "KE",
    "name": "Malaba",
    "lat": "0.63513",
    "lng": "34.28165"
  },
  {
    "country": "KE",
    "name": "Makueni Boma",
    "lat": "-1.80388",
    "lng": "37.62405"
  },
  {
    "country": "KE",
    "name": "Magadi",
    "lat": "-1.90122",
    "lng": "36.287"
  },
  {
    "country": "KE",
    "name": "Machakos",
    "lat": "-1.52233",
    "lng": "37.26521"
  },
  {
    "country": "KE",
    "name": "Kipkelion",
    "lat": "-0.19675",
    "lng": "35.46847"
  },
  {
    "country": "KE",
    "name": "Lugulu",
    "lat": "0.39337",
    "lng": "34.30399"
  },
  {
    "country": "KE",
    "name": "Luanda",
    "lat": "0.31354",
    "lng": "34.07146"
  },
  {
    "country": "KE",
    "name": "Londiani",
    "lat": "-0.16496",
    "lng": "35.59087"
  },
  {
    "country": "KE",
    "name": "Lodwar",
    "lat": "3.11988",
    "lng": "35.59642"
  },
  {
    "country": "KE",
    "name": "Litein",
    "lat": "-0.58226",
    "lng": "35.19029"
  },
  {
    "country": "KE",
    "name": "Limuru",
    "lat": "-1.1136",
    "lng": "36.64205"
  },
  {
    "country": "KE",
    "name": "Lamu",
    "lat": "-2.27169",
    "lng": "40.90201"
  },
  {
    "country": "KE",
    "name": "Kwale",
    "lat": "-4.17375",
    "lng": "39.45206"
  },
  {
    "country": "KE",
    "name": "Konza",
    "lat": "-1.73947",
    "lng": "37.13195"
  },
  {
    "country": "KE",
    "name": "Kitui",
    "lat": "-1.36696",
    "lng": "38.01055"
  },
  {
    "country": "KE",
    "name": "Kitale",
    "lat": "1.01572",
    "lng": "35.00622"
  },
  {
    "country": "KE",
    "name": "Kisumu",
    "lat": "-0.10221",
    "lng": "34.76171"
  },
  {
    "country": "KE",
    "name": "Kisii",
    "lat": "-0.68174",
    "lng": "34.76666"
  },
  {
    "country": "KE",
    "name": "Kipini",
    "lat": "-2.52565",
    "lng": "40.5262"
  },
  {
    "country": "KE",
    "name": "Kinango",
    "lat": "-4.13723",
    "lng": "39.31528"
  },
  {
    "country": "KE",
    "name": "Kihancha",
    "lat": "-1.18376",
    "lng": "34.62616"
  },
  {
    "country": "KE",
    "name": "Kilifi",
    "lat": "-3.63045",
    "lng": "39.84992"
  },
  {
    "country": "KE",
    "name": "Kikuyu",
    "lat": "-1.24627",
    "lng": "36.66291"
  },
  {
    "country": "KE",
    "name": "Kijabe",
    "lat": "-0.93334",
    "lng": "36.57233"
  },
  {
    "country": "KE",
    "name": "Kiambu",
    "lat": "-1.17139",
    "lng": "36.83556"
  },
  {
    "country": "KE",
    "name": "Kerugoya",
    "lat": "-0.49887",
    "lng": "37.28031"
  },
  {
    "country": "KE",
    "name": "Keroka",
    "lat": "-0.77584",
    "lng": "34.94531"
  },
  {
    "country": "KE",
    "name": "Kericho",
    "lat": "-0.36774",
    "lng": "35.28314"
  },
  {
    "country": "KE",
    "name": "Karuri",
    "lat": "-0.7",
    "lng": "37.18333"
  },
  {
    "country": "KE",
    "name": "Kapsowar",
    "lat": "0.9789",
    "lng": "35.55854"
  },
  {
    "country": "KE",
    "name": "Kapsabet",
    "lat": "0.20387",
    "lng": "35.105"
  },
  {
    "country": "KE",
    "name": "Kapenguria",
    "lat": "1.23889",
    "lng": "35.11194"
  },
  {
    "country": "KE",
    "name": "Kangundo",
    "lat": "-1.30342",
    "lng": "37.34813"
  },
  {
    "country": "KE",
    "name": "Kangema",
    "lat": "-0.68553",
    "lng": "36.96463"
  },
  {
    "country": "KE",
    "name": "Kakamega",
    "lat": "0.28422",
    "lng": "34.75229"
  },
  {
    "country": "KE",
    "name": "Kajiado",
    "lat": "-1.85238",
    "lng": "36.77683"
  },
  {
    "country": "KE",
    "name": "Kabarnet",
    "lat": "0.49194",
    "lng": "35.74303"
  },
  {
    "country": "KE",
    "name": "Iten",
    "lat": "0.67028",
    "lng": "35.50806"
  },
  {
    "country": "KE",
    "name": "Isiolo",
    "lat": "0.35462",
    "lng": "37.58218"
  },
  {
    "country": "KE",
    "name": "Homa Bay",
    "lat": "-0.52731",
    "lng": "34.45714"
  },
  {
    "country": "KE",
    "name": "Hola",
    "lat": "-1.48256",
    "lng": "40.03341"
  },
  {
    "country": "KE",
    "name": "Gazi",
    "lat": "-4.42402",
    "lng": "39.50588"
  },
  {
    "country": "KE",
    "name": "Garissa",
    "lat": "-0.45275",
    "lng": "39.64601"
  },
  {
    "country": "KE",
    "name": "Embu",
    "lat": "-0.53987",
    "lng": "37.45743"
  },
  {
    "country": "KE",
    "name": "Eldoret",
    "lat": "0.52036",
    "lng": "35.26993"
  },
  {
    "country": "KE",
    "name": "Eldama Ravine",
    "lat": "0.05196",
    "lng": "35.72734"
  },
  {
    "country": "KE",
    "name": "Chuka",
    "lat": "-0.33316",
    "lng": "37.64587"
  },
  {
    "country": "KE",
    "name": "Chepareria",
    "lat": "1.30583",
    "lng": "35.20365"
  },
  {
    "country": "KE",
    "name": "Butere",
    "lat": "0.20694",
    "lng": "34.49006"
  },
  {
    "country": "KE",
    "name": "Busia",
    "lat": "0.46005",
    "lng": "34.11169"
  },
  {
    "country": "KE",
    "name": "Port Victoria",
    "lat": "0.09809",
    "lng": "33.97248"
  },
  {
    "country": "KE",
    "name": "Bungoma",
    "lat": "0.5635",
    "lng": "34.56055"
  },
  {
    "country": "KE",
    "name": "Bondo",
    "lat": "0.23522",
    "lng": "34.28086"
  },
  {
    "country": "KE",
    "name": "Bomet",
    "lat": "-0.78129",
    "lng": "35.34156"
  },
  {
    "country": "KE",
    "name": "Baringo",
    "lat": "0.46667",
    "lng": "35.96667"
  },
  {
    "country": "KE",
    "name": "Athi River",
    "lat": "-1.4563",
    "lng": "36.97826"
  },
  {
    "country": "KE",
    "name": "Ahero",
    "lat": "-0.17462",
    "lng": "34.9163"
  },
  {
    "country": "KE",
    "name": "Siaya",
    "lat": "0.0607",
    "lng": "34.28806"
  },
  {
    "country": "KE",
    "name": "Ol Kalou",
    "lat": "-0.27088",
    "lng": "36.37917"
  },
  {
    "country": "KE",
    "name": "Bungoma",
    "lat": "0.58333",
    "lng": "34.58333"
  },
  {
    "country": "KE",
    "name": "Kathwana",
    "lat": "-0.33139",
    "lng": "37.86861"
  },
  {
    "country": "KG",
    "name": "Tayan",
    "lat": "39.9026",
    "lng": "71.10826"
  },
  {
    "country": "KG",
    "name": "Suluktu",
    "lat": "39.93652",
    "lng": "69.56779"
  },
  {
    "country": "KG",
    "name": "Kyzyl-Eshme",
    "lat": "39.56559",
    "lng": "72.27153"
  },
  {
    "country": "KG",
    "name": "Korgon",
    "lat": "39.88899",
    "lng": "69.93559"
  },
  {
    "country": "KG",
    "name": "Aydarken",
    "lat": "39.94319",
    "lng": "71.34184"
  },
  {
    "country": "KG",
    "name": "Katran",
    "lat": "39.84434",
    "lng": "70.01474"
  },
  {
    "country": "KG",
    "name": "Isfana",
    "lat": "39.83895",
    "lng": "69.5276"
  },
  {
    "country": "KG",
    "name": "Daroot-Korgon",
    "lat": "39.55274",
    "lng": "72.20518"
  },
  {
    "country": "KG",
    "name": "Andarak",
    "lat": "39.76849",
    "lng": "69.46398"
  },
  {
    "country": "KG",
    "name": "Balykchy",
    "lat": "42.46017",
    "lng": "76.18709"
  },
  {
    "country": "KG",
    "name": "Uch-Korgon",
    "lat": "40.22881",
    "lng": "72.05924"
  },
  {
    "country": "KG",
    "name": "Tyup",
    "lat": "42.7276",
    "lng": "78.36476"
  },
  {
    "country": "KG",
    "name": "Tokmok",
    "lat": "42.84194",
    "lng": "75.30149"
  },
  {
    "country": "KG",
    "name": "Ak-Suu",
    "lat": "42.49948",
    "lng": "78.52702"
  },
  {
    "country": "KG",
    "name": "Tash-Kumyr",
    "lat": "41.34612",
    "lng": "72.21707"
  },
  {
    "country": "KG",
    "name": "Talas",
    "lat": "42.52277",
    "lng": "72.24274"
  },
  {
    "country": "KG",
    "name": "Suzak",
    "lat": "40.8982",
    "lng": "72.90481"
  },
  {
    "country": "KG",
    "name": "Chuy",
    "lat": "42.81973",
    "lng": "75.28233"
  },
  {
    "country": "KG",
    "name": "Sosnovka",
    "lat": "42.63707",
    "lng": "73.89608"
  },
  {
    "country": "KG",
    "name": "Sokuluk",
    "lat": "42.85401",
    "lng": "74.30257"
  },
  {
    "country": "KG",
    "name": "Pokrovka",
    "lat": "42.7362",
    "lng": "71.60982"
  },
  {
    "country": "KG",
    "name": "Kyzyl-Suu",
    "lat": "42.34211",
    "lng": "78.00644"
  },
  {
    "country": "KG",
    "name": "Uzgen",
    "lat": "40.76994",
    "lng": "73.30068"
  },
  {
    "country": "KG",
    "name": "Osh",
    "lat": "40.52828",
    "lng": "72.7985"
  },
  {
    "country": "KG",
    "name": "Orozbekovo",
    "lat": "40.05689",
    "lng": "71.66945"
  },
  {
    "country": "KG",
    "name": "Naryn",
    "lat": "41.42866",
    "lng": "75.99111"
  },
  {
    "country": "KG",
    "name": "Bakai-Ata",
    "lat": "42.49298",
    "lng": "71.9236"
  },
  {
    "country": "KG",
    "name": "Massy",
    "lat": "41.0601",
    "lng": "72.63285"
  },
  {
    "country": "KG",
    "name": "Lebedinovka",
    "lat": "42.88454",
    "lng": "74.67819"
  },
  {
    "country": "KG",
    "name": "Kyzyl-Kyya",
    "lat": "40.25684",
    "lng": "72.12793"
  },
  {
    "country": "KG",
    "name": "Kochkor",
    "lat": "42.21552",
    "lng": "75.75659"
  },
  {
    "country": "KG",
    "name": "Kochkor-Ata",
    "lat": "41.03709",
    "lng": "72.4832"
  },
  {
    "country": "KG",
    "name": "Kyzyl-Adyr",
    "lat": "42.61981",
    "lng": "71.5891"
  },
  {
    "country": "KG",
    "name": "Khalmion",
    "lat": "40.21218",
    "lng": "71.63274"
  },
  {
    "country": "KG",
    "name": "Kazarman",
    "lat": "41.40452",
    "lng": "74.02828"
  },
  {
    "country": "KG",
    "name": "Kerben",
    "lat": "41.49399",
    "lng": "71.75826"
  },
  {
    "country": "KG",
    "name": "Karavan",
    "lat": "40.29513",
    "lng": "72.18627"
  },
  {
    "country": "KG",
    "name": "Kara Suu",
    "lat": "40.7046",
    "lng": "72.86666"
  },
  {
    "country": "KG",
    "name": "Karakol",
    "lat": "42.49068",
    "lng": "78.39362"
  },
  {
    "country": "KG",
    "name": "Kara-Dzhygach",
    "lat": "40.12209",
    "lng": "72.09271"
  },
  {
    "country": "KG",
    "name": "Kara-Balta",
    "lat": "42.81423",
    "lng": "73.84813"
  },
  {
    "country": "KG",
    "name": "Kanysh-Kyya",
    "lat": "41.76536",
    "lng": "71.09181"
  },
  {
    "country": "KG",
    "name": "Kant",
    "lat": "42.89106",
    "lng": "74.85077"
  },
  {
    "country": "KG",
    "name": "Kaindy",
    "lat": "42.82469",
    "lng": "73.67585"
  },
  {
    "country": "KG",
    "name": "Kadzhi-Say",
    "lat": "42.14107",
    "lng": "77.17848"
  },
  {
    "country": "KG",
    "name": "Jalal-Abad",
    "lat": "40.93333",
    "lng": "73"
  },
  {
    "country": "KG",
    "name": "Ivanovka",
    "lat": "42.88778",
    "lng": "75.085"
  },
  {
    "country": "KG",
    "name": "Ivanovo-Alekseyevka",
    "lat": "42.54689",
    "lng": "72.20921"
  },
  {
    "country": "KG",
    "name": "Iradan",
    "lat": "40.26667",
    "lng": "72.1"
  },
  {
    "country": "KG",
    "name": "Gul’cha",
    "lat": "40.3138",
    "lng": "73.44418"
  },
  {
    "country": "KG",
    "name": "Nookat",
    "lat": "40.26597",
    "lng": "72.61834"
  },
  {
    "country": "KG",
    "name": "Cholpon-Ata",
    "lat": "42.64944",
    "lng": "77.08225"
  },
  {
    "country": "KG",
    "name": "Chayek",
    "lat": "41.92768",
    "lng": "74.51699"
  },
  {
    "country": "KG",
    "name": "Kemin",
    "lat": "42.78611",
    "lng": "75.69167"
  },
  {
    "country": "KG",
    "name": "Bokombayevskoye",
    "lat": "42.11769",
    "lng": "76.99332"
  },
  {
    "country": "KG",
    "name": "Bishkek",
    "lat": "42.87",
    "lng": "74.59"
  },
  {
    "country": "KG",
    "name": "Belovodskoye",
    "lat": "42.82944",
    "lng": "74.1083"
  },
  {
    "country": "KG",
    "name": "Bazar-Korgon",
    "lat": "41.0376",
    "lng": "72.74586"
  },
  {
    "country": "KG",
    "name": "Batken",
    "lat": "40.06259",
    "lng": "70.81939"
  },
  {
    "country": "KG",
    "name": "Baetovo",
    "lat": "41.26668",
    "lng": "74.95698"
  },
  {
    "country": "KG",
    "name": "At-Bashi",
    "lat": "41.16951",
    "lng": "75.80099"
  },
  {
    "country": "KG",
    "name": "Aravan",
    "lat": "40.51608",
    "lng": "72.4996"
  },
  {
    "country": "KG",
    "name": "Alga",
    "lat": "40.2363",
    "lng": "71.49899"
  },
  {
    "country": "KG",
    "name": "Ala-Buka",
    "lat": "41.4105",
    "lng": "71.48628"
  },
  {
    "country": "KG",
    "name": "Beshkent",
    "lat": "40.03083",
    "lng": "69.81861"
  },
  {
    "country": "KG",
    "name": "Toktogul",
    "lat": "41.87442",
    "lng": "72.94192"
  },
  {
    "country": "KG",
    "name": "Pulgon",
    "lat": "40.14724",
    "lng": "71.72962"
  },
  {
    "country": "KG",
    "name": "Talas",
    "lat": "42.35473",
    "lng": "72.65678"
  },
  {
    "country": "KG",
    "name": "Üch-Terek",
    "lat": "41.76222",
    "lng": "73.20033"
  },
  {
    "country": "KG",
    "name": "Kara-Dëbë",
    "lat": "40.24428",
    "lng": "72.04475"
  },
  {
    "country": "KG",
    "name": "Kara-Kulja",
    "lat": "40.63223",
    "lng": "73.59249"
  },
  {
    "country": "KG",
    "name": "Chek",
    "lat": "40.10934",
    "lng": "70.84636"
  },
  {
    "country": "KG",
    "name": "Kara-Bak",
    "lat": "40.16169",
    "lng": "70.81959"
  },
  {
    "country": "KG",
    "name": "Samarkandyk",
    "lat": "39.9981",
    "lng": "70.54589"
  },
  {
    "country": "KG",
    "name": "Kyrgyz-Kyshtak",
    "lat": "40.31055",
    "lng": "71.34966"
  },
  {
    "country": "KG",
    "name": "Kyzyl-Bulak",
    "lat": "40.0517",
    "lng": "71.73726"
  },
  {
    "country": "KG",
    "name": "Boz-Adyr",
    "lat": "39.9986",
    "lng": "71.07338"
  },
  {
    "country": "KG",
    "name": "Markaz",
    "lat": "40.24019",
    "lng": "71.89983"
  },
  {
    "country": "KG",
    "name": "Kulundu",
    "lat": "40.10635",
    "lng": "69.64127"
  },
  {
    "country": "KG",
    "name": "Ak-Suu",
    "lat": "39.89877",
    "lng": "69.3716"
  },
  {
    "country": "KG",
    "name": "Toguz-Bulak",
    "lat": "39.84331",
    "lng": "69.71355"
  },
  {
    "country": "KG",
    "name": "Ak-Tatyr",
    "lat": "39.9599",
    "lng": "70.48451"
  },
  {
    "country": "KG",
    "name": "Ormosh",
    "lat": "39.94591",
    "lng": "71.26086"
  },
  {
    "country": "KG",
    "name": "Ak-Say",
    "lat": "39.87438",
    "lng": "70.52211"
  },
  {
    "country": "KH",
    "name": "Phnom Penh",
    "lat": "11.56245",
    "lng": "104.91601"
  },
  {
    "country": "KH",
    "name": "Veun Sai",
    "lat": "13.97598",
    "lng": "106.81144"
  },
  {
    "country": "KH",
    "name": "Ta Khmau",
    "lat": "11.48333",
    "lng": "104.95"
  },
  {
    "country": "KH",
    "name": "Takeo",
    "lat": "10.99081",
    "lng": "104.78498"
  },
  {
    "country": "KH",
    "name": "Svay Rieng",
    "lat": "11.08785",
    "lng": "105.79935"
  },
  {
    "country": "KH",
    "name": "Svay Chek",
    "lat": "13.80539",
    "lng": "102.96184"
  },
  {
    "country": "KH",
    "name": "Suong",
    "lat": "11.91178",
    "lng": "105.65821"
  },
  {
    "country": "KH",
    "name": "Stung Treng",
    "lat": "13.52586",
    "lng": "105.9683"
  },
  {
    "country": "KH",
    "name": "Srae Ambel",
    "lat": "11.12212",
    "lng": "103.75383"
  },
  {
    "country": "KH",
    "name": "Sisophon",
    "lat": "13.58588",
    "lng": "102.97369"
  },
  {
    "country": "KH",
    "name": "Siem Reap",
    "lat": "13.36179",
    "lng": "103.86056"
  },
  {
    "country": "KH",
    "name": "Siem Pang",
    "lat": "14.11728",
    "lng": "106.38838"
  },
  {
    "country": "KH",
    "name": "Sen Monorom",
    "lat": "12.45583",
    "lng": "107.18811"
  },
  {
    "country": "KH",
    "name": "Prey Veng",
    "lat": "11.48682",
    "lng": "105.32533"
  },
  {
    "country": "KH",
    "name": "S’ang",
    "lat": "11.36067",
    "lng": "105.00776"
  },
  {
    "country": "KH",
    "name": "Koah Thum",
    "lat": "11.12421",
    "lng": "105.05722"
  },
  {
    "country": "KH",
    "name": "Pursat",
    "lat": "12.53878",
    "lng": "103.9192"
  },
  {
    "country": "KH",
    "name": "Phumĭ Véal Srê",
    "lat": "10.98081",
    "lng": "104.77828"
  },
  {
    "country": "KH",
    "name": "Bak Khlang",
    "lat": "11.56903",
    "lng": "102.95542"
  },
  {
    "country": "KH",
    "name": "Thma Puok",
    "lat": "13.93987",
    "lng": "103.05307"
  },
  {
    "country": "KH",
    "name": "Ta Loas",
    "lat": "12.8079",
    "lng": "103.46023"
  },
  {
    "country": "KH",
    "name": "Samraong",
    "lat": "14.18175",
    "lng": "103.51761"
  },
  {
    "country": "KH",
    "name": "Sala Krau",
    "lat": "12.95612",
    "lng": "102.60891"
  },
  {
    "country": "KH",
    "name": "Preaek Prasab",
    "lat": "12.35367",
    "lng": "106.03562"
  },
  {
    "country": "KH",
    "name": "Koas Krala",
    "lat": "12.75588",
    "lng": "103.25514"
  },
  {
    "country": "KH",
    "name": "Kampong Seila",
    "lat": "11.09167",
    "lng": "103.90078"
  },
  {
    "country": "KH",
    "name": "Chhuk",
    "lat": "10.83644",
    "lng": "104.45528"
  },
  {
    "country": "KH",
    "name": "Chhloung",
    "lat": "12.2561",
    "lng": "105.97004"
  },
  {
    "country": "KH",
    "name": "Bavel",
    "lat": "13.25128",
    "lng": "102.87795"
  },
  {
    "country": "KH",
    "name": "Banan",
    "lat": "12.93964",
    "lng": "103.14239"
  },
  {
    "country": "KH",
    "name": "Tbeng Meanchey",
    "lat": "13.80731",
    "lng": "104.98046"
  },
  {
    "country": "KH",
    "name": "Paoy Paet",
    "lat": "13.65805",
    "lng": "102.56365"
  },
  {
    "country": "KH",
    "name": "Pailin",
    "lat": "12.84895",
    "lng": "102.60928"
  },
  {
    "country": "KH",
    "name": "Moung Ruessei",
    "lat": "12.77452",
    "lng": "103.44926"
  },
  {
    "country": "KH",
    "name": "Lumphat",
    "lat": "13.49146",
    "lng": "106.98022"
  },
  {
    "country": "KH",
    "name": "Kuleaen",
    "lat": "13.82147",
    "lng": "104.69824"
  },
  {
    "country": "KH",
    "name": "Krong Kep",
    "lat": "10.48291",
    "lng": "104.31672"
  },
  {
    "country": "KH",
    "name": "Koh Kong",
    "lat": "11.61531",
    "lng": "102.9838"
  },
  {
    "country": "KH",
    "name": "Kratié",
    "lat": "12.48811",
    "lng": "106.01879"
  },
  {
    "country": "KH",
    "name": "Batheay",
    "lat": "11.98935",
    "lng": "104.94208"
  },
  {
    "country": "KH",
    "name": "Kampot",
    "lat": "10.61041",
    "lng": "104.18145"
  },
  {
    "country": "KH",
    "name": "Kampong Trach",
    "lat": "10.55847",
    "lng": "104.46753"
  },
  {
    "country": "KH",
    "name": "Kampong Trabaek",
    "lat": "11.14379",
    "lng": "105.48275"
  },
  {
    "country": "KH",
    "name": "Kampong Thom",
    "lat": "12.71112",
    "lng": "104.88873"
  },
  {
    "country": "KH",
    "name": "Kampong Speu",
    "lat": "11.45332",
    "lng": "104.52085"
  },
  {
    "country": "KH",
    "name": "Sihanoukville",
    "lat": "10.60932",
    "lng": "103.52958"
  },
  {
    "country": "KH",
    "name": "Kampong Chhnang",
    "lat": "12.25",
    "lng": "104.66667"
  },
  {
    "country": "KH",
    "name": "Kampong Cham",
    "lat": "11.99339",
    "lng": "105.4635"
  },
  {
    "country": "KH",
    "name": "Sesan",
    "lat": "13.55329",
    "lng": "106.09224"
  },
  {
    "country": "KH",
    "name": "Banlung",
    "lat": "13.73939",
    "lng": "106.98727"
  },
  {
    "country": "KH",
    "name": "Odongk",
    "lat": "11.68267",
    "lng": "104.69945"
  },
  {
    "country": "KH",
    "name": "Battambang",
    "lat": "13.10271",
    "lng": "103.19822"
  },
  {
    "country": "KH",
    "name": "Baray",
    "lat": "12.39429",
    "lng": "105.07518"
  },
  {
    "country": "KH",
    "name": "Bar Kaev",
    "lat": "13.6862",
    "lng": "107.21417"
  },
  {
    "country": "KH",
    "name": "Pal Hal",
    "lat": "13.79226",
    "lng": "104.97859"
  },
  {
    "country": "KH",
    "name": "Anlong Veaeng",
    "lat": "14.23223",
    "lng": "104.08107"
  },
  {
    "country": "KH",
    "name": "Sampov Lun",
    "lat": "13.4319",
    "lng": "102.37574"
  },
  {
    "country": "KH",
    "name": "Smach Mean Chey",
    "lat": "11.54665",
    "lng": "103.03569"
  },
  {
    "country": "KH",
    "name": "Phnum Proek",
    "lat": "13.2235",
    "lng": "102.39546"
  },
  {
    "country": "KH",
    "name": "Kamrieng",
    "lat": "13.08806",
    "lng": "102.49074"
  },
  {
    "country": "KH",
    "name": "Samlout",
    "lat": "12.61698",
    "lng": "102.85862"
  },
  {
    "country": "KH",
    "name": "Ou Chrov",
    "lat": "13.63885",
    "lng": "102.58356"
  },
  {
    "country": "KH",
    "name": "Veal Veaeng",
    "lat": "12.30491",
    "lng": "103.1023"
  },
  {
    "country": "KH",
    "name": "Aek Phnum",
    "lat": "13.15993",
    "lng": "103.23134"
  },
  {
    "country": "KH",
    "name": "Bat Dambang",
    "lat": "13.26298",
    "lng": "103.09037"
  },
  {
    "country": "KH",
    "name": "Phnum Srok",
    "lat": "13.74403",
    "lng": "103.33892"
  },
  {
    "country": "KH",
    "name": "Kralanh",
    "lat": "13.60535",
    "lng": "103.41903"
  },
  {
    "country": "KH",
    "name": "Mongkol Borei",
    "lat": "13.54057",
    "lng": "103.02693"
  },
  {
    "country": "KH",
    "name": "Preah Netr Preah",
    "lat": "13.62371",
    "lng": "103.18212"
  },
  {
    "country": "KH",
    "name": "Mondul Seima",
    "lat": "11.62411",
    "lng": "102.95015"
  },
  {
    "country": "KH",
    "name": "Smach Meanchey",
    "lat": "11.60412",
    "lng": "102.98801"
  },
  {
    "country": "KH",
    "name": "Botum Sakor",
    "lat": "11.1872",
    "lng": "103.47117"
  },
  {
    "country": "KH",
    "name": "Sangkae",
    "lat": "13.07943",
    "lng": "103.24454"
  },
  {
    "country": "KH",
    "name": "Mittakpheap",
    "lat": "10.62268",
    "lng": "103.52473"
  },
  {
    "country": "KH",
    "name": "Thma Bang",
    "lat": "11.62925",
    "lng": "103.52958"
  },
  {
    "country": "KH",
    "name": "Phnum Kravanh",
    "lat": "12.35121",
    "lng": "103.7694"
  },
  {
    "country": "KH",
    "name": "Srei Snam",
    "lat": "13.8342",
    "lng": "103.51315"
  },
  {
    "country": "KH",
    "name": "Chum Kiri",
    "lat": "10.92522",
    "lng": "104.42185"
  },
  {
    "country": "KH",
    "name": "Kampot",
    "lat": "10.60421",
    "lng": "104.25611"
  },
  {
    "country": "KH",
    "name": "Damnak Chang’aeur",
    "lat": "10.53021",
    "lng": "104.36881"
  },
  {
    "country": "KH",
    "name": "Phnum Sruoch",
    "lat": "11.385",
    "lng": "104.37165"
  },
  {
    "country": "KH",
    "name": "Thpong",
    "lat": "11.75375",
    "lng": "104.42743"
  },
  {
    "country": "KH",
    "name": "Soutr Nikom",
    "lat": "13.23879",
    "lng": "104.13784"
  },
  {
    "country": "KH",
    "name": "Trapeang Prasat",
    "lat": "14.18689",
    "lng": "104.35533"
  },
  {
    "country": "KH",
    "name": "Kiri Vongs",
    "lat": "10.63781",
    "lng": "104.87319"
  },
  {
    "country": "KH",
    "name": "Banteay Meas",
    "lat": "10.66781",
    "lng": "104.56026"
  },
  {
    "country": "KH",
    "name": "Kandal Stueng",
    "lat": "11.4135",
    "lng": "104.82648"
  },
  {
    "country": "KH",
    "name": "Ta Khmau",
    "lat": "11.44641",
    "lng": "104.94556"
  },
  {
    "country": "KH",
    "name": "Tram Kak",
    "lat": "11.01173",
    "lng": "104.67631"
  },
  {
    "country": "KH",
    "name": "Basedth",
    "lat": "11.14918",
    "lng": "104.53641"
  },
  {
    "country": "KH",
    "name": "Mukh Kampul",
    "lat": "11.73577",
    "lng": "104.97713"
  },
  {
    "country": "KH",
    "name": "Ponhea Lueu",
    "lat": "11.65577",
    "lng": "104.86684"
  },
  {
    "country": "KH",
    "name": "Ruessei Kaev",
    "lat": "11.62439",
    "lng": "104.90941"
  },
  {
    "country": "KH",
    "name": "Dangkao",
    "lat": "11.56173",
    "lng": "104.85553"
  },
  {
    "country": "KH",
    "name": "Mean Chey",
    "lat": "11.53264",
    "lng": "104.93662"
  },
  {
    "country": "KH",
    "name": "Kampong Leaeng",
    "lat": "12.27446",
    "lng": "104.72737"
  },
  {
    "country": "KH",
    "name": "Stueng Saen",
    "lat": "12.71121",
    "lng": "104.89108"
  },
  {
    "country": "KH",
    "name": "Stoung",
    "lat": "12.9404",
    "lng": "104.57072"
  },
  {
    "country": "KH",
    "name": "Bourei Cholsar",
    "lat": "10.83431",
    "lng": "105.01851"
  },
  {
    "country": "KH",
    "name": "Preah Sdach",
    "lat": "11.09511",
    "lng": "105.38447"
  },
  {
    "country": "KH",
    "name": "Kang Meas",
    "lat": "11.94627",
    "lng": "105.27491"
  },
  {
    "country": "KH",
    "name": "Kaoh Soutin",
    "lat": "11.88548",
    "lng": "105.42782"
  },
  {
    "country": "KH",
    "name": "Sithor Kandal",
    "lat": "11.77264",
    "lng": "105.38274"
  },
  {
    "country": "KH",
    "name": "Prey Veaeng",
    "lat": "11.57101",
    "lng": "105.42058"
  },
  {
    "country": "KH",
    "name": "Chamkar Leu",
    "lat": "12.30851",
    "lng": "105.28186"
  },
  {
    "country": "KH",
    "name": "Cheung Prey",
    "lat": "12.05685",
    "lng": "105.07475"
  },
  {
    "country": "KH",
    "name": "Prey Chhor",
    "lat": "12.05804",
    "lng": "105.25723"
  },
  {
    "country": "KH",
    "name": "Sandan",
    "lat": "13.10459",
    "lng": "105.25407"
  },
  {
    "country": "KH",
    "name": "Rumduol",
    "lat": "11.15888",
    "lng": "105.82261"
  },
  {
    "country": "KH",
    "name": "Svay Teab",
    "lat": "11.05456",
    "lng": "105.88531"
  },
  {
    "country": "KH",
    "name": "Me Sang",
    "lat": "11.32761",
    "lng": "105.54605"
  },
  {
    "country": "KH",
    "name": "Stueng Trang",
    "lat": "12.25578",
    "lng": "105.53522"
  },
  {
    "country": "KH",
    "name": "Chantrea",
    "lat": "10.98431",
    "lng": "106.12486"
  },
  {
    "country": "KH",
    "name": "Kaev Seima",
    "lat": "12.18739",
    "lng": "106.88061"
  },
  {
    "country": "KH",
    "name": "Ou Chum",
    "lat": "13.7978",
    "lng": "106.99378"
  },
  {
    "country": "KH",
    "name": "Andoung Meas",
    "lat": "13.86724",
    "lng": "107.29682"
  },
  {
    "country": "KH",
    "name": "Ou Ya Dav",
    "lat": "13.67061",
    "lng": "107.34701"
  },
  {
    "country": "KH",
    "name": "Sangkom Thmei",
    "lat": "13.58147",
    "lng": "104.91315"
  },
  {
    "country": "KH",
    "name": "Peam Ro",
    "lat": "11.30852",
    "lng": "105.28366"
  },
  {
    "country": "KH",
    "name": "Kampong Leav",
    "lat": "11.49308",
    "lng": "105.34318"
  },
  {
    "country": "KH",
    "name": "Leuk Daek",
    "lat": "11.1751",
    "lng": "105.2292"
  },
  {
    "country": "KH",
    "name": "Peam Chor",
    "lat": "11.09877",
    "lng": "105.22114"
  },
  {
    "country": "KH",
    "name": "Koun Mom",
    "lat": "13.57767",
    "lng": "106.77289"
  },
  {
    "country": "KH",
    "name": "Pechreada",
    "lat": "12.55254",
    "lng": "107.42393"
  },
  {
    "country": "KH",
    "name": "Prey Nob",
    "lat": "10.70939",
    "lng": "103.82091"
  },
  {
    "country": "KH",
    "name": "Bakan",
    "lat": "12.60209",
    "lng": "103.78579"
  },
  {
    "country": "KH",
    "name": "Angkor Thum",
    "lat": "13.48339",
    "lng": "103.87413"
  },
  {
    "country": "KH",
    "name": "Bakong",
    "lat": "13.34741",
    "lng": "103.98756"
  },
  {
    "country": "KH",
    "name": "Varin",
    "lat": "13.79322",
    "lng": "103.76085"
  },
  {
    "country": "KH",
    "name": "Angkor Chum",
    "lat": "13.68385",
    "lng": "103.6479"
  },
  {
    "country": "KH",
    "name": "Aoral",
    "lat": "11.68778",
    "lng": "104.12959"
  },
  {
    "country": "KH",
    "name": "Baribour",
    "lat": "12.43758",
    "lng": "104.46286"
  },
  {
    "country": "KH",
    "name": "Chi Kraeng",
    "lat": "13.12234",
    "lng": "104.34627"
  },
  {
    "country": "KI",
    "name": "Teaoraereke Village",
    "lat": "1.33309",
    "lng": "173.01162"
  },
  {
    "country": "KI",
    "name": "Rawannawi Village",
    "lat": "2.05379",
    "lng": "173.26354"
  },
  {
    "country": "KI",
    "name": "Buota Village",
    "lat": "1.39078",
    "lng": "173.13082"
  },
  {
    "country": "KI",
    "name": "Betio Village",
    "lat": "1.35797",
    "lng": "172.92105"
  },
  {
    "country": "KI",
    "name": "Banraeaba Village",
    "lat": "1.3454",
    "lng": "173.03464"
  },
  {
    "country": "KI",
    "name": "Tarawa",
    "lat": "1.3278",
    "lng": "172.97696"
  },
  {
    "country": "KI",
    "name": "Napari Village",
    "lat": "3.90806",
    "lng": "-159.38832"
  },
  {
    "country": "KI",
    "name": "London Village",
    "lat": "1.98487",
    "lng": "-157.47502"
  },
  {
    "country": "KI",
    "name": "Tabwakea Village",
    "lat": "2.01643",
    "lng": "-157.48773"
  },
  {
    "country": "KI",
    "name": "Banana Village",
    "lat": "1.98329",
    "lng": "-157.36526"
  },
  {
    "country": "KI",
    "name": "Makin Village",
    "lat": "3.3644",
    "lng": "172.98352"
  },
  {
    "country": "KI",
    "name": "Bairiki Village",
    "lat": "1.32924",
    "lng": "172.97522"
  },
  {
    "country": "KI",
    "name": "Ambo Village",
    "lat": "1.35317",
    "lng": "173.04259"
  },
  {
    "country": "KI",
    "name": "Bonriki Village",
    "lat": "1.38081",
    "lng": "173.13887"
  },
  {
    "country": "KI",
    "name": "Temaiku Village",
    "lat": "1.36292",
    "lng": "173.16226"
  },
  {
    "country": "KI",
    "name": "Nawerewere Village",
    "lat": "1.36362",
    "lng": "173.13935"
  },
  {
    "country": "KI",
    "name": "Bikenibeu Village",
    "lat": "1.3673",
    "lng": "173.12415"
  },
  {
    "country": "KI",
    "name": "Eita Village",
    "lat": "1.36154",
    "lng": "173.08113"
  },
  {
    "country": "KM",
    "name": "Ouanani",
    "lat": "-12.3375",
    "lng": "43.7975"
  },
  {
    "country": "KM",
    "name": "Vouani",
    "lat": "-12.24417",
    "lng": "44.37444"
  },
  {
    "country": "KM",
    "name": "Vanambouani",
    "lat": "-11.61139",
    "lng": "43.25306"
  },
  {
    "country": "KM",
    "name": "Singani",
    "lat": "-11.84556",
    "lng": "43.30917"
  },
  {
    "country": "KM",
    "name": "Sima",
    "lat": "-12.19556",
    "lng": "44.27667"
  },
  {
    "country": "KM",
    "name": "Salimani",
    "lat": "-11.80806",
    "lng": "43.25917"
  },
  {
    "country": "KM",
    "name": "Patsi",
    "lat": "-12.15556",
    "lng": "44.43722"
  },
  {
    "country": "KM",
    "name": "Ouzini",
    "lat": "-12.26722",
    "lng": "44.47972"
  },
  {
    "country": "KM",
    "name": "Oussivo",
    "lat": "-11.585",
    "lng": "43.26722"
  },
  {
    "country": "KM",
    "name": "Ourovéni",
    "lat": "-11.90972",
    "lng": "43.48861"
  },
  {
    "country": "KM",
    "name": "Ouellah",
    "lat": "-11.39028",
    "lng": "43.33194"
  },
  {
    "country": "KM",
    "name": "Ouani",
    "lat": "-12.13554",
    "lng": "44.42493"
  },
  {
    "country": "KM",
    "name": "Ongoni",
    "lat": "-12.17028",
    "lng": "44.50694"
  },
  {
    "country": "KM",
    "name": "Ntsoudjini",
    "lat": "-11.65972",
    "lng": "43.26139"
  },
  {
    "country": "KM",
    "name": "Ntsaouéni",
    "lat": "-11.46583",
    "lng": "43.26278"
  },
  {
    "country": "KM",
    "name": "Nioumachoua",
    "lat": "-12.36139",
    "lng": "43.71528"
  },
  {
    "country": "KM",
    "name": "Kyo",
    "lat": "-12.33222",
    "lng": "44.51917"
  },
  {
    "country": "KM",
    "name": "Moutsamoudou",
    "lat": "-12.16672",
    "lng": "44.39944"
  },
  {
    "country": "KM",
    "name": "Mtsamdou",
    "lat": "-11.60694",
    "lng": "43.38056"
  },
  {
    "country": "KM",
    "name": "Mrémani",
    "lat": "-12.30833",
    "lng": "44.49861"
  },
  {
    "country": "KM",
    "name": "Mramani",
    "lat": "-12.34639",
    "lng": "44.52861"
  },
  {
    "country": "KM",
    "name": "Moya",
    "lat": "-12.30667",
    "lng": "44.43778"
  },
  {
    "country": "KM",
    "name": "Moroni",
    "lat": "-11.70216",
    "lng": "43.25506"
  },
  {
    "country": "KM",
    "name": "Mohoro",
    "lat": "-11.82583",
    "lng": "43.44611"
  },
  {
    "country": "KM",
    "name": "Mjimandra",
    "lat": "-12.19167",
    "lng": "44.37028"
  },
  {
    "country": "KM",
    "name": "Mjamaoué",
    "lat": "-12.19361",
    "lng": "44.31"
  },
  {
    "country": "KM",
    "name": "Mitsamiouli",
    "lat": "-11.38472",
    "lng": "43.28444"
  },
  {
    "country": "KM",
    "name": "Mbéni",
    "lat": "-11.50139",
    "lng": "43.3775"
  },
  {
    "country": "KM",
    "name": "Maraharé",
    "lat": "-12.23083",
    "lng": "44.31333"
  },
  {
    "country": "KM",
    "name": "Koni-Djodjo",
    "lat": "-12.22972",
    "lng": "44.48167"
  },
  {
    "country": "KM",
    "name": "Koni-Ngani",
    "lat": "-12.21583",
    "lng": "44.48"
  },
  {
    "country": "KM",
    "name": "Koki",
    "lat": "-12.17139",
    "lng": "44.44167"
  },
  {
    "country": "KM",
    "name": "Kangani",
    "lat": "-12.31167",
    "lng": "44.47472"
  },
  {
    "country": "KM",
    "name": "Ivouani",
    "lat": "-11.39157",
    "lng": "43.39454"
  },
  {
    "country": "KM",
    "name": "Itsandra",
    "lat": "-11.67111",
    "lng": "43.25472"
  },
  {
    "country": "KM",
    "name": "Héroumbili",
    "lat": "-11.54389",
    "lng": "43.37972"
  },
  {
    "country": "KM",
    "name": "Hoani",
    "lat": "-12.25083",
    "lng": "43.67472"
  },
  {
    "country": "KM",
    "name": "Foumbouni",
    "lat": "-11.86167",
    "lng": "43.48417"
  },
  {
    "country": "KM",
    "name": "Fomboni",
    "lat": "-12.28759",
    "lng": "43.74344"
  },
  {
    "country": "KM",
    "name": "Dziani",
    "lat": "-12.18333",
    "lng": "44.48333"
  },
  {
    "country": "KM",
    "name": "Domoni",
    "lat": "-12.25694",
    "lng": "44.53194"
  },
  {
    "country": "KM",
    "name": "Djoyézi",
    "lat": "-12.30587",
    "lng": "43.77425"
  },
  {
    "country": "KM",
    "name": "Dembéni",
    "lat": "-11.87361",
    "lng": "43.39778"
  },
  {
    "country": "KM",
    "name": "Chironkamba",
    "lat": "-12.19111",
    "lng": "44.3525"
  },
  {
    "country": "KM",
    "name": "Chindini",
    "lat": "-11.92083",
    "lng": "43.48111"
  },
  {
    "country": "KM",
    "name": "Chezani",
    "lat": "-11.4314",
    "lng": "43.39625"
  },
  {
    "country": "KM",
    "name": "Chandra",
    "lat": "-12.195",
    "lng": "44.46472"
  },
  {
    "country": "KM",
    "name": "Bouni",
    "lat": "-11.48694",
    "lng": "43.38833"
  },
  {
    "country": "KM",
    "name": "Boungouéni",
    "lat": "-12.20556",
    "lng": "44.29944"
  },
  {
    "country": "KM",
    "name": "Bimbini",
    "lat": "-12.18833",
    "lng": "44.23556"
  },
  {
    "country": "KM",
    "name": "Assimpao",
    "lat": "-12.23306",
    "lng": "44.31972"
  },
  {
    "country": "KM",
    "name": "Antsahé",
    "lat": "-12.35639",
    "lng": "44.5225"
  },
  {
    "country": "KM",
    "name": "Mtakoudja",
    "lat": "-12.26111",
    "lng": "43.70361"
  },
  {
    "country": "KM",
    "name": "Ziroudani",
    "lat": "-12.3325",
    "lng": "43.7775"
  },
  {
    "country": "KM",
    "name": "Kavani",
    "lat": "-12.19194",
    "lng": "44.26944"
  },
  {
    "country": "KM",
    "name": "Bandajou",
    "lat": "-12.19167",
    "lng": "44.28694"
  },
  {
    "country": "KM",
    "name": "Chitrouni",
    "lat": "-12.18583",
    "lng": "44.33556"
  },
  {
    "country": "KM",
    "name": "Hajoho",
    "lat": "-12.1175",
    "lng": "44.48833"
  },
  {
    "country": "KM",
    "name": "Barakani",
    "lat": "-12.13861",
    "lng": "44.43026"
  },
  {
    "country": "KM",
    "name": "Harembo",
    "lat": "-12.14361",
    "lng": "44.49833"
  },
  {
    "country": "KM",
    "name": "Mirontsi",
    "lat": "-12.15667",
    "lng": "44.40806"
  },
  {
    "country": "KM",
    "name": "Pajé",
    "lat": "-12.16972",
    "lng": "44.38806"
  },
  {
    "country": "KM",
    "name": "Limbi",
    "lat": "-12.23944",
    "lng": "44.50528"
  },
  {
    "country": "KM",
    "name": "Lingoni",
    "lat": "-12.25583",
    "lng": "44.41833"
  },
  {
    "country": "KM",
    "name": "Magnassini-Nindri",
    "lat": "-12.27806",
    "lng": "44.41583"
  },
  {
    "country": "KM",
    "name": "Adda-Douéni",
    "lat": "-12.2925",
    "lng": "44.49722"
  },
  {
    "country": "KM",
    "name": "Daji",
    "lat": "-12.32583",
    "lng": "44.48861"
  },
  {
    "country": "KM",
    "name": "Ouhozi",
    "lat": "-11.405",
    "lng": "43.28222"
  },
  {
    "country": "KM",
    "name": "Mandza",
    "lat": "-11.41806",
    "lng": "43.29528"
  },
  {
    "country": "KM",
    "name": "Douniani",
    "lat": "-11.42111",
    "lng": "43.28889"
  },
  {
    "country": "KM",
    "name": "Koua",
    "lat": "-11.42083",
    "lng": "43.27639"
  },
  {
    "country": "KM",
    "name": "Hantsindzi",
    "lat": "-11.43178",
    "lng": "43.41102"
  },
  {
    "country": "KM",
    "name": "Itsandzéni",
    "lat": "-11.47278",
    "lng": "43.38444"
  },
  {
    "country": "KM",
    "name": "Bambadjani",
    "lat": "-11.47861",
    "lng": "43.37722"
  },
  {
    "country": "KM",
    "name": "Mnoungou",
    "lat": "-11.51778",
    "lng": "43.37389"
  },
  {
    "country": "KM",
    "name": "Vanadjou",
    "lat": "-11.6075",
    "lng": "43.27611"
  },
  {
    "country": "KM",
    "name": "Bahani",
    "lat": "-11.63972",
    "lng": "43.28417"
  },
  {
    "country": "KM",
    "name": "Tsidjé",
    "lat": "-11.69806",
    "lng": "43.26194"
  },
  {
    "country": "KM",
    "name": "Mvouni",
    "lat": "-11.71611",
    "lng": "43.26472"
  },
  {
    "country": "KM",
    "name": "Mavingouni",
    "lat": "-11.71639",
    "lng": "43.2525"
  },
  {
    "country": "KM",
    "name": "Séléa",
    "lat": "-11.78444",
    "lng": "43.26083"
  },
  {
    "country": "KM",
    "name": "Madjeouéni",
    "lat": "-11.82167",
    "lng": "43.27806"
  },
  {
    "country": "KM",
    "name": "Nioumamilima",
    "lat": "-11.85111",
    "lng": "43.43722"
  },
  {
    "country": "KM",
    "name": "Mkiriwadjumoi",
    "lat": "-12.31086",
    "lng": "44.43702"
  },
  {
    "country": "KN",
    "name": "Trinity",
    "lat": "17.30037",
    "lng": "-62.77584"
  },
  {
    "country": "KN",
    "name": "Sandy Point Town",
    "lat": "17.35908",
    "lng": "-62.84858"
  },
  {
    "country": "KN",
    "name": "Saint Paul’s",
    "lat": "17.40605",
    "lng": "-62.83562"
  },
  {
    "country": "KN",
    "name": "Nicola Town",
    "lat": "17.37956",
    "lng": "-62.75318"
  },
  {
    "country": "KN",
    "name": "Newcastle",
    "lat": "17.2",
    "lng": "-62.58333"
  },
  {
    "country": "KN",
    "name": "Monkey Hill",
    "lat": "17.32327",
    "lng": "-62.72914"
  },
  {
    "country": "KN",
    "name": "Middle Island",
    "lat": "17.3259",
    "lng": "-62.81055"
  },
  {
    "country": "KN",
    "name": "Market Shop",
    "lat": "17.13218",
    "lng": "-62.57267"
  },
  {
    "country": "KN",
    "name": "Fig Tree",
    "lat": "17.12623",
    "lng": "-62.60265"
  },
  {
    "country": "KN",
    "name": "Dieppe Bay Town",
    "lat": "17.41473",
    "lng": "-62.8139"
  },
  {
    "country": "KN",
    "name": "Cotton Ground",
    "lat": "17.16667",
    "lng": "-62.61667"
  },
  {
    "country": "KN",
    "name": "Charlestown",
    "lat": "17.13333",
    "lng": "-62.61667"
  },
  {
    "country": "KN",
    "name": "Cayon",
    "lat": "17.35",
    "lng": "-62.73333"
  },
  {
    "country": "KN",
    "name": "Basseterre",
    "lat": "17.2955",
    "lng": "-62.72499"
  },
  {
    "country": "KP",
    "name": "Yonggang-ŭp",
    "lat": "38.85611",
    "lng": "125.42444"
  },
  {
    "country": "KP",
    "name": "Yŏngbyŏn",
    "lat": "39.81333",
    "lng": "125.80417"
  },
  {
    "country": "KP",
    "name": "Yŏnan-ŭp",
    "lat": "37.90889",
    "lng": "126.16111"
  },
  {
    "country": "KP",
    "name": "Yŏmju-ŭp",
    "lat": "39.89333",
    "lng": "124.59806"
  },
  {
    "country": "KP",
    "name": "Wŏnsan",
    "lat": "39.15278",
    "lng": "127.44361"
  },
  {
    "country": "KP",
    "name": "T’ongch’ŏn-ŭp",
    "lat": "38.95389",
    "lng": "127.89167"
  },
  {
    "country": "KP",
    "name": "Sŭngho 1-tong",
    "lat": "38.99139",
    "lng": "125.97778"
  },
  {
    "country": "KP",
    "name": "Sunch’ŏn",
    "lat": "39.43167",
    "lng": "125.93278"
  },
  {
    "country": "KP",
    "name": "Sunan",
    "lat": "39.19833",
    "lng": "125.69"
  },
  {
    "country": "KP",
    "name": "Songnim",
    "lat": "38.75417",
    "lng": "125.645"
  },
  {
    "country": "KP",
    "name": "Sil-li",
    "lat": "39.49472",
    "lng": "125.47361"
  },
  {
    "country": "KP",
    "name": "Sinmak",
    "lat": "38.41667",
    "lng": "126.23333"
  },
  {
    "country": "KP",
    "name": "Sinanju",
    "lat": "39.59806",
    "lng": "125.60972"
  },
  {
    "country": "KP",
    "name": "Sariwŏn",
    "lat": "38.50722",
    "lng": "125.75583"
  },
  {
    "country": "KP",
    "name": "Sangsŏng-ni",
    "lat": "39.16944",
    "lng": "126.88556"
  },
  {
    "country": "KP",
    "name": "Samho-rodongjagu",
    "lat": "39.9475",
    "lng": "127.87111"
  },
  {
    "country": "KP",
    "name": "Pyongyang",
    "lat": "39.03385",
    "lng": "125.75432"
  },
  {
    "country": "KP",
    "name": "P’yŏngsŏng",
    "lat": "39.24639",
    "lng": "125.87194"
  },
  {
    "country": "KP",
    "name": "Pyŏksŏng-ŭp",
    "lat": "38.0475",
    "lng": "125.55667"
  },
  {
    "country": "KP",
    "name": "Panghyŏn-dong",
    "lat": "39.88722",
    "lng": "125.24139"
  },
  {
    "country": "KP",
    "name": "Ongjin",
    "lat": "37.93472",
    "lng": "125.36194"
  },
  {
    "country": "KP",
    "name": "Namp’o",
    "lat": "38.7375",
    "lng": "125.40778"
  },
  {
    "country": "KP",
    "name": "Kwaksan",
    "lat": "39.6875",
    "lng": "125.08278"
  },
  {
    "country": "KP",
    "name": "Kusŏng",
    "lat": "39.98111",
    "lng": "125.24472"
  },
  {
    "country": "KP",
    "name": "Kujang-ŭp",
    "lat": "39.86722",
    "lng": "126.03028"
  },
  {
    "country": "KP",
    "name": "Kowŏn-ŭp",
    "lat": "39.43806",
    "lng": "127.24306"
  },
  {
    "country": "KP",
    "name": "Kosan",
    "lat": "38.85583",
    "lng": "127.41806"
  },
  {
    "country": "KP",
    "name": "Koksan",
    "lat": "38.78194",
    "lng": "126.66639"
  },
  {
    "country": "KP",
    "name": "Kangdong-ŭp",
    "lat": "39.1425",
    "lng": "126.09611"
  },
  {
    "country": "KP",
    "name": "Kaesŏng",
    "lat": "37.97083",
    "lng": "126.55444"
  },
  {
    "country": "KP",
    "name": "Hwangju-ŭp",
    "lat": "38.67028",
    "lng": "125.77611"
  },
  {
    "country": "KP",
    "name": "Hŭngnam",
    "lat": "39.83167",
    "lng": "127.61861"
  },
  {
    "country": "KP",
    "name": "Hŭkkyo-ri",
    "lat": "38.79861",
    "lng": "125.79194"
  },
  {
    "country": "KP",
    "name": "Hoeyang",
    "lat": "38.71028",
    "lng": "127.59833"
  },
  {
    "country": "KP",
    "name": "Hamhŭng",
    "lat": "39.91833",
    "lng": "127.53639"
  },
  {
    "country": "KP",
    "name": "Haeju",
    "lat": "38.04056",
    "lng": "125.71472"
  },
  {
    "country": "KP",
    "name": "Chunghwa",
    "lat": "38.86389",
    "lng": "125.8"
  },
  {
    "country": "KP",
    "name": "Chŏngju",
    "lat": "39.69333",
    "lng": "125.21028"
  },
  {
    "country": "KP",
    "name": "Changyŏn",
    "lat": "38.25083",
    "lng": "125.09611"
  },
  {
    "country": "KP",
    "name": "Chaeryŏng-ŭp",
    "lat": "38.39917",
    "lng": "125.61556"
  },
  {
    "country": "KP",
    "name": "Ayang-ni",
    "lat": "38.24306",
    "lng": "125.78"
  },
  {
    "country": "KP",
    "name": "Anju",
    "lat": "39.61778",
    "lng": "125.66472"
  },
  {
    "country": "KP",
    "name": "Anbyŏn-ŭp",
    "lat": "39.0425",
    "lng": "127.52389"
  },
  {
    "country": "KP",
    "name": "Anak",
    "lat": "38.51083",
    "lng": "125.49417"
  },
  {
    "country": "KP",
    "name": "Sinsang-ni",
    "lat": "39.65028",
    "lng": "127.40583"
  },
  {
    "country": "KP",
    "name": "Yuktae-dong",
    "lat": "40.02472",
    "lng": "128.15972"
  },
  {
    "country": "KP",
    "name": "Ungsang-nodongjagu",
    "lat": "42.35778",
    "lng": "130.46222"
  },
  {
    "country": "KP",
    "name": "Ŭiju",
    "lat": "40.19944",
    "lng": "124.53167"
  },
  {
    "country": "KP",
    "name": "Ŭijin-dong",
    "lat": "40.97518",
    "lng": "126.49584"
  },
  {
    "country": "KP",
    "name": "Sŭngam-nodongjagu",
    "lat": "41.66972",
    "lng": "129.66889"
  },
  {
    "country": "KP",
    "name": "Sŏnbong",
    "lat": "42.34161",
    "lng": "130.39445"
  },
  {
    "country": "KP",
    "name": "Sinŭiju",
    "lat": "40.10056",
    "lng": "124.39806"
  },
  {
    "country": "KP",
    "name": "Sakchu-ŭp",
    "lat": "40.38944",
    "lng": "125.04667"
  },
  {
    "country": "KP",
    "name": "Puryŏng",
    "lat": "42.06056",
    "lng": "129.71167"
  },
  {
    "country": "KP",
    "name": "Pukchil-lodongjagu",
    "lat": "40.20194",
    "lng": "125.74833"
  },
  {
    "country": "KP",
    "name": "Yŏnggwang-ŭp",
    "lat": "40.01833",
    "lng": "127.45472"
  },
  {
    "country": "KP",
    "name": "Onsŏng",
    "lat": "42.95722",
    "lng": "129.99333"
  },
  {
    "country": "KP",
    "name": "Nanam",
    "lat": "41.71361",
    "lng": "129.68444"
  },
  {
    "country": "KP",
    "name": "Namyang-dong",
    "lat": "42.95",
    "lng": "129.86667"
  },
  {
    "country": "KP",
    "name": "Rajin",
    "lat": "42.24889",
    "lng": "130.30028"
  },
  {
    "country": "KP",
    "name": "Musan-ŭp",
    "lat": "42.22609",
    "lng": "129.20776"
  },
  {
    "country": "KP",
    "name": "Manp’o",
    "lat": "41.15472",
    "lng": "126.28944"
  },
  {
    "country": "KP",
    "name": "Kyŏngwŏn",
    "lat": "42.81361",
    "lng": "130.15278"
  },
  {
    "country": "KP",
    "name": "Kyŏngsŏng",
    "lat": "41.58778",
    "lng": "129.60611"
  },
  {
    "country": "KP",
    "name": "Kimch’aek-si",
    "lat": "40.66889",
    "lng": "129.18972"
  },
  {
    "country": "KP",
    "name": "Kilju",
    "lat": "40.96417",
    "lng": "129.32778"
  },
  {
    "country": "KP",
    "name": "Kapsan-ŭp",
    "lat": "41.09028",
    "lng": "128.29333"
  },
  {
    "country": "KP",
    "name": "Kanggye",
    "lat": "40.96946",
    "lng": "126.58523"
  },
  {
    "country": "KP",
    "name": "Iwŏn-ŭp",
    "lat": "40.32306",
    "lng": "128.65528"
  },
  {
    "country": "KP",
    "name": "Hyesan-dong",
    "lat": "41.39756",
    "lng": "128.17873"
  },
  {
    "country": "KP",
    "name": "Hyesan",
    "lat": "41.40167",
    "lng": "128.17778"
  },
  {
    "country": "KP",
    "name": "Hŭngju-dong",
    "lat": "40.99629",
    "lng": "126.54756"
  },
  {
    "country": "KP",
    "name": "Hongwŏn",
    "lat": "40.02528",
    "lng": "127.95583"
  },
  {
    "country": "KP",
    "name": "Hoeryŏng",
    "lat": "42.44278",
    "lng": "129.75083"
  },
  {
    "country": "KP",
    "name": "Hoemul-li",
    "lat": "41.43389",
    "lng": "129.67"
  },
  {
    "country": "KP",
    "name": "Hau-ri",
    "lat": "41.20056",
    "lng": "129.47028"
  },
  {
    "country": "KP",
    "name": "Chongjin",
    "lat": "41.79556",
    "lng": "129.77583"
  },
  {
    "country": "KP",
    "name": "Chasŏng",
    "lat": "41.46083",
    "lng": "126.64139"
  },
  {
    "country": "KP",
    "name": "Aoji-ri",
    "lat": "42.52056",
    "lng": "130.39528"
  },
  {
    "country": "KP",
    "name": "Sŭngjibaegam",
    "lat": "41.24278",
    "lng": "128.79889"
  },
  {
    "country": "KP",
    "name": "Komusan 1-tong",
    "lat": "42.10917",
    "lng": "129.7"
  },
  {
    "country": "KR",
    "name": "Heunghae",
    "lat": "36.10945",
    "lng": "129.34517"
  },
  {
    "country": "KR",
    "name": "Yeonil",
    "lat": "35.99526",
    "lng": "129.35162"
  },
  {
    "country": "KR",
    "name": "Neietsu",
    "lat": "37.18447",
    "lng": "128.46821"
  },
  {
    "country": "KR",
    "name": "Eisen",
    "lat": "36.82167",
    "lng": "128.63083"
  },
  {
    "country": "KR",
    "name": "Yeonggwang",
    "lat": "35.27814",
    "lng": "126.51181"
  },
  {
    "country": "KR",
    "name": "Yŏng-dong",
    "lat": "36.175",
    "lng": "127.77639"
  },
  {
    "country": "KR",
    "name": "Yeongdeok",
    "lat": "36.41366",
    "lng": "129.37"
  },
  {
    "country": "KR",
    "name": "Eisen",
    "lat": "35.9675",
    "lng": "128.93083"
  },
  {
    "country": "KR",
    "name": "Iyang",
    "lat": "34.88953",
    "lng": "126.98778"
  },
  {
    "country": "KR",
    "name": "Yeoncheon",
    "lat": "38.10113",
    "lng": "127.07727"
  },
  {
    "country": "KR",
    "name": "Yeoju",
    "lat": "37.29583",
    "lng": "127.63389"
  },
  {
    "country": "KR",
    "name": "Yesan",
    "lat": "36.67756",
    "lng": "126.84272"
  },
  {
    "country": "KR",
    "name": "Yecheon",
    "lat": "36.6574",
    "lng": "128.45514"
  },
  {
    "country": "KR",
    "name": "Yangsan",
    "lat": "35.34199",
    "lng": "129.03358"
  },
  {
    "country": "KR",
    "name": "Yangp'yŏng",
    "lat": "37.48972",
    "lng": "127.49056"
  },
  {
    "country": "KR",
    "name": "Yangju",
    "lat": "37.83311",
    "lng": "127.06169"
  },
  {
    "country": "KR",
    "name": "Yanggu",
    "lat": "38.10583",
    "lng": "127.98944"
  },
  {
    "country": "KR",
    "name": "Wŏnju",
    "lat": "37.35139",
    "lng": "127.94528"
  },
  {
    "country": "KR",
    "name": "Wanju",
    "lat": "35.84509",
    "lng": "127.14752"
  },
  {
    "country": "KR",
    "name": "Waegwan",
    "lat": "35.99251",
    "lng": "128.39785"
  },
  {
    "country": "KR",
    "name": "Ulsan",
    "lat": "35.53722",
    "lng": "129.31667"
  },
  {
    "country": "KR",
    "name": "Uijeongbu-si",
    "lat": "37.7415",
    "lng": "127.0474"
  },
  {
    "country": "KR",
    "name": "Dongnae",
    "lat": "35.20159",
    "lng": "129.08477"
  },
  {
    "country": "KR",
    "name": "Dongbok",
    "lat": "35.07",
    "lng": "127.13028"
  },
  {
    "country": "KR",
    "name": "Tangjin",
    "lat": "36.89444",
    "lng": "126.62972"
  },
  {
    "country": "KR",
    "name": "Damyang",
    "lat": "35.31889",
    "lng": "126.98389"
  },
  {
    "country": "KR",
    "name": "Taesal-li",
    "lat": "36.9714",
    "lng": "126.4542"
  },
  {
    "country": "KR",
    "name": "Daejeon",
    "lat": "36.32139",
    "lng": "127.41972"
  },
  {
    "country": "KR",
    "name": "Daegu",
    "lat": "35.87028",
    "lng": "128.59111"
  },
  {
    "country": "KR",
    "name": "Taisen-ri",
    "lat": "36.34931",
    "lng": "126.59772"
  },
  {
    "country": "KR",
    "name": "T’aebaek",
    "lat": "37.1759",
    "lng": "128.9889"
  },
  {
    "country": "KR",
    "name": "Suwon",
    "lat": "37.29111",
    "lng": "127.00889"
  },
  {
    "country": "KR",
    "name": "Suncheon",
    "lat": "34.9505",
    "lng": "127.48784"
  },
  {
    "country": "KR",
    "name": "Seoul",
    "lat": "37.566",
    "lng": "126.9784"
  },
  {
    "country": "KR",
    "name": "Seosan",
    "lat": "36.78167",
    "lng": "126.45222"
  },
  {
    "country": "KR",
    "name": "Jenzan",
    "lat": "36.24083",
    "lng": "128.2975"
  },
  {
    "country": "KR",
    "name": "Seonghwan",
    "lat": "36.91556",
    "lng": "127.13139"
  },
  {
    "country": "KR",
    "name": "Sokcho",
    "lat": "38.20701",
    "lng": "128.59181"
  },
  {
    "country": "KR",
    "name": "Sintansin",
    "lat": "36.45361",
    "lng": "127.43111"
  },
  {
    "country": "KR",
    "name": "Sangju",
    "lat": "36.41528",
    "lng": "128.16056"
  },
  {
    "country": "KR",
    "name": "Sangju",
    "lat": "34.72423",
    "lng": "127.98521"
  },
  {
    "country": "KR",
    "name": "Santyoku",
    "lat": "37.44056",
    "lng": "129.17083"
  },
  {
    "country": "KR",
    "name": "Pyeongchang",
    "lat": "37.37028",
    "lng": "128.39306"
  },
  {
    "country": "KR",
    "name": "Fuyo",
    "lat": "36.28194",
    "lng": "126.9125"
  },
  {
    "country": "KR",
    "name": "Busan",
    "lat": "35.10278",
    "lng": "129.04028"
  },
  {
    "country": "KR",
    "name": "Bucheon-si",
    "lat": "37.49889",
    "lng": "126.78306"
  },
  {
    "country": "KR",
    "name": "Puan",
    "lat": "35.72806",
    "lng": "126.73194"
  },
  {
    "country": "KR",
    "name": "Beolgyo",
    "lat": "34.84897",
    "lng": "127.34052"
  },
  {
    "country": "KR",
    "name": "Pohang",
    "lat": "36.02917",
    "lng": "129.36481"
  },
  {
    "country": "KR",
    "name": "Beobwon",
    "lat": "37.84902",
    "lng": "126.87533"
  },
  {
    "country": "KR",
    "name": "Osan",
    "lat": "37.15222",
    "lng": "127.07056"
  },
  {
    "country": "KR",
    "name": "Asan",
    "lat": "36.78361",
    "lng": "127.00417"
  },
  {
    "country": "KR",
    "name": "Okcheon",
    "lat": "36.3012",
    "lng": "127.568"
  },
  {
    "country": "KR",
    "name": "Kosong",
    "lat": "38.37881",
    "lng": "128.4676"
  },
  {
    "country": "KR",
    "name": "Nonsan",
    "lat": "36.20389",
    "lng": "127.08472"
  },
  {
    "country": "KR",
    "name": "Nangen",
    "lat": "35.41",
    "lng": "127.38583"
  },
  {
    "country": "KR",
    "name": "Naju",
    "lat": "35.0292",
    "lng": "126.7175"
  },
  {
    "country": "KR",
    "name": "Munsan",
    "lat": "37.85944",
    "lng": "126.785"
  },
  {
    "country": "KR",
    "name": "Mungyeong",
    "lat": "36.59458",
    "lng": "128.19946"
  },
  {
    "country": "KR",
    "name": "Mungyeong",
    "lat": "36.73528",
    "lng": "128.10833"
  },
  {
    "country": "KR",
    "name": "Muan",
    "lat": "34.99014",
    "lng": "126.47899"
  },
  {
    "country": "KR",
    "name": "Mokpo",
    "lat": "34.81282",
    "lng": "126.39181"
  },
  {
    "country": "KR",
    "name": "Miryang",
    "lat": "35.49333",
    "lng": "128.74889"
  },
  {
    "country": "KR",
    "name": "Masan",
    "lat": "35.12725",
    "lng": "126.83149"
  },
  {
    "country": "KR",
    "name": "Gyeongsan-si",
    "lat": "35.82333",
    "lng": "128.73778"
  },
  {
    "country": "KR",
    "name": "Gyeongju",
    "lat": "35.84278",
    "lng": "129.21167"
  },
  {
    "country": "KR",
    "name": "Kwangyang",
    "lat": "34.97528",
    "lng": "127.58917"
  },
  {
    "country": "KR",
    "name": "Gwangju",
    "lat": "37.41",
    "lng": "127.25722"
  },
  {
    "country": "KR",
    "name": "Gwangju",
    "lat": "35.15472",
    "lng": "126.91556"
  },
  {
    "country": "KR",
    "name": "Guryongpo",
    "lat": "35.98994",
    "lng": "129.55377"
  },
  {
    "country": "KR",
    "name": "Kurye",
    "lat": "35.20944",
    "lng": "127.46444"
  },
  {
    "country": "KR",
    "name": "Guri-si",
    "lat": "37.5986",
    "lng": "127.1394"
  },
  {
    "country": "KR",
    "name": "Kunwi",
    "lat": "36.23472",
    "lng": "128.57278"
  },
  {
    "country": "KR",
    "name": "Gunsan",
    "lat": "35.97861",
    "lng": "126.71139"
  },
  {
    "country": "KR",
    "name": "Kinzan",
    "lat": "36.10306",
    "lng": "127.48889"
  },
  {
    "country": "KR",
    "name": "Gumi",
    "lat": "36.1136",
    "lng": "128.336"
  },
  {
    "country": "KR",
    "name": "Goyang-si",
    "lat": "37.65639",
    "lng": "126.835"
  },
  {
    "country": "KR",
    "name": "Goseong",
    "lat": "34.97631",
    "lng": "128.32361"
  },
  {
    "country": "KR",
    "name": "Gongju",
    "lat": "36.45556",
    "lng": "127.12472"
  },
  {
    "country": "KR",
    "name": "Kyosai",
    "lat": "34.85028",
    "lng": "128.58861"
  },
  {
    "country": "KR",
    "name": "Koesan",
    "lat": "36.81083",
    "lng": "127.79472"
  },
  {
    "country": "KR",
    "name": "Koch'ang",
    "lat": "35.43333",
    "lng": "126.7"
  },
  {
    "country": "KR",
    "name": "Kimje",
    "lat": "35.80167",
    "lng": "126.88889"
  },
  {
    "country": "KR",
    "name": "Kimhae",
    "lat": "35.23417",
    "lng": "128.88111"
  },
  {
    "country": "KR",
    "name": "Gimcheon",
    "lat": "36.12176",
    "lng": "128.11981"
  },
  {
    "country": "KR",
    "name": "Gijang",
    "lat": "35.24417",
    "lng": "129.21389"
  },
  {
    "country": "KR",
    "name": "Gapyeong",
    "lat": "37.83101",
    "lng": "127.51059"
  },
  {
    "country": "KR",
    "name": "Gangneung",
    "lat": "37.75266",
    "lng": "128.87239"
  },
  {
    "country": "KR",
    "name": "Ganghwa-gun",
    "lat": "37.74722",
    "lng": "126.48556"
  },
  {
    "country": "KR",
    "name": "Gampo",
    "lat": "35.80538",
    "lng": "129.5011"
  },
  {
    "country": "KR",
    "name": "Iksan",
    "lat": "35.94389",
    "lng": "126.95444"
  },
  {
    "country": "KR",
    "name": "Incheon",
    "lat": "37.45646",
    "lng": "126.70515"
  },
  {
    "country": "KR",
    "name": "Imsil",
    "lat": "35.61306",
    "lng": "127.27944"
  },
  {
    "country": "KR",
    "name": "Icheon-si",
    "lat": "37.27917",
    "lng": "127.4425"
  },
  {
    "country": "KR",
    "name": "Hyeonpung",
    "lat": "35.69557",
    "lng": "128.44608"
  },
  {
    "country": "KR",
    "name": "Hwasun",
    "lat": "35.06125",
    "lng": "126.98746"
  },
  {
    "country": "KR",
    "name": "Hwaseong-si",
    "lat": "37.20682",
    "lng": "126.8169"
  },
  {
    "country": "KR",
    "name": "Hwacheon",
    "lat": "38.10705",
    "lng": "127.70632"
  },
  {
    "country": "KR",
    "name": "Hongseong",
    "lat": "36.6009",
    "lng": "126.665"
  },
  {
    "country": "KR",
    "name": "Hongch’ŏn",
    "lat": "37.6918",
    "lng": "127.8857"
  },
  {
    "country": "KR",
    "name": "Hayang",
    "lat": "35.91333",
    "lng": "128.82"
  },
  {
    "country": "KR",
    "name": "Hancheolli",
    "lat": "34.97411",
    "lng": "127.00028"
  },
  {
    "country": "KR",
    "name": "Haenam",
    "lat": "34.57111",
    "lng": "126.59889"
  },
  {
    "country": "KR",
    "name": "Chuncheon",
    "lat": "37.87472",
    "lng": "127.73417"
  },
  {
    "country": "KR",
    "name": "Cheorwon",
    "lat": "38.20917",
    "lng": "127.2175"
  },
  {
    "country": "KR",
    "name": "Jeonju",
    "lat": "35.82194",
    "lng": "127.14889"
  },
  {
    "country": "KR",
    "name": "Cheongsong gun",
    "lat": "36.43351",
    "lng": "129.057"
  },
  {
    "country": "KR",
    "name": "Cheongpyeong",
    "lat": "37.7355",
    "lng": "127.4174"
  },
  {
    "country": "KR",
    "name": "Jeongok",
    "lat": "38.02596",
    "lng": "127.07021"
  },
  {
    "country": "KR",
    "name": "Cheongju-si",
    "lat": "36.63722",
    "lng": "127.48972"
  },
  {
    "country": "KR",
    "name": "Cheonan",
    "lat": "36.8065",
    "lng": "127.1522"
  },
  {
    "country": "KR",
    "name": "Chinju",
    "lat": "35.19278",
    "lng": "128.08472"
  },
  {
    "country": "KR",
    "name": "Chinch'ŏn",
    "lat": "36.85667",
    "lng": "127.44333"
  },
  {
    "country": "KR",
    "name": "Jinan-gun",
    "lat": "35.79167",
    "lng": "127.42528"
  },
  {
    "country": "KR",
    "name": "Jido",
    "lat": "35.06132",
    "lng": "126.20753"
  },
  {
    "country": "KR",
    "name": "Jeju City",
    "lat": "33.50972",
    "lng": "126.52194"
  },
  {
    "country": "KR",
    "name": "Changwon",
    "lat": "35.22806",
    "lng": "128.68111"
  },
  {
    "country": "KR",
    "name": "Changsu",
    "lat": "35.64842",
    "lng": "127.51523"
  },
  {
    "country": "KR",
    "name": "Jangseong",
    "lat": "35.29778",
    "lng": "126.78444"
  },
  {
    "country": "KR",
    "name": "Changpyeong",
    "lat": "35.23904",
    "lng": "127.01792"
  },
  {
    "country": "KR",
    "name": "Jangheung",
    "lat": "34.68164",
    "lng": "126.90694"
  },
  {
    "country": "KR",
    "name": "Jangan",
    "lat": "35.31296",
    "lng": "129.24244"
  },
  {
    "country": "KR",
    "name": "Anyang-si",
    "lat": "37.3925",
    "lng": "126.92694"
  },
  {
    "country": "KR",
    "name": "Anseong",
    "lat": "37.01083",
    "lng": "127.27028"
  },
  {
    "country": "KR",
    "name": "Ansan-si",
    "lat": "37.32361",
    "lng": "126.82194"
  },
  {
    "country": "KR",
    "name": "Andong",
    "lat": "36.56636",
    "lng": "128.72275"
  },
  {
    "country": "KR",
    "name": "Gaigeturi",
    "lat": "33.46444",
    "lng": "126.31833"
  },
  {
    "country": "KR",
    "name": "Sinhyeon",
    "lat": "34.8825",
    "lng": "128.62667"
  },
  {
    "country": "KR",
    "name": "Yeosu",
    "lat": "34.76062",
    "lng": "127.66215"
  },
  {
    "country": "KR",
    "name": "Gwangyang",
    "lat": "34.9414",
    "lng": "127.69569"
  },
  {
    "country": "KR",
    "name": "Illo",
    "lat": "34.85258",
    "lng": "126.48952"
  },
  {
    "country": "KR",
    "name": "Baeksu",
    "lat": "35.28401",
    "lng": "126.42038"
  },
  {
    "country": "KR",
    "name": "Hongnong",
    "lat": "35.39587",
    "lng": "126.44531"
  },
  {
    "country": "KR",
    "name": "Yŏnmu",
    "lat": "36.12944",
    "lng": "127.1"
  },
  {
    "country": "KR",
    "name": "Tonghae",
    "lat": "37.54389",
    "lng": "129.10694"
  },
  {
    "country": "KR",
    "name": "Cheongha",
    "lat": "36.19797",
    "lng": "129.33911"
  },
  {
    "country": "KR",
    "name": "Ocheon",
    "lat": "35.97046",
    "lng": "129.41222"
  },
  {
    "country": "KR",
    "name": "Ilgwang",
    "lat": "35.264",
    "lng": "129.23349"
  },
  {
    "country": "KR",
    "name": "Pubal",
    "lat": "37.29167",
    "lng": "127.50778"
  },
  {
    "country": "KR",
    "name": "Seongnam-si",
    "lat": "37.43861",
    "lng": "127.13778"
  },
  {
    "country": "KR",
    "name": "Hanam",
    "lat": "37.54",
    "lng": "127.20556"
  },
  {
    "country": "KR",
    "name": "Hwado",
    "lat": "37.6525",
    "lng": "127.3075"
  },
  {
    "country": "KR",
    "name": "Namyangju",
    "lat": "37.63667",
    "lng": "127.21417"
  },
  {
    "country": "KR",
    "name": "Ungsang",
    "lat": "35.40611",
    "lng": "129.16861"
  },
  {
    "country": "KR",
    "name": "Wabu",
    "lat": "37.58972",
    "lng": "127.22028"
  },
  {
    "country": "KR",
    "name": "Naesŏ",
    "lat": "35.24972",
    "lng": "128.52"
  },
  {
    "country": "KR",
    "name": "Hwawŏn",
    "lat": "35.80167",
    "lng": "128.50083"
  },
  {
    "country": "KR",
    "name": "Kwangmyŏng",
    "lat": "37.47722",
    "lng": "126.86639"
  },
  {
    "country": "KR",
    "name": "Paju",
    "lat": "37.83278",
    "lng": "126.81694"
  },
  {
    "country": "KR",
    "name": "Sinan",
    "lat": "34.8262",
    "lng": "126.10863"
  },
  {
    "country": "KR",
    "name": "Seogwipo",
    "lat": "33.25333",
    "lng": "126.56181"
  },
  {
    "country": "KR",
    "name": "Yongsan-dong",
    "lat": "37.5445",
    "lng": "126.9837"
  },
  {
    "country": "KR",
    "name": "Sannae",
    "lat": "35.56782",
    "lng": "127.03012"
  },
  {
    "country": "KR",
    "name": "Singwang",
    "lat": "36.12911",
    "lng": "129.2636"
  },
  {
    "country": "KR",
    "name": "Songgangdong",
    "lat": "36.43406",
    "lng": "127.37559"
  },
  {
    "country": "KR",
    "name": "Daehap",
    "lat": "35.61365",
    "lng": "128.47165"
  },
  {
    "country": "KR",
    "name": "Changnyeong",
    "lat": "35.54145",
    "lng": "128.49506"
  },
  {
    "country": "KR",
    "name": "Songhae",
    "lat": "37.7636",
    "lng": "126.46577"
  },
  {
    "country": "KR",
    "name": "Hajeom",
    "lat": "37.77419",
    "lng": "126.41226"
  },
  {
    "country": "KR",
    "name": "Yangsa",
    "lat": "37.79872",
    "lng": "126.408"
  },
  {
    "country": "KR",
    "name": "Samsan",
    "lat": "37.70306",
    "lng": "126.32136"
  },
  {
    "country": "KR",
    "name": "Seonwon",
    "lat": "37.71223",
    "lng": "126.48439"
  },
  {
    "country": "KR",
    "name": "Wolgot",
    "lat": "37.71646",
    "lng": "126.55429"
  },
  {
    "country": "KR",
    "name": "Haseong",
    "lat": "37.71953",
    "lng": "126.63107"
  },
  {
    "country": "KR",
    "name": "Tongjin",
    "lat": "37.69191",
    "lng": "126.59855"
  },
  {
    "country": "KR",
    "name": "Gyodong",
    "lat": "37.78272",
    "lng": "126.28117"
  },
  {
    "country": "KR",
    "name": "Gwangtan",
    "lat": "37.78055",
    "lng": "126.85004"
  },
  {
    "country": "KR",
    "name": "Jangheung",
    "lat": "37.71727",
    "lng": "126.94122"
  },
  {
    "country": "KR",
    "name": "Tanhyeon",
    "lat": "37.8024",
    "lng": "126.71598"
  },
  {
    "country": "KR",
    "name": "Gwangjeok",
    "lat": "37.82566",
    "lng": "126.98349"
  },
  {
    "country": "KR",
    "name": "Su-dong",
    "lat": "37.70353",
    "lng": "127.3258"
  },
  {
    "country": "KR",
    "name": "Sindong",
    "lat": "37.81735",
    "lng": "127.71656"
  },
  {
    "country": "KR",
    "name": "Dongnae",
    "lat": "37.84747",
    "lng": "127.76164"
  },
  {
    "country": "KR",
    "name": "Seoseok",
    "lat": "37.7119",
    "lng": "128.18713"
  },
  {
    "country": "KR",
    "name": "Jinjeop",
    "lat": "37.72722",
    "lng": "127.18992"
  },
  {
    "country": "KR",
    "name": "Onam",
    "lat": "37.69834",
    "lng": "127.20579"
  },
  {
    "country": "KR",
    "name": "Haean",
    "lat": "38.28634",
    "lng": "128.13774"
  },
  {
    "country": "KR",
    "name": "Toseong",
    "lat": "38.25679",
    "lng": "128.55968"
  },
  {
    "country": "KR",
    "name": "Sinseo",
    "lat": "38.18561",
    "lng": "127.10819"
  },
  {
    "country": "KR",
    "name": "Gwanin",
    "lat": "38.15921",
    "lng": "127.24935"
  },
  {
    "country": "KR",
    "name": "Bangsan",
    "lat": "38.2088",
    "lng": "127.95028"
  },
  {
    "country": "KR",
    "name": "Dongmyeon",
    "lat": "38.20135",
    "lng": "128.04327"
  },
  {
    "country": "KR",
    "name": "Yeonsan",
    "lat": "36.21376",
    "lng": "127.20004"
  },
  {
    "country": "KR",
    "name": "Sejong",
    "lat": "36.59245",
    "lng": "127.29223"
  },
  {
    "country": "KR",
    "name": "Bupyeong",
    "lat": "37.50533",
    "lng": "126.72202"
  },
  {
    "country": "KR",
    "name": "Boseong",
    "lat": "34.77148",
    "lng": "127.07996"
  },
  {
    "country": "KR",
    "name": "Jeongeup",
    "lat": "35.60004",
    "lng": "126.91699"
  },
  {
    "country": "KR",
    "name": "Hwayang",
    "lat": "34.70846",
    "lng": "127.6134"
  },
  {
    "country": "KR",
    "name": "Nammyeon",
    "lat": "34.77247",
    "lng": "127.88668"
  },
  {
    "country": "KR",
    "name": "Mijo",
    "lat": "34.7128",
    "lng": "128.04605"
  },
  {
    "country": "KR",
    "name": "Palgeum",
    "lat": "34.78566",
    "lng": "126.14288"
  },
  {
    "country": "KR",
    "name": "Apae",
    "lat": "34.86689",
    "lng": "126.31279"
  },
  {
    "country": "KR",
    "name": "Sinan",
    "lat": "34.83394",
    "lng": "126.35133"
  },
  {
    "country": "KR",
    "name": "Bannam",
    "lat": "34.90444",
    "lng": "126.65175"
  },
  {
    "country": "KR",
    "name": "Dopo",
    "lat": "34.84601",
    "lng": "126.64367"
  },
  {
    "country": "KR",
    "name": "Deokjin",
    "lat": "34.81951",
    "lng": "126.69688"
  },
  {
    "country": "KR",
    "name": "Seji",
    "lat": "34.92007",
    "lng": "126.7494"
  },
  {
    "country": "KR",
    "name": "Geumjeong",
    "lat": "34.86348",
    "lng": "126.74895"
  },
  {
    "country": "KR",
    "name": "Sijong",
    "lat": "34.86886",
    "lng": "126.60706"
  },
  {
    "country": "KR",
    "name": "Yeongam",
    "lat": "34.80059",
    "lng": "126.69669"
  },
  {
    "country": "KR",
    "name": "Gangdong",
    "lat": "37.72899",
    "lng": "128.95419"
  },
  {
    "country": "KR",
    "name": "Haeryong",
    "lat": "34.91406",
    "lng": "127.53764"
  },
  {
    "country": "KR",
    "name": "Byeollyang",
    "lat": "34.87479",
    "lng": "127.45159"
  },
  {
    "country": "KR",
    "name": "Gujeong",
    "lat": "37.71904",
    "lng": "128.8799"
  },
  {
    "country": "KR",
    "name": "Yuchi",
    "lat": "34.80247",
    "lng": "126.83899"
  },
  {
    "country": "KR",
    "name": "Cheongpung",
    "lat": "34.87676",
    "lng": "126.97029"
  },
  {
    "country": "KR",
    "name": "Mundeok",
    "lat": "34.92966",
    "lng": "127.17236"
  },
  {
    "country": "KR",
    "name": "Joseong",
    "lat": "34.80915",
    "lng": "127.24754"
  },
  {
    "country": "KR",
    "name": "Oeseo",
    "lat": "34.9142",
    "lng": "127.27727"
  },
  {
    "country": "KR",
    "name": "Yureo",
    "lat": "34.87102",
    "lng": "127.18702"
  },
  {
    "country": "KR",
    "name": "Okgok",
    "lat": "34.9903",
    "lng": "127.69875"
  },
  {
    "country": "KR",
    "name": "Jinwol",
    "lat": "34.9791",
    "lng": "127.75807"
  },
  {
    "country": "KR",
    "name": "Geumseong",
    "lat": "34.96449",
    "lng": "127.79025"
  },
  {
    "country": "KR",
    "name": "Jeongnyang",
    "lat": "35.08337",
    "lng": "127.77696"
  },
  {
    "country": "KR",
    "name": "Jinsang",
    "lat": "35.02117",
    "lng": "127.71976"
  },
  {
    "country": "KR",
    "name": "Bonggang",
    "lat": "35.0117",
    "lng": "127.58128"
  },
  {
    "country": "KR",
    "name": "Ongnyong",
    "lat": "35.01766",
    "lng": "127.61925"
  },
  {
    "country": "KR",
    "name": "Sangsa",
    "lat": "34.93944",
    "lng": "127.45523"
  },
  {
    "country": "KR",
    "name": "Seungju",
    "lat": "35.01532",
    "lng": "127.3897"
  },
  {
    "country": "KR",
    "name": "Juam",
    "lat": "35.07733",
    "lng": "127.23496"
  },
  {
    "country": "KR",
    "name": "Songgwang",
    "lat": "34.97504",
    "lng": "127.26377"
  },
  {
    "country": "KR",
    "name": "Dongmyeon",
    "lat": "35.03069",
    "lng": "127.03837"
  },
  {
    "country": "KR",
    "name": "Nammyeon",
    "lat": "35.00782",
    "lng": "127.09621"
  },
  {
    "country": "KR",
    "name": "Nodong",
    "lat": "34.79802",
    "lng": "127.07073"
  },
  {
    "country": "KR",
    "name": "Miryeok",
    "lat": "34.80134",
    "lng": "127.08749"
  },
  {
    "country": "KR",
    "name": "Bongnae",
    "lat": "34.89322",
    "lng": "127.13128"
  },
  {
    "country": "KR",
    "name": "Gyeombaek",
    "lat": "34.82987",
    "lng": "127.15181"
  },
  {
    "country": "KR",
    "name": "Hadong",
    "lat": "35.068",
    "lng": "127.75147"
  },
  {
    "country": "KR",
    "name": "Haeje",
    "lat": "35.11073",
    "lng": "126.29458"
  },
  {
    "country": "KR",
    "name": "Yeomsan",
    "lat": "35.21831",
    "lng": "126.37194"
  },
  {
    "country": "KR",
    "name": "Haebo",
    "lat": "35.18122",
    "lng": "126.60102"
  },
  {
    "country": "KR",
    "name": "Nasan",
    "lat": "35.11447",
    "lng": "126.60908"
  },
  {
    "country": "KR",
    "name": "Bulgap",
    "lat": "35.20946",
    "lng": "126.50768"
  },
  {
    "country": "KR",
    "name": "Nagwol",
    "lat": "35.20248",
    "lng": "126.13757"
  },
  {
    "country": "KR",
    "name": "Imja",
    "lat": "35.08457",
    "lng": "126.11105"
  },
  {
    "country": "KR",
    "name": "Sangha",
    "lat": "35.44487",
    "lng": "126.49517"
  },
  {
    "country": "KR",
    "name": "Simwon",
    "lat": "35.52448",
    "lng": "126.55107"
  },
  {
    "country": "KR",
    "name": "Haeri",
    "lat": "35.46144",
    "lng": "126.53914"
  },
  {
    "country": "KR",
    "name": "Gunnam",
    "lat": "35.24032",
    "lng": "126.4528"
  },
  {
    "country": "KR",
    "name": "Gunseo",
    "lat": "35.25851",
    "lng": "126.47516"
  },
  {
    "country": "KR",
    "name": "Beopseong",
    "lat": "35.3627",
    "lng": "126.4462"
  },
  {
    "country": "KR",
    "name": "Gongeum",
    "lat": "35.37825",
    "lng": "126.51141"
  },
  {
    "country": "KR",
    "name": "Daesan",
    "lat": "35.34168",
    "lng": "126.60327"
  },
  {
    "country": "KR",
    "name": "Myoryang",
    "lat": "35.25755",
    "lng": "126.54315"
  },
  {
    "country": "KR",
    "name": "Daema",
    "lat": "35.30183",
    "lng": "126.57748"
  },
  {
    "country": "KR",
    "name": "Ssangchi",
    "lat": "35.50202",
    "lng": "127.00283"
  },
  {
    "country": "KR",
    "name": "Ingye",
    "lat": "35.41261",
    "lng": "127.14135"
  },
  {
    "country": "KR",
    "name": "Gurim",
    "lat": "35.4536",
    "lng": "127.10232"
  },
  {
    "country": "KR",
    "name": "Gangjin",
    "lat": "35.53034",
    "lng": "127.16357"
  },
  {
    "country": "KR",
    "name": "Donggye",
    "lat": "35.44168",
    "lng": "127.24264"
  },
  {
    "country": "KW",
    "name": "Janūb as Surrah",
    "lat": "29.26917",
    "lng": "47.97806"
  },
  {
    "country": "KW",
    "name": "Ḩawallī",
    "lat": "29.33278",
    "lng": "48.02861"
  },
  {
    "country": "KW",
    "name": "Bayān",
    "lat": "29.3032",
    "lng": "48.04881"
  },
  {
    "country": "KW",
    "name": "Az Zawr",
    "lat": "29.4425",
    "lng": "48.27472"
  },
  {
    "country": "KW",
    "name": "As Sālimīyah",
    "lat": "29.33389",
    "lng": "48.07611"
  },
  {
    "country": "KW",
    "name": "Ash Shāmīyah",
    "lat": "29.34722",
    "lng": "47.96167"
  },
  {
    "country": "KW",
    "name": "Ar Rumaythīyah",
    "lat": "29.31167",
    "lng": "48.07417"
  },
  {
    "country": "KW",
    "name": "Ar Riqqah",
    "lat": "29.14583",
    "lng": "48.09472"
  },
  {
    "country": "KW",
    "name": "Al Wafrah",
    "lat": "28.63917",
    "lng": "47.93056"
  },
  {
    "country": "KW",
    "name": "Al Manqaf",
    "lat": "29.09611",
    "lng": "48.13278"
  },
  {
    "country": "KW",
    "name": "Al Mahbūlah",
    "lat": "29.145",
    "lng": "48.13028"
  },
  {
    "country": "KW",
    "name": "Kuwait City",
    "lat": "29.36972",
    "lng": "47.97833"
  },
  {
    "country": "KW",
    "name": "Al Jahrā’",
    "lat": "29.3375",
    "lng": "47.65806"
  },
  {
    "country": "KW",
    "name": "Al Funayţīs",
    "lat": "29.22528",
    "lng": "48.10167"
  },
  {
    "country": "KW",
    "name": "Al Faḩāḩīl",
    "lat": "29.0825",
    "lng": "48.13028"
  },
  {
    "country": "KW",
    "name": "Al Finţās",
    "lat": "29.17389",
    "lng": "48.12111"
  },
  {
    "country": "KW",
    "name": "Al Farwānīyah",
    "lat": "29.2775",
    "lng": "47.95861"
  },
  {
    "country": "KW",
    "name": "Al Aḩmadī",
    "lat": "29.07694",
    "lng": "48.08389"
  },
  {
    "country": "KW",
    "name": "Ad Dasmah",
    "lat": "29.365",
    "lng": "48.00139"
  },
  {
    "country": "KW",
    "name": "Salwá",
    "lat": "29.29583",
    "lng": "48.07861"
  },
  {
    "country": "KW",
    "name": "Ar Rābiyah",
    "lat": "29.295",
    "lng": "47.93306"
  },
  {
    "country": "KW",
    "name": "Şabāḩ as Sālim",
    "lat": "29.25722",
    "lng": "48.05722"
  },
  {
    "country": "KW",
    "name": "Mubārak al Kabīr",
    "lat": "29.18979",
    "lng": "48.08716"
  },
  {
    "country": "KW",
    "name": "Al-Masayel",
    "lat": "29.2393",
    "lng": "48.08862"
  },
  {
    "country": "KW",
    "name": "Abu Fatira",
    "lat": "29.19746",
    "lng": "48.10278"
  },
  {
    "country": "KW",
    "name": "Abu Al Hasaniya",
    "lat": "29.19076",
    "lng": "48.11355"
  },
  {
    "country": "KY",
    "name": "West Bay",
    "lat": "19.36667",
    "lng": "-81.41667"
  },
  {
    "country": "KY",
    "name": "North Side",
    "lat": "19.35",
    "lng": "-81.2"
  },
  {
    "country": "KY",
    "name": "George Town",
    "lat": "19.2866",
    "lng": "-81.37436"
  },
  {
    "country": "KY",
    "name": "East End",
    "lat": "19.3",
    "lng": "-81.11667"
  },
  {
    "country": "KY",
    "name": "Bodden Town",
    "lat": "19.27647",
    "lng": "-81.2542"
  },
  {
    "country": "KY",
    "name": "Little Cayman",
    "lat": "19.66114",
    "lng": "-80.10984"
  },
  {
    "country": "KZ",
    "name": "Zhumysker",
    "lat": "49.33333",
    "lng": "49.4"
  },
  {
    "country": "KZ",
    "name": "Zhetibay",
    "lat": "43.59417",
    "lng": "52.07889"
  },
  {
    "country": "KZ",
    "name": "Zhanaozen",
    "lat": "43.34116",
    "lng": "52.86192"
  },
  {
    "country": "KZ",
    "name": "Temir",
    "lat": "49.14132",
    "lng": "57.12855"
  },
  {
    "country": "KZ",
    "name": "Taūshyq",
    "lat": "44.34678",
    "lng": "51.34932"
  },
  {
    "country": "KZ",
    "name": "Shubarshi",
    "lat": "48.58022",
    "lng": "57.18289"
  },
  {
    "country": "KZ",
    "name": "Shubarkuduk",
    "lat": "49.14391",
    "lng": "56.48196"
  },
  {
    "country": "KZ",
    "name": "Shetpe",
    "lat": "44.16667",
    "lng": "52.11667"
  },
  {
    "country": "KZ",
    "name": "Shalqar",
    "lat": "47.83333",
    "lng": "59.6"
  },
  {
    "country": "KZ",
    "name": "Shalkar",
    "lat": "48.03333",
    "lng": "48.9"
  },
  {
    "country": "KZ",
    "name": "Sayötesh",
    "lat": "44.32781",
    "lng": "53.53246"
  },
  {
    "country": "KZ",
    "name": "Saykhin",
    "lat": "48.85611",
    "lng": "46.83361"
  },
  {
    "country": "KZ",
    "name": "Peremetnoe",
    "lat": "51.19925",
    "lng": "50.85544"
  },
  {
    "country": "KZ",
    "name": "Oral",
    "lat": "51.23333",
    "lng": "51.36667"
  },
  {
    "country": "KZ",
    "name": "Kandyagash",
    "lat": "49.46912",
    "lng": "57.41914"
  },
  {
    "country": "KZ",
    "name": "Munayshy",
    "lat": "43.49111",
    "lng": "52.10861"
  },
  {
    "country": "KZ",
    "name": "Miyaly",
    "lat": "48.88504",
    "lng": "53.79194"
  },
  {
    "country": "KZ",
    "name": "Martuk",
    "lat": "50.74746",
    "lng": "56.50611"
  },
  {
    "country": "KZ",
    "name": "Maqat",
    "lat": "47.65",
    "lng": "53.31667"
  },
  {
    "country": "KZ",
    "name": "Maloye Ganyushkino",
    "lat": "46.6",
    "lng": "49.26667"
  },
  {
    "country": "KZ",
    "name": "Makhambet",
    "lat": "47.66667",
    "lng": "51.58333"
  },
  {
    "country": "KZ",
    "name": "Qulsary",
    "lat": "46.95307",
    "lng": "54.01978"
  },
  {
    "country": "KZ",
    "name": "Krūgloozernoe",
    "lat": "51.07854",
    "lng": "51.28992"
  },
  {
    "country": "KZ",
    "name": "Khromtau",
    "lat": "50.25117",
    "lng": "58.44003"
  },
  {
    "country": "KZ",
    "name": "Kaztalovka",
    "lat": "49.76612",
    "lng": "48.68903"
  },
  {
    "country": "KZ",
    "name": "Qaraton",
    "lat": "46.43528",
    "lng": "53.48639"
  },
  {
    "country": "KZ",
    "name": "Karagandy",
    "lat": "49.80187",
    "lng": "73.10211"
  },
  {
    "country": "KZ",
    "name": "Tasqala",
    "lat": "51.11073",
    "lng": "50.29454"
  },
  {
    "country": "KZ",
    "name": "Inderbor",
    "lat": "48.55",
    "lng": "51.78333"
  },
  {
    "country": "KZ",
    "name": "Fort-Shevchenko",
    "lat": "44.50654",
    "lng": "50.26388"
  },
  {
    "country": "KZ",
    "name": "Fedorovka",
    "lat": "51.22102",
    "lng": "51.95723"
  },
  {
    "country": "KZ",
    "name": "Yeraliyev",
    "lat": "43.18032",
    "lng": "51.68116"
  },
  {
    "country": "KZ",
    "name": "Embi",
    "lat": "48.82981",
    "lng": "58.15042"
  },
  {
    "country": "KZ",
    "name": "Zhänibek",
    "lat": "49.42207",
    "lng": "46.84705"
  },
  {
    "country": "KZ",
    "name": "Dzhangala",
    "lat": "49.21667",
    "lng": "50.33333"
  },
  {
    "country": "KZ",
    "name": "Dzhambeyty",
    "lat": "50.25676",
    "lng": "52.59895"
  },
  {
    "country": "KZ",
    "name": "Dossor",
    "lat": "47.52722",
    "lng": "52.98111"
  },
  {
    "country": "KZ",
    "name": "Chingirlau",
    "lat": "51.09878",
    "lng": "54.08426"
  },
  {
    "country": "KZ",
    "name": "Chapaev",
    "lat": "50.2",
    "lng": "51.16667"
  },
  {
    "country": "KZ",
    "name": "Burlin",
    "lat": "51.42724",
    "lng": "52.71392"
  },
  {
    "country": "KZ",
    "name": "Beyneu",
    "lat": "45.31667",
    "lng": "55.2"
  },
  {
    "country": "KZ",
    "name": "Bayganin",
    "lat": "48.68975",
    "lng": "55.87512"
  },
  {
    "country": "KZ",
    "name": "Bayshonas",
    "lat": "47.24139",
    "lng": "52.94111"
  },
  {
    "country": "KZ",
    "name": "Baūtīno",
    "lat": "44.54479",
    "lng": "50.24629"
  },
  {
    "country": "KZ",
    "name": "Batamshinskiy",
    "lat": "50.56022",
    "lng": "58.27715"
  },
  {
    "country": "KZ",
    "name": "Balykshi",
    "lat": "47.06667",
    "lng": "51.86667"
  },
  {
    "country": "KZ",
    "name": "Atyrau",
    "lat": "47.11667",
    "lng": "51.88333"
  },
  {
    "country": "KZ",
    "name": "Aktobe",
    "lat": "50.27969",
    "lng": "57.20718"
  },
  {
    "country": "KZ",
    "name": "Aktau",
    "lat": "43.65",
    "lng": "51.16667"
  },
  {
    "country": "KZ",
    "name": "Aqsay",
    "lat": "51.1681",
    "lng": "52.99782"
  },
  {
    "country": "KZ",
    "name": "Akkol’",
    "lat": "48.77177",
    "lng": "53.1858"
  },
  {
    "country": "KZ",
    "name": "Ömirzaq",
    "lat": "43.59786",
    "lng": "51.24171"
  },
  {
    "country": "KZ",
    "name": "Zyryanovsk",
    "lat": "49.72654",
    "lng": "84.27318"
  },
  {
    "country": "KZ",
    "name": "Zhosaly",
    "lat": "45.48778",
    "lng": "64.07806"
  },
  {
    "country": "KZ",
    "name": "Zholymbet",
    "lat": "51.74211",
    "lng": "71.71245"
  },
  {
    "country": "KZ",
    "name": "Zhezqazghan",
    "lat": "47.78333",
    "lng": "67.76667"
  },
  {
    "country": "KZ",
    "name": "Zhezkent",
    "lat": "50.93112",
    "lng": "81.3615"
  },
  {
    "country": "KZ",
    "name": "Dzhetygara",
    "lat": "52.19019",
    "lng": "61.19894"
  },
  {
    "country": "KZ",
    "name": "Zhelezinka",
    "lat": "53.5388",
    "lng": "75.31326"
  },
  {
    "country": "KZ",
    "name": "Zharyk",
    "lat": "48.85692",
    "lng": "72.83598"
  },
  {
    "country": "KZ",
    "name": "Zhangatas",
    "lat": "43.56222",
    "lng": "69.73428"
  },
  {
    "country": "KZ",
    "name": "Ayteke Bi",
    "lat": "45.84607",
    "lng": "62.15264"
  },
  {
    "country": "KZ",
    "name": "Taraz",
    "lat": "42.9",
    "lng": "71.36667"
  },
  {
    "country": "KZ",
    "name": "Zhalghyztobe",
    "lat": "49.21094",
    "lng": "81.21596"
  },
  {
    "country": "KZ",
    "name": "Zhaqsy",
    "lat": "51.91058",
    "lng": "67.31665"
  },
  {
    "country": "KZ",
    "name": "Zaysan",
    "lat": "47.46657",
    "lng": "84.87144"
  },
  {
    "country": "KZ",
    "name": "Yrghyz",
    "lat": "48.61667",
    "lng": "61.26667"
  },
  {
    "country": "KZ",
    "name": "Yavlenka",
    "lat": "54.34525",
    "lng": "68.4574"
  },
  {
    "country": "KZ",
    "name": "Yanykurgan",
    "lat": "43.90652",
    "lng": "67.24637"
  },
  {
    "country": "KZ",
    "name": "Volodarskoye",
    "lat": "53.2927",
    "lng": "68.105"
  },
  {
    "country": "KZ",
    "name": "Verkhniye Kayrakty",
    "lat": "48.68333",
    "lng": "73.28333"
  },
  {
    "country": "KZ",
    "name": "Turar Ryskulov",
    "lat": "42.5334",
    "lng": "70.3496"
  },
  {
    "country": "KZ",
    "name": "Ūst’-Talovka",
    "lat": "50.54927",
    "lng": "81.84997"
  },
  {
    "country": "KZ",
    "name": "Ush-Tyube",
    "lat": "45.25201",
    "lng": "77.98007"
  },
  {
    "country": "KZ",
    "name": "Urzhar",
    "lat": "47.09302",
    "lng": "81.62939"
  },
  {
    "country": "KZ",
    "name": "Turkestan",
    "lat": "43.29733",
    "lng": "68.25175"
  },
  {
    "country": "KZ",
    "name": "Turgen",
    "lat": "43.40056",
    "lng": "77.59333"
  },
  {
    "country": "KZ",
    "name": "Timiryazevo",
    "lat": "53.74947",
    "lng": "66.48852"
  },
  {
    "country": "KZ",
    "name": "Troyebratskiy",
    "lat": "54.44306",
    "lng": "66.07982"
  },
  {
    "country": "KZ",
    "name": "Torghay",
    "lat": "49.63389",
    "lng": "63.49806"
  },
  {
    "country": "KZ",
    "name": "Tokarevka",
    "lat": "50.11573",
    "lng": "73.16034"
  },
  {
    "country": "KZ",
    "name": "Tobol",
    "lat": "52.69366",
    "lng": "62.5914"
  },
  {
    "country": "KZ",
    "name": "Terenozek",
    "lat": "45.05053",
    "lng": "64.98395"
  },
  {
    "country": "KZ",
    "name": "Temirtau",
    "lat": "50.05494",
    "lng": "72.96464"
  },
  {
    "country": "KZ",
    "name": "Temirlanovka",
    "lat": "42.59998",
    "lng": "69.25836"
  },
  {
    "country": "KZ",
    "name": "Tekeli",
    "lat": "44.83322",
    "lng": "78.83089"
  },
  {
    "country": "KZ",
    "name": "Tasböget",
    "lat": "44.77384",
    "lng": "65.55227"
  },
  {
    "country": "KZ",
    "name": "Taranovskoye",
    "lat": "52.83554",
    "lng": "62.52078"
  },
  {
    "country": "KZ",
    "name": "Talshik",
    "lat": "53.63736",
    "lng": "71.87404"
  },
  {
    "country": "KZ",
    "name": "Talghar",
    "lat": "43.30348",
    "lng": "77.24085"
  },
  {
    "country": "KZ",
    "name": "Taldykorgan",
    "lat": "45.01556",
    "lng": "78.37389"
  },
  {
    "country": "KZ",
    "name": "Suykbulak",
    "lat": "49.70837",
    "lng": "81.04854"
  },
  {
    "country": "KZ",
    "name": "Stepnyak",
    "lat": "52.83489",
    "lng": "70.78861"
  },
  {
    "country": "KZ",
    "name": "Smirnovo",
    "lat": "54.5148",
    "lng": "69.42732"
  },
  {
    "country": "KZ",
    "name": "Myrzakent",
    "lat": "40.66338",
    "lng": "68.5451"
  },
  {
    "country": "KZ",
    "name": "Shymkent",
    "lat": "42.3",
    "lng": "69.6"
  },
  {
    "country": "KZ",
    "name": "Chu",
    "lat": "43.60334",
    "lng": "73.75919"
  },
  {
    "country": "KZ",
    "name": "Shortandy",
    "lat": "51.69946",
    "lng": "70.99457"
  },
  {
    "country": "KZ",
    "name": "Shemonaīkha",
    "lat": "50.62811",
    "lng": "81.91213"
  },
  {
    "country": "KZ",
    "name": "Shchuchinsk",
    "lat": "52.93592",
    "lng": "70.18895"
  },
  {
    "country": "KZ",
    "name": "Shar",
    "lat": "49.5872",
    "lng": "81.04883"
  },
  {
    "country": "KZ",
    "name": "Shantobe",
    "lat": "52.45376",
    "lng": "68.17475"
  },
  {
    "country": "KZ",
    "name": "Shakhtinsk",
    "lat": "49.70885",
    "lng": "72.59212"
  },
  {
    "country": "KZ",
    "name": "Shakhan",
    "lat": "49.81958",
    "lng": "72.65407"
  },
  {
    "country": "KZ",
    "name": "Sergeyevka",
    "lat": "53.88139",
    "lng": "67.40882"
  },
  {
    "country": "KZ",
    "name": "Semey",
    "lat": "50.42675",
    "lng": "80.26669"
  },
  {
    "country": "KZ",
    "name": "Sayram",
    "lat": "42.3025",
    "lng": "69.75758"
  },
  {
    "country": "KZ",
    "name": "Sayaq",
    "lat": "47",
    "lng": "77.26667"
  },
  {
    "country": "KZ",
    "name": "Sastobe",
    "lat": "42.5533",
    "lng": "69.99835"
  },
  {
    "country": "KZ",
    "name": "Saryshaghan",
    "lat": "46.11917",
    "lng": "73.61917"
  },
  {
    "country": "KZ",
    "name": "Saryozek",
    "lat": "44.36178",
    "lng": "77.97279"
  },
  {
    "country": "KZ",
    "name": "Sarykamys",
    "lat": "47.78333",
    "lng": "78.71667"
  },
  {
    "country": "KZ",
    "name": "Saryaghash",
    "lat": "41.46042",
    "lng": "69.16791"
  },
  {
    "country": "KZ",
    "name": "Sarkand",
    "lat": "45.41126",
    "lng": "79.91545"
  },
  {
    "country": "KZ",
    "name": "Soran",
    "lat": "49.7908",
    "lng": "72.83744"
  },
  {
    "country": "KZ",
    "name": "Sekseūil",
    "lat": "47.09",
    "lng": "61.15194"
  },
  {
    "country": "KZ",
    "name": "Rudnyy",
    "lat": "52.9729",
    "lng": "63.11677"
  },
  {
    "country": "KZ",
    "name": "Kyzylorda",
    "lat": "44.85278",
    "lng": "65.50917"
  },
  {
    "country": "KZ",
    "name": "Qusmuryn",
    "lat": "52.45107",
    "lng": "64.61977"
  },
  {
    "country": "KZ",
    "name": "Kostanay",
    "lat": "53.21435",
    "lng": "63.62463"
  },
  {
    "country": "KZ",
    "name": "Qashar",
    "lat": "53.36799",
    "lng": "62.86839"
  },
  {
    "country": "KZ",
    "name": "Qarqaraly",
    "lat": "49.41287",
    "lng": "75.47286"
  },
  {
    "country": "KZ",
    "name": "Qarazhal",
    "lat": "48.00627",
    "lng": "70.79607"
  },
  {
    "country": "KZ",
    "name": "Qaraūyl",
    "lat": "48.94509",
    "lng": "79.25502"
  },
  {
    "country": "KZ",
    "name": "Karatau",
    "lat": "43.17869",
    "lng": "70.46768"
  },
  {
    "country": "KZ",
    "name": "Kapshagay",
    "lat": "43.86681",
    "lng": "77.06304"
  },
  {
    "country": "KZ",
    "name": "Tūghyl",
    "lat": "47.72521",
    "lng": "84.20629"
  },
  {
    "country": "KZ",
    "name": "Petropavl",
    "lat": "54.86667",
    "lng": "69.15"
  },
  {
    "country": "KZ",
    "name": "Pervorosiyskiy",
    "lat": "49.7165",
    "lng": "83.8492"
  },
  {
    "country": "KZ",
    "name": "Pervomayka",
    "lat": "43.37361",
    "lng": "76.94"
  },
  {
    "country": "KZ",
    "name": "Pavlodar",
    "lat": "52.28333",
    "lng": "76.96667"
  },
  {
    "country": "KZ",
    "name": "Zharkent",
    "lat": "44.1666",
    "lng": "80.00655"
  },
  {
    "country": "KZ",
    "name": "Oytal",
    "lat": "42.90573",
    "lng": "73.26972"
  },
  {
    "country": "KZ",
    "name": "Ust-Kamenogorsk",
    "lat": "49.97143",
    "lng": "82.60586"
  },
  {
    "country": "KZ",
    "name": "Osakarovka",
    "lat": "50.56219",
    "lng": "72.57089"
  },
  {
    "country": "KZ",
    "name": "Ordzhonikidze",
    "lat": "52.44772",
    "lng": "61.74942"
  },
  {
    "country": "KZ",
    "name": "Ognevka",
    "lat": "49.68351",
    "lng": "83.01674"
  },
  {
    "country": "KZ",
    "name": "Zhabagly",
    "lat": "42.43781",
    "lng": "70.47841"
  },
  {
    "country": "KZ",
    "name": "Novodolinskiy",
    "lat": "49.7065",
    "lng": "72.70807"
  },
  {
    "country": "KZ",
    "name": "Zhanga Buqtyrma",
    "lat": "49.6295",
    "lng": "83.52475"
  },
  {
    "country": "KZ",
    "name": "Narynkol",
    "lat": "42.72636",
    "lng": "80.17495"
  },
  {
    "country": "KZ",
    "name": "Mynaral",
    "lat": "45.41611",
    "lng": "73.68444"
  },
  {
    "country": "KZ",
    "name": "Moyynty",
    "lat": "47.22111",
    "lng": "73.36694"
  },
  {
    "country": "KZ",
    "name": "Kurchatov",
    "lat": "50.75617",
    "lng": "78.54188"
  },
  {
    "country": "KZ",
    "name": "Mikhaylovka",
    "lat": "43",
    "lng": "71.5"
  },
  {
    "country": "KZ",
    "name": "Merke",
    "lat": "42.86976",
    "lng": "73.18463"
  },
  {
    "country": "KZ",
    "name": "Mayqayyng",
    "lat": "51.45981",
    "lng": "75.80232"
  },
  {
    "country": "KZ",
    "name": "Matay",
    "lat": "45.895",
    "lng": "78.71806"
  },
  {
    "country": "KZ",
    "name": "Makinsk",
    "lat": "52.6329",
    "lng": "70.41911"
  },
  {
    "country": "KZ",
    "name": "Lugovoye",
    "lat": "42.9101",
    "lng": "72.72066"
  },
  {
    "country": "KZ",
    "name": "Lugovoy",
    "lat": "42.94197",
    "lng": "72.76098"
  },
  {
    "country": "KZ",
    "name": "Lisakovsk",
    "lat": "52.54707",
    "lng": "62.49987"
  },
  {
    "country": "KZ",
    "name": "Lepsy",
    "lat": "46.235",
    "lng": "78.94556"
  },
  {
    "country": "KZ",
    "name": "Leninskoye",
    "lat": "41.7564",
    "lng": "69.3839"
  },
  {
    "country": "KZ",
    "name": "Leninskiy",
    "lat": "52.25346",
    "lng": "76.78211"
  },
  {
    "country": "KZ",
    "name": "Baikonur",
    "lat": "45.61667",
    "lng": "63.31667"
  },
  {
    "country": "KZ",
    "name": "Ridder",
    "lat": "50.34413",
    "lng": "83.51287"
  },
  {
    "country": "KZ",
    "name": "Lenger",
    "lat": "42.18152",
    "lng": "69.88582"
  },
  {
    "country": "KZ",
    "name": "Kzyltu",
    "lat": "53.63589",
    "lng": "72.34079"
  },
  {
    "country": "KZ",
    "name": "Kyzylzhar",
    "lat": "49.98197",
    "lng": "72.60761"
  },
  {
    "country": "KZ",
    "name": "Kushoky",
    "lat": "50.23091",
    "lng": "73.40146"
  },
  {
    "country": "KZ",
    "name": "Kurchum",
    "lat": "48.56603",
    "lng": "83.66146"
  },
  {
    "country": "KZ",
    "name": "Egindiköl",
    "lat": "51.05412",
    "lng": "69.47928"
  },
  {
    "country": "KZ",
    "name": "Krasnogorskiy",
    "lat": "52.2456",
    "lng": "66.52081"
  },
  {
    "country": "KZ",
    "name": "Taiynsha",
    "lat": "53.84796",
    "lng": "69.76773"
  },
  {
    "country": "KZ",
    "name": "Kokshetau",
    "lat": "53.28333",
    "lng": "69.4"
  },
  {
    "country": "KZ",
    "name": "Komsomolets",
    "lat": "53.75019",
    "lng": "62.0584"
  },
  {
    "country": "KZ",
    "name": "Kokterek",
    "lat": "42.49442",
    "lng": "70.25478"
  },
  {
    "country": "KZ",
    "name": "Koktal",
    "lat": "49.65",
    "lng": "73.51667"
  },
  {
    "country": "KZ",
    "name": "Kokpekty",
    "lat": "48.75",
    "lng": "82.4"
  },
  {
    "country": "KZ",
    "name": "Kīevka",
    "lat": "50.26212",
    "lng": "71.54839"
  },
  {
    "country": "KZ",
    "name": "Balpyk Bī",
    "lat": "44.90225",
    "lng": "78.23157"
  },
  {
    "country": "KZ",
    "name": "Asyqata",
    "lat": "40.8946",
    "lng": "68.3643"
  },
  {
    "country": "KZ",
    "name": "Khantaū",
    "lat": "44.22744",
    "lng": "73.79555"
  },
  {
    "country": "KZ",
    "name": "Kentau",
    "lat": "43.51672",
    "lng": "68.50463"
  },
  {
    "country": "KZ",
    "name": "Kegen",
    "lat": "43.02143",
    "lng": "79.22055"
  },
  {
    "country": "KZ",
    "name": "Qazaly",
    "lat": "45.76278",
    "lng": "62.1075"
  },
  {
    "country": "KZ",
    "name": "Karasu",
    "lat": "52.65995",
    "lng": "65.48421"
  },
  {
    "country": "KZ",
    "name": "Karabas",
    "lat": "46.53333",
    "lng": "76.2"
  },
  {
    "country": "KZ",
    "name": "Kantagi",
    "lat": "43.52786",
    "lng": "68.58287"
  },
  {
    "country": "KZ",
    "name": "Kalkaman",
    "lat": "51.95349",
    "lng": "76.02723"
  },
  {
    "country": "KZ",
    "name": "Qashyr",
    "lat": "53.06649",
    "lng": "76.10489"
  },
  {
    "country": "KZ",
    "name": "Esik",
    "lat": "43.3552",
    "lng": "77.45245"
  },
  {
    "country": "KZ",
    "name": "Irtyshsk",
    "lat": "53.33365",
    "lng": "75.45775"
  },
  {
    "country": "KZ",
    "name": "Atakent",
    "lat": "40.84782",
    "lng": "68.50643"
  },
  {
    "country": "KZ",
    "name": "Granitogorsk",
    "lat": "42.744",
    "lng": "73.46848"
  },
  {
    "country": "KZ",
    "name": "Glubokoye",
    "lat": "50.13887",
    "lng": "82.31114"
  },
  {
    "country": "KZ",
    "name": "Georgiyevka",
    "lat": "43.03882",
    "lng": "74.71287"
  },
  {
    "country": "KZ",
    "name": "Georgīevka",
    "lat": "49.32671",
    "lng": "81.57373"
  },
  {
    "country": "KZ",
    "name": "Moyynkum",
    "lat": "44.28461",
    "lng": "72.9392"
  },
  {
    "country": "KZ",
    "name": "Fyodorovka",
    "lat": "53.63809",
    "lng": "62.69653"
  },
  {
    "country": "KZ",
    "name": "Esil",
    "lat": "51.95495",
    "lng": "66.40841"
  },
  {
    "country": "KZ",
    "name": "Aksu",
    "lat": "52.04023",
    "lng": "76.92748"
  },
  {
    "country": "KZ",
    "name": "Yermentau",
    "lat": "51.62364",
    "lng": "73.10265"
  },
  {
    "country": "KZ",
    "name": "Otegen Batyra",
    "lat": "43.41949",
    "lng": "77.0202"
  },
  {
    "country": "KZ",
    "name": "Ekibastuz",
    "lat": "51.72371",
    "lng": "75.32287"
  },
  {
    "country": "KZ",
    "name": "Zhambyl",
    "lat": "47.20694",
    "lng": "71.39694"
  },
  {
    "country": "KZ",
    "name": "Dzhalagash",
    "lat": "45.08333",
    "lng": "64.66667"
  },
  {
    "country": "KZ",
    "name": "Druzhba",
    "lat": "45.25332",
    "lng": "82.48044"
  },
  {
    "country": "KZ",
    "name": "Dolinka",
    "lat": "49.67685",
    "lng": "72.67822"
  },
  {
    "country": "KZ",
    "name": "Derzhavīnsk",
    "lat": "51.09922",
    "lng": "66.31557"
  },
  {
    "country": "KZ",
    "name": "Chulakkurgan",
    "lat": "43.76453",
    "lng": "69.17856"
  },
  {
    "country": "KZ",
    "name": "Shīeli",
    "lat": "44.16882",
    "lng": "66.73887"
  },
  {
    "country": "KZ",
    "name": "Chayan",
    "lat": "43.03399",
    "lng": "69.38048"
  },
  {
    "country": "KZ",
    "name": "Chardara",
    "lat": "41.25832",
    "lng": "67.96991"
  },
  {
    "country": "KZ",
    "name": "Burunday",
    "lat": "43.35567",
    "lng": "76.85477"
  },
  {
    "country": "KZ",
    "name": "Bulayevo",
    "lat": "54.90596",
    "lng": "70.44155"
  },
  {
    "country": "KZ",
    "name": "Borovskoy",
    "lat": "53.7927",
    "lng": "64.18268"
  },
  {
    "country": "KZ",
    "name": "Būrabay",
    "lat": "53.08382",
    "lng": "70.31379"
  },
  {
    "country": "KZ",
    "name": "Borodulikha",
    "lat": "50.71841",
    "lng": "80.9295"
  },
  {
    "country": "KZ",
    "name": "Priisk Boko",
    "lat": "49.06028",
    "lng": "81.64528"
  },
  {
    "country": "KZ",
    "name": "Bishkul",
    "lat": "54.77763",
    "lng": "69.09951"
  },
  {
    "country": "KZ",
    "name": "Bestobe",
    "lat": "52.49795",
    "lng": "73.09592"
  },
  {
    "country": "KZ",
    "name": "Belyye Vody",
    "lat": "42.42193",
    "lng": "69.82709"
  },
  {
    "country": "KZ",
    "name": "Belousovka",
    "lat": "50.13287",
    "lng": "82.52481"
  },
  {
    "country": "KZ",
    "name": "Belogor’ye",
    "lat": "51.52983",
    "lng": "77.47146"
  },
  {
    "country": "KZ",
    "name": "Belogorskīy",
    "lat": "49.47698",
    "lng": "83.14803"
  },
  {
    "country": "KZ",
    "name": "Bayzhansay",
    "lat": "43.16708",
    "lng": "69.91459"
  },
  {
    "country": "KZ",
    "name": "Bayanaul",
    "lat": "50.79304",
    "lng": "75.70123"
  },
  {
    "country": "KZ",
    "name": "Qogham",
    "lat": "42.82774",
    "lng": "68.28074"
  },
  {
    "country": "KZ",
    "name": "Balqash",
    "lat": "46.84806",
    "lng": "74.995"
  },
  {
    "country": "KZ",
    "name": "Balkashino",
    "lat": "52.51779",
    "lng": "68.7516"
  },
  {
    "country": "KZ",
    "name": "Bakanas",
    "lat": "44.80838",
    "lng": "76.27214"
  },
  {
    "country": "KZ",
    "name": "Ayagoz",
    "lat": "47.96447",
    "lng": "80.43437"
  },
  {
    "country": "KZ",
    "name": "Auezov",
    "lat": "49.71003",
    "lng": "81.58018"
  },
  {
    "country": "KZ",
    "name": "Atbasar",
    "lat": "51.80652",
    "lng": "68.35996"
  },
  {
    "country": "KZ",
    "name": "Atasū",
    "lat": "48.68659",
    "lng": "71.64469"
  },
  {
    "country": "KZ",
    "name": "Asūbulaq",
    "lat": "49.55688",
    "lng": "83.06355"
  },
  {
    "country": "KZ",
    "name": "Astrakhan",
    "lat": "51.53092",
    "lng": "69.79684"
  },
  {
    "country": "KZ",
    "name": "Ashchysay",
    "lat": "43.5537",
    "lng": "68.89792"
  },
  {
    "country": "KZ",
    "name": "Arys",
    "lat": "42.43015",
    "lng": "68.8087"
  },
  {
    "country": "KZ",
    "name": "Arkalyk",
    "lat": "50.24915",
    "lng": "66.92027"
  },
  {
    "country": "KZ",
    "name": "Aral",
    "lat": "46.8",
    "lng": "61.66667"
  },
  {
    "country": "KZ",
    "name": "Aqtoghay",
    "lat": "46.95",
    "lng": "79.66667"
  },
  {
    "country": "KZ",
    "name": "Aktau",
    "lat": "50.23466",
    "lng": "73.06662"
  },
  {
    "country": "KZ",
    "name": "Aksu",
    "lat": "52.44422",
    "lng": "71.95761"
  },
  {
    "country": "KZ",
    "name": "Aqshataū",
    "lat": "47.98917",
    "lng": "74.0575"
  },
  {
    "country": "KZ",
    "name": "Astana",
    "lat": "51.1801",
    "lng": "71.44598"
  },
  {
    "country": "KZ",
    "name": "Aqadyr",
    "lat": "48.26014",
    "lng": "72.85851"
  },
  {
    "country": "KZ",
    "name": "Almaty",
    "lat": "43.25667",
    "lng": "76.92861"
  },
  {
    "country": "KZ",
    "name": "Akkol",
    "lat": "51.99374",
    "lng": "70.94704"
  },
  {
    "country": "KZ",
    "name": "Prigorodnoye",
    "lat": "49.69244",
    "lng": "75.58438"
  },
  {
    "country": "KZ",
    "name": "Aktogay",
    "lat": "48.16667",
    "lng": "75.3"
  },
  {
    "country": "KZ",
    "name": "Aktau",
    "lat": "48.03333",
    "lng": "72.83333"
  },
  {
    "country": "KZ",
    "name": "Aktas",
    "lat": "49.77952",
    "lng": "72.96128"
  },
  {
    "country": "KZ",
    "name": "Aksu-Ayuly",
    "lat": "48.76788",
    "lng": "73.67272"
  },
  {
    "country": "KZ",
    "name": "Aksuat",
    "lat": "48.71667",
    "lng": "83.7"
  },
  {
    "country": "KZ",
    "name": "Akkol’",
    "lat": "53.29617",
    "lng": "69.59997"
  },
  {
    "country": "KZ",
    "name": "Aqbaqay",
    "lat": "45",
    "lng": "72.78333"
  },
  {
    "country": "KZ",
    "name": "Abay",
    "lat": "49.63575",
    "lng": "72.86164"
  },
  {
    "country": "KZ",
    "name": "Shalqīya",
    "lat": "44.00947",
    "lng": "67.41062"
  },
  {
    "country": "KZ",
    "name": "Birlestik",
    "lat": "53.58414",
    "lng": "68.35382"
  },
  {
    "country": "KZ",
    "name": "Maleyevsk",
    "lat": "49.81441",
    "lng": "84.29102"
  },
  {
    "country": "KZ",
    "name": "Belköl",
    "lat": "44.81162",
    "lng": "65.58796"
  },
  {
    "country": "KZ",
    "name": "Novoishimskiy",
    "lat": "53.19806",
    "lng": "66.76944"
  },
  {
    "country": "KZ",
    "name": "Shashūbay",
    "lat": "46.81694",
    "lng": "75.04028"
  },
  {
    "country": "KZ",
    "name": "Shyghanaq",
    "lat": "44.83056",
    "lng": "70.00194"
  },
  {
    "country": "KZ",
    "name": "Shubarköl",
    "lat": "48.88222",
    "lng": "68.80722"
  },
  {
    "country": "KZ",
    "name": "Stepnogorsk",
    "lat": "52.35062",
    "lng": "71.88161"
  },
  {
    "country": "KZ",
    "name": "Zavodskoy",
    "lat": "52.47031",
    "lng": "72.01514"
  },
  {
    "country": "KZ",
    "name": "Ülken",
    "lat": "45.21194",
    "lng": "73.97861"
  },
  {
    "country": "KZ",
    "name": "Altayskiy",
    "lat": "50.24593",
    "lng": "82.36252"
  },
  {
    "country": "KZ",
    "name": "Chemolgan",
    "lat": "43.37633",
    "lng": "76.62456"
  },
  {
    "country": "KZ",
    "name": "Priozersk",
    "lat": "46.03106",
    "lng": "73.70247"
  },
  {
    "country": "KZ",
    "name": "Tyuratam",
    "lat": "45.65005",
    "lng": "63.31163"
  },
  {
    "country": "KZ",
    "name": "Kyzyl-Orda",
    "lat": "44.8479",
    "lng": "65.49989"
  },
  {
    "country": "LA",
    "name": "Vientiane",
    "lat": "17.96667",
    "lng": "102.6"
  },
  {
    "country": "LA",
    "name": "Xam Nua",
    "lat": "20.41591",
    "lng": "104.04838"
  },
  {
    "country": "LA",
    "name": "Savannakhét",
    "lat": "16.56505",
    "lng": "104.75273"
  },
  {
    "country": "LA",
    "name": "Salavan",
    "lat": "15.71652",
    "lng": "106.41744"
  },
  {
    "country": "LA",
    "name": "Phôngsali",
    "lat": "21.68372",
    "lng": "102.10536"
  },
  {
    "country": "LA",
    "name": "Pakse",
    "lat": "15.12022",
    "lng": "105.79898"
  },
  {
    "country": "LA",
    "name": "Pakkading",
    "lat": "18.32459",
    "lng": "103.99378"
  },
  {
    "country": "LA",
    "name": "Ban Xiang-Ngeun",
    "lat": "19.75859",
    "lng": "102.18232"
  },
  {
    "country": "LA",
    "name": "Muang Xay",
    "lat": "20.69229",
    "lng": "101.98368"
  },
  {
    "country": "LA",
    "name": "Sainyabuli",
    "lat": "19.25756",
    "lng": "101.71032"
  },
  {
    "country": "LA",
    "name": "Vangviang",
    "lat": "18.9235",
    "lng": "102.44784"
  },
  {
    "country": "LA",
    "name": "Ban Thatèng",
    "lat": "15.43317",
    "lng": "106.38272"
  },
  {
    "country": "LA",
    "name": "Muang Sing",
    "lat": "21.19206",
    "lng": "101.14789"
  },
  {
    "country": "LA",
    "name": "Muang Sanakham",
    "lat": "17.91006",
    "lng": "101.67348"
  },
  {
    "country": "LA",
    "name": "Phônthong",
    "lat": "15.10116",
    "lng": "105.65416"
  },
  {
    "country": "LA",
    "name": "Muang Phônsavan",
    "lat": "19.45",
    "lng": "103.21667"
  },
  {
    "country": "LA",
    "name": "Muang Phôn-Hông",
    "lat": "18.49565",
    "lng": "102.41421"
  },
  {
    "country": "LA",
    "name": "Muang Phin",
    "lat": "16.53399",
    "lng": "106.02401"
  },
  {
    "country": "LA",
    "name": "Pakxong",
    "lat": "15.18154",
    "lng": "106.23038"
  },
  {
    "country": "LA",
    "name": "Muang Pakxan",
    "lat": "18.38261",
    "lng": "103.65857"
  },
  {
    "country": "LA",
    "name": "Muang Mok",
    "lat": "18.90997",
    "lng": "104.00626"
  },
  {
    "country": "LA",
    "name": "Muang Long",
    "lat": "20.96504",
    "lng": "100.82074"
  },
  {
    "country": "LA",
    "name": "Ban Pakla",
    "lat": "20.8694",
    "lng": "102.11153"
  },
  {
    "country": "LA",
    "name": "Khoa",
    "lat": "21.07833",
    "lng": "102.50608"
  },
  {
    "country": "LA",
    "name": "Muang Không",
    "lat": "14.11785",
    "lng": "105.85469"
  },
  {
    "country": "LA",
    "name": "Thakhèk",
    "lat": "17.41027",
    "lng": "104.83068"
  },
  {
    "country": "LA",
    "name": "Muang Kènthao",
    "lat": "17.73289",
    "lng": "101.39815"
  },
  {
    "country": "LA",
    "name": "Muang Kasi",
    "lat": "19.22926",
    "lng": "102.25319"
  },
  {
    "country": "LA",
    "name": "Muang Hinboun",
    "lat": "17.591",
    "lng": "104.60388"
  },
  {
    "country": "LA",
    "name": "Luang Prabang",
    "lat": "19.88601",
    "lng": "102.13503"
  },
  {
    "country": "LA",
    "name": "Luang Namtha",
    "lat": "20.9486",
    "lng": "101.40188"
  },
  {
    "country": "LA",
    "name": "Muang Khamkeut",
    "lat": "18.22572",
    "lng": "104.73119"
  },
  {
    "country": "LA",
    "name": "Ban Dônghén",
    "lat": "16.70297",
    "lng": "105.28211"
  },
  {
    "country": "LA",
    "name": "Champasak",
    "lat": "14.89204",
    "lng": "105.87787"
  },
  {
    "country": "LA",
    "name": "Borikhan",
    "lat": "18.56286",
    "lng": "103.72671"
  },
  {
    "country": "LA",
    "name": "Lamam",
    "lat": "15.41705",
    "lng": "106.69461"
  },
  {
    "country": "LA",
    "name": "Ban Nahin",
    "lat": "18.24253",
    "lng": "104.21281"
  },
  {
    "country": "LA",
    "name": "Ban Houayxay",
    "lat": "20.27652",
    "lng": "100.41302"
  },
  {
    "country": "LA",
    "name": "Ban Hatgnao",
    "lat": "14.6803",
    "lng": "106.58212"
  },
  {
    "country": "LA",
    "name": "Ban Fangdèng",
    "lat": "14.8132",
    "lng": "106.93434"
  },
  {
    "country": "LA",
    "name": "Attapeu",
    "lat": "14.81071",
    "lng": "106.83184"
  },
  {
    "country": "LA",
    "name": "Ban Houakhoua",
    "lat": "20.2467",
    "lng": "100.45401"
  },
  {
    "country": "LA",
    "name": "Ban Namnga",
    "lat": "21.17193",
    "lng": "102.72562"
  },
  {
    "country": "LA",
    "name": "Viangxai",
    "lat": "20.40677",
    "lng": "104.22379"
  },
  {
    "country": "LA",
    "name": "Muang Nalè",
    "lat": "20.53212",
    "lng": "101.44678"
  },
  {
    "country": "LA",
    "name": "Dak Cheung",
    "lat": "15.46667",
    "lng": "107.26667"
  },
  {
    "country": "LA",
    "name": "Sanaxy",
    "lat": "15.02207",
    "lng": "107.26016"
  },
  {
    "country": "LA",
    "name": "Huameung",
    "lat": "20.14895",
    "lng": "103.85895"
  },
  {
    "country": "LA",
    "name": "Viengxay",
    "lat": "20.34222",
    "lng": "104.34464"
  },
  {
    "country": "LA",
    "name": "Xamtay",
    "lat": "19.94515",
    "lng": "104.51722"
  },
  {
    "country": "LA",
    "name": "Viengthong",
    "lat": "20.32792",
    "lng": "103.40856"
  },
  {
    "country": "LA",
    "name": "Xaysetha",
    "lat": "14.81444",
    "lng": "106.93444"
  },
  {
    "country": "LB",
    "name": "Zghartā",
    "lat": "34.39739",
    "lng": "35.89493"
  },
  {
    "country": "LB",
    "name": "Zahlé",
    "lat": "33.84675",
    "lng": "35.90203"
  },
  {
    "country": "LB",
    "name": "Tripoli",
    "lat": "34.43352",
    "lng": "35.84415"
  },
  {
    "country": "LB",
    "name": "Tyre",
    "lat": "33.27333",
    "lng": "35.19389"
  },
  {
    "country": "LB",
    "name": "Sîr ed Danniyé",
    "lat": "34.38528",
    "lng": "36.03111"
  },
  {
    "country": "LB",
    "name": "Sidon",
    "lat": "33.55751",
    "lng": "35.37148"
  },
  {
    "country": "LB",
    "name": "Ra’s Bayrūt",
    "lat": "33.9",
    "lng": "35.48333"
  },
  {
    "country": "LB",
    "name": "Marjayoûn",
    "lat": "33.36028",
    "lng": "35.59111"
  },
  {
    "country": "LB",
    "name": "Jounieh",
    "lat": "33.98083",
    "lng": "35.61778"
  },
  {
    "country": "LB",
    "name": "Joubb Jannîne",
    "lat": "33.62694",
    "lng": "35.78417"
  },
  {
    "country": "LB",
    "name": "Jbaïl",
    "lat": "34.12111",
    "lng": "35.64806"
  },
  {
    "country": "LB",
    "name": "Jezzîne",
    "lat": "33.54167",
    "lng": "35.58444"
  },
  {
    "country": "LB",
    "name": "Hâsbaïya",
    "lat": "33.39778",
    "lng": "35.685"
  },
  {
    "country": "LB",
    "name": "Halba",
    "lat": "34.54278",
    "lng": "36.07972"
  },
  {
    "country": "LB",
    "name": "Habboûch",
    "lat": "33.40729",
    "lng": "35.48169"
  },
  {
    "country": "LB",
    "name": "Bcharré",
    "lat": "34.25083",
    "lng": "36.01056"
  },
  {
    "country": "LB",
    "name": "Bent Jbaïl",
    "lat": "33.11944",
    "lng": "35.43333"
  },
  {
    "country": "LB",
    "name": "Bhamdoûn el Mhatta",
    "lat": "33.80861",
    "lng": "35.65972"
  },
  {
    "country": "LB",
    "name": "Bhamdoun",
    "lat": "33.795",
    "lng": "35.65111"
  },
  {
    "country": "LB",
    "name": "Beït ed Dîne",
    "lat": "33.69417",
    "lng": "35.58083"
  },
  {
    "country": "LB",
    "name": "Beirut",
    "lat": "33.89332",
    "lng": "35.50157"
  },
  {
    "country": "LB",
    "name": "Baalbek",
    "lat": "34.00583",
    "lng": "36.21806"
  },
  {
    "country": "LB",
    "name": "Baabda",
    "lat": "33.83389",
    "lng": "35.54417"
  },
  {
    "country": "LB",
    "name": "Ain Ebel",
    "lat": "33.11023",
    "lng": "35.40251"
  },
  {
    "country": "LB",
    "name": "En Nâqoûra",
    "lat": "33.11806",
    "lng": "35.13972"
  },
  {
    "country": "LB",
    "name": "Nabatîyé et Tahta",
    "lat": "33.37889",
    "lng": "35.48389"
  },
  {
    "country": "LB",
    "name": "Aanjar",
    "lat": "33.72778",
    "lng": "35.93111"
  },
  {
    "country": "LB",
    "name": "Amioûn",
    "lat": "34.3",
    "lng": "35.80889"
  },
  {
    "country": "LB",
    "name": "Jdaidet el Matn",
    "lat": "33.89056",
    "lng": "35.56639"
  },
  {
    "country": "LB",
    "name": "El Hermel",
    "lat": "34.39417",
    "lng": "36.38472"
  },
  {
    "country": "LB",
    "name": "Batroûn",
    "lat": "34.25528",
    "lng": "35.65806"
  },
  {
    "country": "LB",
    "name": "Aaley",
    "lat": "33.80528",
    "lng": "35.6"
  },
  {
    "country": "LB",
    "name": "Râchaïya el Ouadi",
    "lat": "33.50089",
    "lng": "35.8437"
  },
  {
    "country": "LC",
    "name": "Vieux Fort",
    "lat": "13.71667",
    "lng": "-60.95"
  },
  {
    "country": "LC",
    "name": "Soufrière",
    "lat": "13.85616",
    "lng": "-61.0566"
  },
  {
    "country": "LC",
    "name": "Praslin",
    "lat": "13.87545",
    "lng": "-60.89717"
  },
  {
    "country": "LC",
    "name": "Micoud",
    "lat": "13.81667",
    "lng": "-60.9"
  },
  {
    "country": "LC",
    "name": "Laborie",
    "lat": "13.75",
    "lng": "-60.98333"
  },
  {
    "country": "LC",
    "name": "Gros Islet",
    "lat": "14.06667",
    "lng": "-60.95"
  },
  {
    "country": "LC",
    "name": "Dennery",
    "lat": "13.89958",
    "lng": "-60.88786"
  },
  {
    "country": "LC",
    "name": "Choiseul",
    "lat": "13.77273",
    "lng": "-61.04931"
  },
  {
    "country": "LC",
    "name": "Castries",
    "lat": "13.9957",
    "lng": "-61.00614"
  },
  {
    "country": "LC",
    "name": "Canaries",
    "lat": "13.90224",
    "lng": "-61.06459"
  },
  {
    "country": "LC",
    "name": "Bisee",
    "lat": "14.02429",
    "lng": "-60.97445"
  },
  {
    "country": "LC",
    "name": "Anse La Raye",
    "lat": "13.94619",
    "lng": "-61.03879"
  },
  {
    "country": "LI",
    "name": "Vaduz",
    "lat": "47.14151",
    "lng": "9.52154"
  },
  {
    "country": "LI",
    "name": "Triesenberg",
    "lat": "47.11815",
    "lng": "9.54197"
  },
  {
    "country": "LI",
    "name": "Triesen",
    "lat": "47.10752",
    "lng": "9.52815"
  },
  {
    "country": "LI",
    "name": "Schellenberg",
    "lat": "47.23123",
    "lng": "9.54678"
  },
  {
    "country": "LI",
    "name": "Schaan",
    "lat": "47.16498",
    "lng": "9.50867"
  },
  {
    "country": "LI",
    "name": "Ruggell",
    "lat": "47.23799",
    "lng": "9.5254"
  },
  {
    "country": "LI",
    "name": "Planken",
    "lat": "47.18516",
    "lng": "9.54437"
  },
  {
    "country": "LI",
    "name": "Mauren",
    "lat": "47.21805",
    "lng": "9.5442"
  },
  {
    "country": "LI",
    "name": "Gamprin",
    "lat": "47.22038",
    "lng": "9.50935"
  },
  {
    "country": "LI",
    "name": "Eschen",
    "lat": "47.21071",
    "lng": "9.52223"
  },
  {
    "country": "LI",
    "name": "Balzers",
    "lat": "47.06665",
    "lng": "9.50251"
  },
  {
    "country": "LK",
    "name": "Welisara",
    "lat": "7.0281",
    "lng": "79.9014"
  },
  {
    "country": "LK",
    "name": "Weligama",
    "lat": "5.97501",
    "lng": "80.42968"
  },
  {
    "country": "LK",
    "name": "Wattegama",
    "lat": "6.7989",
    "lng": "81.4808"
  },
  {
    "country": "LK",
    "name": "Wattala",
    "lat": "6.9779",
    "lng": "79.8898"
  },
  {
    "country": "LK",
    "name": "Vavuniya",
    "lat": "8.7514",
    "lng": "80.4971"
  },
  {
    "country": "LK",
    "name": "Valvedditturai",
    "lat": "9.81667",
    "lng": "80.16667"
  },
  {
    "country": "LK",
    "name": "Vakarai",
    "lat": "8.13333",
    "lng": "81.43333"
  },
  {
    "country": "LK",
    "name": "Unawatuna",
    "lat": "6.0212",
    "lng": "80.2503"
  },
  {
    "country": "LK",
    "name": "Trincomalee",
    "lat": "8.5711",
    "lng": "81.2335"
  },
  {
    "country": "LK",
    "name": "Tangalle",
    "lat": "6.02338",
    "lng": "80.79738"
  },
  {
    "country": "LK",
    "name": "Talpe",
    "lat": "5.9999",
    "lng": "80.2787"
  },
  {
    "country": "LK",
    "name": "Talawakele",
    "lat": "6.9371",
    "lng": "80.6581"
  },
  {
    "country": "LK",
    "name": "Sigiriya",
    "lat": "7.94946",
    "lng": "80.75037"
  },
  {
    "country": "LK",
    "name": "Ratnapura",
    "lat": "6.68278",
    "lng": "80.39917"
  },
  {
    "country": "LK",
    "name": "Puttalam",
    "lat": "8.0362",
    "lng": "79.8283"
  },
  {
    "country": "LK",
    "name": "Polonnaruwa",
    "lat": "7.93965",
    "lng": "81.00274"
  },
  {
    "country": "LK",
    "name": "Point Pedro",
    "lat": "9.81667",
    "lng": "80.23333"
  },
  {
    "country": "LK",
    "name": "Pita Kotte",
    "lat": "6.8905",
    "lng": "79.9015"
  },
  {
    "country": "LK",
    "name": "Peliyagoda",
    "lat": "6.9685",
    "lng": "79.8836"
  },
  {
    "country": "LK",
    "name": "Panadura",
    "lat": "6.7132",
    "lng": "79.9026"
  },
  {
    "country": "LK",
    "name": "Nuwara Eliya",
    "lat": "6.97078",
    "lng": "80.78286"
  },
  {
    "country": "LK",
    "name": "Negombo",
    "lat": "7.2083",
    "lng": "79.8358"
  },
  {
    "country": "LK",
    "name": "Mulleriyawa",
    "lat": "6.933",
    "lng": "79.9297"
  },
  {
    "country": "LK",
    "name": "Dehiwala-Mount Lavinia",
    "lat": "6.84019",
    "lng": "79.87116"
  },
  {
    "country": "LK",
    "name": "Moratuwa",
    "lat": "6.773",
    "lng": "79.8816"
  },
  {
    "country": "LK",
    "name": "Monaragala",
    "lat": "6.8714",
    "lng": "81.3487"
  },
  {
    "country": "LK",
    "name": "Minuwangoda",
    "lat": "7.1663",
    "lng": "79.9533"
  },
  {
    "country": "LK",
    "name": "Mihintale",
    "lat": "8.3593",
    "lng": "80.5103"
  },
  {
    "country": "LK",
    "name": "Matara",
    "lat": "5.94851",
    "lng": "80.53528"
  },
  {
    "country": "LK",
    "name": "Matale",
    "lat": "7.4698",
    "lng": "80.6217"
  },
  {
    "country": "LK",
    "name": "Maharagama",
    "lat": "6.848",
    "lng": "79.9265"
  },
  {
    "country": "LK",
    "name": "Kurunegala",
    "lat": "7.4863",
    "lng": "80.3623"
  },
  {
    "country": "LK",
    "name": "Kuliyapitiya",
    "lat": "7.4688",
    "lng": "80.0401"
  },
  {
    "country": "LK",
    "name": "Sri Jayewardenepura Kotte",
    "lat": "6.88297",
    "lng": "79.90708"
  },
  {
    "country": "LK",
    "name": "Kotikawatta",
    "lat": "6.9269",
    "lng": "79.9095"
  },
  {
    "country": "LK",
    "name": "Kolonnawa",
    "lat": "6.9329",
    "lng": "79.8848"
  },
  {
    "country": "LK",
    "name": "Koggala",
    "lat": "5.9886",
    "lng": "80.3286"
  },
  {
    "country": "LK",
    "name": "Kilinochchi",
    "lat": "9.3961",
    "lng": "80.3982"
  },
  {
    "country": "LK",
    "name": "Kelaniya",
    "lat": "6.9553",
    "lng": "79.922"
  },
  {
    "country": "LK",
    "name": "Kegalle",
    "lat": "7.2523",
    "lng": "80.3436"
  },
  {
    "country": "LK",
    "name": "Katunayaka",
    "lat": "7.16992",
    "lng": "79.88837"
  },
  {
    "country": "LK",
    "name": "Kataragama",
    "lat": "6.4134",
    "lng": "81.3346"
  },
  {
    "country": "LK",
    "name": "Kandy",
    "lat": "7.2955",
    "lng": "80.6356"
  },
  {
    "country": "LK",
    "name": "Kandana",
    "lat": "7.048",
    "lng": "79.8937"
  },
  {
    "country": "LK",
    "name": "Kalutara",
    "lat": "6.5831",
    "lng": "79.9593"
  },
  {
    "country": "LK",
    "name": "Kalmunai",
    "lat": "7.40902",
    "lng": "81.83472"
  },
  {
    "country": "LK",
    "name": "Kadugannawa",
    "lat": "7.2547",
    "lng": "80.5242"
  },
  {
    "country": "LK",
    "name": "Jaffna",
    "lat": "9.66845",
    "lng": "80.00742"
  },
  {
    "country": "LK",
    "name": "Ja Ela",
    "lat": "7.0744",
    "lng": "79.8919"
  },
  {
    "country": "LK",
    "name": "Horana South",
    "lat": "6.7159",
    "lng": "80.0626"
  },
  {
    "country": "LK",
    "name": "Homagama",
    "lat": "6.844",
    "lng": "80.0024"
  },
  {
    "country": "LK",
    "name": "Hikkaduwa",
    "lat": "6.1407",
    "lng": "80.1012"
  },
  {
    "country": "LK",
    "name": "Hendala",
    "lat": "6.9909",
    "lng": "79.883"
  },
  {
    "country": "LK",
    "name": "Hatton",
    "lat": "6.8916",
    "lng": "80.5955"
  },
  {
    "country": "LK",
    "name": "Haputale",
    "lat": "6.76566",
    "lng": "80.95104"
  },
  {
    "country": "LK",
    "name": "Hanwella Ihala",
    "lat": "6.9012",
    "lng": "80.0852"
  },
  {
    "country": "LK",
    "name": "Gampola",
    "lat": "7.1643",
    "lng": "80.5696"
  },
  {
    "country": "LK",
    "name": "Gampaha",
    "lat": "7.0897",
    "lng": "79.9925"
  },
  {
    "country": "LK",
    "name": "Galle",
    "lat": "6.0367",
    "lng": "80.217"
  },
  {
    "country": "LK",
    "name": "Galkissa",
    "lat": "6.8293",
    "lng": "79.863"
  },
  {
    "country": "LK",
    "name": "Eravur Town",
    "lat": "7.7782",
    "lng": "81.6038"
  },
  {
    "country": "LK",
    "name": "Ella Town",
    "lat": "6.8756",
    "lng": "81.0463"
  },
  {
    "country": "LK",
    "name": "Dambulla",
    "lat": "7.86",
    "lng": "80.65167"
  },
  {
    "country": "LK",
    "name": "Colombo",
    "lat": "6.93194",
    "lng": "79.84778"
  },
  {
    "country": "LK",
    "name": "Chilaw",
    "lat": "7.57583",
    "lng": "79.79528"
  },
  {
    "country": "LK",
    "name": "Beruwala",
    "lat": "6.4788",
    "lng": "79.9828"
  },
  {
    "country": "LK",
    "name": "Bentota",
    "lat": "6.42598",
    "lng": "79.99575"
  },
  {
    "country": "LK",
    "name": "Batticaloa",
    "lat": "7.7102",
    "lng": "81.6924"
  },
  {
    "country": "LK",
    "name": "Battaramulla South",
    "lat": "6.8964",
    "lng": "79.9181"
  },
  {
    "country": "LK",
    "name": "Badulla",
    "lat": "6.9895",
    "lng": "81.0557"
  },
  {
    "country": "LK",
    "name": "Anuradhapura",
    "lat": "8.31223",
    "lng": "80.41306"
  },
  {
    "country": "LK",
    "name": "Ampara",
    "lat": "7.29754",
    "lng": "81.68202"
  },
  {
    "country": "LK",
    "name": "Ambalangoda",
    "lat": "6.2355",
    "lng": "80.0538"
  },
  {
    "country": "LK",
    "name": "Horawala Junction",
    "lat": "6.48088",
    "lng": "80.12708"
  },
  {
    "country": "LK",
    "name": "Padaviya Divisional Secretariat",
    "lat": "8.845",
    "lng": "80.7625"
  },
  {
    "country": "LK",
    "name": "Mount Lavinia",
    "lat": "6.83947",
    "lng": "79.86451"
  },
  {
    "country": "LR",
    "name": "Zwedru",
    "lat": "6.06846",
    "lng": "-8.13559"
  },
  {
    "country": "LR",
    "name": "New Yekepa",
    "lat": "7.57944",
    "lng": "-8.53778"
  },
  {
    "country": "LR",
    "name": "Voinjama",
    "lat": "8.42194",
    "lng": "-9.74778"
  },
  {
    "country": "LR",
    "name": "Tubmanburg",
    "lat": "6.87064",
    "lng": "-10.8211"
  },
  {
    "country": "LR",
    "name": "Fish Town",
    "lat": "5.19739",
    "lng": "-7.87579"
  },
  {
    "country": "LR",
    "name": "Sanniquellie",
    "lat": "7.36215",
    "lng": "-8.71326"
  },
  {
    "country": "LR",
    "name": "Robertsport",
    "lat": "6.75329",
    "lng": "-11.3671"
  },
  {
    "country": "LR",
    "name": "Cestos City",
    "lat": "5.45683",
    "lng": "-9.58167"
  },
  {
    "country": "LR",
    "name": "Monrovia",
    "lat": "6.30054",
    "lng": "-10.7969"
  },
  {
    "country": "LR",
    "name": "Kakata",
    "lat": "6.53104",
    "lng": "-10.35368"
  },
  {
    "country": "LR",
    "name": "Harper",
    "lat": "4.3782",
    "lng": "-7.71081"
  },
  {
    "country": "LR",
    "name": "Greenville",
    "lat": "5.01133",
    "lng": "-9.0388"
  },
  {
    "country": "LR",
    "name": "Gbarnga",
    "lat": "6.99543",
    "lng": "-9.47122"
  },
  {
    "country": "LR",
    "name": "Ganta",
    "lat": "7.30222",
    "lng": "-8.53083"
  },
  {
    "country": "LR",
    "name": "Buchanan",
    "lat": "5.87693",
    "lng": "-10.04964"
  },
  {
    "country": "LR",
    "name": "Bopolu",
    "lat": "7.06667",
    "lng": "-10.4875"
  },
  {
    "country": "LR",
    "name": "Bensonville",
    "lat": "6.44716",
    "lng": "-10.61283"
  },
  {
    "country": "LR",
    "name": "Barclayville",
    "lat": "4.67443",
    "lng": "-8.23306"
  },
  {
    "country": "LR",
    "name": "Buutuo",
    "lat": "6.8275",
    "lng": "-8.3428"
  },
  {
    "country": "LS",
    "name": "Teyateyaneng",
    "lat": "-29.14719",
    "lng": "27.74895"
  },
  {
    "country": "LS",
    "name": "Quthing",
    "lat": "-30.40001",
    "lng": "27.70027"
  },
  {
    "country": "LS",
    "name": "Qacha’s Nek",
    "lat": "-30.11537",
    "lng": "28.68936"
  },
  {
    "country": "LS",
    "name": "Nako",
    "lat": "-29.61667",
    "lng": "27.76667"
  },
  {
    "country": "LS",
    "name": "Mokhotlong",
    "lat": "-29.28939",
    "lng": "29.06751"
  },
  {
    "country": "LS",
    "name": "Mohale’s Hoek",
    "lat": "-30.15137",
    "lng": "27.47691"
  },
  {
    "country": "LS",
    "name": "Maseru",
    "lat": "-29.31667",
    "lng": "27.48333"
  },
  {
    "country": "LS",
    "name": "Maputsoe",
    "lat": "-28.8866",
    "lng": "27.89915"
  },
  {
    "country": "LS",
    "name": "Mafeteng",
    "lat": "-29.82299",
    "lng": "27.23744"
  },
  {
    "country": "LS",
    "name": "Leribe",
    "lat": "-28.87185",
    "lng": "28.04501"
  },
  {
    "country": "LS",
    "name": "Butha-Buthe",
    "lat": "-28.76659",
    "lng": "28.24937"
  },
  {
    "country": "LS",
    "name": "Thaba-Tseka",
    "lat": "-29.52204",
    "lng": "28.6084"
  },
  {
    "country": "LT",
    "name": "Žiežmariai",
    "lat": "54.80725",
    "lng": "24.44073"
  },
  {
    "country": "LT",
    "name": "Žemaičių Naumiestis",
    "lat": "55.35941",
    "lng": "21.70364"
  },
  {
    "country": "LT",
    "name": "Zarasai",
    "lat": "55.73225",
    "lng": "26.25115"
  },
  {
    "country": "LT",
    "name": "Žagarė",
    "lat": "56.36149",
    "lng": "23.25094"
  },
  {
    "country": "LT",
    "name": "Visaginas",
    "lat": "55.59678",
    "lng": "26.43984"
  },
  {
    "country": "LT",
    "name": "Virbalis",
    "lat": "54.62858",
    "lng": "22.82272"
  },
  {
    "country": "LT",
    "name": "Vilnius",
    "lat": "54.68916",
    "lng": "25.2798"
  },
  {
    "country": "LT",
    "name": "Vilkija",
    "lat": "55.04609",
    "lng": "23.58552"
  },
  {
    "country": "LT",
    "name": "Vilkaviskis",
    "lat": "54.65167",
    "lng": "23.03222"
  },
  {
    "country": "LT",
    "name": "Vievis",
    "lat": "54.76667",
    "lng": "24.8"
  },
  {
    "country": "LT",
    "name": "Viekšniai",
    "lat": "56.23598",
    "lng": "22.51667"
  },
  {
    "country": "LT",
    "name": "Venta",
    "lat": "56.19162",
    "lng": "22.69528"
  },
  {
    "country": "LT",
    "name": "Veisiejai",
    "lat": "54.1011",
    "lng": "23.69614"
  },
  {
    "country": "LT",
    "name": "Varniai",
    "lat": "55.74435",
    "lng": "22.37251"
  },
  {
    "country": "LT",
    "name": "Varėna",
    "lat": "54.21546",
    "lng": "24.57538"
  },
  {
    "country": "LT",
    "name": "Vabalninkas",
    "lat": "55.98151",
    "lng": "24.74828"
  },
  {
    "country": "LT",
    "name": "Utena",
    "lat": "55.49764",
    "lng": "25.59918"
  },
  {
    "country": "LT",
    "name": "Ukmerge",
    "lat": "55.25",
    "lng": "24.75"
  },
  {
    "country": "LT",
    "name": "Tytuvėnėliai",
    "lat": "55.62345",
    "lng": "23.17162"
  },
  {
    "country": "LT",
    "name": "Trakai",
    "lat": "54.63783",
    "lng": "24.93433"
  },
  {
    "country": "LT",
    "name": "Telsiai",
    "lat": "55.98139",
    "lng": "22.24722"
  },
  {
    "country": "LT",
    "name": "Taurage",
    "lat": "55.25222",
    "lng": "22.28972"
  },
  {
    "country": "LT",
    "name": "Šventoji",
    "lat": "56.0261",
    "lng": "21.08411"
  },
  {
    "country": "LT",
    "name": "Švenčionys",
    "lat": "55.135",
    "lng": "26.159"
  },
  {
    "country": "LT",
    "name": "Švenčionėliai",
    "lat": "55.16163",
    "lng": "26.00177"
  },
  {
    "country": "LT",
    "name": "Skuodas",
    "lat": "56.27057",
    "lng": "21.53208"
  },
  {
    "country": "LT",
    "name": "Būgai",
    "lat": "55.41387",
    "lng": "22.60894"
  },
  {
    "country": "LT",
    "name": "Skaidiškės",
    "lat": "54.61398",
    "lng": "25.39573"
  },
  {
    "country": "LT",
    "name": "Širvintos",
    "lat": "55.044",
    "lng": "24.95446"
  },
  {
    "country": "LT",
    "name": "Simnas",
    "lat": "54.382",
    "lng": "23.646"
  },
  {
    "country": "LT",
    "name": "Silute",
    "lat": "55.34889",
    "lng": "21.48306"
  },
  {
    "country": "LT",
    "name": "Šilalė",
    "lat": "55.4898",
    "lng": "22.18692"
  },
  {
    "country": "LT",
    "name": "Šiauliai",
    "lat": "55.93333",
    "lng": "23.31667"
  },
  {
    "country": "LT",
    "name": "Senieji Trakai",
    "lat": "54.609",
    "lng": "24.98"
  },
  {
    "country": "LT",
    "name": "Šeduva",
    "lat": "55.7493",
    "lng": "23.7561"
  },
  {
    "country": "LT",
    "name": "Seda",
    "lat": "56.16854",
    "lng": "22.09071"
  },
  {
    "country": "LT",
    "name": "Sargėnai",
    "lat": "54.94933",
    "lng": "23.88316"
  },
  {
    "country": "LT",
    "name": "Šalčininkai",
    "lat": "54.30864",
    "lng": "25.38677"
  },
  {
    "country": "LT",
    "name": "Salantai",
    "lat": "56.0565",
    "lng": "21.5689"
  },
  {
    "country": "LT",
    "name": "Šakiai",
    "lat": "54.95339",
    "lng": "23.04779"
  },
  {
    "country": "LT",
    "name": "Rusnė",
    "lat": "55.2982",
    "lng": "21.3712"
  },
  {
    "country": "LT",
    "name": "Rūdiškės",
    "lat": "54.51609",
    "lng": "24.83084"
  },
  {
    "country": "LT",
    "name": "Rokiškis",
    "lat": "55.95867",
    "lng": "25.59466"
  },
  {
    "country": "LT",
    "name": "Rietavas",
    "lat": "55.72708",
    "lng": "21.92343"
  },
  {
    "country": "LT",
    "name": "Raseiniai",
    "lat": "55.37973",
    "lng": "23.12386"
  },
  {
    "country": "LT",
    "name": "Ramygala",
    "lat": "55.514",
    "lng": "24.3"
  },
  {
    "country": "LT",
    "name": "Ramučiai",
    "lat": "54.9483",
    "lng": "24.0305"
  },
  {
    "country": "LT",
    "name": "Radviliskis",
    "lat": "55.81667",
    "lng": "23.53333"
  },
  {
    "country": "LT",
    "name": "Prienai",
    "lat": "54.636",
    "lng": "23.94585"
  },
  {
    "country": "LT",
    "name": "Priekulė",
    "lat": "55.55427",
    "lng": "21.31903"
  },
  {
    "country": "LT",
    "name": "Plunge",
    "lat": "55.91139",
    "lng": "21.84417"
  },
  {
    "country": "LT",
    "name": "Plateliai",
    "lat": "56.04657",
    "lng": "21.81615"
  },
  {
    "country": "LT",
    "name": "Pasvalys",
    "lat": "56.05944",
    "lng": "24.40361"
  },
  {
    "country": "LT",
    "name": "Panevėžys",
    "lat": "55.73333",
    "lng": "24.35"
  },
  {
    "country": "LT",
    "name": "Palanga",
    "lat": "55.9175",
    "lng": "21.06861"
  },
  {
    "country": "LT",
    "name": "Pakruojis",
    "lat": "55.97889",
    "lng": "23.85508"
  },
  {
    "country": "LT",
    "name": "Pagėgiai",
    "lat": "55.13793",
    "lng": "21.91378"
  },
  {
    "country": "LT",
    "name": "Pabradė",
    "lat": "54.981",
    "lng": "25.761"
  },
  {
    "country": "LT",
    "name": "Fabijoniškės",
    "lat": "54.73333",
    "lng": "25.24167"
  },
  {
    "country": "LT",
    "name": "Obeliai",
    "lat": "55.96895",
    "lng": "25.15648"
  },
  {
    "country": "LT",
    "name": "Nida",
    "lat": "55.3086",
    "lng": "20.99651"
  },
  {
    "country": "LT",
    "name": "Neringa",
    "lat": "55.37194",
    "lng": "21.06472"
  },
  {
    "country": "LT",
    "name": "Nemenčinė",
    "lat": "54.84776",
    "lng": "25.46992"
  },
  {
    "country": "LT",
    "name": "Naujoji Akmene",
    "lat": "56.31667",
    "lng": "22.9"
  },
  {
    "country": "LT",
    "name": "Molėtai",
    "lat": "55.22469",
    "lng": "25.41688"
  },
  {
    "country": "LT",
    "name": "Mazeikiai",
    "lat": "56.31667",
    "lng": "22.33333"
  },
  {
    "country": "LT",
    "name": "Marijampolė",
    "lat": "54.55991",
    "lng": "23.35412"
  },
  {
    "country": "LT",
    "name": "Linkuva",
    "lat": "56.08596",
    "lng": "23.97061"
  },
  {
    "country": "LT",
    "name": "Lentvaris",
    "lat": "54.64364",
    "lng": "25.05162"
  },
  {
    "country": "LT",
    "name": "Lazdijai",
    "lat": "54.23326",
    "lng": "23.51466"
  },
  {
    "country": "LT",
    "name": "Kybartai",
    "lat": "54.63858",
    "lng": "22.76316"
  },
  {
    "country": "LT",
    "name": "Kuršėnai",
    "lat": "56.00318",
    "lng": "22.93662"
  },
  {
    "country": "LT",
    "name": "Kupiskis",
    "lat": "55.83333",
    "lng": "24.96667"
  },
  {
    "country": "LT",
    "name": "Kulautuva",
    "lat": "54.94212",
    "lng": "23.64218"
  },
  {
    "country": "LT",
    "name": "Kudirkos Naumiestis",
    "lat": "54.77353",
    "lng": "22.86138"
  },
  {
    "country": "LT",
    "name": "Kretinga",
    "lat": "55.8888",
    "lng": "21.24448"
  },
  {
    "country": "LT",
    "name": "Klaipėda",
    "lat": "55.70888",
    "lng": "21.14312"
  },
  {
    "country": "LT",
    "name": "Kelmė",
    "lat": "55.63009",
    "lng": "22.9349"
  },
  {
    "country": "LT",
    "name": "Kėdainiai",
    "lat": "55.28782",
    "lng": "23.97275"
  },
  {
    "country": "LT",
    "name": "Kazlų Rūda",
    "lat": "54.749",
    "lng": "23.49"
  },
  {
    "country": "LT",
    "name": "Kaunas",
    "lat": "54.90272",
    "lng": "23.90961"
  },
  {
    "country": "LT",
    "name": "Karmėlava",
    "lat": "54.97055",
    "lng": "24.06182"
  },
  {
    "country": "LT",
    "name": "Kalvarija",
    "lat": "54.417",
    "lng": "23.223"
  },
  {
    "country": "LT",
    "name": "Kaišiadorys",
    "lat": "54.86528",
    "lng": "24.46815"
  },
  {
    "country": "LT",
    "name": "Jurbarkas",
    "lat": "55.07556",
    "lng": "22.76416"
  },
  {
    "country": "LT",
    "name": "Juodupė",
    "lat": "56.087",
    "lng": "25.607"
  },
  {
    "country": "LT",
    "name": "Joniškis",
    "lat": "56.23939",
    "lng": "23.61541"
  },
  {
    "country": "LT",
    "name": "Jonava",
    "lat": "55.08333",
    "lng": "24.28333"
  },
  {
    "country": "LT",
    "name": "Jieznas",
    "lat": "54.59937",
    "lng": "24.17593"
  },
  {
    "country": "LT",
    "name": "Ignalina",
    "lat": "55.34063",
    "lng": "26.16049"
  },
  {
    "country": "LT",
    "name": "Grigiškės",
    "lat": "54.68333",
    "lng": "25.08333"
  },
  {
    "country": "LT",
    "name": "Gelgaudiškis",
    "lat": "55.07688",
    "lng": "22.97699"
  },
  {
    "country": "LT",
    "name": "Garliava",
    "lat": "54.82139",
    "lng": "23.8713"
  },
  {
    "country": "LT",
    "name": "Gargždai",
    "lat": "55.70951",
    "lng": "21.39441"
  },
  {
    "country": "LT",
    "name": "Ežerėlis",
    "lat": "54.88315",
    "lng": "23.60396"
  },
  {
    "country": "LT",
    "name": "Elektrėnai",
    "lat": "54.78544",
    "lng": "24.66302"
  },
  {
    "country": "LT",
    "name": "Eišiškės",
    "lat": "54.17414",
    "lng": "24.99917"
  },
  {
    "country": "LT",
    "name": "Dūkštas",
    "lat": "55.522",
    "lng": "26.321"
  },
  {
    "country": "LT",
    "name": "Druskininkai",
    "lat": "54.01573",
    "lng": "23.98703"
  },
  {
    "country": "LT",
    "name": "Daugai",
    "lat": "54.36667",
    "lng": "24.33333"
  },
  {
    "country": "LT",
    "name": "Birzai",
    "lat": "56.2",
    "lng": "24.75"
  },
  {
    "country": "LT",
    "name": "Birštonas",
    "lat": "54.608",
    "lng": "24.034"
  },
  {
    "country": "LT",
    "name": "Baltoji Vokė",
    "lat": "54.60002",
    "lng": "25.19318"
  },
  {
    "country": "LT",
    "name": "Aukstadvaris",
    "lat": "54.57946",
    "lng": "24.52683"
  },
  {
    "country": "LT",
    "name": "Ariogala",
    "lat": "55.262",
    "lng": "23.477"
  },
  {
    "country": "LT",
    "name": "Anyksciai",
    "lat": "55.52557",
    "lng": "25.10264"
  },
  {
    "country": "LT",
    "name": "Alytus",
    "lat": "54.39635",
    "lng": "24.04142"
  },
  {
    "country": "LT",
    "name": "Aleksotas",
    "lat": "54.88037",
    "lng": "23.90842"
  },
  {
    "country": "LT",
    "name": "Akmenė",
    "lat": "56.25",
    "lng": "22.75"
  },
  {
    "country": "LT",
    "name": "Dainava (Kaunas)",
    "lat": "54.91525",
    "lng": "23.96831"
  },
  {
    "country": "LT",
    "name": "Šilainiai",
    "lat": "54.92911",
    "lng": "23.88599"
  },
  {
    "country": "LT",
    "name": "Eiguliai",
    "lat": "54.93133",
    "lng": "23.93243"
  },
  {
    "country": "LT",
    "name": "Akademija (Kaunas)",
    "lat": "54.8964",
    "lng": "23.82411"
  },
  {
    "country": "LT",
    "name": "Mastaiciai",
    "lat": "54.81998",
    "lng": "23.84462"
  },
  {
    "country": "LT",
    "name": "Pašilaičiai",
    "lat": "54.73429",
    "lng": "25.21912"
  },
  {
    "country": "LT",
    "name": "Pilaitė",
    "lat": "54.69981",
    "lng": "25.18393"
  },
  {
    "country": "LT",
    "name": "Justiniškės",
    "lat": "54.71664",
    "lng": "25.2174"
  },
  {
    "country": "LT",
    "name": "Šeškinė",
    "lat": "54.70972",
    "lng": "25.25053"
  },
  {
    "country": "LT",
    "name": "Lazdynai",
    "lat": "54.66815",
    "lng": "25.20684"
  },
  {
    "country": "LT",
    "name": "Vilkpėdė",
    "lat": "54.66969",
    "lng": "25.2477"
  },
  {
    "country": "LT",
    "name": "Naujamiestis",
    "lat": "54.67951",
    "lng": "25.26855"
  },
  {
    "country": "LT",
    "name": "Rasos",
    "lat": "54.67877",
    "lng": "25.31173"
  },
  {
    "country": "LU",
    "name": "Wormeldange",
    "lat": "49.61114",
    "lng": "6.40546"
  },
  {
    "country": "LU",
    "name": "Winseler",
    "lat": "49.96778",
    "lng": "5.89028"
  },
  {
    "country": "LU",
    "name": "Wincrange",
    "lat": "50.05333",
    "lng": "5.91917"
  },
  {
    "country": "LU",
    "name": "Wilwerwiltz",
    "lat": "49.98889",
    "lng": "5.99917"
  },
  {
    "country": "LU",
    "name": "Wiltz",
    "lat": "49.96547",
    "lng": "5.9339"
  },
  {
    "country": "LU",
    "name": "Weiswampach",
    "lat": "50.13722",
    "lng": "6.075"
  },
  {
    "country": "LU",
    "name": "Weiler-la-Tour",
    "lat": "49.54083",
    "lng": "6.20083"
  },
  {
    "country": "LU",
    "name": "Wasserbillig",
    "lat": "49.71534",
    "lng": "6.49861"
  },
  {
    "country": "LU",
    "name": "Warken",
    "lat": "49.85918",
    "lng": "6.08415"
  },
  {
    "country": "LU",
    "name": "Walferdange",
    "lat": "49.66321",
    "lng": "6.13224"
  },
  {
    "country": "LU",
    "name": "Waldbredimus",
    "lat": "49.55676",
    "lng": "6.28789"
  },
  {
    "country": "LU",
    "name": "Waldbillig",
    "lat": "49.79636",
    "lng": "6.28431"
  },
  {
    "country": "LU",
    "name": "Wahl",
    "lat": "49.83667",
    "lng": "5.90639"
  },
  {
    "country": "LU",
    "name": "Vichten",
    "lat": "49.80306",
    "lng": "6"
  },
  {
    "country": "LU",
    "name": "Vianden",
    "lat": "49.935",
    "lng": "6.20889"
  },
  {
    "country": "LU",
    "name": "Useldange",
    "lat": "49.76972",
    "lng": "5.98222"
  },
  {
    "country": "LU",
    "name": "Tuntange",
    "lat": "49.71778",
    "lng": "6.01028"
  },
  {
    "country": "LU",
    "name": "Troisvierges",
    "lat": "50.12111",
    "lng": "6.00028"
  },
  {
    "country": "LU",
    "name": "Tétange",
    "lat": "49.47583",
    "lng": "6.04222"
  },
  {
    "country": "LU",
    "name": "Tandel",
    "lat": "49.8975",
    "lng": "6.18333"
  },
  {
    "country": "LU",
    "name": "Strassen",
    "lat": "49.62056",
    "lng": "6.07333"
  },
  {
    "country": "LU",
    "name": "Steinsel",
    "lat": "49.67694",
    "lng": "6.12389"
  },
  {
    "country": "LU",
    "name": "Steinfort",
    "lat": "49.66139",
    "lng": "5.91917"
  },
  {
    "country": "LU",
    "name": "Stadtbredimus",
    "lat": "49.56278",
    "lng": "6.36444"
  },
  {
    "country": "LU",
    "name": "Soleuvre",
    "lat": "49.52148",
    "lng": "5.93781"
  },
  {
    "country": "LU",
    "name": "Septfontaines",
    "lat": "49.70111",
    "lng": "5.96722"
  },
  {
    "country": "LU",
    "name": "Schuttrange",
    "lat": "49.62056",
    "lng": "6.26861"
  },
  {
    "country": "LU",
    "name": "Schrassig",
    "lat": "49.61014",
    "lng": "6.25903"
  },
  {
    "country": "LU",
    "name": "Schouweiler",
    "lat": "49.5825",
    "lng": "5.95639"
  },
  {
    "country": "LU",
    "name": "Schifflange",
    "lat": "49.50639",
    "lng": "6.01278"
  },
  {
    "country": "LU",
    "name": "Schieren",
    "lat": "49.83056",
    "lng": "6.09861"
  },
  {
    "country": "LU",
    "name": "Schengen",
    "lat": "49.47",
    "lng": "6.362"
  },
  {
    "country": "LU",
    "name": "Sanem",
    "lat": "49.54806",
    "lng": "5.92889"
  },
  {
    "country": "LU",
    "name": "Sandweiler",
    "lat": "49.61471",
    "lng": "6.22221"
  },
  {
    "country": "LU",
    "name": "Saeul",
    "lat": "49.72722",
    "lng": "5.98639"
  },
  {
    "country": "LU",
    "name": "Rumelange",
    "lat": "49.45964",
    "lng": "6.03089"
  },
  {
    "country": "LU",
    "name": "Rosport",
    "lat": "49.8047",
    "lng": "6.50532"
  },
  {
    "country": "LU",
    "name": "Rollingen",
    "lat": "49.74167",
    "lng": "6.11444"
  },
  {
    "country": "LU",
    "name": "Roeser",
    "lat": "49.53721",
    "lng": "6.14629"
  },
  {
    "country": "LU",
    "name": "Rodange",
    "lat": "49.54639",
    "lng": "5.84083"
  },
  {
    "country": "LU",
    "name": "Remich",
    "lat": "49.545",
    "lng": "6.36694"
  },
  {
    "country": "LU",
    "name": "Reisdorf",
    "lat": "49.86861",
    "lng": "6.26778"
  },
  {
    "country": "LU",
    "name": "Redange-sur-Attert",
    "lat": "49.76437",
    "lng": "5.88997"
  },
  {
    "country": "LU",
    "name": "Reckange-sur-Mess",
    "lat": "49.5625",
    "lng": "6.00889"
  },
  {
    "country": "LU",
    "name": "Rambrouch",
    "lat": "49.83083",
    "lng": "5.845"
  },
  {
    "country": "LU",
    "name": "Putscheid",
    "lat": "49.96083",
    "lng": "6.14306"
  },
  {
    "country": "LU",
    "name": "Pontpierre",
    "lat": "49.53639",
    "lng": "6.02944"
  },
  {
    "country": "LU",
    "name": "Pétange",
    "lat": "49.55833",
    "lng": "5.88056"
  },
  {
    "country": "LU",
    "name": "Olm",
    "lat": "49.65722",
    "lng": "6.00028"
  },
  {
    "country": "LU",
    "name": "Obercorn",
    "lat": "49.51361",
    "lng": "5.89611"
  },
  {
    "country": "LU",
    "name": "Nommern",
    "lat": "49.78694",
    "lng": "6.17472"
  },
  {
    "country": "LU",
    "name": "Niedercorn",
    "lat": "49.53611",
    "lng": "5.89306"
  },
  {
    "country": "LU",
    "name": "Niederanven",
    "lat": "49.65196",
    "lng": "6.26199"
  },
  {
    "country": "LU",
    "name": "Müllendorf",
    "lat": "49.68028",
    "lng": "6.13"
  },
  {
    "country": "LU",
    "name": "Moutfort",
    "lat": "49.58528",
    "lng": "6.25556"
  },
  {
    "country": "LU",
    "name": "Mondorf-les-Bains",
    "lat": "49.505",
    "lng": "6.28111"
  },
  {
    "country": "LU",
    "name": "Mondercange",
    "lat": "49.53306",
    "lng": "5.98833"
  },
  {
    "country": "LU",
    "name": "Mompach",
    "lat": "49.74611",
    "lng": "6.465"
  },
  {
    "country": "LU",
    "name": "Mertzig",
    "lat": "49.83389",
    "lng": "6.0075"
  },
  {
    "country": "LU",
    "name": "Mertert",
    "lat": "49.70261",
    "lng": "6.47966"
  },
  {
    "country": "LU",
    "name": "Mersch",
    "lat": "49.74889",
    "lng": "6.10611"
  },
  {
    "country": "LU",
    "name": "Medernach",
    "lat": "49.80955",
    "lng": "6.21521"
  },
  {
    "country": "LU",
    "name": "Manternach",
    "lat": "49.70278",
    "lng": "6.42639"
  },
  {
    "country": "LU",
    "name": "Mamer",
    "lat": "49.6275",
    "lng": "6.02333"
  },
  {
    "country": "LU",
    "name": "Luxembourg",
    "lat": "49.61167",
    "lng": "6.13"
  },
  {
    "country": "LU",
    "name": "Lorentzweiler",
    "lat": "49.70131",
    "lng": "6.14234"
  },
  {
    "country": "LU",
    "name": "Lintgen",
    "lat": "49.72243",
    "lng": "6.13016"
  },
  {
    "country": "LU",
    "name": "Leudelange",
    "lat": "49.56833",
    "lng": "6.06528"
  },
  {
    "country": "LU",
    "name": "Lenningen",
    "lat": "49.60045",
    "lng": "6.36719"
  },
  {
    "country": "LU",
    "name": "Larochette",
    "lat": "49.78362",
    "lng": "6.21891"
  },
  {
    "country": "LU",
    "name": "Lamadelaine",
    "lat": "49.54639",
    "lng": "5.85639"
  },
  {
    "country": "LU",
    "name": "Kopstal",
    "lat": "49.66444",
    "lng": "6.07306"
  },
  {
    "country": "LU",
    "name": "Koerich",
    "lat": "49.67",
    "lng": "5.95"
  },
  {
    "country": "LU",
    "name": "Kirchberg",
    "lat": "49.62389",
    "lng": "6.14944"
  },
  {
    "country": "LU",
    "name": "Kehlen",
    "lat": "49.66833",
    "lng": "6.03583"
  },
  {
    "country": "LU",
    "name": "Kayl",
    "lat": "49.48917",
    "lng": "6.03972"
  },
  {
    "country": "LU",
    "name": "Junglinster",
    "lat": "49.70722",
    "lng": "6.25306"
  },
  {
    "country": "LU",
    "name": "Itzig",
    "lat": "49.58769",
    "lng": "6.17065"
  },
  {
    "country": "LU",
    "name": "Hosingen",
    "lat": "50.01218",
    "lng": "6.09089"
  },
  {
    "country": "LU",
    "name": "Hobscheid",
    "lat": "49.68861",
    "lng": "5.91472"
  },
  {
    "country": "LU",
    "name": "Hesperange",
    "lat": "49.56806",
    "lng": "6.15139"
  },
  {
    "country": "LU",
    "name": "Helmsange",
    "lat": "49.65278",
    "lng": "6.14139"
  },
  {
    "country": "LU",
    "name": "Heisdorf",
    "lat": "49.67207",
    "lng": "6.14202"
  },
  {
    "country": "LU",
    "name": "Heffingen",
    "lat": "49.76907",
    "lng": "6.24049"
  },
  {
    "country": "LU",
    "name": "Hautcharage",
    "lat": "49.57499",
    "lng": "5.9097"
  },
  {
    "country": "LU",
    "name": "Grosbous",
    "lat": "49.82778",
    "lng": "5.96722"
  },
  {
    "country": "LU",
    "name": "Grevenmacher",
    "lat": "49.67751",
    "lng": "6.44022"
  },
  {
    "country": "LU",
    "name": "Gonderange",
    "lat": "49.69537",
    "lng": "6.24577"
  },
  {
    "country": "LU",
    "name": "Goesdorf",
    "lat": "49.92131",
    "lng": "5.96601"
  },
  {
    "country": "LU",
    "name": "Garnich",
    "lat": "49.61667",
    "lng": "5.9525"
  },
  {
    "country": "LU",
    "name": "Frisange",
    "lat": "49.51616",
    "lng": "6.18858"
  },
  {
    "country": "LU",
    "name": "Flaxweiler",
    "lat": "49.66602",
    "lng": "6.34321"
  },
  {
    "country": "LU",
    "name": "Fischbach",
    "lat": "49.746",
    "lng": "6.18702"
  },
  {
    "country": "LU",
    "name": "Niederfeulen",
    "lat": "49.85556",
    "lng": "6.04722"
  },
  {
    "country": "LU",
    "name": "Fentange",
    "lat": "49.56278",
    "lng": "6.15389"
  },
  {
    "country": "LU",
    "name": "Ettelbruck",
    "lat": "49.8475",
    "lng": "6.10417"
  },
  {
    "country": "LU",
    "name": "Esch-sur-Sûre",
    "lat": "49.91139",
    "lng": "5.93639"
  },
  {
    "country": "LU",
    "name": "Esch-sur-Alzette",
    "lat": "49.49583",
    "lng": "5.98056"
  },
  {
    "country": "LU",
    "name": "Erpeldange",
    "lat": "49.86472",
    "lng": "6.11472"
  },
  {
    "country": "LU",
    "name": "Ell",
    "lat": "49.76389",
    "lng": "5.85722"
  },
  {
    "country": "LU",
    "name": "Eischen",
    "lat": "49.68556",
    "lng": "5.87861"
  },
  {
    "country": "LU",
    "name": "Echternach",
    "lat": "49.81212",
    "lng": "6.41846"
  },
  {
    "country": "LU",
    "name": "Dudelange",
    "lat": "49.48056",
    "lng": "6.0875"
  },
  {
    "country": "LU",
    "name": "Dippach",
    "lat": "49.58701",
    "lng": "5.9833"
  },
  {
    "country": "LU",
    "name": "Differdange",
    "lat": "49.52417",
    "lng": "5.89139"
  },
  {
    "country": "LU",
    "name": "Diekirch",
    "lat": "49.86778",
    "lng": "6.15583"
  },
  {
    "country": "LU",
    "name": "Dalheim",
    "lat": "49.54083",
    "lng": "6.25972"
  },
  {
    "country": "LU",
    "name": "Crauthem",
    "lat": "49.53556",
    "lng": "6.14694"
  },
  {
    "country": "LU",
    "name": "Contern",
    "lat": "49.58194",
    "lng": "6.22667"
  },
  {
    "country": "LU",
    "name": "Consdorf",
    "lat": "49.78018",
    "lng": "6.3395"
  },
  {
    "country": "LU",
    "name": "Colmar",
    "lat": "49.81028",
    "lng": "6.09722"
  },
  {
    "country": "LU",
    "name": "Clervaux",
    "lat": "50.05472",
    "lng": "6.03139"
  },
  {
    "country": "LU",
    "name": "Clemency",
    "lat": "49.59667",
    "lng": "5.87583"
  },
  {
    "country": "LU",
    "name": "Capellen",
    "lat": "49.645",
    "lng": "5.99083"
  },
  {
    "country": "LU",
    "name": "Bridel",
    "lat": "49.65579",
    "lng": "6.07999"
  },
  {
    "country": "LU",
    "name": "Bous",
    "lat": "49.55389",
    "lng": "6.32917"
  },
  {
    "country": "LU",
    "name": "Bourscheid",
    "lat": "49.90862",
    "lng": "6.0675"
  },
  {
    "country": "LU",
    "name": "Boulaide",
    "lat": "49.88778",
    "lng": "5.81639"
  },
  {
    "country": "LU",
    "name": "Boevange-sur-Attert",
    "lat": "49.77256",
    "lng": "6.01532"
  },
  {
    "country": "LU",
    "name": "Biwer",
    "lat": "49.70605",
    "lng": "6.37201"
  },
  {
    "country": "LU",
    "name": "Bissen",
    "lat": "49.78733",
    "lng": "6.0654"
  },
  {
    "country": "LU",
    "name": "Betzdorf",
    "lat": "49.68333",
    "lng": "6.35"
  },
  {
    "country": "LU",
    "name": "Bettendorf",
    "lat": "49.87667",
    "lng": "6.21806"
  },
  {
    "country": "LU",
    "name": "Bettembourg",
    "lat": "49.51861",
    "lng": "6.10278"
  },
  {
    "country": "LU",
    "name": "Bettborn",
    "lat": "49.79528",
    "lng": "5.94111"
  },
  {
    "country": "LU",
    "name": "Bertrange",
    "lat": "49.61111",
    "lng": "6.05"
  },
  {
    "country": "LU",
    "name": "Bergem",
    "lat": "49.525",
    "lng": "6.04222"
  },
  {
    "country": "LU",
    "name": "Béreldange",
    "lat": "49.65507",
    "lng": "6.11874"
  },
  {
    "country": "LU",
    "name": "Berdorf",
    "lat": "49.82051",
    "lng": "6.34945"
  },
  {
    "country": "LU",
    "name": "Belvaux",
    "lat": "49.51014",
    "lng": "5.92414"
  },
  {
    "country": "LU",
    "name": "Beckerich",
    "lat": "49.73114",
    "lng": "5.88241"
  },
  {
    "country": "LU",
    "name": "Bech",
    "lat": "49.7526",
    "lng": "6.36379"
  },
  {
    "country": "LU",
    "name": "Beaufort",
    "lat": "49.83583",
    "lng": "6.29167"
  },
  {
    "country": "LU",
    "name": "Bavigne",
    "lat": "49.92194",
    "lng": "5.84944"
  },
  {
    "country": "LU",
    "name": "Bascharage",
    "lat": "49.56727",
    "lng": "5.9073"
  },
  {
    "country": "LU",
    "name": "Aspelt",
    "lat": "49.52278",
    "lng": "6.22472"
  },
  {
    "country": "LU",
    "name": "Alzingen",
    "lat": "49.565",
    "lng": "6.16361"
  },
  {
    "country": "LV",
    "name": "Valmiera",
    "lat": "57.54108",
    "lng": "25.42751"
  },
  {
    "country": "LV",
    "name": "Zilupe",
    "lat": "56.38616",
    "lng": "28.12165"
  },
  {
    "country": "LV",
    "name": "Zelmeņi",
    "lat": "56.45167",
    "lng": "23.35194"
  },
  {
    "country": "LV",
    "name": "Viļaka",
    "lat": "57.18458",
    "lng": "27.6722"
  },
  {
    "country": "LV",
    "name": "Viļāni",
    "lat": "56.55253",
    "lng": "26.92449"
  },
  {
    "country": "LV",
    "name": "Viesīte",
    "lat": "56.34751",
    "lng": "25.55514"
  },
  {
    "country": "LV",
    "name": "Vecumnieki",
    "lat": "56.60608",
    "lng": "24.52232"
  },
  {
    "country": "LV",
    "name": "Ventspils",
    "lat": "57.38988",
    "lng": "21.57288"
  },
  {
    "country": "LV",
    "name": "Vecvārkava",
    "lat": "56.19838",
    "lng": "26.50811"
  },
  {
    "country": "LV",
    "name": "Vecpiebalga",
    "lat": "57.0609",
    "lng": "25.81624"
  },
  {
    "country": "LV",
    "name": "Varakļāni",
    "lat": "56.60826",
    "lng": "26.75377"
  },
  {
    "country": "LV",
    "name": "Vangaži",
    "lat": "57.09358",
    "lng": "24.54468"
  },
  {
    "country": "LV",
    "name": "Valka",
    "lat": "57.7752",
    "lng": "26.01013"
  },
  {
    "country": "LV",
    "name": "Valdemārpils",
    "lat": "57.37068",
    "lng": "22.59188"
  },
  {
    "country": "LV",
    "name": "Vaiņode",
    "lat": "56.41848",
    "lng": "21.85405"
  },
  {
    "country": "LV",
    "name": "Ulbroka",
    "lat": "56.9363",
    "lng": "24.30387"
  },
  {
    "country": "LV",
    "name": "Tukums",
    "lat": "56.96764",
    "lng": "23.15554"
  },
  {
    "country": "LV",
    "name": "Tīreļi",
    "lat": "56.83991",
    "lng": "23.58902"
  },
  {
    "country": "LV",
    "name": "Tērvete",
    "lat": "56.47989",
    "lng": "23.38895"
  },
  {
    "country": "LV",
    "name": "Talsi",
    "lat": "57.24562",
    "lng": "22.58137"
  },
  {
    "country": "LV",
    "name": "Strenči",
    "lat": "57.62574",
    "lng": "25.68535"
  },
  {
    "country": "LV",
    "name": "Stende",
    "lat": "57.14497",
    "lng": "22.53482"
  },
  {
    "country": "LV",
    "name": "Stalbe",
    "lat": "57.37065",
    "lng": "25.03106"
  },
  {
    "country": "LV",
    "name": "Staicele",
    "lat": "57.83639",
    "lng": "24.75"
  },
  {
    "country": "LV",
    "name": "Smiltene",
    "lat": "57.42444",
    "lng": "25.90164"
  },
  {
    "country": "LV",
    "name": "Smārde",
    "lat": "56.9542",
    "lng": "23.33736"
  },
  {
    "country": "LV",
    "name": "Skrunda",
    "lat": "56.67749",
    "lng": "22.01649"
  },
  {
    "country": "LV",
    "name": "Skrīveri",
    "lat": "56.645",
    "lng": "25.12058"
  },
  {
    "country": "LV",
    "name": "Sigulda",
    "lat": "57.15375",
    "lng": "24.85953"
  },
  {
    "country": "LV",
    "name": "Seda",
    "lat": "57.65042",
    "lng": "25.75089"
  },
  {
    "country": "LV",
    "name": "Saulkrasti",
    "lat": "57.26224",
    "lng": "24.41471"
  },
  {
    "country": "LV",
    "name": "Saldus",
    "lat": "56.66363",
    "lng": "22.48807"
  },
  {
    "country": "LV",
    "name": "Salaspils",
    "lat": "56.86014",
    "lng": "24.36544"
  },
  {
    "country": "LV",
    "name": "Salacgrīva",
    "lat": "57.75312",
    "lng": "24.35895"
  },
  {
    "country": "LV",
    "name": "Sala",
    "lat": "56.50675",
    "lng": "25.76423"
  },
  {
    "country": "LV",
    "name": "Sabile",
    "lat": "57.04577",
    "lng": "22.57261"
  },
  {
    "country": "LV",
    "name": "Rūjiena",
    "lat": "57.89752",
    "lng": "25.33155"
  },
  {
    "country": "LV",
    "name": "Rugāji",
    "lat": "57.00325",
    "lng": "27.13371"
  },
  {
    "country": "LV",
    "name": "Rucava",
    "lat": "56.16314",
    "lng": "21.16156"
  },
  {
    "country": "LV",
    "name": "Garkalne",
    "lat": "57.04486",
    "lng": "24.41951"
  },
  {
    "country": "LV",
    "name": "Ropaži",
    "lat": "56.9747",
    "lng": "24.63295"
  },
  {
    "country": "LV",
    "name": "Roja",
    "lat": "57.50146",
    "lng": "22.80881"
  },
  {
    "country": "LV",
    "name": "Riga",
    "lat": "56.946",
    "lng": "24.10589"
  },
  {
    "country": "LV",
    "name": "Riebiņi",
    "lat": "56.3428",
    "lng": "26.79995"
  },
  {
    "country": "LV",
    "name": "Rēzekne",
    "lat": "56.51028",
    "lng": "27.34"
  },
  {
    "country": "LV",
    "name": "Rauna",
    "lat": "57.33173",
    "lng": "25.60947"
  },
  {
    "country": "LV",
    "name": "Ragana",
    "lat": "57.18074",
    "lng": "24.70731"
  },
  {
    "country": "LV",
    "name": "Priekuļi",
    "lat": "57.315",
    "lng": "25.36147"
  },
  {
    "country": "LV",
    "name": "Priekule",
    "lat": "56.44679",
    "lng": "21.58968"
  },
  {
    "country": "LV",
    "name": "Preiļi",
    "lat": "56.29444",
    "lng": "26.72459"
  },
  {
    "country": "LV",
    "name": "Pļaviņas",
    "lat": "56.6178",
    "lng": "25.72552"
  },
  {
    "country": "LV",
    "name": "Piņķi",
    "lat": "56.94189",
    "lng": "23.91365"
  },
  {
    "country": "LV",
    "name": "Piltene",
    "lat": "57.22426",
    "lng": "21.67439"
  },
  {
    "country": "LV",
    "name": "Pilsrundāle",
    "lat": "56.41812",
    "lng": "24.01625"
  },
  {
    "country": "LV",
    "name": "Pāvilosta",
    "lat": "56.88791",
    "lng": "21.18593"
  },
  {
    "country": "LV",
    "name": "Ozolnieki",
    "lat": "56.68944",
    "lng": "23.79136"
  },
  {
    "country": "LV",
    "name": "Olaine",
    "lat": "56.79472",
    "lng": "23.9358"
  },
  {
    "country": "LV",
    "name": "Ogre",
    "lat": "56.8162",
    "lng": "24.61401"
  },
  {
    "country": "LV",
    "name": "Nīca",
    "lat": "56.34601",
    "lng": "21.06401"
  },
  {
    "country": "LV",
    "name": "Nereta",
    "lat": "56.20279",
    "lng": "25.30752"
  },
  {
    "country": "LV",
    "name": "Naukšēni",
    "lat": "57.88349",
    "lng": "25.45609"
  },
  {
    "country": "LV",
    "name": "Mūrmuiža",
    "lat": "57.47312",
    "lng": "25.49174"
  },
  {
    "country": "LV",
    "name": "Mežaparks",
    "lat": "57.00008",
    "lng": "24.15997"
  },
  {
    "country": "LV",
    "name": "Mērsrags",
    "lat": "57.33535",
    "lng": "23.12455"
  },
  {
    "country": "LV",
    "name": "Mazsalaca",
    "lat": "57.86329",
    "lng": "25.05475"
  },
  {
    "country": "LV",
    "name": "Matīši",
    "lat": "57.69892",
    "lng": "25.15886"
  },
  {
    "country": "LV",
    "name": "Mālpils",
    "lat": "57.0101",
    "lng": "24.95783"
  },
  {
    "country": "LV",
    "name": "Madona",
    "lat": "56.85329",
    "lng": "26.21698"
  },
  {
    "country": "LV",
    "name": "Ludza",
    "lat": "56.53958",
    "lng": "27.71891"
  },
  {
    "country": "LV",
    "name": "Lubāna",
    "lat": "56.90425",
    "lng": "26.71606"
  },
  {
    "country": "LV",
    "name": "Loja",
    "lat": "57.15336",
    "lng": "24.6433"
  },
  {
    "country": "LV",
    "name": "Līvāni",
    "lat": "56.35431",
    "lng": "26.17579"
  },
  {
    "country": "LV",
    "name": "Limbaži",
    "lat": "57.51287",
    "lng": "24.71941"
  },
  {
    "country": "LV",
    "name": "Līgatne",
    "lat": "57.23429",
    "lng": "25.04059"
  },
  {
    "country": "LV",
    "name": "Liepāja",
    "lat": "56.52707",
    "lng": "21.02357"
  },
  {
    "country": "LV",
    "name": "Lielvārde",
    "lat": "56.72066",
    "lng": "24.80743"
  },
  {
    "country": "LV",
    "name": "Lieģi",
    "lat": "56.58173",
    "lng": "21.33399"
  },
  {
    "country": "LV",
    "name": "Kuldīga",
    "lat": "56.97399",
    "lng": "21.95721"
  },
  {
    "country": "LV",
    "name": "Krustpils",
    "lat": "56.51068",
    "lng": "25.86117"
  },
  {
    "country": "LV",
    "name": "Krāslava",
    "lat": "55.89514",
    "lng": "27.16799"
  },
  {
    "country": "LV",
    "name": "Koknese",
    "lat": "56.65163",
    "lng": "25.43637"
  },
  {
    "country": "LV",
    "name": "Kocēni",
    "lat": "57.52057",
    "lng": "25.33821"
  },
  {
    "country": "LV",
    "name": "Ķekava",
    "lat": "56.82662",
    "lng": "24.23"
  },
  {
    "country": "LV",
    "name": "Ķegums",
    "lat": "56.7451",
    "lng": "24.72439"
  },
  {
    "country": "LV",
    "name": "Kārsava",
    "lat": "56.78405",
    "lng": "27.68829"
  },
  {
    "country": "LV",
    "name": "Karosta",
    "lat": "56.55128",
    "lng": "21.01287"
  },
  {
    "country": "LV",
    "name": "Kandava",
    "lat": "57.04087",
    "lng": "22.77466"
  },
  {
    "country": "LV",
    "name": "Jūrmala",
    "lat": "56.968",
    "lng": "23.77038"
  },
  {
    "country": "LV",
    "name": "Jumprava",
    "lat": "56.67613",
    "lng": "24.9721"
  },
  {
    "country": "LV",
    "name": "Jelgava",
    "lat": "56.65",
    "lng": "23.71278"
  },
  {
    "country": "LV",
    "name": "Jēkabpils",
    "lat": "56.49903",
    "lng": "25.85735"
  },
  {
    "country": "LV",
    "name": "Jaunpils",
    "lat": "56.73137",
    "lng": "23.01247"
  },
  {
    "country": "LV",
    "name": "Jaunpiebalga",
    "lat": "57.17745",
    "lng": "26.0284"
  },
  {
    "country": "LV",
    "name": "Jaunjelgava",
    "lat": "56.61319",
    "lng": "25.08316"
  },
  {
    "country": "LV",
    "name": "Jaunciems",
    "lat": "57.0391",
    "lng": "24.17413"
  },
  {
    "country": "LV",
    "name": "Jaunaglona",
    "lat": "56.16066",
    "lng": "27.00714"
  },
  {
    "country": "LV",
    "name": "Inčukalns",
    "lat": "57.09867",
    "lng": "24.6863"
  },
  {
    "country": "LV",
    "name": "Ilūkste",
    "lat": "55.97754",
    "lng": "26.29655"
  },
  {
    "country": "LV",
    "name": "Ikšķile",
    "lat": "56.83399",
    "lng": "24.49679"
  },
  {
    "country": "LV",
    "name": "Iecava",
    "lat": "56.59766",
    "lng": "24.20763"
  },
  {
    "country": "LV",
    "name": "Gulbene",
    "lat": "57.17767",
    "lng": "26.75291"
  },
  {
    "country": "LV",
    "name": "Grobiņa",
    "lat": "56.53521",
    "lng": "21.16782"
  },
  {
    "country": "LV",
    "name": "Cibla",
    "lat": "56.5498",
    "lng": "27.8837"
  },
  {
    "country": "LV",
    "name": "Ērgļi",
    "lat": "56.89752",
    "lng": "25.63668"
  },
  {
    "country": "LV",
    "name": "Engure",
    "lat": "57.16061",
    "lng": "23.22527"
  },
  {
    "country": "LV",
    "name": "Dundaga",
    "lat": "57.50498",
    "lng": "22.35041"
  },
  {
    "country": "LV",
    "name": "Drabeši",
    "lat": "57.24316",
    "lng": "25.27748"
  },
  {
    "country": "LV",
    "name": "Dobele",
    "lat": "56.62372",
    "lng": "23.2751"
  },
  {
    "country": "LV",
    "name": "Daugavpils",
    "lat": "55.88333",
    "lng": "26.53333"
  },
  {
    "country": "LV",
    "name": "Daugavgrīva",
    "lat": "57.04315",
    "lng": "24.03613"
  },
  {
    "country": "LV",
    "name": "Dagda",
    "lat": "56.09512",
    "lng": "27.53723"
  },
  {
    "country": "LV",
    "name": "Cesvaine",
    "lat": "56.96754",
    "lng": "26.30764"
  },
  {
    "country": "LV",
    "name": "Cēsis",
    "lat": "57.31188",
    "lng": "25.27456"
  },
  {
    "country": "LV",
    "name": "Carnikava",
    "lat": "57.12935",
    "lng": "24.28423"
  },
  {
    "country": "LV",
    "name": "Brocēni",
    "lat": "56.6789",
    "lng": "22.56945"
  },
  {
    "country": "LV",
    "name": "Bolderaja",
    "lat": "57.03132",
    "lng": "24.05571"
  },
  {
    "country": "LV",
    "name": "Berģi",
    "lat": "56.98639",
    "lng": "24.29917"
  },
  {
    "country": "LV",
    "name": "Bauska",
    "lat": "56.40794",
    "lng": "24.19443"
  },
  {
    "country": "LV",
    "name": "Balvi",
    "lat": "57.1313",
    "lng": "27.26583"
  },
  {
    "country": "LV",
    "name": "Baltinava",
    "lat": "56.94394",
    "lng": "27.64401"
  },
  {
    "country": "LV",
    "name": "Baldone",
    "lat": "56.74451",
    "lng": "24.40078"
  },
  {
    "country": "LV",
    "name": "Auce",
    "lat": "56.45981",
    "lng": "22.90169"
  },
  {
    "country": "LV",
    "name": "Ape",
    "lat": "57.53928",
    "lng": "26.69291"
  },
  {
    "country": "LV",
    "name": "Alūksne",
    "lat": "57.42162",
    "lng": "27.04662"
  },
  {
    "country": "LV",
    "name": "Alsunga",
    "lat": "56.98194",
    "lng": "21.55938"
  },
  {
    "country": "LV",
    "name": "Aloja",
    "lat": "57.76723",
    "lng": "24.87743"
  },
  {
    "country": "LV",
    "name": "Aknīste",
    "lat": "56.16152",
    "lng": "25.74783"
  },
  {
    "country": "LV",
    "name": "Aizpute",
    "lat": "56.72108",
    "lng": "21.60156"
  },
  {
    "country": "LV",
    "name": "Aizkraukle",
    "lat": "56.60477",
    "lng": "25.25534"
  },
  {
    "country": "LV",
    "name": "Ainaži",
    "lat": "57.86348",
    "lng": "24.35853"
  },
  {
    "country": "LV",
    "name": "Aglona",
    "lat": "56.13333",
    "lng": "27.01667"
  },
  {
    "country": "LV",
    "name": "Ādaži",
    "lat": "57.07045",
    "lng": "24.33713"
  },
  {
    "country": "LV",
    "name": "Baloži",
    "lat": "56.87643",
    "lng": "24.11825"
  },
  {
    "country": "LV",
    "name": "Mārupe",
    "lat": "56.90544",
    "lng": "24.05113"
  },
  {
    "country": "LY",
    "name": "Al Bardīyah",
    "lat": "31.75598",
    "lng": "25.0866"
  },
  {
    "country": "LY",
    "name": "Tobruk",
    "lat": "32.08963",
    "lng": "23.95385"
  },
  {
    "country": "LY",
    "name": "Qaryat Sulūq",
    "lat": "31.66818",
    "lng": "20.25205"
  },
  {
    "country": "LY",
    "name": "Gialo",
    "lat": "29.03333",
    "lng": "21.55"
  },
  {
    "country": "LY",
    "name": "Darnah",
    "lat": "32.76704",
    "lng": "22.63669"
  },
  {
    "country": "LY",
    "name": "Benghazi",
    "lat": "32.11486",
    "lng": "20.06859"
  },
  {
    "country": "LY",
    "name": "Az Zuwaytīnah",
    "lat": "30.9522",
    "lng": "20.12022"
  },
  {
    "country": "LY",
    "name": "Awjilah",
    "lat": "29.10806",
    "lng": "21.28694"
  },
  {
    "country": "LY",
    "name": "At Tāj",
    "lat": "24.20487",
    "lng": "23.2857"
  },
  {
    "country": "LY",
    "name": "Tūkrah",
    "lat": "32.53414",
    "lng": "20.57911"
  },
  {
    "country": "LY",
    "name": "Al Qubbah",
    "lat": "32.75684",
    "lng": "22.24106"
  },
  {
    "country": "LY",
    "name": "Al Marj",
    "lat": "32.49257",
    "lng": "20.82909"
  },
  {
    "country": "LY",
    "name": "Al Jawf",
    "lat": "24.1989",
    "lng": "23.29093"
  },
  {
    "country": "LY",
    "name": "Al Jaghbūb",
    "lat": "29.74262",
    "lng": "24.51676"
  },
  {
    "country": "LY",
    "name": "Al Bayḑā’",
    "lat": "32.76272",
    "lng": "21.75506"
  },
  {
    "country": "LY",
    "name": "Al Abyār",
    "lat": "32.19",
    "lng": "20.59653"
  },
  {
    "country": "LY",
    "name": "Ajdabiya",
    "lat": "30.75545",
    "lng": "20.22625"
  },
  {
    "country": "LY",
    "name": "Zuwārah",
    "lat": "32.9312",
    "lng": "12.08199"
  },
  {
    "country": "LY",
    "name": "Zliten",
    "lat": "32.46739",
    "lng": "14.56874"
  },
  {
    "country": "LY",
    "name": "Zalţan",
    "lat": "32.94699",
    "lng": "11.86668"
  },
  {
    "country": "LY",
    "name": "Yafran",
    "lat": "32.06329",
    "lng": "12.52859"
  },
  {
    "country": "LY",
    "name": "Waddān",
    "lat": "29.1614",
    "lng": "16.13904"
  },
  {
    "country": "LY",
    "name": "Tarhuna",
    "lat": "32.43501",
    "lng": "13.6332"
  },
  {
    "country": "LY",
    "name": "Tripoli",
    "lat": "32.87519",
    "lng": "13.18746"
  },
  {
    "country": "LY",
    "name": "Tagiura",
    "lat": "32.88167",
    "lng": "13.35056"
  },
  {
    "country": "LY",
    "name": "Sirte",
    "lat": "31.20892",
    "lng": "16.58866"
  },
  {
    "country": "LY",
    "name": "Şurmān",
    "lat": "32.75668",
    "lng": "12.57159"
  },
  {
    "country": "LY",
    "name": "Şabrātah",
    "lat": "32.79335",
    "lng": "12.48845"
  },
  {
    "country": "LY",
    "name": "Sabhā",
    "lat": "27.03766",
    "lng": "14.42832"
  },
  {
    "country": "LY",
    "name": "Nālūt",
    "lat": "31.86848",
    "lng": "10.9812"
  },
  {
    "country": "LY",
    "name": "Murzuq",
    "lat": "25.91552",
    "lng": "13.91839"
  },
  {
    "country": "LY",
    "name": "Mizdah",
    "lat": "31.44934",
    "lng": "12.9853"
  },
  {
    "country": "LY",
    "name": "Mişrātah",
    "lat": "32.37535",
    "lng": "15.09254"
  },
  {
    "country": "LY",
    "name": "Masallātah",
    "lat": "32.61667",
    "lng": "14"
  },
  {
    "country": "LY",
    "name": "Al Burayqah",
    "lat": "30.40624",
    "lng": "19.57386"
  },
  {
    "country": "LY",
    "name": "Marādah",
    "lat": "29.22054",
    "lng": "19.20454"
  },
  {
    "country": "LY",
    "name": "Giado",
    "lat": "31.95506",
    "lng": "12.02901"
  },
  {
    "country": "LY",
    "name": "Hūn",
    "lat": "29.12684",
    "lng": "15.94772"
  },
  {
    "country": "LY",
    "name": "Zawiya",
    "lat": "32.75222",
    "lng": "12.72778"
  },
  {
    "country": "LY",
    "name": "Ghat",
    "lat": "24.96334",
    "lng": "10.18003"
  },
  {
    "country": "LY",
    "name": "Gharyan",
    "lat": "32.17222",
    "lng": "13.02028"
  },
  {
    "country": "LY",
    "name": "Ghadāmis",
    "lat": "30.13366",
    "lng": "9.50072"
  },
  {
    "country": "LY",
    "name": "Brak",
    "lat": "27.54956",
    "lng": "14.27139"
  },
  {
    "country": "LY",
    "name": "Bani Walid",
    "lat": "31.74554",
    "lng": "13.98354"
  },
  {
    "country": "LY",
    "name": "Zintan",
    "lat": "31.93155",
    "lng": "12.25291"
  },
  {
    "country": "LY",
    "name": "Az Zāwīyah",
    "lat": "32.7571",
    "lng": "12.72764"
  },
  {
    "country": "LY",
    "name": "Ubari",
    "lat": "26.59034",
    "lng": "12.77511"
  },
  {
    "country": "LY",
    "name": "Al Qaţrūn",
    "lat": "24.95139",
    "lng": "14.64861"
  },
  {
    "country": "LY",
    "name": "Al Khums",
    "lat": "32.64861",
    "lng": "14.26191"
  },
  {
    "country": "LY",
    "name": "Al Jadīd",
    "lat": "27.05",
    "lng": "14.4"
  },
  {
    "country": "LY",
    "name": "Al ‘Azīzīyah",
    "lat": "32.53194",
    "lng": "13.0175"
  },
  {
    "country": "LY",
    "name": "Idrī",
    "lat": "27.44707",
    "lng": "13.05173"
  },
  {
    "country": "LY",
    "name": "Qasr Abu Hadi",
    "lat": "31.05926",
    "lng": "16.65905"
  },
  {
    "country": "MA",
    "name": "Smara",
    "lat": "26.73841",
    "lng": "-11.67194"
  },
  {
    "country": "MA",
    "name": "Zoumi",
    "lat": "34.80321",
    "lng": "-5.34458"
  },
  {
    "country": "MA",
    "name": "Zinat",
    "lat": "35.43",
    "lng": "-5.4"
  },
  {
    "country": "MA",
    "name": "Saddina",
    "lat": "35.6141",
    "lng": "-5.45191"
  },
  {
    "country": "MA",
    "name": "Setti Fatma",
    "lat": "31.22508",
    "lng": "-7.67751"
  },
  {
    "country": "MA",
    "name": "Zawyat ech Cheïkh",
    "lat": "32.64445",
    "lng": "-5.91826"
  },
  {
    "country": "MA",
    "name": "Zaïo",
    "lat": "34.94282",
    "lng": "-2.7329"
  },
  {
    "country": "MA",
    "name": "Zagora",
    "lat": "30.33241",
    "lng": "-5.8384"
  },
  {
    "country": "MA",
    "name": "Youssoufia",
    "lat": "32.24634",
    "lng": "-8.52941"
  },
  {
    "country": "MA",
    "name": "Touama",
    "lat": "31.53501",
    "lng": "-7.49291"
  },
  {
    "country": "MA",
    "name": "Tmourghout",
    "lat": "33.9065",
    "lng": "-4.02696"
  },
  {
    "country": "MA",
    "name": "Tiztoutine",
    "lat": "34.97159",
    "lng": "-3.15273"
  },
  {
    "country": "MA",
    "name": "Tiznit",
    "lat": "29.69742",
    "lng": "-9.73162"
  },
  {
    "country": "MA",
    "name": "Tizguine",
    "lat": "31.22836",
    "lng": "-8.31611"
  },
  {
    "country": "MA",
    "name": "Tit Mellil",
    "lat": "33.55808",
    "lng": "-7.48647"
  },
  {
    "country": "MA",
    "name": "Tissa",
    "lat": "34.28791",
    "lng": "-4.66372"
  },
  {
    "country": "MA",
    "name": "Tirhanimîne",
    "lat": "35.23619",
    "lng": "-3.95453"
  },
  {
    "country": "MA",
    "name": "Tiout",
    "lat": "30.3887",
    "lng": "-8.69572"
  },
  {
    "country": "MA",
    "name": "Tiouli",
    "lat": "34.36679",
    "lng": "-1.83705"
  },
  {
    "country": "MA",
    "name": "Tinghir",
    "lat": "31.51472",
    "lng": "-5.53278"
  },
  {
    "country": "MA",
    "name": "Timoulilt",
    "lat": "32.20368",
    "lng": "-6.4666"
  },
  {
    "country": "MA",
    "name": "Timezgana",
    "lat": "34.58",
    "lng": "-4.73"
  },
  {
    "country": "MA",
    "name": "Timezgadiouine",
    "lat": "30.88366",
    "lng": "-9.04548"
  },
  {
    "country": "MA",
    "name": "Tilmi",
    "lat": "31.81794",
    "lng": "-5.76812"
  },
  {
    "country": "MA",
    "name": "Tifni",
    "lat": "31.62777",
    "lng": "-6.94093"
  },
  {
    "country": "MA",
    "name": "Tiflet",
    "lat": "33.89469",
    "lng": "-6.30649"
  },
  {
    "country": "MA",
    "name": "Tétouan",
    "lat": "35.57845",
    "lng": "-5.36837"
  },
  {
    "country": "MA",
    "name": "Temara",
    "lat": "33.92866",
    "lng": "-6.90656"
  },
  {
    "country": "MA",
    "name": "Telouet",
    "lat": "31.28925",
    "lng": "-7.23789"
  },
  {
    "country": "MA",
    "name": "Tazouta",
    "lat": "33.66991",
    "lng": "-4.63392"
  },
  {
    "country": "MA",
    "name": "Taznakht",
    "lat": "30.57836",
    "lng": "-7.20341"
  },
  {
    "country": "MA",
    "name": "Tazemmourt",
    "lat": "30.40854",
    "lng": "-8.829"
  },
  {
    "country": "MA",
    "name": "Tazarine",
    "lat": "33.88307",
    "lng": "-4.1862"
  },
  {
    "country": "MA",
    "name": "Taza",
    "lat": "34.21",
    "lng": "-4.01"
  },
  {
    "country": "MA",
    "name": "Tata",
    "lat": "29.74409",
    "lng": "-7.973"
  },
  {
    "country": "MA",
    "name": "Tarsouat",
    "lat": "29.58153",
    "lng": "-9.02664"
  },
  {
    "country": "MA",
    "name": "Taroudant",
    "lat": "30.47028",
    "lng": "-8.87695"
  },
  {
    "country": "MA",
    "name": "Teroual",
    "lat": "34.67452",
    "lng": "-5.27331"
  },
  {
    "country": "MA",
    "name": "Targuist",
    "lat": "34.93769",
    "lng": "-4.31856"
  },
  {
    "country": "MA",
    "name": "Tarfaya",
    "lat": "27.9392",
    "lng": "-12.92604"
  },
  {
    "country": "MA",
    "name": "Taourirt",
    "lat": "34.40731",
    "lng": "-2.89732"
  },
  {
    "country": "MA",
    "name": "Taounza",
    "lat": "32.09368",
    "lng": "-6.60607"
  },
  {
    "country": "MA",
    "name": "Taounate",
    "lat": "34.53661",
    "lng": "-4.64009"
  },
  {
    "country": "MA",
    "name": "Taouloukoult",
    "lat": "31.22218",
    "lng": "-9.07943"
  },
  {
    "country": "MA",
    "name": "Taouima",
    "lat": "35.1299",
    "lng": "-2.9279"
  },
  {
    "country": "MA",
    "name": "Tan-Tan",
    "lat": "28.43799",
    "lng": "-11.10321"
  },
  {
    "country": "MA",
    "name": "Tangier",
    "lat": "35.76727",
    "lng": "-5.79975"
  },
  {
    "country": "MA",
    "name": "Tanalt",
    "lat": "29.77548",
    "lng": "-9.16796"
  },
  {
    "country": "MA",
    "name": "Tamorot",
    "lat": "34.93632",
    "lng": "-4.7794"
  },
  {
    "country": "MA",
    "name": "Tamanar",
    "lat": "31.00087",
    "lng": "-9.67802"
  },
  {
    "country": "MA",
    "name": "Talzemt",
    "lat": "33.59",
    "lng": "-4.19"
  },
  {
    "country": "MA",
    "name": "Talmest",
    "lat": "31.81",
    "lng": "-9.33"
  },
  {
    "country": "MA",
    "name": "Taliouine",
    "lat": "30.52917",
    "lng": "-7.91262"
  },
  {
    "country": "MA",
    "name": "Tahla",
    "lat": "34.04965",
    "lng": "-4.42162"
  },
  {
    "country": "MA",
    "name": "Tafraout",
    "lat": "29.72449",
    "lng": "-8.9747"
  },
  {
    "country": "MA",
    "name": "Tadrart",
    "lat": "30.77477",
    "lng": "-9.45951"
  },
  {
    "country": "MA",
    "name": "Tabouda",
    "lat": "34.71923",
    "lng": "-5.1403"
  },
  {
    "country": "MA",
    "name": "Tabia",
    "lat": "32.03009",
    "lng": "-6.79985"
  },
  {
    "country": "MA",
    "name": "Tabia",
    "lat": "30.03462",
    "lng": "-8.87688"
  },
  {
    "country": "MA",
    "name": "Tabant",
    "lat": "31.65255",
    "lng": "-6.41049"
  },
  {
    "country": "MA",
    "name": "Souq Larb’a al Gharb",
    "lat": "34.68664",
    "lng": "-6.00272"
  },
  {
    "country": "MA",
    "name": "Senada",
    "lat": "35.07452",
    "lng": "-4.21583"
  },
  {
    "country": "MA",
    "name": "Skoura",
    "lat": "31.06262",
    "lng": "-6.5525"
  },
  {
    "country": "MA",
    "name": "Sidi Yahya Ou Saad",
    "lat": "32.68011",
    "lng": "-5.57738"
  },
  {
    "country": "MA",
    "name": "Sidi Yahia El Gharb",
    "lat": "34.30494",
    "lng": "-6.30404"
  },
  {
    "country": "MA",
    "name": "Sidi Smai’il",
    "lat": "32.82461",
    "lng": "-8.51122"
  },
  {
    "country": "MA",
    "name": "Sidi Slimane",
    "lat": "34.26479",
    "lng": "-5.92598"
  },
  {
    "country": "MA",
    "name": "Sidi Redouane",
    "lat": "34.68692",
    "lng": "-5.44538"
  },
  {
    "country": "MA",
    "name": "Sidi Rahhal",
    "lat": "31.65031",
    "lng": "-7.47288"
  },
  {
    "country": "MA",
    "name": "Sidi Qacem",
    "lat": "34.22149",
    "lng": "-5.70775"
  },
  {
    "country": "MA",
    "name": "Sidi Moussa",
    "lat": "32.27209",
    "lng": "-7.20095"
  },
  {
    "country": "MA",
    "name": "Sidi Lamine",
    "lat": "32.90783",
    "lng": "-6.05069"
  },
  {
    "country": "MA",
    "name": "Sidi Jaber",
    "lat": "32.38952",
    "lng": "-6.42095"
  },
  {
    "country": "MA",
    "name": "Sidi Ifni",
    "lat": "29.37975",
    "lng": "-10.17299"
  },
  {
    "country": "MA",
    "name": "Sidi Harazem",
    "lat": "34.02733",
    "lng": "-4.88343"
  },
  {
    "country": "MA",
    "name": "Sidi Bousber",
    "lat": "34.56283",
    "lng": "-5.36208"
  },
  {
    "country": "MA",
    "name": "Sidi Bou Othmane",
    "lat": "31.90226",
    "lng": "-7.94169"
  },
  {
    "country": "MA",
    "name": "Sidi Bennour",
    "lat": "32.65236",
    "lng": "-8.42769"
  },
  {
    "country": "MA",
    "name": "Sidi Amar",
    "lat": "32.94987",
    "lng": "-5.83225"
  },
  {
    "country": "MA",
    "name": "Sidi Abdallah",
    "lat": "32.53544",
    "lng": "-7.83243"
  },
  {
    "country": "MA",
    "name": "Settat",
    "lat": "33.00103",
    "lng": "-7.61662"
  },
  {
    "country": "MA",
    "name": "Selouane",
    "lat": "35.07313",
    "lng": "-2.9423"
  },
  {
    "country": "MA",
    "name": "Sefrou",
    "lat": "33.83186",
    "lng": "-4.828"
  },
  {
    "country": "MA",
    "name": "Sale",
    "lat": "34.0531",
    "lng": "-6.79846"
  },
  {
    "country": "MA",
    "name": "Saidia",
    "lat": "35.08195",
    "lng": "-2.22897"
  },
  {
    "country": "MA",
    "name": "Safi",
    "lat": "32.29939",
    "lng": "-9.23718"
  },
  {
    "country": "MA",
    "name": "Rouadi",
    "lat": "35.14119",
    "lng": "-4.13631"
  },
  {
    "country": "MA",
    "name": "Reçani",
    "lat": "31.28318",
    "lng": "-4.26565"
  },
  {
    "country": "MA",
    "name": "Rislane",
    "lat": "34.76987",
    "lng": "-2.46034"
  },
  {
    "country": "MA",
    "name": "Ghouazi",
    "lat": "34.47737",
    "lng": "-5.30235"
  },
  {
    "country": "MA",
    "name": "Reggada",
    "lat": "29.58016",
    "lng": "-9.70086"
  },
  {
    "country": "MA",
    "name": "Ratba",
    "lat": "34.77772",
    "lng": "-4.93989"
  },
  {
    "country": "MA",
    "name": "Rabat",
    "lat": "34.01325",
    "lng": "-6.83255"
  },
  {
    "country": "MA",
    "name": "Ourtzagh",
    "lat": "34.53477",
    "lng": "-4.96878"
  },
  {
    "country": "MA",
    "name": "Oulmes",
    "lat": "33.42585",
    "lng": "-6.00137"
  },
  {
    "country": "MA",
    "name": "Oulad Teïma",
    "lat": "30.39467",
    "lng": "-9.20897"
  },
  {
    "country": "MA",
    "name": "Oulad Tayeb",
    "lat": "33.94633",
    "lng": "-4.99509"
  },
  {
    "country": "MA",
    "name": "Oulad Daoud",
    "lat": "34.40438",
    "lng": "-4.69342"
  },
  {
    "country": "MA",
    "name": "Oulad Ayad",
    "lat": "32.2",
    "lng": "-6.8"
  },
  {
    "country": "MA",
    "name": "Oukaïmedene",
    "lat": "31.20603",
    "lng": "-7.86089"
  },
  {
    "country": "MA",
    "name": "Oujda-Angad",
    "lat": "34.68139",
    "lng": "-1.90858"
  },
  {
    "country": "MA",
    "name": "Ouijjane",
    "lat": "29.62777",
    "lng": "-9.53959"
  },
  {
    "country": "MA",
    "name": "Oued Zem",
    "lat": "32.8627",
    "lng": "-6.57359"
  },
  {
    "country": "MA",
    "name": "Oued Laou",
    "lat": "35.4484",
    "lng": "-5.09627"
  },
  {
    "country": "MA",
    "name": "Oued Amlil",
    "lat": "34.2",
    "lng": "-4.28"
  },
  {
    "country": "MA",
    "name": "Ouezzane",
    "lat": "34.79584",
    "lng": "-5.57849"
  },
  {
    "country": "MA",
    "name": "Ouarzazat",
    "lat": "30.91894",
    "lng": "-6.89341"
  },
  {
    "country": "MA",
    "name": "Oualidia",
    "lat": "32.73372",
    "lng": "-9.03059"
  },
  {
    "country": "MA",
    "name": "Zawyat an Nwaçer",
    "lat": "33.37981",
    "lng": "-7.61932"
  },
  {
    "country": "MA",
    "name": "Nador",
    "lat": "35.16813",
    "lng": "-2.93352"
  },
  {
    "country": "MA",
    "name": "Moulay Yacoub",
    "lat": "34.08793",
    "lng": "-5.18171"
  },
  {
    "country": "MA",
    "name": "Moulay Brahim",
    "lat": "31.28785",
    "lng": "-7.9683"
  },
  {
    "country": "MA",
    "name": "Moulay Bouchta",
    "lat": "34.48922",
    "lng": "-5.13023"
  },
  {
    "country": "MA",
    "name": "Moulay Abdallah",
    "lat": "33.19664",
    "lng": "-8.58811"
  },
  {
    "country": "MA",
    "name": "Al Aaroui",
    "lat": "35.0109",
    "lng": "-3.00938"
  },
  {
    "country": "MA",
    "name": "Mohammedia",
    "lat": "33.68607",
    "lng": "-7.38298"
  },
  {
    "country": "MA",
    "name": "Missour",
    "lat": "33.04893",
    "lng": "-3.98947"
  },
  {
    "country": "MA",
    "name": "Midelt",
    "lat": "32.6852",
    "lng": "-4.74512"
  },
  {
    "country": "MA",
    "name": "Midar",
    "lat": "34.94025",
    "lng": "-3.53311"
  },
  {
    "country": "MA",
    "name": "Meknès",
    "lat": "33.89352",
    "lng": "-5.54727"
  },
  {
    "country": "MA",
    "name": "Mediouna",
    "lat": "33.45161",
    "lng": "-7.51995"
  },
  {
    "country": "MA",
    "name": "Mechraa Bel Ksiri",
    "lat": "34.57373",
    "lng": "-5.95585"
  },
  {
    "country": "MA",
    "name": "Mdiq",
    "lat": "35.68313",
    "lng": "-5.32871"
  },
  {
    "country": "MA",
    "name": "Matmata",
    "lat": "34.09914",
    "lng": "-4.55219"
  },
  {
    "country": "MA",
    "name": "Martil",
    "lat": "35.61662",
    "lng": "-5.27522"
  },
  {
    "country": "MA",
    "name": "Marrakesh",
    "lat": "31.63416",
    "lng": "-7.99994"
  },
  {
    "country": "MA",
    "name": "Madagh",
    "lat": "35.01032",
    "lng": "-2.33701"
  },
  {
    "country": "MA",
    "name": "Ifrane",
    "lat": "31.70217",
    "lng": "-6.3494"
  },
  {
    "country": "MA",
    "name": "Larache",
    "lat": "35.19321",
    "lng": "-6.15572"
  },
  {
    "country": "MA",
    "name": "Lalla Mimouna",
    "lat": "34.84606",
    "lng": "-6.06645"
  },
  {
    "country": "MA",
    "name": "Ksar El Kebir",
    "lat": "35.00044",
    "lng": "-5.90378"
  },
  {
    "country": "MA",
    "name": "Khouribga",
    "lat": "32.88108",
    "lng": "-6.9063"
  },
  {
    "country": "MA",
    "name": "Khenifra",
    "lat": "32.93492",
    "lng": "-5.66167"
  },
  {
    "country": "MA",
    "name": "Kerrouchen",
    "lat": "32.79639",
    "lng": "-5.3188"
  },
  {
    "country": "MA",
    "name": "Kenitra",
    "lat": "34.26101",
    "lng": "-6.5802"
  },
  {
    "country": "MA",
    "name": "Kasba Tadla",
    "lat": "32.5977",
    "lng": "-6.26844"
  },
  {
    "country": "MA",
    "name": "Kariat Arkmane",
    "lat": "35.1071",
    "lng": "-2.74693"
  },
  {
    "country": "MA",
    "name": "Karia Ba Mohamed",
    "lat": "34.37094",
    "lng": "-5.2138"
  },
  {
    "country": "MA",
    "name": "Jorf",
    "lat": "31.49442",
    "lng": "-4.40598"
  },
  {
    "country": "MA",
    "name": "Jerada",
    "lat": "34.31",
    "lng": "-2.16"
  },
  {
    "country": "MA",
    "name": "Itzer",
    "lat": "32.8783",
    "lng": "-5.0515"
  },
  {
    "country": "MA",
    "name": "Isseksi",
    "lat": "32.22981",
    "lng": "-6.27661"
  },
  {
    "country": "MA",
    "name": "Inezgane",
    "lat": "30.35535",
    "lng": "-9.53639"
  },
  {
    "country": "MA",
    "name": "Imider",
    "lat": "31.37324",
    "lng": "-5.79384"
  },
  {
    "country": "MA",
    "name": "Imilchil",
    "lat": "32.15309",
    "lng": "-5.62453"
  },
  {
    "country": "MA",
    "name": "Iguidi",
    "lat": "30.83826",
    "lng": "-7.90294"
  },
  {
    "country": "MA",
    "name": "Ifrane",
    "lat": "33.52666",
    "lng": "-5.11019"
  },
  {
    "country": "MA",
    "name": "Hassi Berkane",
    "lat": "34.83898",
    "lng": "-2.86699"
  },
  {
    "country": "MA",
    "name": "Zerkten",
    "lat": "31.4447",
    "lng": "-7.39224"
  },
  {
    "country": "MA",
    "name": "Had Kourt",
    "lat": "34.61588",
    "lng": "-5.7404"
  },
  {
    "country": "MA",
    "name": "Oulad Frej",
    "lat": "32.95956",
    "lng": "-8.2274"
  },
  {
    "country": "MA",
    "name": "Guisser",
    "lat": "32.76645",
    "lng": "-7.49818"
  },
  {
    "country": "MA",
    "name": "Guercif",
    "lat": "34.22568",
    "lng": "-3.35361"
  },
  {
    "country": "MA",
    "name": "Guenfouda",
    "lat": "34.48361",
    "lng": "-2.04562"
  },
  {
    "country": "MA",
    "name": "Guelmim",
    "lat": "28.98696",
    "lng": "-10.05738"
  },
  {
    "country": "MA",
    "name": "Goulmima",
    "lat": "31.69227",
    "lng": "-4.95256"
  },
  {
    "country": "MA",
    "name": "Galaz",
    "lat": "34.54424",
    "lng": "-4.80355"
  },
  {
    "country": "MA",
    "name": "Fnidek",
    "lat": "35.84906",
    "lng": "-5.35747"
  },
  {
    "country": "MA",
    "name": "Al Fqih Ben Çalah",
    "lat": "32.50213",
    "lng": "-6.68771"
  },
  {
    "country": "MA",
    "name": "Figuig (Centre)",
    "lat": "32.10891",
    "lng": "-1.22855"
  },
  {
    "country": "MA",
    "name": "Fifi",
    "lat": "34.94873",
    "lng": "-5.24798"
  },
  {
    "country": "MA",
    "name": "Fezna",
    "lat": "31.52921",
    "lng": "-4.45562"
  },
  {
    "country": "MA",
    "name": "Fès al Bali",
    "lat": "34.0701",
    "lng": "-4.95473"
  },
  {
    "country": "MA",
    "name": "Fès",
    "lat": "34.03313",
    "lng": "-5.00028"
  },
  {
    "country": "MA",
    "name": "Ezzhiliga",
    "lat": "33.3",
    "lng": "-6.53"
  },
  {
    "country": "MA",
    "name": "Essaouira",
    "lat": "31.5125",
    "lng": "-9.77"
  },
  {
    "country": "MA",
    "name": "Arfoud",
    "lat": "31.4353",
    "lng": "-4.23258"
  },
  {
    "country": "MA",
    "name": "El Ksiba",
    "lat": "32.57286",
    "lng": "-6.01947"
  },
  {
    "country": "MA",
    "name": "Kelaat Mgouna",
    "lat": "31.24573",
    "lng": "-6.1326"
  },
  {
    "country": "MA",
    "name": "El Jadid",
    "lat": "33.25682",
    "lng": "-8.50882"
  },
  {
    "country": "MA",
    "name": "El Hajeb",
    "lat": "33.68786",
    "lng": "-5.371"
  },
  {
    "country": "MA",
    "name": "Ouaoula",
    "lat": "31.87",
    "lng": "-6.75"
  },
  {
    "country": "MA",
    "name": "El Aïoun",
    "lat": "34.58319",
    "lng": "-2.50612"
  },
  {
    "country": "MA",
    "name": "Imzouren",
    "lat": "35.14637",
    "lng": "-3.85063"
  },
  {
    "country": "MA",
    "name": "Derdara",
    "lat": "35.11041",
    "lng": "-5.29015"
  },
  {
    "country": "MA",
    "name": "Demnate",
    "lat": "31.73443",
    "lng": "-7.00505"
  },
  {
    "country": "MA",
    "name": "Debdou",
    "lat": "33.98228",
    "lng": "-3.04263"
  },
  {
    "country": "MA",
    "name": "Riah",
    "lat": "33.15122",
    "lng": "-7.37504"
  },
  {
    "country": "MA",
    "name": "Dar Ould Zidouh",
    "lat": "32.31247",
    "lng": "-6.90494"
  },
  {
    "country": "MA",
    "name": "Dar Bouazza",
    "lat": "33.51535",
    "lng": "-7.81677"
  },
  {
    "country": "MA",
    "name": "Dar Chaoui",
    "lat": "35.5377",
    "lng": "-5.71742"
  },
  {
    "country": "MA",
    "name": "Chichaoua",
    "lat": "31.54351",
    "lng": "-8.76275"
  },
  {
    "country": "MA",
    "name": "Chefchaouene",
    "lat": "35.16878",
    "lng": "-5.2636"
  },
  {
    "country": "MA",
    "name": "Casablanca",
    "lat": "33.58831",
    "lng": "-7.61138"
  },
  {
    "country": "MA",
    "name": "Bzou",
    "lat": "32.09171",
    "lng": "-7.04786"
  },
  {
    "country": "MA",
    "name": "Brikcha",
    "lat": "34.96732",
    "lng": "-5.57295"
  },
  {
    "country": "MA",
    "name": "Bouznika",
    "lat": "33.78942",
    "lng": "-7.15968"
  },
  {
    "country": "MA",
    "name": "Bouskoura",
    "lat": "33.44976",
    "lng": "-7.65239"
  },
  {
    "country": "MA",
    "name": "Boumia",
    "lat": "32.7236",
    "lng": "-5.1025"
  },
  {
    "country": "MA",
    "name": "Boulemane",
    "lat": "33.36376",
    "lng": "-4.72896"
  },
  {
    "country": "MA",
    "name": "Boulaouane",
    "lat": "32.85995",
    "lng": "-8.05555"
  },
  {
    "country": "MA",
    "name": "Boudinar",
    "lat": "35.15601",
    "lng": "-3.62358"
  },
  {
    "country": "MA",
    "name": "Bouarfa",
    "lat": "32.53379",
    "lng": "-1.96209"
  },
  {
    "country": "MA",
    "name": "Bouabout",
    "lat": "31.26554",
    "lng": "-9.17865"
  },
  {
    "country": "MA",
    "name": "Bigoudine",
    "lat": "30.72376",
    "lng": "-9.21097"
  },
  {
    "country": "MA",
    "name": "Bhalil",
    "lat": "33.85194",
    "lng": "-4.87228"
  },
  {
    "country": "MA",
    "name": "Berkane",
    "lat": "34.92",
    "lng": "-2.32"
  },
  {
    "country": "MA",
    "name": "Beni Mellal",
    "lat": "32.33725",
    "lng": "-6.34983"
  },
  {
    "country": "MA",
    "name": "Berrechid",
    "lat": "33.26553",
    "lng": "-7.58754"
  },
  {
    "country": "MA",
    "name": "Bab Taza",
    "lat": "35.06166",
    "lng": "-5.19828"
  },
  {
    "country": "MA",
    "name": "Azrou",
    "lat": "33.43443",
    "lng": "-5.22126"
  },
  {
    "country": "MA",
    "name": "Azilal",
    "lat": "31.96156",
    "lng": "-6.57109"
  },
  {
    "country": "MA",
    "name": "Azgour",
    "lat": "31.13753",
    "lng": "-8.31488"
  },
  {
    "country": "MA",
    "name": "Azemmour",
    "lat": "33.28952",
    "lng": "-8.3425"
  },
  {
    "country": "MA",
    "name": "Assoul",
    "lat": "31.95286",
    "lng": "-5.20812"
  },
  {
    "country": "MA",
    "name": "Assads",
    "lat": "30.23",
    "lng": "-8.86"
  },
  {
    "country": "MA",
    "name": "Asilah",
    "lat": "35.46522",
    "lng": "-6.03415"
  },
  {
    "country": "MA",
    "name": "Argana",
    "lat": "30.7825",
    "lng": "-9.11968"
  },
  {
    "country": "MA",
    "name": "Arbaoua",
    "lat": "34.90239",
    "lng": "-5.94871"
  },
  {
    "country": "MA",
    "name": "Arazane",
    "lat": "30.50346",
    "lng": "-8.60637"
  },
  {
    "country": "MA",
    "name": "Aourir",
    "lat": "30.49238",
    "lng": "-9.6355"
  },
  {
    "country": "MA",
    "name": "Aoulouz",
    "lat": "30.67307",
    "lng": "-8.18087"
  },
  {
    "country": "MA",
    "name": "Aoufous",
    "lat": "31.68",
    "lng": "-4.17"
  },
  {
    "country": "MA",
    "name": "Amouguer",
    "lat": "32.27491",
    "lng": "-4.93535"
  },
  {
    "country": "MA",
    "name": "Amizmiz",
    "lat": "31.21673",
    "lng": "-8.23184"
  },
  {
    "country": "MA",
    "name": "Amerzgane",
    "lat": "31.0437",
    "lng": "-7.21037"
  },
  {
    "country": "MA",
    "name": "Amersid",
    "lat": "32.74983",
    "lng": "-4.47063"
  },
  {
    "country": "MA",
    "name": "Amalou",
    "lat": "30.19153",
    "lng": "-8.74873"
  },
  {
    "country": "MA",
    "name": "Alnif",
    "lat": "31.11411",
    "lng": "-5.17154"
  },
  {
    "country": "MA",
    "name": "Almis Marmoucha",
    "lat": "33.32",
    "lng": "-4.18"
  },
  {
    "country": "MA",
    "name": "Khemisset",
    "lat": "33.82404",
    "lng": "-6.06627"
  },
  {
    "country": "MA",
    "name": "Al Hoceïma",
    "lat": "35.25165",
    "lng": "-3.93723"
  },
  {
    "country": "MA",
    "name": "Aknoul",
    "lat": "34.65371",
    "lng": "-3.86754"
  },
  {
    "country": "MA",
    "name": "Ajdir",
    "lat": "34.74347",
    "lng": "-3.97582"
  },
  {
    "country": "MA",
    "name": "Anergui",
    "lat": "32.06914",
    "lng": "-5.93961"
  },
  {
    "country": "MA",
    "name": "Aïn Leuh",
    "lat": "33.28984",
    "lng": "-5.33863"
  },
  {
    "country": "MA",
    "name": "Aïn Beni Mathar",
    "lat": "34.0097",
    "lng": "-2.03238"
  },
  {
    "country": "MA",
    "name": "Ahfir",
    "lat": "34.95368",
    "lng": "-2.10027"
  },
  {
    "country": "MA",
    "name": "Aguelmous",
    "lat": "33.16139",
    "lng": "-5.84626"
  },
  {
    "country": "MA",
    "name": "Agdz",
    "lat": "30.69356",
    "lng": "-6.44628"
  },
  {
    "country": "MA",
    "name": "Agadir Melloul",
    "lat": "30.22492",
    "lng": "-7.79601"
  },
  {
    "country": "MA",
    "name": "Agadir",
    "lat": "30.42018",
    "lng": "-9.59815"
  },
  {
    "country": "MA",
    "name": "Adassil",
    "lat": "31.10783",
    "lng": "-8.49083"
  },
  {
    "country": "MA",
    "name": "Adar",
    "lat": "30.14111",
    "lng": "-8.37221"
  },
  {
    "country": "MA",
    "name": "Skhirate",
    "lat": "33.8527",
    "lng": "-7.03171"
  },
  {
    "country": "MA",
    "name": "Abadou",
    "lat": "31.57917",
    "lng": "-7.31308"
  },
  {
    "country": "MA",
    "name": "Mellila",
    "lat": "33.38",
    "lng": "-7.14"
  },
  {
    "country": "MA",
    "name": "Tidili Mesfioua",
    "lat": "31.46586",
    "lng": "-7.61199"
  },
  {
    "country": "MA",
    "name": "Mhamid",
    "lat": "29.82",
    "lng": "-5.72"
  },
  {
    "country": "MA",
    "name": "Taghazout",
    "lat": "30.54259",
    "lng": "-9.71115"
  },
  {
    "country": "MA",
    "name": "Tamri",
    "lat": "30.69602",
    "lng": "-9.82972"
  },
  {
    "country": "MA",
    "name": "Smimou",
    "lat": "31.21014",
    "lng": "-9.70863"
  },
  {
    "country": "MA",
    "name": "Tizgane",
    "lat": "35.41211",
    "lng": "-5.06836"
  },
  {
    "country": "MA",
    "name": "Bouarouss",
    "lat": "34.36",
    "lng": "-4.81"
  },
  {
    "country": "MA",
    "name": "Azla",
    "lat": "35.55303",
    "lng": "-5.24472"
  },
  {
    "country": "MA",
    "name": "Boukhalef",
    "lat": "35.7328",
    "lng": "-5.89954"
  },
  {
    "country": "MA",
    "name": "Jebel Tiskaouine",
    "lat": "31.02722",
    "lng": "-5.11643"
  },
  {
    "country": "MA",
    "name": "Boujniba",
    "lat": "32.90046",
    "lng": "-6.77464"
  },
  {
    "country": "MA",
    "name": "Errachidia",
    "lat": "31.9314",
    "lng": "-4.42663"
  },
  {
    "country": "MA",
    "name": "Sidi Abdallah Ghiat",
    "lat": "31.523",
    "lng": "-7.833"
  },
  {
    "country": "MA",
    "name": "Dakhla",
    "lat": "30.41071",
    "lng": "-9.55572"
  },
  {
    "country": "MA",
    "name": "Mosquée",
    "lat": "34.80622",
    "lng": "-2.41297"
  },
  {
    "country": "MA",
    "name": "Akhfennir",
    "lat": "28.09455",
    "lng": "-12.05157"
  },
  {
    "country": "MA",
    "name": "Gueltat Zemmour",
    "lat": "25.14276",
    "lng": "-12.37168"
  },
  {
    "country": "MA",
    "name": "Zawit Al Bour",
    "lat": "30.67478",
    "lng": "-8.17424"
  },
  {
    "country": "MA",
    "name": "Cap Negro II",
    "lat": "35.6597",
    "lng": "-5.28525"
  },
  {
    "country": "MA",
    "name": "Bni Bouayach",
    "lat": "35.10506",
    "lng": "-3.84028"
  },
  {
    "country": "MA",
    "name": "Imlili",
    "lat": "22.6558",
    "lng": "-15.60719"
  },
  {
    "country": "MC",
    "name": "Monte-Carlo",
    "lat": "43.73976",
    "lng": "7.42732"
  },
  {
    "country": "MC",
    "name": "Monaco",
    "lat": "43.73333",
    "lng": "7.41667"
  },
  {
    "country": "MC",
    "name": "La Condamine",
    "lat": "43.73439",
    "lng": "7.42024"
  },
  {
    "country": "MC",
    "name": "Fontvieille",
    "lat": "43.72687",
    "lng": "7.41766"
  },
  {
    "country": "MC",
    "name": "Saint-Roman",
    "lat": "43.7489",
    "lng": "7.43423"
  },
  {
    "country": "MC",
    "name": "Moneghetti",
    "lat": "43.73679",
    "lng": "7.41647"
  },
  {
    "country": "MD",
    "name": "Tiraspolul Nou",
    "lat": "46.82874",
    "lng": "29.52174"
  },
  {
    "country": "MD",
    "name": "Edineţ",
    "lat": "48.17215",
    "lng": "27.30337"
  },
  {
    "country": "MD",
    "name": "Iargara",
    "lat": "46.4252",
    "lng": "28.42676"
  },
  {
    "country": "MD",
    "name": "Vulcăneşti",
    "lat": "45.68492",
    "lng": "28.40613"
  },
  {
    "country": "MD",
    "name": "Vişniovca",
    "lat": "46.3326",
    "lng": "28.44797"
  },
  {
    "country": "MD",
    "name": "Varniţa",
    "lat": "46.86606",
    "lng": "29.46636"
  },
  {
    "country": "MD",
    "name": "Vadul lui Vodă",
    "lat": "47.09009",
    "lng": "29.0757"
  },
  {
    "country": "MD",
    "name": "Ustia",
    "lat": "47.25524",
    "lng": "29.12406"
  },
  {
    "country": "MD",
    "name": "Ungheni",
    "lat": "47.21079",
    "lng": "27.80047"
  },
  {
    "country": "MD",
    "name": "Tvardița",
    "lat": "46.14826",
    "lng": "28.96491"
  },
  {
    "country": "MD",
    "name": "Tiraspol",
    "lat": "46.84274",
    "lng": "29.62909"
  },
  {
    "country": "MD",
    "name": "Teleneşti",
    "lat": "47.5011",
    "lng": "28.36536"
  },
  {
    "country": "MD",
    "name": "Taraclia",
    "lat": "45.90273",
    "lng": "28.66816"
  },
  {
    "country": "MD",
    "name": "Sîngera",
    "lat": "46.91557",
    "lng": "28.96673"
  },
  {
    "country": "MD",
    "name": "Ştefan Vodă",
    "lat": "46.51287",
    "lng": "29.66193"
  },
  {
    "country": "MD",
    "name": "Strășeni",
    "lat": "47.14216",
    "lng": "28.60774"
  },
  {
    "country": "MD",
    "name": "Stăuceni",
    "lat": "47.09643",
    "lng": "28.86791"
  },
  {
    "country": "MD",
    "name": "Bilicenii Vechi",
    "lat": "47.6558",
    "lng": "28.04734"
  },
  {
    "country": "MD",
    "name": "Soroca",
    "lat": "48.15659",
    "lng": "28.28489"
  },
  {
    "country": "MD",
    "name": "Şoldăneşti",
    "lat": "47.81608",
    "lng": "28.79718"
  },
  {
    "country": "MD",
    "name": "Slobozia",
    "lat": "46.72927",
    "lng": "29.70446"
  },
  {
    "country": "MD",
    "name": "Saharna",
    "lat": "47.69107",
    "lng": "28.97458"
  },
  {
    "country": "MD",
    "name": "Rîşcani",
    "lat": "47.94792",
    "lng": "27.56376"
  },
  {
    "country": "MD",
    "name": "Rîbniţa",
    "lat": "47.76817",
    "lng": "29.01"
  },
  {
    "country": "MD",
    "name": "Rezina",
    "lat": "47.74928",
    "lng": "28.96583"
  },
  {
    "country": "MD",
    "name": "Pervomaisc",
    "lat": "46.73253",
    "lng": "29.9617"
  },
  {
    "country": "MD",
    "name": "Orhei",
    "lat": "47.38494",
    "lng": "28.82446"
  },
  {
    "country": "MD",
    "name": "Ocniţa",
    "lat": "48.38274",
    "lng": "27.43805"
  },
  {
    "country": "MD",
    "name": "Anenii Noi",
    "lat": "46.87839",
    "lng": "29.23483"
  },
  {
    "country": "MD",
    "name": "Nisporeni",
    "lat": "47.08159",
    "lng": "28.17138"
  },
  {
    "country": "MD",
    "name": "Mîndreşti",
    "lat": "47.50525",
    "lng": "28.27687"
  },
  {
    "country": "MD",
    "name": "Maiac",
    "lat": "47.23727",
    "lng": "29.38498"
  },
  {
    "country": "MD",
    "name": "Mărculeşti",
    "lat": "47.86897",
    "lng": "28.24109"
  },
  {
    "country": "MD",
    "name": "Leova",
    "lat": "46.4823",
    "lng": "28.25301"
  },
  {
    "country": "MD",
    "name": "Sîngerei",
    "lat": "47.63632",
    "lng": "28.14296"
  },
  {
    "country": "MD",
    "name": "Cricova",
    "lat": "47.13835",
    "lng": "28.86156"
  },
  {
    "country": "MD",
    "name": "Crasnoe",
    "lat": "46.64844",
    "lng": "29.80403"
  },
  {
    "country": "MD",
    "name": "Hînceşti",
    "lat": "46.83047",
    "lng": "28.59064"
  },
  {
    "country": "MD",
    "name": "Cocieri",
    "lat": "47.3017",
    "lng": "29.11755"
  },
  {
    "country": "MD",
    "name": "Chiţcani",
    "lat": "46.78296",
    "lng": "29.61682"
  },
  {
    "country": "MD",
    "name": "Căuşeni",
    "lat": "46.63674",
    "lng": "29.41114"
  },
  {
    "country": "MD",
    "name": "Ialoveni",
    "lat": "46.94346",
    "lng": "28.78233"
  },
  {
    "country": "MD",
    "name": "Hryhoriopol",
    "lat": "47.15413",
    "lng": "29.30008"
  },
  {
    "country": "MD",
    "name": "Glodeni",
    "lat": "47.77513",
    "lng": "27.51891"
  },
  {
    "country": "MD",
    "name": "Ghindești",
    "lat": "47.85482",
    "lng": "28.37679"
  },
  {
    "country": "MD",
    "name": "Floreşti",
    "lat": "47.89137",
    "lng": "28.29312"
  },
  {
    "country": "MD",
    "name": "Fălești",
    "lat": "47.57667",
    "lng": "27.71264"
  },
  {
    "country": "MD",
    "name": "Giurgiuleşti",
    "lat": "45.48167",
    "lng": "28.19722"
  },
  {
    "country": "MD",
    "name": "Dubăsari",
    "lat": "47.26562",
    "lng": "29.16667"
  },
  {
    "country": "MD",
    "name": "Drochia",
    "lat": "48.03555",
    "lng": "27.81293"
  },
  {
    "country": "MD",
    "name": "Donduşeni",
    "lat": "48.24268",
    "lng": "27.6101"
  },
  {
    "country": "MD",
    "name": "Dnestrovsc",
    "lat": "46.6164",
    "lng": "29.91926"
  },
  {
    "country": "MD",
    "name": "Dancu",
    "lat": "46.75818",
    "lng": "28.20716"
  },
  {
    "country": "MD",
    "name": "Criuleni",
    "lat": "47.21307",
    "lng": "29.15926"
  },
  {
    "country": "MD",
    "name": "Comrat",
    "lat": "46.29456",
    "lng": "28.6565"
  },
  {
    "country": "MD",
    "name": "Cimişlia",
    "lat": "46.52685",
    "lng": "28.76441"
  },
  {
    "country": "MD",
    "name": "Chisinau",
    "lat": "47.00556",
    "lng": "28.8575"
  },
  {
    "country": "MD",
    "name": "Ceadîr-Lunga",
    "lat": "46.06169",
    "lng": "28.83078"
  },
  {
    "country": "MD",
    "name": "Cantemir",
    "lat": "46.27743",
    "lng": "28.2027"
  },
  {
    "country": "MD",
    "name": "Camenca",
    "lat": "48.03233",
    "lng": "28.69899"
  },
  {
    "country": "MD",
    "name": "Călăraşi",
    "lat": "47.2556",
    "lng": "28.30987"
  },
  {
    "country": "MD",
    "name": "Cahul",
    "lat": "45.90425",
    "lng": "28.19929"
  },
  {
    "country": "MD",
    "name": "Bucovăţ",
    "lat": "47.19064",
    "lng": "28.45802"
  },
  {
    "country": "MD",
    "name": "Bugeac",
    "lat": "46.36554",
    "lng": "28.6625"
  },
  {
    "country": "MD",
    "name": "Briceni",
    "lat": "48.36289",
    "lng": "27.07787"
  },
  {
    "country": "MD",
    "name": "Briceni",
    "lat": "48.35628",
    "lng": "27.70293"
  },
  {
    "country": "MD",
    "name": "Bender",
    "lat": "46.83156",
    "lng": "29.47769"
  },
  {
    "country": "MD",
    "name": "Basarabeasca",
    "lat": "46.3317",
    "lng": "28.96365"
  },
  {
    "country": "MD",
    "name": "Bălţi",
    "lat": "47.76314",
    "lng": "27.92932"
  },
  {
    "country": "MD",
    "name": "Otaci",
    "lat": "48.43285",
    "lng": "27.79912"
  },
  {
    "country": "MD",
    "name": "Vatra",
    "lat": "47.0746",
    "lng": "28.73685"
  },
  {
    "country": "MD",
    "name": "Ciorescu",
    "lat": "47.13",
    "lng": "28.88937"
  },
  {
    "country": "MD",
    "name": "Biruinţa",
    "lat": "47.81353",
    "lng": "28.07004"
  },
  {
    "country": "ME",
    "name": "Rožaje",
    "lat": "42.83299",
    "lng": "20.16652"
  },
  {
    "country": "ME",
    "name": "Žabljak",
    "lat": "43.15423",
    "lng": "19.12325"
  },
  {
    "country": "ME",
    "name": "Ulcinj",
    "lat": "41.92936",
    "lng": "19.22436"
  },
  {
    "country": "ME",
    "name": "Tuzi",
    "lat": "42.36556",
    "lng": "19.33139"
  },
  {
    "country": "ME",
    "name": "Tivat",
    "lat": "42.43639",
    "lng": "18.69611"
  },
  {
    "country": "ME",
    "name": "Sutomore",
    "lat": "42.14278",
    "lng": "19.04667"
  },
  {
    "country": "ME",
    "name": "Stari Bar",
    "lat": "42.097",
    "lng": "19.136"
  },
  {
    "country": "ME",
    "name": "Spuž",
    "lat": "42.515",
    "lng": "19.195"
  },
  {
    "country": "ME",
    "name": "Šavnik",
    "lat": "42.95639",
    "lng": "19.09667"
  },
  {
    "country": "ME",
    "name": "Risan",
    "lat": "42.515",
    "lng": "18.69556"
  },
  {
    "country": "ME",
    "name": "Prčanj",
    "lat": "42.4575",
    "lng": "18.74222"
  },
  {
    "country": "ME",
    "name": "Podgorica",
    "lat": "42.44111",
    "lng": "19.26361"
  },
  {
    "country": "ME",
    "name": "Plužine",
    "lat": "43.15278",
    "lng": "18.83944"
  },
  {
    "country": "ME",
    "name": "Pljevlja",
    "lat": "43.3567",
    "lng": "19.35843"
  },
  {
    "country": "ME",
    "name": "Plav",
    "lat": "42.59694",
    "lng": "19.94556"
  },
  {
    "country": "ME",
    "name": "Petrovac na Moru",
    "lat": "42.20556",
    "lng": "18.9425"
  },
  {
    "country": "ME",
    "name": "Nikšić",
    "lat": "42.7731",
    "lng": "18.94446"
  },
  {
    "country": "ME",
    "name": "Mojkovac",
    "lat": "42.96044",
    "lng": "19.5833"
  },
  {
    "country": "ME",
    "name": "Mojanovići",
    "lat": "42.34167",
    "lng": "19.22139"
  },
  {
    "country": "ME",
    "name": "Mataguži",
    "lat": "42.32361",
    "lng": "19.27278"
  },
  {
    "country": "ME",
    "name": "Lipci",
    "lat": "42.49722",
    "lng": "18.65806"
  },
  {
    "country": "ME",
    "name": "Kotor",
    "lat": "42.42067",
    "lng": "18.76825"
  },
  {
    "country": "ME",
    "name": "Kolašin",
    "lat": "42.82229",
    "lng": "19.51653"
  },
  {
    "country": "ME",
    "name": "Berane",
    "lat": "42.8425",
    "lng": "19.87333"
  },
  {
    "country": "ME",
    "name": "Igalo",
    "lat": "42.46007",
    "lng": "18.50647"
  },
  {
    "country": "ME",
    "name": "Herceg-Novi",
    "lat": "42.45306",
    "lng": "18.5375"
  },
  {
    "country": "ME",
    "name": "Gusinje",
    "lat": "42.56194",
    "lng": "19.83389"
  },
  {
    "country": "ME",
    "name": "Goričani",
    "lat": "42.33222",
    "lng": "19.21194"
  },
  {
    "country": "ME",
    "name": "Golubovci",
    "lat": "42.335",
    "lng": "19.23111"
  },
  {
    "country": "ME",
    "name": "Dobrota",
    "lat": "42.45417",
    "lng": "18.76833"
  },
  {
    "country": "ME",
    "name": "Danilovgrad",
    "lat": "42.55384",
    "lng": "19.14608"
  },
  {
    "country": "ME",
    "name": "Cetinje",
    "lat": "42.39063",
    "lng": "18.91417"
  },
  {
    "country": "ME",
    "name": "Budva",
    "lat": "42.28639",
    "lng": "18.84"
  },
  {
    "country": "ME",
    "name": "Bijelo Polje",
    "lat": "43.03834",
    "lng": "19.74758"
  },
  {
    "country": "ME",
    "name": "Bijela",
    "lat": "42.45333",
    "lng": "18.65556"
  },
  {
    "country": "ME",
    "name": "Bar",
    "lat": "42.09306",
    "lng": "19.10028"
  },
  {
    "country": "ME",
    "name": "Andrijevica",
    "lat": "42.73389",
    "lng": "19.79194"
  },
  {
    "country": "ME",
    "name": "Petnjica",
    "lat": "42.90889",
    "lng": "19.96444"
  },
  {
    "country": "ME",
    "name": "Šušanj",
    "lat": "42.11556",
    "lng": "19.08833"
  },
  {
    "country": "MF",
    "name": "Marigot",
    "lat": "18.06819",
    "lng": "-63.08302"
  },
  {
    "country": "MG",
    "name": "Toamasina",
    "lat": "-18.1492",
    "lng": "49.40234"
  },
  {
    "country": "MG",
    "name": "Vondrozo",
    "lat": "-22.81667",
    "lng": "47.28333"
  },
  {
    "country": "MG",
    "name": "Vohipaho",
    "lat": "-23.55",
    "lng": "47.5"
  },
  {
    "country": "MG",
    "name": "Vohimanitra",
    "lat": "-21.7",
    "lng": "47.7"
  },
  {
    "country": "MG",
    "name": "Vohibinany",
    "lat": "-17.35",
    "lng": "49.03333"
  },
  {
    "country": "MG",
    "name": "Vavatenina",
    "lat": "-17.46667",
    "lng": "49.2"
  },
  {
    "country": "MG",
    "name": "Vangaindrano",
    "lat": "-23.35",
    "lng": "47.6"
  },
  {
    "country": "MG",
    "name": "Tsiroanomandidy",
    "lat": "-18.76969",
    "lng": "46.04653"
  },
  {
    "country": "MG",
    "name": "Tsiombe",
    "lat": "-25.3",
    "lng": "45.48333"
  },
  {
    "country": "MG",
    "name": "Tsaratanana",
    "lat": "-16.79706",
    "lng": "47.65165"
  },
  {
    "country": "MG",
    "name": "Tranovaho",
    "lat": "-25.3",
    "lng": "44.96667"
  },
  {
    "country": "MG",
    "name": "Toliara",
    "lat": "-23.35",
    "lng": "43.66667"
  },
  {
    "country": "MG",
    "name": "Tôlanaro",
    "lat": "-25.03249",
    "lng": "46.98329"
  },
  {
    "country": "MG",
    "name": "Soavinandriana",
    "lat": "-19.16667",
    "lng": "46.73333"
  },
  {
    "country": "MG",
    "name": "Soanindrariny",
    "lat": "-19.9",
    "lng": "47.23333"
  },
  {
    "country": "MG",
    "name": "Soanierana Ivongo",
    "lat": "-16.91667",
    "lng": "49.58333"
  },
  {
    "country": "MG",
    "name": "Sitampiky",
    "lat": "-16.66667",
    "lng": "46.1"
  },
  {
    "country": "MG",
    "name": "Savana",
    "lat": "-22.38333",
    "lng": "47.9"
  },
  {
    "country": "MG",
    "name": "Sambava",
    "lat": "-14.26667",
    "lng": "50.16667"
  },
  {
    "country": "MG",
    "name": "Sambaina",
    "lat": "-18.9",
    "lng": "47.78333"
  },
  {
    "country": "MG",
    "name": "Sakaraha",
    "lat": "-22.9",
    "lng": "44.53333"
  },
  {
    "country": "MG",
    "name": "Sahavato",
    "lat": "-20.6",
    "lng": "48.33333"
  },
  {
    "country": "MG",
    "name": "Sahatavy",
    "lat": "-17.45",
    "lng": "49"
  },
  {
    "country": "MG",
    "name": "Sadjoavato",
    "lat": "-12.61667",
    "lng": "49.35"
  },
  {
    "country": "MG",
    "name": "Sadabe",
    "lat": "-18.63333",
    "lng": "47.7"
  },
  {
    "country": "MG",
    "name": "Ranohira",
    "lat": "-22.48333",
    "lng": "45.4"
  },
  {
    "country": "MG",
    "name": "Nosy Varika",
    "lat": "-20.58333",
    "lng": "48.53333"
  },
  {
    "country": "MG",
    "name": "Nandihizana",
    "lat": "-18.9",
    "lng": "47.71667"
  },
  {
    "country": "MG",
    "name": "Morondava",
    "lat": "-20.28869",
    "lng": "44.31782"
  },
  {
    "country": "MG",
    "name": "Moramanga",
    "lat": "-18.94948",
    "lng": "48.23007"
  },
  {
    "country": "MG",
    "name": "Miarinarivo",
    "lat": "-18.95873",
    "lng": "46.90553"
  },
  {
    "country": "MG",
    "name": "Miandrivazo",
    "lat": "-19.52905",
    "lng": "45.45559"
  },
  {
    "country": "MG",
    "name": "Miandrarivo",
    "lat": "-19.43333",
    "lng": "46.75"
  },
  {
    "country": "MG",
    "name": "Miadanandriana",
    "lat": "-19.03333",
    "lng": "47.78333"
  },
  {
    "country": "MG",
    "name": "Merikanjaka",
    "lat": "-19.13333",
    "lng": "47.85"
  },
  {
    "country": "MG",
    "name": "Marovoay",
    "lat": "-16.11064",
    "lng": "46.64383"
  },
  {
    "country": "MG",
    "name": "Marolambo",
    "lat": "-20.05",
    "lng": "48.11667"
  },
  {
    "country": "MG",
    "name": "Maroantsetra",
    "lat": "-15.43527",
    "lng": "49.73794"
  },
  {
    "country": "MG",
    "name": "Mantasoa",
    "lat": "-19.01667",
    "lng": "47.83333"
  },
  {
    "country": "MG",
    "name": "Manjakandriana",
    "lat": "-18.91667",
    "lng": "47.8"
  },
  {
    "country": "MG",
    "name": "Manja",
    "lat": "-21.43333",
    "lng": "44.33333"
  },
  {
    "country": "MG",
    "name": "Mandritsara",
    "lat": "-15.85744",
    "lng": "48.82824"
  },
  {
    "country": "MG",
    "name": "Manato",
    "lat": "-22.4",
    "lng": "47.48333"
  },
  {
    "country": "MG",
    "name": "Mananjary",
    "lat": "-21.23034",
    "lng": "48.34173"
  },
  {
    "country": "MG",
    "name": "Mananara",
    "lat": "-16.16864",
    "lng": "49.76622"
  },
  {
    "country": "MG",
    "name": "Manakara",
    "lat": "-22.14862",
    "lng": "48.01055"
  },
  {
    "country": "MG",
    "name": "Maintirano",
    "lat": "-18.06354",
    "lng": "44.02951"
  },
  {
    "country": "MG",
    "name": "Mahavelona",
    "lat": "-17.68475",
    "lng": "49.50869"
  },
  {
    "country": "MG",
    "name": "Mahanoro",
    "lat": "-19.9",
    "lng": "48.8"
  },
  {
    "country": "MG",
    "name": "Mahalina",
    "lat": "-12.53333",
    "lng": "48.81667"
  },
  {
    "country": "MG",
    "name": "Mahajanga",
    "lat": "-15.71667",
    "lng": "46.31667"
  },
  {
    "country": "MG",
    "name": "Mahabe",
    "lat": "-17.08333",
    "lng": "45.33333"
  },
  {
    "country": "MG",
    "name": "Maevatanana",
    "lat": "-16.95",
    "lng": "46.83333"
  },
  {
    "country": "MG",
    "name": "Kopoky",
    "lat": "-25.2",
    "lng": "45.2"
  },
  {
    "country": "MG",
    "name": "Ikongo",
    "lat": "-21.88333",
    "lng": "47.43333"
  },
  {
    "country": "MG",
    "name": "Ikalamavony",
    "lat": "-21.15",
    "lng": "46.58333"
  },
  {
    "country": "MG",
    "name": "Ihosy",
    "lat": "-22.40293",
    "lng": "46.12576"
  },
  {
    "country": "MG",
    "name": "Ifatsy",
    "lat": "-22.4",
    "lng": "47.75"
  },
  {
    "country": "MG",
    "name": "Ifanadiana",
    "lat": "-21.3",
    "lng": "47.63333"
  },
  {
    "country": "MG",
    "name": "Fianarantsoa",
    "lat": "-21.45267",
    "lng": "47.08569"
  },
  {
    "country": "MG",
    "name": "Fenoarivo Be",
    "lat": "-18.43333",
    "lng": "46.56667"
  },
  {
    "country": "MG",
    "name": "Fenoarivo Atsinanana",
    "lat": "-17.38095",
    "lng": "49.40826"
  },
  {
    "country": "MG",
    "name": "Faratsiho",
    "lat": "-19.4",
    "lng": "46.95"
  },
  {
    "country": "MG",
    "name": "Farafangana",
    "lat": "-22.82223",
    "lng": "47.82615"
  },
  {
    "country": "MG",
    "name": "Fandriana",
    "lat": "-20.23333",
    "lng": "47.38333"
  },
  {
    "country": "MG",
    "name": "Fandrandava",
    "lat": "-21.51667",
    "lng": "47.25"
  },
  {
    "country": "MG",
    "name": "Betioky",
    "lat": "-23.72065",
    "lng": "44.38069"
  },
  {
    "country": "MG",
    "name": "Beteza",
    "lat": "-24.45",
    "lng": "45.11667"
  },
  {
    "country": "MG",
    "name": "Betafo",
    "lat": "-19.83333",
    "lng": "46.85"
  },
  {
    "country": "MG",
    "name": "Beroroha",
    "lat": "-21.66667",
    "lng": "45.16667"
  },
  {
    "country": "MG",
    "name": "Bemaitso",
    "lat": "-17.06667",
    "lng": "48.5"
  },
  {
    "country": "MG",
    "name": "Belo sur Tsiribihina",
    "lat": "-19.69787",
    "lng": "44.54587"
  },
  {
    "country": "MG",
    "name": "Beloha",
    "lat": "-25.16667",
    "lng": "45.05"
  },
  {
    "country": "MG",
    "name": "Behompy",
    "lat": "-23.25",
    "lng": "43.85"
  },
  {
    "country": "MG",
    "name": "Bealanana",
    "lat": "-14.54329",
    "lng": "48.74981"
  },
  {
    "country": "MG",
    "name": "Arivonimamo",
    "lat": "-19.01667",
    "lng": "47.18333"
  },
  {
    "country": "MG",
    "name": "Antsohimbondrona",
    "lat": "-13.08333",
    "lng": "48.85"
  },
  {
    "country": "MG",
    "name": "Antsohihy",
    "lat": "-14.87959",
    "lng": "47.98751"
  },
  {
    "country": "MG",
    "name": "Antsiranana",
    "lat": "-12.31732",
    "lng": "49.29188"
  },
  {
    "country": "MG",
    "name": "Antsirabe Afovoany",
    "lat": "-15.95",
    "lng": "48.96667"
  },
  {
    "country": "MG",
    "name": "Antsirabe",
    "lat": "-19.86586",
    "lng": "47.03333"
  },
  {
    "country": "MG",
    "name": "Antanimena",
    "lat": "-23.55",
    "lng": "44.1"
  },
  {
    "country": "MG",
    "name": "Antanifotsy",
    "lat": "-19.65",
    "lng": "47.31667"
  },
  {
    "country": "MG",
    "name": "Antananarivo",
    "lat": "-18.91368",
    "lng": "47.53613"
  },
  {
    "country": "MG",
    "name": "Antalaha",
    "lat": "-14.90033",
    "lng": "50.27876"
  },
  {
    "country": "MG",
    "name": "Antakotako",
    "lat": "-15.31667",
    "lng": "49.8"
  },
  {
    "country": "MG",
    "name": "Ankazondandy",
    "lat": "-18.7",
    "lng": "47.78333"
  },
  {
    "country": "MG",
    "name": "Ankazobe",
    "lat": "-18.31667",
    "lng": "47.11667"
  },
  {
    "country": "MG",
    "name": "Ankazoabo",
    "lat": "-22.28333",
    "lng": "44.51667"
  },
  {
    "country": "MG",
    "name": "Anjozorobe",
    "lat": "-18.4",
    "lng": "47.86667"
  },
  {
    "country": "MG",
    "name": "Anjepy",
    "lat": "-18.85",
    "lng": "47.71667"
  },
  {
    "country": "MG",
    "name": "Andramasina",
    "lat": "-19.18785",
    "lng": "47.59016"
  },
  {
    "country": "MG",
    "name": "Hell-Ville",
    "lat": "-13.39718",
    "lng": "48.26663"
  },
  {
    "country": "MG",
    "name": "Andilamena",
    "lat": "-17.01009",
    "lng": "48.57313"
  },
  {
    "country": "MG",
    "name": "Andovoranto",
    "lat": "-18.95443",
    "lng": "49.1094"
  },
  {
    "country": "MG",
    "name": "Andapa",
    "lat": "-14.65",
    "lng": "49.65"
  },
  {
    "country": "MG",
    "name": "Anandravy",
    "lat": "-22.9",
    "lng": "47.36667"
  },
  {
    "country": "MG",
    "name": "Anakao",
    "lat": "-23.66667",
    "lng": "43.65"
  },
  {
    "country": "MG",
    "name": "Ampasimanolotra",
    "lat": "-18.81667",
    "lng": "49.06667"
  },
  {
    "country": "MG",
    "name": "Amparafaravola",
    "lat": "-17.5876",
    "lng": "48.22391"
  },
  {
    "country": "MG",
    "name": "Ampanihy",
    "lat": "-24.6937",
    "lng": "44.74581"
  },
  {
    "country": "MG",
    "name": "Ampahana",
    "lat": "-14.75",
    "lng": "50.21667"
  },
  {
    "country": "MG",
    "name": "Ambovombe",
    "lat": "-25.17838",
    "lng": "46.08722"
  },
  {
    "country": "MG",
    "name": "Ambositra",
    "lat": "-20.53034",
    "lng": "47.24344"
  },
  {
    "country": "MG",
    "name": "Ambohitseheno",
    "lat": "-18.78333",
    "lng": "47.8"
  },
  {
    "country": "MG",
    "name": "Ambohitrolomahitsy",
    "lat": "-18.7",
    "lng": "47.68333"
  },
  {
    "country": "MG",
    "name": "Ambohitrandriamanitra",
    "lat": "-19.08333",
    "lng": "47.78333"
  },
  {
    "country": "MG",
    "name": "Ambodivoara",
    "lat": "-14.33333",
    "lng": "49.98333"
  },
  {
    "country": "MG",
    "name": "Ambodifotatra",
    "lat": "-16.98333",
    "lng": "49.85"
  },
  {
    "country": "MG",
    "name": "Amboasary",
    "lat": "-25.03333",
    "lng": "46.38333"
  },
  {
    "country": "MG",
    "name": "Amboasary",
    "lat": "-24.33333",
    "lng": "45.95"
  },
  {
    "country": "MG",
    "name": "Amboanjo",
    "lat": "-22",
    "lng": "47.85"
  },
  {
    "country": "MG",
    "name": "Ambilobe",
    "lat": "-13.2",
    "lng": "49.05"
  },
  {
    "country": "MG",
    "name": "Ambatondrazaka",
    "lat": "-17.83333",
    "lng": "48.41667"
  },
  {
    "country": "MG",
    "name": "Ambatolaona",
    "lat": "-18.93333",
    "lng": "47.9"
  },
  {
    "country": "MG",
    "name": "Ambatolampy",
    "lat": "-19.38333",
    "lng": "47.41667"
  },
  {
    "country": "MG",
    "name": "Ambatofinandrahana",
    "lat": "-20.55284",
    "lng": "46.80365"
  },
  {
    "country": "MG",
    "name": "Ambato Boeny",
    "lat": "-16.46667",
    "lng": "46.71667"
  },
  {
    "country": "MG",
    "name": "Ambarakaraka",
    "lat": "-13.5",
    "lng": "48.86667"
  },
  {
    "country": "MG",
    "name": "Ambanja",
    "lat": "-13.669",
    "lng": "48.453"
  },
  {
    "country": "MG",
    "name": "Ambalavao",
    "lat": "-21.83333",
    "lng": "46.93333"
  },
  {
    "country": "MG",
    "name": "Ambalasoa",
    "lat": "-23.11667",
    "lng": "46"
  },
  {
    "country": "MG",
    "name": "Alarobia",
    "lat": "-18.96667",
    "lng": "47.73333"
  },
  {
    "country": "MG",
    "name": "Antsampanimahazo",
    "lat": "-19.63988",
    "lng": "47.1565"
  },
  {
    "country": "MH",
    "name": "Likiep",
    "lat": "9.82511",
    "lng": "169.31065"
  },
  {
    "country": "MH",
    "name": "Jabor",
    "lat": "5.92098",
    "lng": "169.64335"
  },
  {
    "country": "MH",
    "name": "Ailuk",
    "lat": "10.21972",
    "lng": "169.97967"
  },
  {
    "country": "MH",
    "name": "Majuro",
    "lat": "7.08971",
    "lng": "171.38027"
  },
  {
    "country": "MH",
    "name": "Taroa",
    "lat": "8.70576",
    "lng": "171.2275"
  },
  {
    "country": "MH",
    "name": "Ebaye",
    "lat": "8.77479",
    "lng": "167.73919"
  },
  {
    "country": "MH",
    "name": "Enewetak",
    "lat": "11.34735",
    "lng": "162.33733"
  },
  {
    "country": "MH",
    "name": "Ebon",
    "lat": "4.58199",
    "lng": "168.69636"
  },
  {
    "country": "MH",
    "name": "Aur",
    "lat": "8.1499",
    "lng": "171.16869"
  },
  {
    "country": "MH",
    "name": "Arno",
    "lat": "7.06691",
    "lng": "171.55413"
  },
  {
    "country": "MH",
    "name": "Airuk",
    "lat": "7.27717",
    "lng": "168.8203"
  },
  {
    "country": "MH",
    "name": "Mili",
    "lat": "6.0815",
    "lng": "171.73502"
  },
  {
    "country": "MH",
    "name": "Lae",
    "lat": "8.92217",
    "lng": "166.26344"
  },
  {
    "country": "MH",
    "name": "Utrik",
    "lat": "11.22778",
    "lng": "169.84739"
  },
  {
    "country": "MH",
    "name": "Ujae",
    "lat": "8.93218",
    "lng": "165.76416"
  },
  {
    "country": "MH",
    "name": "Rongelap",
    "lat": "11.16351",
    "lng": "166.89408"
  },
  {
    "country": "MH",
    "name": "Loen",
    "lat": "7.76007",
    "lng": "168.23072"
  },
  {
    "country": "MH",
    "name": "Namdrik",
    "lat": "5.59944",
    "lng": "168.10282"
  },
  {
    "country": "MH",
    "name": "Mejit",
    "lat": "10.27531",
    "lng": "170.86461"
  },
  {
    "country": "MH",
    "name": "Lib",
    "lat": "8.31221",
    "lng": "167.37662"
  },
  {
    "country": "MH",
    "name": "Kili",
    "lat": "5.64387",
    "lng": "169.12109"
  },
  {
    "country": "MH",
    "name": "Jabat",
    "lat": "7.75003",
    "lng": "168.97513"
  },
  {
    "country": "MH",
    "name": "Wotje",
    "lat": "9.45429",
    "lng": "170.23674"
  },
  {
    "country": "MH",
    "name": "Wotho",
    "lat": "10.16575",
    "lng": "166.01022"
  },
  {
    "country": "MH",
    "name": "RMI Capitol",
    "lat": "7.08931",
    "lng": "171.3805"
  },
  {
    "country": "MK",
    "name": "Zrnovci",
    "lat": "41.85417",
    "lng": "22.44444"
  },
  {
    "country": "MK",
    "name": "Zletovo",
    "lat": "41.98861",
    "lng": "22.23611"
  },
  {
    "country": "MK",
    "name": "Žitoše",
    "lat": "41.41991",
    "lng": "21.29078"
  },
  {
    "country": "MK",
    "name": "Zelino",
    "lat": "41.98028",
    "lng": "21.06417"
  },
  {
    "country": "MK",
    "name": "Zelenikovo",
    "lat": "41.88413",
    "lng": "21.58848"
  },
  {
    "country": "MK",
    "name": "Zajas",
    "lat": "41.60722",
    "lng": "20.93833"
  },
  {
    "country": "MK",
    "name": "Vrutok",
    "lat": "41.76861",
    "lng": "20.83917"
  },
  {
    "country": "MK",
    "name": "Vratnica",
    "lat": "42.14333",
    "lng": "21.11694"
  },
  {
    "country": "MK",
    "name": "Vrapčište",
    "lat": "41.83439",
    "lng": "20.88563"
  },
  {
    "country": "MK",
    "name": "Vraneštica",
    "lat": "41.44496",
    "lng": "21.02683"
  },
  {
    "country": "MK",
    "name": "Vladimirovo",
    "lat": "41.71",
    "lng": "22.79278"
  },
  {
    "country": "MK",
    "name": "Vinica",
    "lat": "41.88278",
    "lng": "22.50917"
  },
  {
    "country": "MK",
    "name": "Vevčani",
    "lat": "41.24056",
    "lng": "20.59333"
  },
  {
    "country": "MK",
    "name": "Veljusa",
    "lat": "41.47611",
    "lng": "22.5675"
  },
  {
    "country": "MK",
    "name": "Velesta",
    "lat": "41.24083",
    "lng": "20.64389"
  },
  {
    "country": "MK",
    "name": "Vataša",
    "lat": "41.41694",
    "lng": "22.01889"
  },
  {
    "country": "MK",
    "name": "Vasilevo",
    "lat": "41.47408",
    "lng": "22.64301"
  },
  {
    "country": "MK",
    "name": "Markov Grad",
    "lat": "41.35722",
    "lng": "21.5325"
  },
  {
    "country": "MK",
    "name": "Valandovo",
    "lat": "41.31744",
    "lng": "22.56002"
  },
  {
    "country": "MK",
    "name": "Vaksince",
    "lat": "42.20611",
    "lng": "21.66306"
  },
  {
    "country": "MK",
    "name": "Usje",
    "lat": "41.95871",
    "lng": "21.45835"
  },
  {
    "country": "MK",
    "name": "Tuin",
    "lat": "41.61944",
    "lng": "21.04528"
  },
  {
    "country": "MK",
    "name": "Topolčani",
    "lat": "41.22772",
    "lng": "21.43113"
  },
  {
    "country": "MK",
    "name": "Veles",
    "lat": "41.71556",
    "lng": "21.77556"
  },
  {
    "country": "MK",
    "name": "Tetovo",
    "lat": "42.00973",
    "lng": "20.97155"
  },
  {
    "country": "MK",
    "name": "Tearce",
    "lat": "42.07666",
    "lng": "21.0531"
  },
  {
    "country": "MK",
    "name": "Sveti Nikole",
    "lat": "41.86956",
    "lng": "21.95274"
  },
  {
    "country": "MK",
    "name": "Sušica",
    "lat": "41.43982",
    "lng": "22.83676"
  },
  {
    "country": "MK",
    "name": "Студеничани",
    "lat": "41.91583",
    "lng": "21.53056"
  },
  {
    "country": "MK",
    "name": "Strumica",
    "lat": "41.4375",
    "lng": "22.64333"
  },
  {
    "country": "MK",
    "name": "Struga",
    "lat": "41.17799",
    "lng": "20.67784"
  },
  {
    "country": "MK",
    "name": "Strelci",
    "lat": "41.54046",
    "lng": "21.00563"
  },
  {
    "country": "MK",
    "name": "Stojakovo",
    "lat": "41.15556",
    "lng": "22.5775"
  },
  {
    "country": "MK",
    "name": "Shtip",
    "lat": "41.74583",
    "lng": "22.19583"
  },
  {
    "country": "MK",
    "name": "Старо Нагоричане",
    "lat": "42.19806",
    "lng": "21.82861"
  },
  {
    "country": "MK",
    "name": "Star Dojran",
    "lat": "41.18647",
    "lng": "22.7203"
  },
  {
    "country": "MK",
    "name": "Dolno Srpci",
    "lat": "41.1748",
    "lng": "21.36464"
  },
  {
    "country": "MK",
    "name": "Sredno Konjare",
    "lat": "41.95743",
    "lng": "21.71494"
  },
  {
    "country": "MK",
    "name": "Srbinovo",
    "lat": "41.70586",
    "lng": "20.95859"
  },
  {
    "country": "MK",
    "name": "Srbica",
    "lat": "41.58672",
    "lng": "21.03027"
  },
  {
    "country": "MK",
    "name": "Sopotnica",
    "lat": "41.29594",
    "lng": "21.15357"
  },
  {
    "country": "MK",
    "name": "Сопиште",
    "lat": "41.95472",
    "lng": "21.4275"
  },
  {
    "country": "MK",
    "name": "Слупчане",
    "lat": "42.17333",
    "lng": "21.62778"
  },
  {
    "country": "MK",
    "name": "Slepče",
    "lat": "41.23333",
    "lng": "21.175"
  },
  {
    "country": "MK",
    "name": "Slatino",
    "lat": "42.06784",
    "lng": "21.03902"
  },
  {
    "country": "MK",
    "name": "Skopje",
    "lat": "41.99646",
    "lng": "21.43141"
  },
  {
    "country": "MK",
    "name": "Šipkovica",
    "lat": "42.035",
    "lng": "20.91556"
  },
  {
    "country": "MK",
    "name": "Selce",
    "lat": "42.03482",
    "lng": "20.94035"
  },
  {
    "country": "MK",
    "name": "Sekirnik",
    "lat": "41.43999",
    "lng": "22.79536"
  },
  {
    "country": "MK",
    "name": "Sedlarevo",
    "lat": "41.88306",
    "lng": "21.1275"
  },
  {
    "country": "MK",
    "name": "Saraj",
    "lat": "42",
    "lng": "21.32778"
  },
  {
    "country": "MK",
    "name": "Samokov",
    "lat": "41.68331",
    "lng": "21.14625"
  },
  {
    "country": "MK",
    "name": "Rusinovo",
    "lat": "41.68728",
    "lng": "22.80849"
  },
  {
    "country": "MK",
    "name": "Rostusa",
    "lat": "41.61",
    "lng": "20.6"
  },
  {
    "country": "MK",
    "name": "Rosoman",
    "lat": "41.51671",
    "lng": "21.94585"
  },
  {
    "country": "MK",
    "name": "Romanovci",
    "lat": "42.09472",
    "lng": "21.69306"
  },
  {
    "country": "MK",
    "name": "Resen",
    "lat": "41.08934",
    "lng": "21.01092"
  },
  {
    "country": "MK",
    "name": "Ранковце",
    "lat": "42.16964",
    "lng": "22.11617"
  },
  {
    "country": "MK",
    "name": "Radovis",
    "lat": "41.63833",
    "lng": "22.46472"
  },
  {
    "country": "MK",
    "name": "Radolista",
    "lat": "41.16417",
    "lng": "20.62333"
  },
  {
    "country": "MK",
    "name": "Radishani",
    "lat": "42.06111",
    "lng": "21.44778"
  },
  {
    "country": "MK",
    "name": "Pršovce",
    "lat": "42.08336",
    "lng": "21.05994"
  },
  {
    "country": "MK",
    "name": "Probishtip",
    "lat": "42.00306",
    "lng": "22.17861"
  },
  {
    "country": "MK",
    "name": "Prilep",
    "lat": "41.34514",
    "lng": "21.55504"
  },
  {
    "country": "MK",
    "name": "Podareš",
    "lat": "41.61389",
    "lng": "22.54222"
  },
  {
    "country": "MK",
    "name": "Plasnica",
    "lat": "41.46722",
    "lng": "21.12306"
  },
  {
    "country": "MK",
    "name": "Pirok",
    "lat": "41.91083",
    "lng": "20.91056"
  },
  {
    "country": "MK",
    "name": "Pirava",
    "lat": "41.32042",
    "lng": "22.53047"
  },
  {
    "country": "MK",
    "name": "Петровец",
    "lat": "41.93889",
    "lng": "21.615"
  },
  {
    "country": "MK",
    "name": "Pehčevo",
    "lat": "41.76226",
    "lng": "22.88921"
  },
  {
    "country": "MK",
    "name": "Otlja",
    "lat": "42.14315",
    "lng": "21.58675"
  },
  {
    "country": "MK",
    "name": "Orizari",
    "lat": "41.92262",
    "lng": "22.44628"
  },
  {
    "country": "MK",
    "name": "Orashac",
    "lat": "42.0625",
    "lng": "21.79972"
  },
  {
    "country": "MK",
    "name": "Oraovica",
    "lat": "41.62583",
    "lng": "22.51333"
  },
  {
    "country": "MK",
    "name": "Oktisi",
    "lat": "41.2325",
    "lng": "20.60722"
  },
  {
    "country": "MK",
    "name": "Ohrid",
    "lat": "41.11722",
    "lng": "20.80194"
  },
  {
    "country": "MK",
    "name": "Ognjaci",
    "lat": "41.92167",
    "lng": "21.58306"
  },
  {
    "country": "MK",
    "name": "Obršani",
    "lat": "41.28168",
    "lng": "21.3615"
  },
  {
    "country": "MK",
    "name": "Oblesevo",
    "lat": "41.88333",
    "lng": "22.33389"
  },
  {
    "country": "MK",
    "name": "Novo Selo",
    "lat": "41.41486",
    "lng": "22.88164"
  },
  {
    "country": "MK",
    "name": "Novaci",
    "lat": "41.04197",
    "lng": "21.45866"
  },
  {
    "country": "MK",
    "name": "Нераште",
    "lat": "42.10667",
    "lng": "21.10889"
  },
  {
    "country": "MK",
    "name": "Negotino",
    "lat": "41.87792",
    "lng": "20.88389"
  },
  {
    "country": "MK",
    "name": "Negotino",
    "lat": "41.48456",
    "lng": "22.09056"
  },
  {
    "country": "MK",
    "name": "Murtino",
    "lat": "41.41537",
    "lng": "22.72589"
  },
  {
    "country": "MK",
    "name": "Demir Hisar",
    "lat": "41.22097",
    "lng": "21.20302"
  },
  {
    "country": "MK",
    "name": "Morani",
    "lat": "41.90978",
    "lng": "21.54997"
  },
  {
    "country": "MK",
    "name": "Mogila",
    "lat": "41.10833",
    "lng": "21.37861"
  },
  {
    "country": "MK",
    "name": "Mislesevo",
    "lat": "41.185",
    "lng": "20.70861"
  },
  {
    "country": "MK",
    "name": "Miravci",
    "lat": "41.30925",
    "lng": "22.43641"
  },
  {
    "country": "MK",
    "name": "Miletino",
    "lat": "41.90753",
    "lng": "21.01601"
  },
  {
    "country": "MK",
    "name": "Miladinovci",
    "lat": "41.98029",
    "lng": "21.64982"
  },
  {
    "country": "MK",
    "name": "Mešeišta",
    "lat": "41.23814",
    "lng": "20.77414"
  },
  {
    "country": "MK",
    "name": "Matejce",
    "lat": "42.12556",
    "lng": "21.59778"
  },
  {
    "country": "MK",
    "name": "Marino",
    "lat": "41.98776",
    "lng": "21.59148"
  },
  {
    "country": "MK",
    "name": "Lukovo",
    "lat": "41.35339",
    "lng": "20.60637"
  },
  {
    "country": "MK",
    "name": "Lojane",
    "lat": "42.23276",
    "lng": "21.6655"
  },
  {
    "country": "MK",
    "name": "Logovardi",
    "lat": "41.03096",
    "lng": "21.40967"
  },
  {
    "country": "MK",
    "name": "Ljubin",
    "lat": "42.00139",
    "lng": "21.30917"
  },
  {
    "country": "MK",
    "name": "Lisičani",
    "lat": "41.46139",
    "lng": "21.05444"
  },
  {
    "country": "MK",
    "name": "Lipkovo",
    "lat": "42.15639",
    "lng": "21.58528"
  },
  {
    "country": "MK",
    "name": "Lažani",
    "lat": "41.44222",
    "lng": "21.31583"
  },
  {
    "country": "MK",
    "name": "Larce",
    "lat": "41.93319",
    "lng": "21.12628"
  },
  {
    "country": "MK",
    "name": "Labunista",
    "lat": "41.26861",
    "lng": "20.59611"
  },
  {
    "country": "MK",
    "name": "Kumanovo",
    "lat": "42.13222",
    "lng": "21.71444"
  },
  {
    "country": "MK",
    "name": "Kukurečani",
    "lat": "41.09562",
    "lng": "21.32454"
  },
  {
    "country": "MK",
    "name": "Kuklis",
    "lat": "41.40528",
    "lng": "22.66528"
  },
  {
    "country": "MK",
    "name": "Крушопек",
    "lat": "41.97833",
    "lng": "21.35444"
  },
  {
    "country": "MK",
    "name": "Krusevo",
    "lat": "41.36889",
    "lng": "21.24889"
  },
  {
    "country": "MK",
    "name": "Krivogashtani",
    "lat": "41.33611",
    "lng": "21.33306"
  },
  {
    "country": "MK",
    "name": "Kriva Palanka",
    "lat": "42.20088",
    "lng": "22.33244"
  },
  {
    "country": "MK",
    "name": "Kratovo",
    "lat": "42.07838",
    "lng": "22.1807"
  },
  {
    "country": "MK",
    "name": "Krani",
    "lat": "40.93934",
    "lng": "21.10911"
  },
  {
    "country": "MK",
    "name": "Kosel",
    "lat": "41.17444",
    "lng": "20.83556"
  },
  {
    "country": "MK",
    "name": "Kondovo",
    "lat": "42.01167",
    "lng": "21.31361"
  },
  {
    "country": "MK",
    "name": "Konče",
    "lat": "41.49511",
    "lng": "22.38359"
  },
  {
    "country": "MK",
    "name": "Kochani",
    "lat": "41.91639",
    "lng": "22.41278"
  },
  {
    "country": "MK",
    "name": "Клечовце",
    "lat": "42.11611",
    "lng": "21.85722"
  },
  {
    "country": "MK",
    "name": "Kičevo",
    "lat": "41.51267",
    "lng": "20.95886"
  },
  {
    "country": "MK",
    "name": "Kavadarci",
    "lat": "41.43306",
    "lng": "22.01194"
  },
  {
    "country": "MK",
    "name": "Karbinci",
    "lat": "41.81758",
    "lng": "22.23529"
  },
  {
    "country": "MK",
    "name": "Kanatlarci",
    "lat": "41.21028",
    "lng": "21.50333"
  },
  {
    "country": "MK",
    "name": "Kamenjane",
    "lat": "41.94568",
    "lng": "20.92894"
  },
  {
    "country": "MK",
    "name": "Makedonska Kamenica",
    "lat": "42.02079",
    "lng": "22.5876"
  },
  {
    "country": "MK",
    "name": "Kadino",
    "lat": "41.96889",
    "lng": "21.60139"
  },
  {
    "country": "MK",
    "name": "Јурумлери",
    "lat": "41.96722",
    "lng": "21.55694"
  },
  {
    "country": "MK",
    "name": "Jegunovce",
    "lat": "42.07238",
    "lng": "21.12367"
  },
  {
    "country": "MK",
    "name": "Jankovec",
    "lat": "41.11028",
    "lng": "21.01139"
  },
  {
    "country": "MK",
    "name": "Izvor",
    "lat": "42.20322",
    "lng": "21.57812"
  },
  {
    "country": "MK",
    "name": "Ivankovci",
    "lat": "41.84889",
    "lng": "21.82028"
  },
  {
    "country": "MK",
    "name": "Ilovica",
    "lat": "41.47224",
    "lng": "22.8048"
  },
  {
    "country": "MK",
    "name": "Идризово",
    "lat": "41.96083",
    "lng": "21.57556"
  },
  {
    "country": "MK",
    "name": "Gurgurnica",
    "lat": "41.84508",
    "lng": "21.10538"
  },
  {
    "country": "MK",
    "name": "Grnčari",
    "lat": "41.01722",
    "lng": "21.05333"
  },
  {
    "country": "MK",
    "name": "Грчец",
    "lat": "41.98806",
    "lng": "21.33028"
  },
  {
    "country": "MK",
    "name": "Gradsko",
    "lat": "41.5775",
    "lng": "21.94278"
  },
  {
    "country": "MK",
    "name": "Gradec",
    "lat": "41.89611",
    "lng": "20.90417"
  },
  {
    "country": "MK",
    "name": "Gradec",
    "lat": "41.85068",
    "lng": "22.51132"
  },
  {
    "country": "MK",
    "name": "Gostivar",
    "lat": "41.79601",
    "lng": "20.90819"
  },
  {
    "country": "MK",
    "name": "Gorobinci",
    "lat": "41.87507",
    "lng": "21.87599"
  },
  {
    "country": "MK",
    "name": "Gorno Orizari",
    "lat": "41.68583",
    "lng": "21.73475"
  },
  {
    "country": "MK",
    "name": "Gorno Orizari",
    "lat": "41.05188",
    "lng": "21.34548"
  },
  {
    "country": "MK",
    "name": "Golema Rečica",
    "lat": "41.98803",
    "lng": "20.94517"
  },
  {
    "country": "MK",
    "name": "Gevgelija",
    "lat": "41.14166",
    "lng": "22.50141"
  },
  {
    "country": "MK",
    "name": "Forino",
    "lat": "41.82334",
    "lng": "20.96174"
  },
  {
    "country": "MK",
    "name": "Lozovo",
    "lat": "41.78389",
    "lng": "21.90556"
  },
  {
    "country": "MK",
    "name": "Džepčište",
    "lat": "42.03287",
    "lng": "20.99817"
  },
  {
    "country": "MK",
    "name": "Drugovo",
    "lat": "41.4849",
    "lng": "20.92636"
  },
  {
    "country": "MK",
    "name": "Dračevo",
    "lat": "41.93667",
    "lng": "21.52167"
  },
  {
    "country": "MK",
    "name": "Gjorče Petro",
    "lat": "42.00778",
    "lng": "21.35306"
  },
  {
    "country": "MK",
    "name": "Dolno Palčište",
    "lat": "41.96859",
    "lng": "20.92899"
  },
  {
    "country": "MK",
    "name": "Dolno Orizari",
    "lat": "41.05028",
    "lng": "21.37944"
  },
  {
    "country": "MK",
    "name": "Dolno Količani",
    "lat": "41.88639",
    "lng": "21.48556"
  },
  {
    "country": "MK",
    "name": "Dolneni",
    "lat": "41.42579",
    "lng": "21.45402"
  },
  {
    "country": "MK",
    "name": "Dolna Banjica",
    "lat": "41.78611",
    "lng": "20.90611"
  },
  {
    "country": "MK",
    "name": "Dobruševo",
    "lat": "41.16861",
    "lng": "21.4825"
  },
  {
    "country": "MK",
    "name": "Dobrošte",
    "lat": "42.10333",
    "lng": "21.07778"
  },
  {
    "country": "MK",
    "name": "Dobri Dol",
    "lat": "41.8652",
    "lng": "20.89009"
  },
  {
    "country": "MK",
    "name": "Desovo",
    "lat": "41.46278",
    "lng": "21.49111"
  },
  {
    "country": "MK",
    "name": "Demir Kapija",
    "lat": "41.40613",
    "lng": "22.24631"
  },
  {
    "country": "MK",
    "name": "Delogožda",
    "lat": "41.25728",
    "lng": "20.7218"
  },
  {
    "country": "MK",
    "name": "Delcevo",
    "lat": "41.96722",
    "lng": "22.76944"
  },
  {
    "country": "MK",
    "name": "Debar",
    "lat": "41.52444",
    "lng": "20.52421"
  },
  {
    "country": "MK",
    "name": "Чучер - Сандево",
    "lat": "42.10361",
    "lng": "21.38222"
  },
  {
    "country": "MK",
    "name": "Crnilište",
    "lat": "41.53025",
    "lng": "21.41416"
  },
  {
    "country": "MK",
    "name": "Црешево",
    "lat": "42.05083",
    "lng": "21.50972"
  },
  {
    "country": "MK",
    "name": "Češinovo",
    "lat": "41.87148",
    "lng": "22.28961"
  },
  {
    "country": "MK",
    "name": "Čelopek",
    "lat": "41.93167",
    "lng": "21.01333"
  },
  {
    "country": "MK",
    "name": "Cegrane",
    "lat": "41.83889",
    "lng": "20.97583"
  },
  {
    "country": "MK",
    "name": "Čaška",
    "lat": "41.65056",
    "lng": "21.66222"
  },
  {
    "country": "MK",
    "name": "Capari",
    "lat": "41.05656",
    "lng": "21.17884"
  },
  {
    "country": "MK",
    "name": "Булачани",
    "lat": "42.07056",
    "lng": "21.50278"
  },
  {
    "country": "MK",
    "name": "Bukovik",
    "lat": "41.96833",
    "lng": "21.23694"
  },
  {
    "country": "MK",
    "name": "Bučin",
    "lat": "41.27377",
    "lng": "21.31692"
  },
  {
    "country": "MK",
    "name": "Brvenica",
    "lat": "41.96722",
    "lng": "20.98083"
  },
  {
    "country": "MK",
    "name": "Makedonski Brod",
    "lat": "41.51361",
    "lng": "21.21528"
  },
  {
    "country": "MK",
    "name": "Bosilovo",
    "lat": "41.44056",
    "lng": "22.72778"
  },
  {
    "country": "MK",
    "name": "Bojane",
    "lat": "42.00009",
    "lng": "21.19265"
  },
  {
    "country": "MK",
    "name": "Bogovinje",
    "lat": "41.92361",
    "lng": "20.91361"
  },
  {
    "country": "MK",
    "name": "Bogomila",
    "lat": "41.59306",
    "lng": "21.47167"
  },
  {
    "country": "MK",
    "name": "Bogdanci",
    "lat": "41.20306",
    "lng": "22.57556"
  },
  {
    "country": "MK",
    "name": "Blatec",
    "lat": "41.83668",
    "lng": "22.57909"
  },
  {
    "country": "MK",
    "name": "Bitola",
    "lat": "41.03143",
    "lng": "21.33474"
  },
  {
    "country": "MK",
    "name": "Bistrica",
    "lat": "40.97892",
    "lng": "21.3658"
  },
  {
    "country": "MK",
    "name": "Berovo",
    "lat": "41.70306",
    "lng": "22.85778"
  },
  {
    "country": "MK",
    "name": "Beranci",
    "lat": "41.15969",
    "lng": "21.35963"
  },
  {
    "country": "MK",
    "name": "Belčišta",
    "lat": "41.30278",
    "lng": "20.83028"
  },
  {
    "country": "MK",
    "name": "Bedinje",
    "lat": "42.14167",
    "lng": "21.69639"
  },
  {
    "country": "MK",
    "name": "Batinci",
    "lat": "41.91909",
    "lng": "21.47978"
  },
  {
    "country": "MK",
    "name": "Арачиново",
    "lat": "42.02639",
    "lng": "21.56194"
  },
  {
    "country": "MK",
    "name": "Poroj",
    "lat": "42.02913",
    "lng": "20.99266"
  },
  {
    "country": "MK",
    "name": "Strimnica",
    "lat": "41.96719",
    "lng": "21.03598"
  },
  {
    "country": "MK",
    "name": "Dobarce",
    "lat": "41.9553",
    "lng": "21.08875"
  },
  {
    "country": "MK",
    "name": "Zelenikovo",
    "lat": "41.87333",
    "lng": "21.60306"
  },
  {
    "country": "MK",
    "name": "Šuto Orizare",
    "lat": "42.04",
    "lng": "21.425"
  },
  {
    "country": "MK",
    "name": "Butel",
    "lat": "42.03083",
    "lng": "21.44667"
  },
  {
    "country": "MK",
    "name": "Čair",
    "lat": "42.01528",
    "lng": "21.44111"
  },
  {
    "country": "MK",
    "name": "Ilinden",
    "lat": "41.99451",
    "lng": "21.58002"
  },
  {
    "country": "MK",
    "name": "Kisela Voda",
    "lat": "41.94889",
    "lng": "21.50278"
  },
  {
    "country": "MK",
    "name": "Centar Župa",
    "lat": "41.47849",
    "lng": "20.55945"
  },
  {
    "country": "ML",
    "name": "Youwarou",
    "lat": "15.3684",
    "lng": "-4.2628"
  },
  {
    "country": "ML",
    "name": "Yorosso",
    "lat": "12.35811",
    "lng": "-4.77688"
  },
  {
    "country": "ML",
    "name": "Yélimané",
    "lat": "15.11868",
    "lng": "-10.57729"
  },
  {
    "country": "ML",
    "name": "Yanfolila",
    "lat": "11.18333",
    "lng": "-8.15"
  },
  {
    "country": "ML",
    "name": "Tominian",
    "lat": "13.28737",
    "lng": "-4.59317"
  },
  {
    "country": "ML",
    "name": "Timbuktu",
    "lat": "16.77348",
    "lng": "-3.00742"
  },
  {
    "country": "ML",
    "name": "Tessalit",
    "lat": "20.20126",
    "lng": "1.01186"
  },
  {
    "country": "ML",
    "name": "Ténenkou",
    "lat": "14.45722",
    "lng": "-4.9169"
  },
  {
    "country": "ML",
    "name": "Taoudenni",
    "lat": "22.67443",
    "lng": "-3.97891"
  },
  {
    "country": "ML",
    "name": "Sokolo",
    "lat": "14.7328",
    "lng": "-6.1219"
  },
  {
    "country": "ML",
    "name": "Sikasso",
    "lat": "11.31755",
    "lng": "-5.66654"
  },
  {
    "country": "ML",
    "name": "Séguéla",
    "lat": "14.11266",
    "lng": "-6.72865"
  },
  {
    "country": "ML",
    "name": "Ségou",
    "lat": "13.4317",
    "lng": "-6.2157"
  },
  {
    "country": "ML",
    "name": "San",
    "lat": "13.30335",
    "lng": "-4.89562"
  },
  {
    "country": "ML",
    "name": "Sagalo",
    "lat": "12.2",
    "lng": "-10.7"
  },
  {
    "country": "ML",
    "name": "Ntossoni",
    "lat": "12.5304",
    "lng": "-5.77003"
  },
  {
    "country": "ML",
    "name": "Nioro",
    "lat": "15.22932",
    "lng": "-9.59277"
  },
  {
    "country": "ML",
    "name": "Niono",
    "lat": "14.2526",
    "lng": "-5.993"
  },
  {
    "country": "ML",
    "name": "Niafunké",
    "lat": "15.9322",
    "lng": "-3.9906"
  },
  {
    "country": "ML",
    "name": "Nara",
    "lat": "15.16875",
    "lng": "-7.28466"
  },
  {
    "country": "ML",
    "name": "Mopti",
    "lat": "14.4843",
    "lng": "-4.18296"
  },
  {
    "country": "ML",
    "name": "Ménaka",
    "lat": "15.9182",
    "lng": "2.4022"
  },
  {
    "country": "ML",
    "name": "Markala",
    "lat": "13.7021",
    "lng": "-6.0659"
  },
  {
    "country": "ML",
    "name": "Koutiala",
    "lat": "12.39173",
    "lng": "-5.46421"
  },
  {
    "country": "ML",
    "name": "Koulikoro",
    "lat": "12.86273",
    "lng": "-7.55985"
  },
  {
    "country": "ML",
    "name": "Koro",
    "lat": "14.064",
    "lng": "-3.07539"
  },
  {
    "country": "ML",
    "name": "Kolondiéba",
    "lat": "11.08943",
    "lng": "-6.8929"
  },
  {
    "country": "ML",
    "name": "Kolokani",
    "lat": "13.5728",
    "lng": "-8.0339"
  },
  {
    "country": "ML",
    "name": "Kokofata",
    "lat": "12.88333",
    "lng": "-9.95"
  },
  {
    "country": "ML",
    "name": "Kita",
    "lat": "13.0349",
    "lng": "-9.4895"
  },
  {
    "country": "ML",
    "name": "Kidal",
    "lat": "18.44111",
    "lng": "1.40778"
  },
  {
    "country": "ML",
    "name": "Kinmparana",
    "lat": "12.84217",
    "lng": "-4.9245"
  },
  {
    "country": "ML",
    "name": "Ké-Macina",
    "lat": "13.9641",
    "lng": "-5.35791"
  },
  {
    "country": "ML",
    "name": "Kayes",
    "lat": "14.44693",
    "lng": "-11.44448"
  },
  {
    "country": "ML",
    "name": "Kati",
    "lat": "12.74409",
    "lng": "-8.07257"
  },
  {
    "country": "ML",
    "name": "Kangaba",
    "lat": "11.93333",
    "lng": "-8.41667"
  },
  {
    "country": "ML",
    "name": "Kadiolo",
    "lat": "10.55",
    "lng": "-5.76667"
  },
  {
    "country": "ML",
    "name": "Gourma Rharous",
    "lat": "16.87778",
    "lng": "-1.92306"
  },
  {
    "country": "ML",
    "name": "Goundam",
    "lat": "16.41453",
    "lng": "-3.67075"
  },
  {
    "country": "ML",
    "name": "Gao",
    "lat": "16.27167",
    "lng": "-0.04472"
  },
  {
    "country": "ML",
    "name": "Douentza",
    "lat": "15.00155",
    "lng": "-2.94978"
  },
  {
    "country": "ML",
    "name": "Djénné",
    "lat": "13.90608",
    "lng": "-4.55332"
  },
  {
    "country": "ML",
    "name": "Diré",
    "lat": "16.25705",
    "lng": "-3.40126"
  },
  {
    "country": "ML",
    "name": "Diré",
    "lat": "12.28333",
    "lng": "-10.96667"
  },
  {
    "country": "ML",
    "name": "Dioila",
    "lat": "12.4822",
    "lng": "-6.7911"
  },
  {
    "country": "ML",
    "name": "Diéma",
    "lat": "14.54",
    "lng": "-9.1921"
  },
  {
    "country": "ML",
    "name": "Bourem",
    "lat": "16.955",
    "lng": "-0.34861"
  },
  {
    "country": "ML",
    "name": "Bougouni",
    "lat": "11.41769",
    "lng": "-7.48323"
  },
  {
    "country": "ML",
    "name": "Bla",
    "lat": "12.95007",
    "lng": "-5.76024"
  },
  {
    "country": "ML",
    "name": "Barouéli",
    "lat": "13.077",
    "lng": "-6.8312"
  },
  {
    "country": "ML",
    "name": "Bankass",
    "lat": "14.0775",
    "lng": "-3.51594"
  },
  {
    "country": "ML",
    "name": "Bandiagara",
    "lat": "14.35005",
    "lng": "-3.61038"
  },
  {
    "country": "ML",
    "name": "Banamba",
    "lat": "13.54773",
    "lng": "-7.44808"
  },
  {
    "country": "ML",
    "name": "Bamako",
    "lat": "12.65",
    "lng": "-8"
  },
  {
    "country": "ML",
    "name": "Bafoulabé",
    "lat": "13.8065",
    "lng": "-10.8321"
  },
  {
    "country": "ML",
    "name": "Araouane",
    "lat": "18.90476",
    "lng": "-3.52649"
  },
  {
    "country": "ML",
    "name": "Ansongo",
    "lat": "15.6597",
    "lng": "0.5022"
  },
  {
    "country": "ML",
    "name": "Abeïbara",
    "lat": "19.11667",
    "lng": "1.75"
  },
  {
    "country": "ML",
    "name": "Inékar",
    "lat": "15.95944",
    "lng": "3.14111"
  },
  {
    "country": "ML",
    "name": "Ti-n-Essako",
    "lat": "18.45059",
    "lng": "2.48795"
  },
  {
    "country": "ML",
    "name": "Leleni",
    "lat": "12.38944",
    "lng": "-5.24528"
  },
  {
    "country": "ML",
    "name": "Figuira-Toma",
    "lat": "11.91667",
    "lng": "-8.36667"
  },
  {
    "country": "MM",
    "name": "Yenangyaung",
    "lat": "20.46504",
    "lng": "94.8712"
  },
  {
    "country": "MM",
    "name": "Nyaungdon",
    "lat": "17.04459",
    "lng": "95.63957"
  },
  {
    "country": "MM",
    "name": "Yamethin",
    "lat": "20.43189",
    "lng": "96.13875"
  },
  {
    "country": "MM",
    "name": "Wakema",
    "lat": "16.60333",
    "lng": "95.18278"
  },
  {
    "country": "MM",
    "name": "Twante",
    "lat": "16.71047",
    "lng": "95.92866"
  },
  {
    "country": "MM",
    "name": "Taungoo",
    "lat": "18.94291",
    "lng": "96.43408"
  },
  {
    "country": "MM",
    "name": "Thongwa",
    "lat": "16.75998",
    "lng": "96.52498"
  },
  {
    "country": "MM",
    "name": "Thayetmyo",
    "lat": "19.32076",
    "lng": "95.18272"
  },
  {
    "country": "MM",
    "name": "Thaton",
    "lat": "16.91867",
    "lng": "97.37001"
  },
  {
    "country": "MM",
    "name": "Tharyarwady",
    "lat": "17.65399",
    "lng": "95.78813"
  },
  {
    "country": "MM",
    "name": "Thanatpin",
    "lat": "17.29136",
    "lng": "96.57523"
  },
  {
    "country": "MM",
    "name": "Thanatpin",
    "lat": "17.21194",
    "lng": "96.30333"
  },
  {
    "country": "MM",
    "name": "Dawei",
    "lat": "14.0823",
    "lng": "98.19151"
  },
  {
    "country": "MM",
    "name": "Taunggyi",
    "lat": "20.78919",
    "lng": "97.03776"
  },
  {
    "country": "MM",
    "name": "Taungdwingyi",
    "lat": "20.0065",
    "lng": "95.54531"
  },
  {
    "country": "MM",
    "name": "Tachilek",
    "lat": "20.4475",
    "lng": "99.88083"
  },
  {
    "country": "MM",
    "name": "Syriam",
    "lat": "16.76887",
    "lng": "96.24503"
  },
  {
    "country": "MM",
    "name": "Sittwe",
    "lat": "20.14624",
    "lng": "92.89835"
  },
  {
    "country": "MM",
    "name": "Shwebo",
    "lat": "22.56925",
    "lng": "95.69818"
  },
  {
    "country": "MM",
    "name": "Sagaing",
    "lat": "21.8787",
    "lng": "95.97965"
  },
  {
    "country": "MM",
    "name": "Yangon",
    "lat": "16.80528",
    "lng": "96.15611"
  },
  {
    "country": "MM",
    "name": "Pyu",
    "lat": "18.4813",
    "lng": "96.43742"
  },
  {
    "country": "MM",
    "name": "Pyinmana",
    "lat": "19.7381",
    "lng": "96.20742"
  },
  {
    "country": "MM",
    "name": "Pyay",
    "lat": "18.82464",
    "lng": "95.22216"
  },
  {
    "country": "MM",
    "name": "Pyapon",
    "lat": "16.28543",
    "lng": "95.67882"
  },
  {
    "country": "MM",
    "name": "Bago",
    "lat": "17.33521",
    "lng": "96.48135"
  },
  {
    "country": "MM",
    "name": "Paungde",
    "lat": "18.49167",
    "lng": "95.50591"
  },
  {
    "country": "MM",
    "name": "Pakokku",
    "lat": "21.33489",
    "lng": "95.08438"
  },
  {
    "country": "MM",
    "name": "Hpa-An",
    "lat": "16.88953",
    "lng": "97.63482"
  },
  {
    "country": "MM",
    "name": "Nyaungshwe",
    "lat": "20.66084",
    "lng": "96.93405"
  },
  {
    "country": "MM",
    "name": "Nyaunglebin",
    "lat": "17.95363",
    "lng": "96.72247"
  },
  {
    "country": "MM",
    "name": "Myitkyina",
    "lat": "25.38327",
    "lng": "97.39637"
  },
  {
    "country": "MM",
    "name": "Myingyan",
    "lat": "21.46002",
    "lng": "95.3884"
  },
  {
    "country": "MM",
    "name": "Myawadi",
    "lat": "16.68911",
    "lng": "98.50893"
  },
  {
    "country": "MM",
    "name": "Myanaung",
    "lat": "18.28651",
    "lng": "95.32014"
  },
  {
    "country": "MM",
    "name": "Mudon",
    "lat": "16.25624",
    "lng": "97.7246"
  },
  {
    "country": "MM",
    "name": "Mawlamyinegyunn",
    "lat": "16.3772",
    "lng": "95.26488"
  },
  {
    "country": "MM",
    "name": "Mawlamyine",
    "lat": "16.49051",
    "lng": "97.62825"
  },
  {
    "country": "MM",
    "name": "Monywa",
    "lat": "22.10856",
    "lng": "95.13583"
  },
  {
    "country": "MM",
    "name": "Mogok",
    "lat": "22.91766",
    "lng": "96.50982"
  },
  {
    "country": "MM",
    "name": "Minbu",
    "lat": "20.18059",
    "lng": "94.87595"
  },
  {
    "country": "MM",
    "name": "Mikenaungea",
    "lat": "15.95846",
    "lng": "98.42721"
  },
  {
    "country": "MM",
    "name": "Myeik",
    "lat": "12.43954",
    "lng": "98.60028"
  },
  {
    "country": "MM",
    "name": "Meiktila",
    "lat": "20.87776",
    "lng": "95.85844"
  },
  {
    "country": "MM",
    "name": "Pyin Oo Lwin",
    "lat": "22.03501",
    "lng": "96.45683"
  },
  {
    "country": "MM",
    "name": "Mawlaik",
    "lat": "23.64254",
    "lng": "94.40478"
  },
  {
    "country": "MM",
    "name": "Maubin",
    "lat": "16.73148",
    "lng": "95.65441"
  },
  {
    "country": "MM",
    "name": "Martaban",
    "lat": "16.52834",
    "lng": "97.6157"
  },
  {
    "country": "MM",
    "name": "Mandalay",
    "lat": "21.97473",
    "lng": "96.08359"
  },
  {
    "country": "MM",
    "name": "Magway",
    "lat": "20.14956",
    "lng": "94.93246"
  },
  {
    "country": "MM",
    "name": "Loikaw",
    "lat": "19.67798",
    "lng": "97.20975"
  },
  {
    "country": "MM",
    "name": "Letpandan",
    "lat": "17.78664",
    "lng": "95.75076"
  },
  {
    "country": "MM",
    "name": "Lashio",
    "lat": "22.9359",
    "lng": "97.7498"
  },
  {
    "country": "MM",
    "name": "Kyaukse",
    "lat": "21.6056",
    "lng": "96.13508"
  },
  {
    "country": "MM",
    "name": "Kyaikto",
    "lat": "17.30858",
    "lng": "97.01124"
  },
  {
    "country": "MM",
    "name": "Kyaiklat",
    "lat": "16.44502",
    "lng": "95.72373"
  },
  {
    "country": "MM",
    "name": "Kyaikkami",
    "lat": "16.07686",
    "lng": "97.56388"
  },
  {
    "country": "MM",
    "name": "Kayan",
    "lat": "16.90802",
    "lng": "96.56037"
  },
  {
    "country": "MM",
    "name": "Kawthoung",
    "lat": "9.98238",
    "lng": "98.55034"
  },
  {
    "country": "MM",
    "name": "Kanbe",
    "lat": "16.70728",
    "lng": "96.00168"
  },
  {
    "country": "MM",
    "name": "Hinthada",
    "lat": "17.64944",
    "lng": "95.45705"
  },
  {
    "country": "MM",
    "name": "Hakha",
    "lat": "22.64452",
    "lng": "93.61076"
  },
  {
    "country": "MM",
    "name": "Falam",
    "lat": "22.91335",
    "lng": "93.67779"
  },
  {
    "country": "MM",
    "name": "Chauk",
    "lat": "20.89921",
    "lng": "94.81784"
  },
  {
    "country": "MM",
    "name": "Bogale",
    "lat": "16.29415",
    "lng": "95.39742"
  },
  {
    "country": "MM",
    "name": "Bhamo",
    "lat": "24.25256",
    "lng": "97.23357"
  },
  {
    "country": "MM",
    "name": "Pathein",
    "lat": "16.77919",
    "lng": "94.73212"
  },
  {
    "country": "MM",
    "name": "Myaydo",
    "lat": "19.36838",
    "lng": "95.21512"
  },
  {
    "country": "MM",
    "name": "Nay Pyi Taw",
    "lat": "19.745",
    "lng": "96.12972"
  },
  {
    "country": "MM",
    "name": "Tagondaing",
    "lat": "16.0675",
    "lng": "97.90694"
  },
  {
    "country": "MM",
    "name": "Tamoowoug",
    "lat": "16.03447",
    "lng": "97.91458"
  },
  {
    "country": "MM",
    "name": "Dellok",
    "lat": "16.04072",
    "lng": "97.91773"
  },
  {
    "country": "MM",
    "name": "Pulei",
    "lat": "16.06243",
    "lng": "97.8828"
  },
  {
    "country": "MM",
    "name": "Klonhtoug",
    "lat": "15.95411",
    "lng": "98.4325"
  },
  {
    "country": "MM",
    "name": "Kyain Seikgyi Township",
    "lat": "15.82288",
    "lng": "98.25257"
  },
  {
    "country": "MN",
    "name": "Uyenchi Somon",
    "lat": "46.05",
    "lng": "92.01667"
  },
  {
    "country": "MN",
    "name": "Uujim",
    "lat": "48.9",
    "lng": "89.61667"
  },
  {
    "country": "MN",
    "name": "Urdgol",
    "lat": "47.83333",
    "lng": "92.65"
  },
  {
    "country": "MN",
    "name": "Uliastay",
    "lat": "47.74167",
    "lng": "96.84444"
  },
  {
    "country": "MN",
    "name": "Ulaantolgoy",
    "lat": "46.68333",
    "lng": "92.78333"
  },
  {
    "country": "MN",
    "name": "Ulaangom",
    "lat": "49.98111",
    "lng": "92.06667"
  },
  {
    "country": "MN",
    "name": "Tsetserleg",
    "lat": "49.27128",
    "lng": "94.85836"
  },
  {
    "country": "MN",
    "name": "Tsetsegnuur",
    "lat": "46.6",
    "lng": "93.26667"
  },
  {
    "country": "MN",
    "name": "Tsenher",
    "lat": "46.91667",
    "lng": "92.11667"
  },
  {
    "country": "MN",
    "name": "Tseel",
    "lat": "45.56667",
    "lng": "95.86667"
  },
  {
    "country": "MN",
    "name": "Tsalgar",
    "lat": "49.71667",
    "lng": "93.26667"
  },
  {
    "country": "MN",
    "name": "Tsahir",
    "lat": "48.07972",
    "lng": "98.85167"
  },
  {
    "country": "MN",
    "name": "Tsagaantüngi",
    "lat": "49.05",
    "lng": "90.45"
  },
  {
    "country": "MN",
    "name": "Tsagaan-Olom",
    "lat": "46.71327",
    "lng": "96.52588"
  },
  {
    "country": "MN",
    "name": "Tsagaanchuluut",
    "lat": "47.11196",
    "lng": "96.67145"
  },
  {
    "country": "MN",
    "name": "Tosontsengel",
    "lat": "48.75667",
    "lng": "98.28389"
  },
  {
    "country": "MN",
    "name": "Tooromt",
    "lat": "50.46667",
    "lng": "93.58333"
  },
  {
    "country": "MN",
    "name": "Tolbo",
    "lat": "48.41667",
    "lng": "90.28333"
  },
  {
    "country": "MN",
    "name": "Tögrög",
    "lat": "47.42414",
    "lng": "92.22439"
  },
  {
    "country": "MN",
    "name": "Tögrög",
    "lat": "45.82976",
    "lng": "94.81544"
  },
  {
    "country": "MN",
    "name": "Vlaa Vula",
    "lat": "50.68333",
    "lng": "99.23333"
  },
  {
    "country": "MN",
    "name": "Tegsh",
    "lat": "48.75132",
    "lng": "95.99974"
  },
  {
    "country": "MN",
    "name": "Taygan",
    "lat": "46.35356",
    "lng": "97.36633"
  },
  {
    "country": "MN",
    "name": "Talshand",
    "lat": "45.33333",
    "lng": "97.98333"
  },
  {
    "country": "MN",
    "name": "Tahilt",
    "lat": "45.3466",
    "lng": "96.6457"
  },
  {
    "country": "MN",
    "name": "Shiree",
    "lat": "47.49714",
    "lng": "96.80311"
  },
  {
    "country": "MN",
    "name": "Sharga",
    "lat": "49.8",
    "lng": "98.8"
  },
  {
    "country": "MN",
    "name": "Sharga",
    "lat": "46.25",
    "lng": "95.26667"
  },
  {
    "country": "MN",
    "name": "Sharbulag",
    "lat": "48.81667",
    "lng": "93.1"
  },
  {
    "country": "MN",
    "name": "Sayn-Ust",
    "lat": "47.35732",
    "lng": "94.52448"
  },
  {
    "country": "MN",
    "name": "Sangiyn Dalay",
    "lat": "45.13333",
    "lng": "97.75"
  },
  {
    "country": "MN",
    "name": "Rashaant",
    "lat": "47.76667",
    "lng": "90.83333"
  },
  {
    "country": "MN",
    "name": "Oygon",
    "lat": "48.98562",
    "lng": "96.54339"
  },
  {
    "country": "MN",
    "name": "Telmin Suma",
    "lat": "48.64278",
    "lng": "97.61861"
  },
  {
    "country": "MN",
    "name": "Orgil",
    "lat": "48.58722",
    "lng": "99.35083"
  },
  {
    "country": "MN",
    "name": "Ölgii",
    "lat": "48.96833",
    "lng": "89.9625"
  },
  {
    "country": "MN",
    "name": "Nuga",
    "lat": "48.31667",
    "lng": "95.11667"
  },
  {
    "country": "MN",
    "name": "Nogoonnuur",
    "lat": "49.61627",
    "lng": "90.24204"
  },
  {
    "country": "MN",
    "name": "Naranbulag",
    "lat": "49.36667",
    "lng": "92.56667"
  },
  {
    "country": "MN",
    "name": "Namir",
    "lat": "49.10641",
    "lng": "91.71782"
  },
  {
    "country": "MN",
    "name": "Tsagaanhayrhan",
    "lat": "49.4",
    "lng": "94.23333"
  },
  {
    "country": "MN",
    "name": "Mandal",
    "lat": "49.9",
    "lng": "99.43333"
  },
  {
    "country": "MN",
    "name": "Jargalant",
    "lat": "49.30677",
    "lng": "95.44785"
  },
  {
    "country": "MN",
    "name": "Jargalant",
    "lat": "47.15",
    "lng": "99.63333"
  },
  {
    "country": "MN",
    "name": "Jargalant",
    "lat": "46.9267",
    "lng": "91.08782"
  },
  {
    "country": "MN",
    "name": "Jargalant",
    "lat": "45.70954",
    "lng": "97.17596"
  },
  {
    "country": "MN",
    "name": "Ider",
    "lat": "48.77278",
    "lng": "99.87389"
  },
  {
    "country": "MN",
    "name": "Hunt",
    "lat": "47.86667",
    "lng": "99.46667"
  },
  {
    "country": "MN",
    "name": "Hungiy",
    "lat": "48.51672",
    "lng": "94.29428"
  },
  {
    "country": "MN",
    "name": "Höviyn Am",
    "lat": "47.23123",
    "lng": "98.5714"
  },
  {
    "country": "MN",
    "name": "Höshööt",
    "lat": "48.94776",
    "lng": "89.14358"
  },
  {
    "country": "MN",
    "name": "Holboo",
    "lat": "48.58876",
    "lng": "95.43257"
  },
  {
    "country": "MN",
    "name": "Höhtolgoy",
    "lat": "49.28001",
    "lng": "90.91015"
  },
  {
    "country": "MN",
    "name": "Hödrögö",
    "lat": "48.87284",
    "lng": "96.96259"
  },
  {
    "country": "MN",
    "name": "Havtsal",
    "lat": "50.1",
    "lng": "91.66667"
  },
  {
    "country": "MN",
    "name": "Har-Us",
    "lat": "49.03333",
    "lng": "92.03333"
  },
  {
    "country": "MN",
    "name": "Har-Us",
    "lat": "48.48333",
    "lng": "91.43333"
  },
  {
    "country": "MN",
    "name": "Harmod",
    "lat": "50.3413",
    "lng": "91.60641"
  },
  {
    "country": "MN",
    "name": "Harhiraa",
    "lat": "49.77849",
    "lng": "91.90424"
  },
  {
    "country": "MN",
    "name": "Haliun",
    "lat": "45.9296",
    "lng": "96.16239"
  },
  {
    "country": "MN",
    "name": "Halban",
    "lat": "49.52877",
    "lng": "97.7409"
  },
  {
    "country": "MN",
    "name": "Erdenet",
    "lat": "48.94877",
    "lng": "99.53665"
  },
  {
    "country": "MN",
    "name": "Dzüyl",
    "lat": "46.30686",
    "lng": "93.90409"
  },
  {
    "country": "MN",
    "name": "Dzuunmod",
    "lat": "48.21987",
    "lng": "97.3744"
  },
  {
    "country": "MN",
    "name": "Dzüünhövöö",
    "lat": "50.60977",
    "lng": "92.4024"
  },
  {
    "country": "MN",
    "name": "Dzür",
    "lat": "49.65796",
    "lng": "95.79323"
  },
  {
    "country": "MN",
    "name": "Dzöölön",
    "lat": "51.10719",
    "lng": "99.67226"
  },
  {
    "country": "MN",
    "name": "Dzel",
    "lat": "49.90713",
    "lng": "93.78582"
  },
  {
    "country": "MN",
    "name": "Dzalaa",
    "lat": "44.53333",
    "lng": "99.26667"
  },
  {
    "country": "MN",
    "name": "Dzag",
    "lat": "46.94229",
    "lng": "99.16689"
  },
  {
    "country": "MN",
    "name": "Dzadgay",
    "lat": "46.21061",
    "lng": "99.59862"
  },
  {
    "country": "MN",
    "name": "Duut",
    "lat": "47.51667",
    "lng": "91.63333"
  },
  {
    "country": "MN",
    "name": "Khovd",
    "lat": "48.00556",
    "lng": "91.64194"
  },
  {
    "country": "MN",
    "name": "Tsagaannuur",
    "lat": "51.35639",
    "lng": "99.34444"
  },
  {
    "country": "MN",
    "name": "Delgermörön",
    "lat": "46.40946",
    "lng": "98.28712"
  },
  {
    "country": "MN",
    "name": "Darvi",
    "lat": "46.45",
    "lng": "94.11667"
  },
  {
    "country": "MN",
    "name": "Chihertey",
    "lat": "48.30272",
    "lng": "89.51557"
  },
  {
    "country": "MN",
    "name": "Chandmanĭ",
    "lat": "48.05",
    "lng": "96.25"
  },
  {
    "country": "MN",
    "name": "Buyant",
    "lat": "48.57967",
    "lng": "89.5475"
  },
  {
    "country": "MN",
    "name": "Buyant",
    "lat": "48.06667",
    "lng": "91.81667"
  },
  {
    "country": "MN",
    "name": "Buyant",
    "lat": "47.21211",
    "lng": "97.60666"
  },
  {
    "country": "MN",
    "name": "Buyant",
    "lat": "46.1664",
    "lng": "98.69173"
  },
  {
    "country": "MN",
    "name": "Buyanbat",
    "lat": "46.97838",
    "lng": "95.92532"
  },
  {
    "country": "MN",
    "name": "Bürenhayrhan",
    "lat": "46.09237",
    "lng": "91.54796"
  },
  {
    "country": "MN",
    "name": "Darvi",
    "lat": "46.93678",
    "lng": "93.61673"
  },
  {
    "country": "MN",
    "name": "Bulgan",
    "lat": "44.78333",
    "lng": "98.65"
  },
  {
    "country": "MN",
    "name": "Bugat",
    "lat": "49.53333",
    "lng": "93.81667"
  },
  {
    "country": "MN",
    "name": "Buga",
    "lat": "48.95",
    "lng": "89.98333"
  },
  {
    "country": "MN",
    "name": "Buga",
    "lat": "47.65013",
    "lng": "95.0005"
  },
  {
    "country": "MN",
    "name": "Altay sumu",
    "lat": "45.8",
    "lng": "92.28333"
  },
  {
    "country": "MN",
    "name": "Bilüü",
    "lat": "49.04372",
    "lng": "89.43798"
  },
  {
    "country": "MN",
    "name": "Bayshint",
    "lat": "49.66667",
    "lng": "90.28333"
  },
  {
    "country": "MN",
    "name": "Bayan-Uhaa",
    "lat": "48.71906",
    "lng": "98.79181"
  },
  {
    "country": "MN",
    "name": "Bayansayr",
    "lat": "45.55529",
    "lng": "99.43314"
  },
  {
    "country": "MN",
    "name": "Bayan-Ovoo",
    "lat": "44.61667",
    "lng": "94.91667"
  },
  {
    "country": "MN",
    "name": "Bayanhoshuu",
    "lat": "48.23333",
    "lng": "91.91667"
  },
  {
    "country": "MN",
    "name": "Bayangol",
    "lat": "45.55655",
    "lng": "94.36449"
  },
  {
    "country": "MN",
    "name": "Bayanbulag",
    "lat": "46.80981",
    "lng": "98.09006"
  },
  {
    "country": "MN",
    "name": "Bayan",
    "lat": "49.43333",
    "lng": "99.6"
  },
  {
    "country": "MN",
    "name": "Bayan",
    "lat": "46.9929",
    "lng": "95.19962"
  },
  {
    "country": "MN",
    "name": "Baruunturuun",
    "lat": "49.65963",
    "lng": "94.40414"
  },
  {
    "country": "MN",
    "name": "Balgatay",
    "lat": "46.9",
    "lng": "97.15"
  },
  {
    "country": "MN",
    "name": "Altraga",
    "lat": "50.1791",
    "lng": "98.97205"
  },
  {
    "country": "MN",
    "name": "Altay",
    "lat": "49.70317",
    "lng": "96.3592"
  },
  {
    "country": "MN",
    "name": "Altai",
    "lat": "46.37222",
    "lng": "96.25833"
  },
  {
    "country": "MN",
    "name": "Altanteel",
    "lat": "47.11044",
    "lng": "92.84374"
  },
  {
    "country": "MN",
    "name": "Altanbulag",
    "lat": "49.30688",
    "lng": "96.34237"
  },
  {
    "country": "MN",
    "name": "Altan",
    "lat": "48.11667",
    "lng": "95.71667"
  },
  {
    "country": "MN",
    "name": "Aldar",
    "lat": "47.64226",
    "lng": "96.53687"
  },
  {
    "country": "MN",
    "name": "Horgo",
    "lat": "48.16",
    "lng": "99.87556"
  },
  {
    "country": "MN",
    "name": "Üydzen",
    "lat": "44.08216",
    "lng": "106.86985"
  },
  {
    "country": "MN",
    "name": "Uubulan",
    "lat": "48.60885",
    "lng": "101.93424"
  },
  {
    "country": "MN",
    "name": "Urt",
    "lat": "43.23245",
    "lng": "101.04813"
  },
  {
    "country": "MN",
    "name": "Uldz",
    "lat": "48.69028",
    "lng": "111.99463"
  },
  {
    "country": "MN",
    "name": "Ulaan-Uul",
    "lat": "46.0674",
    "lng": "100.81724"
  },
  {
    "country": "MN",
    "name": "Ulaan-Uul",
    "lat": "44.33333",
    "lng": "111.23333"
  },
  {
    "country": "MN",
    "name": "Ulaanjirem",
    "lat": "45.05",
    "lng": "105.56667"
  },
  {
    "country": "MN",
    "name": "Ulaanhudag",
    "lat": "47.33333",
    "lng": "104.5"
  },
  {
    "country": "MN",
    "name": "Ulaanhad",
    "lat": "47.94993",
    "lng": "105.55321"
  },
  {
    "country": "MN",
    "name": "Ulaan-Ereg",
    "lat": "46.9",
    "lng": "109.75"
  },
  {
    "country": "MN",
    "name": "Ulaandel",
    "lat": "46.36446",
    "lng": "113.577"
  },
  {
    "country": "MN",
    "name": "Ulan Bator",
    "lat": "47.90771",
    "lng": "106.88324"
  },
  {
    "country": "MN",
    "name": "Turt",
    "lat": "51.50725",
    "lng": "100.66257"
  },
  {
    "country": "MN",
    "name": "Tsul-Ulaan",
    "lat": "47.83333",
    "lng": "104.5"
  },
  {
    "country": "MN",
    "name": "Tsoohor",
    "lat": "43.30657",
    "lng": "104.07417"
  },
  {
    "country": "MN",
    "name": "Tsomog",
    "lat": "45.91667",
    "lng": "109.06667"
  },
  {
    "country": "MN",
    "name": "Tsetserleg",
    "lat": "47.475",
    "lng": "101.45417"
  },
  {
    "country": "MN",
    "name": "Tsengel",
    "lat": "49.47833",
    "lng": "100.88944"
  },
  {
    "country": "MN",
    "name": "Tsant",
    "lat": "46.18333",
    "lng": "106.71667"
  },
  {
    "country": "MN",
    "name": "Tsagaan-Ovoo",
    "lat": "45.96404",
    "lng": "101.45977"
  },
  {
    "country": "MN",
    "name": "Tsagaan-Ovoo",
    "lat": "45.50719",
    "lng": "105.75594"
  },
  {
    "country": "MN",
    "name": "Tsagaandörvölj",
    "lat": "45.79817",
    "lng": "109.31826"
  },
  {
    "country": "MN",
    "name": "Tsagaanders",
    "lat": "48.05",
    "lng": "114.36667"
  },
  {
    "country": "MN",
    "name": "Naran-mandokhu Somon",
    "lat": "44.4",
    "lng": "108.25"
  },
  {
    "country": "MN",
    "name": "Teshig",
    "lat": "49.94669",
    "lng": "102.66123"
  },
  {
    "country": "MN",
    "name": "Teel",
    "lat": "48.04639",
    "lng": "100.50917"
  },
  {
    "country": "MN",
    "name": "Tavin",
    "lat": "46.39194",
    "lng": "105.73517"
  },
  {
    "country": "MN",
    "name": "Tavanbulag",
    "lat": "47.38185",
    "lng": "101.90815"
  },
  {
    "country": "MN",
    "name": "Dashinchilling",
    "lat": "47.85",
    "lng": "104.05"
  },
  {
    "country": "MN",
    "name": "Suugaant",
    "lat": "45.53257",
    "lng": "107.04546"
  },
  {
    "country": "MN",
    "name": "Sümiyn Bulag",
    "lat": "49.13333",
    "lng": "114.88333"
  },
  {
    "country": "MN",
    "name": "Sühbaatar",
    "lat": "50.23139",
    "lng": "106.20778"
  },
  {
    "country": "MN",
    "name": "Sört",
    "lat": "49.31751",
    "lng": "104.38196"
  },
  {
    "country": "MN",
    "name": "Shireet",
    "lat": "45.72727",
    "lng": "112.35563"
  },
  {
    "country": "MN",
    "name": "Shiree",
    "lat": "45.85",
    "lng": "103.4"
  },
  {
    "country": "MN",
    "name": "Sharïngol",
    "lat": "49.23733",
    "lng": "106.43005"
  },
  {
    "country": "MN",
    "name": "Sharhulsan",
    "lat": "44.65",
    "lng": "104.05"
  },
  {
    "country": "MN",
    "name": "Sharga",
    "lat": "49.04192",
    "lng": "102.08925"
  },
  {
    "country": "MN",
    "name": "Sergelen",
    "lat": "48.56667",
    "lng": "114.08333"
  },
  {
    "country": "MN",
    "name": "Sergelen",
    "lat": "46.2",
    "lng": "111.81667"
  },
  {
    "country": "MN",
    "name": "Senj",
    "lat": "44.71667",
    "lng": "110.76667"
  },
  {
    "country": "MN",
    "name": "Selenge",
    "lat": "49.43333",
    "lng": "101.46667"
  },
  {
    "country": "MN",
    "name": "Saynshand",
    "lat": "43.61667",
    "lng": "102.53333"
  },
  {
    "country": "MN",
    "name": "Sangiyn Dalay",
    "lat": "46.65",
    "lng": "103.31667"
  },
  {
    "country": "MN",
    "name": "Sangiyn Dalay",
    "lat": "46.00793",
    "lng": "104.94209"
  },
  {
    "country": "MN",
    "name": "Sangiyn Dalay",
    "lat": "42.84199",
    "lng": "105.13796"
  },
  {
    "country": "MN",
    "name": "Rashaant",
    "lat": "49.12667",
    "lng": "101.42806"
  },
  {
    "country": "MN",
    "name": "Rashaant",
    "lat": "45.3",
    "lng": "106.2"
  },
  {
    "country": "MN",
    "name": "Övt",
    "lat": "46.81667",
    "lng": "102.25"
  },
  {
    "country": "MN",
    "name": "Ovoot",
    "lat": "45.30423",
    "lng": "113.84977"
  },
  {
    "country": "MN",
    "name": "Orhontuul",
    "lat": "48.94972",
    "lng": "104.97583"
  },
  {
    "country": "MN",
    "name": "Örgön",
    "lat": "44.73637",
    "lng": "100.39135"
  },
  {
    "country": "MN",
    "name": "Orgil",
    "lat": "48.4538",
    "lng": "105.31769"
  },
  {
    "country": "MN",
    "name": "Onon",
    "lat": "48.61667",
    "lng": "110.6"
  },
  {
    "country": "MN",
    "name": "Ongon",
    "lat": "46.98259",
    "lng": "103.78389"
  },
  {
    "country": "MN",
    "name": "Ongi",
    "lat": "46.46667",
    "lng": "102.28333"
  },
  {
    "country": "MN",
    "name": "Ongi",
    "lat": "45.45",
    "lng": "103.9"
  },
  {
    "country": "MN",
    "name": "Öndörhoshuu",
    "lat": "48",
    "lng": "113.93333"
  },
  {
    "country": "MN",
    "name": "Undurkhaan",
    "lat": "47.31944",
    "lng": "110.65556"
  },
  {
    "country": "MN",
    "name": "Öldziyt",
    "lat": "48.52843",
    "lng": "101.37394"
  },
  {
    "country": "MN",
    "name": "Öldziyt",
    "lat": "44.68333",
    "lng": "109.01667"
  },
  {
    "country": "MN",
    "name": "Ögöömör",
    "lat": "43.78336",
    "lng": "104.48067"
  },
  {
    "country": "MN",
    "name": "Nüden",
    "lat": "43.58333",
    "lng": "110.46667"
  },
  {
    "country": "MN",
    "name": "Nomgon",
    "lat": "49.2001",
    "lng": "105.66582"
  },
  {
    "country": "MN",
    "name": "Nart",
    "lat": "49.145",
    "lng": "105.38833"
  },
  {
    "country": "MN",
    "name": "Naranbulag",
    "lat": "49.2436",
    "lng": "113.37427"
  },
  {
    "country": "MN",
    "name": "Murun-kuren",
    "lat": "49.63417",
    "lng": "100.1625"
  },
  {
    "country": "MN",
    "name": "Mörön",
    "lat": "47.38254",
    "lng": "110.31647"
  },
  {
    "country": "MN",
    "name": "Mönhbulag",
    "lat": "46.75",
    "lng": "103.51667"
  },
  {
    "country": "MN",
    "name": "Modot",
    "lat": "47.75",
    "lng": "109.05"
  },
  {
    "country": "MN",
    "name": "Mayhan",
    "lat": "46.09121",
    "lng": "103.83951"
  },
  {
    "country": "MN",
    "name": "Mardzad",
    "lat": "45.95",
    "lng": "102.05"
  },
  {
    "country": "MN",
    "name": "Manhan",
    "lat": "50.12139",
    "lng": "100.04306"
  },
  {
    "country": "MN",
    "name": "Mandalgovi",
    "lat": "45.7625",
    "lng": "106.27083"
  },
  {
    "country": "MN",
    "name": "Dzüünkharaa",
    "lat": "48.63333",
    "lng": "106.73333"
  },
  {
    "country": "MN",
    "name": "Mandal",
    "lat": "48.63111",
    "lng": "103.52917"
  },
  {
    "country": "MN",
    "name": "Mandal",
    "lat": "48.37062",
    "lng": "106.74076"
  },
  {
    "country": "MN",
    "name": "Maanĭt",
    "lat": "48.29667",
    "lng": "103.42556"
  },
  {
    "country": "MN",
    "name": "Maanĭt",
    "lat": "47.25",
    "lng": "107.53333"
  },
  {
    "country": "MN",
    "name": "Sujji",
    "lat": "47.86667",
    "lng": "105.25"
  },
  {
    "country": "MN",
    "name": "Javhlant",
    "lat": "48.80189",
    "lng": "105.924"
  },
  {
    "country": "MN",
    "name": "Javarthushuu",
    "lat": "49.15",
    "lng": "112.73333"
  },
  {
    "country": "MN",
    "name": "Jargalant",
    "lat": "50.0675",
    "lng": "105.88056"
  },
  {
    "country": "MN",
    "name": "Jargalant",
    "lat": "49.29591",
    "lng": "100.25711"
  },
  {
    "country": "MN",
    "name": "Jargalant",
    "lat": "48.52056",
    "lng": "105.86833"
  },
  {
    "country": "MN",
    "name": "Jargalant",
    "lat": "47.79309",
    "lng": "101.97235"
  },
  {
    "country": "MN",
    "name": "Jargalant",
    "lat": "47.53333",
    "lng": "100.21667"
  },
  {
    "country": "MN",
    "name": "Ingettolgoy",
    "lat": "49.46167",
    "lng": "103.97417"
  },
  {
    "country": "MN",
    "name": "Ihsüüj",
    "lat": "48.2257",
    "lng": "106.29152"
  },
  {
    "country": "MN",
    "name": "Ihbulag",
    "lat": "43.2",
    "lng": "107.2"
  },
  {
    "country": "MN",
    "name": "Huurch",
    "lat": "50.10361",
    "lng": "105.42"
  },
  {
    "country": "MN",
    "name": "Hutag",
    "lat": "49.395",
    "lng": "102.69333"
  },
  {
    "country": "MN",
    "name": "Hüremt",
    "lat": "48.66306",
    "lng": "102.62278"
  },
  {
    "country": "MN",
    "name": "Hüremt",
    "lat": "46.30241",
    "lng": "102.44554"
  },
  {
    "country": "MN",
    "name": "Hulstay",
    "lat": "48.43333",
    "lng": "114.86667"
  },
  {
    "country": "MN",
    "name": "Hujirt",
    "lat": "48.88199",
    "lng": "101.23953"
  },
  {
    "country": "MN",
    "name": "Khujirt",
    "lat": "46.89704",
    "lng": "102.76903"
  },
  {
    "country": "MN",
    "name": "Hujirt",
    "lat": "46.6",
    "lng": "104.58333"
  },
  {
    "country": "MN",
    "name": "Noyon Suma",
    "lat": "43.17361",
    "lng": "102.13194"
  },
  {
    "country": "MN",
    "name": "Khuvsget",
    "lat": "43.60639",
    "lng": "109.63806"
  },
  {
    "country": "MN",
    "name": "Hovd",
    "lat": "44.66667",
    "lng": "102.38333"
  },
  {
    "country": "MN",
    "name": "Hovd",
    "lat": "44.67024",
    "lng": "102.17491"
  },
  {
    "country": "MN",
    "name": "Hotont",
    "lat": "47.36278",
    "lng": "102.46794"
  },
  {
    "country": "MN",
    "name": "Höshööt",
    "lat": "48.1009",
    "lng": "102.55686"
  },
  {
    "country": "MN",
    "name": "Horiult",
    "lat": "45.2",
    "lng": "100.76667"
  },
  {
    "country": "MN",
    "name": "Tsagaan-Owoo",
    "lat": "48.4",
    "lng": "113.43333"
  },
  {
    "country": "MN",
    "name": "Bayan Uula Sumu",
    "lat": "45.16667",
    "lng": "101.4"
  },
  {
    "country": "MN",
    "name": "Hoolt",
    "lat": "45.53333",
    "lng": "102.98333"
  },
  {
    "country": "MN",
    "name": "Hongor",
    "lat": "45.8",
    "lng": "111.2"
  },
  {
    "country": "MN",
    "name": "Hongor",
    "lat": "45.13507",
    "lng": "113.68378"
  },
  {
    "country": "MN",
    "name": "Undur Sume",
    "lat": "50.47278",
    "lng": "100.92778"
  },
  {
    "country": "MN",
    "name": "Höhbürd",
    "lat": "46.28575",
    "lng": "100.44834"
  },
  {
    "country": "MN",
    "name": "Herlen",
    "lat": "47.3",
    "lng": "110.56667"
  },
  {
    "country": "MN",
    "name": "Haylaastay",
    "lat": "46.77076",
    "lng": "113.88248"
  },
  {
    "country": "MN",
    "name": "Havirga",
    "lat": "45.66667",
    "lng": "113.08333"
  },
  {
    "country": "MN",
    "name": "Hatavch",
    "lat": "46.16667",
    "lng": "112.95"
  },
  {
    "country": "MN",
    "name": "Hatansuudal",
    "lat": "44.54595",
    "lng": "100.82788"
  },
  {
    "country": "MN",
    "name": "Hashaat",
    "lat": "45.24323",
    "lng": "104.80511"
  },
  {
    "country": "MN",
    "name": "Orhon",
    "lat": "49.8325",
    "lng": "106.13639"
  },
  {
    "country": "MN",
    "name": "Harhorin",
    "lat": "47.19753",
    "lng": "102.82379"
  },
  {
    "country": "MN",
    "name": "Haraat",
    "lat": "46.41667",
    "lng": "107.65"
  },
  {
    "country": "MN",
    "name": "Hanhöhiy",
    "lat": "47.61667",
    "lng": "112.13333"
  },
  {
    "country": "MN",
    "name": "Hajuu-Us",
    "lat": "46.04988",
    "lng": "107.48955"
  },
  {
    "country": "MN",
    "name": "Erhet",
    "lat": "48.27394",
    "lng": "102.9812"
  },
  {
    "country": "MN",
    "name": "Ergel",
    "lat": "43.15",
    "lng": "109.13333"
  },
  {
    "country": "MN",
    "name": "Ereencav",
    "lat": "49.8807",
    "lng": "115.72526"
  },
  {
    "country": "MN",
    "name": "Erdenetsogt",
    "lat": "46.41845",
    "lng": "100.82239"
  },
  {
    "country": "MN",
    "name": "Erdenetsogt",
    "lat": "42.97238",
    "lng": "106.11866"
  },
  {
    "country": "MN",
    "name": "Erdenet",
    "lat": "49.03333",
    "lng": "104.08333"
  },
  {
    "country": "MN",
    "name": "Eg-Uur",
    "lat": "50.10944",
    "lng": "101.57528"
  },
  {
    "country": "MN",
    "name": "Enhtal",
    "lat": "49.2475",
    "lng": "105.37361"
  },
  {
    "country": "MN",
    "name": "Eg",
    "lat": "48.68333",
    "lng": "110.18333"
  },
  {
    "country": "MN",
    "name": "Dzuunmod",
    "lat": "47.70694",
    "lng": "106.95278"
  },
  {
    "country": "MN",
    "name": "Dzüünharaa",
    "lat": "48.85229",
    "lng": "106.45786"
  },
  {
    "country": "MN",
    "name": "Dzüünbulag",
    "lat": "46.95343",
    "lng": "115.29396"
  },
  {
    "country": "MN",
    "name": "Dzüünbulag",
    "lat": "46.38333",
    "lng": "112.18333"
  },
  {
    "country": "MN",
    "name": "Dzogsool",
    "lat": "46.8",
    "lng": "107.15"
  },
  {
    "country": "MN",
    "name": "Dzelter",
    "lat": "50.31556",
    "lng": "105.04583"
  },
  {
    "country": "MN",
    "name": "Dzegstey",
    "lat": "47.66805",
    "lng": "102.54999"
  },
  {
    "country": "MN",
    "name": "Dzaanhoshuu",
    "lat": "47.49331",
    "lng": "100.87801"
  },
  {
    "country": "MN",
    "name": "Dund-Urt",
    "lat": "48.03791",
    "lng": "105.9219"
  },
  {
    "country": "MN",
    "name": "Dundbürd",
    "lat": "47.9459",
    "lng": "111.49784"
  },
  {
    "country": "MN",
    "name": "Doloon",
    "lat": "44.42446",
    "lng": "105.32078"
  },
  {
    "country": "MN",
    "name": "Delgerhaan",
    "lat": "50.08578",
    "lng": "106.18578"
  },
  {
    "country": "MN",
    "name": "Dashbalbar",
    "lat": "49.54571",
    "lng": "114.40287"
  },
  {
    "country": "MN",
    "name": "Darhan",
    "lat": "49.48667",
    "lng": "105.92278"
  },
  {
    "country": "MN",
    "name": "Darhan",
    "lat": "48.25463",
    "lng": "103.88054"
  },
  {
    "country": "MN",
    "name": "Darhan",
    "lat": "46.61667",
    "lng": "109.41667"
  },
  {
    "country": "MN",
    "name": "Dalay",
    "lat": "43.46787",
    "lng": "103.51284"
  },
  {
    "country": "MN",
    "name": "Dalandzadgad",
    "lat": "43.57083",
    "lng": "104.425"
  },
  {
    "country": "MN",
    "name": "Choyr",
    "lat": "46.36111",
    "lng": "108.36111"
  },
  {
    "country": "MN",
    "name": "Choibalsan",
    "lat": "48.07257",
    "lng": "114.53264"
  },
  {
    "country": "MN",
    "name": "Chonogol",
    "lat": "45.9",
    "lng": "115.36667"
  },
  {
    "country": "MN",
    "name": "Chandmanĭ",
    "lat": "45.53333",
    "lng": "110.46667"
  },
  {
    "country": "MN",
    "name": "Saynshand",
    "lat": "44.88239",
    "lng": "110.11631"
  },
  {
    "country": "MN",
    "name": "Buyant",
    "lat": "46.25",
    "lng": "110.83333"
  },
  {
    "country": "MN",
    "name": "Burgaltay",
    "lat": "49.265",
    "lng": "104.74348"
  },
  {
    "country": "MN",
    "name": "Bumbat",
    "lat": "46.49674",
    "lng": "104.11777"
  },
  {
    "country": "MN",
    "name": "Bulgan",
    "lat": "50.54194",
    "lng": "101.51417"
  },
  {
    "country": "MN",
    "name": "Bulgan",
    "lat": "48.8125",
    "lng": "103.53472"
  },
  {
    "country": "MN",
    "name": "Bulgan",
    "lat": "44.09745",
    "lng": "103.54288"
  },
  {
    "country": "MN",
    "name": "Bulagtay",
    "lat": "49.77594",
    "lng": "107.51616"
  },
  {
    "country": "MN",
    "name": "Bulagiyn Denj",
    "lat": "47.31869",
    "lng": "101.11576"
  },
  {
    "country": "MN",
    "name": "Bulag",
    "lat": "49.85946",
    "lng": "100.62687"
  },
  {
    "country": "MN",
    "name": "Bulag",
    "lat": "48.2",
    "lng": "108.48333"
  },
  {
    "country": "MN",
    "name": "Bugat",
    "lat": "49.06667",
    "lng": "103.66583"
  },
  {
    "country": "MN",
    "name": "Bugant",
    "lat": "49.58333",
    "lng": "106.85"
  },
  {
    "country": "MN",
    "name": "Bornuur",
    "lat": "48.46667",
    "lng": "106.26667"
  },
  {
    "country": "MN",
    "name": "Böhöt",
    "lat": "45.23223",
    "lng": "108.28245"
  },
  {
    "country": "MN",
    "name": "Bodĭ",
    "lat": "45.41171",
    "lng": "100.574"
  },
  {
    "country": "MN",
    "name": "Bayshint",
    "lat": "47.41667",
    "lng": "104.81667"
  },
  {
    "country": "MN",
    "name": "Bayasgalant",
    "lat": "47.17945",
    "lng": "108.25996"
  },
  {
    "country": "MN",
    "name": "Bayasgalant",
    "lat": "46.98333",
    "lng": "112.05"
  },
  {
    "country": "MN",
    "name": "Bayan-Ulaan",
    "lat": "46.52178",
    "lng": "102.59428"
  },
  {
    "country": "MN",
    "name": "Bayantsagaan",
    "lat": "48.73167",
    "lng": "100.76"
  },
  {
    "country": "MN",
    "name": "Bayantöhöm",
    "lat": "46.91667",
    "lng": "105.05"
  },
  {
    "country": "MN",
    "name": "Bayan-Ovoo",
    "lat": "49.01667",
    "lng": "111.63333"
  },
  {
    "country": "MN",
    "name": "Javhlant",
    "lat": "47.78333",
    "lng": "112.11667"
  },
  {
    "country": "MN",
    "name": "Bayanhoshuu",
    "lat": "46.70197",
    "lng": "100.1433"
  },
  {
    "country": "MN",
    "name": "Bayanhongor",
    "lat": "46.71667",
    "lng": "100.11667"
  },
  {
    "country": "MN",
    "name": "Bayanhongor",
    "lat": "46.19444",
    "lng": "100.71806"
  },
  {
    "country": "MN",
    "name": "Bayandelger",
    "lat": "47.72732",
    "lng": "108.11062"
  },
  {
    "country": "MN",
    "name": "Bayanbulag",
    "lat": "47.86667",
    "lng": "109.91667"
  },
  {
    "country": "MN",
    "name": "Bayanbaraat",
    "lat": "46.86667",
    "lng": "106.25"
  },
  {
    "country": "MN",
    "name": "Bayan",
    "lat": "48.55",
    "lng": "111.08333"
  },
  {
    "country": "MN",
    "name": "Bayan",
    "lat": "47.91667",
    "lng": "112.95"
  },
  {
    "country": "MN",
    "name": "Bayan",
    "lat": "47.45",
    "lng": "103.15"
  },
  {
    "country": "MN",
    "name": "Bayan",
    "lat": "47.16667",
    "lng": "110.81667"
  },
  {
    "country": "MN",
    "name": "Bayan",
    "lat": "46.25",
    "lng": "110.16667"
  },
  {
    "country": "MN",
    "name": "Bat-Öldziyt",
    "lat": "48.21552",
    "lng": "104.77318"
  },
  {
    "country": "MN",
    "name": "Baruun-Urt",
    "lat": "46.68056",
    "lng": "113.27917"
  },
  {
    "country": "MN",
    "name": "Baruunsuu",
    "lat": "43.65595",
    "lng": "105.75577"
  },
  {
    "country": "MN",
    "name": "Hushaat",
    "lat": "49.5",
    "lng": "105.61667"
  },
  {
    "country": "MN",
    "name": "Badrah",
    "lat": "49.61833",
    "lng": "101.98972"
  },
  {
    "country": "MN",
    "name": "Avraga",
    "lat": "47.17851",
    "lng": "109.18968"
  },
  {
    "country": "MN",
    "name": "Avdzaga",
    "lat": "47.63333",
    "lng": "103.51667"
  },
  {
    "country": "MN",
    "name": "Arvayheer",
    "lat": "46.26389",
    "lng": "102.775"
  },
  {
    "country": "MN",
    "name": "Arhust",
    "lat": "47.79425",
    "lng": "107.88334"
  },
  {
    "country": "MN",
    "name": "Arguut",
    "lat": "45.46278",
    "lng": "102.42056"
  },
  {
    "country": "MN",
    "name": "Argatay",
    "lat": "45.76667",
    "lng": "107.98333"
  },
  {
    "country": "MN",
    "name": "Argalant",
    "lat": "47.94211",
    "lng": "105.89584"
  },
  {
    "country": "MN",
    "name": "Ar-Asgat",
    "lat": "48.26222",
    "lng": "105.41194"
  },
  {
    "country": "MN",
    "name": "Amardalay",
    "lat": "46.12572",
    "lng": "106.37426"
  },
  {
    "country": "MN",
    "name": "Altan-Ovoo",
    "lat": "47.44742",
    "lng": "101.75503"
  },
  {
    "country": "MN",
    "name": "Altanbulag",
    "lat": "50.31556",
    "lng": "106.49861"
  },
  {
    "country": "MN",
    "name": "Altanbulag",
    "lat": "47.7",
    "lng": "106.4"
  },
  {
    "country": "MN",
    "name": "Asgat",
    "lat": "49.51082",
    "lng": "96.79944"
  },
  {
    "country": "MN",
    "name": "Ulaanshiveet",
    "lat": "47.28948",
    "lng": "103.85659"
  },
  {
    "country": "MN",
    "name": "Sümber",
    "lat": "47.65858",
    "lng": "118.51014"
  },
  {
    "country": "MN",
    "name": "Bayantal",
    "lat": "46.56221",
    "lng": "108.30439"
  },
  {
    "country": "MN",
    "name": "Shiveegovĭ",
    "lat": "46.10558",
    "lng": "108.62061"
  },
  {
    "country": "MN",
    "name": "Hongor",
    "lat": "49.23012",
    "lng": "105.89674"
  },
  {
    "country": "MN",
    "name": "Jargalant",
    "lat": "49.12915",
    "lng": "104.40803"
  },
  {
    "country": "MN",
    "name": "Höshigiyn-Ar",
    "lat": "47.55717",
    "lng": "106.96333"
  },
  {
    "country": "MN",
    "name": "Зуунмод",
    "lat": "47.70693",
    "lng": "106.95276"
  },
  {
    "country": "MN",
    "name": "Kharkhorin",
    "lat": "47.19245",
    "lng": "102.81349"
  },
  {
    "country": "MO",
    "name": "Macau",
    "lat": "22.20056",
    "lng": "113.54611"
  },
  {
    "country": "MP",
    "name": "San Jose Village",
    "lat": "14.96823",
    "lng": "145.61998"
  },
  {
    "country": "MP",
    "name": "Saipan",
    "lat": "15.21233",
    "lng": "145.7545"
  },
  {
    "country": "MQ",
    "name": "Saint-Pierre",
    "lat": "14.74309",
    "lng": "-61.17541"
  },
  {
    "country": "MQ",
    "name": "Saint-Joseph",
    "lat": "14.67099",
    "lng": "-61.03905"
  },
  {
    "country": "MQ",
    "name": "Sainte-Marie",
    "lat": "14.78352",
    "lng": "-60.99227"
  },
  {
    "country": "MQ",
    "name": "Sainte-Luce",
    "lat": "14.46848",
    "lng": "-60.92138"
  },
  {
    "country": "MQ",
    "name": "Rivière-Pilote",
    "lat": "14.48738",
    "lng": "-60.90257"
  },
  {
    "country": "MQ",
    "name": "Le Vauclin",
    "lat": "14.5454",
    "lng": "-60.83831"
  },
  {
    "country": "MQ",
    "name": "Les Trois-Îlets",
    "lat": "14.53912",
    "lng": "-61.03354"
  },
  {
    "country": "MQ",
    "name": "Saint-Esprit",
    "lat": "14.55",
    "lng": "-60.93333"
  },
  {
    "country": "MQ",
    "name": "Le Robert",
    "lat": "14.67751",
    "lng": "-60.94228"
  },
  {
    "country": "MQ",
    "name": "Le Morne-Rouge",
    "lat": "14.7761",
    "lng": "-61.13564"
  },
  {
    "country": "MQ",
    "name": "Le Marin",
    "lat": "14.47158",
    "lng": "-60.86989"
  },
  {
    "country": "MQ",
    "name": "Le Lorrain",
    "lat": "14.83257",
    "lng": "-61.05553"
  },
  {
    "country": "MQ",
    "name": "Le Lamentin",
    "lat": "14.61341",
    "lng": "-60.99964"
  },
  {
    "country": "MQ",
    "name": "Le François",
    "lat": "14.61513",
    "lng": "-60.90311"
  },
  {
    "country": "MQ",
    "name": "La Trinité",
    "lat": "14.73807",
    "lng": "-60.96319"
  },
  {
    "country": "MQ",
    "name": "Le Gros-Morne",
    "lat": "14.7",
    "lng": "-61"
  },
  {
    "country": "MQ",
    "name": "Fort-de-France",
    "lat": "14.60365",
    "lng": "-61.07418"
  },
  {
    "country": "MQ",
    "name": "Ducos",
    "lat": "14.57529",
    "lng": "-60.97453"
  },
  {
    "country": "MQ",
    "name": "Basse-Pointe",
    "lat": "14.86935",
    "lng": "-61.11521"
  },
  {
    "country": "MR",
    "name": "Zouerate",
    "lat": "22.73542",
    "lng": "-12.47134"
  },
  {
    "country": "MR",
    "name": "Tékane",
    "lat": "16.57806",
    "lng": "-15.45972"
  },
  {
    "country": "MR",
    "name": "Tidjikja",
    "lat": "18.55644",
    "lng": "-11.42715"
  },
  {
    "country": "MR",
    "name": "Sélibaby",
    "lat": "15.15846",
    "lng": "-12.1843"
  },
  {
    "country": "MR",
    "name": "Rosso",
    "lat": "16.51378",
    "lng": "-15.80503"
  },
  {
    "country": "MR",
    "name": "Nouakchott",
    "lat": "18.08581",
    "lng": "-15.9785"
  },
  {
    "country": "MR",
    "name": "Nouadhibou",
    "lat": "20.94188",
    "lng": "-17.03842"
  },
  {
    "country": "MR",
    "name": "Néma",
    "lat": "16.61702",
    "lng": "-7.25649"
  },
  {
    "country": "MR",
    "name": "Kiffa",
    "lat": "16.62073",
    "lng": "-11.40208"
  },
  {
    "country": "MR",
    "name": "Kaédi",
    "lat": "16.15027",
    "lng": "-13.5037"
  },
  {
    "country": "MR",
    "name": "’Elb el Jmel",
    "lat": "17.0105",
    "lng": "-13.97102"
  },
  {
    "country": "MR",
    "name": "Chingueṭṭi",
    "lat": "20.463",
    "lng": "-12.362"
  },
  {
    "country": "MR",
    "name": "Barkéwol",
    "lat": "16.64039",
    "lng": "-12.49849"
  },
  {
    "country": "MR",
    "name": "Aioun",
    "lat": "16.6614",
    "lng": "-9.6149"
  },
  {
    "country": "MR",
    "name": "Atar",
    "lat": "20.5177",
    "lng": "-13.04857"
  },
  {
    "country": "MR",
    "name": "Aleg",
    "lat": "17.05314",
    "lng": "-13.91312"
  },
  {
    "country": "MR",
    "name": "Akjoujt",
    "lat": "19.74657",
    "lng": "-14.38531"
  },
  {
    "country": "MR",
    "name": "Arafat",
    "lat": "18.04639",
    "lng": "-15.97194"
  },
  {
    "country": "MR",
    "name": "Tevragh Zeina",
    "lat": "18.09894",
    "lng": "-15.98848"
  },
  {
    "country": "MR",
    "name": "Dar Naim",
    "lat": "18.10808",
    "lng": "-15.92666"
  },
  {
    "country": "MS",
    "name": "Saint Peters",
    "lat": "16.7727",
    "lng": "-62.21729"
  },
  {
    "country": "MS",
    "name": "Plymouth",
    "lat": "16.70555",
    "lng": "-62.21292"
  },
  {
    "country": "MS",
    "name": "Brades",
    "lat": "16.79183",
    "lng": "-62.21058"
  },
  {
    "country": "MT",
    "name": "Marsaxlokk",
    "lat": "35.84194",
    "lng": "14.54306"
  },
  {
    "country": "MT",
    "name": "Żurrieq",
    "lat": "35.83111",
    "lng": "14.47417"
  },
  {
    "country": "MT",
    "name": "Żejtun",
    "lat": "35.85583",
    "lng": "14.53306"
  },
  {
    "country": "MT",
    "name": "Żebbuġ",
    "lat": "36.07222",
    "lng": "14.23583"
  },
  {
    "country": "MT",
    "name": "Haz-Zebbug",
    "lat": "35.87194",
    "lng": "14.44111"
  },
  {
    "country": "MT",
    "name": "Żabbar",
    "lat": "35.87611",
    "lng": "14.535"
  },
  {
    "country": "MT",
    "name": "Xgħajra",
    "lat": "35.88556",
    "lng": "14.5475"
  },
  {
    "country": "MT",
    "name": "Xewkija",
    "lat": "36.03278",
    "lng": "14.25806"
  },
  {
    "country": "MT",
    "name": "Xagħra",
    "lat": "36.05",
    "lng": "14.26444"
  },
  {
    "country": "MT",
    "name": "Valletta",
    "lat": "35.89972",
    "lng": "14.51472"
  },
  {
    "country": "MT",
    "name": "Ta’ Xbiex",
    "lat": "35.89917",
    "lng": "14.49444"
  },
  {
    "country": "MT",
    "name": "Tarxien",
    "lat": "35.86583",
    "lng": "14.515"
  },
  {
    "country": "MT",
    "name": "Sliema",
    "lat": "35.9125",
    "lng": "14.50194"
  },
  {
    "country": "MT",
    "name": "Siġġiewi",
    "lat": "35.85556",
    "lng": "14.43639"
  },
  {
    "country": "MT",
    "name": "Santa Venera",
    "lat": "35.89083",
    "lng": "14.47417"
  },
  {
    "country": "MT",
    "name": "Saint Lucia",
    "lat": "36.04306",
    "lng": "14.21722"
  },
  {
    "country": "MT",
    "name": "Santa Luċija",
    "lat": "35.86278",
    "lng": "14.5075"
  },
  {
    "country": "MT",
    "name": "San Pawl il-Baħar",
    "lat": "35.95064",
    "lng": "14.41561"
  },
  {
    "country": "MT",
    "name": "Sannat",
    "lat": "36.02444",
    "lng": "14.24278"
  },
  {
    "country": "MT",
    "name": "San Lawrenz",
    "lat": "36.05556",
    "lng": "14.20361"
  },
  {
    "country": "MT",
    "name": "San Ġiljan",
    "lat": "35.91839",
    "lng": "14.48977"
  },
  {
    "country": "MT",
    "name": "Safi",
    "lat": "35.83306",
    "lng": "14.48472"
  },
  {
    "country": "MT",
    "name": "Paola",
    "lat": "35.87306",
    "lng": "14.49889"
  },
  {
    "country": "MT",
    "name": "Victoria",
    "lat": "36.04444",
    "lng": "14.23972"
  },
  {
    "country": "MT",
    "name": "Rabat",
    "lat": "35.88152",
    "lng": "14.39872"
  },
  {
    "country": "MT",
    "name": "Qrendi",
    "lat": "35.83472",
    "lng": "14.45833"
  },
  {
    "country": "MT",
    "name": "Qormi",
    "lat": "35.87601",
    "lng": "14.472"
  },
  {
    "country": "MT",
    "name": "Qala",
    "lat": "36.03611",
    "lng": "14.30944"
  },
  {
    "country": "MT",
    "name": "Pietà",
    "lat": "35.89472",
    "lng": "14.495"
  },
  {
    "country": "MT",
    "name": "Naxxar",
    "lat": "35.91361",
    "lng": "14.44361"
  },
  {
    "country": "MT",
    "name": "Nadur",
    "lat": "36.03778",
    "lng": "14.29417"
  },
  {
    "country": "MT",
    "name": "Munxar",
    "lat": "36.03",
    "lng": "14.23333"
  },
  {
    "country": "MT",
    "name": "Imtarfa",
    "lat": "35.89333",
    "lng": "14.39889"
  },
  {
    "country": "MT",
    "name": "Imsida",
    "lat": "35.8925",
    "lng": "14.48278"
  },
  {
    "country": "MT",
    "name": "Mqabba",
    "lat": "35.84763",
    "lng": "14.46824"
  },
  {
    "country": "MT",
    "name": "Mosta",
    "lat": "35.90917",
    "lng": "14.42556"
  },
  {
    "country": "MT",
    "name": "Mġarr",
    "lat": "36.02528",
    "lng": "14.295"
  },
  {
    "country": "MT",
    "name": "Imġarr",
    "lat": "35.92056",
    "lng": "14.36639"
  },
  {
    "country": "MT",
    "name": "Mellieħa",
    "lat": "35.95639",
    "lng": "14.36222"
  },
  {
    "country": "MT",
    "name": "Imdina",
    "lat": "35.88694",
    "lng": "14.4025"
  },
  {
    "country": "MT",
    "name": "Marsaskala",
    "lat": "35.8622",
    "lng": "14.56701"
  },
  {
    "country": "MT",
    "name": "Marsa",
    "lat": "35.87917",
    "lng": "14.49528"
  },
  {
    "country": "MT",
    "name": "Luqa",
    "lat": "35.85889",
    "lng": "14.48861"
  },
  {
    "country": "MT",
    "name": "Senglea",
    "lat": "35.8875",
    "lng": "14.51694"
  },
  {
    "country": "MT",
    "name": "L-Iklin",
    "lat": "35.90414",
    "lng": "14.45415"
  },
  {
    "country": "MT",
    "name": "Lija",
    "lat": "35.90056",
    "lng": "14.44639"
  },
  {
    "country": "MT",
    "name": "Kirkop",
    "lat": "35.84222",
    "lng": "14.48528"
  },
  {
    "country": "MT",
    "name": "Kerċem",
    "lat": "36.04194",
    "lng": "14.22667"
  },
  {
    "country": "MT",
    "name": "Kalkara",
    "lat": "35.88917",
    "lng": "14.53278"
  },
  {
    "country": "MT",
    "name": "Swieqi",
    "lat": "35.9225",
    "lng": "14.48"
  },
  {
    "country": "MT",
    "name": "Gżira",
    "lat": "35.90583",
    "lng": "14.48806"
  },
  {
    "country": "MT",
    "name": "Floriana",
    "lat": "35.89583",
    "lng": "14.50833"
  },
  {
    "country": "MT",
    "name": "Vittoriosa",
    "lat": "35.89222",
    "lng": "14.51833"
  },
  {
    "country": "MT",
    "name": "Ħamrun",
    "lat": "35.88472",
    "lng": "14.48444"
  },
  {
    "country": "MT",
    "name": "Gudja",
    "lat": "35.84917",
    "lng": "14.50306"
  },
  {
    "country": "MT",
    "name": "Għaxaq",
    "lat": "35.84889",
    "lng": "14.51667"
  },
  {
    "country": "MT",
    "name": "Hal Gharghur",
    "lat": "35.92409",
    "lng": "14.45118"
  },
  {
    "country": "MT",
    "name": "Għarb",
    "lat": "36.06",
    "lng": "14.20889"
  },
  {
    "country": "MT",
    "name": "Għajnsielem",
    "lat": "36.02639",
    "lng": "14.285"
  },
  {
    "country": "MT",
    "name": "Fgura",
    "lat": "35.87028",
    "lng": "14.51333"
  },
  {
    "country": "MT",
    "name": "Dingli",
    "lat": "35.86139",
    "lng": "14.38222"
  },
  {
    "country": "MT",
    "name": "Cospicua",
    "lat": "35.88556",
    "lng": "14.5275"
  },
  {
    "country": "MT",
    "name": "Birżebbuġa",
    "lat": "35.82583",
    "lng": "14.52694"
  },
  {
    "country": "MT",
    "name": "Birkirkara",
    "lat": "35.89722",
    "lng": "14.46111"
  },
  {
    "country": "MT",
    "name": "Balzan",
    "lat": "35.90028",
    "lng": "14.455"
  },
  {
    "country": "MT",
    "name": "Attard",
    "lat": "35.88972",
    "lng": "14.4425"
  },
  {
    "country": "MT",
    "name": "Saint John",
    "lat": "35.90556",
    "lng": "14.47611"
  },
  {
    "country": "MT",
    "name": "Fontana",
    "lat": "36.0375",
    "lng": "14.23611"
  },
  {
    "country": "MT",
    "name": "Pembroke",
    "lat": "35.93056",
    "lng": "14.47639"
  },
  {
    "country": "MU",
    "name": "Verdun",
    "lat": "-20.23417",
    "lng": "57.55476"
  },
  {
    "country": "MU",
    "name": "Vacoas",
    "lat": "-20.29806",
    "lng": "57.47833"
  },
  {
    "country": "MU",
    "name": "Triolet",
    "lat": "-20.05472",
    "lng": "57.54528"
  },
  {
    "country": "MU",
    "name": "The Vale",
    "lat": "-20.02833",
    "lng": "57.58778"
  },
  {
    "country": "MU",
    "name": "Terre Rouge",
    "lat": "-20.12611",
    "lng": "57.52444"
  },
  {
    "country": "MU",
    "name": "Tamarin",
    "lat": "-20.32556",
    "lng": "57.37056"
  },
  {
    "country": "MU",
    "name": "Surinam",
    "lat": "-20.50972",
    "lng": "57.50528"
  },
  {
    "country": "MU",
    "name": "Souillac",
    "lat": "-20.51667",
    "lng": "57.51667"
  },
  {
    "country": "MU",
    "name": "Sebastopol",
    "lat": "-20.2907",
    "lng": "57.68779"
  },
  {
    "country": "MU",
    "name": "Saint Pierre",
    "lat": "-20.2175",
    "lng": "57.52083"
  },
  {
    "country": "MU",
    "name": "Saint Julien",
    "lat": "-20.22639",
    "lng": "57.63639"
  },
  {
    "country": "MU",
    "name": "Saint Hubert",
    "lat": "-20.36417",
    "lng": "57.63833"
  },
  {
    "country": "MU",
    "name": "Saint Aubin",
    "lat": "-20.496",
    "lng": "57.55"
  },
  {
    "country": "MU",
    "name": "Morcellement Saint André",
    "lat": "-20.07306",
    "lng": "57.55806"
  },
  {
    "country": "MU",
    "name": "Rose Belle",
    "lat": "-20.40028",
    "lng": "57.59667"
  },
  {
    "country": "MU",
    "name": "Roche Terre",
    "lat": "-20.01861",
    "lng": "57.64472"
  },
  {
    "country": "MU",
    "name": "Roches Noire",
    "lat": "-20.11111",
    "lng": "57.71222"
  },
  {
    "country": "MU",
    "name": "Grande Rivière Noire",
    "lat": "-20.36028",
    "lng": "57.36611"
  },
  {
    "country": "MU",
    "name": "Rivière du Rempart",
    "lat": "-20.10306",
    "lng": "57.68472"
  },
  {
    "country": "MU",
    "name": "Rivière des Anguilles",
    "lat": "-20.48528",
    "lng": "57.55083"
  },
  {
    "country": "MU",
    "name": "Queen Victoria",
    "lat": "-20.22",
    "lng": "57.7075"
  },
  {
    "country": "MU",
    "name": "Quatre Soeurs",
    "lat": "-20.29917",
    "lng": "57.77056"
  },
  {
    "country": "MU",
    "name": "Quatre Bornes",
    "lat": "-20.26381",
    "lng": "57.4791"
  },
  {
    "country": "MU",
    "name": "Quartier Militaire",
    "lat": "-20.2479",
    "lng": "57.59737"
  },
  {
    "country": "MU",
    "name": "Providence",
    "lat": "-20.24472",
    "lng": "57.61222"
  },
  {
    "country": "MU",
    "name": "Poste de Flacq",
    "lat": "-20.16306",
    "lng": "57.73056"
  },
  {
    "country": "MU",
    "name": "Port Louis",
    "lat": "-20.16194",
    "lng": "57.49889"
  },
  {
    "country": "MU",
    "name": "Plaine Magnien",
    "lat": "-20.42967",
    "lng": "57.66968"
  },
  {
    "country": "MU",
    "name": "Plaine des Papayes",
    "lat": "-20.065",
    "lng": "57.5725"
  },
  {
    "country": "MU",
    "name": "Petit Raffray",
    "lat": "-20.01333",
    "lng": "57.61194"
  },
  {
    "country": "MU",
    "name": "Petite Rivière",
    "lat": "-20.19551",
    "lng": "57.44592"
  },
  {
    "country": "MU",
    "name": "Petite Case Noyale",
    "lat": "-20.39306",
    "lng": "57.365"
  },
  {
    "country": "MU",
    "name": "Pamplemousses",
    "lat": "-20.10389",
    "lng": "57.57028"
  },
  {
    "country": "MU",
    "name": "Pailles",
    "lat": "-20.19271",
    "lng": "57.48826"
  },
  {
    "country": "MU",
    "name": "Olivia",
    "lat": "-20.28778",
    "lng": "57.73097"
  },
  {
    "country": "MU",
    "name": "Nouvelle France",
    "lat": "-20.37056",
    "lng": "57.56111"
  },
  {
    "country": "MU",
    "name": "Notre Dame",
    "lat": "-20.14056",
    "lng": "57.55306"
  },
  {
    "country": "MU",
    "name": "New Grove",
    "lat": "-20.40861",
    "lng": "57.61361"
  },
  {
    "country": "MU",
    "name": "Piton",
    "lat": "-20.09028",
    "lng": "57.63028"
  },
  {
    "country": "MU",
    "name": "Montagne Blanche",
    "lat": "-20.28538",
    "lng": "57.65865"
  },
  {
    "country": "MU",
    "name": "Moka",
    "lat": "-20.21889",
    "lng": "57.49583"
  },
  {
    "country": "MU",
    "name": "Midlands",
    "lat": "-20.31907",
    "lng": "57.57016"
  },
  {
    "country": "MU",
    "name": "Melrose",
    "lat": "-20.26972",
    "lng": "57.63194"
  },
  {
    "country": "MU",
    "name": "Mahébourg",
    "lat": "-20.40806",
    "lng": "57.7"
  },
  {
    "country": "MU",
    "name": "Long Mountain",
    "lat": "-20.14306",
    "lng": "57.56222"
  },
  {
    "country": "MU",
    "name": "Lalmatie",
    "lat": "-20.18972",
    "lng": "57.66111"
  },
  {
    "country": "MU",
    "name": "Dagotière",
    "lat": "-20.24476",
    "lng": "57.56188"
  },
  {
    "country": "MU",
    "name": "Grand Sable",
    "lat": "-20.31417",
    "lng": "57.76444"
  },
  {
    "country": "MU",
    "name": "Grande Rivière Sud Est",
    "lat": "-20.28611",
    "lng": "57.77583"
  },
  {
    "country": "MU",
    "name": "Grand Gaube",
    "lat": "-20.00639",
    "lng": "57.66083"
  },
  {
    "country": "MU",
    "name": "Grand Baie",
    "lat": "-20.01816",
    "lng": "57.58015"
  },
  {
    "country": "MU",
    "name": "Grand Bois",
    "lat": "-20.41889",
    "lng": "57.54417"
  },
  {
    "country": "MU",
    "name": "Goodlands",
    "lat": "-20.035",
    "lng": "57.64306"
  },
  {
    "country": "MU",
    "name": "Fond du Sac",
    "lat": "-20.04306",
    "lng": "57.57861"
  },
  {
    "country": "MU",
    "name": "Flic en Flac",
    "lat": "-20.27417",
    "lng": "57.36306"
  },
  {
    "country": "MU",
    "name": "Espérance Trébuchet",
    "lat": "-20.06972",
    "lng": "57.64194"
  },
  {
    "country": "MU",
    "name": "Curepipe",
    "lat": "-20.31472",
    "lng": "57.52028"
  },
  {
    "country": "MU",
    "name": "Crève Coeur",
    "lat": "-20.19111",
    "lng": "57.55722"
  },
  {
    "country": "MU",
    "name": "Clémencia",
    "lat": "-20.26389",
    "lng": "57.70611"
  },
  {
    "country": "MU",
    "name": "Chemin Grenier",
    "lat": "-20.48722",
    "lng": "57.46556"
  },
  {
    "country": "MU",
    "name": "Chamouny",
    "lat": "-20.48222",
    "lng": "57.46611"
  },
  {
    "country": "MU",
    "name": "Centre de Flacq",
    "lat": "-20.18972",
    "lng": "57.71444"
  },
  {
    "country": "MU",
    "name": "Cascavelle",
    "lat": "-20.28694",
    "lng": "57.40722"
  },
  {
    "country": "MU",
    "name": "Cap Malheureux",
    "lat": "-19.98417",
    "lng": "57.61417"
  },
  {
    "country": "MU",
    "name": "Camp Thorel",
    "lat": "-20.21472",
    "lng": "57.61611"
  },
  {
    "country": "MU",
    "name": "Camp Diable",
    "lat": "-20.46278",
    "lng": "57.57889"
  },
  {
    "country": "MU",
    "name": "Camp de Masque",
    "lat": "-20.23694",
    "lng": "57.66333"
  },
  {
    "country": "MU",
    "name": "Brisée Verdière",
    "lat": "-20.16389",
    "lng": "57.64667"
  },
  {
    "country": "MU",
    "name": "Bon Accueil",
    "lat": "-20.17083",
    "lng": "57.65639"
  },
  {
    "country": "MU",
    "name": "Bois des Amourettes",
    "lat": "-20.36306",
    "lng": "57.73111"
  },
  {
    "country": "MU",
    "name": "Bel Air Rivière Sèche",
    "lat": "-20.25777",
    "lng": "57.74976"
  },
  {
    "country": "MU",
    "name": "Beau Vallon",
    "lat": "-20.41889",
    "lng": "57.69528"
  },
  {
    "country": "MU",
    "name": "Beau Bassin-Rose Hill",
    "lat": "-20.23325",
    "lng": "57.46609"
  },
  {
    "country": "MU",
    "name": "Bambous",
    "lat": "-20.25667",
    "lng": "57.40611"
  },
  {
    "country": "MU",
    "name": "Albion",
    "lat": "-20.20814",
    "lng": "57.40766"
  },
  {
    "country": "MU",
    "name": "Laventure",
    "lat": "-20.14583",
    "lng": "57.67667"
  },
  {
    "country": "MU",
    "name": "Cluny",
    "lat": "-20.36694",
    "lng": "57.60389"
  },
  {
    "country": "MU",
    "name": "Cottage",
    "lat": "-20.05972",
    "lng": "57.62917"
  },
  {
    "country": "MU",
    "name": "Pointe aux Piments",
    "lat": "-20.06278",
    "lng": "57.51306"
  },
  {
    "country": "MU",
    "name": "Congomah",
    "lat": "-20.14889",
    "lng": "57.59083"
  },
  {
    "country": "MU",
    "name": "Amaury",
    "lat": "-20.13083",
    "lng": "57.65917"
  },
  {
    "country": "MU",
    "name": "Plaines des Roches",
    "lat": "-20.11167",
    "lng": "57.69083"
  },
  {
    "country": "MU",
    "name": "Mare La Chaux",
    "lat": "-20.19806",
    "lng": "57.74944"
  },
  {
    "country": "MU",
    "name": "Quatre Cocos",
    "lat": "-20.20151",
    "lng": "57.77448"
  },
  {
    "country": "MU",
    "name": "Camp Ithier",
    "lat": "-20.21583",
    "lng": "57.74556"
  },
  {
    "country": "MU",
    "name": "Ecroignard",
    "lat": "-20.22611",
    "lng": "57.73611"
  },
  {
    "country": "MU",
    "name": "Bambous Virieux",
    "lat": "-20.34278",
    "lng": "57.7575"
  },
  {
    "country": "MU",
    "name": "Ebene",
    "lat": "-20.24494",
    "lng": "57.49163"
  },
  {
    "country": "MU",
    "name": "Gros Cailloux",
    "lat": "-20.20722",
    "lng": "57.43"
  },
  {
    "country": "MU",
    "name": "Mapou",
    "lat": "-20.07583",
    "lng": "57.60139"
  },
  {
    "country": "MU",
    "name": "Dubreuil",
    "lat": "-20.30132",
    "lng": "57.59861"
  },
  {
    "country": "MU",
    "name": "Le Hochet",
    "lat": "-20.135",
    "lng": "57.52111"
  },
  {
    "country": "MU",
    "name": "Calebasses",
    "lat": "-20.11167",
    "lng": "57.55389"
  },
  {
    "country": "MU",
    "name": "Arsenal",
    "lat": "-20.10556",
    "lng": "57.53528"
  },
  {
    "country": "MU",
    "name": "Port Mathurin",
    "lat": "-19.68333",
    "lng": "63.41667"
  },
  {
    "country": "MU",
    "name": "Baie aux Huîtres",
    "lat": "-19.69444",
    "lng": "63.40833"
  },
  {
    "country": "MU",
    "name": "Cargados Carajos",
    "lat": "-16.60329",
    "lng": "59.65851"
  },
  {
    "country": "MV",
    "name": "Meedhoo",
    "lat": "-0.58333",
    "lng": "73.23333"
  },
  {
    "country": "MV",
    "name": "Male",
    "lat": "4.17521",
    "lng": "73.50916"
  },
  {
    "country": "MV",
    "name": "Hithadhoo",
    "lat": "-0.6",
    "lng": "73.08333"
  },
  {
    "country": "MV",
    "name": "Mahibadhoo",
    "lat": "3.75713",
    "lng": "72.96893"
  },
  {
    "country": "MV",
    "name": "Eydhafushi",
    "lat": "5.10327",
    "lng": "73.07078"
  },
  {
    "country": "MV",
    "name": "Kudahuvadhoo",
    "lat": "2.67075",
    "lng": "72.89437"
  },
  {
    "country": "MV",
    "name": "Viligili",
    "lat": "0.75906",
    "lng": "73.43296"
  },
  {
    "country": "MV",
    "name": "Thinadhoo",
    "lat": "0.5306",
    "lng": "72.99969"
  },
  {
    "country": "MV",
    "name": "Fuvahmulah",
    "lat": "-0.29878",
    "lng": "73.42403"
  },
  {
    "country": "MV",
    "name": "Dhidhdhoo",
    "lat": "6.88744",
    "lng": "73.11402"
  },
  {
    "country": "MV",
    "name": "Kulhudhuffushi",
    "lat": "6.62207",
    "lng": "73.06998"
  },
  {
    "country": "MV",
    "name": "Naifaru",
    "lat": "5.44438",
    "lng": "73.36571"
  },
  {
    "country": "MV",
    "name": "Muli",
    "lat": "2.91667",
    "lng": "73.56667"
  },
  {
    "country": "MV",
    "name": "Manadhoo",
    "lat": "5.76687",
    "lng": "73.4136"
  },
  {
    "country": "MV",
    "name": "Ugoofaaru",
    "lat": "5.66812",
    "lng": "73.03017"
  },
  {
    "country": "MV",
    "name": "Funadhoo",
    "lat": "6.15091",
    "lng": "73.29013"
  },
  {
    "country": "MV",
    "name": "Veymandoo",
    "lat": "2.18772",
    "lng": "73.09556"
  },
  {
    "country": "MV",
    "name": "Felidhoo",
    "lat": "3.47182",
    "lng": "73.54699"
  },
  {
    "country": "MV",
    "name": "Hulhumale",
    "lat": "4.21169",
    "lng": "73.54008"
  },
  {
    "country": "MV",
    "name": "Fonadhoo",
    "lat": "1.83243",
    "lng": "73.50257"
  },
  {
    "country": "MV",
    "name": "Vilufushi",
    "lat": "2.50306",
    "lng": "73.30859"
  },
  {
    "country": "MV",
    "name": "Madifushi",
    "lat": "2.35582",
    "lng": "73.35473"
  },
  {
    "country": "MV",
    "name": "Guraidhoo",
    "lat": "2.32473",
    "lng": "73.31846"
  },
  {
    "country": "MV",
    "name": "Open Stage",
    "lat": "5.1053",
    "lng": "73.07115"
  },
  {
    "country": "MV",
    "name": "Guraidhoo",
    "lat": "3.90045",
    "lng": "73.46623"
  },
  {
    "country": "MV",
    "name": "Maafushi",
    "lat": "3.94231",
    "lng": "73.4907"
  },
  {
    "country": "MW",
    "name": "Karonga",
    "lat": "-9.93333",
    "lng": "33.93333"
  },
  {
    "country": "MW",
    "name": "Chitipa",
    "lat": "-9.70237",
    "lng": "33.26969"
  },
  {
    "country": "MW",
    "name": "Zomba",
    "lat": "-15.38596",
    "lng": "35.3188"
  },
  {
    "country": "MW",
    "name": "Thyolo",
    "lat": "-16.06775",
    "lng": "35.14046"
  },
  {
    "country": "MW",
    "name": "Salima",
    "lat": "-13.7804",
    "lng": "34.4587"
  },
  {
    "country": "MW",
    "name": "Rumphi",
    "lat": "-11.01863",
    "lng": "33.85746"
  },
  {
    "country": "MW",
    "name": "Phalombe",
    "lat": "-15.80635",
    "lng": "35.65067"
  },
  {
    "country": "MW",
    "name": "Ntchisi",
    "lat": "-13.52775",
    "lng": "33.9149"
  },
  {
    "country": "MW",
    "name": "Ntcheu",
    "lat": "-14.82027",
    "lng": "34.63586"
  },
  {
    "country": "MW",
    "name": "Nsanje",
    "lat": "-16.91995",
    "lng": "35.26199"
  },
  {
    "country": "MW",
    "name": "Nkhotakota",
    "lat": "-12.92744",
    "lng": "34.29614"
  },
  {
    "country": "MW",
    "name": "Nkhata Bay",
    "lat": "-11.60659",
    "lng": "34.29073"
  },
  {
    "country": "MW",
    "name": "Likoma",
    "lat": "-12.06667",
    "lng": "34.73333"
  },
  {
    "country": "MW",
    "name": "Neno",
    "lat": "-15.39805",
    "lng": "34.65343"
  },
  {
    "country": "MW",
    "name": "Mzuzu",
    "lat": "-11.46556",
    "lng": "34.02071"
  },
  {
    "country": "MW",
    "name": "Mzimba",
    "lat": "-11.9",
    "lng": "33.6"
  },
  {
    "country": "MW",
    "name": "Mwanza",
    "lat": "-15.60262",
    "lng": "34.52479"
  },
  {
    "country": "MW",
    "name": "Mulanje",
    "lat": "-16.03163",
    "lng": "35.5"
  },
  {
    "country": "MW",
    "name": "Mponela",
    "lat": "-13.53194",
    "lng": "33.74008"
  },
  {
    "country": "MW",
    "name": "Monkey Bay",
    "lat": "-14.08239",
    "lng": "34.91652"
  },
  {
    "country": "MW",
    "name": "Mchinji",
    "lat": "-13.79841",
    "lng": "32.88019"
  },
  {
    "country": "MW",
    "name": "Mangochi",
    "lat": "-14.47815",
    "lng": "35.26448"
  },
  {
    "country": "MW",
    "name": "Machinga",
    "lat": "-15.16849",
    "lng": "35.30002"
  },
  {
    "country": "MW",
    "name": "Luchenza",
    "lat": "-16.00693",
    "lng": "35.30947"
  },
  {
    "country": "MW",
    "name": "Liwonde",
    "lat": "-15.06665",
    "lng": "35.22543"
  },
  {
    "country": "MW",
    "name": "Livingstonia",
    "lat": "-10.60602",
    "lng": "34.10628"
  },
  {
    "country": "MW",
    "name": "Lilongwe",
    "lat": "-13.96692",
    "lng": "33.78725"
  },
  {
    "country": "MW",
    "name": "Kasungu",
    "lat": "-13.03333",
    "lng": "33.48333"
  },
  {
    "country": "MW",
    "name": "Dowa",
    "lat": "-13.65399",
    "lng": "33.93754"
  },
  {
    "country": "MW",
    "name": "Dedza",
    "lat": "-14.3779",
    "lng": "34.33322"
  },
  {
    "country": "MW",
    "name": "Chiradzulu",
    "lat": "-15.67461",
    "lng": "35.14071"
  },
  {
    "country": "MW",
    "name": "Chipoka",
    "lat": "-13.99329",
    "lng": "34.51566"
  },
  {
    "country": "MW",
    "name": "Chikwawa",
    "lat": "-16.03352",
    "lng": "34.80091"
  },
  {
    "country": "MW",
    "name": "Blantyre",
    "lat": "-15.78499",
    "lng": "35.00854"
  },
  {
    "country": "MW",
    "name": "Balaka",
    "lat": "-14.97928",
    "lng": "34.95575"
  },
  {
    "country": "MW",
    "name": "Makata",
    "lat": "-15.78721",
    "lng": "35.03046"
  },
  {
    "country": "MX",
    "name": "Cuauhtémoc",
    "lat": "22.54408",
    "lng": "-98.15074"
  },
  {
    "country": "MX",
    "name": "González",
    "lat": "22.82735",
    "lng": "-98.42713"
  },
  {
    "country": "MX",
    "name": "Santa Martha",
    "lat": "22.34278",
    "lng": "-98.70639"
  },
  {
    "country": "MX",
    "name": "Gómez Farías",
    "lat": "22.88371",
    "lng": "-99.02612"
  },
  {
    "country": "MX",
    "name": "Xicoténcatl",
    "lat": "22.99623",
    "lng": "-98.94218"
  },
  {
    "country": "MX",
    "name": "San Fernando",
    "lat": "24.84749",
    "lng": "-98.14828"
  },
  {
    "country": "MX",
    "name": "El Control",
    "lat": "25.95867",
    "lng": "-97.81281"
  },
  {
    "country": "MX",
    "name": "Ciudad Gustavo Díaz Ordaz",
    "lat": "26.23186",
    "lng": "-98.5956"
  },
  {
    "country": "MX",
    "name": "Matlapa",
    "lat": "21.33649",
    "lng": "-98.82777"
  },
  {
    "country": "MX",
    "name": "Nueva Primavera",
    "lat": "21.91342",
    "lng": "-98.85785"
  },
  {
    "country": "MX",
    "name": "Tamcuime",
    "lat": "21.60137",
    "lng": "-99.01077"
  },
  {
    "country": "MX",
    "name": "Tampate",
    "lat": "21.63639",
    "lng": "-99.02552"
  },
  {
    "country": "MX",
    "name": "Ciudad Valles",
    "lat": "21.99631",
    "lng": "-99.01093"
  },
  {
    "country": "MX",
    "name": "El Naranjo",
    "lat": "22.52597",
    "lng": "-99.32968"
  },
  {
    "country": "MX",
    "name": "Zumpango",
    "lat": "19.7967",
    "lng": "-99.09946"
  },
  {
    "country": "MX",
    "name": "Zumpango del Río",
    "lat": "17.65437",
    "lng": "-99.52725"
  },
  {
    "country": "MX",
    "name": "Zumpahuacán",
    "lat": "18.91642",
    "lng": "-99.56568"
  },
  {
    "country": "MX",
    "name": "Zozocolco de Hidalgo",
    "lat": "20.14048",
    "lng": "-97.57567"
  },
  {
    "country": "MX",
    "name": "Zoquitlán",
    "lat": "18.33523",
    "lng": "-97.01745"
  },
  {
    "country": "MX",
    "name": "Zoquiopan",
    "lat": "20.00898",
    "lng": "-97.59606"
  },
  {
    "country": "MX",
    "name": "Zoogocho",
    "lat": "17.24009",
    "lng": "-96.24299"
  },
  {
    "country": "MX",
    "name": "Zontecomatlán de López y Fuentes",
    "lat": "20.76236",
    "lng": "-98.34319"
  },
  {
    "country": "MX",
    "name": "Zongozotla",
    "lat": "19.9793",
    "lng": "-97.72751"
  },
  {
    "country": "MX",
    "name": "Zongolica",
    "lat": "18.66673",
    "lng": "-96.99707"
  },
  {
    "country": "MX",
    "name": "Santa María Zolotepec",
    "lat": "19.41728",
    "lng": "-99.49327"
  },
  {
    "country": "MX",
    "name": "Zitlala",
    "lat": "17.69049",
    "lng": "-99.18642"
  },
  {
    "country": "MX",
    "name": "Zinacantán",
    "lat": "16.7602",
    "lng": "-92.72257"
  },
  {
    "country": "MX",
    "name": "Zimatlán de Álvarez",
    "lat": "16.86939",
    "lng": "-96.78435"
  },
  {
    "country": "MX",
    "name": "Zimapan",
    "lat": "20.73814",
    "lng": "-99.3818"
  },
  {
    "country": "MX",
    "name": "Zempoala",
    "lat": "19.91587",
    "lng": "-98.666"
  },
  {
    "country": "MX",
    "name": "Villa Zempoala",
    "lat": "19.44422",
    "lng": "-96.40773"
  },
  {
    "country": "MX",
    "name": "General Zaragoza",
    "lat": "23.97319",
    "lng": "-99.77233"
  },
  {
    "country": "MX",
    "name": "Zaragoza",
    "lat": "21.27975",
    "lng": "-97.72055"
  },
  {
    "country": "MX",
    "name": "Zaragoza",
    "lat": "19.77097",
    "lng": "-97.55506"
  },
  {
    "country": "MX",
    "name": "Zaragoza de Guadalupe",
    "lat": "19.1483",
    "lng": "-99.64405"
  },
  {
    "country": "MX",
    "name": "Zapotlán de Juárez",
    "lat": "19.97709",
    "lng": "-98.8642"
  },
  {
    "country": "MX",
    "name": "Zapotitlán",
    "lat": "18.3296",
    "lng": "-97.47399"
  },
  {
    "country": "MX",
    "name": "Zapotitlán Palmas",
    "lat": "17.88965",
    "lng": "-97.81849"
  },
  {
    "country": "MX",
    "name": "Zacualtipán",
    "lat": "20.65002",
    "lng": "-98.65628"
  },
  {
    "country": "MX",
    "name": "Zacualpan",
    "lat": "20.43332",
    "lng": "-98.3483"
  },
  {
    "country": "MX",
    "name": "Zacualpan",
    "lat": "18.71895",
    "lng": "-99.77605"
  },
  {
    "country": "MX",
    "name": "Zacatlán",
    "lat": "19.9355",
    "lng": "-97.96125"
  },
  {
    "country": "MX",
    "name": "Zacatepec",
    "lat": "19.26631",
    "lng": "-97.5328"
  },
  {
    "country": "MX",
    "name": "Zacatepec",
    "lat": "18.65409",
    "lng": "-99.18981"
  },
  {
    "country": "MX",
    "name": "Zacapoaxtla",
    "lat": "19.87271",
    "lng": "-97.58899"
  },
  {
    "country": "MX",
    "name": "Zacapala",
    "lat": "18.59415",
    "lng": "-98.06583"
  },
  {
    "country": "MX",
    "name": "Zacamixtle",
    "lat": "21.24762",
    "lng": "-97.72155"
  },
  {
    "country": "MX",
    "name": "Villa de Zaachila",
    "lat": "16.95098",
    "lng": "-96.74938"
  },
  {
    "country": "MX",
    "name": "Yucuyachi",
    "lat": "17.60858",
    "lng": "-98.19675"
  },
  {
    "country": "MX",
    "name": "San Pedro Mártir Yucuxaco",
    "lat": "17.43245",
    "lng": "-97.611"
  },
  {
    "country": "MX",
    "name": "Santiago Yogana",
    "lat": "16.4613",
    "lng": "-96.78786"
  },
  {
    "country": "MX",
    "name": "Magdalena Yodocono de Porfirio Díaz",
    "lat": "17.3847",
    "lng": "-97.3553"
  },
  {
    "country": "MX",
    "name": "San Agustín Yatareni",
    "lat": "17.08198",
    "lng": "-96.66578"
  },
  {
    "country": "MX",
    "name": "Yehualtepec",
    "lat": "18.79518",
    "lng": "-97.6616"
  },
  {
    "country": "MX",
    "name": "Yecuatla",
    "lat": "19.86614",
    "lng": "-96.77836"
  },
  {
    "country": "MX",
    "name": "Yecapixtla",
    "lat": "18.88333",
    "lng": "-98.865"
  },
  {
    "country": "MX",
    "name": "Yaxkukul",
    "lat": "21.06139",
    "lng": "-89.41932"
  },
  {
    "country": "MX",
    "name": "Yaxe",
    "lat": "16.72595",
    "lng": "-96.47191"
  },
  {
    "country": "MX",
    "name": "Yaxcabá",
    "lat": "20.54846",
    "lng": "-88.82714"
  },
  {
    "country": "MX",
    "name": "Yautepec",
    "lat": "18.88188",
    "lng": "-99.06715"
  },
  {
    "country": "MX",
    "name": "Yatzachi",
    "lat": "17.22588",
    "lng": "-96.22137"
  },
  {
    "country": "MX",
    "name": "Yaonahuac",
    "lat": "19.87076",
    "lng": "-97.46587"
  },
  {
    "country": "MX",
    "name": "Yanga",
    "lat": "18.83288",
    "lng": "-96.79837"
  },
  {
    "country": "MX",
    "name": "Yajalón",
    "lat": "17.17276",
    "lng": "-92.33315"
  },
  {
    "country": "MX",
    "name": "Xoxolpa",
    "lat": "20.87574",
    "lng": "-98.42386"
  },
  {
    "country": "MX",
    "name": "Xoxocotla",
    "lat": "18.68415",
    "lng": "-99.24577"
  },
  {
    "country": "MX",
    "name": "Xoxocotla",
    "lat": "18.64658",
    "lng": "-97.15244"
  },
  {
    "country": "MX",
    "name": "Xopilapa",
    "lat": "18.50472",
    "lng": "-97.07944"
  },
  {
    "country": "MX",
    "name": "Xonacatlán",
    "lat": "19.40513",
    "lng": "-99.52807"
  },
  {
    "country": "MX",
    "name": "Xometla",
    "lat": "19.64281",
    "lng": "-98.88171"
  },
  {
    "country": "MX",
    "name": "Xocotla",
    "lat": "19.01511",
    "lng": "-97.10092"
  },
  {
    "country": "MX",
    "name": "Xochitlan Todos Santos",
    "lat": "18.70395",
    "lng": "-97.77609"
  },
  {
    "country": "MX",
    "name": "Xochitepec",
    "lat": "18.7808",
    "lng": "-99.23049"
  },
  {
    "country": "MX",
    "name": "Xochistlahuaca",
    "lat": "16.78915",
    "lng": "-98.24172"
  },
  {
    "country": "MX",
    "name": "Xochimilco",
    "lat": "19.25465",
    "lng": "-99.10356"
  },
  {
    "country": "MX",
    "name": "Xochiltepec",
    "lat": "18.65095",
    "lng": "-98.3445"
  },
  {
    "country": "MX",
    "name": "Xochihuehuetlán",
    "lat": "17.90619",
    "lng": "-98.48818"
  },
  {
    "country": "MX",
    "name": "Xilitla",
    "lat": "21.38681",
    "lng": "-98.99009"
  },
  {
    "country": "MX",
    "name": "Xicotepec de Juárez",
    "lat": "20.27605",
    "lng": "-97.96111"
  },
  {
    "country": "MX",
    "name": "Xico",
    "lat": "19.42178",
    "lng": "-97.00819"
  },
  {
    "country": "MX",
    "name": "Xico",
    "lat": "19.27032",
    "lng": "-98.95088"
  },
  {
    "country": "MX",
    "name": "Xayacatlán de Bravo",
    "lat": "18.23712",
    "lng": "-97.97524"
  },
  {
    "country": "MX",
    "name": "Santa María Xadani",
    "lat": "16.36198",
    "lng": "-95.01826"
  },
  {
    "country": "MX",
    "name": "Xaltianguis",
    "lat": "17.09834",
    "lng": "-99.71557"
  },
  {
    "country": "MX",
    "name": "Xaltepuxtla",
    "lat": "20.17546",
    "lng": "-97.97208"
  },
  {
    "country": "MX",
    "name": "Xaltepec",
    "lat": "18.88163",
    "lng": "-97.60825"
  },
  {
    "country": "MX",
    "name": "Xalpatlahuac",
    "lat": "17.47066",
    "lng": "-98.60675"
  },
  {
    "country": "MX",
    "name": "Xaloztoc",
    "lat": "19.40775",
    "lng": "-98.04602"
  },
  {
    "country": "MX",
    "name": "Santa Ana Xalmimilulco",
    "lat": "19.21287",
    "lng": "-98.38207"
  },
  {
    "country": "MX",
    "name": "Vista Hermosa",
    "lat": "19.51616",
    "lng": "-99.22335"
  },
  {
    "country": "MX",
    "name": "San Antonio Virreyes",
    "lat": "19.40989",
    "lng": "-97.63697"
  },
  {
    "country": "MX",
    "name": "Villa Victoria",
    "lat": "19.43693",
    "lng": "-99.99589"
  },
  {
    "country": "MX",
    "name": "Camarón de Tejeda",
    "lat": "19.02166",
    "lng": "-96.61513"
  },
  {
    "country": "MX",
    "name": "Álvaro Obregón",
    "lat": "19.35867",
    "lng": "-99.20329"
  },
  {
    "country": "MX",
    "name": "Villa Mainero",
    "lat": "24.56007",
    "lng": "-99.61561"
  },
  {
    "country": "MX",
    "name": "Villahermosa",
    "lat": "17.98689",
    "lng": "-92.93028"
  },
  {
    "country": "MX",
    "name": "Gustavo Adolfo Madero",
    "lat": "19.49392",
    "lng": "-99.11075"
  },
  {
    "country": "MX",
    "name": "Villa Guerrero",
    "lat": "18.96211",
    "lng": "-99.64061"
  },
  {
    "country": "MX",
    "name": "Villagrán",
    "lat": "24.47264",
    "lng": "-99.49107"
  },
  {
    "country": "MX",
    "name": "Villaflores",
    "lat": "16.2341",
    "lng": "-93.27037"
  },
  {
    "country": "MX",
    "name": "El Triunfo",
    "lat": "17.92241",
    "lng": "-91.16946"
  },
  {
    "country": "MX",
    "name": "Villa del Carbón",
    "lat": "19.72875",
    "lng": "-99.46362"
  },
  {
    "country": "MX",
    "name": "Ciudad Cuauhtémoc",
    "lat": "22.18439",
    "lng": "-97.83472"
  },
  {
    "country": "MX",
    "name": "Villa Cuauhtémoc",
    "lat": "19.41676",
    "lng": "-99.55872"
  },
  {
    "country": "MX",
    "name": "Villa Corzo",
    "lat": "16.1851",
    "lng": "-93.26881"
  },
  {
    "country": "MX",
    "name": "Villa Comaltitlán",
    "lat": "15.21397",
    "lng": "-92.57659"
  },
  {
    "country": "MX",
    "name": "Tesechoacan",
    "lat": "18.13749",
    "lng": "-95.65835"
  },
  {
    "country": "MX",
    "name": "Villa Aldama",
    "lat": "19.64861",
    "lng": "-97.22333"
  },
  {
    "country": "MX",
    "name": "Veracruz",
    "lat": "19.18095",
    "lng": "-96.1429"
  },
  {
    "country": "MX",
    "name": "Venustiano Carranza",
    "lat": "16.33815",
    "lng": "-92.563"
  },
  {
    "country": "MX",
    "name": "Veinte de Noviembre",
    "lat": "14.9773",
    "lng": "-92.26509"
  },
  {
    "country": "MX",
    "name": "Vega de Alatorre",
    "lat": "20.02823",
    "lng": "-96.64751"
  },
  {
    "country": "MX",
    "name": "Valle Hermoso",
    "lat": "25.67207",
    "lng": "-97.81313"
  },
  {
    "country": "MX",
    "name": "Vallecillo",
    "lat": "26.66033",
    "lng": "-99.98744"
  },
  {
    "country": "MX",
    "name": "Valladolid",
    "lat": "20.68812",
    "lng": "-88.19936"
  },
  {
    "country": "MX",
    "name": "Úrsulo Galván",
    "lat": "19.40531",
    "lng": "-96.3609"
  },
  {
    "country": "MX",
    "name": "Unión Juárez",
    "lat": "15.06279",
    "lng": "-92.08068"
  },
  {
    "country": "MX",
    "name": "Unión Hidalgo",
    "lat": "16.4723",
    "lng": "-94.82952"
  },
  {
    "country": "MX",
    "name": "Uman",
    "lat": "20.88213",
    "lng": "-89.74649"
  },
  {
    "country": "MX",
    "name": "Ucú",
    "lat": "21.03135",
    "lng": "-89.74466"
  },
  {
    "country": "MX",
    "name": "Uayma",
    "lat": "20.71781",
    "lng": "-88.31693"
  },
  {
    "country": "MX",
    "name": "Tzucacab",
    "lat": "20.07237",
    "lng": "-89.05022"
  },
  {
    "country": "MX",
    "name": "Tzompantepec",
    "lat": "19.37608",
    "lng": "-98.09014"
  },
  {
    "country": "MX",
    "name": "Tzinacapan",
    "lat": "20.02944",
    "lng": "-97.54047"
  },
  {
    "country": "MX",
    "name": "Tzimol",
    "lat": "16.18356",
    "lng": "-92.18934"
  },
  {
    "country": "MX",
    "name": "Tuzantán",
    "lat": "15.14711",
    "lng": "-92.42237"
  },
  {
    "country": "MX",
    "name": "Tuzamapan",
    "lat": "20.06572",
    "lng": "-97.5752"
  },
  {
    "country": "MX",
    "name": "Tuzamapan",
    "lat": "19.40253",
    "lng": "-96.8636"
  },
  {
    "country": "MX",
    "name": "Tuxtla",
    "lat": "16.75973",
    "lng": "-93.11308"
  },
  {
    "country": "MX",
    "name": "Tuxtla Chico",
    "lat": "14.93945",
    "lng": "-92.1673"
  },
  {
    "country": "MX",
    "name": "Tuxtla",
    "lat": "20.00037",
    "lng": "-97.65526"
  },
  {
    "country": "MX",
    "name": "Tuxtilla",
    "lat": "18.23888",
    "lng": "-95.89456"
  },
  {
    "country": "MX",
    "name": "Túxpam de Rodríguez Cano",
    "lat": "20.95777",
    "lng": "-97.40805"
  },
  {
    "country": "MX",
    "name": "Tunkas",
    "lat": "20.90294",
    "lng": "-88.75171"
  },
  {
    "country": "MX",
    "name": "Tulum",
    "lat": "20.21173",
    "lng": "-87.46325"
  },
  {
    "country": "MX",
    "name": "Tultitlán de Mariano Escobedo",
    "lat": "19.64655",
    "lng": "-99.16787"
  },
  {
    "country": "MX",
    "name": "Tultepec",
    "lat": "19.685",
    "lng": "-99.12806"
  },
  {
    "country": "MX",
    "name": "Tulcingo de Valle",
    "lat": "18.0437",
    "lng": "-98.44074"
  },
  {
    "country": "MX",
    "name": "Tulancingo",
    "lat": "20.08355",
    "lng": "-98.36288"
  },
  {
    "country": "MX",
    "name": "Tula de Allende",
    "lat": "20.05161",
    "lng": "-99.34397"
  },
  {
    "country": "MX",
    "name": "Ciudad Tula",
    "lat": "22.99732",
    "lng": "-99.71101"
  },
  {
    "country": "MX",
    "name": "Trinidad Zaachila",
    "lat": "16.92135",
    "lng": "-96.76384"
  },
  {
    "country": "MX",
    "name": "Tres Picos",
    "lat": "15.88209",
    "lng": "-93.52867"
  },
  {
    "country": "MX",
    "name": "Trapiche del Rosario",
    "lat": "19.54306",
    "lng": "-96.74111"
  },
  {
    "country": "MX",
    "name": "Totutla",
    "lat": "19.21169",
    "lng": "-96.96118"
  },
  {
    "country": "MX",
    "name": "Totontepec Villa de Morelos",
    "lat": "17.25679",
    "lng": "-96.02786"
  },
  {
    "country": "MX",
    "name": "Totoltepec de Guerrero",
    "lat": "18.2256",
    "lng": "-97.85511"
  },
  {
    "country": "MX",
    "name": "Totolapan",
    "lat": "18.98487",
    "lng": "-98.92073"
  },
  {
    "country": "MX",
    "name": "Totolapa",
    "lat": "16.54357",
    "lng": "-92.68019"
  },
  {
    "country": "MX",
    "name": "San Miguel Totocuitlapilco",
    "lat": "19.23107",
    "lng": "-99.59116"
  },
  {
    "country": "MX",
    "name": "Tonayán",
    "lat": "19.683",
    "lng": "-96.92118"
  },
  {
    "country": "MX",
    "name": "Santo Domingo Tomaltepec",
    "lat": "17.06117",
    "lng": "-96.6228"
  },
  {
    "country": "MX",
    "name": "Tonalixco",
    "lat": "18.78194",
    "lng": "-97.05972"
  },
  {
    "country": "MX",
    "name": "Tomatlán",
    "lat": "19.03102",
    "lng": "-97.00986"
  },
  {
    "country": "MX",
    "name": "Toluca",
    "lat": "19.28786",
    "lng": "-99.65324"
  },
  {
    "country": "MX",
    "name": "Tolome",
    "lat": "19.26667",
    "lng": "-96.39472"
  },
  {
    "country": "MX",
    "name": "Tolimán",
    "lat": "20.90845",
    "lng": "-99.9304"
  },
  {
    "country": "MX",
    "name": "Tolcayuca",
    "lat": "19.95814",
    "lng": "-98.91941"
  },
  {
    "country": "MX",
    "name": "Tocuila",
    "lat": "18.95",
    "lng": "-97.01667"
  },
  {
    "country": "MX",
    "name": "Tochtepec",
    "lat": "18.83928",
    "lng": "-97.82282"
  },
  {
    "country": "MX",
    "name": "Tochimilco",
    "lat": "18.89062",
    "lng": "-98.57154"
  },
  {
    "country": "MX",
    "name": "Tocatlán",
    "lat": "19.38865",
    "lng": "-98.0274"
  },
  {
    "country": "MX",
    "name": "Tlazala de Fabela",
    "lat": "19.55857",
    "lng": "-99.41469"
  },
  {
    "country": "MX",
    "name": "Tlayacapan",
    "lat": "18.95556",
    "lng": "-98.98111"
  },
  {
    "country": "MX",
    "name": "Tlaxco",
    "lat": "19.61442",
    "lng": "-98.11997"
  },
  {
    "country": "MX",
    "name": "Tlaxcoapan",
    "lat": "20.09163",
    "lng": "-99.22042"
  },
  {
    "country": "MX",
    "name": "Tlaxco",
    "lat": "20.42345",
    "lng": "-98.02917"
  },
  {
    "country": "MX",
    "name": "San Bernardino Tlaxcalancingo",
    "lat": "19.02867",
    "lng": "-98.27698"
  },
  {
    "country": "MX",
    "name": "Tlatlauquitepec",
    "lat": "19.84765",
    "lng": "-97.49718"
  },
  {
    "country": "MX",
    "name": "Tlatenchi",
    "lat": "18.59639",
    "lng": "-99.18639"
  },
  {
    "country": "MX",
    "name": "Tlaquiltenango",
    "lat": "18.63429",
    "lng": "-99.1632"
  },
  {
    "country": "MX",
    "name": "Tlaquilpa",
    "lat": "18.6102",
    "lng": "-97.11852"
  },
  {
    "country": "MX",
    "name": "Tlapa de Comonfort",
    "lat": "17.54528",
    "lng": "-98.57599"
  },
  {
    "country": "MX",
    "name": "Tlapacoyan",
    "lat": "19.96268",
    "lng": "-97.21141"
  },
  {
    "country": "MX",
    "name": "Tlanepantla",
    "lat": "18.8631",
    "lng": "-97.88701"
  },
  {
    "country": "MX",
    "name": "Tlanchinol",
    "lat": "20.9919",
    "lng": "-98.65715"
  },
  {
    "country": "MX",
    "name": "Tlanalapa",
    "lat": "19.81868",
    "lng": "-98.60396"
  },
  {
    "country": "MX",
    "name": "Tlanalapan",
    "lat": "19.25084",
    "lng": "-97.27604"
  },
  {
    "country": "MX",
    "name": "Tlamixtlahuacan",
    "lat": "17.50306",
    "lng": "-99.22583"
  },
  {
    "country": "MX",
    "name": "Tlamacazapa",
    "lat": "18.49649",
    "lng": "-99.50037"
  },
  {
    "country": "MX",
    "name": "Tlaltizapán",
    "lat": "18.6863",
    "lng": "-99.11868"
  },
  {
    "country": "MX",
    "name": "Tlaltenango",
    "lat": "19.17165",
    "lng": "-98.34072"
  },
  {
    "country": "MX",
    "name": "Tlalpan",
    "lat": "19.29513",
    "lng": "-99.16206"
  },
  {
    "country": "MX",
    "name": "Tlalnepantla",
    "lat": "19.54005",
    "lng": "-99.19538"
  },
  {
    "country": "MX",
    "name": "Tlalnepantla",
    "lat": "19.00885",
    "lng": "-98.99613"
  },
  {
    "country": "MX",
    "name": "Tlalnelhuayocan",
    "lat": "19.56681",
    "lng": "-96.97534"
  },
  {
    "country": "MX",
    "name": "Tlalmanalco",
    "lat": "19.20521",
    "lng": "-98.80115"
  },
  {
    "country": "MX",
    "name": "Tlalixtaquilla",
    "lat": "17.57674",
    "lng": "-98.36727"
  },
  {
    "country": "MX",
    "name": "Tlalixtac de Cabrera",
    "lat": "17.07112",
    "lng": "-96.6471"
  },
  {
    "country": "MX",
    "name": "Tlalixcoyan",
    "lat": "18.80222",
    "lng": "-96.06056"
  },
  {
    "country": "MX",
    "name": "San Andrés Tlalamac",
    "lat": "18.96694",
    "lng": "-98.80778"
  },
  {
    "country": "MX",
    "name": "Tlahuelompa (San Francisco Tlahuelompa)",
    "lat": "20.65082",
    "lng": "-98.57522"
  },
  {
    "country": "MX",
    "name": "Tlahuelilpan",
    "lat": "20.13076",
    "lng": "-99.23145"
  },
  {
    "country": "MX",
    "name": "Tláhuac",
    "lat": "19.28689",
    "lng": "-99.00507"
  },
  {
    "country": "MX",
    "name": "Tlacuilotepec",
    "lat": "20.32574",
    "lng": "-98.06867"
  },
  {
    "country": "MX",
    "name": "San José Tlacotitlán",
    "lat": "18.98583",
    "lng": "-98.80611"
  },
  {
    "country": "MX",
    "name": "Tlacotepec (San Mateo)",
    "lat": "20.06028",
    "lng": "-97.84917"
  },
  {
    "country": "MX",
    "name": "Tlacotepec de Mejía",
    "lat": "19.18946",
    "lng": "-96.83805"
  },
  {
    "country": "MX",
    "name": "Tlacotepec",
    "lat": "18.81444",
    "lng": "-98.74514"
  },
  {
    "country": "MX",
    "name": "Tlacotepec",
    "lat": "18.68193",
    "lng": "-97.65602"
  },
  {
    "country": "MX",
    "name": "Tlacotepec",
    "lat": "17.78978",
    "lng": "-99.97961"
  },
  {
    "country": "MX",
    "name": "Tlacotalpan",
    "lat": "18.61333",
    "lng": "-95.6589"
  },
  {
    "country": "MX",
    "name": "Tlacolula de Matamoros",
    "lat": "16.95471",
    "lng": "-96.4759"
  },
  {
    "country": "MX",
    "name": "Tlacojalpan",
    "lat": "18.23096",
    "lng": "-95.94682"
  },
  {
    "country": "MX",
    "name": "San Jerónimo Tlacochahuaya",
    "lat": "17.00874",
    "lng": "-96.58275"
  },
  {
    "country": "MX",
    "name": "Tlacoachistlahuaca",
    "lat": "16.81045",
    "lng": "-98.30078"
  },
  {
    "country": "MX",
    "name": "Tlachichuca",
    "lat": "19.11485",
    "lng": "-97.41915"
  },
  {
    "country": "MX",
    "name": "Tlachichilco",
    "lat": "20.62123",
    "lng": "-98.199"
  },
  {
    "country": "MX",
    "name": "Tizimín",
    "lat": "21.14268",
    "lng": "-88.15101"
  },
  {
    "country": "MX",
    "name": "Tizayuca",
    "lat": "19.83721",
    "lng": "-98.97607"
  },
  {
    "country": "MX",
    "name": "Tixtla de Guerrero",
    "lat": "17.56732",
    "lng": "-99.39799"
  },
  {
    "country": "MX",
    "name": "Tixpehual",
    "lat": "20.97739",
    "lng": "-89.44203"
  },
  {
    "country": "MX",
    "name": "Tixkokob",
    "lat": "21.0022",
    "lng": "-89.39484"
  },
  {
    "country": "MX",
    "name": "Tixcacaltuyub",
    "lat": "20.49316",
    "lng": "-88.91637"
  },
  {
    "country": "MX",
    "name": "Tinum",
    "lat": "20.76779",
    "lng": "-88.39164"
  },
  {
    "country": "MX",
    "name": "Timucuy",
    "lat": "20.81023",
    "lng": "-89.51383"
  },
  {
    "country": "MX",
    "name": "Tilzapotla",
    "lat": "18.48916",
    "lng": "-99.27442"
  },
  {
    "country": "MX",
    "name": "Santiago Tillo",
    "lat": "17.46085",
    "lng": "-97.32019"
  },
  {
    "country": "MX",
    "name": "San Martín Tilcajete",
    "lat": "16.86008",
    "lng": "-96.6949"
  },
  {
    "country": "MX",
    "name": "Tilapa",
    "lat": "18.59717",
    "lng": "-98.55156"
  },
  {
    "country": "MX",
    "name": "Tila",
    "lat": "17.30054",
    "lng": "-92.4273"
  },
  {
    "country": "MX",
    "name": "Tikuch",
    "lat": "20.70301",
    "lng": "-88.11272"
  },
  {
    "country": "MX",
    "name": "Tihuatlan",
    "lat": "20.71449",
    "lng": "-97.53335"
  },
  {
    "country": "MX",
    "name": "Tiholop",
    "lat": "20.33234",
    "lng": "-88.68958"
  },
  {
    "country": "MX",
    "name": "Tierra Colorada",
    "lat": "17.16571",
    "lng": "-99.52791"
  },
  {
    "country": "MX",
    "name": "Ticul",
    "lat": "20.39833",
    "lng": "-89.53541"
  },
  {
    "country": "MX",
    "name": "Santiago Tianguistenco de Galeana",
    "lat": "19.18024",
    "lng": "-99.46644"
  },
  {
    "country": "MX",
    "name": "Tezontepec de Aldama",
    "lat": "20.19073",
    "lng": "-99.27429"
  },
  {
    "country": "MX",
    "name": "Tezontepec",
    "lat": "19.88063",
    "lng": "-98.81972"
  },
  {
    "country": "MX",
    "name": "Tezoatlán de Segura y Luna",
    "lat": "17.65388",
    "lng": "-97.81068"
  },
  {
    "country": "MX",
    "name": "Teziutlan",
    "lat": "19.8173",
    "lng": "-97.35992"
  },
  {
    "country": "MX",
    "name": "Texistepec",
    "lat": "17.89476",
    "lng": "-94.81711"
  },
  {
    "country": "MX",
    "name": "Texhuacán",
    "lat": "18.62233",
    "lng": "-97.04025"
  },
  {
    "country": "MX",
    "name": "Texcoco de Mora",
    "lat": "19.51194",
    "lng": "-98.88293"
  },
  {
    "country": "MX",
    "name": "Texcatepec",
    "lat": "20.58505",
    "lng": "-98.36538"
  },
  {
    "country": "MX",
    "name": "Texcalyacac",
    "lat": "19.13253",
    "lng": "-99.50163"
  },
  {
    "country": "MX",
    "name": "San Juan Texcalpan",
    "lat": "18.93583",
    "lng": "-98.92889"
  },
  {
    "country": "MX",
    "name": "Texcala",
    "lat": "18.93444",
    "lng": "-98.79472"
  },
  {
    "country": "MX",
    "name": "San Gabriel Tetzoyocán",
    "lat": "18.75727",
    "lng": "-97.70324"
  },
  {
    "country": "MX",
    "name": "Tetiz",
    "lat": "20.96316",
    "lng": "-89.93384"
  },
  {
    "country": "MX",
    "name": "Tetipac",
    "lat": "18.64778",
    "lng": "-99.64778"
  },
  {
    "country": "MX",
    "name": "Tetepango",
    "lat": "20.10168",
    "lng": "-99.15108"
  },
  {
    "country": "MX",
    "name": "Teteltzingo",
    "lat": "19.05141",
    "lng": "-97.14465"
  },
  {
    "country": "MX",
    "name": "Teteles de Avila Castillo",
    "lat": "19.85748",
    "lng": "-97.45703"
  },
  {
    "country": "MX",
    "name": "Tetela de Ocampo",
    "lat": "19.8177",
    "lng": "-97.80691"
  },
  {
    "country": "MX",
    "name": "Tetela del Volcán",
    "lat": "18.89306",
    "lng": "-98.72972"
  },
  {
    "country": "MX",
    "name": "Tetecala",
    "lat": "18.73009",
    "lng": "-99.40021"
  },
  {
    "country": "MX",
    "name": "Tesoco",
    "lat": "20.72259",
    "lng": "-88.15456"
  },
  {
    "country": "MX",
    "name": "Terrenate",
    "lat": "19.47666",
    "lng": "-97.9202"
  },
  {
    "country": "MX",
    "name": "Tequixquiac",
    "lat": "19.90944",
    "lng": "-99.14472"
  },
  {
    "country": "MX",
    "name": "Tequisquiapan",
    "lat": "20.5225",
    "lng": "-99.89167"
  },
  {
    "country": "MX",
    "name": "Tequila",
    "lat": "18.72998",
    "lng": "-97.06991"
  },
  {
    "country": "MX",
    "name": "San Martín Tequesquipan (Tequesquipan)",
    "lat": "19.05806",
    "lng": "-99.94667"
  },
  {
    "country": "MX",
    "name": "San Juan Tepulco",
    "lat": "19.11709",
    "lng": "-97.98847"
  },
  {
    "country": "MX",
    "name": "Cuautitlán Izcalli",
    "lat": "19.64388",
    "lng": "-99.21598"
  },
  {
    "country": "MX",
    "name": "Tepoztlán",
    "lat": "18.98622",
    "lng": "-99.10051"
  },
  {
    "country": "MX",
    "name": "Tepotzotlán",
    "lat": "19.72116",
    "lng": "-99.22391"
  },
  {
    "country": "MX",
    "name": "Tepeyahualco",
    "lat": "18.81428",
    "lng": "-97.87702"
  },
  {
    "country": "MX",
    "name": "Tepexi de Rodríguez",
    "lat": "18.58108",
    "lng": "-97.92606"
  },
  {
    "country": "MX",
    "name": "Tepetzintla",
    "lat": "21.1641",
    "lng": "-97.85236"
  },
  {
    "country": "MX",
    "name": "Tepetzintla",
    "lat": "19.9672",
    "lng": "-97.84143"
  },
  {
    "country": "MX",
    "name": "Tepetlaoxtoc de Hidalgo",
    "lat": "19.57437",
    "lng": "-98.81835"
  },
  {
    "country": "MX",
    "name": "Tepetlán",
    "lat": "19.67318",
    "lng": "-96.79734"
  },
  {
    "country": "MX",
    "name": "Tepetlacolco",
    "lat": "18.64104",
    "lng": "-97.69284"
  },
  {
    "country": "MX",
    "name": "Barrio Tepetitlán Emilio Portes Gil",
    "lat": "19.65306",
    "lng": "-99.88667"
  },
  {
    "country": "MX",
    "name": "Santa Cecilia Tepetitlán",
    "lat": "19.19254",
    "lng": "-97.43395"
  },
  {
    "country": "MX",
    "name": "Tepetitla",
    "lat": "19.26531",
    "lng": "-98.37645"
  },
  {
    "country": "MX",
    "name": "Tepepa",
    "lat": "20.1344",
    "lng": "-98.17131"
  },
  {
    "country": "MX",
    "name": "Tepeojuma",
    "lat": "18.72468",
    "lng": "-98.44633"
  },
  {
    "country": "MX",
    "name": "Tepeji del Río de Ocampo",
    "lat": "19.90481",
    "lng": "-99.34379"
  },
  {
    "country": "MX",
    "name": "Tepecoacuilco de Trujano",
    "lat": "18.2875",
    "lng": "-99.46423"
  },
  {
    "country": "MX",
    "name": "Tepeapulco",
    "lat": "19.7884",
    "lng": "-98.55266"
  },
  {
    "country": "MX",
    "name": "Tepeaca",
    "lat": "18.96688",
    "lng": "-97.8998"
  },
  {
    "country": "MX",
    "name": "Tepatlaxco de Hidalgo",
    "lat": "19.06747",
    "lng": "-97.96595"
  },
  {
    "country": "MX",
    "name": "Tepatlaxco",
    "lat": "19.06927",
    "lng": "-96.84481"
  },
  {
    "country": "MX",
    "name": "Tepatepec",
    "lat": "20.24568",
    "lng": "-99.08981"
  },
  {
    "country": "MX",
    "name": "Tepango",
    "lat": "20.00314",
    "lng": "-97.79651"
  },
  {
    "country": "MX",
    "name": "Tepanco",
    "lat": "18.55686",
    "lng": "-97.5613"
  },
  {
    "country": "MX",
    "name": "Tepalcingo",
    "lat": "18.59498",
    "lng": "-98.84537"
  },
  {
    "country": "MX",
    "name": "Tepakan",
    "lat": "21.04882",
    "lng": "-89.03873"
  },
  {
    "country": "MX",
    "name": "Teotitlán del Valle",
    "lat": "17.02975",
    "lng": "-96.51926"
  },
  {
    "country": "MX",
    "name": "Teopisca",
    "lat": "16.54182",
    "lng": "-92.47405"
  },
  {
    "country": "MX",
    "name": "Teopantlán",
    "lat": "18.71219",
    "lng": "-98.26341"
  },
  {
    "country": "MX",
    "name": "Teoloyucan",
    "lat": "19.74423",
    "lng": "-99.18113"
  },
  {
    "country": "MX",
    "name": "Teocelo",
    "lat": "19.3856",
    "lng": "-96.97371"
  },
  {
    "country": "MX",
    "name": "Tenosique",
    "lat": "17.4729",
    "lng": "-91.4236"
  },
  {
    "country": "MX",
    "name": "Tanetze de Zaragoza",
    "lat": "17.37616",
    "lng": "-96.30111"
  },
  {
    "country": "MX",
    "name": "Tenejapa",
    "lat": "16.81878",
    "lng": "-92.50646"
  },
  {
    "country": "MX",
    "name": "Tenango del Aire",
    "lat": "19.15774",
    "lng": "-98.85687"
  },
  {
    "country": "MX",
    "name": "Tenango de Doria",
    "lat": "20.33828",
    "lng": "-98.22805"
  },
  {
    "country": "MX",
    "name": "Tenango de Arista",
    "lat": "19.10446",
    "lng": "-99.5898"
  },
  {
    "country": "MX",
    "name": "San Sebastián Tenango",
    "lat": "18.66282",
    "lng": "-98.17392"
  },
  {
    "country": "MX",
    "name": "Tenango",
    "lat": "16.96667",
    "lng": "-92.41667"
  },
  {
    "country": "MX",
    "name": "Tenancingo de Degollado",
    "lat": "18.96136",
    "lng": "-99.5903"
  },
  {
    "country": "MX",
    "name": "Tenampulco",
    "lat": "20.17042",
    "lng": "-97.40496"
  },
  {
    "country": "MX",
    "name": "Tenampa",
    "lat": "19.24877",
    "lng": "-96.8839"
  },
  {
    "country": "MX",
    "name": "Tenabo",
    "lat": "20.03981",
    "lng": "-90.22573"
  },
  {
    "country": "MX",
    "name": "Tempoal de Sánchez",
    "lat": "21.51998",
    "lng": "-98.38829"
  },
  {
    "country": "MX",
    "name": "Temozon",
    "lat": "20.80393",
    "lng": "-88.20155"
  },
  {
    "country": "MX",
    "name": "Temoaya",
    "lat": "19.46747",
    "lng": "-99.59407"
  },
  {
    "country": "MX",
    "name": "Temoac",
    "lat": "18.77222",
    "lng": "-98.7775"
  },
  {
    "country": "MX",
    "name": "Temixco",
    "lat": "18.85254",
    "lng": "-99.22537"
  },
  {
    "country": "MX",
    "name": "Temax",
    "lat": "21.15105",
    "lng": "-88.94039"
  },
  {
    "country": "MX",
    "name": "Temascalcingo",
    "lat": "19.91635",
    "lng": "-100.00369"
  },
  {
    "country": "MX",
    "name": "Temascalapa",
    "lat": "19.82766",
    "lng": "-98.90171"
  },
  {
    "country": "MX",
    "name": "Temapache",
    "lat": "21.06611",
    "lng": "-97.64207"
  },
  {
    "country": "MX",
    "name": "Temamatla",
    "lat": "19.20306",
    "lng": "-98.86921"
  },
  {
    "country": "MX",
    "name": "Teloloapan",
    "lat": "18.36663",
    "lng": "-99.87185"
  },
  {
    "country": "MX",
    "name": "Telixtac",
    "lat": "18.56031",
    "lng": "-98.77625"
  },
  {
    "country": "MX",
    "name": "Telchac Puerto",
    "lat": "21.34121",
    "lng": "-89.26333"
  },
  {
    "country": "MX",
    "name": "Telchac Pueblo",
    "lat": "21.20312",
    "lng": "-89.26945"
  },
  {
    "country": "MX",
    "name": "Tekit",
    "lat": "20.53465",
    "lng": "-89.33315"
  },
  {
    "country": "MX",
    "name": "Tecax",
    "lat": "20.2052",
    "lng": "-89.28522"
  },
  {
    "country": "MX",
    "name": "Tekanto",
    "lat": "21.00968",
    "lng": "-89.10723"
  },
  {
    "country": "MX",
    "name": "San Felipe Tejalápam",
    "lat": "17.11134",
    "lng": "-96.8542"
  },
  {
    "country": "MX",
    "name": "San Juan Teitipac",
    "lat": "16.92799",
    "lng": "-96.60619"
  },
  {
    "country": "MX",
    "name": "Tehuixtla",
    "lat": "18.55944",
    "lng": "-99.27119"
  },
  {
    "country": "MX",
    "name": "Tehuipango",
    "lat": "18.51964",
    "lng": "-97.05438"
  },
  {
    "country": "MX",
    "name": "Tehuetlán",
    "lat": "21.05337",
    "lng": "-98.50853"
  },
  {
    "country": "MX",
    "name": "Tehuacán",
    "lat": "18.46422",
    "lng": "-97.39735"
  },
  {
    "country": "MX",
    "name": "Tecpatán",
    "lat": "17.13676",
    "lng": "-93.31133"
  },
  {
    "country": "MX",
    "name": "Tecozautla",
    "lat": "20.53359",
    "lng": "-99.63449"
  },
  {
    "country": "MX",
    "name": "San Marcos Tecomaxusco",
    "lat": "18.98152",
    "lng": "-98.76035"
  },
  {
    "country": "MX",
    "name": "Tecolutla",
    "lat": "20.48049",
    "lng": "-97.01309"
  },
  {
    "country": "MX",
    "name": "Villa Tecolutilla",
    "lat": "18.28338",
    "lng": "-93.33398"
  },
  {
    "country": "MX",
    "name": "Tekoh",
    "lat": "20.74361",
    "lng": "-89.47406"
  },
  {
    "country": "MX",
    "name": "Barra de Tecoanapa",
    "lat": "16.50864",
    "lng": "-98.73216"
  },
  {
    "country": "MX",
    "name": "San Pedro Techuchulco",
    "lat": "19.11359",
    "lng": "-99.52425"
  },
  {
    "country": "MX",
    "name": "Tecamachalco",
    "lat": "18.88352",
    "lng": "-97.73344"
  },
  {
    "country": "MX",
    "name": "Tecali",
    "lat": "18.9006",
    "lng": "-97.97064"
  },
  {
    "country": "MX",
    "name": "Tecajec",
    "lat": "18.79806",
    "lng": "-98.815"
  },
  {
    "country": "MX",
    "name": "Teapa",
    "lat": "17.5497",
    "lng": "-92.95211"
  },
  {
    "country": "MX",
    "name": "Teabo",
    "lat": "20.40059",
    "lng": "-89.28316"
  },
  {
    "country": "MX",
    "name": "Taxco de Alarcón",
    "lat": "18.55462",
    "lng": "-99.60592"
  },
  {
    "country": "MX",
    "name": "Tatatila",
    "lat": "19.6932",
    "lng": "-97.1116"
  },
  {
    "country": "MX",
    "name": "Tatahuicapan",
    "lat": "18.24621",
    "lng": "-94.76124"
  },
  {
    "country": "MX",
    "name": "Tasquillo",
    "lat": "20.54836",
    "lng": "-99.31352"
  },
  {
    "country": "MX",
    "name": "Tapilula",
    "lat": "17.2495",
    "lng": "-93.0167"
  },
  {
    "country": "MX",
    "name": "Tapalapa",
    "lat": "17.19109",
    "lng": "-93.10518"
  },
  {
    "country": "MX",
    "name": "Tapachula",
    "lat": "14.90385",
    "lng": "-92.25749"
  },
  {
    "country": "MX",
    "name": "Tantoyuca",
    "lat": "21.35064",
    "lng": "-98.2257"
  },
  {
    "country": "MX",
    "name": "Tantima",
    "lat": "21.33228",
    "lng": "-97.83327"
  },
  {
    "country": "MX",
    "name": "Tanute",
    "lat": "21.65243",
    "lng": "-99.03765"
  },
  {
    "country": "MX",
    "name": "Tanquián de Escobedo",
    "lat": "21.60587",
    "lng": "-98.66275"
  },
  {
    "country": "MX",
    "name": "Tanlajás",
    "lat": "21.66518",
    "lng": "-98.886"
  },
  {
    "country": "MX",
    "name": "Tancoco",
    "lat": "21.28622",
    "lng": "-97.79139"
  },
  {
    "country": "MX",
    "name": "Tamulte de las Sabanas",
    "lat": "18.16168",
    "lng": "-92.78354"
  },
  {
    "country": "MX",
    "name": "Tamuín",
    "lat": "22.00554",
    "lng": "-98.77972"
  },
  {
    "country": "MX",
    "name": "Tampico Alto",
    "lat": "22.1124",
    "lng": "-97.80184"
  },
  {
    "country": "MX",
    "name": "Tampico",
    "lat": "22.24484",
    "lng": "-97.8352"
  },
  {
    "country": "MX",
    "name": "Tampamolón Corona",
    "lat": "21.5588",
    "lng": "-98.81874"
  },
  {
    "country": "MX",
    "name": "Tampacán",
    "lat": "21.40201",
    "lng": "-98.72819"
  },
  {
    "country": "MX",
    "name": "Tamiahua",
    "lat": "21.27881",
    "lng": "-97.4462"
  },
  {
    "country": "MX",
    "name": "Tamazunchale",
    "lat": "21.25993",
    "lng": "-98.78935"
  },
  {
    "country": "MX",
    "name": "Tamasopo",
    "lat": "21.92426",
    "lng": "-99.39365"
  },
  {
    "country": "MX",
    "name": "Tamápatz",
    "lat": "21.56654",
    "lng": "-99.07764"
  },
  {
    "country": "MX",
    "name": "Tamalín",
    "lat": "21.33936",
    "lng": "-97.81188"
  },
  {
    "country": "MX",
    "name": "Tahmek",
    "lat": "20.8736",
    "lng": "-89.25473"
  },
  {
    "country": "MX",
    "name": "San Juan Tahitic",
    "lat": "19.93605",
    "lng": "-97.55082"
  },
  {
    "country": "MX",
    "name": "Tacotalpa",
    "lat": "17.59638",
    "lng": "-92.82596"
  },
  {
    "country": "MX",
    "name": "Sunuapa",
    "lat": "17.49172",
    "lng": "-93.24385"
  },
  {
    "country": "MX",
    "name": "Sultepec",
    "lat": "18.85855",
    "lng": "-99.96588"
  },
  {
    "country": "MX",
    "name": "Sucilá",
    "lat": "21.1565",
    "lng": "-88.31405"
  },
  {
    "country": "MX",
    "name": "Brisas Barra de Suchiate",
    "lat": "14.53588",
    "lng": "-92.22414"
  },
  {
    "country": "MX",
    "name": "Suchiapa",
    "lat": "16.62555",
    "lng": "-93.10074"
  },
  {
    "country": "MX",
    "name": "Soyaniquilpan",
    "lat": "20.01488",
    "lng": "-99.53022"
  },
  {
    "country": "MX",
    "name": "Soyaló",
    "lat": "16.8913",
    "lng": "-92.92433"
  },
  {
    "country": "MX",
    "name": "Sotuta",
    "lat": "20.59678",
    "lng": "-89.00815"
  },
  {
    "country": "MX",
    "name": "Soto la Marina",
    "lat": "23.76953",
    "lng": "-98.20442"
  },
  {
    "country": "MX",
    "name": "Soteapan",
    "lat": "18.23391",
    "lng": "-94.87296"
  },
  {
    "country": "MX",
    "name": "Solosuchiapa",
    "lat": "17.42952",
    "lng": "-93.03255"
  },
  {
    "country": "MX",
    "name": "Soltepec",
    "lat": "19.12111",
    "lng": "-97.70861"
  },
  {
    "country": "MX",
    "name": "Soledad de Doblado",
    "lat": "19.04637",
    "lng": "-96.42142"
  },
  {
    "country": "MX",
    "name": "Soconusco",
    "lat": "17.96315",
    "lng": "-94.88097"
  },
  {
    "country": "MX",
    "name": "Socoltenango",
    "lat": "16.24484",
    "lng": "-92.35038"
  },
  {
    "country": "MX",
    "name": "Xochiapa",
    "lat": "17.66354",
    "lng": "-95.73494"
  },
  {
    "country": "MX",
    "name": "Sochiapa",
    "lat": "19.19292",
    "lng": "-96.93989"
  },
  {
    "country": "MX",
    "name": "Santiago Apostol",
    "lat": "16.80381",
    "lng": "-96.72046"
  },
  {
    "country": "MX",
    "name": "Sisal",
    "lat": "21.167",
    "lng": "-90.02532"
  },
  {
    "country": "MX",
    "name": "Singuilucan",
    "lat": "19.96874",
    "lng": "-98.51935"
  },
  {
    "country": "MX",
    "name": "Simojovel de Allende",
    "lat": "17.14036",
    "lng": "-92.71394"
  },
  {
    "country": "MX",
    "name": "Siltepec",
    "lat": "15.55717",
    "lng": "-92.32314"
  },
  {
    "country": "MX",
    "name": "Sierra Papacal",
    "lat": "21.12522",
    "lng": "-89.73018"
  },
  {
    "country": "MX",
    "name": "Seyé",
    "lat": "20.83568",
    "lng": "-89.37174"
  },
  {
    "country": "MX",
    "name": "Seybaplaya",
    "lat": "19.63994",
    "lng": "-90.68706"
  },
  {
    "country": "MX",
    "name": "Sergio Butrón Casas",
    "lat": "18.5139",
    "lng": "-88.56883"
  },
  {
    "country": "MX",
    "name": "San Sebastián del Monte",
    "lat": "17.67778",
    "lng": "-98.02194"
  },
  {
    "country": "MX",
    "name": "Sayula de Alemán",
    "lat": "17.88191",
    "lng": "-94.95986"
  },
  {
    "country": "MX",
    "name": "Santa Isabel Xiloxoxtla",
    "lat": "19.26786",
    "lng": "-98.21399"
  },
  {
    "country": "MX",
    "name": "San Vicente Tancuayalab",
    "lat": "21.71886",
    "lng": "-98.58769"
  },
  {
    "country": "MX",
    "name": "San Vicente Lachixío",
    "lat": "16.70502",
    "lng": "-97.01864"
  },
  {
    "country": "MX",
    "name": "San Vicente Coatlán",
    "lat": "16.38852",
    "lng": "-96.8439"
  },
  {
    "country": "MX",
    "name": "Santo Tomás Jalieza",
    "lat": "16.84469",
    "lng": "-96.67063"
  },
  {
    "country": "MX",
    "name": "Hueyotlipan",
    "lat": "18.89148",
    "lng": "-97.86575"
  },
  {
    "country": "MX",
    "name": "Santo Tomás Chautla",
    "lat": "18.96573",
    "lng": "-98.15288"
  },
  {
    "country": "MX",
    "name": "Santo Tomás Atzingo",
    "lat": "19.1727",
    "lng": "-98.77873"
  },
  {
    "country": "MX",
    "name": "Santos Reyes Tepejillo",
    "lat": "17.43782",
    "lng": "-97.93845"
  },
  {
    "country": "MX",
    "name": "Santo Domingo Zanatepec",
    "lat": "16.48307",
    "lng": "-94.34754"
  },
  {
    "country": "MX",
    "name": "Xagacía",
    "lat": "17.15436",
    "lng": "-96.26753"
  },
  {
    "country": "MX",
    "name": "Santo Domingo Tlatayapam",
    "lat": "17.40778",
    "lng": "-97.34581"
  },
  {
    "country": "MX",
    "name": "Santo Domingo Tepuxtepec",
    "lat": "16.95584",
    "lng": "-96.05823"
  },
  {
    "country": "MX",
    "name": "Santo Domingo Tehuantepec",
    "lat": "16.32463",
    "lng": "-95.24104"
  },
  {
    "country": "MX",
    "name": "Santo Domingo Shomege (Shomege)",
    "lat": "19.84524",
    "lng": "-99.90166"
  },
  {
    "country": "MX",
    "name": "Santo Domingo Huehuetlán",
    "lat": "18.7394",
    "lng": "-98.16438"
  },
  {
    "country": "MX",
    "name": "Santo Domingo Atoyatempan",
    "lat": "18.90444",
    "lng": "-98.37306"
  },
  {
    "country": "MX",
    "name": "Albarradas",
    "lat": "17.06752",
    "lng": "-96.20012"
  },
  {
    "country": "MX",
    "name": "Santo Domingo de Guzmán",
    "lat": "19.59306",
    "lng": "-99.77972"
  },
  {
    "country": "MX",
    "name": "Santo Domingo",
    "lat": "15.03067",
    "lng": "-92.10361"
  },
  {
    "country": "MX",
    "name": "Santiago Zoochila",
    "lat": "17.22059",
    "lng": "-96.24212"
  },
  {
    "country": "MX",
    "name": "Zautla",
    "lat": "19.71475",
    "lng": "-97.67146"
  },
  {
    "country": "MX",
    "name": "Santiago Yaitepec",
    "lat": "16.22628",
    "lng": "-97.26953"
  },
  {
    "country": "MX",
    "name": "Santiago Tuxtla",
    "lat": "18.46576",
    "lng": "-95.3006"
  },
  {
    "country": "MX",
    "name": "Texcaltitlán",
    "lat": "18.93032",
    "lng": "-99.9387"
  },
  {
    "country": "MX",
    "name": "Santiago Texcalcingo",
    "lat": "18.20835",
    "lng": "-96.96887"
  },
  {
    "country": "MX",
    "name": "Tetla",
    "lat": "19.44204",
    "lng": "-98.10325"
  },
  {
    "country": "MX",
    "name": "Santiago Suchilquitongo",
    "lat": "17.25316",
    "lng": "-96.87825"
  },
  {
    "country": "MX",
    "name": "Pinotepa Nacional",
    "lat": "16.34014",
    "lng": "-98.05297"
  },
  {
    "country": "MX",
    "name": "Santiago Nuyoó",
    "lat": "17.01449",
    "lng": "-97.76659"
  },
  {
    "country": "MX",
    "name": "Santiago Nundíche",
    "lat": "17.33136",
    "lng": "-97.67392"
  },
  {
    "country": "MX",
    "name": "Santiago Nejapilla",
    "lat": "17.41983",
    "lng": "-97.37411"
  },
  {
    "country": "MX",
    "name": "Santiago Miltepec",
    "lat": "17.98461",
    "lng": "-97.69006"
  },
  {
    "country": "MX",
    "name": "Miahuatlán",
    "lat": "18.54983",
    "lng": "-97.43953"
  },
  {
    "country": "MX",
    "name": "Santiago Matatlán",
    "lat": "16.8647",
    "lng": "-96.38261"
  },
  {
    "country": "MX",
    "name": "Santiago Laxopa",
    "lat": "17.21842",
    "lng": "-96.31099"
  },
  {
    "country": "MX",
    "name": "Santiago Lalopa",
    "lat": "17.41786",
    "lng": "-96.24893"
  },
  {
    "country": "MX",
    "name": "Santiago Juxtlahuaca",
    "lat": "17.33462",
    "lng": "-98.01147"
  },
  {
    "country": "MX",
    "name": "Jamiltepec",
    "lat": "16.28258",
    "lng": "-97.82446"
  },
  {
    "country": "MX",
    "name": "Santiago Huauclilla",
    "lat": "17.45179",
    "lng": "-97.07277"
  },
  {
    "country": "MX",
    "name": "Santiago Huajolotitlán",
    "lat": "17.82783",
    "lng": "-97.73266"
  },
  {
    "country": "MX",
    "name": "Santiago de la Peña",
    "lat": "20.94512",
    "lng": "-97.40493"
  },
  {
    "country": "MX",
    "name": "Santiago Comaltepec",
    "lat": "17.56547",
    "lng": "-96.54873"
  },
  {
    "country": "MX",
    "name": "Santiago Choápam",
    "lat": "17.36084",
    "lng": "-95.92219"
  },
  {
    "country": "MX",
    "name": "Santiago Chazumba",
    "lat": "18.19012",
    "lng": "-97.67983"
  },
  {
    "country": "MX",
    "name": "Santiago Ayuquililla",
    "lat": "17.9331",
    "lng": "-97.95769"
  },
  {
    "country": "MX",
    "name": "Santiago Atzitzihuacán",
    "lat": "18.82472",
    "lng": "-98.58167"
  },
  {
    "country": "MX",
    "name": "Santiago Astata",
    "lat": "15.98775",
    "lng": "-95.67571"
  },
  {
    "country": "MX",
    "name": "Apoala",
    "lat": "17.64845",
    "lng": "-97.13608"
  },
  {
    "country": "MX",
    "name": "Santiago Alseseca",
    "lat": "18.84511",
    "lng": "-97.70716"
  },
  {
    "country": "MX",
    "name": "Santiago Acutzilapan",
    "lat": "19.7864",
    "lng": "-99.76569"
  },
  {
    "country": "MX",
    "name": "Santiago Acatlán",
    "lat": "18.99334",
    "lng": "-97.93375"
  },
  {
    "country": "MX",
    "name": "Santiago Tulantepec",
    "lat": "20.03618",
    "lng": "-98.35563"
  },
  {
    "country": "MX",
    "name": "Santiago el Pinar",
    "lat": "16.94068",
    "lng": "-92.71455"
  },
  {
    "country": "MX",
    "name": "Santa Rosalía",
    "lat": "18.08851",
    "lng": "-93.35806"
  },
  {
    "country": "MX",
    "name": "Santa Rita Tlahuapan",
    "lat": "19.33211",
    "lng": "-98.57688"
  },
  {
    "country": "MX",
    "name": "Santander Jiménez",
    "lat": "24.21682",
    "lng": "-98.48433"
  },
  {
    "country": "MX",
    "name": "Santa María Zoquitlán",
    "lat": "16.55886",
    "lng": "-96.35325"
  },
  {
    "country": "MX",
    "name": "Santa María Zacatepec",
    "lat": "16.76369",
    "lng": "-97.99028"
  },
  {
    "country": "MX",
    "name": "Santa María Yavesía",
    "lat": "17.23531",
    "lng": "-96.43062"
  },
  {
    "country": "MX",
    "name": "Yalina",
    "lat": "17.23969",
    "lng": "-96.26233"
  },
  {
    "country": "MX",
    "name": "Santa María Xonacatepec",
    "lat": "19.08944",
    "lng": "-98.10361"
  },
  {
    "country": "MX",
    "name": "Santa María Xadani",
    "lat": "15.94825",
    "lng": "-96.07364"
  },
  {
    "country": "MX",
    "name": "Santa María Tonameca",
    "lat": "15.74805",
    "lng": "-96.54704"
  },
  {
    "country": "MX",
    "name": "Tlahuitoltepec",
    "lat": "17.09746",
    "lng": "-96.06279"
  },
  {
    "country": "MX",
    "name": "Santa María Tepantlali",
    "lat": "16.99663",
    "lng": "-96.00883"
  },
  {
    "country": "MX",
    "name": "Santa María Teopoxco",
    "lat": "18.16655",
    "lng": "-96.95488"
  },
  {
    "country": "MX",
    "name": "Santa María Sola",
    "lat": "16.56615",
    "lng": "-97.01297"
  },
  {
    "country": "MX",
    "name": "Santa María Rayón",
    "lat": "19.14808",
    "lng": "-99.57974"
  },
  {
    "country": "MX",
    "name": "Santa María Petapa",
    "lat": "16.8206",
    "lng": "-95.11913"
  },
  {
    "country": "MX",
    "name": "Nopaltepec",
    "lat": "19.77829",
    "lng": "-98.71046"
  },
  {
    "country": "MX",
    "name": "Santa María Nduayaco",
    "lat": "17.40996",
    "lng": "-97.49321"
  },
  {
    "country": "MX",
    "name": "Santa María Nativitas",
    "lat": "19.58113",
    "lng": "-99.60857"
  },
  {
    "country": "MX",
    "name": "Nativitas",
    "lat": "17.6616",
    "lng": "-97.33566"
  },
  {
    "country": "MX",
    "name": "Moyotzingo",
    "lat": "19.24811",
    "lng": "-98.40486"
  },
  {
    "country": "MX",
    "name": "Santa María Mazatla",
    "lat": "19.51528",
    "lng": "-99.38694"
  },
  {
    "country": "MX",
    "name": "Santa María Magdalena Cahuacán",
    "lat": "19.63161",
    "lng": "-99.41123"
  },
  {
    "country": "MX",
    "name": "Santa María la Alta",
    "lat": "18.59982",
    "lng": "-97.65809"
  },
  {
    "country": "MX",
    "name": "Santa María la Asunción",
    "lat": "18.10722",
    "lng": "-96.81917"
  },
  {
    "country": "MX",
    "name": "Santa María Jicaltepec",
    "lat": "16.37917",
    "lng": "-98.04333"
  },
  {
    "country": "MX",
    "name": "Santa María Ixtiyucán",
    "lat": "19.18688",
    "lng": "-97.81094"
  },
  {
    "country": "MX",
    "name": "Santa María Huazolotitlán",
    "lat": "16.30359",
    "lng": "-97.91293"
  },
  {
    "country": "MX",
    "name": "Santa María Huatulco",
    "lat": "15.83267",
    "lng": "-96.32063"
  },
  {
    "country": "MX",
    "name": "Santa María Ecatepec",
    "lat": "16.28498",
    "lng": "-95.87997"
  },
  {
    "country": "MX",
    "name": "Santa María del Tule",
    "lat": "17.04712",
    "lng": "-96.63573"
  },
  {
    "country": "MX",
    "name": "Santa María del Monte",
    "lat": "19.28973",
    "lng": "-99.82355"
  },
  {
    "country": "MX",
    "name": "Santa María Cortijo",
    "lat": "16.45151",
    "lng": "-98.28549"
  },
  {
    "country": "MX",
    "name": "Coronango",
    "lat": "19.1209",
    "lng": "-98.30594"
  },
  {
    "country": "MX",
    "name": "Santa María Colotepec",
    "lat": "15.89737",
    "lng": "-96.93951"
  },
  {
    "country": "MX",
    "name": "Santa María Chimalhuacán",
    "lat": "19.42155",
    "lng": "-98.95038"
  },
  {
    "country": "MX",
    "name": "Santa María Chilapa de Díaz",
    "lat": "17.51667",
    "lng": "-97.68333"
  },
  {
    "country": "MX",
    "name": "Santa María Chachoápam",
    "lat": "17.5257",
    "lng": "-97.28422"
  },
  {
    "country": "MX",
    "name": "Santa María Camotlán",
    "lat": "17.89688",
    "lng": "-97.692"
  },
  {
    "country": "MX",
    "name": "Ayoquezco de Aldama",
    "lat": "16.6837",
    "lng": "-96.84287"
  },
  {
    "country": "MX",
    "name": "Heroica Ciudad de Tlaxiaco",
    "lat": "17.26916",
    "lng": "-97.68053"
  },
  {
    "country": "MX",
    "name": "Santa María Apazco",
    "lat": "17.63433",
    "lng": "-97.10034"
  },
  {
    "country": "MX",
    "name": "Santa María Ajoloapan",
    "lat": "19.97694",
    "lng": "-99.04472"
  },
  {
    "country": "MX",
    "name": "Acuexcomac",
    "lat": "19.03742",
    "lng": "-98.38501"
  },
  {
    "country": "MX",
    "name": "Santa María Acú",
    "lat": "20.54644",
    "lng": "-90.16365"
  },
  {
    "country": "MX",
    "name": "Santa María Huecatitla",
    "lat": "19.72511",
    "lng": "-99.16911"
  },
  {
    "country": "MX",
    "name": "Santa Rita",
    "lat": "16.13167",
    "lng": "-91.975"
  },
  {
    "country": "MX",
    "name": "Santa Isabel Cholula",
    "lat": "18.99667",
    "lng": "-98.37944"
  },
  {
    "country": "MX",
    "name": "Santa Inés del Monte",
    "lat": "16.92387",
    "lng": "-96.86238"
  },
  {
    "country": "MX",
    "name": "Ahuatempan",
    "lat": "18.41269",
    "lng": "-98.0185"
  },
  {
    "country": "MX",
    "name": "El Carrizal",
    "lat": "16.06438",
    "lng": "-95.39308"
  },
  {
    "country": "MX",
    "name": "Santa Gertrudis",
    "lat": "19.73333",
    "lng": "-99.36667"
  },
  {
    "country": "MX",
    "name": "Santa Gertrudis",
    "lat": "16.7858",
    "lng": "-96.80024"
  },
  {
    "country": "MX",
    "name": "Guillermo Zúñiga",
    "lat": "24.01548",
    "lng": "-99.20074"
  },
  {
    "country": "MX",
    "name": "Santa Elena",
    "lat": "20.3289",
    "lng": "-89.64363"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Zenzontepec",
    "lat": "16.53399",
    "lng": "-97.49546"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Xoxocotlán",
    "lat": "17.02958",
    "lng": "-96.73518"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Xitla",
    "lat": "16.32321",
    "lng": "-96.67369"
  },
  {
    "country": "MX",
    "name": "Manzana Tercera de Santa Cruz Tepexpan",
    "lat": "19.56917",
    "lng": "-99.70361"
  },
  {
    "country": "MX",
    "name": "Tecámac",
    "lat": "19.71288",
    "lng": "-98.96895"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Tayata",
    "lat": "17.35718",
    "lng": "-97.56843"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Nundaco",
    "lat": "17.17109",
    "lng": "-97.72382"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Mixtepec",
    "lat": "16.79283",
    "lng": "-96.88072"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Tlaxcala",
    "lat": "19.35468",
    "lng": "-98.15076"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Cuauhtenco",
    "lat": "19.24907",
    "lng": "-99.72939"
  },
  {
    "country": "MX",
    "name": "Santa Clara",
    "lat": "18.97616",
    "lng": "-98.3014"
  },
  {
    "country": "MX",
    "name": "Santa Clara Huitziltepec",
    "lat": "18.7689",
    "lng": "-97.88117"
  },
  {
    "country": "MX",
    "name": "Santa Catarina Tlaltempan",
    "lat": "18.61541",
    "lng": "-98.0808"
  },
  {
    "country": "MX",
    "name": "Santa Catarina Tayata",
    "lat": "17.34715",
    "lng": "-97.55822"
  },
  {
    "country": "MX",
    "name": "Santa Catarina Quiané",
    "lat": "16.88255",
    "lng": "-96.74067"
  },
  {
    "country": "MX",
    "name": "Pantelhó",
    "lat": "17.00563",
    "lng": "-92.47165"
  },
  {
    "country": "MX",
    "name": "Santa Catarina Otzolotepec",
    "lat": "18.57705",
    "lng": "-97.26603"
  },
  {
    "country": "MX",
    "name": "Santa Catarina Minas",
    "lat": "16.77969",
    "lng": "-96.61536"
  },
  {
    "country": "MX",
    "name": "Santa Catarina Mechoacán",
    "lat": "16.33591",
    "lng": "-97.83707"
  },
  {
    "country": "MX",
    "name": "Santa Catarina Loxicha",
    "lat": "16.06864",
    "lng": "-96.75391"
  },
  {
    "country": "MX",
    "name": "Santa Catarina Juquila",
    "lat": "16.23819",
    "lng": "-97.29161"
  },
  {
    "country": "MX",
    "name": "Santa Catarina Cuixtla",
    "lat": "16.30616",
    "lng": "-96.64236"
  },
  {
    "country": "MX",
    "name": "Santa Catarina Ayotzingo",
    "lat": "19.20948",
    "lng": "-98.92985"
  },
  {
    "country": "MX",
    "name": "Santa Catarina",
    "lat": "21.65624",
    "lng": "-99.49548"
  },
  {
    "country": "MX",
    "name": "Santa Catarina",
    "lat": "18.96972",
    "lng": "-99.14028"
  },
  {
    "country": "MX",
    "name": "Santa Apolonia Teacalco",
    "lat": "19.24153",
    "lng": "-98.31188"
  },
  {
    "country": "MX",
    "name": "Santa Ana Tlapacoyan",
    "lat": "16.7434",
    "lng": "-96.83688"
  },
  {
    "country": "MX",
    "name": "Santa Ana Nextlalpan",
    "lat": "19.74171",
    "lng": "-99.07496"
  },
  {
    "country": "MX",
    "name": "Santa Ana Jilotzingo",
    "lat": "19.54116",
    "lng": "-99.39477"
  },
  {
    "country": "MX",
    "name": "Santa Anita Huiloac",
    "lat": "19.38841",
    "lng": "-98.14362"
  },
  {
    "country": "MX",
    "name": "Santa Ana Hueytlalpan",
    "lat": "20.17484",
    "lng": "-98.31209"
  },
  {
    "country": "MX",
    "name": "Santa Ana del Valle",
    "lat": "16.99488",
    "lng": "-96.47112"
  },
  {
    "country": "MX",
    "name": "Santa Ana Coatepec",
    "lat": "18.83667",
    "lng": "-98.43472"
  },
  {
    "country": "MX",
    "name": "Santa Ana Chiautempan",
    "lat": "19.30633",
    "lng": "-98.21773"
  },
  {
    "country": "MX",
    "name": "Santa Ana Acozautla",
    "lat": "18.95556",
    "lng": "-98.38306"
  },
  {
    "country": "MX",
    "name": "Santa Ana Ixtlahuatzingo (Santa Ana)",
    "lat": "18.97056",
    "lng": "-99.62361"
  },
  {
    "country": "MX",
    "name": "Santa Ana",
    "lat": "17.05455",
    "lng": "-95.08509"
  },
  {
    "country": "MX",
    "name": "Santa Ana",
    "lat": "16.34139",
    "lng": "-96.71697"
  },
  {
    "country": "MX",
    "name": "San Simonito",
    "lat": "18.99139",
    "lng": "-99.54"
  },
  {
    "country": "MX",
    "name": "San Simón Almolongas",
    "lat": "16.40659",
    "lng": "-96.71927"
  },
  {
    "country": "MX",
    "name": "Zinacatepec",
    "lat": "18.33516",
    "lng": "-97.24621"
  },
  {
    "country": "MX",
    "name": "San Sebastián Villanueva",
    "lat": "19.06085",
    "lng": "-97.71935"
  },
  {
    "country": "MX",
    "name": "Santa María Tutla",
    "lat": "17.70493",
    "lng": "-97.64016"
  },
  {
    "country": "MX",
    "name": "San Sebastian Teitipac",
    "lat": "16.95192",
    "lng": "-96.61427"
  },
  {
    "country": "MX",
    "name": "San Sebastián Coatlán",
    "lat": "16.20212",
    "lng": "-96.82645"
  },
  {
    "country": "MX",
    "name": "San Sebastián Abasolo",
    "lat": "16.99432",
    "lng": "-96.58701"
  },
  {
    "country": "MX",
    "name": "Huixcolotla",
    "lat": "18.92073",
    "lng": "-97.77166"
  },
  {
    "country": "MX",
    "name": "San Salvador el Verde",
    "lat": "19.27002",
    "lng": "-98.51648"
  },
  {
    "country": "MX",
    "name": "San Salvador El Seco",
    "lat": "19.13325",
    "lng": "-97.64167"
  },
  {
    "country": "MX",
    "name": "San Salvador Atenco",
    "lat": "19.5517",
    "lng": "-98.91867"
  },
  {
    "country": "MX",
    "name": "San Salvador",
    "lat": "20.28583",
    "lng": "-99.01457"
  },
  {
    "country": "MX",
    "name": "San Raymundo Jalpam",
    "lat": "16.97164",
    "lng": "-96.75699"
  },
  {
    "country": "MX",
    "name": "San Rafael",
    "lat": "20.18862",
    "lng": "-96.86737"
  },
  {
    "country": "MX",
    "name": "San Pedro y San Pablo Tequistepec",
    "lat": "18.06106",
    "lng": "-97.71816"
  },
  {
    "country": "MX",
    "name": "Villa de Etla",
    "lat": "17.20615",
    "lng": "-96.7989"
  },
  {
    "country": "MX",
    "name": "Ayutla",
    "lat": "17.02756",
    "lng": "-96.07632"
  },
  {
    "country": "MX",
    "name": "San Pedro Yólox",
    "lat": "17.58907",
    "lng": "-96.55235"
  },
  {
    "country": "MX",
    "name": "San Pedro Topiltepec",
    "lat": "17.43633",
    "lng": "-97.34403"
  },
  {
    "country": "MX",
    "name": "San Pedro Tlanixco",
    "lat": "19.06259",
    "lng": "-99.65237"
  },
  {
    "country": "MX",
    "name": "San Pedro Tidaá",
    "lat": "17.34122",
    "lng": "-97.37239"
  },
  {
    "country": "MX",
    "name": "San Pedro Tetitlán",
    "lat": "18.25972",
    "lng": "-97.32306"
  },
  {
    "country": "MX",
    "name": "San Pedro Taviche",
    "lat": "16.63858",
    "lng": "-96.53687"
  },
  {
    "country": "MX",
    "name": "San Pedro Tapanatepec",
    "lat": "16.37107",
    "lng": "-94.19313"
  },
  {
    "country": "MX",
    "name": "San Pedro Quiatoni",
    "lat": "16.78295",
    "lng": "-96.03085"
  },
  {
    "country": "MX",
    "name": "San Pedro Pochutla",
    "lat": "15.74587",
    "lng": "-96.46601"
  },
  {
    "country": "MX",
    "name": "San Pedro Mixtepec",
    "lat": "16.2706",
    "lng": "-96.28406"
  },
  {
    "country": "MX",
    "name": "San Pedro Mixtepec",
    "lat": "15.98211",
    "lng": "-97.07984"
  },
  {
    "country": "MX",
    "name": "San Pedro Mártir Quiechapa",
    "lat": "16.41516",
    "lng": "-96.24451"
  },
  {
    "country": "MX",
    "name": "San Pedro Los Baños",
    "lat": "19.62537",
    "lng": "-99.8217"
  },
  {
    "country": "MX",
    "name": "San Pedro Jicayán",
    "lat": "16.45179",
    "lng": "-98.01425"
  },
  {
    "country": "MX",
    "name": "Jaltepetongo",
    "lat": "17.68623",
    "lng": "-97.03569"
  },
  {
    "country": "MX",
    "name": "San Pedro Ixcatlán",
    "lat": "18.14575",
    "lng": "-96.50953"
  },
  {
    "country": "MX",
    "name": "San Pedro Huamelula",
    "lat": "16.02697",
    "lng": "-95.66735"
  },
  {
    "country": "MX",
    "name": "San Pedro el Alto",
    "lat": "19.91056",
    "lng": "-99.96361"
  },
  {
    "country": "MX",
    "name": "San Pedro el Alto",
    "lat": "19.58429",
    "lng": "-99.8805"
  },
  {
    "country": "MX",
    "name": "Cajonos",
    "lat": "17.16801",
    "lng": "-96.26174"
  },
  {
    "country": "MX",
    "name": "San Pedro Buenavista",
    "lat": "16.08333",
    "lng": "-93.11667"
  },
  {
    "country": "MX",
    "name": "San Pedro Atoyac",
    "lat": "16.49005",
    "lng": "-97.98585"
  },
  {
    "country": "MX",
    "name": "Ciudad de Atlixco",
    "lat": "18.90372",
    "lng": "-98.43922"
  },
  {
    "country": "MX",
    "name": "San Pedro Apóstol",
    "lat": "16.73695",
    "lng": "-96.72474"
  },
  {
    "country": "MX",
    "name": "Yaganiza",
    "lat": "17.14495",
    "lng": "-96.2296"
  },
  {
    "country": "MX",
    "name": "San Pablo Villa de Mitla",
    "lat": "16.92283",
    "lng": "-96.3599"
  },
  {
    "country": "MX",
    "name": "San Pablo Tolimán",
    "lat": "20.85703",
    "lng": "-99.89985"
  },
  {
    "country": "MX",
    "name": "San Pablo Tecalco",
    "lat": "19.67309",
    "lng": "-98.95837"
  },
  {
    "country": "MX",
    "name": "San Pablo Macuiltianguis",
    "lat": "17.53348",
    "lng": "-96.55212"
  },
  {
    "country": "MX",
    "name": "San Pablo Huixtepec",
    "lat": "16.81948",
    "lng": "-96.78128"
  },
  {
    "country": "MX",
    "name": "San Pablo Huitzo",
    "lat": "17.27708",
    "lng": "-96.88661"
  },
  {
    "country": "MX",
    "name": "San Pablo Etla",
    "lat": "17.14397",
    "lng": "-96.74812"
  },
  {
    "country": "MX",
    "name": "San Pablo de las Tunas",
    "lat": "18.99556",
    "lng": "-97.70972"
  },
  {
    "country": "MX",
    "name": "San Pablo de las Salinas",
    "lat": "19.66658",
    "lng": "-99.09477"
  },
  {
    "country": "MX",
    "name": "San Pablo Coatlán",
    "lat": "16.22429",
    "lng": "-96.78379"
  },
  {
    "country": "MX",
    "name": "Chalchihuitán",
    "lat": "16.96445",
    "lng": "-92.61903"
  },
  {
    "country": "MX",
    "name": "San Pablo Autopan",
    "lat": "19.35638",
    "lng": "-99.65724"
  },
  {
    "country": "MX",
    "name": "San Pablo Atlazalpan",
    "lat": "19.21742",
    "lng": "-98.90763"
  },
  {
    "country": "MX",
    "name": "Apetatitlán Antonio Carbajal",
    "lat": "19.33622",
    "lng": "-98.17912"
  },
  {
    "country": "MX",
    "name": "San Nicolás de los Ranchos",
    "lat": "19.07139",
    "lng": "-98.48601"
  },
  {
    "country": "MX",
    "name": "San Nicolas Buenos Aires",
    "lat": "19.16488",
    "lng": "-97.55131"
  },
  {
    "country": "MX",
    "name": "San Nicolás Coatepec",
    "lat": "19.13735",
    "lng": "-99.42948"
  },
  {
    "country": "MX",
    "name": "San Nicolás",
    "lat": "24.69377",
    "lng": "-98.83"
  },
  {
    "country": "MX",
    "name": "San Nicolás",
    "lat": "20.47689",
    "lng": "-99.93749"
  },
  {
    "country": "MX",
    "name": "San Miguel Zozutla",
    "lat": "18.7543",
    "lng": "-97.65478"
  },
  {
    "country": "MX",
    "name": "Zinacantepec",
    "lat": "19.28428",
    "lng": "-99.73394"
  },
  {
    "country": "MX",
    "name": "San Miguel Xoxtla",
    "lat": "19.16763",
    "lng": "-98.30758"
  },
  {
    "country": "MX",
    "name": "Tonalixco",
    "lat": "19.98111",
    "lng": "-97.83944"
  },
  {
    "country": "MX",
    "name": "San Miguel Contla",
    "lat": "19.36111",
    "lng": "-98.1325"
  },
  {
    "country": "MX",
    "name": "San Miguel Tlacamama",
    "lat": "16.41547",
    "lng": "-98.06301"
  },
  {
    "country": "MX",
    "name": "San Miguel Tilquiapam",
    "lat": "16.78218",
    "lng": "-96.58165"
  },
  {
    "country": "MX",
    "name": "San Miguel Tenextatiloyan",
    "lat": "19.70973",
    "lng": "-97.59769"
  },
  {
    "country": "MX",
    "name": "San Miguel Tenango",
    "lat": "16.26659",
    "lng": "-95.59532"
  },
  {
    "country": "MX",
    "name": "Villa Talea de Castro",
    "lat": "17.35983",
    "lng": "-96.24953"
  },
  {
    "country": "MX",
    "name": "San Miguel Quetzaltepec",
    "lat": "16.9738",
    "lng": "-95.76045"
  },
  {
    "country": "MX",
    "name": "San Miguel Panixtlahuaca",
    "lat": "16.24844",
    "lng": "-97.38427"
  },
  {
    "country": "MX",
    "name": "San Miguel Oxtotilpan",
    "lat": "19.15083",
    "lng": "-99.88605"
  },
  {
    "country": "MX",
    "name": "San Miguel Ixitlán",
    "lat": "18.00082",
    "lng": "-97.77483"
  },
  {
    "country": "MX",
    "name": "Huautepec",
    "lat": "18.10138",
    "lng": "-96.7959"
  },
  {
    "country": "MX",
    "name": "San Miguel Ejutla",
    "lat": "16.58053",
    "lng": "-96.73897"
  },
  {
    "country": "MX",
    "name": "San Miguel del Puerto",
    "lat": "15.92169",
    "lng": "-96.17499"
  },
  {
    "country": "MX",
    "name": "San Miguel Coatlinchán",
    "lat": "19.44999",
    "lng": "-98.87274"
  },
  {
    "country": "MX",
    "name": "San Miguel Coatlán",
    "lat": "16.19701",
    "lng": "-96.69458"
  },
  {
    "country": "MX",
    "name": "Chapultepec",
    "lat": "19.20216",
    "lng": "-99.56176"
  },
  {
    "country": "MX",
    "name": "San Miguel Canoa",
    "lat": "19.15194",
    "lng": "-98.10306"
  },
  {
    "country": "MX",
    "name": "San Miguel Balderas",
    "lat": "19.10943",
    "lng": "-99.65165"
  },
  {
    "country": "MX",
    "name": "San Miguel Aloápam",
    "lat": "17.41136",
    "lng": "-96.69154"
  },
  {
    "country": "MX",
    "name": "San Miguel Achiutla",
    "lat": "17.309",
    "lng": "-97.48392"
  },
  {
    "country": "MX",
    "name": "San Miguel Tenochtitlán",
    "lat": "19.76028",
    "lng": "-99.9225"
  },
  {
    "country": "MX",
    "name": "San Matias Tlalancaleca",
    "lat": "19.32536",
    "lng": "-98.49863"
  },
  {
    "country": "MX",
    "name": "San Mateo Xoloc",
    "lat": "19.7065",
    "lng": "-99.24818"
  },
  {
    "country": "MX",
    "name": "Tlaixpan",
    "lat": "18.91217",
    "lng": "-97.73818"
  },
  {
    "country": "MX",
    "name": "San Mateo Texcalyacac",
    "lat": "19.16667",
    "lng": "-99.46667"
  },
  {
    "country": "MX",
    "name": "San Mateo Piñas",
    "lat": "16.00049",
    "lng": "-96.33449"
  },
  {
    "country": "MX",
    "name": "San Mateo Parra",
    "lat": "18.99139",
    "lng": "-97.86167"
  },
  {
    "country": "MX",
    "name": "San Mateo Nejápam",
    "lat": "17.65604",
    "lng": "-98.41662"
  },
  {
    "country": "MX",
    "name": "Mexicaltzingo",
    "lat": "19.2113",
    "lng": "-99.58469"
  },
  {
    "country": "MX",
    "name": "San Mateo Ixtacalco",
    "lat": "19.6992",
    "lng": "-99.17159"
  },
  {
    "country": "MX",
    "name": "San Mateo Yoloxochitlán",
    "lat": "18.14341",
    "lng": "-96.86865"
  },
  {
    "country": "MX",
    "name": "San Mateo del Mar",
    "lat": "16.21054",
    "lng": "-94.98218"
  },
  {
    "country": "MX",
    "name": "San Mateo Cajonos",
    "lat": "17.16147",
    "lng": "-96.20777"
  },
  {
    "country": "MX",
    "name": "San Mateo Atenco",
    "lat": "19.26757",
    "lng": "-99.53214"
  },
  {
    "country": "MX",
    "name": "Xaltocan",
    "lat": "19.42427",
    "lng": "-98.21033"
  },
  {
    "country": "MX",
    "name": "Toxpalan",
    "lat": "18.10125",
    "lng": "-97.05869"
  },
  {
    "country": "MX",
    "name": "Totoltepec",
    "lat": "18.65255",
    "lng": "-98.34706"
  },
  {
    "country": "MX",
    "name": "San Martín Tlapala",
    "lat": "18.96667",
    "lng": "-98.45889"
  },
  {
    "country": "MX",
    "name": "San Martin Texmelucan de Labastida",
    "lat": "19.28431",
    "lng": "-98.43885"
  },
  {
    "country": "MX",
    "name": "San Pedro la Joya",
    "lat": "19.06528",
    "lng": "-97.83806"
  },
  {
    "country": "MX",
    "name": "San Martín de los Canseco",
    "lat": "16.65655",
    "lng": "-96.72777"
  },
  {
    "country": "MX",
    "name": "San Martín de las Pirámides",
    "lat": "19.70582",
    "lng": "-98.83554"
  },
  {
    "country": "MX",
    "name": "San Martín Chalchicuautla",
    "lat": "21.37033",
    "lng": "-98.65697"
  },
  {
    "country": "MX",
    "name": "San Marcos Tlacoyalco",
    "lat": "18.67388",
    "lng": "-97.60354"
  },
  {
    "country": "MX",
    "name": "Vega de San Marcos",
    "lat": "20.18539",
    "lng": "-96.94877"
  },
  {
    "country": "MX",
    "name": "San Marcos",
    "lat": "20.06667",
    "lng": "-99.33333"
  },
  {
    "country": "MX",
    "name": "San Marcos",
    "lat": "16.79772",
    "lng": "-99.38921"
  },
  {
    "country": "MX",
    "name": "Teolocholco",
    "lat": "19.24333",
    "lng": "-98.19083"
  },
  {
    "country": "MX",
    "name": "San Luis Amatlán",
    "lat": "16.38652",
    "lng": "-96.49824"
  },
  {
    "country": "MX",
    "name": "San Luis Acatlán",
    "lat": "16.80901",
    "lng": "-98.73331"
  },
  {
    "country": "MX",
    "name": "San Lucas Tecopilco",
    "lat": "19.48626",
    "lng": "-98.25605"
  },
  {
    "country": "MX",
    "name": "San Lucas Quiavini",
    "lat": "16.89555",
    "lng": "-96.46813"
  },
  {
    "country": "MX",
    "name": "San Lucas Ojitlán",
    "lat": "18.05767",
    "lng": "-96.39825"
  },
  {
    "country": "MX",
    "name": "San Lorenzo Toxico",
    "lat": "19.50917",
    "lng": "-99.76278"
  },
  {
    "country": "MX",
    "name": "Texmelucan",
    "lat": "16.5851",
    "lng": "-97.19907"
  },
  {
    "country": "MX",
    "name": "San Lorenzo Oyamel",
    "lat": "19.43355",
    "lng": "-99.57761"
  },
  {
    "country": "MX",
    "name": "San Lorenzo Chiautzingo",
    "lat": "19.20432",
    "lng": "-98.46747"
  },
  {
    "country": "MX",
    "name": "Almecatla",
    "lat": "19.14286",
    "lng": "-98.23597"
  },
  {
    "country": "MX",
    "name": "San Lorenzo Cuaunecuiltitla",
    "lat": "18.20664",
    "lng": "-96.91315"
  },
  {
    "country": "MX",
    "name": "San Lorenzo",
    "lat": "16.39483",
    "lng": "-97.87403"
  },
  {
    "country": "MX",
    "name": "San Juan Yatzona",
    "lat": "17.40184",
    "lng": "-96.16878"
  },
  {
    "country": "MX",
    "name": "San Juan Yaee",
    "lat": "17.43",
    "lng": "-96.28355"
  },
  {
    "country": "MX",
    "name": "San Juan Xiutetelco",
    "lat": "19.79563",
    "lng": "-97.32578"
  },
  {
    "country": "MX",
    "name": "San Juan Tizahuapán",
    "lat": "20.05073",
    "lng": "-98.6654"
  },
  {
    "country": "MX",
    "name": "Tianguismanalco",
    "lat": "18.97624",
    "lng": "-98.44861"
  },
  {
    "country": "MX",
    "name": "San Juan Tepa",
    "lat": "20.21579",
    "lng": "-99.06592"
  },
  {
    "country": "MX",
    "name": "Teotihuacán",
    "lat": "19.68862",
    "lng": "-98.8611"
  },
  {
    "country": "MX",
    "name": "San Juan Tejaluca",
    "lat": "18.89917",
    "lng": "-98.40472"
  },
  {
    "country": "MX",
    "name": "San Juan Quiotepec",
    "lat": "17.60156",
    "lng": "-96.58731"
  },
  {
    "country": "MX",
    "name": "San Juan Ozolotepec",
    "lat": "16.1332",
    "lng": "-96.25925"
  },
  {
    "country": "MX",
    "name": "San Juan Mixtepec",
    "lat": "17.30539",
    "lng": "-97.83158"
  },
  {
    "country": "MX",
    "name": "San Juan Mixtepec",
    "lat": "16.27709",
    "lng": "-96.30057"
  },
  {
    "country": "MX",
    "name": "San Juan de los Cues",
    "lat": "18.04654",
    "lng": "-97.0602"
  },
  {
    "country": "MX",
    "name": "San Juán Lachigalla",
    "lat": "16.58947",
    "lng": "-96.55052"
  },
  {
    "country": "MX",
    "name": "San Juan Juquila Vijanos",
    "lat": "17.35372",
    "lng": "-96.30385"
  },
  {
    "country": "MX",
    "name": "Ixtenco",
    "lat": "19.25146",
    "lng": "-97.89412"
  },
  {
    "country": "MX",
    "name": "San Juan Ixcaquixtla",
    "lat": "18.46067",
    "lng": "-97.83103"
  },
  {
    "country": "MX",
    "name": "San Juan Ihualtepec",
    "lat": "17.74023",
    "lng": "-98.2889"
  },
  {
    "country": "MX",
    "name": "San Juan Guichicovi",
    "lat": "16.96231",
    "lng": "-95.09418"
  },
  {
    "country": "MX",
    "name": "San Juan Guelavía",
    "lat": "16.95507",
    "lng": "-96.54359"
  },
  {
    "country": "MX",
    "name": "San Juan Evangelista",
    "lat": "17.88615",
    "lng": "-95.13961"
  },
  {
    "country": "MX",
    "name": "San Juan Epatlán",
    "lat": "18.64272",
    "lng": "-98.3725"
  },
  {
    "country": "MX",
    "name": "San Juan Diuxi",
    "lat": "17.28597",
    "lng": "-97.37005"
  },
  {
    "country": "MX",
    "name": "San Juan del Río",
    "lat": "20.38886",
    "lng": "-99.99577"
  },
  {
    "country": "MX",
    "name": "San Juan de los Reyes (Luis Valenzuela)",
    "lat": "18.51778",
    "lng": "-95.44889"
  },
  {
    "country": "MX",
    "name": "San Juan del Estado",
    "lat": "17.2743",
    "lng": "-96.79912"
  },
  {
    "country": "MX",
    "name": "San Juan de las Huertas",
    "lat": "19.24755",
    "lng": "-99.75834"
  },
  {
    "country": "MX",
    "name": "San Juan Cuautla",
    "lat": "18.24416",
    "lng": "-96.95673"
  },
  {
    "country": "MX",
    "name": "San Juan Chilateca",
    "lat": "16.83042",
    "lng": "-96.66915"
  },
  {
    "country": "MX",
    "name": "San Juan Cacahuatepec",
    "lat": "16.61532",
    "lng": "-98.15501"
  },
  {
    "country": "MX",
    "name": "Valle Nacional",
    "lat": "17.77579",
    "lng": "-96.30174"
  },
  {
    "country": "MX",
    "name": "Tuxtepec",
    "lat": "18.0883",
    "lng": "-96.12535"
  },
  {
    "country": "MX",
    "name": "Tlacoatzintepec",
    "lat": "17.85985",
    "lng": "-96.58647"
  },
  {
    "country": "MX",
    "name": "Tlachichilco",
    "lat": "17.6222",
    "lng": "-98.34312"
  },
  {
    "country": "MX",
    "name": "Cuicatlan",
    "lat": "17.80272",
    "lng": "-96.95939"
  },
  {
    "country": "MX",
    "name": "Coixtlahuaca",
    "lat": "17.72021",
    "lng": "-97.3188"
  },
  {
    "country": "MX",
    "name": "Animas Trujano",
    "lat": "16.99086",
    "lng": "-96.71319"
  },
  {
    "country": "MX",
    "name": "San Juan Atzompa",
    "lat": "18.74497",
    "lng": "-98.02451"
  },
  {
    "country": "MX",
    "name": "San Juan Amecac",
    "lat": "18.83469",
    "lng": "-98.65909"
  },
  {
    "country": "MX",
    "name": "San Juan Achiutla",
    "lat": "17.35019",
    "lng": "-97.50804"
  },
  {
    "country": "MX",
    "name": "San José Tenango",
    "lat": "18.15084",
    "lng": "-96.71744"
  },
  {
    "country": "MX",
    "name": "Miahuatlán",
    "lat": "18.29163",
    "lng": "-97.28789"
  },
  {
    "country": "MX",
    "name": "San José Lachiguirí",
    "lat": "16.37784",
    "lng": "-96.33589"
  },
  {
    "country": "MX",
    "name": "San José Estancia Grande",
    "lat": "16.36545",
    "lng": "-98.25092"
  },
  {
    "country": "MX",
    "name": "San José Chiltepec",
    "lat": "17.94734",
    "lng": "-96.16957"
  },
  {
    "country": "MX",
    "name": "San José Chiapa",
    "lat": "19.24105",
    "lng": "-97.76642"
  },
  {
    "country": "MX",
    "name": "San José Ayuquila",
    "lat": "17.94221",
    "lng": "-97.96861"
  },
  {
    "country": "MX",
    "name": "San José Acateno",
    "lat": "20.13067",
    "lng": "-97.20997"
  },
  {
    "country": "MX",
    "name": "San Joaquín",
    "lat": "20.91562",
    "lng": "-99.5652"
  },
  {
    "country": "MX",
    "name": "San Jerónimo Xayacatlán",
    "lat": "18.22034",
    "lng": "-97.91288"
  },
  {
    "country": "MX",
    "name": "San Jerónimo Tecóatl",
    "lat": "18.16633",
    "lng": "-96.91256"
  },
  {
    "country": "MX",
    "name": "San Jerónimo Taviche",
    "lat": "16.71468",
    "lng": "-96.5936"
  },
  {
    "country": "MX",
    "name": "San Jerónimo Sosola",
    "lat": "17.36685",
    "lng": "-97.03291"
  },
  {
    "country": "MX",
    "name": "San Jerónimo Silacayoapilla",
    "lat": "17.81021",
    "lng": "-97.84488"
  },
  {
    "country": "MX",
    "name": "San Jerónimo Ocotitla",
    "lat": "19.03127",
    "lng": "-97.96359"
  },
  {
    "country": "MX",
    "name": "San Jerónimo Coatlán",
    "lat": "16.23211",
    "lng": "-96.87047"
  },
  {
    "country": "MX",
    "name": "San Jerónimo Axochitlán",
    "lat": "18.27833",
    "lng": "-97.26278"
  },
  {
    "country": "MX",
    "name": "San Isidro Apango",
    "lat": "15.80952",
    "lng": "-96.35856"
  },
  {
    "country": "MX",
    "name": "San Isidro",
    "lat": "18.89111",
    "lng": "-97.12583"
  },
  {
    "country": "MX",
    "name": "San Ildefonso Villa Alta",
    "lat": "17.33827",
    "lng": "-96.15232"
  },
  {
    "country": "MX",
    "name": "San Ildefonso Amatlán",
    "lat": "16.3339",
    "lng": "-96.49122"
  },
  {
    "country": "MX",
    "name": "San Ildefonso",
    "lat": "19.56111",
    "lng": "-99.78583"
  },
  {
    "country": "MX",
    "name": "San Hipólito",
    "lat": "18.94069",
    "lng": "-97.87322"
  },
  {
    "country": "MX",
    "name": "San Gregorio Atzompa",
    "lat": "19.02349",
    "lng": "-98.34822"
  },
  {
    "country": "MX",
    "name": "San Gaspar Tonatico",
    "lat": "18.80671",
    "lng": "-99.66917"
  },
  {
    "country": "MX",
    "name": "San Gabriel Mixtepec",
    "lat": "16.09593",
    "lng": "-97.08237"
  },
  {
    "country": "MX",
    "name": "San Gabriel Chilac",
    "lat": "18.32596",
    "lng": "-97.34697"
  },
  {
    "country": "MX",
    "name": "Casa Blanca",
    "lat": "18.14976",
    "lng": "-97.13729"
  },
  {
    "country": "MX",
    "name": "San Gabriel las Palmas",
    "lat": "18.61417",
    "lng": "-99.34694"
  },
  {
    "country": "MX",
    "name": "San Francisco Zacacalco",
    "lat": "19.92875",
    "lng": "-98.98279"
  },
  {
    "country": "MX",
    "name": "San Francisco Tlalcilalcalpan",
    "lat": "19.29474",
    "lng": "-99.76771"
  },
  {
    "country": "MX",
    "name": "San Francisco Tetlanohcan",
    "lat": "19.2602",
    "lng": "-98.1637"
  },
  {
    "country": "MX",
    "name": "San Francisco Tepexoxica",
    "lat": "19.06043",
    "lng": "-99.54783"
  },
  {
    "country": "MX",
    "name": "San Francisco Telixtlahuaca",
    "lat": "17.29684",
    "lng": "-96.90529"
  },
  {
    "country": "MX",
    "name": "San Francisco Sola",
    "lat": "16.51584",
    "lng": "-96.97488"
  },
  {
    "country": "MX",
    "name": "San Francisco Ozolotepec",
    "lat": "16.10079",
    "lng": "-96.22181"
  },
  {
    "country": "MX",
    "name": "Mixtla",
    "lat": "18.90502",
    "lng": "-97.89554"
  },
  {
    "country": "MX",
    "name": "San Francisco Lachigoló",
    "lat": "17.01624",
    "lng": "-96.59947"
  },
  {
    "country": "MX",
    "name": "San Francisco Huehuetlán",
    "lat": "18.19725",
    "lng": "-96.94805"
  },
  {
    "country": "MX",
    "name": "San Francisco del Mar Viejo",
    "lat": "16.23185",
    "lng": "-94.63297"
  },
  {
    "country": "MX",
    "name": "San Francisco Chindúa",
    "lat": "17.42809",
    "lng": "-97.31266"
  },
  {
    "country": "MX",
    "name": "San Francisco Cajonos",
    "lat": "17.17091",
    "lng": "-96.25024"
  },
  {
    "country": "MX",
    "name": "Atexcatzingo",
    "lat": "19.46882",
    "lng": "-98.14716"
  },
  {
    "country": "MX",
    "name": "San Francisco Acuautla",
    "lat": "19.34564",
    "lng": "-98.86034"
  },
  {
    "country": "MX",
    "name": "San Francisco",
    "lat": "20.55254",
    "lng": "-98.00209"
  },
  {
    "country": "MX",
    "name": "Occidente (San Francisco)",
    "lat": "18.3313",
    "lng": "-93.25238"
  },
  {
    "country": "MX",
    "name": "San Francisco Ozomatlán",
    "lat": "17.92537",
    "lng": "-99.33902"
  },
  {
    "country": "MX",
    "name": "San Fernando",
    "lat": "16.87153",
    "lng": "-93.20759"
  },
  {
    "country": "MX",
    "name": "San Felipe Usila",
    "lat": "17.8879",
    "lng": "-96.52474"
  },
  {
    "country": "MX",
    "name": "Teotlaltzingo",
    "lat": "19.23088",
    "lng": "-98.50077"
  },
  {
    "country": "MX",
    "name": "San Felipe Jalapa de Díaz",
    "lat": "18.0712",
    "lng": "-96.53562"
  },
  {
    "country": "MX",
    "name": "Villa Mariano Matamoros",
    "lat": "19.32659",
    "lng": "-98.37827"
  },
  {
    "country": "MX",
    "name": "San Felipe del Progreso",
    "lat": "19.7144",
    "lng": "-99.95197"
  },
  {
    "country": "MX",
    "name": "Cuautempan",
    "lat": "19.9138",
    "lng": "-97.79498"
  },
  {
    "country": "MX",
    "name": "San Esteban Atatlahuca",
    "lat": "17.06716",
    "lng": "-97.67836"
  },
  {
    "country": "MX",
    "name": "San Esteban",
    "lat": "20.54452",
    "lng": "-98.06004"
  },
  {
    "country": "MX",
    "name": "Yauhquemehcan",
    "lat": "19.40697",
    "lng": "-98.1823"
  },
  {
    "country": "MX",
    "name": "San Dionisio Ocotepec",
    "lat": "16.80457",
    "lng": "-96.39334"
  },
  {
    "country": "MX",
    "name": "San Dionisio del Mar",
    "lat": "16.32371",
    "lng": "-94.7583"
  },
  {
    "country": "MX",
    "name": "Xochimanca",
    "lat": "19.49052",
    "lng": "-98.82433"
  },
  {
    "country": "MX",
    "name": "San Diego Huehuecalco",
    "lat": "19.09276",
    "lng": "-98.76336"
  },
  {
    "country": "MX",
    "name": "Sanctórum",
    "lat": "19.49333",
    "lng": "-98.47156"
  },
  {
    "country": "MX",
    "name": "Sanctorum",
    "lat": "19.09917",
    "lng": "-98.25417"
  },
  {
    "country": "MX",
    "name": "San Cristóbal Lachirioag",
    "lat": "17.33582",
    "lng": "-96.16503"
  },
  {
    "country": "MX",
    "name": "San Cristóbal de las Casas",
    "lat": "16.73176",
    "lng": "-92.64126"
  },
  {
    "country": "MX",
    "name": "San Cristóbal Amoltepec",
    "lat": "17.28428",
    "lng": "-97.57216"
  },
  {
    "country": "MX",
    "name": "San Cristóbal Amatlán",
    "lat": "16.31713",
    "lng": "-96.40785"
  },
  {
    "country": "MX",
    "name": "San Ciro de Acosta",
    "lat": "21.65072",
    "lng": "-99.81916"
  },
  {
    "country": "MX",
    "name": "San Carlos Yautepec",
    "lat": "16.49699",
    "lng": "-96.10648"
  },
  {
    "country": "MX",
    "name": "San Carlos",
    "lat": "24.58223",
    "lng": "-98.94208"
  },
  {
    "country": "MX",
    "name": "San Carlos",
    "lat": "17.55221",
    "lng": "-91.15408"
  },
  {
    "country": "MX",
    "name": "San Buenaventura",
    "lat": "19.26595",
    "lng": "-99.67332"
  },
  {
    "country": "MX",
    "name": "San Bernardo Mixtepec",
    "lat": "16.82579",
    "lng": "-96.89911"
  },
  {
    "country": "MX",
    "name": "Amaxac de Guerrero",
    "lat": "19.34661",
    "lng": "-98.17057"
  },
  {
    "country": "MX",
    "name": "San Bartolo Yautepec",
    "lat": "16.42935",
    "lng": "-95.97438"
  },
  {
    "country": "MX",
    "name": "San Bartolo Tutotepec",
    "lat": "20.39841",
    "lng": "-98.2008"
  },
  {
    "country": "MX",
    "name": "Teontepec",
    "lat": "18.49217",
    "lng": "-97.52962"
  },
  {
    "country": "MX",
    "name": "Soyaltepec",
    "lat": "17.59174",
    "lng": "-97.30819"
  },
  {
    "country": "MX",
    "name": "San Bartolomé Loxícha",
    "lat": "15.96981",
    "lng": "-96.70957"
  },
  {
    "country": "MX",
    "name": "San Bartolomé Ayautla",
    "lat": "18.03239",
    "lng": "-96.67078"
  },
  {
    "country": "MX",
    "name": "San Bartolo del Llano",
    "lat": "19.59069",
    "lng": "-99.74099"
  },
  {
    "country": "MX",
    "name": "San Bartolo Cuautlalpan",
    "lat": "19.8151",
    "lng": "-99.01044"
  },
  {
    "country": "MX",
    "name": "San Baltazar Loxicha",
    "lat": "16.0767",
    "lng": "-96.7874"
  },
  {
    "country": "MX",
    "name": "San Baltazar Chichicapam",
    "lat": "16.76151",
    "lng": "-96.4897"
  },
  {
    "country": "MX",
    "name": "Xochitlaxco (San Baltazar)",
    "lat": "19.94139",
    "lng": "-97.86361"
  },
  {
    "country": "MX",
    "name": "San Baltazar Atlimeyaya",
    "lat": "18.98694",
    "lng": "-98.48111"
  },
  {
    "country": "MX",
    "name": "Nanahuatípam",
    "lat": "18.13414",
    "lng": "-97.12501"
  },
  {
    "country": "MX",
    "name": "Cuaxomulco",
    "lat": "19.35264",
    "lng": "-98.0967"
  },
  {
    "country": "MX",
    "name": "San Antonio",
    "lat": "21.62059",
    "lng": "-98.90322"
  },
  {
    "country": "MX",
    "name": "San Antonio la Isla",
    "lat": "19.16441",
    "lng": "-99.56685"
  },
  {
    "country": "MX",
    "name": "San Andrés Yaá",
    "lat": "17.2929",
    "lng": "-96.15384"
  },
  {
    "country": "MX",
    "name": "San Andrés Tuxtla",
    "lat": "18.4487",
    "lng": "-95.21327"
  },
  {
    "country": "MX",
    "name": "San Andrés Timilpan",
    "lat": "19.8761",
    "lng": "-99.73375"
  },
  {
    "country": "MX",
    "name": "Tepetlapa",
    "lat": "17.66601",
    "lng": "-98.39188"
  },
  {
    "country": "MX",
    "name": "San Andrés Tepetitlán",
    "lat": "18.89833",
    "lng": "-99.91972"
  },
  {
    "country": "MX",
    "name": "San Andrés Tenejapan",
    "lat": "18.78921",
    "lng": "-97.09399"
  },
  {
    "country": "MX",
    "name": "San Andrés Solaga",
    "lat": "17.27254",
    "lng": "-96.2361"
  },
  {
    "country": "MX",
    "name": "San Andrés Sinaxtla",
    "lat": "17.46928",
    "lng": "-97.28298"
  },
  {
    "country": "MX",
    "name": "San Andrés Huayápam",
    "lat": "17.10264",
    "lng": "-96.66556"
  },
  {
    "country": "MX",
    "name": "San Andrés Huaxpaltepec",
    "lat": "16.32952",
    "lng": "-97.91647"
  },
  {
    "country": "MX",
    "name": "San Andrés Calpan",
    "lat": "19.10356",
    "lng": "-98.46188"
  },
  {
    "country": "MX",
    "name": "San Andrés Cacaloapan",
    "lat": "18.58364",
    "lng": "-97.58711"
  },
  {
    "country": "MX",
    "name": "San Agustín Tlaxiaca",
    "lat": "20.1151",
    "lng": "-98.8864"
  },
  {
    "country": "MX",
    "name": "San Agustín Oapan",
    "lat": "17.9525",
    "lng": "-99.43806"
  },
  {
    "country": "MX",
    "name": "San Agustín Loxicha",
    "lat": "16.01687",
    "lng": "-96.61615"
  },
  {
    "country": "MX",
    "name": "San Agustín Huixaxtla",
    "lat": "18.91778",
    "lng": "-98.39694"
  },
  {
    "country": "MX",
    "name": "San Agustín Amatengo",
    "lat": "16.51086",
    "lng": "-96.78919"
  },
  {
    "country": "MX",
    "name": "Salto de Agua",
    "lat": "17.55435",
    "lng": "-92.33941"
  },
  {
    "country": "MX",
    "name": "Saltillo",
    "lat": "19.29644",
    "lng": "-97.29661"
  },
  {
    "country": "MX",
    "name": "Saltabarranca",
    "lat": "18.59119",
    "lng": "-95.53226"
  },
  {
    "country": "MX",
    "name": "Salitrillo",
    "lat": "19.43333",
    "lng": "-99.85"
  },
  {
    "country": "MX",
    "name": "Salina Cruz",
    "lat": "16.17535",
    "lng": "-95.19424"
  },
  {
    "country": "MX",
    "name": "Sahcaba",
    "lat": "20.79174",
    "lng": "-89.18138"
  },
  {
    "country": "MX",
    "name": "Sacalum",
    "lat": "20.49749",
    "lng": "-89.59035"
  },
  {
    "country": "MX",
    "name": "Sabanilla",
    "lat": "17.28384",
    "lng": "-92.55315"
  },
  {
    "country": "MX",
    "name": "Sabancuy",
    "lat": "18.9727",
    "lng": "-91.17783"
  },
  {
    "country": "MX",
    "name": "Saban",
    "lat": "20.0345",
    "lng": "-88.53891"
  },
  {
    "country": "MX",
    "name": "Juan Rodríguez Clara",
    "lat": "17.99283",
    "lng": "-95.40099"
  },
  {
    "country": "MX",
    "name": "Rioverde",
    "lat": "21.93115",
    "lng": "-99.99488"
  },
  {
    "country": "MX",
    "name": "Río Lagartos",
    "lat": "21.5967",
    "lng": "-88.15773"
  },
  {
    "country": "MX",
    "name": "Río Frío de Juárez",
    "lat": "19.35336",
    "lng": "-98.67057"
  },
  {
    "country": "MX",
    "name": "Ciudad Río Bravo",
    "lat": "25.98729",
    "lng": "-98.09414"
  },
  {
    "country": "MX",
    "name": "Río Blanco",
    "lat": "18.83036",
    "lng": "-97.156"
  },
  {
    "country": "MX",
    "name": "Colonia Rincón Viejo",
    "lat": "16.88678",
    "lng": "-95.04731"
  },
  {
    "country": "MX",
    "name": "Rinconada",
    "lat": "19.35438",
    "lng": "-96.56581"
  },
  {
    "country": "MX",
    "name": "Reynosa",
    "lat": "26.08061",
    "lng": "-98.28835"
  },
  {
    "country": "MX",
    "name": "Reforma",
    "lat": "17.86519",
    "lng": "-93.14897"
  },
  {
    "country": "MX",
    "name": "Rayón",
    "lat": "21.84329",
    "lng": "-99.64258"
  },
  {
    "country": "MX",
    "name": "Rayón",
    "lat": "17.20137",
    "lng": "-93.0111"
  },
  {
    "country": "MX",
    "name": "Rafael Lucio",
    "lat": "19.59308",
    "lng": "-96.99023"
  },
  {
    "country": "MX",
    "name": "Grajales",
    "lat": "19.22796",
    "lng": "-97.80307"
  },
  {
    "country": "MX",
    "name": "Rafael J. García",
    "lat": "19.25413",
    "lng": "-97.18315"
  },
  {
    "country": "MX",
    "name": "Rafael Delgado",
    "lat": "18.81014",
    "lng": "-97.07172"
  },
  {
    "country": "MX",
    "name": "Rodulfo Figueroa",
    "lat": "15.92006",
    "lng": "-91.9037"
  },
  {
    "country": "MX",
    "name": "Quintana Roo",
    "lat": "20.86946",
    "lng": "-88.63153"
  },
  {
    "country": "MX",
    "name": "Santa Catalina Quieri",
    "lat": "16.32141",
    "lng": "-96.26618"
  },
  {
    "country": "MX",
    "name": "Santa María Quiegolani",
    "lat": "16.27705",
    "lng": "-96.05269"
  },
  {
    "country": "MX",
    "name": "Quechultenango",
    "lat": "17.41425",
    "lng": "-99.24221"
  },
  {
    "country": "MX",
    "name": "Quecholac",
    "lat": "18.95471",
    "lng": "-97.65858"
  },
  {
    "country": "MX",
    "name": "Quebrantadero",
    "lat": "18.52429",
    "lng": "-98.79023"
  },
  {
    "country": "MX",
    "name": "Putla Villa de Guerrero",
    "lat": "17.0263",
    "lng": "-97.92854"
  },
  {
    "country": "MX",
    "name": "Puerto Madero",
    "lat": "14.72076",
    "lng": "-92.42146"
  },
  {
    "country": "MX",
    "name": "Puerto Escondido",
    "lat": "15.87037",
    "lng": "-97.07726"
  },
  {
    "country": "MX",
    "name": "Puente de Ixtla",
    "lat": "18.61472",
    "lng": "-99.31806"
  },
  {
    "country": "MX",
    "name": "Pueblo Nuevo",
    "lat": "17.16027",
    "lng": "-92.89977"
  },
  {
    "country": "MX",
    "name": "Pueblo Nuevo",
    "lat": "19.67419",
    "lng": "-99.6175"
  },
  {
    "country": "MX",
    "name": "Puebla",
    "lat": "19.03793",
    "lng": "-98.20346"
  },
  {
    "country": "MX",
    "name": "Progreso de Zaragoza",
    "lat": "20.2749",
    "lng": "-97.71163"
  },
  {
    "country": "MX",
    "name": "Progreso de Alvaro Obregon",
    "lat": "20.24929",
    "lng": "-99.18988"
  },
  {
    "country": "MX",
    "name": "Progreso",
    "lat": "21.28306",
    "lng": "-89.66123"
  },
  {
    "country": "MX",
    "name": "Progreso Industrial",
    "lat": "19.63635",
    "lng": "-99.35687"
  },
  {
    "country": "MX",
    "name": "Presidio",
    "lat": "19.06933",
    "lng": "-96.97209"
  },
  {
    "country": "MX",
    "name": "Poza Rica de Hidalgo",
    "lat": "20.53315",
    "lng": "-97.45946"
  },
  {
    "country": "MX",
    "name": "Potrero del Llano",
    "lat": "21.0797",
    "lng": "-97.72814"
  },
  {
    "country": "MX",
    "name": "Portezuelo",
    "lat": "20.48687",
    "lng": "-99.3061"
  },
  {
    "country": "MX",
    "name": "Pomuch",
    "lat": "20.13727",
    "lng": "-90.17488"
  },
  {
    "country": "MX",
    "name": "Polyuc",
    "lat": "19.60889",
    "lng": "-88.56148"
  },
  {
    "country": "MX",
    "name": "Polotitlán de la Ilustración",
    "lat": "20.2253",
    "lng": "-99.81537"
  },
  {
    "country": "MX",
    "name": "Polanco",
    "lat": "19.43332",
    "lng": "-99.19919"
  },
  {
    "country": "MX",
    "name": "Pluma Hidalgo",
    "lat": "15.92711",
    "lng": "-96.41852"
  },
  {
    "country": "MX",
    "name": "Playa Vicente",
    "lat": "17.83107",
    "lng": "-95.81189"
  },
  {
    "country": "MX",
    "name": "Playa del Carmen",
    "lat": "20.6274",
    "lng": "-87.07987"
  },
  {
    "country": "MX",
    "name": "Platón Sánchez",
    "lat": "21.27182",
    "lng": "-98.37456"
  },
  {
    "country": "MX",
    "name": "Plan de las Hayas",
    "lat": "19.75963",
    "lng": "-96.67594"
  },
  {
    "country": "MX",
    "name": "Piste",
    "lat": "20.69972",
    "lng": "-88.58889"
  },
  {
    "country": "MX",
    "name": "Pinotepa de Don Luis",
    "lat": "16.42716",
    "lng": "-97.97678"
  },
  {
    "country": "MX",
    "name": "Pinal de Amoles",
    "lat": "21.13448",
    "lng": "-99.6259"
  },
  {
    "country": "MX",
    "name": "Pijijiapan",
    "lat": "15.68618",
    "lng": "-93.20938"
  },
  {
    "country": "MX",
    "name": "Piedras Negras",
    "lat": "18.77026",
    "lng": "-96.17178"
  },
  {
    "country": "MX",
    "name": "Zamora Pico de Oro",
    "lat": "16.33205",
    "lng": "-90.7656"
  },
  {
    "country": "MX",
    "name": "Pichucalco",
    "lat": "17.51",
    "lng": "-93.11591"
  },
  {
    "country": "MX",
    "name": "Peto",
    "lat": "20.12776",
    "lng": "-88.92282"
  },
  {
    "country": "MX",
    "name": "Petlalcingo",
    "lat": "18.08463",
    "lng": "-97.9175"
  },
  {
    "country": "MX",
    "name": "Petaquillas",
    "lat": "17.48636",
    "lng": "-99.45633"
  },
  {
    "country": "MX",
    "name": "Petalcingo",
    "lat": "17.22715",
    "lng": "-92.41511"
  },
  {
    "country": "MX",
    "name": "Perote",
    "lat": "19.56233",
    "lng": "-97.24235"
  },
  {
    "country": "MX",
    "name": "Peñamiller",
    "lat": "21.05408",
    "lng": "-99.81573"
  },
  {
    "country": "MX",
    "name": "Colonias Pedernales",
    "lat": "20.04583",
    "lng": "-97.05139"
  },
  {
    "country": "MX",
    "name": "Paxtepec",
    "lat": "20.05278",
    "lng": "-98.43139"
  },
  {
    "country": "MX",
    "name": "Paso de Ovejas",
    "lat": "19.2845",
    "lng": "-96.44037"
  },
  {
    "country": "MX",
    "name": "Paso del Toro",
    "lat": "19.035",
    "lng": "-96.13555"
  },
  {
    "country": "MX",
    "name": "Paso del Macho",
    "lat": "18.97098",
    "lng": "-96.72419"
  },
  {
    "country": "MX",
    "name": "Parás",
    "lat": "26.50013",
    "lng": "-99.52156"
  },
  {
    "country": "MX",
    "name": "Paraiso",
    "lat": "18.40116",
    "lng": "-93.21406"
  },
  {
    "country": "MX",
    "name": "Papantla de Olarte",
    "lat": "20.44655",
    "lng": "-97.32494"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Papalutla",
    "lat": "16.95627",
    "lng": "-96.5831"
  },
  {
    "country": "MX",
    "name": "Papalotla",
    "lat": "19.56341",
    "lng": "-98.85681"
  },
  {
    "country": "MX",
    "name": "Pánuco",
    "lat": "22.05373",
    "lng": "-98.18498"
  },
  {
    "country": "MX",
    "name": "Pantepec",
    "lat": "17.18842",
    "lng": "-93.04998"
  },
  {
    "country": "MX",
    "name": "Panotla",
    "lat": "19.31619",
    "lng": "-98.27013"
  },
  {
    "country": "MX",
    "name": "Panales",
    "lat": "20.46965",
    "lng": "-99.26674"
  },
  {
    "country": "MX",
    "name": "Panabá",
    "lat": "21.29598",
    "lng": "-88.26982"
  },
  {
    "country": "MX",
    "name": "Palomares",
    "lat": "17.1383",
    "lng": "-95.06266"
  },
  {
    "country": "MX",
    "name": "Palmillas",
    "lat": "23.30225",
    "lng": "-99.54896"
  },
  {
    "country": "MX",
    "name": "Palmarito Tochapan",
    "lat": "18.90135",
    "lng": "-97.63833"
  },
  {
    "country": "MX",
    "name": "Palmar de Bravo",
    "lat": "18.83573",
    "lng": "-97.54704"
  },
  {
    "country": "MX",
    "name": "Palizada",
    "lat": "18.25503",
    "lng": "-92.0911"
  },
  {
    "country": "MX",
    "name": "Palenque",
    "lat": "17.50953",
    "lng": "-91.98248"
  },
  {
    "country": "MX",
    "name": "Pajapan",
    "lat": "18.26267",
    "lng": "-94.69172"
  },
  {
    "country": "MX",
    "name": "Pahuatlán de Valle",
    "lat": "20.278",
    "lng": "-98.14997"
  },
  {
    "country": "MX",
    "name": "Pachuquilla",
    "lat": "20.07099",
    "lng": "-98.69572"
  },
  {
    "country": "MX",
    "name": "Pachuca de Soto",
    "lat": "20.11697",
    "lng": "-98.73329"
  },
  {
    "country": "MX",
    "name": "San Martín Pachivia (Pachivia)",
    "lat": "18.40855",
    "lng": "-99.78759"
  },
  {
    "country": "MX",
    "name": "Ozumba de Alzate",
    "lat": "19.03689",
    "lng": "-98.79516"
  },
  {
    "country": "MX",
    "name": "Ozuluama de Mascareñas",
    "lat": "21.6604",
    "lng": "-97.85049"
  },
  {
    "country": "MX",
    "name": "Santo Domingo Ozolotepec",
    "lat": "16.15017",
    "lng": "-96.31046"
  },
  {
    "country": "MX",
    "name": "Oxkutzkab",
    "lat": "20.30734",
    "lng": "-89.41809"
  },
  {
    "country": "MX",
    "name": "Oxchuc",
    "lat": "16.78588",
    "lng": "-92.34455"
  },
  {
    "country": "MX",
    "name": "Oviedo",
    "lat": "22.04478",
    "lng": "-98.40043"
  },
  {
    "country": "MX",
    "name": "Otumba",
    "lat": "19.69985",
    "lng": "-98.75638"
  },
  {
    "country": "MX",
    "name": "Oteapan",
    "lat": "18.00173",
    "lng": "-94.66615"
  },
  {
    "country": "MX",
    "name": "Otatitlán",
    "lat": "18.17706",
    "lng": "-96.0335"
  },
  {
    "country": "MX",
    "name": "Ostuacán",
    "lat": "17.40664",
    "lng": "-93.33643"
  },
  {
    "country": "MX",
    "name": "San Felipe Orizatlán",
    "lat": "21.17109",
    "lng": "-98.60744"
  },
  {
    "country": "MX",
    "name": "Orizaba",
    "lat": "18.85195",
    "lng": "-97.09957"
  },
  {
    "country": "MX",
    "name": "Oriental",
    "lat": "19.37614",
    "lng": "-97.62051"
  },
  {
    "country": "MX",
    "name": "Opichen",
    "lat": "20.55169",
    "lng": "-89.85714"
  },
  {
    "country": "MX",
    "name": "Omitlán de Juárez",
    "lat": "20.1698",
    "lng": "-98.64842"
  },
  {
    "country": "MX",
    "name": "Ometepec",
    "lat": "16.69008",
    "lng": "-98.40797"
  },
  {
    "country": "MX",
    "name": "Omealca",
    "lat": "18.74732",
    "lng": "-96.7852"
  },
  {
    "country": "MX",
    "name": "Oluta",
    "lat": "17.92972",
    "lng": "-94.89662"
  },
  {
    "country": "MX",
    "name": "Olinalá",
    "lat": "17.77861",
    "lng": "-98.73944"
  },
  {
    "country": "MX",
    "name": "Olcuatitán",
    "lat": "18.19045",
    "lng": "-92.96114"
  },
  {
    "country": "MX",
    "name": "Ocuituco",
    "lat": "18.87731",
    "lng": "-98.77323"
  },
  {
    "country": "MX",
    "name": "Ocuilan de Arteaga",
    "lat": "18.97784",
    "lng": "-99.41986"
  },
  {
    "country": "MX",
    "name": "Ocozocoautla de Espinosa",
    "lat": "16.76231",
    "lng": "-93.37476"
  },
  {
    "country": "MX",
    "name": "Ocoyoacac",
    "lat": "19.27127",
    "lng": "-99.45787"
  },
  {
    "country": "MX",
    "name": "Ocotlán de Morelos",
    "lat": "16.79151",
    "lng": "-96.67455"
  },
  {
    "country": "MX",
    "name": "San Francisco Ocotlán",
    "lat": "19.13411",
    "lng": "-98.28345"
  },
  {
    "country": "MX",
    "name": "Ocotlamanic",
    "lat": "18.32389",
    "lng": "-97.09667"
  },
  {
    "country": "MX",
    "name": "Santa María Magdalena Ocotitlán",
    "lat": "19.23713",
    "lng": "-99.62418"
  },
  {
    "country": "MX",
    "name": "Ocotepec",
    "lat": "17.2262",
    "lng": "-93.1644"
  },
  {
    "country": "MX",
    "name": "Ocosingo",
    "lat": "16.90639",
    "lng": "-92.09374"
  },
  {
    "country": "MX",
    "name": "Ocampo",
    "lat": "22.84695",
    "lng": "-99.33866"
  },
  {
    "country": "MX",
    "name": "Oaxtepec",
    "lat": "18.91825",
    "lng": "-98.95644"
  },
  {
    "country": "MX",
    "name": "Oaxaca",
    "lat": "17.06542",
    "lng": "-96.72365"
  },
  {
    "country": "MX",
    "name": "Nunkiní",
    "lat": "20.40046",
    "lng": "-90.14803"
  },
  {
    "country": "MX",
    "name": "Osumacinta",
    "lat": "16.93611",
    "lng": "-93.09028"
  },
  {
    "country": "MX",
    "name": "Nuevo Progreso",
    "lat": "23.17605",
    "lng": "-97.95"
  },
  {
    "country": "MX",
    "name": "Nueva Villa de Padilla",
    "lat": "24.04784",
    "lng": "-98.90085"
  },
  {
    "country": "MX",
    "name": "Nuevo Morelos",
    "lat": "22.53604",
    "lng": "-99.21934"
  },
  {
    "country": "MX",
    "name": "Nuevo Laredo",
    "lat": "27.47629",
    "lng": "-99.51639"
  },
  {
    "country": "MX",
    "name": "Nueva Palestina",
    "lat": "15.8061",
    "lng": "-92.75067"
  },
  {
    "country": "MX",
    "name": "Nueva Ciudad Guerrero",
    "lat": "26.56219",
    "lng": "-99.22863"
  },
  {
    "country": "MX",
    "name": "Nopalucán",
    "lat": "19.2184",
    "lng": "-97.82272"
  },
  {
    "country": "MX",
    "name": "Nogales",
    "lat": "18.82776",
    "lng": "-97.16311"
  },
  {
    "country": "MX",
    "name": "Niltepec",
    "lat": "16.56401",
    "lng": "-94.61373"
  },
  {
    "country": "MX",
    "name": "Nicolás Ruiz",
    "lat": "16.43714",
    "lng": "-92.58522"
  },
  {
    "country": "MX",
    "name": "Nicolás Romero",
    "lat": "19.64177",
    "lng": "-99.3068"
  },
  {
    "country": "MX",
    "name": "Nicolás Bravo",
    "lat": "18.4591",
    "lng": "-88.92802"
  },
  {
    "country": "MX",
    "name": "Nepantla de Sor Juana Inés de la Cruz",
    "lat": "18.98028",
    "lng": "-98.84083"
  },
  {
    "country": "MX",
    "name": "Necaxa",
    "lat": "20.21271",
    "lng": "-98.01188"
  },
  {
    "country": "MX",
    "name": "Nealtican",
    "lat": "19.0499",
    "lng": "-98.4272"
  },
  {
    "country": "MX",
    "name": "Nautla",
    "lat": "20.20795",
    "lng": "-96.77305"
  },
  {
    "country": "MX",
    "name": "Naupan",
    "lat": "20.23131",
    "lng": "-98.10881"
  },
  {
    "country": "MX",
    "name": "Naucalpan de Juárez",
    "lat": "19.47851",
    "lng": "-99.23963"
  },
  {
    "country": "MX",
    "name": "Natívitas",
    "lat": "19.23333",
    "lng": "-98.31472"
  },
  {
    "country": "MX",
    "name": "Naranjos",
    "lat": "21.35087",
    "lng": "-97.68656"
  },
  {
    "country": "MX",
    "name": "Naranjal",
    "lat": "18.81074",
    "lng": "-96.96282"
  },
  {
    "country": "MX",
    "name": "Naolinco de Victoria",
    "lat": "19.65474",
    "lng": "-96.8732"
  },
  {
    "country": "MX",
    "name": "Nanchital de Lázaro Cárdenas del Río",
    "lat": "18.07117",
    "lng": "-94.40756"
  },
  {
    "country": "MX",
    "name": "Ciudad de Nanacamilpa",
    "lat": "19.49339",
    "lng": "-98.53665"
  },
  {
    "country": "MX",
    "name": "Nacajuca",
    "lat": "18.16971",
    "lng": "-93.01843"
  },
  {
    "country": "MX",
    "name": "Muna",
    "lat": "20.48794",
    "lng": "-89.71387"
  },
  {
    "country": "MX",
    "name": "Motzorongo",
    "lat": "18.64252",
    "lng": "-96.72949"
  },
  {
    "country": "MX",
    "name": "Motul",
    "lat": "21.09571",
    "lng": "-89.28332"
  },
  {
    "country": "MX",
    "name": "Motozintla",
    "lat": "15.36694",
    "lng": "-92.24605"
  },
  {
    "country": "MX",
    "name": "Morelos Cañada",
    "lat": "18.73549",
    "lng": "-97.42068"
  },
  {
    "country": "MX",
    "name": "Moralillo",
    "lat": "22.22552",
    "lng": "-97.91213"
  },
  {
    "country": "MX",
    "name": "Monte Redondo",
    "lat": "15.65217",
    "lng": "-92.05045"
  },
  {
    "country": "MX",
    "name": "Montemorelos",
    "lat": "25.18909",
    "lng": "-99.82865"
  },
  {
    "country": "MX",
    "name": "Montecristo",
    "lat": "15.69263",
    "lng": "-92.61999"
  },
  {
    "country": "MX",
    "name": "Montecillo",
    "lat": "19.45711",
    "lng": "-98.90835"
  },
  {
    "country": "MX",
    "name": "La Laguna y Monte del Castillo",
    "lat": "18.98334",
    "lng": "-96.07806"
  },
  {
    "country": "MX",
    "name": "Monte Blanco",
    "lat": "18.96642",
    "lng": "-97.01684"
  },
  {
    "country": "MX",
    "name": "Santiago Momoxpan",
    "lat": "19.07361",
    "lng": "-98.26694"
  },
  {
    "country": "MX",
    "name": "Moloacán",
    "lat": "17.98544",
    "lng": "-94.34714"
  },
  {
    "country": "MX",
    "name": "Molango",
    "lat": "20.78693",
    "lng": "-98.72878"
  },
  {
    "country": "MX",
    "name": "Mohoneras",
    "lat": "17.235",
    "lng": "-99.51611"
  },
  {
    "country": "MX",
    "name": "Mococha",
    "lat": "21.10621",
    "lng": "-89.45217"
  },
  {
    "country": "MX",
    "name": "Mochitlán",
    "lat": "17.47192",
    "lng": "-99.37048"
  },
  {
    "country": "MX",
    "name": "Mixtla de Altamirano",
    "lat": "18.59591",
    "lng": "-96.99293"
  },
  {
    "country": "MX",
    "name": "Santa María Mixtequilla",
    "lat": "16.37496",
    "lng": "-95.26034"
  },
  {
    "country": "MX",
    "name": "Mixquiahuala de Juarez",
    "lat": "20.23031",
    "lng": "-99.21396"
  },
  {
    "country": "MX",
    "name": "Misantla",
    "lat": "19.92992",
    "lng": "-96.85194"
  },
  {
    "country": "MX",
    "name": "Miramar",
    "lat": "22.32085",
    "lng": "-97.8595"
  },
  {
    "country": "MX",
    "name": "Miquihuana",
    "lat": "23.57575",
    "lng": "-99.75438"
  },
  {
    "country": "MX",
    "name": "Mineral del Monte",
    "lat": "20.1383",
    "lng": "-98.67364"
  },
  {
    "country": "MX",
    "name": "Minatitlán",
    "lat": "18.00011",
    "lng": "-94.5569"
  },
  {
    "country": "MX",
    "name": "Milpa Alta",
    "lat": "19.19251",
    "lng": "-99.02317"
  },
  {
    "country": "MX",
    "name": "Mier",
    "lat": "26.42969",
    "lng": "-99.15212"
  },
  {
    "country": "MX",
    "name": "Miahuatlán de Porfirio Díaz",
    "lat": "16.33276",
    "lng": "-96.59562"
  },
  {
    "country": "MX",
    "name": "Miahuatlán",
    "lat": "19.70794",
    "lng": "-96.87082"
  },
  {
    "country": "MX",
    "name": "Miacatlán",
    "lat": "18.76203",
    "lng": "-99.35944"
  },
  {
    "country": "MX",
    "name": "Mezcala",
    "lat": "17.9324",
    "lng": "-99.60257"
  },
  {
    "country": "MX",
    "name": "Mezquititlán",
    "lat": "20.53307",
    "lng": "-98.63749"
  },
  {
    "country": "MX",
    "name": "Metlatónoc",
    "lat": "17.19482",
    "lng": "-98.40706"
  },
  {
    "country": "MX",
    "name": "Metlaltoyuca",
    "lat": "20.73556",
    "lng": "-97.85194"
  },
  {
    "country": "MX",
    "name": "Metepec",
    "lat": "20.23762",
    "lng": "-98.32122"
  },
  {
    "country": "MX",
    "name": "Metepec",
    "lat": "19.25934",
    "lng": "-99.60175"
  },
  {
    "country": "MX",
    "name": "Metapa",
    "lat": "14.83624",
    "lng": "-92.19186"
  },
  {
    "country": "MX",
    "name": "Mérida",
    "lat": "20.97537",
    "lng": "-89.61696"
  },
  {
    "country": "MX",
    "name": "Méndez",
    "lat": "25.11819",
    "lng": "-98.58666"
  },
  {
    "country": "MX",
    "name": "Melchor Ocampo",
    "lat": "26.05502",
    "lng": "-99.54381"
  },
  {
    "country": "MX",
    "name": "Medellín de Bravo",
    "lat": "19.05869",
    "lng": "-96.15781"
  },
  {
    "country": "MX",
    "name": "Mecayapan",
    "lat": "18.22001",
    "lng": "-94.83794"
  },
  {
    "country": "MX",
    "name": "Mecatlán",
    "lat": "20.21053",
    "lng": "-97.68204"
  },
  {
    "country": "MX",
    "name": "Mazatlán Villa de Flores",
    "lat": "18.03264",
    "lng": "-96.91404"
  },
  {
    "country": "MX",
    "name": "Mazatlán",
    "lat": "17.4362",
    "lng": "-99.46483"
  },
  {
    "country": "MX",
    "name": "Mazatepec",
    "lat": "18.72795",
    "lng": "-99.36339"
  },
  {
    "country": "MX",
    "name": "Mazatecochco",
    "lat": "19.17865",
    "lng": "-98.18677"
  },
  {
    "country": "MX",
    "name": "Mazatán",
    "lat": "14.86319",
    "lng": "-92.4503"
  },
  {
    "country": "MX",
    "name": "Mazapa",
    "lat": "15.38773",
    "lng": "-92.1878"
  },
  {
    "country": "MX",
    "name": "Mayanalán",
    "lat": "18.1729",
    "lng": "-99.43259"
  },
  {
    "country": "MX",
    "name": "Maxcanú",
    "lat": "20.58456",
    "lng": "-90.001"
  },
  {
    "country": "MX",
    "name": "Matías Romero",
    "lat": "16.87902",
    "lng": "-95.03939"
  },
  {
    "country": "MX",
    "name": "Mata Tenatito (Casco Hacienda)",
    "lat": "18.72187",
    "lng": "-96.66288"
  },
  {
    "country": "MX",
    "name": "Heroica Matamoros",
    "lat": "25.87972",
    "lng": "-97.50417"
  },
  {
    "country": "MX",
    "name": "Martínez de la Torre",
    "lat": "20.07082",
    "lng": "-97.06078"
  },
  {
    "country": "MX",
    "name": "Maitinez",
    "lat": "22.37167",
    "lng": "-99.29306"
  },
  {
    "country": "MX",
    "name": "Mariano Escobedo",
    "lat": "18.91333",
    "lng": "-97.13"
  },
  {
    "country": "MX",
    "name": "Maravilla Tenejapa",
    "lat": "16.14155",
    "lng": "-91.29595"
  },
  {
    "country": "MX",
    "name": "Mapastepec",
    "lat": "15.43358",
    "lng": "-92.90039"
  },
  {
    "country": "MX",
    "name": "Manuel Lazos",
    "lat": "14.97159",
    "lng": "-92.18726"
  },
  {
    "country": "MX",
    "name": "Colonia Manuel González",
    "lat": "19.11495",
    "lng": "-96.85939"
  },
  {
    "country": "MX",
    "name": "Ursulo Galván",
    "lat": "22.72779",
    "lng": "-98.32191"
  },
  {
    "country": "MX",
    "name": "Manlio Fabio Altamirano",
    "lat": "19.09425",
    "lng": "-96.33351"
  },
  {
    "country": "MX",
    "name": "Mani",
    "lat": "20.38774",
    "lng": "-89.39189"
  },
  {
    "country": "MX",
    "name": "Mama",
    "lat": "20.47857",
    "lng": "-89.36498"
  },
  {
    "country": "MX",
    "name": "Maltrata",
    "lat": "18.81091",
    "lng": "-97.27538"
  },
  {
    "country": "MX",
    "name": "Malinaltepec",
    "lat": "17.24501",
    "lng": "-98.67091"
  },
  {
    "country": "MX",
    "name": "Malinalco",
    "lat": "18.94847",
    "lng": "-99.49619"
  },
  {
    "country": "MX",
    "name": "Santa María Malacatepec",
    "lat": "18.94147",
    "lng": "-98.30218"
  },
  {
    "country": "MX",
    "name": "Magdalena Tequisistlán",
    "lat": "16.39929",
    "lng": "-95.60204"
  },
  {
    "country": "MX",
    "name": "Magdalena Teitipac",
    "lat": "16.90393",
    "lng": "-96.5584"
  },
  {
    "country": "MX",
    "name": "Magdalena Mixtepec",
    "lat": "16.89659",
    "lng": "-96.90618"
  },
  {
    "country": "MX",
    "name": "Magdalena Jaltepec",
    "lat": "17.32318",
    "lng": "-97.22122"
  },
  {
    "country": "MX",
    "name": "Magdalena Cuayucatepec",
    "lat": "18.54972",
    "lng": "-97.48472"
  },
  {
    "country": "MX",
    "name": "Magdalena Contreras",
    "lat": "19.33212",
    "lng": "-99.21118"
  },
  {
    "country": "MX",
    "name": "Macuspana",
    "lat": "17.76052",
    "lng": "-92.59539"
  },
  {
    "country": "MX",
    "name": "Macultepec",
    "lat": "18.15026",
    "lng": "-92.86092"
  },
  {
    "country": "MX",
    "name": "Luis Gil Pérez",
    "lat": "17.87541",
    "lng": "-93.07124"
  },
  {
    "country": "MX",
    "name": "Reyes Acozac",
    "lat": "19.7755",
    "lng": "-98.98079"
  },
  {
    "country": "MX",
    "name": "Los Reyes",
    "lat": "20.15529",
    "lng": "-98.16424"
  },
  {
    "country": "MX",
    "name": "Los Reyes Acaquilpan",
    "lat": "19.36357",
    "lng": "-98.97707"
  },
  {
    "country": "MX",
    "name": "Los Reyes de Juárez",
    "lat": "18.94918",
    "lng": "-97.80379"
  },
  {
    "country": "MX",
    "name": "Los Reyes",
    "lat": "18.67062",
    "lng": "-97.0429"
  },
  {
    "country": "MX",
    "name": "Los Ramones",
    "lat": "25.69716",
    "lng": "-99.62529"
  },
  {
    "country": "MX",
    "name": "Los Herreras",
    "lat": "25.90797",
    "lng": "-99.40479"
  },
  {
    "country": "MX",
    "name": "Los Altos",
    "lat": "21.50976",
    "lng": "-97.75705"
  },
  {
    "country": "MX",
    "name": "Almagres",
    "lat": "17.8075",
    "lng": "-94.9175"
  },
  {
    "country": "MX",
    "name": "Los Aldamas",
    "lat": "26.06217",
    "lng": "-99.19556"
  },
  {
    "country": "MX",
    "name": "Loma Grande",
    "lat": "18.9225",
    "lng": "-97.23083"
  },
  {
    "country": "MX",
    "name": "Loma de Sogotegoyo",
    "lat": "18.21896",
    "lng": "-94.97373"
  },
  {
    "country": "MX",
    "name": "Loché",
    "lat": "21.38828",
    "lng": "-88.14566"
  },
  {
    "country": "MX",
    "name": "Llera de Canales",
    "lat": "23.31774",
    "lng": "-99.02608"
  },
  {
    "country": "MX",
    "name": "Llano de Enmedio",
    "lat": "20.78328",
    "lng": "-98.01364"
  },
  {
    "country": "MX",
    "name": "Linares",
    "lat": "24.85798",
    "lng": "-99.56768"
  },
  {
    "country": "MX",
    "name": "Libres",
    "lat": "19.46574",
    "lng": "-97.68737"
  },
  {
    "country": "MX",
    "name": "Lerma de Villada",
    "lat": "19.28881",
    "lng": "-99.51163"
  },
  {
    "country": "MX",
    "name": "Lerdo de Tejada",
    "lat": "18.62936",
    "lng": "-95.51968"
  },
  {
    "country": "MX",
    "name": "Lázaro Cárdenas",
    "lat": "19.64032",
    "lng": "-98.47166"
  },
  {
    "country": "MX",
    "name": "Lázaro Cárdenas",
    "lat": "15.7168",
    "lng": "-92.25458"
  },
  {
    "country": "MX",
    "name": "La Trinitaria",
    "lat": "16.11859",
    "lng": "-92.05201"
  },
  {
    "country": "MX",
    "name": "Las Vigas de Ramírez",
    "lat": "19.63722",
    "lng": "-97.09821"
  },
  {
    "country": "MX",
    "name": "Las Rosas",
    "lat": "16.36574",
    "lng": "-92.3704"
  },
  {
    "country": "MX",
    "name": "Vegas de la Soledad y Soledad Dos",
    "lat": "20.94476",
    "lng": "-97.83273"
  },
  {
    "country": "MX",
    "name": "Las Minas",
    "lat": "19.69091",
    "lng": "-97.14597"
  },
  {
    "country": "MX",
    "name": "Las Margaritas",
    "lat": "16.31265",
    "lng": "-91.98107"
  },
  {
    "country": "MX",
    "name": "Las Lomas",
    "lat": "19.44745",
    "lng": "-96.9061"
  },
  {
    "country": "MX",
    "name": "Las Choapas",
    "lat": "17.91177",
    "lng": "-94.09646"
  },
  {
    "country": "MX",
    "name": "Las Amilpas",
    "lat": "16.36667",
    "lng": "-94.61667"
  },
  {
    "country": "MX",
    "name": "Larráinzar",
    "lat": "16.88392",
    "lng": "-92.71329"
  },
  {
    "country": "MX",
    "name": "La Reforma",
    "lat": "24.69822",
    "lng": "-99.54127"
  },
  {
    "country": "MX",
    "name": "La Perla",
    "lat": "18.92817",
    "lng": "-97.13362"
  },
  {
    "country": "MX",
    "name": "La Pedrera",
    "lat": "22.39353",
    "lng": "-97.8821"
  },
  {
    "country": "MX",
    "name": "Landero y Coss",
    "lat": "19.73499",
    "lng": "-96.85231"
  },
  {
    "country": "MX",
    "name": "Landa de Matamoros",
    "lat": "21.18484",
    "lng": "-99.31985"
  },
  {
    "country": "MX",
    "name": "La Misión",
    "lat": "23.80326",
    "lng": "-99.17025"
  },
  {
    "country": "MX",
    "name": "La Magdalena Yancuitlalpan",
    "lat": "18.91083",
    "lng": "-98.58944"
  },
  {
    "country": "MX",
    "name": "La Libertad",
    "lat": "14.59167",
    "lng": "-92.19315"
  },
  {
    "country": "MX",
    "name": "La Joya",
    "lat": "19.61099",
    "lng": "-97.02687"
  },
  {
    "country": "MX",
    "name": "La Joya",
    "lat": "18.66667",
    "lng": "-99.46667"
  },
  {
    "country": "MX",
    "name": "La Isla",
    "lat": "18.6",
    "lng": "-96.15"
  },
  {
    "country": "MX",
    "name": "Lagunillas",
    "lat": "21.5901",
    "lng": "-99.56601"
  },
  {
    "country": "MX",
    "name": "Laguna Chica (Pueblo Nuevo)",
    "lat": "18.54306",
    "lng": "-96.73306"
  },
  {
    "country": "MX",
    "name": "La Guadalupe",
    "lat": "16.68883",
    "lng": "-98.26222"
  },
  {
    "country": "MX",
    "name": "La Grandeza",
    "lat": "15.51033",
    "lng": "-92.22603"
  },
  {
    "country": "MX",
    "name": "La Defensa",
    "lat": "20.10507",
    "lng": "-96.96079"
  },
  {
    "country": "MX",
    "name": "Santo Tomás la Concordia",
    "lat": "19.22917",
    "lng": "-98.31944"
  },
  {
    "country": "MX",
    "name": "La Concordia",
    "lat": "16.11774",
    "lng": "-92.69018"
  },
  {
    "country": "MX",
    "name": "La Concepción de los Baños",
    "lat": "19.68249",
    "lng": "-99.86104"
  },
  {
    "country": "MX",
    "name": "La Concepción Coatipac (La Conchita)",
    "lat": "19.18188",
    "lng": "-99.56833"
  },
  {
    "country": "MX",
    "name": "La Ceiba",
    "lat": "20.75287",
    "lng": "-97.9084"
  },
  {
    "country": "MX",
    "name": "Komchén",
    "lat": "21.10342",
    "lng": "-89.66242"
  },
  {
    "country": "MX",
    "name": "Kinchil",
    "lat": "20.91519",
    "lng": "-89.94825"
  },
  {
    "country": "MX",
    "name": "Kantunil",
    "lat": "20.79645",
    "lng": "-89.03539"
  },
  {
    "country": "MX",
    "name": "Kanasín",
    "lat": "20.93482",
    "lng": "-89.55871"
  },
  {
    "country": "MX",
    "name": "Juchitepec",
    "lat": "19.10059",
    "lng": "-98.8788"
  },
  {
    "country": "MX",
    "name": "Juchitán de Zaragoza",
    "lat": "16.43603",
    "lng": "-95.01975"
  },
  {
    "country": "MX",
    "name": "Juchique de Ferrer",
    "lat": "19.83985",
    "lng": "-96.69463"
  },
  {
    "country": "MX",
    "name": "Colonia Juárez",
    "lat": "16.20967",
    "lng": "-95.02722"
  },
  {
    "country": "MX",
    "name": "Juan Marcos (San José Buenavista)",
    "lat": "19.72917",
    "lng": "-97.19667"
  },
  {
    "country": "MX",
    "name": "José Cardel",
    "lat": "19.3681",
    "lng": "-96.36951"
  },
  {
    "country": "MX",
    "name": "Joquicingo",
    "lat": "19.05032",
    "lng": "-99.53375"
  },
  {
    "country": "MX",
    "name": "Jonuta",
    "lat": "18.08984",
    "lng": "-92.13807"
  },
  {
    "country": "MX",
    "name": "Jonotla",
    "lat": "20.03032",
    "lng": "-97.5753"
  },
  {
    "country": "MX",
    "name": "Jonacatepec",
    "lat": "18.68081",
    "lng": "-98.80336"
  },
  {
    "country": "MX",
    "name": "Jojutla",
    "lat": "18.61472",
    "lng": "-99.18028"
  },
  {
    "country": "MX",
    "name": "Jocotitlán",
    "lat": "19.70991",
    "lng": "-99.78867"
  },
  {
    "country": "MX",
    "name": "Jiutepec",
    "lat": "18.88139",
    "lng": "-99.17778"
  },
  {
    "country": "MX",
    "name": "Jitotol",
    "lat": "17.06723",
    "lng": "-92.86111"
  },
  {
    "country": "MX",
    "name": "Jiquipilco",
    "lat": "19.55644",
    "lng": "-99.60833"
  },
  {
    "country": "MX",
    "name": "Jiquipilas",
    "lat": "16.66806",
    "lng": "-93.64667"
  },
  {
    "country": "MX",
    "name": "Jilotzingo",
    "lat": "19.86889",
    "lng": "-99.06194"
  },
  {
    "country": "MX",
    "name": "Jilotepec de Molina Enríquez",
    "lat": "19.95194",
    "lng": "-99.53278"
  },
  {
    "country": "MX",
    "name": "Jilotepec",
    "lat": "19.61184",
    "lng": "-96.95169"
  },
  {
    "country": "MX",
    "name": "Jesús del Monte",
    "lat": "19.12089",
    "lng": "-99.98786"
  },
  {
    "country": "MX",
    "name": "Jesús Carranza",
    "lat": "17.43526",
    "lng": "-95.02637"
  },
  {
    "country": "MX",
    "name": "San Juan Bautista Jayacatlán",
    "lat": "17.42443",
    "lng": "-96.82309"
  },
  {
    "country": "MX",
    "name": "Jaumave",
    "lat": "23.40621",
    "lng": "-99.38072"
  },
  {
    "country": "MX",
    "name": "Jantetelco",
    "lat": "18.71828",
    "lng": "-98.7776"
  },
  {
    "country": "MX",
    "name": "Jamapa",
    "lat": "19.04179",
    "lng": "-96.24143"
  },
  {
    "country": "MX",
    "name": "Jaltocan",
    "lat": "21.13284",
    "lng": "-98.53898"
  },
  {
    "country": "MX",
    "name": "Jáltipan de Morelos",
    "lat": "17.96542",
    "lng": "-94.71396"
  },
  {
    "country": "MX",
    "name": "Jaltepec",
    "lat": "19.7296",
    "lng": "-98.63456"
  },
  {
    "country": "MX",
    "name": "Jaltenco",
    "lat": "19.75298",
    "lng": "-99.0939"
  },
  {
    "country": "MX",
    "name": "Jalpan",
    "lat": "21.21802",
    "lng": "-99.47152"
  },
  {
    "country": "MX",
    "name": "Jalpa de Méndez",
    "lat": "18.17633",
    "lng": "-93.063"
  },
  {
    "country": "MX",
    "name": "Jalcomulco",
    "lat": "19.33185",
    "lng": "-96.7625"
  },
  {
    "country": "MX",
    "name": "Xalatlaco",
    "lat": "19.18314",
    "lng": "-99.41844"
  },
  {
    "country": "MX",
    "name": "Jalapilla",
    "lat": "18.82642",
    "lng": "-97.08865"
  },
  {
    "country": "MX",
    "name": "Xalapa de Enríquez",
    "lat": "19.53124",
    "lng": "-96.91589"
  },
  {
    "country": "MX",
    "name": "Jalapa",
    "lat": "16.5",
    "lng": "-95.46667"
  },
  {
    "country": "MX",
    "name": "Jalacingo",
    "lat": "19.80333",
    "lng": "-97.3083"
  },
  {
    "country": "MX",
    "name": "Jacala",
    "lat": "21.00952",
    "lng": "-99.19134"
  },
  {
    "country": "MX",
    "name": "Izúcar de Matamoros",
    "lat": "18.60157",
    "lng": "-98.46152"
  },
  {
    "country": "MX",
    "name": "1ra. Sección de Izapa",
    "lat": "14.92083",
    "lng": "-92.17083"
  },
  {
    "country": "MX",
    "name": "Izamal",
    "lat": "20.93537",
    "lng": "-89.01802"
  },
  {
    "country": "MX",
    "name": "Ixtlahuaca de Rayón",
    "lat": "19.56889",
    "lng": "-99.76694"
  },
  {
    "country": "MX",
    "name": "Ixtepec",
    "lat": "16.56052",
    "lng": "-95.10375"
  },
  {
    "country": "MX",
    "name": "Ixtapangajoya",
    "lat": "17.49849",
    "lng": "-93.00155"
  },
  {
    "country": "MX",
    "name": "Ixtapan de la Sal",
    "lat": "18.84369",
    "lng": "-99.67671"
  },
  {
    "country": "MX",
    "name": "Ixtapaluca",
    "lat": "19.31556",
    "lng": "-98.88284"
  },
  {
    "country": "MX",
    "name": "Iztapalapa",
    "lat": "19.35529",
    "lng": "-99.06224"
  },
  {
    "country": "MX",
    "name": "Ixtapa",
    "lat": "16.8032",
    "lng": "-92.90532"
  },
  {
    "country": "MX",
    "name": "Ixtaczoquitlán",
    "lat": "18.85364",
    "lng": "-97.06229"
  },
  {
    "country": "MX",
    "name": "Ixtacomitán",
    "lat": "17.43093",
    "lng": "-93.09704"
  },
  {
    "country": "MX",
    "name": "Ixtacamaxtitlán",
    "lat": "19.62352",
    "lng": "-97.81539"
  },
  {
    "country": "MX",
    "name": "Iztacalco",
    "lat": "19.39528",
    "lng": "-99.09778"
  },
  {
    "country": "MX",
    "name": "Ixmiquilpan",
    "lat": "20.47841",
    "lng": "-99.21697"
  },
  {
    "country": "MX",
    "name": "Ixil",
    "lat": "21.15235",
    "lng": "-89.48182"
  },
  {
    "country": "MX",
    "name": "Ixhuatlán de Madero",
    "lat": "20.68879",
    "lng": "-98.01177"
  },
  {
    "country": "MX",
    "name": "Ixhuatlán del Café",
    "lat": "19.05118",
    "lng": "-96.98391"
  },
  {
    "country": "MX",
    "name": "Ixhuatlancillo",
    "lat": "18.89766",
    "lng": "-97.14899"
  },
  {
    "country": "MX",
    "name": "San Francisco Ixhuatan",
    "lat": "16.35109",
    "lng": "-94.48402"
  },
  {
    "country": "MX",
    "name": "Ixcatlán",
    "lat": "21.08134",
    "lng": "-98.53468"
  },
  {
    "country": "MX",
    "name": "Ixcatepec",
    "lat": "21.23695",
    "lng": "-98.00689"
  },
  {
    "country": "MX",
    "name": "Ixcateopan de Cuauhtémoc",
    "lat": "18.50139",
    "lng": "-99.79139"
  },
  {
    "country": "MX",
    "name": "Ixcapuzalco",
    "lat": "18.51204",
    "lng": "-99.88755"
  },
  {
    "country": "MX",
    "name": "Iturbide",
    "lat": "24.72596",
    "lng": "-99.90406"
  },
  {
    "country": "MX",
    "name": "Isla Mujeres",
    "lat": "21.23114",
    "lng": "-86.73105"
  },
  {
    "country": "MX",
    "name": "Isla Aguada",
    "lat": "18.78714",
    "lng": "-91.49277"
  },
  {
    "country": "MX",
    "name": "Ixhuatán",
    "lat": "17.29341",
    "lng": "-93.00829"
  },
  {
    "country": "MX",
    "name": "Iliatenco",
    "lat": "17.0456",
    "lng": "-98.68607"
  },
  {
    "country": "MX",
    "name": "Ilamatlán",
    "lat": "20.78053",
    "lng": "-98.4432"
  },
  {
    "country": "MX",
    "name": "Igualapa",
    "lat": "16.74566",
    "lng": "-98.47666"
  },
  {
    "country": "MX",
    "name": "Iguala de la Independencia",
    "lat": "18.34536",
    "lng": "-99.5413"
  },
  {
    "country": "MX",
    "name": "Ignacio de la Llave",
    "lat": "18.7258",
    "lng": "-95.98696"
  },
  {
    "country": "MX",
    "name": "Itzincab Palomeque",
    "lat": "20.91644",
    "lng": "-89.69823"
  },
  {
    "country": "MX",
    "name": "Hunucmá",
    "lat": "21.01723",
    "lng": "-89.87551"
  },
  {
    "country": "MX",
    "name": "Huixtla",
    "lat": "15.13915",
    "lng": "-92.4641"
  },
  {
    "country": "MX",
    "name": "Huixtán",
    "lat": "16.71062",
    "lng": "-92.45317"
  },
  {
    "country": "MX",
    "name": "Huixquilucan de Degollado",
    "lat": "19.36028",
    "lng": "-99.3498"
  },
  {
    "country": "MX",
    "name": "Ciudad de Huitzuco",
    "lat": "18.30334",
    "lng": "-99.33376"
  },
  {
    "country": "MX",
    "name": "Huitziltepec",
    "lat": "17.7561",
    "lng": "-99.47983"
  },
  {
    "country": "MX",
    "name": "Huitzilan",
    "lat": "19.9675",
    "lng": "-97.69441"
  },
  {
    "country": "MX",
    "name": "Huitzilac",
    "lat": "19.02983",
    "lng": "-99.26788"
  },
  {
    "country": "MX",
    "name": "Huitiupán",
    "lat": "17.1724",
    "lng": "-92.68621"
  },
  {
    "country": "MX",
    "name": "Huixtepec",
    "lat": "16.65361",
    "lng": "-98.30455"
  },
  {
    "country": "MX",
    "name": "Huimanguillo",
    "lat": "17.83366",
    "lng": "-93.38926"
  },
  {
    "country": "MX",
    "name": "Huiloapan de Cuauhtémoc",
    "lat": "18.81722",
    "lng": "-97.15444"
  },
  {
    "country": "MX",
    "name": "Huiloapan",
    "lat": "18.75",
    "lng": "-97.31667"
  },
  {
    "country": "MX",
    "name": "Huichapan",
    "lat": "20.37593",
    "lng": "-99.64869"
  },
  {
    "country": "MX",
    "name": "Huhi",
    "lat": "20.72603",
    "lng": "-89.16072"
  },
  {
    "country": "MX",
    "name": "Hueytamalco",
    "lat": "19.94029",
    "lng": "-97.28848"
  },
  {
    "country": "MX",
    "name": "Hueypoxtla",
    "lat": "19.91301",
    "lng": "-99.07384"
  },
  {
    "country": "MX",
    "name": "Hueyotlipan",
    "lat": "19.47088",
    "lng": "-98.34778"
  },
  {
    "country": "MX",
    "name": "Hueycantenango",
    "lat": "17.44873",
    "lng": "-99.0244"
  },
  {
    "country": "MX",
    "name": "Hueyapan de Ocampo",
    "lat": "18.14479",
    "lng": "-95.14873"
  },
  {
    "country": "MX",
    "name": "Hueyapan",
    "lat": "18.8897",
    "lng": "-98.682"
  },
  {
    "country": "MX",
    "name": "Huepalcalco (San Miguel)",
    "lat": "18.90889",
    "lng": "-98.75"
  },
  {
    "country": "MX",
    "name": "Huejutla de Reyes",
    "lat": "21.14",
    "lng": "-98.41944"
  },
  {
    "country": "MX",
    "name": "Huejotzingo",
    "lat": "19.15892",
    "lng": "-98.40824"
  },
  {
    "country": "MX",
    "name": "Huehuetoca",
    "lat": "19.83567",
    "lng": "-99.20131"
  },
  {
    "country": "MX",
    "name": "Huehuetlán",
    "lat": "21.54649",
    "lng": "-98.96768"
  },
  {
    "country": "MX",
    "name": "Huehuetla",
    "lat": "20.4605",
    "lng": "-98.07627"
  },
  {
    "country": "MX",
    "name": "Huehuetla",
    "lat": "20.10578",
    "lng": "-97.62517"
  },
  {
    "country": "MX",
    "name": "Huehuetán",
    "lat": "15.01981",
    "lng": "-92.38249"
  },
  {
    "country": "MX",
    "name": "Huazuntlán",
    "lat": "18.15667",
    "lng": "-94.79306"
  },
  {
    "country": "MX",
    "name": "Huazulco",
    "lat": "18.75299",
    "lng": "-98.77535"
  },
  {
    "country": "MX",
    "name": "Huayacocotla",
    "lat": "20.53671",
    "lng": "-98.4808"
  },
  {
    "country": "MX",
    "name": "Huautla de Jiménez",
    "lat": "18.1315",
    "lng": "-96.84088"
  },
  {
    "country": "MX",
    "name": "Huautla",
    "lat": "21.03105",
    "lng": "-98.28685"
  },
  {
    "country": "MX",
    "name": "San Miguel Huautla",
    "lat": "17.74538",
    "lng": "-97.13712"
  },
  {
    "country": "MX",
    "name": "Huauchinango",
    "lat": "20.17376",
    "lng": "-98.05491"
  },
  {
    "country": "MX",
    "name": "Huatusco",
    "lat": "19.14876",
    "lng": "-96.9676"
  },
  {
    "country": "MX",
    "name": "Huatlatlauca",
    "lat": "18.68147",
    "lng": "-98.05042"
  },
  {
    "country": "MX",
    "name": "Huasca de Ocampo",
    "lat": "20.20357",
    "lng": "-98.57603"
  },
  {
    "country": "MX",
    "name": "Huaquechula",
    "lat": "18.77116",
    "lng": "-98.5446"
  },
  {
    "country": "MX",
    "name": "Huamuxtitlán",
    "lat": "17.80448",
    "lng": "-98.56417"
  },
  {
    "country": "MX",
    "name": "Hualahuises",
    "lat": "24.88295",
    "lng": "-99.6749"
  },
  {
    "country": "MX",
    "name": "Ciudad de Huajuapan de León",
    "lat": "17.80787",
    "lng": "-97.77956"
  },
  {
    "country": "MX",
    "name": "Ex-Hacienda el Hospital",
    "lat": "18.83111",
    "lng": "-98.99667"
  },
  {
    "country": "MX",
    "name": "Hornitos",
    "lat": "19.46083",
    "lng": "-96.42111"
  },
  {
    "country": "MX",
    "name": "Hopelchén",
    "lat": "19.74671",
    "lng": "-89.84437"
  },
  {
    "country": "MX",
    "name": "Homun",
    "lat": "20.73918",
    "lng": "-89.2849"
  },
  {
    "country": "MX",
    "name": "Hoctun",
    "lat": "20.86513",
    "lng": "-89.20125"
  },
  {
    "country": "MX",
    "name": "Hocaba",
    "lat": "20.8162",
    "lng": "-89.24626"
  },
  {
    "country": "MX",
    "name": "Villa Hidalgo",
    "lat": "17.18409",
    "lng": "-96.17831"
  },
  {
    "country": "MX",
    "name": "Hidalgotitlán",
    "lat": "17.77051",
    "lng": "-94.64703"
  },
  {
    "country": "MX",
    "name": "Hidalgo",
    "lat": "27.78994",
    "lng": "-99.87699"
  },
  {
    "country": "MX",
    "name": "Hidalgo",
    "lat": "26.05",
    "lng": "-98.2"
  },
  {
    "country": "MX",
    "name": "Hidalgo",
    "lat": "24.24812",
    "lng": "-99.43897"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Hidalgo",
    "lat": "19.96663",
    "lng": "-96.87998"
  },
  {
    "country": "MX",
    "name": "Hecelchakán",
    "lat": "20.17735",
    "lng": "-90.13357"
  },
  {
    "country": "MX",
    "name": "Halachó",
    "lat": "20.4777",
    "lng": "-90.08104"
  },
  {
    "country": "MX",
    "name": "Gutiérrez Zamora",
    "lat": "20.45347",
    "lng": "-97.08588"
  },
  {
    "country": "MX",
    "name": "Guemes",
    "lat": "23.91865",
    "lng": "-99.00609"
  },
  {
    "country": "MX",
    "name": "Nuevo Juan del Grijalva",
    "lat": "17.42722",
    "lng": "-93.37222"
  },
  {
    "country": "MX",
    "name": "Graciano Sánchez",
    "lat": "23.92569",
    "lng": "-99.2961"
  },
  {
    "country": "MX",
    "name": "General Treviño",
    "lat": "26.22316",
    "lng": "-99.48503"
  },
  {
    "country": "MX",
    "name": "Ciudad General Terán",
    "lat": "25.25857",
    "lng": "-99.68371"
  },
  {
    "country": "MX",
    "name": "Tancanhuitz",
    "lat": "21.5979",
    "lng": "-98.96773"
  },
  {
    "country": "MX",
    "name": "General Bravo",
    "lat": "25.79239",
    "lng": "-99.18147"
  },
  {
    "country": "MX",
    "name": "Frontera Hidalgo",
    "lat": "14.77744",
    "lng": "-92.17741"
  },
  {
    "country": "MX",
    "name": "Comalapa",
    "lat": "15.65924",
    "lng": "-92.14237"
  },
  {
    "country": "MX",
    "name": "Frontera",
    "lat": "18.54326",
    "lng": "-92.6453"
  },
  {
    "country": "MX",
    "name": "Francisco I. Madero",
    "lat": "15.06996",
    "lng": "-92.54435"
  },
  {
    "country": "MX",
    "name": "Fortín de las Flores",
    "lat": "18.90806",
    "lng": "-97"
  },
  {
    "country": "MX",
    "name": "Fontezuelas",
    "lat": "20.48861",
    "lng": "-98.87306"
  },
  {
    "country": "MX",
    "name": "Flor de Cacao",
    "lat": "16.12889",
    "lng": "-90.45111"
  },
  {
    "country": "MX",
    "name": "Filomeno Mata",
    "lat": "20.20004",
    "lng": "-97.70392"
  },
  {
    "country": "MX",
    "name": "Felipe Carrillo Puerto",
    "lat": "19.5775",
    "lng": "-88.04529"
  },
  {
    "country": "MX",
    "name": "Ezequiel Montes",
    "lat": "20.66481",
    "lng": "-99.8996"
  },
  {
    "country": "MX",
    "name": "Puntilla Aldama",
    "lat": "20.18915",
    "lng": "-96.90693"
  },
  {
    "country": "MX",
    "name": "Espita",
    "lat": "21.01098",
    "lng": "-88.30681"
  },
  {
    "country": "MX",
    "name": "El Espinal",
    "lat": "16.48525",
    "lng": "-95.03995"
  },
  {
    "country": "MX",
    "name": "Esperanza",
    "lat": "18.85853",
    "lng": "-97.37641"
  },
  {
    "country": "MX",
    "name": "Españita",
    "lat": "19.46286",
    "lng": "-98.42434"
  },
  {
    "country": "MX",
    "name": "Escuintla",
    "lat": "15.31944",
    "lng": "-92.65833"
  },
  {
    "country": "MX",
    "name": "Escárcega",
    "lat": "18.60891",
    "lng": "-90.74544"
  },
  {
    "country": "MX",
    "name": "Epazoyucan",
    "lat": "20.01801",
    "lng": "-98.63623"
  },
  {
    "country": "MX",
    "name": "Villa Emilio Carranza",
    "lat": "19.9702",
    "lng": "-96.61162"
  },
  {
    "country": "MX",
    "name": "Emiliano Zapata",
    "lat": "19.6549",
    "lng": "-98.54497"
  },
  {
    "country": "MX",
    "name": "Emiliano Zapata",
    "lat": "18.84065",
    "lng": "-99.18463"
  },
  {
    "country": "MX",
    "name": "Emiliano Zapata",
    "lat": "17.74058",
    "lng": "-91.76635"
  },
  {
    "country": "MX",
    "name": "San Lucas",
    "lat": "16.61167",
    "lng": "-92.71806"
  },
  {
    "country": "MX",
    "name": "El Tejar",
    "lat": "19.07433",
    "lng": "-96.16097"
  },
  {
    "country": "MX",
    "name": "El Rincón",
    "lat": "20.74111",
    "lng": "-99.78472"
  },
  {
    "country": "MX",
    "name": "El Porvenir de Velasco Suárez",
    "lat": "15.45695",
    "lng": "-92.27987"
  },
  {
    "country": "MX",
    "name": "San Marcos Eloxochitlán",
    "lat": "20.02528",
    "lng": "-97.87194"
  },
  {
    "country": "MX",
    "name": "Eloxochitlán de Flores Magón",
    "lat": "18.17724",
    "lng": "-96.87538"
  },
  {
    "country": "MX",
    "name": "El Ocotito",
    "lat": "17.24603",
    "lng": "-99.51525"
  },
  {
    "country": "MX",
    "name": "El Nopal",
    "lat": "16.91161",
    "lng": "-92.84471"
  },
  {
    "country": "MX",
    "name": "Ciudad Mante",
    "lat": "22.74304",
    "lng": "-98.9739"
  },
  {
    "country": "MX",
    "name": "El Llano",
    "lat": "20.06537",
    "lng": "-99.31976"
  },
  {
    "country": "MX",
    "name": "El Limonar",
    "lat": "16.97026",
    "lng": "-91.3782"
  },
  {
    "country": "MX",
    "name": "El Higo",
    "lat": "21.76708",
    "lng": "-98.45186"
  },
  {
    "country": "MX",
    "name": "El Espinal",
    "lat": "16.36862",
    "lng": "-94.10449"
  },
  {
    "country": "MX",
    "name": "El Cazadero",
    "lat": "20.30011",
    "lng": "-99.87186"
  },
  {
    "country": "MX",
    "name": "El Castillo",
    "lat": "19.54661",
    "lng": "-96.86425"
  },
  {
    "country": "MX",
    "name": "El Carmen Aztama",
    "lat": "19.22972",
    "lng": "-98.21944"
  },
  {
    "country": "MX",
    "name": "El Bosque",
    "lat": "17.06273",
    "lng": "-92.72147"
  },
  {
    "country": "MX",
    "name": "El Arenal",
    "lat": "20.22258",
    "lng": "-98.90957"
  },
  {
    "country": "MX",
    "name": "Ejutla de Crespo",
    "lat": "16.56623",
    "lng": "-96.73123"
  },
  {
    "country": "MX",
    "name": "Ecatzingo de Hidalgo",
    "lat": "18.95508",
    "lng": "-98.75198"
  },
  {
    "country": "MX",
    "name": "Ecatepec de Morelos",
    "lat": "19.60492",
    "lng": "-99.06064"
  },
  {
    "country": "MX",
    "name": "Ébano",
    "lat": "22.21808",
    "lng": "-98.37706"
  },
  {
    "country": "MX",
    "name": "Dzitnup",
    "lat": "20.64725",
    "lng": "-88.24453"
  },
  {
    "country": "MX",
    "name": "Dzitbalché",
    "lat": "20.31857",
    "lng": "-90.05611"
  },
  {
    "country": "MX",
    "name": "Dzitás",
    "lat": "20.84089",
    "lng": "-88.52908"
  },
  {
    "country": "MX",
    "name": "Dzilam González",
    "lat": "21.28098",
    "lng": "-88.92957"
  },
  {
    "country": "MX",
    "name": "Dzilam de Bravo",
    "lat": "21.39194",
    "lng": "-88.8941"
  },
  {
    "country": "MX",
    "name": "Dzidzantun",
    "lat": "21.24898",
    "lng": "-89.04205"
  },
  {
    "country": "MX",
    "name": "Dzibalchén",
    "lat": "19.45847",
    "lng": "-89.73111"
  },
  {
    "country": "MX",
    "name": "Dzemul",
    "lat": "21.21036",
    "lng": "-89.30956"
  },
  {
    "country": "MX",
    "name": "Dzan",
    "lat": "20.38888",
    "lng": "-89.46855"
  },
  {
    "country": "MX",
    "name": "Doxhicho",
    "lat": "19.92878",
    "lng": "-99.55804"
  },
  {
    "country": "MX",
    "name": "Doxey",
    "lat": "20.09169",
    "lng": "-99.24362"
  },
  {
    "country": "MX",
    "name": "Dos Ríos",
    "lat": "19.48417",
    "lng": "-96.79944"
  },
  {
    "country": "MX",
    "name": "Domingo Arenas",
    "lat": "19.13998",
    "lng": "-98.45678"
  },
  {
    "country": "MX",
    "name": "Doctor González",
    "lat": "25.85983",
    "lng": "-99.94409"
  },
  {
    "country": "MX",
    "name": "Doctor Coss",
    "lat": "25.92492",
    "lng": "-99.18316"
  },
  {
    "country": "MX",
    "name": "Villa Díaz Ordaz",
    "lat": "16.99578",
    "lng": "-96.43231"
  },
  {
    "country": "MX",
    "name": "Cuzama",
    "lat": "20.74202",
    "lng": "-89.31732"
  },
  {
    "country": "MX",
    "name": "Cunduacán",
    "lat": "18.06557",
    "lng": "-93.17302"
  },
  {
    "country": "MX",
    "name": "Cuitláhuac",
    "lat": "18.81429",
    "lng": "-96.72281"
  },
  {
    "country": "MX",
    "name": "Cuilapan de Guerrero",
    "lat": "16.97756",
    "lng": "-96.78081"
  },
  {
    "country": "MX",
    "name": "Cuichapa",
    "lat": "18.7715",
    "lng": "-96.8689"
  },
  {
    "country": "MX",
    "name": "Cuetzalan",
    "lat": "20.01766",
    "lng": "-97.52277"
  },
  {
    "country": "MX",
    "name": "Cuetzala del Progreso",
    "lat": "18.13472",
    "lng": "-99.8319"
  },
  {
    "country": "MX",
    "name": "Cuernavaca",
    "lat": "18.9261",
    "lng": "-99.23075"
  },
  {
    "country": "MX",
    "name": "Cuautlapán",
    "lat": "18.87747",
    "lng": "-97.02291"
  },
  {
    "country": "MX",
    "name": "Cuautlancingo",
    "lat": "19.08995",
    "lng": "-98.27319"
  },
  {
    "country": "MX",
    "name": "Cuautla",
    "lat": "18.8106",
    "lng": "-98.93525"
  },
  {
    "country": "MX",
    "name": "Santiago Cuautlalpan",
    "lat": "19.68417",
    "lng": "-99.2887"
  },
  {
    "country": "MX",
    "name": "Cuautitlán",
    "lat": "19.67052",
    "lng": "-99.17989"
  },
  {
    "country": "MX",
    "name": "Cuautepec de Hinojosa",
    "lat": "20.03557",
    "lng": "-98.31015"
  },
  {
    "country": "MX",
    "name": "Cuautepec",
    "lat": "16.75004",
    "lng": "-99.0024"
  },
  {
    "country": "MX",
    "name": "Cuauchichinola",
    "lat": "18.66389",
    "lng": "-99.37583"
  },
  {
    "country": "MX",
    "name": "Cuapiaxtla de Madero",
    "lat": "18.91544",
    "lng": "-97.82382"
  },
  {
    "country": "MX",
    "name": "Cuapiaxtla",
    "lat": "19.29588",
    "lng": "-97.7688"
  },
  {
    "country": "MX",
    "name": "Cuanalá",
    "lat": "19.10917",
    "lng": "-98.32788"
  },
  {
    "country": "MX",
    "name": "Cualác",
    "lat": "17.7435",
    "lng": "-98.66039"
  },
  {
    "country": "MX",
    "name": "Cuajinicuilapa",
    "lat": "16.47347",
    "lng": "-98.41389"
  },
  {
    "country": "MX",
    "name": "Delegación Cuajimalpa de Morelos",
    "lat": "19.3692",
    "lng": "-99.29089"
  },
  {
    "country": "MX",
    "name": "Cuacnopalan",
    "lat": "18.81758",
    "lng": "-97.51116"
  },
  {
    "country": "MX",
    "name": "Cruz Grande",
    "lat": "16.72241",
    "lng": "-99.12356"
  },
  {
    "country": "MX",
    "name": "Cruz del Milagro",
    "lat": "17.90833",
    "lng": "-95.01083"
  },
  {
    "country": "MX",
    "name": "Cruillas",
    "lat": "24.75658",
    "lng": "-98.53739"
  },
  {
    "country": "MX",
    "name": "Nuevo Crucitas",
    "lat": "22.10833",
    "lng": "-99.20444"
  },
  {
    "country": "MX",
    "name": "Cristóbal Obregón",
    "lat": "16.35",
    "lng": "-93.53333"
  },
  {
    "country": "MX",
    "name": "Cozumel",
    "lat": "20.50038",
    "lng": "-86.94272"
  },
  {
    "country": "MX",
    "name": "Coyutla",
    "lat": "20.2472",
    "lng": "-97.65824"
  },
  {
    "country": "MX",
    "name": "Coyotepec",
    "lat": "19.77722",
    "lng": "-99.21295"
  },
  {
    "country": "MX",
    "name": "Coyoacán",
    "lat": "19.3467",
    "lng": "-99.16174"
  },
  {
    "country": "MX",
    "name": "Coxquihui",
    "lat": "20.18398",
    "lng": "-97.58568"
  },
  {
    "country": "MX",
    "name": "Coxcatlán",
    "lat": "21.54103",
    "lng": "-98.90713"
  },
  {
    "country": "MX",
    "name": "Coxcatlán",
    "lat": "18.26709",
    "lng": "-97.15078"
  },
  {
    "country": "MX",
    "name": "Cosoleacaque",
    "lat": "17.99913",
    "lng": "-94.6359"
  },
  {
    "country": "MX",
    "name": "Cosolapa",
    "lat": "18.60055",
    "lng": "-96.68524"
  },
  {
    "country": "MX",
    "name": "Coscomatepec de Bravo",
    "lat": "19.07275",
    "lng": "-97.04685"
  },
  {
    "country": "MX",
    "name": "Cosautlán",
    "lat": "19.33196",
    "lng": "-96.9903"
  },
  {
    "country": "MX",
    "name": "Cosamaloapan",
    "lat": "18.36759",
    "lng": "-95.79857"
  },
  {
    "country": "MX",
    "name": "Corral Nuevo",
    "lat": "18.11461",
    "lng": "-95.11542"
  },
  {
    "country": "MX",
    "name": "Corralillos",
    "lat": "20.48273",
    "lng": "-97.52582"
  },
  {
    "country": "MX",
    "name": "Córdoba",
    "lat": "18.8842",
    "lng": "-96.92559"
  },
  {
    "country": "MX",
    "name": "Copoya",
    "lat": "16.71191",
    "lng": "-93.12089"
  },
  {
    "country": "MX",
    "name": "Copanatoyac",
    "lat": "17.46335",
    "lng": "-98.71362"
  },
  {
    "country": "MX",
    "name": "Copalillo",
    "lat": "18.03427",
    "lng": "-99.04124"
  },
  {
    "country": "MX",
    "name": "Copala",
    "lat": "16.60774",
    "lng": "-98.97821"
  },
  {
    "country": "MX",
    "name": "Copainalá",
    "lat": "17.09366",
    "lng": "-93.21059"
  },
  {
    "country": "MX",
    "name": "Contla",
    "lat": "19.32932",
    "lng": "-98.1664"
  },
  {
    "country": "MX",
    "name": "Constancia del Rosario",
    "lat": "17.0382",
    "lng": "-97.94125"
  },
  {
    "country": "MX",
    "name": "Conkal",
    "lat": "21.07365",
    "lng": "-89.51995"
  },
  {
    "country": "MX",
    "name": "Concepción Capulac (La Ex-Hacienda)",
    "lat": "19.09444",
    "lng": "-98.06139"
  },
  {
    "country": "MX",
    "name": "Comoapan",
    "lat": "18.40684",
    "lng": "-95.17415"
  },
  {
    "country": "MX",
    "name": "Comitán",
    "lat": "16.2471",
    "lng": "-92.13515"
  },
  {
    "country": "MX",
    "name": "San Pedro Comitancillo",
    "lat": "16.49134",
    "lng": "-95.15649"
  },
  {
    "country": "MX",
    "name": "Comapa",
    "lat": "19.16404",
    "lng": "-96.8866"
  },
  {
    "country": "MX",
    "name": "Comales",
    "lat": "26.18187",
    "lng": "-98.92037"
  },
  {
    "country": "MX",
    "name": "Comalcalco",
    "lat": "18.26316",
    "lng": "-93.22397"
  },
  {
    "country": "MX",
    "name": "Colotepec",
    "lat": "17.04104",
    "lng": "-99.21273"
  },
  {
    "country": "MX",
    "name": "Colipa",
    "lat": "19.92323",
    "lng": "-96.72713"
  },
  {
    "country": "MX",
    "name": "Coetzala",
    "lat": "18.78521",
    "lng": "-96.91697"
  },
  {
    "country": "MX",
    "name": "Cocula",
    "lat": "18.24116",
    "lng": "-99.66202"
  },
  {
    "country": "MX",
    "name": "Cocoyoc",
    "lat": "18.88417",
    "lng": "-98.98194"
  },
  {
    "country": "MX",
    "name": "Cocotitlán",
    "lat": "19.23336",
    "lng": "-98.86596"
  },
  {
    "country": "MX",
    "name": "Coba",
    "lat": "20.48298",
    "lng": "-87.73888"
  },
  {
    "country": "MX",
    "name": "Coatzintla",
    "lat": "20.48699",
    "lng": "-97.46823"
  },
  {
    "country": "MX",
    "name": "Coatzingo",
    "lat": "18.61199",
    "lng": "-98.17267"
  },
  {
    "country": "MX",
    "name": "Coatzacoalcos",
    "lat": "18.14905",
    "lng": "-94.4447"
  },
  {
    "country": "MX",
    "name": "Coatlán del Río",
    "lat": "18.74423",
    "lng": "-99.43324"
  },
  {
    "country": "MX",
    "name": "Coatetelco",
    "lat": "18.72963",
    "lng": "-99.32605"
  },
  {
    "country": "MX",
    "name": "Coatepec Harinas",
    "lat": "18.89492",
    "lng": "-99.72153"
  },
  {
    "country": "MX",
    "name": "Coatepec",
    "lat": "19.45229",
    "lng": "-96.96148"
  },
  {
    "country": "MX",
    "name": "Santa Maria Coatepec",
    "lat": "19.10924",
    "lng": "-97.59253"
  },
  {
    "country": "MX",
    "name": "Coatecas Altas",
    "lat": "16.53926",
    "lng": "-96.66878"
  },
  {
    "country": "MX",
    "name": "Coapilla",
    "lat": "17.13137",
    "lng": "-93.15946"
  },
  {
    "country": "MX",
    "name": "San Juan Coajomulco",
    "lat": "19.75306",
    "lng": "-99.96861"
  },
  {
    "country": "MX",
    "name": "Coacoatzintla",
    "lat": "19.65163",
    "lng": "-96.94043"
  },
  {
    "country": "MX",
    "name": "Coacalco",
    "lat": "19.62923",
    "lng": "-99.10689"
  },
  {
    "country": "MX",
    "name": "Ciudad Victoria",
    "lat": "23.74174",
    "lng": "-99.14599"
  },
  {
    "country": "MX",
    "name": "Ciudad Serdán",
    "lat": "18.98856",
    "lng": "-97.44643"
  },
  {
    "country": "MX",
    "name": "Ciudad Sahagun",
    "lat": "19.77557",
    "lng": "-98.57471"
  },
  {
    "country": "MX",
    "name": "Ciudad Pemex",
    "lat": "17.88268",
    "lng": "-92.48406"
  },
  {
    "country": "MX",
    "name": "Ciudad Nezahualcoyotl",
    "lat": "19.40061",
    "lng": "-99.01483"
  },
  {
    "country": "MX",
    "name": "Ciudad Miguel Alemán",
    "lat": "26.39952",
    "lng": "-99.02836"
  },
  {
    "country": "MX",
    "name": "Ciudad Mendoza",
    "lat": "18.80645",
    "lng": "-97.1787"
  },
  {
    "country": "MX",
    "name": "Ciudad Madero",
    "lat": "22.27228",
    "lng": "-97.83623"
  },
  {
    "country": "MX",
    "name": "Ciudad Hidalgo",
    "lat": "14.68148",
    "lng": "-92.15217"
  },
  {
    "country": "MX",
    "name": "Ciudad Fernández",
    "lat": "21.94045",
    "lng": "-100.01153"
  },
  {
    "country": "MX",
    "name": "Mexico City",
    "lat": "19.42847",
    "lng": "-99.12766"
  },
  {
    "country": "MX",
    "name": "Ciudad del Maíz",
    "lat": "22.40187",
    "lng": "-99.60468"
  },
  {
    "country": "MX",
    "name": "Ciudad del Carmen",
    "lat": "18.64592",
    "lng": "-91.82991"
  },
  {
    "country": "MX",
    "name": "Ciudad Camargo",
    "lat": "26.31437",
    "lng": "-98.83378"
  },
  {
    "country": "MX",
    "name": "Citlaltépec",
    "lat": "21.32912",
    "lng": "-97.87861"
  },
  {
    "country": "MX",
    "name": "Cintalapa de Figueroa",
    "lat": "16.68393",
    "lng": "-93.71814"
  },
  {
    "country": "MX",
    "name": "Cieneguilla",
    "lat": "16.32353",
    "lng": "-97.31762"
  },
  {
    "country": "MX",
    "name": "Ciénega de Zimatlán",
    "lat": "16.89343",
    "lng": "-96.76756"
  },
  {
    "country": "MX",
    "name": "Chunhuhub",
    "lat": "19.58533",
    "lng": "-88.5922"
  },
  {
    "country": "MX",
    "name": "Chumayel",
    "lat": "20.42833",
    "lng": "-89.30111"
  },
  {
    "country": "MX",
    "name": "Chumatlán",
    "lat": "20.20574",
    "lng": "-97.59402"
  },
  {
    "country": "MX",
    "name": "Chontla",
    "lat": "21.2958",
    "lng": "-97.92419"
  },
  {
    "country": "MX",
    "name": "Chontalpa",
    "lat": "17.66614",
    "lng": "-93.48115"
  },
  {
    "country": "MX",
    "name": "San Pedro Chochula",
    "lat": "19.26359",
    "lng": "-99.4859"
  },
  {
    "country": "MX",
    "name": "Cholula",
    "lat": "19.06406",
    "lng": "-98.30352"
  },
  {
    "country": "MX",
    "name": "Cholul Cantón",
    "lat": "21.01078",
    "lng": "-89.29147"
  },
  {
    "country": "MX",
    "name": "Chochola",
    "lat": "20.75087",
    "lng": "-89.83041"
  },
  {
    "country": "MX",
    "name": "Chocamán",
    "lat": "19.01214",
    "lng": "-97.03291"
  },
  {
    "country": "MX",
    "name": "Chiquihuitlán de Benito Juárez",
    "lat": "17.99582",
    "lng": "-96.74474"
  },
  {
    "country": "MX",
    "name": "Chinampa de Gorostiza",
    "lat": "21.35959",
    "lng": "-97.73484"
  },
  {
    "country": "MX",
    "name": "Chinameca",
    "lat": "18.02195",
    "lng": "-94.67945"
  },
  {
    "country": "MX",
    "name": "China",
    "lat": "25.69997",
    "lng": "-99.23454"
  },
  {
    "country": "MX",
    "name": "Chiná",
    "lat": "19.76993",
    "lng": "-90.49595"
  },
  {
    "country": "MX",
    "name": "Santiago Camotlán",
    "lat": "17.44541",
    "lng": "-96.18509"
  },
  {
    "country": "MX",
    "name": "San Francisco Chimalpa",
    "lat": "19.44279",
    "lng": "-99.34398"
  },
  {
    "country": "MX",
    "name": "Chilpancingo",
    "lat": "17.5506",
    "lng": "-99.50578"
  },
  {
    "country": "MX",
    "name": "Chilón",
    "lat": "17.23333",
    "lng": "-92.41667"
  },
  {
    "country": "MX",
    "name": "Chilcuautla",
    "lat": "20.33059",
    "lng": "-99.23117"
  },
  {
    "country": "MX",
    "name": "Chilapa",
    "lat": "18.98861",
    "lng": "-97.15417"
  },
  {
    "country": "MX",
    "name": "Chilapa de Álvarez",
    "lat": "17.59917",
    "lng": "-99.17389"
  },
  {
    "country": "MX",
    "name": "Chila de la Sal",
    "lat": "18.10975",
    "lng": "-98.48574"
  },
  {
    "country": "MX",
    "name": "Chikindzonot",
    "lat": "20.33436",
    "lng": "-88.4863"
  },
  {
    "country": "MX",
    "name": "Chinautla",
    "lat": "19.81996",
    "lng": "-97.38859"
  },
  {
    "country": "MX",
    "name": "Chignahuapan",
    "lat": "19.83866",
    "lng": "-98.03171"
  },
  {
    "country": "MX",
    "name": "Chigmecatitlán",
    "lat": "18.64634",
    "lng": "-98.07203"
  },
  {
    "country": "MX",
    "name": "Chietla",
    "lat": "18.52028",
    "lng": "-98.57889"
  },
  {
    "country": "MX",
    "name": "Chicxulub Pueblo",
    "lat": "21.13617",
    "lng": "-89.51625"
  },
  {
    "country": "MX",
    "name": "Chicualoque",
    "lat": "20.38272",
    "lng": "-97.66163"
  },
  {
    "country": "MX",
    "name": "Chicontepec",
    "lat": "20.97214",
    "lng": "-98.17239"
  },
  {
    "country": "MX",
    "name": "Chiconquiaco",
    "lat": "19.74208",
    "lng": "-96.81851"
  },
  {
    "country": "MX",
    "name": "Chiconcuac",
    "lat": "19.55939",
    "lng": "-98.89884"
  },
  {
    "country": "MX",
    "name": "Chiconamel",
    "lat": "21.2305",
    "lng": "-98.46024"
  },
  {
    "country": "MX",
    "name": "Chicomuselo",
    "lat": "15.7442",
    "lng": "-92.2833"
  },
  {
    "country": "MX",
    "name": "Chicoloapan",
    "lat": "19.41687",
    "lng": "-98.90202"
  },
  {
    "country": "MX",
    "name": "Chicola",
    "lat": "18.90139",
    "lng": "-97.10806"
  },
  {
    "country": "MX",
    "name": "Chicoasén",
    "lat": "16.96633",
    "lng": "-93.10486"
  },
  {
    "country": "MX",
    "name": "Chichiquila",
    "lat": "19.20073",
    "lng": "-97.06691"
  },
  {
    "country": "MX",
    "name": "Chichimila",
    "lat": "20.63176",
    "lng": "-88.21689"
  },
  {
    "country": "MX",
    "name": "Chichihualco",
    "lat": "17.65902",
    "lng": "-99.67624"
  },
  {
    "country": "MX",
    "name": "Chichén-Itzá",
    "lat": "20.66667",
    "lng": "-88.56667"
  },
  {
    "country": "MX",
    "name": "Chiautla de Tapia",
    "lat": "18.30149",
    "lng": "-98.60339"
  },
  {
    "country": "MX",
    "name": "Chiautla",
    "lat": "19.54895",
    "lng": "-98.88236"
  },
  {
    "country": "MX",
    "name": "Chiaucingo",
    "lat": "17.74207",
    "lng": "-98.6972"
  },
  {
    "country": "MX",
    "name": "Chiapilla",
    "lat": "16.56975",
    "lng": "-92.72037"
  },
  {
    "country": "MX",
    "name": "Chiapa de Corzo",
    "lat": "16.7077",
    "lng": "-93.01184"
  },
  {
    "country": "MX",
    "name": "Chetumal",
    "lat": "18.51413",
    "lng": "-88.30381"
  },
  {
    "country": "MX",
    "name": "Chenalhó",
    "lat": "16.89367",
    "lng": "-92.62651"
  },
  {
    "country": "MX",
    "name": "Chemax",
    "lat": "20.65613",
    "lng": "-87.9364"
  },
  {
    "country": "MX",
    "name": "Chelem",
    "lat": "21.26967",
    "lng": "-89.74006"
  },
  {
    "country": "MX",
    "name": "San Agustín Chayuco",
    "lat": "16.40234",
    "lng": "-97.80823"
  },
  {
    "country": "MX",
    "name": "Chapultenango",
    "lat": "17.34114",
    "lng": "-93.1303"
  },
  {
    "country": "MX",
    "name": "Chapulhuacán",
    "lat": "21.15731",
    "lng": "-98.90361"
  },
  {
    "country": "MX",
    "name": "Chapa de Mota",
    "lat": "19.81406",
    "lng": "-99.52615"
  },
  {
    "country": "MX",
    "name": "Chanal",
    "lat": "16.71667",
    "lng": "-92.4"
  },
  {
    "country": "MX",
    "name": "Chamula",
    "lat": "16.78416",
    "lng": "-92.68959"
  },
  {
    "country": "MX",
    "name": "Champotón",
    "lat": "19.34745",
    "lng": "-90.72039"
  },
  {
    "country": "MX",
    "name": "Chalma",
    "lat": "21.20881",
    "lng": "-98.39799"
  },
  {
    "country": "MX",
    "name": "Chalco",
    "lat": "19.26174",
    "lng": "-98.89775"
  },
  {
    "country": "MX",
    "name": "Chahuite",
    "lat": "16.3",
    "lng": "-94.18333"
  },
  {
    "country": "MX",
    "name": "Chacaltianguis",
    "lat": "18.30528",
    "lng": "-95.84167"
  },
  {
    "country": "MX",
    "name": "Chacalapa",
    "lat": "18.0786",
    "lng": "-94.7028"
  },
  {
    "country": "MX",
    "name": "Cerro Gordo",
    "lat": "19.56951",
    "lng": "-96.64835"
  },
  {
    "country": "MX",
    "name": "Cerro Azul",
    "lat": "21.192",
    "lng": "-97.74088"
  },
  {
    "country": "MX",
    "name": "Ciudad Cerralvo",
    "lat": "26.08499",
    "lng": "-99.61508"
  },
  {
    "country": "MX",
    "name": "San Miguel Cerezo (El Cerezo)",
    "lat": "20.15909",
    "lng": "-98.72853"
  },
  {
    "country": "MX",
    "name": "Cepeda",
    "lat": "20.506",
    "lng": "-90.10979"
  },
  {
    "country": "MX",
    "name": "Cenotillo",
    "lat": "20.96621",
    "lng": "-88.60438"
  },
  {
    "country": "MX",
    "name": "Celestún",
    "lat": "20.85973",
    "lng": "-90.39902"
  },
  {
    "country": "MX",
    "name": "Cazones de Herrera",
    "lat": "20.70423",
    "lng": "-97.30994"
  },
  {
    "country": "MX",
    "name": "Caxhuacán",
    "lat": "20.06359",
    "lng": "-97.60688"
  },
  {
    "country": "MX",
    "name": "Caucel",
    "lat": "21.01539",
    "lng": "-89.70347"
  },
  {
    "country": "MX",
    "name": "Catemaco",
    "lat": "18.42131",
    "lng": "-95.11398"
  },
  {
    "country": "MX",
    "name": "Catazajá",
    "lat": "17.72392",
    "lng": "-92.01244"
  },
  {
    "country": "MX",
    "name": "Castillo de Teayo",
    "lat": "20.74927",
    "lng": "-97.6303"
  },
  {
    "country": "MX",
    "name": "Casas",
    "lat": "23.72686",
    "lng": "-98.73662"
  },
  {
    "country": "MX",
    "name": "Carlos A. Carrillo",
    "lat": "18.37477",
    "lng": "-95.75444"
  },
  {
    "country": "MX",
    "name": "Cárdenas",
    "lat": "22.00144",
    "lng": "-99.64247"
  },
  {
    "country": "MX",
    "name": "Cárdenas",
    "lat": "18.00135",
    "lng": "-93.37559"
  },
  {
    "country": "MX",
    "name": "Capulhuac de Mirafuentes",
    "lat": "19.19354",
    "lng": "-99.46585"
  },
  {
    "country": "MX",
    "name": "Cansahcab",
    "lat": "21.15749",
    "lng": "-89.10131"
  },
  {
    "country": "MX",
    "name": "Candelaria Loxicha",
    "lat": "15.92638",
    "lng": "-96.49268"
  },
  {
    "country": "MX",
    "name": "Cancún",
    "lat": "21.17429",
    "lng": "-86.84656"
  },
  {
    "country": "MX",
    "name": "Cancuc",
    "lat": "16.91667",
    "lng": "-92.48333"
  },
  {
    "country": "MX",
    "name": "Campeche",
    "lat": "19.84386",
    "lng": "-90.52554"
  },
  {
    "country": "MX",
    "name": "Camargo",
    "lat": "26.25457",
    "lng": "-98.84353"
  },
  {
    "country": "MX",
    "name": "San Martín Caltenco",
    "lat": "18.88487",
    "lng": "-97.81887"
  },
  {
    "country": "MX",
    "name": "Calpulalpan",
    "lat": "19.58867",
    "lng": "-98.56972"
  },
  {
    "country": "MX",
    "name": "Calotmul",
    "lat": "21.0205",
    "lng": "-88.17723"
  },
  {
    "country": "MX",
    "name": "Calnali",
    "lat": "20.89687",
    "lng": "-98.58511"
  },
  {
    "country": "MX",
    "name": "Calmeca",
    "lat": "18.63501",
    "lng": "-98.63414"
  },
  {
    "country": "MX",
    "name": "Calkiní",
    "lat": "20.36905",
    "lng": "-90.05119"
  },
  {
    "country": "MX",
    "name": "Calixtlahuaca",
    "lat": "19.33651",
    "lng": "-99.68923"
  },
  {
    "country": "MX",
    "name": "Calimaya",
    "lat": "19.16324",
    "lng": "-99.6181"
  },
  {
    "country": "MX",
    "name": "Calihualá",
    "lat": "17.53134",
    "lng": "-98.27792"
  },
  {
    "country": "MX",
    "name": "Calderitas",
    "lat": "18.55564",
    "lng": "-88.25518"
  },
  {
    "country": "MX",
    "name": "Calcahualco",
    "lat": "19.12243",
    "lng": "-97.08556"
  },
  {
    "country": "MX",
    "name": "Cadereyta Jiménez",
    "lat": "25.58896",
    "lng": "-100.00156"
  },
  {
    "country": "MX",
    "name": "Cadereyta",
    "lat": "20.69701",
    "lng": "-99.81624"
  },
  {
    "country": "MX",
    "name": "Cadereyta",
    "lat": "25.58333",
    "lng": "-99.98333"
  },
  {
    "country": "MX",
    "name": "San Lorenzo Cacaotepec",
    "lat": "17.12774",
    "lng": "-96.80244"
  },
  {
    "country": "MX",
    "name": "Santiago Cacaloxtepec",
    "lat": "17.72158",
    "lng": "-97.74044"
  },
  {
    "country": "MX",
    "name": "Cacalotenango",
    "lat": "18.54639",
    "lng": "-99.64361"
  },
  {
    "country": "MX",
    "name": "Cacaloxúchitl",
    "lat": "18.78747",
    "lng": "-98.48614"
  },
  {
    "country": "MX",
    "name": "Cacalomacan",
    "lat": "19.25311",
    "lng": "-99.70623"
  },
  {
    "country": "MX",
    "name": "Cacalchen",
    "lat": "20.98358",
    "lng": "-89.22686"
  },
  {
    "country": "MX",
    "name": "Cacahoatán",
    "lat": "14.99201",
    "lng": "-92.16376"
  },
  {
    "country": "MX",
    "name": "Bustamante",
    "lat": "23.43524",
    "lng": "-99.75875"
  },
  {
    "country": "MX",
    "name": "Burgos",
    "lat": "24.94722",
    "lng": "-98.79921"
  },
  {
    "country": "MX",
    "name": "Buenavista de Cuéllar",
    "lat": "18.45958",
    "lng": "-99.40868"
  },
  {
    "country": "MX",
    "name": "Buena Vista",
    "lat": "19.04278",
    "lng": "-96.85667"
  },
  {
    "country": "MX",
    "name": "Buenavista",
    "lat": "17.91667",
    "lng": "-92.53333"
  },
  {
    "country": "MX",
    "name": "Buctzotz",
    "lat": "21.20303",
    "lng": "-88.79271"
  },
  {
    "country": "MX",
    "name": "Bochil",
    "lat": "16.99625",
    "lng": "-92.89218"
  },
  {
    "country": "MX",
    "name": "Miguel Bocanegra",
    "lat": "19.84574",
    "lng": "-99.11193"
  },
  {
    "country": "MX",
    "name": "Boca del Rio",
    "lat": "19.10464",
    "lng": "-96.10405"
  },
  {
    "country": "MX",
    "name": "Boca del Monte",
    "lat": "19.15451",
    "lng": "-96.8327"
  },
  {
    "country": "MX",
    "name": "Blasillo 1ra. Sección (Nicolás Bravo)",
    "lat": "18.07861",
    "lng": "-93.91833"
  },
  {
    "country": "MX",
    "name": "San Melchor Betaza",
    "lat": "17.25267",
    "lng": "-96.15284"
  },
  {
    "country": "MX",
    "name": "Berriozábal",
    "lat": "16.79853",
    "lng": "-93.27163"
  },
  {
    "country": "MX",
    "name": "Benito Juárez",
    "lat": "20.88635",
    "lng": "-98.20594"
  },
  {
    "country": "MX",
    "name": "Benito Juárez",
    "lat": "19.81654",
    "lng": "-97.79108"
  },
  {
    "country": "MX",
    "name": "Benito Juárez",
    "lat": "19.37391",
    "lng": "-97.909"
  },
  {
    "country": "MX",
    "name": "Bella Vista",
    "lat": "15.58359",
    "lng": "-92.24683"
  },
  {
    "country": "MX",
    "name": "Belén",
    "lat": "17.78907",
    "lng": "-92.61137"
  },
  {
    "country": "MX",
    "name": "Bejucal de Ocampo",
    "lat": "15.45535",
    "lng": "-92.15835"
  },
  {
    "country": "MX",
    "name": "Bécal",
    "lat": "20.44172",
    "lng": "-90.02738"
  },
  {
    "country": "MX",
    "name": "Banderilla",
    "lat": "19.58893",
    "lng": "-96.93727"
  },
  {
    "country": "MX",
    "name": "Nuevo Balsas",
    "lat": "18.03253",
    "lng": "-99.75913"
  },
  {
    "country": "MX",
    "name": "Balancán",
    "lat": "17.80903",
    "lng": "-91.53682"
  },
  {
    "country": "MX",
    "name": "Bajos del Ejido",
    "lat": "16.96086",
    "lng": "-99.97169"
  },
  {
    "country": "MX",
    "name": "Bacalar",
    "lat": "18.68109",
    "lng": "-88.39333"
  },
  {
    "country": "MX",
    "name": "Baca",
    "lat": "21.10874",
    "lng": "-89.39866"
  },
  {
    "country": "MX",
    "name": "Azoyú",
    "lat": "16.73314",
    "lng": "-98.60166"
  },
  {
    "country": "MX",
    "name": "Azcapotzalco",
    "lat": "19.48698",
    "lng": "-99.18594"
  },
  {
    "country": "MX",
    "name": "Ayutla de los Libres",
    "lat": "16.96376",
    "lng": "-99.09616"
  },
  {
    "country": "MX",
    "name": "Ayutla",
    "lat": "18.54503",
    "lng": "-98.50537"
  },
  {
    "country": "MX",
    "name": "Ayotzintepec",
    "lat": "17.67261",
    "lng": "-96.12855"
  },
  {
    "country": "MX",
    "name": "Ayotoxco de Guerrero",
    "lat": "20.09589",
    "lng": "-97.40961"
  },
  {
    "country": "MX",
    "name": "Ayometitla",
    "lat": "19.20722",
    "lng": "-98.19306"
  },
  {
    "country": "MX",
    "name": "Ayapango",
    "lat": "19.12692",
    "lng": "-98.79988"
  },
  {
    "country": "MX",
    "name": "Ayapa",
    "lat": "18.2241",
    "lng": "-93.11158"
  },
  {
    "country": "MX",
    "name": "Ciudad Ayala",
    "lat": "18.76694",
    "lng": "-98.98222"
  },
  {
    "country": "MX",
    "name": "Ayahualulco",
    "lat": "19.35113",
    "lng": "-97.14874"
  },
  {
    "country": "MX",
    "name": "Axutla",
    "lat": "18.18938",
    "lng": "-98.38935"
  },
  {
    "country": "MX",
    "name": "San Miguel Axoxuca",
    "lat": "17.5493",
    "lng": "-98.66163"
  },
  {
    "country": "MX",
    "name": "Axochiapan",
    "lat": "18.50246",
    "lng": "-98.75358"
  },
  {
    "country": "MX",
    "name": "Axixintla",
    "lat": "18.60222",
    "lng": "-99.51806"
  },
  {
    "country": "MX",
    "name": "Axapusco",
    "lat": "19.72456",
    "lng": "-98.75863"
  },
  {
    "country": "MX",
    "name": "Soledad Atzompa",
    "lat": "18.75499",
    "lng": "-97.1504"
  },
  {
    "country": "MX",
    "name": "Atzitzintla",
    "lat": "18.89915",
    "lng": "-97.3244"
  },
  {
    "country": "MX",
    "name": "Atzalan",
    "lat": "19.78864",
    "lng": "-97.24195"
  },
  {
    "country": "MX",
    "name": "Atzala",
    "lat": "18.54639",
    "lng": "-98.55306"
  },
  {
    "country": "MX",
    "name": "Atzacan",
    "lat": "18.90724",
    "lng": "-97.08307"
  },
  {
    "country": "MX",
    "name": "Atoyatempan",
    "lat": "18.81925",
    "lng": "-97.9139"
  },
  {
    "country": "MX",
    "name": "Atotonilco el Grande",
    "lat": "20.28632",
    "lng": "-98.6685"
  },
  {
    "country": "MX",
    "name": "Atlzayanca",
    "lat": "19.43111",
    "lng": "-97.79556"
  },
  {
    "country": "MX",
    "name": "Atlixtac",
    "lat": "17.56312",
    "lng": "-98.93415"
  },
  {
    "country": "MX",
    "name": "Atlixco",
    "lat": "18.90815",
    "lng": "-98.43613"
  },
  {
    "country": "MX",
    "name": "Atliaca",
    "lat": "17.65168",
    "lng": "-99.37471"
  },
  {
    "country": "MX",
    "name": "Atlequizayan",
    "lat": "20.01214",
    "lng": "-97.62423"
  },
  {
    "country": "MX",
    "name": "Atlautla",
    "lat": "19.02188",
    "lng": "-98.77859"
  },
  {
    "country": "MX",
    "name": "Atlatongo",
    "lat": "19.66776",
    "lng": "-98.90402"
  },
  {
    "country": "MX",
    "name": "Atlatlahucan",
    "lat": "18.93413",
    "lng": "-98.8982"
  },
  {
    "country": "MX",
    "name": "San Bartolomé Atlatlahuca",
    "lat": "19.06963",
    "lng": "-99.60981"
  },
  {
    "country": "MX",
    "name": "Atlahuilco",
    "lat": "18.69717",
    "lng": "-97.0916"
  },
  {
    "country": "MX",
    "name": "Atlacomulco de Fabela",
    "lat": "19.79919",
    "lng": "-99.875"
  },
  {
    "country": "MX",
    "name": "Ciudad López Mateos",
    "lat": "19.55793",
    "lng": "-99.25675"
  },
  {
    "country": "MX",
    "name": "Atizapán",
    "lat": "19.25",
    "lng": "-99.55"
  },
  {
    "country": "MX",
    "name": "Atitalaquia",
    "lat": "20.05964",
    "lng": "-99.22163"
  },
  {
    "country": "MX",
    "name": "Atengo",
    "lat": "20.17526",
    "lng": "-99.32714"
  },
  {
    "country": "MX",
    "name": "Atencingo",
    "lat": "18.51347",
    "lng": "-98.60542"
  },
  {
    "country": "MX",
    "name": "Atenango del Río",
    "lat": "18.10526",
    "lng": "-99.10777"
  },
  {
    "country": "MX",
    "name": "Atempan",
    "lat": "19.83945",
    "lng": "-97.45855"
  },
  {
    "country": "MX",
    "name": "Asunción Tlacolulita",
    "lat": "16.29942",
    "lng": "-95.72668"
  },
  {
    "country": "MX",
    "name": "Asunción Ocotlán",
    "lat": "16.76195",
    "lng": "-96.72137"
  },
  {
    "country": "MX",
    "name": "Asunción Nochixtlán",
    "lat": "17.45916",
    "lng": "-97.22605"
  },
  {
    "country": "MX",
    "name": "Asunción Ixtaltepec",
    "lat": "16.50315",
    "lng": "-95.06121"
  },
  {
    "country": "MX",
    "name": "Astacinga",
    "lat": "18.569",
    "lng": "-97.10376"
  },
  {
    "country": "MX",
    "name": "Arroyo Seco",
    "lat": "21.54777",
    "lng": "-99.68832"
  },
  {
    "country": "MX",
    "name": "Aramberri",
    "lat": "24.09984",
    "lng": "-99.81729"
  },
  {
    "country": "MX",
    "name": "Aquixtla",
    "lat": "19.79582",
    "lng": "-97.93553"
  },
  {
    "country": "MX",
    "name": "Aquismón",
    "lat": "21.62159",
    "lng": "-99.01984"
  },
  {
    "country": "MX",
    "name": "Aquiles Serdán",
    "lat": "17.78333",
    "lng": "-92.28333"
  },
  {
    "country": "MX",
    "name": "Aquila",
    "lat": "18.79565",
    "lng": "-97.30845"
  },
  {
    "country": "MX",
    "name": "Apizaco",
    "lat": "19.41333",
    "lng": "-98.14358"
  },
  {
    "country": "MX",
    "name": "Apazapan",
    "lat": "19.32072",
    "lng": "-96.71874"
  },
  {
    "country": "MX",
    "name": "Apaxtla de Castrejón",
    "lat": "18.13127",
    "lng": "-99.93255"
  },
  {
    "country": "MX",
    "name": "Apaxco de Ocampo",
    "lat": "19.97512",
    "lng": "-99.17112"
  },
  {
    "country": "MX",
    "name": "San Pedro Apatlaco",
    "lat": "18.79306",
    "lng": "-98.95972"
  },
  {
    "country": "MX",
    "name": "Apango",
    "lat": "17.74121",
    "lng": "-99.32909"
  },
  {
    "country": "MX",
    "name": "Apan",
    "lat": "19.71128",
    "lng": "-98.45086"
  },
  {
    "country": "MX",
    "name": "Antón Lizardo",
    "lat": "19.05962",
    "lng": "-95.99272"
  },
  {
    "country": "MX",
    "name": "Antiguo Morelos",
    "lat": "22.5495",
    "lng": "-99.08123"
  },
  {
    "country": "MX",
    "name": "Ángel R. Cabada",
    "lat": "18.59601",
    "lng": "-95.4458"
  },
  {
    "country": "MX",
    "name": "Jaltenango de la Paz",
    "lat": "15.87314",
    "lng": "-92.72437"
  },
  {
    "country": "MX",
    "name": "Anenecuilco",
    "lat": "18.77738",
    "lng": "-98.98907"
  },
  {
    "country": "MX",
    "name": "Anahuac",
    "lat": "22.20275",
    "lng": "-97.85506"
  },
  {
    "country": "MX",
    "name": "San Pedro Amuzgos",
    "lat": "16.65388",
    "lng": "-98.09175"
  },
  {
    "country": "MX",
    "name": "Amozoc de Mota",
    "lat": "19.04611",
    "lng": "-98.045"
  },
  {
    "country": "MX",
    "name": "San Miguel Ameyalco",
    "lat": "19.30681",
    "lng": "-99.4588"
  },
  {
    "country": "MX",
    "name": "Ameluca",
    "lat": "20.56344",
    "lng": "-97.82571"
  },
  {
    "country": "MX",
    "name": "Amecameca",
    "lat": "19.12384",
    "lng": "-98.76649"
  },
  {
    "country": "MX",
    "name": "Amayuca",
    "lat": "18.72408",
    "lng": "-98.79812"
  },
  {
    "country": "MX",
    "name": "Amatlán de los Reyes",
    "lat": "18.84658",
    "lng": "-96.91595"
  },
  {
    "country": "MX",
    "name": "Amatitlán",
    "lat": "18.43158",
    "lng": "-95.73319"
  },
  {
    "country": "MX",
    "name": "Amatenango del Valle",
    "lat": "16.52722",
    "lng": "-92.43472"
  },
  {
    "country": "MX",
    "name": "Amatenango de la Frontera",
    "lat": "15.43438",
    "lng": "-92.1157"
  },
  {
    "country": "MX",
    "name": "Amatán",
    "lat": "17.37429",
    "lng": "-92.81893"
  },
  {
    "country": "MX",
    "name": "Amacuzac",
    "lat": "18.59861",
    "lng": "-99.36944"
  },
  {
    "country": "MX",
    "name": "Álvaro Obregón",
    "lat": "14.92231",
    "lng": "-92.37813"
  },
  {
    "country": "MX",
    "name": "Alvarado",
    "lat": "18.77143",
    "lng": "-95.76181"
  },
  {
    "country": "MX",
    "name": "Altotonga",
    "lat": "19.76613",
    "lng": "-97.24514"
  },
  {
    "country": "MX",
    "name": "Alto Lucero",
    "lat": "19.62442",
    "lng": "-96.73409"
  },
  {
    "country": "MX",
    "name": "Altepexi",
    "lat": "18.37035",
    "lng": "-97.29966"
  },
  {
    "country": "MX",
    "name": "Altamirano",
    "lat": "16.88333",
    "lng": "-92.15"
  },
  {
    "country": "MX",
    "name": "Altamira",
    "lat": "22.39215",
    "lng": "-97.93867"
  },
  {
    "country": "MX",
    "name": "Alpuyeca",
    "lat": "18.74006",
    "lng": "-99.25937"
  },
  {
    "country": "MX",
    "name": "Alpoyeca",
    "lat": "17.67041",
    "lng": "-98.50974"
  },
  {
    "country": "MX",
    "name": "Alpatláhuac",
    "lat": "19.12015",
    "lng": "-97.09367"
  },
  {
    "country": "MX",
    "name": "San Antonio Alpanocan",
    "lat": "18.87722",
    "lng": "-98.71083"
  },
  {
    "country": "MX",
    "name": "Villa de Almoloya de Juárez",
    "lat": "19.36915",
    "lng": "-99.75836"
  },
  {
    "country": "MX",
    "name": "Almoloya de Alquisiras",
    "lat": "18.86564",
    "lng": "-99.89452"
  },
  {
    "country": "MX",
    "name": "Almoloya",
    "lat": "19.70435",
    "lng": "-98.40379"
  },
  {
    "country": "MX",
    "name": "Almoloya del Río",
    "lat": "19.16046",
    "lng": "-99.4874"
  },
  {
    "country": "MX",
    "name": "San Miguel Almaya",
    "lat": "19.21047",
    "lng": "-99.44195"
  },
  {
    "country": "MX",
    "name": "Ignacio Allende",
    "lat": "18.38299",
    "lng": "-92.84418"
  },
  {
    "country": "MX",
    "name": "Allende",
    "lat": "18.15514",
    "lng": "-94.39289"
  },
  {
    "country": "MX",
    "name": "Aljojuca",
    "lat": "19.09933",
    "lng": "-97.52973"
  },
  {
    "country": "MX",
    "name": "Axtla de Terrazas",
    "lat": "21.43923",
    "lng": "-98.87508"
  },
  {
    "country": "MX",
    "name": "Aldama",
    "lat": "22.92157",
    "lng": "-98.07519"
  },
  {
    "country": "MX",
    "name": "Alcozauca de Guerrero",
    "lat": "17.46481",
    "lng": "-98.38428"
  },
  {
    "country": "MX",
    "name": "Alaquines",
    "lat": "22.12973",
    "lng": "-99.60093"
  },
  {
    "country": "MX",
    "name": "Álamo",
    "lat": "20.91154",
    "lng": "-97.67554"
  },
  {
    "country": "MX",
    "name": "Akil",
    "lat": "20.26547",
    "lng": "-89.34787"
  },
  {
    "country": "MX",
    "name": "Ajalpan",
    "lat": "18.37908",
    "lng": "-97.25867"
  },
  {
    "country": "MX",
    "name": "Ahuehuetzingo",
    "lat": "18.68024",
    "lng": "-99.30834"
  },
  {
    "country": "MX",
    "name": "Ahuazotepec",
    "lat": "20.04535",
    "lng": "-98.16332"
  },
  {
    "country": "MX",
    "name": "Ahuatlán",
    "lat": "18.57276",
    "lng": "-98.25692"
  },
  {
    "country": "MX",
    "name": "Lomas de Ahuatepec",
    "lat": "18.97139",
    "lng": "-99.18972"
  },
  {
    "country": "MX",
    "name": "Ahuacuotzingo",
    "lat": "17.71431",
    "lng": "-98.93492"
  },
  {
    "country": "MX",
    "name": "Ahuacatitlán Cuarto y Quinto Cuartel",
    "lat": "19.96222",
    "lng": "-99.98694"
  },
  {
    "country": "MX",
    "name": "Agualeguas",
    "lat": "26.31362",
    "lng": "-99.53728"
  },
  {
    "country": "MX",
    "name": "Agua Dulce",
    "lat": "20.36337",
    "lng": "-97.29315"
  },
  {
    "country": "MX",
    "name": "Agua Dulce",
    "lat": "18.13909",
    "lng": "-94.14527"
  },
  {
    "country": "MX",
    "name": "Acultzingo",
    "lat": "18.71894",
    "lng": "-97.30367"
  },
  {
    "country": "MX",
    "name": "Aculco de Espinoza",
    "lat": "20.09867",
    "lng": "-99.82757"
  },
  {
    "country": "MX",
    "name": "Acula",
    "lat": "18.50563",
    "lng": "-95.77427"
  },
  {
    "country": "MX",
    "name": "Actopan",
    "lat": "20.26961",
    "lng": "-98.94377"
  },
  {
    "country": "MX",
    "name": "Actopan",
    "lat": "19.50427",
    "lng": "-96.61668"
  },
  {
    "country": "MX",
    "name": "Altzayanca",
    "lat": "19.43121",
    "lng": "-97.79555"
  },
  {
    "country": "MX",
    "name": "Acteopan",
    "lat": "18.76388",
    "lng": "-98.71366"
  },
  {
    "country": "MX",
    "name": "Acoyotla",
    "lat": "21.12551",
    "lng": "-98.77729"
  },
  {
    "country": "MX",
    "name": "Achichipico",
    "lat": "18.94861",
    "lng": "-98.82611"
  },
  {
    "country": "MX",
    "name": "San Jerónimo Acazulco",
    "lat": "19.26563",
    "lng": "-99.41629"
  },
  {
    "country": "MX",
    "name": "Acayucan",
    "lat": "17.94979",
    "lng": "-94.91386"
  },
  {
    "country": "MX",
    "name": "Acayuca",
    "lat": "20.02567",
    "lng": "-98.8411"
  },
  {
    "country": "MX",
    "name": "Acaxtlahuacán de Albino Zertuche",
    "lat": "18.01714",
    "lng": "-98.54018"
  },
  {
    "country": "MX",
    "name": "Acaxochitlán",
    "lat": "20.15789",
    "lng": "-98.20172"
  },
  {
    "country": "MX",
    "name": "Acatzingo",
    "lat": "18.98196",
    "lng": "-97.78363"
  },
  {
    "country": "MX",
    "name": "Acatlán de Pérez Figueroa",
    "lat": "18.53973",
    "lng": "-96.60568"
  },
  {
    "country": "MX",
    "name": "Acatlán de Osorio",
    "lat": "18.2025",
    "lng": "-98.04864"
  },
  {
    "country": "MX",
    "name": "Acatlán",
    "lat": "20.14562",
    "lng": "-98.43959"
  },
  {
    "country": "MX",
    "name": "Acatlán",
    "lat": "19.69677",
    "lng": "-96.84216"
  },
  {
    "country": "MX",
    "name": "Acatepec",
    "lat": "16.7375",
    "lng": "-98.4275"
  },
  {
    "country": "MX",
    "name": "Acatempan",
    "lat": "18.31809",
    "lng": "-99.88298"
  },
  {
    "country": "MX",
    "name": "Acapulco de Juárez",
    "lat": "16.84942",
    "lng": "-99.90891"
  },
  {
    "country": "MX",
    "name": "Acapetahua",
    "lat": "15.28189",
    "lng": "-92.68987"
  },
  {
    "country": "MX",
    "name": "Acanceh",
    "lat": "20.81269",
    "lng": "-89.45295"
  },
  {
    "country": "MX",
    "name": "Acamixtla",
    "lat": "18.56512",
    "lng": "-99.56599"
  },
  {
    "country": "MX",
    "name": "Acambay",
    "lat": "19.95522",
    "lng": "-99.84428"
  },
  {
    "country": "MX",
    "name": "Acala",
    "lat": "16.55625",
    "lng": "-92.80449"
  },
  {
    "country": "MX",
    "name": "Acajete",
    "lat": "19.58646",
    "lng": "-97.00995"
  },
  {
    "country": "MX",
    "name": "Acajete",
    "lat": "19.11154",
    "lng": "-97.95231"
  },
  {
    "country": "MX",
    "name": "Acahuizotla",
    "lat": "17.36054",
    "lng": "-99.46759"
  },
  {
    "country": "MX",
    "name": "San Antonio Acahualco",
    "lat": "19.274",
    "lng": "-99.77169"
  },
  {
    "country": "MX",
    "name": "Acacoyagua",
    "lat": "15.34054",
    "lng": "-92.67519"
  },
  {
    "country": "MX",
    "name": "Abasolo del Valle",
    "lat": "17.78306",
    "lng": "-95.54556"
  },
  {
    "country": "MX",
    "name": "Abasolo",
    "lat": "24.05844",
    "lng": "-98.37333"
  },
  {
    "country": "MX",
    "name": "Talismán",
    "lat": "14.96333",
    "lng": "-92.14722"
  },
  {
    "country": "MX",
    "name": "San Nicolás Tecomatlán",
    "lat": "20.17944",
    "lng": "-99.03639"
  },
  {
    "country": "MX",
    "name": "Ajacuba",
    "lat": "20.0917",
    "lng": "-99.12246"
  },
  {
    "country": "MX",
    "name": "San Pablo de los Remedios",
    "lat": "19.64111",
    "lng": "-99.83833"
  },
  {
    "country": "MX",
    "name": "Miraflores",
    "lat": "19.2221",
    "lng": "-98.80741"
  },
  {
    "country": "MX",
    "name": "San Miguel Tecomatlán",
    "lat": "18.97833",
    "lng": "-99.52861"
  },
  {
    "country": "MX",
    "name": "Higuerón",
    "lat": "18.5775",
    "lng": "-99.18056"
  },
  {
    "country": "MX",
    "name": "Cuauhtempan (San Andrés Cuauhtempan)",
    "lat": "18.97472",
    "lng": "-98.94639"
  },
  {
    "country": "MX",
    "name": "Tlaltetelco (San Miguel Tlaltetelco)",
    "lat": "18.95222",
    "lng": "-98.88806"
  },
  {
    "country": "MX",
    "name": "Huecahuasco",
    "lat": "18.93694",
    "lng": "-98.7825"
  },
  {
    "country": "MX",
    "name": "Santiago Tlacotepec",
    "lat": "19.22708",
    "lng": "-99.67083"
  },
  {
    "country": "MX",
    "name": "San José Río Manzo",
    "lat": "17.67003",
    "lng": "-95.88012"
  },
  {
    "country": "MX",
    "name": "San Juan del Río",
    "lat": "17.49278",
    "lng": "-95.76028"
  },
  {
    "country": "MX",
    "name": "Santa María Temaxcalapa",
    "lat": "17.38036",
    "lng": "-96.16137"
  },
  {
    "country": "MX",
    "name": "Yucuita",
    "lat": "17.51073",
    "lng": "-97.26965"
  },
  {
    "country": "MX",
    "name": "Santa María Puxmetacán",
    "lat": "17.26861",
    "lng": "-95.62333"
  },
  {
    "country": "MX",
    "name": "Santiago Malacatepec",
    "lat": "17.01639",
    "lng": "-95.6075"
  },
  {
    "country": "MX",
    "name": "San Antonio de la Cal",
    "lat": "17.02833",
    "lng": "-96.70056"
  },
  {
    "country": "MX",
    "name": "San Agustin de las Juntas",
    "lat": "17.00389",
    "lng": "-96.70806"
  },
  {
    "country": "MX",
    "name": "Magdalena Apasco",
    "lat": "17.24083",
    "lng": "-96.82083"
  },
  {
    "country": "MX",
    "name": "San Miguel Tecomatlán",
    "lat": "17.39454",
    "lng": "-97.26845"
  },
  {
    "country": "MX",
    "name": "Congregación Calles",
    "lat": "25.22528",
    "lng": "-99.93472"
  },
  {
    "country": "MX",
    "name": "Hidalgo",
    "lat": "25.8579",
    "lng": "-99.61898"
  },
  {
    "country": "MX",
    "name": "Atarjea",
    "lat": "21.26777",
    "lng": "-99.71914"
  },
  {
    "country": "MX",
    "name": "Santa Rosa",
    "lat": "16.31655",
    "lng": "-95.09944"
  },
  {
    "country": "MX",
    "name": "Lázaro Cárdenas",
    "lat": "16.72818",
    "lng": "-94.85981"
  },
  {
    "country": "MX",
    "name": "El Bajío",
    "lat": "16.88917",
    "lng": "-95.03528"
  },
  {
    "country": "MX",
    "name": "San Nicolás",
    "lat": "16.4201",
    "lng": "-96.74133"
  },
  {
    "country": "MX",
    "name": "El Arador",
    "lat": "16.54111",
    "lng": "-97.18194"
  },
  {
    "country": "MX",
    "name": "San Juan Colorado",
    "lat": "16.46066",
    "lng": "-97.95431"
  },
  {
    "country": "MX",
    "name": "San Juan Jicayán",
    "lat": "16.47583",
    "lng": "-98.0125"
  },
  {
    "country": "MX",
    "name": "Santiago Llano Grande",
    "lat": "16.48833",
    "lng": "-98.28972"
  },
  {
    "country": "MX",
    "name": "Santo Domingo Armenta",
    "lat": "16.33194",
    "lng": "-98.37778"
  },
  {
    "country": "MX",
    "name": "José María Morelos",
    "lat": "16.20389",
    "lng": "-97.93"
  },
  {
    "country": "MX",
    "name": "Santiago Tetepec",
    "lat": "16.32172",
    "lng": "-97.74794"
  },
  {
    "country": "MX",
    "name": "Tataltepec de Valdés",
    "lat": "16.30549",
    "lng": "-97.54615"
  },
  {
    "country": "MX",
    "name": "San Cristóbal Honduras",
    "lat": "16.32528",
    "lng": "-97.04111"
  },
  {
    "country": "MX",
    "name": "Sitio de Xitlapehua",
    "lat": "16.35139",
    "lng": "-96.53215"
  },
  {
    "country": "MX",
    "name": "Santos Reyes Nopala",
    "lat": "16.10694",
    "lng": "-97.14435"
  },
  {
    "country": "MX",
    "name": "Santo Domingo de Morelos",
    "lat": "15.83397",
    "lng": "-96.66695"
  },
  {
    "country": "MX",
    "name": "San Miguel Figueroa",
    "lat": "15.78639",
    "lng": "-96.40417"
  },
  {
    "country": "MX",
    "name": "San Pablo Cuatro Venados",
    "lat": "16.9812",
    "lng": "-96.89103"
  },
  {
    "country": "MX",
    "name": "San Antonio Huitepec",
    "lat": "16.92667",
    "lng": "-97.14694"
  },
  {
    "country": "MX",
    "name": "San Miguel Mixtepec",
    "lat": "16.77719",
    "lng": "-96.95726"
  },
  {
    "country": "MX",
    "name": "Santiago Textitlán",
    "lat": "16.69264",
    "lng": "-97.25884"
  },
  {
    "country": "MX",
    "name": "Santa María Lachixío",
    "lat": "16.72694",
    "lng": "-97.01889"
  },
  {
    "country": "MX",
    "name": "Teojomulco",
    "lat": "16.59032",
    "lng": "-97.22493"
  },
  {
    "country": "MX",
    "name": "Santa María Yucuhiti",
    "lat": "17.01873",
    "lng": "-97.76951"
  },
  {
    "country": "MX",
    "name": "El Jicaral",
    "lat": "17.12617",
    "lng": "-98.19697"
  },
  {
    "country": "MX",
    "name": "San Juan Ñumí",
    "lat": "17.39734",
    "lng": "-97.70624"
  },
  {
    "country": "MX",
    "name": "Santa María del Rosario",
    "lat": "17.35276",
    "lng": "-97.5948"
  },
  {
    "country": "MX",
    "name": "Santiago Tilantongo",
    "lat": "17.28464",
    "lng": "-97.33879"
  },
  {
    "country": "MX",
    "name": "Santiago Tenango",
    "lat": "17.32489",
    "lng": "-97.00467"
  },
  {
    "country": "MX",
    "name": "San Pedro Coxcaltepec Cántaros",
    "lat": "17.49933",
    "lng": "-97.13802"
  },
  {
    "country": "MX",
    "name": "Magdalena Zahuatlán",
    "lat": "17.38978",
    "lng": "-97.22747"
  },
  {
    "country": "MX",
    "name": "San Francisco Jaltepetongo",
    "lat": "17.38579",
    "lng": "-97.26481"
  },
  {
    "country": "MX",
    "name": "San Francisco Nuxaño",
    "lat": "17.38173",
    "lng": "-97.34262"
  },
  {
    "country": "MX",
    "name": "San Mateo Etlatongo",
    "lat": "17.41609",
    "lng": "-97.27389"
  },
  {
    "country": "MX",
    "name": "San Juan Sayultepec",
    "lat": "17.45306",
    "lng": "-97.28481"
  },
  {
    "country": "MX",
    "name": "San Vicente Nuñu",
    "lat": "17.45648",
    "lng": "-97.44319"
  },
  {
    "country": "MX",
    "name": "Santiago Yolomécatl",
    "lat": "17.47237",
    "lng": "-97.56981"
  },
  {
    "country": "MX",
    "name": "San Miguel Tlacotepec",
    "lat": "17.45621",
    "lng": "-98.00547"
  },
  {
    "country": "MX",
    "name": "Silacayoápam",
    "lat": "17.50297",
    "lng": "-98.13966"
  },
  {
    "country": "MX",
    "name": "Ixpantepec Nieves",
    "lat": "17.5069",
    "lng": "-98.04264"
  },
  {
    "country": "MX",
    "name": "San Sebastián Nicananduta",
    "lat": "17.51828",
    "lng": "-97.6835"
  },
  {
    "country": "MX",
    "name": "Chicahua",
    "lat": "17.63667",
    "lng": "-97.19497"
  },
  {
    "country": "MX",
    "name": "Santo Domingo Yodohino",
    "lat": "17.61694",
    "lng": "-97.68289"
  },
  {
    "country": "MX",
    "name": "Santa Cruz de Bravo",
    "lat": "17.58096",
    "lng": "-98.22378"
  },
  {
    "country": "MX",
    "name": "Ahuehuetitlán",
    "lat": "17.6713",
    "lng": "-98.32024"
  },
  {
    "country": "MX",
    "name": "Tamazola",
    "lat": "17.6702",
    "lng": "-98.22084"
  },
  {
    "country": "MX",
    "name": "San Lorenzo",
    "lat": "17.66867",
    "lng": "-98.11986"
  },
  {
    "country": "MX",
    "name": "San Jorge Nuchita",
    "lat": "17.65669",
    "lng": "-98.10383"
  },
  {
    "country": "MX",
    "name": "San Agustín Atenango",
    "lat": "17.6115",
    "lng": "-98.01095"
  },
  {
    "country": "MX",
    "name": "Santo Domingo Tonalá",
    "lat": "17.67352",
    "lng": "-97.96556"
  },
  {
    "country": "MX",
    "name": "San Marcos Arteaga",
    "lat": "17.72238",
    "lng": "-97.86034"
  },
  {
    "country": "MX",
    "name": "San Andrés Dinicuiti",
    "lat": "17.68812",
    "lng": "-97.72669"
  },
  {
    "country": "MX",
    "name": "Tamazulapam Villa del Progreso",
    "lat": "17.6771",
    "lng": "-97.57315"
  },
  {
    "country": "MX",
    "name": "Texcatitlán",
    "lat": "17.71259",
    "lng": "-97.06625"
  },
  {
    "country": "MX",
    "name": "Mariscala de Juárez",
    "lat": "17.85972",
    "lng": "-98.14083"
  },
  {
    "country": "MX",
    "name": "San Lorenzo Vista Hermosa",
    "lat": "17.95888",
    "lng": "-98.06852"
  },
  {
    "country": "MX",
    "name": "Teotitlán",
    "lat": "18.13179",
    "lng": "-97.07056"
  },
  {
    "country": "MX",
    "name": "Chila",
    "lat": "17.96962",
    "lng": "-97.86072"
  },
  {
    "country": "MX",
    "name": "Cosoltepec",
    "lat": "18.14255",
    "lng": "-97.79084"
  },
  {
    "country": "MX",
    "name": "San Lucas Zoquiápam",
    "lat": "18.13669",
    "lng": "-96.90545"
  },
  {
    "country": "MX",
    "name": "San Pedro Ocopetatillo",
    "lat": "18.18638",
    "lng": "-96.91166"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Acatepec",
    "lat": "18.16369",
    "lng": "-96.87503"
  },
  {
    "country": "MX",
    "name": "Tezonapa",
    "lat": "18.60706",
    "lng": "-96.68417"
  },
  {
    "country": "MX",
    "name": "Piedra de Amolar",
    "lat": "18.12",
    "lng": "-96.45122"
  },
  {
    "country": "MX",
    "name": "Temascal",
    "lat": "18.24285",
    "lng": "-96.40165"
  },
  {
    "country": "MX",
    "name": "Isla Soyaltepec",
    "lat": "18.20107",
    "lng": "-96.48325"
  },
  {
    "country": "MX",
    "name": "Tetela",
    "lat": "18.50887",
    "lng": "-96.4588"
  },
  {
    "country": "MX",
    "name": "Tierra Blanca",
    "lat": "18.44771",
    "lng": "-96.35912"
  },
  {
    "country": "MX",
    "name": "Benemérito Juárez",
    "lat": "18.11944",
    "lng": "-96.00194"
  },
  {
    "country": "MX",
    "name": "Macín Chico",
    "lat": "18.0682",
    "lng": "-96.27184"
  },
  {
    "country": "MX",
    "name": "San Pedro Sochiápam",
    "lat": "17.82803",
    "lng": "-96.66274"
  },
  {
    "country": "MX",
    "name": "San Juan Petlapa",
    "lat": "17.46916",
    "lng": "-96.0361"
  },
  {
    "country": "MX",
    "name": "Santo Domingo Roayaga",
    "lat": "17.33782",
    "lng": "-96.11506"
  },
  {
    "country": "MX",
    "name": "San Juan Tabaá",
    "lat": "17.30495",
    "lng": "-96.20718"
  },
  {
    "country": "MX",
    "name": "Tamazulapam",
    "lat": "17.05485",
    "lng": "-96.06534"
  },
  {
    "country": "MX",
    "name": "San Felipe Cihualtepec",
    "lat": "17.47763",
    "lng": "-95.36767"
  },
  {
    "country": "MX",
    "name": "El Paraíso",
    "lat": "17.51592",
    "lng": "-95.14271"
  },
  {
    "country": "MX",
    "name": "Paso Real de Sarabia",
    "lat": "17.07389",
    "lng": "-95.04667"
  },
  {
    "country": "MX",
    "name": "Rojas de Cuauhtémoc",
    "lat": "17.00587",
    "lng": "-96.61919"
  },
  {
    "country": "MX",
    "name": "Guadalupe Etla",
    "lat": "17.17268",
    "lng": "-96.81022"
  },
  {
    "country": "MX",
    "name": "Santa Ana Zegache",
    "lat": "16.83706",
    "lng": "-96.72948"
  },
  {
    "country": "MX",
    "name": "San Bartolomé Quialana",
    "lat": "16.90302",
    "lng": "-96.50169"
  },
  {
    "country": "MX",
    "name": "San Antonino Castillo Velasco",
    "lat": "16.80143",
    "lng": "-96.68283"
  },
  {
    "country": "MX",
    "name": "Santa Inés Yatzeche",
    "lat": "16.80658",
    "lng": "-96.75719"
  },
  {
    "country": "MX",
    "name": "Santa María Coyotepec",
    "lat": "16.96663",
    "lng": "-96.70513"
  },
  {
    "country": "MX",
    "name": "Santa María Jalapa del Marqués",
    "lat": "16.44027",
    "lng": "-95.44454"
  },
  {
    "country": "MX",
    "name": "Guadalupe Victoria",
    "lat": "16.89627",
    "lng": "-95.84981"
  },
  {
    "country": "MX",
    "name": "San Lorenzo Albarradas",
    "lat": "16.91129",
    "lng": "-96.25826"
  },
  {
    "country": "MX",
    "name": "Santiago Xanica",
    "lat": "16.01009",
    "lng": "-96.22462"
  },
  {
    "country": "MX",
    "name": "El Coyul",
    "lat": "15.91472",
    "lng": "-95.81028"
  },
  {
    "country": "MX",
    "name": "La Erradura",
    "lat": "15.83402",
    "lng": "-96.33478"
  },
  {
    "country": "MX",
    "name": "Santa María Guelacé",
    "lat": "17.00119",
    "lng": "-96.60346"
  },
  {
    "country": "MX",
    "name": "La Pe",
    "lat": "16.63027",
    "lng": "-96.79766"
  },
  {
    "country": "MX",
    "name": "Taniche",
    "lat": "16.5686",
    "lng": "-96.75514"
  },
  {
    "country": "MX",
    "name": "La Blanca",
    "lat": "16.59482",
    "lng": "-94.69256"
  },
  {
    "country": "MX",
    "name": "San Blas Atempa",
    "lat": "16.33103",
    "lng": "-95.22559"
  },
  {
    "country": "MX",
    "name": "Occidente 4ta. Sección",
    "lat": "18.30347",
    "lng": "-93.23388"
  },
  {
    "country": "MX",
    "name": "Miguel Hidalgo",
    "lat": "18.25691",
    "lng": "-93.31073"
  },
  {
    "country": "MX",
    "name": "Aquiles Serdán",
    "lat": "18.4135",
    "lng": "-93.0134"
  },
  {
    "country": "MX",
    "name": "Oriente 1ra. Sección",
    "lat": "18.33889",
    "lng": "-93.20056"
  },
  {
    "country": "MX",
    "name": "Tecoluta 2da. Sección",
    "lat": "18.24408",
    "lng": "-93.01956"
  },
  {
    "country": "MX",
    "name": "Gobernador Cruz",
    "lat": "18.43364",
    "lng": "-92.8718"
  },
  {
    "country": "MX",
    "name": "Villa la Venta",
    "lat": "18.09863",
    "lng": "-94.04593"
  },
  {
    "country": "MX",
    "name": "Poblado C-11 José María Morelos y Pavón",
    "lat": "18.17419",
    "lng": "-93.62356"
  },
  {
    "country": "MX",
    "name": "El Tular",
    "lat": "18.15429",
    "lng": "-93.3382"
  },
  {
    "country": "MX",
    "name": "Cúlico 2da. Sección",
    "lat": "18.14116",
    "lng": "-93.13222"
  },
  {
    "country": "MX",
    "name": "Cumuapa 1ra. Sección",
    "lat": "17.98519",
    "lng": "-93.13806"
  },
  {
    "country": "MX",
    "name": "Saloya 2da. Sección",
    "lat": "18.05306",
    "lng": "-92.93639"
  },
  {
    "country": "MX",
    "name": "Tres Bocas 1ra. Sección",
    "lat": "17.93231",
    "lng": "-93.87444"
  },
  {
    "country": "MX",
    "name": "Huapacal 1ra. Sección",
    "lat": "17.92667",
    "lng": "-93.76639"
  },
  {
    "country": "MX",
    "name": "Paso de la Mina 3ra. Sección",
    "lat": "17.96335",
    "lng": "-93.66582"
  },
  {
    "country": "MX",
    "name": "Parilla",
    "lat": "17.91552",
    "lng": "-92.91612"
  },
  {
    "country": "MX",
    "name": "Río de Teapa",
    "lat": "17.78342",
    "lng": "-92.90033"
  },
  {
    "country": "MX",
    "name": "Aquiles Serdán 1ra. Sección",
    "lat": "17.82474",
    "lng": "-92.73977"
  },
  {
    "country": "MX",
    "name": "Jalapa",
    "lat": "17.72168",
    "lng": "-92.81272"
  },
  {
    "country": "MX",
    "name": "Palomas",
    "lat": "17.65466",
    "lng": "-92.478"
  },
  {
    "country": "MX",
    "name": "La Libertad",
    "lat": "17.6874",
    "lng": "-91.72071"
  },
  {
    "country": "MX",
    "name": "Libertad",
    "lat": "17.41027",
    "lng": "-92.71502"
  },
  {
    "country": "MX",
    "name": "Tepehuacán de Guerrero",
    "lat": "21.01361",
    "lng": "-98.84278"
  },
  {
    "country": "MX",
    "name": "Zacualtipanito",
    "lat": "21.15407",
    "lng": "-98.79997"
  },
  {
    "country": "MX",
    "name": "Chalahuiyapa",
    "lat": "21.15088",
    "lng": "-98.36429"
  },
  {
    "country": "MX",
    "name": "Tecacahuaco",
    "lat": "20.94133",
    "lng": "-98.33889"
  },
  {
    "country": "MX",
    "name": "Zoquitipán",
    "lat": "20.90902",
    "lng": "-98.43242"
  },
  {
    "country": "MX",
    "name": "Barrio Aztlán",
    "lat": "20.46562",
    "lng": "-98.08553"
  },
  {
    "country": "MX",
    "name": "Santa María Amajac",
    "lat": "20.32389",
    "lng": "-98.74222"
  },
  {
    "country": "MX",
    "name": "Pozuelos",
    "lat": "20.49333",
    "lng": "-99.05972"
  },
  {
    "country": "MX",
    "name": "Taxadho",
    "lat": "20.4333",
    "lng": "-99.14934"
  },
  {
    "country": "MX",
    "name": "El Nith",
    "lat": "20.48778",
    "lng": "-99.19194"
  },
  {
    "country": "MX",
    "name": "San Bartolo Ozocalpan",
    "lat": "20.22336",
    "lng": "-99.48906"
  },
  {
    "country": "MX",
    "name": "General Pedro María Anaya",
    "lat": "20.156",
    "lng": "-99.348"
  },
  {
    "country": "MX",
    "name": "Tenango",
    "lat": "20.22714",
    "lng": "-99.29068"
  },
  {
    "country": "MX",
    "name": "Presas",
    "lat": "20.15946",
    "lng": "-99.25242"
  },
  {
    "country": "MX",
    "name": "La Cruz",
    "lat": "20.17603",
    "lng": "-99.24156"
  },
  {
    "country": "MX",
    "name": "Ocampo",
    "lat": "20.00896",
    "lng": "-99.23926"
  },
  {
    "country": "MX",
    "name": "Munitepec de Madero",
    "lat": "20.12858",
    "lng": "-99.19948"
  },
  {
    "country": "MX",
    "name": "Colonia Teñhe",
    "lat": "20.19291",
    "lng": "-99.17866"
  },
  {
    "country": "MX",
    "name": "El Huixmí",
    "lat": "20.07569",
    "lng": "-98.81972"
  },
  {
    "country": "MX",
    "name": "Nuevo Centro de Población Agrícola el Chacón",
    "lat": "20.07028",
    "lng": "-98.73944"
  },
  {
    "country": "MX",
    "name": "Carboneras",
    "lat": "20.09",
    "lng": "-98.70528"
  },
  {
    "country": "MX",
    "name": "Camelia (Barrio la Camelia)",
    "lat": "20.14917",
    "lng": "-98.72222"
  },
  {
    "country": "MX",
    "name": "Ahuehuetitla",
    "lat": "20.08444",
    "lng": "-98.41667"
  },
  {
    "country": "MX",
    "name": "Santa María Nativitas",
    "lat": "20.03889",
    "lng": "-98.29639"
  },
  {
    "country": "MX",
    "name": "Vicente Guerrero (San Javier)",
    "lat": "19.94991",
    "lng": "-98.90135"
  },
  {
    "country": "MX",
    "name": "Emiliano Zapata",
    "lat": "19.55861",
    "lng": "-97.91667"
  },
  {
    "country": "MX",
    "name": "Lázaro Cárdenas",
    "lat": "19.5375",
    "lng": "-97.98222"
  },
  {
    "country": "MX",
    "name": "Atlangatepec",
    "lat": "19.5322",
    "lng": "-98.20888"
  },
  {
    "country": "MX",
    "name": "San José Tepeyahualco",
    "lat": "19.59944",
    "lng": "-98.26889"
  },
  {
    "country": "MX",
    "name": "Lagunilla",
    "lat": "19.63607",
    "lng": "-98.27434"
  },
  {
    "country": "MX",
    "name": "Benito Juárez",
    "lat": "19.5859",
    "lng": "-98.42827"
  },
  {
    "country": "MX",
    "name": "La Soledad",
    "lat": "19.53841",
    "lng": "-98.6175"
  },
  {
    "country": "MX",
    "name": "Muñoz",
    "lat": "19.47458",
    "lng": "-98.20963"
  },
  {
    "country": "MX",
    "name": "San José Teacalco",
    "lat": "19.33558",
    "lng": "-98.06455"
  },
  {
    "country": "MX",
    "name": "Colonia Venustiano Carranza",
    "lat": "19.40005",
    "lng": "-98.05822"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Pocitos",
    "lat": "19.37924",
    "lng": "-97.76116"
  },
  {
    "country": "MX",
    "name": "Villa de El Carmen Tequexquitla",
    "lat": "19.32426",
    "lng": "-97.6535"
  },
  {
    "country": "MX",
    "name": "Huamantla",
    "lat": "19.31451",
    "lng": "-97.9252"
  },
  {
    "country": "MX",
    "name": "Zitlaltépec",
    "lat": "19.20389",
    "lng": "-97.90722"
  },
  {
    "country": "MX",
    "name": "Colonia Cuauhtémoc",
    "lat": "19.33182",
    "lng": "-97.96487"
  },
  {
    "country": "MX",
    "name": "Tetlanohcán",
    "lat": "19.2603",
    "lng": "-98.16433"
  },
  {
    "country": "MX",
    "name": "Xicohtzinco",
    "lat": "19.17371",
    "lng": "-98.23377"
  },
  {
    "country": "MX",
    "name": "Concepción Chimalpa",
    "lat": "19.21639",
    "lng": "-98.19806"
  },
  {
    "country": "MX",
    "name": "Acuamanala",
    "lat": "19.22361",
    "lng": "-98.20056"
  },
  {
    "country": "MX",
    "name": "La Magdalena Tlaltelulco",
    "lat": "19.28287",
    "lng": "-98.19609"
  },
  {
    "country": "MX",
    "name": "Tepeyanco",
    "lat": "19.24558",
    "lng": "-98.23409"
  },
  {
    "country": "MX",
    "name": "San Jerónimo Zacualpan",
    "lat": "19.24083",
    "lng": "-98.26139"
  },
  {
    "country": "MX",
    "name": "San Juan Huactzinco",
    "lat": "19.23342",
    "lng": "-98.25259"
  },
  {
    "country": "MX",
    "name": "Zacatelco",
    "lat": "19.21583",
    "lng": "-98.23972"
  },
  {
    "country": "MX",
    "name": "Tetlatlahuca",
    "lat": "19.23232",
    "lng": "-98.29561"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Aquiahuac",
    "lat": "19.23944",
    "lng": "-98.28222"
  },
  {
    "country": "MX",
    "name": "San Damián Texoloc",
    "lat": "19.27833",
    "lng": "-98.28544"
  },
  {
    "country": "MX",
    "name": "Tlaxcala",
    "lat": "19.31905",
    "lng": "-98.19982"
  },
  {
    "country": "MX",
    "name": "Totolac",
    "lat": "19.3258",
    "lng": "-98.25834"
  },
  {
    "country": "MX",
    "name": "Santa Ana Nopalucan",
    "lat": "19.2981",
    "lng": "-98.33321"
  },
  {
    "country": "MX",
    "name": "Papalotla",
    "lat": "19.16861",
    "lng": "-98.20389"
  },
  {
    "country": "MX",
    "name": "Tenancingo",
    "lat": "19.14725",
    "lng": "-98.20132"
  },
  {
    "country": "MX",
    "name": "Villa Vicente Guerrero",
    "lat": "19.12123",
    "lng": "-98.16572"
  },
  {
    "country": "MX",
    "name": "Guadalupe Texcalac",
    "lat": "19.43839",
    "lng": "-98.07806"
  },
  {
    "country": "MX",
    "name": "Pueblo Juárez",
    "lat": "17.64341",
    "lng": "-93.15964"
  },
  {
    "country": "MX",
    "name": "Juárez",
    "lat": "17.60572",
    "lng": "-93.19433"
  },
  {
    "country": "MX",
    "name": "Nuevo Nicapa",
    "lat": "17.63464",
    "lng": "-93.07238"
  },
  {
    "country": "MX",
    "name": "Lacandón",
    "lat": "17.02141",
    "lng": "-91.59523"
  },
  {
    "country": "MX",
    "name": "Chilón",
    "lat": "17.10566",
    "lng": "-92.27292"
  },
  {
    "country": "MX",
    "name": "Nuevo Limar",
    "lat": "17.45514",
    "lng": "-92.3989"
  },
  {
    "country": "MX",
    "name": "El Limar",
    "lat": "17.41491",
    "lng": "-92.40293"
  },
  {
    "country": "MX",
    "name": "Nuevo Sitalá",
    "lat": "17.13936",
    "lng": "-92.48287"
  },
  {
    "country": "MX",
    "name": "José María Morelos y Pavón",
    "lat": "17.24105",
    "lng": "-92.70231"
  },
  {
    "country": "MX",
    "name": "San Andrés Duraznal",
    "lat": "17.13167",
    "lng": "-92.80491"
  },
  {
    "country": "MX",
    "name": "Rincón Chamula",
    "lat": "17.20718",
    "lng": "-92.93912"
  },
  {
    "country": "MX",
    "name": "San Miguel la Sardina",
    "lat": "17.29417",
    "lng": "-93.3525"
  },
  {
    "country": "MX",
    "name": "Adolfo López Mateos",
    "lat": "17.216",
    "lng": "-93.47895"
  },
  {
    "country": "MX",
    "name": "José María Pino Suárez",
    "lat": "16.50571",
    "lng": "-93.7391"
  },
  {
    "country": "MX",
    "name": "Cuauhtémoc",
    "lat": "16.55",
    "lng": "-93.71611"
  },
  {
    "country": "MX",
    "name": "Lázaro Cárdenas",
    "lat": "16.60417",
    "lng": "-93.79139"
  },
  {
    "country": "MX",
    "name": "Alfonso Moguel",
    "lat": "16.6675",
    "lng": "-93.50639"
  },
  {
    "country": "MX",
    "name": "Vicente Guerrero",
    "lat": "16.66028",
    "lng": "-93.58306"
  },
  {
    "country": "MX",
    "name": "Hermenegildo Galeana",
    "lat": "16.57722",
    "lng": "-93.35944"
  },
  {
    "country": "MX",
    "name": "Ignacio Zaragoza (El Morro)",
    "lat": "16.59944",
    "lng": "-93.35083"
  },
  {
    "country": "MX",
    "name": "Aldama",
    "lat": "16.91707",
    "lng": "-92.68839"
  },
  {
    "country": "MX",
    "name": "San Juan Cancuc",
    "lat": "16.89272",
    "lng": "-92.37006"
  },
  {
    "country": "MX",
    "name": "Altamirano",
    "lat": "16.73457",
    "lng": "-92.03843"
  },
  {
    "country": "MX",
    "name": "Benemérito de las Américas",
    "lat": "16.51599",
    "lng": "-90.65371"
  },
  {
    "country": "MX",
    "name": "Emiliano Zapata",
    "lat": "16.28917",
    "lng": "-90.62083"
  },
  {
    "country": "MX",
    "name": "Chihuahua",
    "lat": "16.02966",
    "lng": "-91.97331"
  },
  {
    "country": "MX",
    "name": "La Independencia",
    "lat": "16.25263",
    "lng": "-92.02371"
  },
  {
    "country": "MX",
    "name": "Yasha",
    "lat": "16.39141",
    "lng": "-92.06878"
  },
  {
    "country": "MX",
    "name": "Mariano Matamoros",
    "lat": "16.48119",
    "lng": "-92.58472"
  },
  {
    "country": "MX",
    "name": "Ricardo Flores Magón",
    "lat": "16.39397",
    "lng": "-92.69618"
  },
  {
    "country": "MX",
    "name": "Miguel Hidalgo",
    "lat": "16.3506",
    "lng": "-92.62852"
  },
  {
    "country": "MX",
    "name": "Presidente Echeverría (Laja Tendida)",
    "lat": "16.33583",
    "lng": "-92.66861"
  },
  {
    "country": "MX",
    "name": "Nueva Libertad",
    "lat": "16.09038",
    "lng": "-92.80813"
  },
  {
    "country": "MX",
    "name": "Unión Buena Vista",
    "lat": "16.48582",
    "lng": "-92.81823"
  },
  {
    "country": "MX",
    "name": "Manuel Ávila Camacho",
    "lat": "16.14647",
    "lng": "-93.01701"
  },
  {
    "country": "MX",
    "name": "Doctor Domingo Chanona",
    "lat": "16.34611",
    "lng": "-93.41667"
  },
  {
    "country": "MX",
    "name": "Joaquín Miguel Gutiérrez",
    "lat": "16.37",
    "lng": "-93.36556"
  },
  {
    "country": "MX",
    "name": "Nuevo México",
    "lat": "16.46944",
    "lng": "-93.43806"
  },
  {
    "country": "MX",
    "name": "Cristóbal Obregón",
    "lat": "16.43246",
    "lng": "-93.45689"
  },
  {
    "country": "MX",
    "name": "Libertad Melchor Ocampo",
    "lat": "16.37389",
    "lng": "-93.475"
  },
  {
    "country": "MX",
    "name": "Agrónomos Mexicanos",
    "lat": "16.35",
    "lng": "-93.53"
  },
  {
    "country": "MX",
    "name": "Nueva Palestina",
    "lat": "16.49278",
    "lng": "-93.63361"
  },
  {
    "country": "MX",
    "name": "Julián Grajales",
    "lat": "16.42917",
    "lng": "-93.71417"
  },
  {
    "country": "MX",
    "name": "Tonalá",
    "lat": "16.08977",
    "lng": "-93.75489"
  },
  {
    "country": "MX",
    "name": "Tierra y Libertad",
    "lat": "16.37889",
    "lng": "-93.86056"
  },
  {
    "country": "MX",
    "name": "Tiltepec",
    "lat": "16.39389",
    "lng": "-93.86972"
  },
  {
    "country": "MX",
    "name": "Villamorelos",
    "lat": "16.48",
    "lng": "-93.92778"
  },
  {
    "country": "MX",
    "name": "Arriaga",
    "lat": "16.23589",
    "lng": "-93.89995"
  },
  {
    "country": "MX",
    "name": "San Luqueño",
    "lat": "16.01278",
    "lng": "-93.84583"
  },
  {
    "country": "MX",
    "name": "Paredón",
    "lat": "16.05083",
    "lng": "-93.86667"
  },
  {
    "country": "MX",
    "name": "Doctor Belisario Domínguez (La Barra)",
    "lat": "15.88947",
    "lng": "-93.70404"
  },
  {
    "country": "MX",
    "name": "Manuel Ávila Camacho (Ponte Duro)",
    "lat": "15.80973",
    "lng": "-93.58933"
  },
  {
    "country": "MX",
    "name": "El Palmarcito",
    "lat": "15.49728",
    "lng": "-93.21387"
  },
  {
    "country": "MX",
    "name": "Pilcaya",
    "lat": "18.74691",
    "lng": "-99.67501"
  },
  {
    "country": "MX",
    "name": "San Gaspar",
    "lat": "18.7775",
    "lng": "-99.54861"
  },
  {
    "country": "MX",
    "name": "San Andrés Nicolás Bravo",
    "lat": "18.76778",
    "lng": "-99.46528"
  },
  {
    "country": "MX",
    "name": "El Terrero",
    "lat": "18.79028",
    "lng": "-99.64528"
  },
  {
    "country": "MX",
    "name": "San José Chalmita",
    "lat": "18.85862",
    "lng": "-99.54831"
  },
  {
    "country": "MX",
    "name": "San Pablo Tejalpa",
    "lat": "18.86667",
    "lng": "-99.59111"
  },
  {
    "country": "MX",
    "name": "La Finca",
    "lat": "18.89047",
    "lng": "-99.64028"
  },
  {
    "country": "MX",
    "name": "Buenavista",
    "lat": "18.94556",
    "lng": "-99.65694"
  },
  {
    "country": "MX",
    "name": "Acatzingo (Acatzingo de la Piedra)",
    "lat": "18.92389",
    "lng": "-99.58861"
  },
  {
    "country": "MX",
    "name": "El Carmen (El Desierto del Carmen)",
    "lat": "18.92028",
    "lng": "-99.55667"
  },
  {
    "country": "MX",
    "name": "San Nicolás",
    "lat": "18.93333",
    "lng": "-99.56833"
  },
  {
    "country": "MX",
    "name": "Tepalcatepec",
    "lat": "18.93556",
    "lng": "-99.59917"
  },
  {
    "country": "MX",
    "name": "Jesús Carranza (Rancho de Jesús)",
    "lat": "18.94528",
    "lng": "-99.63056"
  },
  {
    "country": "MX",
    "name": "Santiago Oxtotitlán",
    "lat": "18.96146",
    "lng": "-99.66827"
  },
  {
    "country": "MX",
    "name": "San Agustín",
    "lat": "18.94224",
    "lng": "-99.93913"
  },
  {
    "country": "MX",
    "name": "Texcapilla",
    "lat": "18.94574",
    "lng": "-99.89535"
  },
  {
    "country": "MX",
    "name": "El Salitre",
    "lat": "18.9525",
    "lng": "-99.58972"
  },
  {
    "country": "MX",
    "name": "Chalchihuapan",
    "lat": "18.97694",
    "lng": "-99.57472"
  },
  {
    "country": "MX",
    "name": "Tepoxtepec",
    "lat": "18.96278",
    "lng": "-99.55639"
  },
  {
    "country": "MX",
    "name": "San Miguel",
    "lat": "18.99389",
    "lng": "-99.66639"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Pueblo Nuevo (Pueblo Nuevo)",
    "lat": "19.1",
    "lng": "-99.65806"
  },
  {
    "country": "MX",
    "name": "Cerro La Calera",
    "lat": "19.18333",
    "lng": "-99.81667"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Atizapán",
    "lat": "19.17692",
    "lng": "-99.48852"
  },
  {
    "country": "MX",
    "name": "San Juan Tlacotompa (Tlacotompa)",
    "lat": "18.94111",
    "lng": "-98.79056"
  },
  {
    "country": "MX",
    "name": "San Juan Tepecoculco",
    "lat": "18.98306",
    "lng": "-98.7875"
  },
  {
    "country": "MX",
    "name": "Tepetlixpa",
    "lat": "19.02893",
    "lng": "-98.82129"
  },
  {
    "country": "MX",
    "name": "Tezoyuca",
    "lat": "19.59283",
    "lng": "-98.91084"
  },
  {
    "country": "MX",
    "name": "Acolman",
    "lat": "19.62375",
    "lng": "-98.92407"
  },
  {
    "country": "MX",
    "name": "San Pablo Ixquitlán",
    "lat": "19.70944",
    "lng": "-98.78833"
  },
  {
    "country": "MX",
    "name": "San Antonio de las Palmas",
    "lat": "19.71806",
    "lng": "-98.85684"
  },
  {
    "country": "MX",
    "name": "Ixtlahuaca de Cuauhtémoc",
    "lat": "19.88139",
    "lng": "-98.86028"
  },
  {
    "country": "MX",
    "name": "La Soledad Barrio",
    "lat": "20.09194",
    "lng": "-99.82306"
  },
  {
    "country": "MX",
    "name": "San Juan Daxthi",
    "lat": "20.09838",
    "lng": "-99.52599"
  },
  {
    "country": "MX",
    "name": "La Comunidad",
    "lat": "20.02111",
    "lng": "-99.57611"
  },
  {
    "country": "MX",
    "name": "Ganzda",
    "lat": "19.99",
    "lng": "-99.8475"
  },
  {
    "country": "MX",
    "name": "Bobashi de Guadalupe",
    "lat": "19.87583",
    "lng": "-99.91167"
  },
  {
    "country": "MX",
    "name": "San Luis Anáhuac (Toriles)",
    "lat": "19.79679",
    "lng": "-99.40029"
  },
  {
    "country": "MX",
    "name": "Santiago Casandeje",
    "lat": "19.76972",
    "lng": "-99.96917"
  },
  {
    "country": "MX",
    "name": "Santa Ana Ixtlahuaca (Santa Ana Ixtlahuacingo)",
    "lat": "19.58472",
    "lng": "-99.8875"
  },
  {
    "country": "MX",
    "name": "Jaltocan",
    "lat": "20.61968",
    "lng": "-97.81787"
  },
  {
    "country": "MX",
    "name": "Venustiano Carranza",
    "lat": "20.50667",
    "lng": "-97.66806"
  },
  {
    "country": "MX",
    "name": "Atla",
    "lat": "20.27527",
    "lng": "-98.12469"
  },
  {
    "country": "MX",
    "name": "San Pedro Tlaolantongo",
    "lat": "20.23139",
    "lng": "-97.80139"
  },
  {
    "country": "MX",
    "name": "Tlaola",
    "lat": "20.13861",
    "lng": "-97.92306"
  },
  {
    "country": "MX",
    "name": "Ixtepec",
    "lat": "20.02461",
    "lng": "-97.64612"
  },
  {
    "country": "MX",
    "name": "Ciudad de Tlatlauquitepec",
    "lat": "19.85278",
    "lng": "-97.49528"
  },
  {
    "country": "MX",
    "name": "San Andrés Cholula",
    "lat": "19.05144",
    "lng": "-98.29526"
  },
  {
    "country": "MX",
    "name": "Mazapiltepec",
    "lat": "19.11912",
    "lng": "-97.7028"
  },
  {
    "country": "MX",
    "name": "González Ortega",
    "lat": "19.34268",
    "lng": "-97.27023"
  },
  {
    "country": "MX",
    "name": "Guadalupe Victoria",
    "lat": "19.2911",
    "lng": "-97.3429"
  },
  {
    "country": "MX",
    "name": "José María Morelos",
    "lat": "19.14147",
    "lng": "-97.46809"
  },
  {
    "country": "MX",
    "name": "San Miguel Zoapan",
    "lat": "19.08433",
    "lng": "-97.35359"
  },
  {
    "country": "MX",
    "name": "San José Cuyachapa",
    "lat": "18.85466",
    "lng": "-97.31398"
  },
  {
    "country": "MX",
    "name": "Chapulco",
    "lat": "18.62586",
    "lng": "-97.40474"
  },
  {
    "country": "MX",
    "name": "San Pedro Temamatla",
    "lat": "18.92553",
    "lng": "-97.51198"
  },
  {
    "country": "MX",
    "name": "Actipan de Morelos",
    "lat": "18.96003",
    "lng": "-97.79904"
  },
  {
    "country": "MX",
    "name": "Dolores Hidalgo",
    "lat": "18.75697",
    "lng": "-97.86062"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Ajajalpan",
    "lat": "18.95169",
    "lng": "-97.94998"
  },
  {
    "country": "MX",
    "name": "San Antonio Juárez",
    "lat": "18.79379",
    "lng": "-97.98964"
  },
  {
    "country": "MX",
    "name": "Santa Lucía Cosamaloapan",
    "lat": "18.88361",
    "lng": "-98.35194"
  },
  {
    "country": "MX",
    "name": "San Pablo Ahuatempa",
    "lat": "18.98139",
    "lng": "-98.35889"
  },
  {
    "country": "MX",
    "name": "San Isidro Huilotepec",
    "lat": "18.88083",
    "lng": "-98.38306"
  },
  {
    "country": "MX",
    "name": "Teacalco de Dorantes (San José Teacalco)",
    "lat": "18.80444",
    "lng": "-98.50722"
  },
  {
    "country": "MX",
    "name": "San Juan Raboso",
    "lat": "18.57153",
    "lng": "-98.43962"
  },
  {
    "country": "MX",
    "name": "Tlapanalá",
    "lat": "18.69585",
    "lng": "-98.53561"
  },
  {
    "country": "MX",
    "name": "San Diego el Organal",
    "lat": "18.73083",
    "lng": "-98.51667"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Cuautomatitla",
    "lat": "18.88917",
    "lng": "-98.65917"
  },
  {
    "country": "MX",
    "name": "Huehuetlan el Chico",
    "lat": "18.37347",
    "lng": "-98.69002"
  },
  {
    "country": "MX",
    "name": "Tlancualpican",
    "lat": "18.43333",
    "lng": "-98.7"
  },
  {
    "country": "MX",
    "name": "Teotlalco",
    "lat": "18.4691",
    "lng": "-98.77822"
  },
  {
    "country": "MX",
    "name": "Xochitepec",
    "lat": "18.22833",
    "lng": "-98.87611"
  },
  {
    "country": "MX",
    "name": "Ciudad de Chiautla de Tapia",
    "lat": "18.3",
    "lng": "-98.60389"
  },
  {
    "country": "MX",
    "name": "Ixcamilpa",
    "lat": "18.02769",
    "lng": "-98.69643"
  },
  {
    "country": "MX",
    "name": "Xicotlán",
    "lat": "18.05918",
    "lng": "-98.52457"
  },
  {
    "country": "MX",
    "name": "Hermenegildo Galeana",
    "lat": "18.25667",
    "lng": "-98.10222"
  },
  {
    "country": "MX",
    "name": "Telpatlán",
    "lat": "18.48417",
    "lng": "-97.15222"
  },
  {
    "country": "MX",
    "name": "Calipan",
    "lat": "18.29519",
    "lng": "-97.16376"
  },
  {
    "country": "MX",
    "name": "Jolalpan",
    "lat": "18.32495",
    "lng": "-98.84489"
  },
  {
    "country": "MX",
    "name": "Villa Madero",
    "lat": "19.52833",
    "lng": "-90.69917"
  },
  {
    "country": "MX",
    "name": "La Joya",
    "lat": "19.48028",
    "lng": "-90.67333"
  },
  {
    "country": "MX",
    "name": "Santo Domingo Kesté",
    "lat": "19.49972",
    "lng": "-90.51139"
  },
  {
    "country": "MX",
    "name": "San Pablo Pixtún",
    "lat": "19.13361",
    "lng": "-90.73194"
  },
  {
    "country": "MX",
    "name": "Colonia Emiliano Zapata",
    "lat": "18.66504",
    "lng": "-92.31088"
  },
  {
    "country": "MX",
    "name": "Xpujil",
    "lat": "18.5076",
    "lng": "-89.39437"
  },
  {
    "country": "MX",
    "name": "Haro",
    "lat": "18.44418",
    "lng": "-90.79153"
  },
  {
    "country": "MX",
    "name": "San Juan de Dios (Naranjas de Dios)",
    "lat": "18.54972",
    "lng": "-99.55583"
  },
  {
    "country": "MX",
    "name": "Tecuexcontitlán (Tecoescontitlán)",
    "lat": "18.14254",
    "lng": "-99.57787"
  },
  {
    "country": "MX",
    "name": "Maxela",
    "lat": "18.05347",
    "lng": "-99.59351"
  },
  {
    "country": "MX",
    "name": "Axaxacualco",
    "lat": "17.80387",
    "lng": "-99.46175"
  },
  {
    "country": "MX",
    "name": "El Fresno",
    "lat": "17.43143",
    "lng": "-99.58605"
  },
  {
    "country": "MX",
    "name": "Julián Blanco (Dos Caminos)",
    "lat": "17.21889",
    "lng": "-99.52472"
  },
  {
    "country": "MX",
    "name": "Lomas de Chapultepec",
    "lat": "16.71615",
    "lng": "-99.61021"
  },
  {
    "country": "MX",
    "name": "Cerro de Piedra",
    "lat": "16.77646",
    "lng": "-99.63037"
  },
  {
    "country": "MX",
    "name": "Llano de la Puerta",
    "lat": "16.74355",
    "lng": "-99.52721"
  },
  {
    "country": "MX",
    "name": "Campanario",
    "lat": "16.83534",
    "lng": "-99.57178"
  },
  {
    "country": "MX",
    "name": "Llano Grande",
    "lat": "16.9401",
    "lng": "-99.43353"
  },
  {
    "country": "MX",
    "name": "Ocotlán",
    "lat": "16.93947",
    "lng": "-99.36919"
  },
  {
    "country": "MX",
    "name": "Tecolcuautla",
    "lat": "17.7865",
    "lng": "-98.94828"
  },
  {
    "country": "MX",
    "name": "Pochutla",
    "lat": "17.65907",
    "lng": "-98.89798"
  },
  {
    "country": "MX",
    "name": "Santa Catarina",
    "lat": "17.54835",
    "lng": "-99.175"
  },
  {
    "country": "MX",
    "name": "San Francisco",
    "lat": "17.00583",
    "lng": "-99.28306"
  },
  {
    "country": "MX",
    "name": "La Dicha",
    "lat": "16.7672",
    "lng": "-99.01058"
  },
  {
    "country": "MX",
    "name": "Las Vigas",
    "lat": "16.76144",
    "lng": "-99.22942"
  },
  {
    "country": "MX",
    "name": "Marquelia",
    "lat": "16.58335",
    "lng": "-98.81686"
  },
  {
    "country": "MX",
    "name": "Xalatzala",
    "lat": "17.47355",
    "lng": "-98.57355"
  },
  {
    "country": "MX",
    "name": "Paraje Montero (Paraje Montero de Zaragoza)",
    "lat": "17.16349",
    "lng": "-98.70394"
  },
  {
    "country": "MX",
    "name": "Cochoapa el Grande",
    "lat": "17.1928",
    "lng": "-98.45592"
  },
  {
    "country": "MX",
    "name": "San Pablo Atzompa",
    "lat": "17.24722",
    "lng": "-98.37"
  },
  {
    "country": "MX",
    "name": "Rancho Viejo (Rancho Nuevo de la Democracia)",
    "lat": "17.03257",
    "lng": "-98.22389"
  },
  {
    "country": "MX",
    "name": "Juchitán",
    "lat": "16.62402",
    "lng": "-98.64028"
  },
  {
    "country": "MX",
    "name": "El Pitahayo",
    "lat": "16.53236",
    "lng": "-98.5276"
  },
  {
    "country": "MX",
    "name": "Tixhualactún",
    "lat": "20.64403",
    "lng": "-88.14308"
  },
  {
    "country": "MX",
    "name": "Kinil",
    "lat": "20.32379",
    "lng": "-89.13285"
  },
  {
    "country": "MX",
    "name": "Xul",
    "lat": "20.10222",
    "lng": "-89.46"
  },
  {
    "country": "MX",
    "name": "Kantunilkín",
    "lat": "21.10182",
    "lng": "-87.48644"
  },
  {
    "country": "MX",
    "name": "Alfredo V. Bonfil",
    "lat": "21.08776",
    "lng": "-86.84706"
  },
  {
    "country": "MX",
    "name": "Leona Vicario",
    "lat": "20.9897",
    "lng": "-87.20224"
  },
  {
    "country": "MX",
    "name": "X Cabil",
    "lat": "20.16542",
    "lng": "-88.46398"
  },
  {
    "country": "MX",
    "name": "La Presumida",
    "lat": "19.80083",
    "lng": "-88.75389"
  },
  {
    "country": "MX",
    "name": "José María Morelos",
    "lat": "19.74887",
    "lng": "-88.70866"
  },
  {
    "country": "MX",
    "name": "Kancabchén",
    "lat": "19.71389",
    "lng": "-88.86167"
  },
  {
    "country": "MX",
    "name": "X-Hazil Sur",
    "lat": "19.39167",
    "lng": "-88.07417"
  },
  {
    "country": "MX",
    "name": "Los Divorciados",
    "lat": "19.07687",
    "lng": "-88.45647"
  },
  {
    "country": "MX",
    "name": "Francisco I. Madero",
    "lat": "19.52718",
    "lng": "-97.27067"
  },
  {
    "country": "MX",
    "name": "Guadalupe Victoria",
    "lat": "19.54167",
    "lng": "-97.27789"
  },
  {
    "country": "MX",
    "name": "El Espinal",
    "lat": "19.62444",
    "lng": "-96.8725"
  },
  {
    "country": "MX",
    "name": "El Paraíso (La Charca)",
    "lat": "19.42889",
    "lng": "-96.355"
  },
  {
    "country": "MX",
    "name": "Cabezas",
    "lat": "19.37167",
    "lng": "-96.38278"
  },
  {
    "country": "MX",
    "name": "El Hatito",
    "lat": "19.2775",
    "lng": "-96.39361"
  },
  {
    "country": "MX",
    "name": "Plan del Río",
    "lat": "19.40184",
    "lng": "-96.6525"
  },
  {
    "country": "MX",
    "name": "Bella Esperanza",
    "lat": "19.43329",
    "lng": "-96.86648"
  },
  {
    "country": "MX",
    "name": "Tlaltetela",
    "lat": "19.31421",
    "lng": "-96.90105"
  },
  {
    "country": "MX",
    "name": "Ixhuacán de los Reyes",
    "lat": "19.35526",
    "lng": "-97.11751"
  },
  {
    "country": "MX",
    "name": "Cuiyachapa",
    "lat": "19.04569",
    "lng": "-97.17436"
  },
  {
    "country": "MX",
    "name": "Tetlaxco",
    "lat": "19.04044",
    "lng": "-97.06393"
  },
  {
    "country": "MX",
    "name": "Ixcatla",
    "lat": "19.07528",
    "lng": "-96.91889"
  },
  {
    "country": "MX",
    "name": "San José Tenejapa",
    "lat": "19.01556",
    "lng": "-96.84306"
  },
  {
    "country": "MX",
    "name": "Mata de Indio",
    "lat": "19.23028",
    "lng": "-96.84136"
  },
  {
    "country": "MX",
    "name": "Sonora",
    "lat": "19.11219",
    "lng": "-96.63531"
  },
  {
    "country": "MX",
    "name": "San Francisco Nacaxtle",
    "lat": "19.11083",
    "lng": "-96.59583"
  },
  {
    "country": "MX",
    "name": "Las Amapolas",
    "lat": "19.15194",
    "lng": "-96.19778"
  },
  {
    "country": "MX",
    "name": "Paraje Nuevo",
    "lat": "18.87886",
    "lng": "-96.86066"
  },
  {
    "country": "MX",
    "name": "Veinte de Noviembre",
    "lat": "18.865",
    "lng": "-96.95472"
  },
  {
    "country": "MX",
    "name": "Trapiche Viejo",
    "lat": "18.84306",
    "lng": "-96.94556"
  },
  {
    "country": "MX",
    "name": "Rincón de Buena Vista",
    "lat": "18.75556",
    "lng": "-96.86861"
  },
  {
    "country": "MX",
    "name": "San José de Tapia",
    "lat": "18.84722",
    "lng": "-96.95389"
  },
  {
    "country": "MX",
    "name": "Monte Salas",
    "lat": "18.93722",
    "lng": "-97.01833"
  },
  {
    "country": "MX",
    "name": "Buenavista",
    "lat": "18.89306",
    "lng": "-97.03694"
  },
  {
    "country": "MX",
    "name": "Campo Chico",
    "lat": "18.83639",
    "lng": "-97.02802"
  },
  {
    "country": "MX",
    "name": "Tlilapan",
    "lat": "18.8056",
    "lng": "-97.09867"
  },
  {
    "country": "MX",
    "name": "La Cuesta",
    "lat": "18.79028",
    "lng": "-97.16806"
  },
  {
    "country": "MX",
    "name": "San Isidro el Berro",
    "lat": "18.92722",
    "lng": "-97.20556"
  },
  {
    "country": "MX",
    "name": "San José Súchil",
    "lat": "18.88778",
    "lng": "-97.23722"
  },
  {
    "country": "MX",
    "name": "El Aguacate",
    "lat": "18.19778",
    "lng": "-94.97028"
  },
  {
    "country": "MX",
    "name": "Ixhuapan",
    "lat": "18.01333",
    "lng": "-94.87667"
  },
  {
    "country": "MX",
    "name": "Tlacuilolapan",
    "lat": "17.97778",
    "lng": "-94.26306"
  },
  {
    "country": "MX",
    "name": "Zaragoza",
    "lat": "17.95783",
    "lng": "-94.64231"
  },
  {
    "country": "MX",
    "name": "Coacotla",
    "lat": "17.93611",
    "lng": "-94.66667"
  },
  {
    "country": "MX",
    "name": "Las Lomas de Tacamichapan",
    "lat": "17.86611",
    "lng": "-94.70833"
  },
  {
    "country": "MX",
    "name": "Colonia Lealtad",
    "lat": "17.96306",
    "lng": "-94.9025"
  },
  {
    "country": "MX",
    "name": "Congregación Hidalgo",
    "lat": "17.9375",
    "lng": "-94.97056"
  },
  {
    "country": "MX",
    "name": "Dehesa",
    "lat": "17.94167",
    "lng": "-94.99806"
  },
  {
    "country": "MX",
    "name": "San Pedro Coyutla",
    "lat": "21.2241",
    "lng": "-98.43002"
  },
  {
    "country": "MX",
    "name": "Otatitlán",
    "lat": "20.63556",
    "lng": "-98.14028"
  },
  {
    "country": "MX",
    "name": "Tenantitla",
    "lat": "20.77031",
    "lng": "-98.14433"
  },
  {
    "country": "MX",
    "name": "Xochimilco",
    "lat": "20.86302",
    "lng": "-98.06967"
  },
  {
    "country": "MX",
    "name": "Pisaflores",
    "lat": "20.60941",
    "lng": "-97.92782"
  },
  {
    "country": "MX",
    "name": "Tincontlán",
    "lat": "20.82141",
    "lng": "-97.69083"
  },
  {
    "country": "MX",
    "name": "Alto Lucero",
    "lat": "20.95361",
    "lng": "-97.44194"
  },
  {
    "country": "MX",
    "name": "La Victoria (La Peñita)",
    "lat": "20.93694",
    "lng": "-97.3725"
  },
  {
    "country": "MX",
    "name": "Barra de Cazones",
    "lat": "20.72222",
    "lng": "-97.2025"
  },
  {
    "country": "MX",
    "name": "Polutla",
    "lat": "20.52799",
    "lng": "-97.25884"
  },
  {
    "country": "MX",
    "name": "Las Lomas",
    "lat": "20.26067",
    "lng": "-97.61528"
  },
  {
    "country": "MX",
    "name": "Macedonio Alonso",
    "lat": "20.27417",
    "lng": "-97.69194"
  },
  {
    "country": "MX",
    "name": "Ignacio Zaragoza",
    "lat": "19.71222",
    "lng": "-97.225"
  },
  {
    "country": "MX",
    "name": "Gutiérrez Zamora",
    "lat": "19.72417",
    "lng": "-97.215"
  },
  {
    "country": "MX",
    "name": "San Marcos Atesquilapan",
    "lat": "19.68972",
    "lng": "-96.88537"
  },
  {
    "country": "MX",
    "name": "Monte Verde Chivería",
    "lat": "19.70304",
    "lng": "-96.69601"
  },
  {
    "country": "MX",
    "name": "Palma Sola",
    "lat": "19.77132",
    "lng": "-96.43225"
  },
  {
    "country": "MX",
    "name": "Manuel María Contreras",
    "lat": "20.44617",
    "lng": "-97.48329"
  },
  {
    "country": "MX",
    "name": "Tapalapan",
    "lat": "18.5325",
    "lng": "-95.30631"
  },
  {
    "country": "MX",
    "name": "Presidio (Plan de Libres)",
    "lat": "18.68056",
    "lng": "-96.77194"
  },
  {
    "country": "MX",
    "name": "Loma Bonita",
    "lat": "18.10721",
    "lng": "-95.87904"
  },
  {
    "country": "MX",
    "name": "Isla",
    "lat": "18.0278",
    "lng": "-95.52946"
  },
  {
    "country": "MX",
    "name": "Tlapacoyan",
    "lat": "18.45667",
    "lng": "-95.40056"
  },
  {
    "country": "MX",
    "name": "Santa Rosa Abata",
    "lat": "18.4619",
    "lng": "-95.16765"
  },
  {
    "country": "MX",
    "name": "Juan Jacobo Torres [Bodega de Totontepec]",
    "lat": "18.33645",
    "lng": "-95.26033"
  },
  {
    "country": "MX",
    "name": "Tilapan",
    "lat": "18.34917",
    "lng": "-95.32806"
  },
  {
    "country": "MX",
    "name": "Estación Juanita",
    "lat": "17.80889",
    "lng": "-95.2175"
  },
  {
    "country": "MX",
    "name": "Vista Hermosa",
    "lat": "17.92361",
    "lng": "-95.06083"
  },
  {
    "country": "MX",
    "name": "Aguilera",
    "lat": "17.81083",
    "lng": "-95.015"
  },
  {
    "country": "MX",
    "name": "Venustiano Carranza (Peña Blanca)",
    "lat": "17.64194",
    "lng": "-94.75417"
  },
  {
    "country": "MX",
    "name": "San Lorenzo Tenochtitlán",
    "lat": "17.755",
    "lng": "-94.76028"
  },
  {
    "country": "MX",
    "name": "La Chinantla",
    "lat": "17.27739",
    "lng": "-94.44944"
  },
  {
    "country": "MX",
    "name": "Poblado Cinco",
    "lat": "17.27453",
    "lng": "-94.55152"
  },
  {
    "country": "MX",
    "name": "Boxasní",
    "lat": "20.67083",
    "lng": "-99.84861"
  },
  {
    "country": "MX",
    "name": "La Llave",
    "lat": "20.46628",
    "lng": "-99.99373"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Escandón",
    "lat": "20.41603",
    "lng": "-99.95563"
  },
  {
    "country": "MX",
    "name": "Paso de Mata",
    "lat": "20.3423",
    "lng": "-99.92712"
  },
  {
    "country": "MX",
    "name": "Yosphí",
    "lat": "20.17083",
    "lng": "-99.95222"
  },
  {
    "country": "MX",
    "name": "San Bartolo el Viejo",
    "lat": "19.29889",
    "lng": "-99.82389"
  },
  {
    "country": "MX",
    "name": "San Pedro de la Hortaliza (Ejido Almoloyán)",
    "lat": "19.38806",
    "lng": "-99.81778"
  },
  {
    "country": "MX",
    "name": "Las Peñas",
    "lat": "19.44972",
    "lng": "-99.99944"
  },
  {
    "country": "MX",
    "name": "El Rincón de los Perales",
    "lat": "19.54222",
    "lng": "-99.82806"
  },
  {
    "country": "MX",
    "name": "Guadalupe Cachi",
    "lat": "19.60111",
    "lng": "-99.825"
  },
  {
    "country": "MX",
    "name": "Emiliano Zapata (Santo Domingo)",
    "lat": "19.57972",
    "lng": "-99.78806"
  },
  {
    "country": "MX",
    "name": "San Francisco de Guzmán",
    "lat": "19.62028",
    "lng": "-99.77472"
  },
  {
    "country": "MX",
    "name": "Fresno Nichi",
    "lat": "19.56694",
    "lng": "-99.94889"
  },
  {
    "country": "MX",
    "name": "Mina Vieja",
    "lat": "19.5525",
    "lng": "-99.94389"
  },
  {
    "country": "MX",
    "name": "Palos Amarillos (Palos Amarillos Yebuciví)",
    "lat": "19.53944",
    "lng": "-99.91667"
  },
  {
    "country": "MX",
    "name": "Cuadrilla Vieja",
    "lat": "19.51205",
    "lng": "-99.98692"
  },
  {
    "country": "MX",
    "name": "Barrio de San Isidro",
    "lat": "19.52139",
    "lng": "-99.95861"
  },
  {
    "country": "MX",
    "name": "San Antonio de las Huertas",
    "lat": "19.56222",
    "lng": "-99.97111"
  },
  {
    "country": "MX",
    "name": "San Juan Cote Ejido",
    "lat": "19.60516",
    "lng": "-99.95913"
  },
  {
    "country": "MX",
    "name": "San Jerónimo Bonchete",
    "lat": "19.63106",
    "lng": "-99.94949"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Mextepec",
    "lat": "19.65972",
    "lng": "-99.95306"
  },
  {
    "country": "MX",
    "name": "Dolores Hidalgo",
    "lat": "19.65528",
    "lng": "-99.92639"
  },
  {
    "country": "MX",
    "name": "Ejido del Tunal Nenaxi",
    "lat": "19.74389",
    "lng": "-99.90889"
  },
  {
    "country": "MX",
    "name": "San Lucas Ocotepec",
    "lat": "19.67833",
    "lng": "-99.97194"
  },
  {
    "country": "MX",
    "name": "El Carmen Ocotepec",
    "lat": "19.68722",
    "lng": "-99.97417"
  },
  {
    "country": "MX",
    "name": "San Juan Jalpa Centro",
    "lat": "19.69806",
    "lng": "-99.93"
  },
  {
    "country": "MX",
    "name": "San Agustín Mextepec",
    "lat": "19.63292",
    "lng": "-99.92654"
  },
  {
    "country": "MX",
    "name": "Santa Ana la Ladera",
    "lat": "19.59583",
    "lng": "-99.87"
  },
  {
    "country": "MX",
    "name": "San Isidro Boxipe",
    "lat": "19.60111",
    "lng": "-99.89083"
  },
  {
    "country": "MX",
    "name": "Santa María Endare",
    "lat": "19.72556",
    "lng": "-99.81583"
  },
  {
    "country": "MX",
    "name": "Mavoro",
    "lat": "19.70417",
    "lng": "-99.82222"
  },
  {
    "country": "MX",
    "name": "Emilio Portes Gil",
    "lat": "19.64444",
    "lng": "-99.91667"
  },
  {
    "country": "MX",
    "name": "San Juan de las Manzanas",
    "lat": "19.55111",
    "lng": "-99.83833"
  },
  {
    "country": "MX",
    "name": "La Concepción Enyege",
    "lat": "19.56472",
    "lng": "-99.84139"
  },
  {
    "country": "MX",
    "name": "San Andrés del Pedregal",
    "lat": "19.58139",
    "lng": "-99.86889"
  },
  {
    "country": "MX",
    "name": "Santiago Citendejé",
    "lat": "19.78139",
    "lng": "-99.92917"
  },
  {
    "country": "MX",
    "name": "Cuendo",
    "lat": "19.80028",
    "lng": "-99.94778"
  },
  {
    "country": "MX",
    "name": "San Lorenzo Tlacotepec",
    "lat": "19.8125",
    "lng": "-99.91222"
  },
  {
    "country": "MX",
    "name": "San Juan de los Jarros",
    "lat": "19.86194",
    "lng": "-99.91611"
  },
  {
    "country": "MX",
    "name": "San Luis Boro",
    "lat": "19.81316",
    "lng": "-99.8558"
  },
  {
    "country": "MX",
    "name": "Tecoac (Santa María Nativitas)",
    "lat": "19.78917",
    "lng": "-99.85306"
  },
  {
    "country": "MX",
    "name": "San Bartolo Lanzados",
    "lat": "19.86639",
    "lng": "-99.89389"
  },
  {
    "country": "MX",
    "name": "San José del Tunal",
    "lat": "19.79056",
    "lng": "-99.84"
  },
  {
    "country": "MX",
    "name": "El Rincón de la Candelaria",
    "lat": "19.79",
    "lng": "-99.84306"
  },
  {
    "country": "MX",
    "name": "San Francisco Chalchihuapan",
    "lat": "19.77",
    "lng": "-99.82167"
  },
  {
    "country": "MX",
    "name": "San Antonio Enchisi",
    "lat": "19.75472",
    "lng": "-99.81667"
  },
  {
    "country": "MX",
    "name": "San Pedro del Rosal",
    "lat": "19.77806",
    "lng": "-99.8125"
  },
  {
    "country": "MX",
    "name": "San Felipe Pueblo Nuevo",
    "lat": "19.76778",
    "lng": "-99.75833"
  },
  {
    "country": "MX",
    "name": "Tixmadeje Chiquito",
    "lat": "19.96556",
    "lng": "-99.91444"
  },
  {
    "country": "MX",
    "name": "Detiña (San Antonio Detiña)",
    "lat": "19.97028",
    "lng": "-99.88389"
  },
  {
    "country": "MX",
    "name": "La Caridad",
    "lat": "19.94778",
    "lng": "-99.83694"
  },
  {
    "country": "MX",
    "name": "San Mateo el Viejo",
    "lat": "19.91441",
    "lng": "-99.9108"
  },
  {
    "country": "MX",
    "name": "San Jerónimo de los Jarros",
    "lat": "19.87861",
    "lng": "-99.92333"
  },
  {
    "country": "MX",
    "name": "Chosto de los Jarros",
    "lat": "19.86333",
    "lng": "-99.91"
  },
  {
    "country": "MX",
    "name": "San José Toxi",
    "lat": "19.86639",
    "lng": "-99.93861"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Bombatevi",
    "lat": "19.805",
    "lng": "-99.88667"
  },
  {
    "country": "MX",
    "name": "Tercera Manzana de Zaragoza",
    "lat": "19.89556",
    "lng": "-99.75278"
  },
  {
    "country": "MX",
    "name": "Las Huertas",
    "lat": "19.97222",
    "lng": "-99.55611"
  },
  {
    "country": "MX",
    "name": "San Bartolo Morelos",
    "lat": "19.78643",
    "lng": "-99.66879"
  },
  {
    "country": "MX",
    "name": "Jalpa de los Baños",
    "lat": "19.67833",
    "lng": "-99.87389"
  },
  {
    "country": "MX",
    "name": "San Marcos Tlazalpan",
    "lat": "19.80611",
    "lng": "-99.7175"
  },
  {
    "country": "MX",
    "name": "San José Boqui",
    "lat": "19.70167",
    "lng": "-99.72861"
  },
  {
    "country": "MX",
    "name": "Huemetla",
    "lat": "19.715",
    "lng": "-99.73583"
  },
  {
    "country": "MX",
    "name": "Barrio de Boyecha",
    "lat": "19.70778",
    "lng": "-99.68444"
  },
  {
    "country": "MX",
    "name": "Los Arana",
    "lat": "19.70944",
    "lng": "-99.50139"
  },
  {
    "country": "MX",
    "name": "San Antonio Nixini",
    "lat": "19.67472",
    "lng": "-99.68472"
  },
  {
    "country": "MX",
    "name": "San Lorenzo Malacota",
    "lat": "19.64972",
    "lng": "-99.61333"
  },
  {
    "country": "MX",
    "name": "Rancho Alegre",
    "lat": "19.62528",
    "lng": "-99.68361"
  },
  {
    "country": "MX",
    "name": "Santa María del Llano",
    "lat": "19.63444",
    "lng": "-99.725"
  },
  {
    "country": "MX",
    "name": "Barrio de San Pedro la Cabecera",
    "lat": "19.56528",
    "lng": "-99.75"
  },
  {
    "country": "MX",
    "name": "San Miguel Yuxtepec",
    "lat": "19.54056",
    "lng": "-99.7125"
  },
  {
    "country": "MX",
    "name": "Enthavi",
    "lat": "19.49842",
    "lng": "-99.57502"
  },
  {
    "country": "MX",
    "name": "Pothé",
    "lat": "19.47417",
    "lng": "-99.60306"
  },
  {
    "country": "MX",
    "name": "San Pedro Abajo",
    "lat": "19.48093",
    "lng": "-99.567"
  },
  {
    "country": "MX",
    "name": "San Mateo Capulhuac",
    "lat": "19.47028",
    "lng": "-99.52611"
  },
  {
    "country": "MX",
    "name": "Ejido de Dolores",
    "lat": "19.43083",
    "lng": "-99.61278"
  },
  {
    "country": "MX",
    "name": "San José Pathé",
    "lat": "19.43528",
    "lng": "-99.63111"
  },
  {
    "country": "MX",
    "name": "La Cabecera",
    "lat": "19.35611",
    "lng": "-99.74806"
  },
  {
    "country": "MX",
    "name": "San Martín Toltepec",
    "lat": "19.35194",
    "lng": "-99.70583"
  },
  {
    "country": "MX",
    "name": "San Marcos Yachihuacaltepec",
    "lat": "19.32319",
    "lng": "-99.6791"
  },
  {
    "country": "MX",
    "name": "San Mateo Otzacatipan",
    "lat": "19.33273",
    "lng": "-99.60345"
  },
  {
    "country": "MX",
    "name": "Santa María Totoltepec",
    "lat": "19.30653",
    "lng": "-99.59279"
  },
  {
    "country": "MX",
    "name": "El Cerrillo Vista Hermosa",
    "lat": "19.32337",
    "lng": "-99.5425"
  },
  {
    "country": "MX",
    "name": "San Antonio Buenavista",
    "lat": "19.26083",
    "lng": "-99.71194"
  },
  {
    "country": "MX",
    "name": "San Pedro Tultepec",
    "lat": "19.26514",
    "lng": "-99.50934"
  },
  {
    "country": "MX",
    "name": "San Bartolomé Tlaltelulco",
    "lat": "19.22738",
    "lng": "-99.62964"
  },
  {
    "country": "MX",
    "name": "San Juan Tilapa",
    "lat": "19.22021",
    "lng": "-99.66012"
  },
  {
    "country": "MX",
    "name": "Santa María Nativitas",
    "lat": "19.21139",
    "lng": "-99.62944"
  },
  {
    "country": "MX",
    "name": "San Pedro Tlaltizapan",
    "lat": "19.19973",
    "lng": "-99.49956"
  },
  {
    "country": "MX",
    "name": "San Andrés Ocotlán",
    "lat": "19.19297",
    "lng": "-99.58612"
  },
  {
    "country": "MX",
    "name": "San Francisco Putla",
    "lat": "19.12778",
    "lng": "-99.63556"
  },
  {
    "country": "MX",
    "name": "San Gabriel Zepayautla",
    "lat": "19.01306",
    "lng": "-99.55194"
  },
  {
    "country": "MX",
    "name": "San Pedro Zictepec",
    "lat": "19.03659",
    "lng": "-99.57771"
  },
  {
    "country": "MX",
    "name": "Maxtleca de Galeana",
    "lat": "19.02889",
    "lng": "-99.55722"
  },
  {
    "country": "MX",
    "name": "Santa María Jajalpa",
    "lat": "19.11167",
    "lng": "-99.53583"
  },
  {
    "country": "MX",
    "name": "Tlacomulco",
    "lat": "19.12111",
    "lng": "-99.4475"
  },
  {
    "country": "MX",
    "name": "San Lorenzo Huehuetitlán",
    "lat": "19.13417",
    "lng": "-99.48222"
  },
  {
    "country": "MX",
    "name": "Santiago Tílapa",
    "lat": "19.18953",
    "lng": "-99.42089"
  },
  {
    "country": "MX",
    "name": "Tres Marías",
    "lat": "19.0549",
    "lng": "-99.24301"
  },
  {
    "country": "MX",
    "name": "San Pedro Cholula",
    "lat": "19.26444",
    "lng": "-99.48639"
  },
  {
    "country": "MX",
    "name": "San Mateo Atarasquíllo",
    "lat": "19.32304",
    "lng": "-99.46156"
  },
  {
    "country": "MX",
    "name": "San Lorenzo Acopilco",
    "lat": "19.32889",
    "lng": "-99.32556"
  },
  {
    "country": "MX",
    "name": "Benito Juarez",
    "lat": "19.3984",
    "lng": "-99.15766"
  },
  {
    "country": "MX",
    "name": "Venustiano Carranza",
    "lat": "19.44361",
    "lng": "-99.10499"
  },
  {
    "country": "MX",
    "name": "Miguel Hidalgo",
    "lat": "19.43411",
    "lng": "-99.20024"
  },
  {
    "country": "MX",
    "name": "Cuauhtémoc",
    "lat": "19.44506",
    "lng": "-99.14612"
  },
  {
    "country": "MX",
    "name": "Huixquilucan",
    "lat": "19.35985",
    "lng": "-99.35016"
  },
  {
    "country": "MX",
    "name": "Zacamulpa",
    "lat": "19.35565",
    "lng": "-99.33145"
  },
  {
    "country": "MX",
    "name": "San Bartolomé Coatepec",
    "lat": "19.39776",
    "lng": "-99.31211"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Huitzizilapan",
    "lat": "19.39694",
    "lng": "-99.44806"
  },
  {
    "country": "MX",
    "name": "Loma del Río",
    "lat": "19.60056",
    "lng": "-99.35056"
  },
  {
    "country": "MX",
    "name": "San Miguel Hila",
    "lat": "19.59361",
    "lng": "-99.32528"
  },
  {
    "country": "MX",
    "name": "San José el Vidrio",
    "lat": "19.65333",
    "lng": "-99.38417"
  },
  {
    "country": "MX",
    "name": "San Luis Taxhimay",
    "lat": "19.83972",
    "lng": "-99.39861"
  },
  {
    "country": "MX",
    "name": "San Ignacio Nopala",
    "lat": "19.83528",
    "lng": "-99.34556"
  },
  {
    "country": "MX",
    "name": "Santiago Tlapanaloya",
    "lat": "19.87056",
    "lng": "-99.35083"
  },
  {
    "country": "MX",
    "name": "Cantera de Villagrán",
    "lat": "19.84083",
    "lng": "-99.30917"
  },
  {
    "country": "MX",
    "name": "Santiago Tlautla",
    "lat": "19.96444",
    "lng": "-99.37222"
  },
  {
    "country": "MX",
    "name": "Santa María Ilucan",
    "lat": "19.98889",
    "lng": "-99.33889"
  },
  {
    "country": "MX",
    "name": "San Miguel Vindho",
    "lat": "19.99447",
    "lng": "-99.31782"
  },
  {
    "country": "MX",
    "name": "Unidad San Miguel Jagüeyes",
    "lat": "19.82361",
    "lng": "-99.28889"
  },
  {
    "country": "MX",
    "name": "Emiliano Zapata (San José Bata)",
    "lat": "19.91111",
    "lng": "-99.00667"
  },
  {
    "country": "MX",
    "name": "San Pedro Xalpa",
    "lat": "19.82666",
    "lng": "-99.18466"
  },
  {
    "country": "MX",
    "name": "Melchor Ocampo",
    "lat": "19.70186",
    "lng": "-99.14485"
  },
  {
    "country": "MX",
    "name": "Huilango",
    "lat": "19.68056",
    "lng": "-99.25639"
  },
  {
    "country": "MX",
    "name": "Santiago Teyahualco",
    "lat": "19.65985",
    "lng": "-99.12493"
  },
  {
    "country": "MX",
    "name": "Tonanitla",
    "lat": "19.68794",
    "lng": "-99.05342"
  },
  {
    "country": "MX",
    "name": "Ojo de Agua",
    "lat": "19.68028",
    "lng": "-99.01"
  },
  {
    "country": "MX",
    "name": "Santo Tomás Chiconautla",
    "lat": "19.63894",
    "lng": "-99.00755"
  },
  {
    "country": "MX",
    "name": "Buenavista",
    "lat": "19.60833",
    "lng": "-99.16944"
  },
  {
    "country": "MX",
    "name": "San Ignacio Río Muerto",
    "lat": "27.41656",
    "lng": "-110.24584"
  },
  {
    "country": "MX",
    "name": "Rosario",
    "lat": "27.84111",
    "lng": "-109.36806"
  },
  {
    "country": "MX",
    "name": "Vicam",
    "lat": "27.64354",
    "lng": "-110.29351"
  },
  {
    "country": "MX",
    "name": "Antonio Rosales",
    "lat": "28.07889",
    "lng": "-110.61349"
  },
  {
    "country": "MX",
    "name": "Miguel Alemán (La Doce)",
    "lat": "28.84028",
    "lng": "-111.4775"
  },
  {
    "country": "MX",
    "name": "Villa Hidalgo",
    "lat": "30.16183",
    "lng": "-109.32154"
  },
  {
    "country": "MX",
    "name": "El Diamante (La Retranca)",
    "lat": "30.84556",
    "lng": "-112.63972"
  },
  {
    "country": "MX",
    "name": "Trinidad García de la Cadena",
    "lat": "21.21035",
    "lng": "-103.46532"
  },
  {
    "country": "MX",
    "name": "Florencia",
    "lat": "21.50392",
    "lng": "-103.55353"
  },
  {
    "country": "MX",
    "name": "Santa María de la Paz",
    "lat": "21.51205",
    "lng": "-103.40804"
  },
  {
    "country": "MX",
    "name": "El Plateado de Joaquín Amaro",
    "lat": "21.93622",
    "lng": "-103.09267"
  },
  {
    "country": "MX",
    "name": "El Nigromante",
    "lat": "22.15373",
    "lng": "-101.71056"
  },
  {
    "country": "MX",
    "name": "Colonia José María Morelos",
    "lat": "22.36794",
    "lng": "-101.79449"
  },
  {
    "country": "MX",
    "name": "Piedra Gorda",
    "lat": "22.50759",
    "lng": "-102.33187"
  },
  {
    "country": "MX",
    "name": "Genaro Codina",
    "lat": "22.48755",
    "lng": "-102.45754"
  },
  {
    "country": "MX",
    "name": "General Pánfilo Natera",
    "lat": "22.66461",
    "lng": "-102.11007"
  },
  {
    "country": "MX",
    "name": "Pozo de Jarillas",
    "lat": "22.65279",
    "lng": "-102.19782"
  },
  {
    "country": "MX",
    "name": "La Luz",
    "lat": "22.88",
    "lng": "-102.31028"
  },
  {
    "country": "MX",
    "name": "El Lampotal",
    "lat": "22.89583",
    "lng": "-102.41944"
  },
  {
    "country": "MX",
    "name": "General Enrique Estrada",
    "lat": "22.99747",
    "lng": "-102.74255"
  },
  {
    "country": "MX",
    "name": "Las Catarinas",
    "lat": "23.09115",
    "lng": "-102.61597"
  },
  {
    "country": "MX",
    "name": "Cañas",
    "lat": "23.74366",
    "lng": "-103.244"
  },
  {
    "country": "MX",
    "name": "Cerro Gordo",
    "lat": "21.97448",
    "lng": "-100.80661"
  },
  {
    "country": "MX",
    "name": "Villa Juárez",
    "lat": "22.32617",
    "lng": "-100.26689"
  },
  {
    "country": "MX",
    "name": "La Esperanza",
    "lat": "22.00788",
    "lng": "-100.76496"
  },
  {
    "country": "MX",
    "name": "Los Zacatones",
    "lat": "22.96139",
    "lng": "-102.05556"
  },
  {
    "country": "MX",
    "name": "Dulce Grande",
    "lat": "23.00175",
    "lng": "-102.17405"
  },
  {
    "country": "MX",
    "name": "Praxédis Guerrero",
    "lat": "31.36667",
    "lng": "-106.01667"
  },
  {
    "country": "MX",
    "name": "Matamoros",
    "lat": "26.76209",
    "lng": "-105.58523"
  },
  {
    "country": "MX",
    "name": "Julimes",
    "lat": "28.42376",
    "lng": "-105.42727"
  },
  {
    "country": "MX",
    "name": "Ignacio Zaragoza",
    "lat": "29.64248",
    "lng": "-107.76375"
  },
  {
    "country": "MX",
    "name": "Galeana",
    "lat": "30.11393",
    "lng": "-107.61636"
  },
  {
    "country": "MX",
    "name": "José Esteban Coronado",
    "lat": "26.73722",
    "lng": "-105.15833"
  },
  {
    "country": "MX",
    "name": "Ejido Benito Juárez",
    "lat": "30.14937",
    "lng": "-106.88362"
  },
  {
    "country": "MX",
    "name": "Adolfo López Mateos",
    "lat": "28.46667",
    "lng": "-107.3"
  },
  {
    "country": "MX",
    "name": "Ojo de Agua de Palmillas",
    "lat": "22.61972",
    "lng": "-105.60389"
  },
  {
    "country": "MX",
    "name": "Cristo Rey",
    "lat": "22.58167",
    "lng": "-105.72444"
  },
  {
    "country": "MX",
    "name": "Tecualilla",
    "lat": "22.76667",
    "lng": "-105.67167"
  },
  {
    "country": "MX",
    "name": "Isla del Bosque",
    "lat": "22.73306",
    "lng": "-105.84556"
  },
  {
    "country": "MX",
    "name": "El Huajote",
    "lat": "23.12889",
    "lng": "-106.05889"
  },
  {
    "country": "MX",
    "name": "Concordia",
    "lat": "23.28694",
    "lng": "-106.06389"
  },
  {
    "country": "MX",
    "name": "Eldorado",
    "lat": "24.32444",
    "lng": "-107.36722"
  },
  {
    "country": "MX",
    "name": "Las Aguamitas",
    "lat": "24.57556",
    "lng": "-107.80056"
  },
  {
    "country": "MX",
    "name": "Lo de Jesús (Campo Romero)",
    "lat": "24.68",
    "lng": "-107.54556"
  },
  {
    "country": "MX",
    "name": "El Limón de los Ramos",
    "lat": "24.91361",
    "lng": "-107.52333"
  },
  {
    "country": "MX",
    "name": "Dautillos",
    "lat": "24.72167",
    "lng": "-107.97528"
  },
  {
    "country": "MX",
    "name": "Leyva Solano",
    "lat": "25.66163",
    "lng": "-108.637"
  },
  {
    "country": "MX",
    "name": "El Huitusi",
    "lat": "25.50974",
    "lng": "-108.77875"
  },
  {
    "country": "MX",
    "name": "Benito Juárez (Vinatería)",
    "lat": "25.97376",
    "lng": "-108.87315"
  },
  {
    "country": "MX",
    "name": "El Refugio",
    "lat": "25.99619",
    "lng": "-109.2999"
  },
  {
    "country": "MX",
    "name": "Cihuatlán",
    "lat": "19.2366",
    "lng": "-104.56512"
  },
  {
    "country": "MX",
    "name": "Jaboncillo",
    "lat": "25.74809",
    "lng": "-103.2655"
  },
  {
    "country": "MX",
    "name": "Lamadrid",
    "lat": "27.05087",
    "lng": "-101.79552"
  },
  {
    "country": "MX",
    "name": "Minas de Barroterán",
    "lat": "27.65144",
    "lng": "-101.28212"
  },
  {
    "country": "MX",
    "name": "Seis de Octubre",
    "lat": "25.81361",
    "lng": "-103.57333"
  },
  {
    "country": "MX",
    "name": "Camalú",
    "lat": "30.84222",
    "lng": "-116.06328"
  },
  {
    "country": "MX",
    "name": "Primo Tapia",
    "lat": "32.22226",
    "lng": "-116.9139"
  },
  {
    "country": "MX",
    "name": "Progreso",
    "lat": "32.58039",
    "lng": "-115.58479"
  },
  {
    "country": "MX",
    "name": "Estación Coahuila",
    "lat": "32.19304",
    "lng": "-114.99933"
  },
  {
    "country": "MX",
    "name": "Doctor Alberto Oviedo Mota",
    "lat": "32.22756",
    "lng": "-115.16792"
  },
  {
    "country": "MX",
    "name": "Guadalupe Victoria",
    "lat": "32.28924",
    "lng": "-115.10534"
  },
  {
    "country": "MX",
    "name": "Delta",
    "lat": "32.35497",
    "lng": "-115.19617"
  },
  {
    "country": "MX",
    "name": "Islas Agrarias Grupo A",
    "lat": "32.61096",
    "lng": "-115.33151"
  },
  {
    "country": "MX",
    "name": "Zirándaro de los Chávez",
    "lat": "18.47622",
    "lng": "-100.97915"
  },
  {
    "country": "MX",
    "name": "Zinapécuaro",
    "lat": "19.86006",
    "lng": "-100.82857"
  },
  {
    "country": "MX",
    "name": "Zináparo",
    "lat": "20.17252",
    "lng": "-101.99771"
  },
  {
    "country": "MX",
    "name": "Ixtapa-Zihuatanejo",
    "lat": "17.64344",
    "lng": "-101.55212"
  },
  {
    "country": "MX",
    "name": "Zaragoza",
    "lat": "28.4932",
    "lng": "-100.9223"
  },
  {
    "country": "MX",
    "name": "Villa Zaragoza",
    "lat": "22.03716",
    "lng": "-100.73088"
  },
  {
    "country": "MX",
    "name": "Zapotlanejo",
    "lat": "20.62248",
    "lng": "-103.06766"
  },
  {
    "country": "MX",
    "name": "Zapotlán del Rey",
    "lat": "20.46639",
    "lng": "-102.92611"
  },
  {
    "country": "MX",
    "name": "Zapotitlán de Vadillo",
    "lat": "19.5493",
    "lng": "-103.81111"
  },
  {
    "country": "MX",
    "name": "Zapotiltic",
    "lat": "19.62749",
    "lng": "-103.41752"
  },
  {
    "country": "MX",
    "name": "El Zapote",
    "lat": "21.11257",
    "lng": "-102.80555"
  },
  {
    "country": "MX",
    "name": "Zapopan",
    "lat": "20.72356",
    "lng": "-103.38479"
  },
  {
    "country": "MX",
    "name": "Zamora",
    "lat": "19.9855",
    "lng": "-102.28387"
  },
  {
    "country": "MX",
    "name": "Zacualpan",
    "lat": "21.24715",
    "lng": "-105.1657"
  },
  {
    "country": "MX",
    "name": "Zacualpan",
    "lat": "17.08895",
    "lng": "-100.3259"
  },
  {
    "country": "MX",
    "name": "Zacoalco de Torres",
    "lat": "20.22816",
    "lng": "-103.5687"
  },
  {
    "country": "MX",
    "name": "Zacatecas",
    "lat": "22.76843",
    "lng": "-102.58141"
  },
  {
    "country": "MX",
    "name": "Zacapú",
    "lat": "19.81396",
    "lng": "-101.79157"
  },
  {
    "country": "MX",
    "name": "Yuriria",
    "lat": "20.21081",
    "lng": "-101.13212"
  },
  {
    "country": "MX",
    "name": "Yurécuaro",
    "lat": "20.33606",
    "lng": "-102.28382"
  },
  {
    "country": "MX",
    "name": "Yerbabuena",
    "lat": "20.96319",
    "lng": "-101.27448"
  },
  {
    "country": "MX",
    "name": "Yavaros",
    "lat": "26.70483",
    "lng": "-109.52103"
  },
  {
    "country": "MX",
    "name": "Yahualica de González Gallo",
    "lat": "21.17978",
    "lng": "-102.88611"
  },
  {
    "country": "MX",
    "name": "Yago",
    "lat": "21.83601",
    "lng": "-105.06451"
  },
  {
    "country": "MX",
    "name": "Vista Hermosa de Negrete",
    "lat": "20.27169",
    "lng": "-102.47488"
  },
  {
    "country": "MX",
    "name": "Villa Unión",
    "lat": "28.22228",
    "lng": "-100.72624"
  },
  {
    "country": "MX",
    "name": "Villa Union",
    "lat": "28.21667",
    "lng": "-100.71667"
  },
  {
    "country": "MX",
    "name": "Villa Unión",
    "lat": "23.9746",
    "lng": "-104.04705"
  },
  {
    "country": "MX",
    "name": "Villa Unión",
    "lat": "23.18992",
    "lng": "-106.21947"
  },
  {
    "country": "MX",
    "name": "Villa Pesqueira",
    "lat": "29.11813",
    "lng": "-109.96753"
  },
  {
    "country": "MX",
    "name": "Villa Ocampo",
    "lat": "26.44085",
    "lng": "-105.5064"
  },
  {
    "country": "MX",
    "name": "Cañadas de Obregón",
    "lat": "21.14925",
    "lng": "-102.68735"
  },
  {
    "country": "MX",
    "name": "Villanueva",
    "lat": "22.35527",
    "lng": "-102.88264"
  },
  {
    "country": "MX",
    "name": "Villamar",
    "lat": "20.0204",
    "lng": "-102.59655"
  },
  {
    "country": "MX",
    "name": "Francisco I. Madero",
    "lat": "24.40091",
    "lng": "-104.3198"
  },
  {
    "country": "MX",
    "name": "Villa Madero",
    "lat": "19.3915",
    "lng": "-101.27883"
  },
  {
    "country": "MX",
    "name": "López",
    "lat": "27.00245",
    "lng": "-105.03446"
  },
  {
    "country": "MX",
    "name": "Ciudad de Villaldama",
    "lat": "26.49952",
    "lng": "-100.42508"
  },
  {
    "country": "MX",
    "name": "Juárez",
    "lat": "27.60747",
    "lng": "-100.72664"
  },
  {
    "country": "MX",
    "name": "Villa Juárez",
    "lat": "27.12851",
    "lng": "-109.83921"
  },
  {
    "country": "MX",
    "name": "Villa Juárez",
    "lat": "21.68917",
    "lng": "-105.38972"
  },
  {
    "country": "MX",
    "name": "Villa Hidalgo",
    "lat": "26.24833",
    "lng": "-104.91441"
  },
  {
    "country": "MX",
    "name": "Villa Hidalgo",
    "lat": "22.35682",
    "lng": "-101.71259"
  },
  {
    "country": "MX",
    "name": "Villa Hidalgo",
    "lat": "21.74185",
    "lng": "-105.23096"
  },
  {
    "country": "MX",
    "name": "Villa Hidalgo",
    "lat": "21.67616",
    "lng": "-102.58803"
  },
  {
    "country": "MX",
    "name": "Villa Guerrero",
    "lat": "21.98341",
    "lng": "-103.59506"
  },
  {
    "country": "MX",
    "name": "Villagrán",
    "lat": "20.51452",
    "lng": "-100.99745"
  },
  {
    "country": "MX",
    "name": "Villa González Ortega",
    "lat": "22.51222",
    "lng": "-101.91616"
  },
  {
    "country": "MX",
    "name": "Villa García",
    "lat": "22.16169",
    "lng": "-101.95556"
  },
  {
    "country": "MX",
    "name": "Frontera",
    "lat": "26.92814",
    "lng": "-101.45212"
  },
  {
    "country": "MX",
    "name": "Escobedo",
    "lat": "27.23372",
    "lng": "-101.41314"
  },
  {
    "country": "MX",
    "name": "Santa Clara del Cobre",
    "lat": "19.4058",
    "lng": "-101.63998"
  },
  {
    "country": "MX",
    "name": "Villa de Reyes",
    "lat": "21.80309",
    "lng": "-100.93418"
  },
  {
    "country": "MX",
    "name": "El Pueblito",
    "lat": "20.53996",
    "lng": "-100.43817"
  },
  {
    "country": "MX",
    "name": "Villa Hidalgo",
    "lat": "22.45049",
    "lng": "-100.67827"
  },
  {
    "country": "MX",
    "name": "Villa de Guadalupe",
    "lat": "23.37384",
    "lng": "-100.75703"
  },
  {
    "country": "MX",
    "name": "García",
    "lat": "25.81201",
    "lng": "-100.59874"
  },
  {
    "country": "MX",
    "name": "Villa de Cos",
    "lat": "23.29329",
    "lng": "-102.3502"
  },
  {
    "country": "MX",
    "name": "Ciudad de Villa de Álvarez",
    "lat": "19.26722",
    "lng": "-103.73778"
  },
  {
    "country": "MX",
    "name": "Coronado",
    "lat": "26.73839",
    "lng": "-105.15902"
  },
  {
    "country": "MX",
    "name": "Villa Corona",
    "lat": "20.41564",
    "lng": "-103.66416"
  },
  {
    "country": "MX",
    "name": "Villachuato",
    "lat": "20.14848",
    "lng": "-101.6346"
  },
  {
    "country": "MX",
    "name": "San José Villa de Allende",
    "lat": "19.37521",
    "lng": "-100.1485"
  },
  {
    "country": "MX",
    "name": "Miguel Ahumada",
    "lat": "30.61861",
    "lng": "-106.51222"
  },
  {
    "country": "MX",
    "name": "El Vegil",
    "lat": "20.43111",
    "lng": "-100.35024"
  },
  {
    "country": "MX",
    "name": "Viesca",
    "lat": "25.33923",
    "lng": "-102.80493"
  },
  {
    "country": "MX",
    "name": "El Vergel",
    "lat": "25.63965",
    "lng": "-103.52139"
  },
  {
    "country": "MX",
    "name": "Ejido Venustiano Carranza",
    "lat": "25.35091",
    "lng": "-102.95698"
  },
  {
    "country": "MX",
    "name": "Venustiano Carranza",
    "lat": "20.11553",
    "lng": "-102.65391"
  },
  {
    "country": "MX",
    "name": "San Gabriel",
    "lat": "19.74795",
    "lng": "-103.76731"
  },
  {
    "country": "MX",
    "name": "Venado",
    "lat": "22.92997",
    "lng": "-101.09537"
  },
  {
    "country": "MX",
    "name": "Veinte de Noviembre",
    "lat": "25.71193",
    "lng": "-103.3296"
  },
  {
    "country": "MX",
    "name": "Vanegas",
    "lat": "23.88459",
    "lng": "-100.95148"
  },
  {
    "country": "MX",
    "name": "Valtierrilla",
    "lat": "20.53244",
    "lng": "-101.12761"
  },
  {
    "country": "MX",
    "name": "Valparaíso",
    "lat": "22.77104",
    "lng": "-103.56991"
  },
  {
    "country": "MX",
    "name": "Valle de Zaragoza",
    "lat": "27.45066",
    "lng": "-105.80847"
  },
  {
    "country": "MX",
    "name": "Valle de Santiago",
    "lat": "20.3914",
    "lng": "-101.19222"
  },
  {
    "country": "MX",
    "name": "Valle del Rosario",
    "lat": "27.31881",
    "lng": "-106.29551"
  },
  {
    "country": "MX",
    "name": "Valle de Juárez",
    "lat": "19.93248",
    "lng": "-102.94358"
  },
  {
    "country": "MX",
    "name": "Valle de Guadalupe",
    "lat": "21.01114",
    "lng": "-102.61683"
  },
  {
    "country": "MX",
    "name": "Valle de Bravo",
    "lat": "19.19501",
    "lng": "-100.13132"
  },
  {
    "country": "MX",
    "name": "Valle de Banderas",
    "lat": "20.80792",
    "lng": "-105.24813"
  },
  {
    "country": "MX",
    "name": "Valle de Allende",
    "lat": "26.93527",
    "lng": "-105.39271"
  },
  {
    "country": "MX",
    "name": "Valentín Gómez Farías",
    "lat": "28.21667",
    "lng": "-106.58333"
  },
  {
    "country": "MX",
    "name": "Valencia de Cerro Gordo",
    "lat": "20.60133",
    "lng": "-101.08173"
  },
  {
    "country": "MX",
    "name": "Usmajac",
    "lat": "19.87458",
    "lng": "-103.54085"
  },
  {
    "country": "MX",
    "name": "Uruapan",
    "lat": "19.41116",
    "lng": "-102.05644"
  },
  {
    "country": "MX",
    "name": "Uruachi",
    "lat": "27.86715",
    "lng": "-108.21517"
  },
  {
    "country": "MX",
    "name": "Urique",
    "lat": "27.21122",
    "lng": "-107.91415"
  },
  {
    "country": "MX",
    "name": "Uriangato",
    "lat": "20.14085",
    "lng": "-101.18251"
  },
  {
    "country": "MX",
    "name": "Ures",
    "lat": "29.42708",
    "lng": "-110.3876"
  },
  {
    "country": "MX",
    "name": "Unión de Tula",
    "lat": "19.95646",
    "lng": "-104.26805"
  },
  {
    "country": "MX",
    "name": "Unión de San Antonio",
    "lat": "21.12714",
    "lng": "-102.00619"
  },
  {
    "country": "MX",
    "name": "Tzitzio",
    "lat": "19.58582",
    "lng": "-100.92472"
  },
  {
    "country": "MX",
    "name": "Tzintzuntzán",
    "lat": "19.62847",
    "lng": "-101.57831"
  },
  {
    "country": "MX",
    "name": "Tuzantla",
    "lat": "19.20289",
    "lng": "-100.56679"
  },
  {
    "country": "MX",
    "name": "Tuxpan",
    "lat": "21.94221",
    "lng": "-105.2987"
  },
  {
    "country": "MX",
    "name": "Tuxpan",
    "lat": "19.56788",
    "lng": "-100.46189"
  },
  {
    "country": "MX",
    "name": "Tuxpan",
    "lat": "19.55555",
    "lng": "-103.37587"
  },
  {
    "country": "MX",
    "name": "Tuxcueca",
    "lat": "20.15401",
    "lng": "-103.18502"
  },
  {
    "country": "MX",
    "name": "Tuxcacuesco",
    "lat": "19.69848",
    "lng": "-103.98429"
  },
  {
    "country": "MX",
    "name": "Turicato",
    "lat": "19.05402",
    "lng": "-101.41899"
  },
  {
    "country": "MX",
    "name": "Tumbiscatío de Ruiz",
    "lat": "18.52667",
    "lng": "-102.37823"
  },
  {
    "country": "MX",
    "name": "Tubutama",
    "lat": "30.88458",
    "lng": "-111.46514"
  },
  {
    "country": "MX",
    "name": "Tres Mezquites",
    "lat": "20.26203",
    "lng": "-101.62735"
  },
  {
    "country": "MX",
    "name": "Trapiche de Abra",
    "lat": "20.53958",
    "lng": "-103.81977"
  },
  {
    "country": "MX",
    "name": "Trancoso",
    "lat": "22.73542",
    "lng": "-102.36697"
  },
  {
    "country": "MX",
    "name": "Tototlán",
    "lat": "20.54217",
    "lng": "-102.79222"
  },
  {
    "country": "MX",
    "name": "Totatiche",
    "lat": "21.9284",
    "lng": "-103.44405"
  },
  {
    "country": "MX",
    "name": "Torreón",
    "lat": "25.54389",
    "lng": "-103.41898"
  },
  {
    "country": "MX",
    "name": "Topolobampo",
    "lat": "25.60084",
    "lng": "-109.0523"
  },
  {
    "country": "MX",
    "name": "Topia",
    "lat": "25.2109",
    "lng": "-106.57134"
  },
  {
    "country": "MX",
    "name": "Tonila",
    "lat": "19.43365",
    "lng": "-103.51657"
  },
  {
    "country": "MX",
    "name": "Tonaya",
    "lat": "19.78634",
    "lng": "-103.97122"
  },
  {
    "country": "MX",
    "name": "Tonalá",
    "lat": "20.62445",
    "lng": "-103.23423"
  },
  {
    "country": "MX",
    "name": "Tomendán",
    "lat": "19.31142",
    "lng": "-101.8603"
  },
  {
    "country": "MX",
    "name": "Tomatlán",
    "lat": "19.93664",
    "lng": "-105.2501"
  },
  {
    "country": "MX",
    "name": "Tolimán",
    "lat": "19.6014",
    "lng": "-103.91522"
  },
  {
    "country": "MX",
    "name": "Todos Santos",
    "lat": "23.44688",
    "lng": "-110.22308"
  },
  {
    "country": "MX",
    "name": "Tlazazalca",
    "lat": "19.97085",
    "lng": "-102.05842"
  },
  {
    "country": "MX",
    "name": "Tlatlaya",
    "lat": "18.61773",
    "lng": "-100.20779"
  },
  {
    "country": "MX",
    "name": "Tlaquepaque",
    "lat": "20.64091",
    "lng": "-103.29327"
  },
  {
    "country": "MX",
    "name": "Tlapehuala",
    "lat": "18.24101",
    "lng": "-100.5379"
  },
  {
    "country": "MX",
    "name": "Tlalpujahua de Rayón",
    "lat": "19.80523",
    "lng": "-100.17409"
  },
  {
    "country": "MX",
    "name": "Tlalchapa",
    "lat": "18.41027",
    "lng": "-100.47623"
  },
  {
    "country": "MX",
    "name": "Tlajomulco de Zúñiga",
    "lat": "20.47421",
    "lng": "-103.44654"
  },
  {
    "country": "MX",
    "name": "Tlahualilo de Zaragoza",
    "lat": "26.10593",
    "lng": "-103.44257"
  },
  {
    "country": "MX",
    "name": "Tlacote el Bajo",
    "lat": "20.66139",
    "lng": "-100.50769"
  },
  {
    "country": "MX",
    "name": "Tizapán el Alto",
    "lat": "20.16137",
    "lng": "-103.04397"
  },
  {
    "country": "MX",
    "name": "Tiquicheo",
    "lat": "18.90301",
    "lng": "-100.73731"
  },
  {
    "country": "MX",
    "name": "Tingüindín",
    "lat": "19.73921",
    "lng": "-102.4812"
  },
  {
    "country": "MX",
    "name": "Tingambato",
    "lat": "19.50109",
    "lng": "-101.85327"
  },
  {
    "country": "MX",
    "name": "Tijuana",
    "lat": "32.5027",
    "lng": "-117.00371"
  },
  {
    "country": "MX",
    "name": "Tierra Nueva",
    "lat": "21.66904",
    "lng": "-100.57287"
  },
  {
    "country": "MX",
    "name": "Tierra Blanca",
    "lat": "21.10006",
    "lng": "-100.15931"
  },
  {
    "country": "MX",
    "name": "Teúl de González Ortega",
    "lat": "21.4634",
    "lng": "-103.46131"
  },
  {
    "country": "MX",
    "name": "Teuchitlán",
    "lat": "20.68476",
    "lng": "-103.8492"
  },
  {
    "country": "MX",
    "name": "Tesistán",
    "lat": "20.80051",
    "lng": "-103.46993"
  },
  {
    "country": "MX",
    "name": "Tequila",
    "lat": "20.88205",
    "lng": "-103.83599"
  },
  {
    "country": "MX",
    "name": "Tepic",
    "lat": "21.50951",
    "lng": "-104.89569"
  },
  {
    "country": "MX",
    "name": "Tepezalá",
    "lat": "22.22393",
    "lng": "-102.1696"
  },
  {
    "country": "MX",
    "name": "Tepetongo",
    "lat": "22.45847",
    "lng": "-103.1512"
  },
  {
    "country": "MX",
    "name": "Tepechitlán",
    "lat": "21.67063",
    "lng": "-103.3264"
  },
  {
    "country": "MX",
    "name": "Tepec",
    "lat": "19.98964",
    "lng": "-103.64116"
  },
  {
    "country": "MX",
    "name": "Tepatitlán de Morelos",
    "lat": "20.81692",
    "lng": "-102.76347"
  },
  {
    "country": "MX",
    "name": "Tepalcatepec",
    "lat": "19.18666",
    "lng": "-102.8493"
  },
  {
    "country": "MX",
    "name": "Tepache",
    "lat": "29.53275",
    "lng": "-109.53134"
  },
  {
    "country": "MX",
    "name": "Teocuitatlán de Corona",
    "lat": "20.09223",
    "lng": "-103.378"
  },
  {
    "country": "MX",
    "name": "Teocaltiche",
    "lat": "21.43421",
    "lng": "-102.57449"
  },
  {
    "country": "MX",
    "name": "Tenería del Santuario",
    "lat": "20.59955",
    "lng": "-100.7979"
  },
  {
    "country": "MX",
    "name": "Tenamaxtlán",
    "lat": "20.21742",
    "lng": "-104.16459"
  },
  {
    "country": "MX",
    "name": "Temósachic",
    "lat": "28.95469",
    "lng": "-107.82957"
  },
  {
    "country": "MX",
    "name": "Témoris",
    "lat": "27.27569",
    "lng": "-108.27946"
  },
  {
    "country": "MX",
    "name": "Temascaltepec de González",
    "lat": "19.04409",
    "lng": "-100.04236"
  },
  {
    "country": "MX",
    "name": "Tejupilco de Hidalgo",
    "lat": "18.90475",
    "lng": "-100.15275"
  },
  {
    "country": "MX",
    "name": "Tecuala",
    "lat": "22.39815",
    "lng": "-105.45808"
  },
  {
    "country": "MX",
    "name": "Técpan de Galeana",
    "lat": "17.21976",
    "lng": "-100.63032"
  },
  {
    "country": "MX",
    "name": "Tecomatán",
    "lat": "20.11514",
    "lng": "-102.49634"
  },
  {
    "country": "MX",
    "name": "Tecomán",
    "lat": "18.91678",
    "lng": "-103.87786"
  },
  {
    "country": "MX",
    "name": "Tecolots",
    "lat": "32.56667",
    "lng": "-114.98333"
  },
  {
    "country": "MX",
    "name": "Tecolotlán",
    "lat": "20.20167",
    "lng": "-104.04748"
  },
  {
    "country": "MX",
    "name": "Techaluta de Montenegro",
    "lat": "20.07316",
    "lng": "-103.55118"
  },
  {
    "country": "MX",
    "name": "Tecate",
    "lat": "32.56717",
    "lng": "-116.62509"
  },
  {
    "country": "MX",
    "name": "Tecalitlán",
    "lat": "19.47182",
    "lng": "-103.3072"
  },
  {
    "country": "MX",
    "name": "Teacapan",
    "lat": "22.53959",
    "lng": "-105.73623"
  },
  {
    "country": "MX",
    "name": "Tayoltita",
    "lat": "24.10278",
    "lng": "-105.93083"
  },
  {
    "country": "MX",
    "name": "Tarimoro",
    "lat": "20.28336",
    "lng": "-100.75477"
  },
  {
    "country": "MX",
    "name": "Campestre Tarímbaro",
    "lat": "19.775",
    "lng": "-101.12917"
  },
  {
    "country": "MX",
    "name": "Taretán",
    "lat": "19.3342",
    "lng": "-101.91849"
  },
  {
    "country": "MX",
    "name": "Tarandacuao",
    "lat": "20.00094",
    "lng": "-100.51856"
  },
  {
    "country": "MX",
    "name": "Tapeixtles",
    "lat": "19.06912",
    "lng": "-104.28339"
  },
  {
    "country": "MX",
    "name": "Tapalpa",
    "lat": "19.94563",
    "lng": "-103.75954"
  },
  {
    "country": "MX",
    "name": "Tanhuato de Guerrero",
    "lat": "20.28552",
    "lng": "-102.33113"
  },
  {
    "country": "MX",
    "name": "Tangancícuaro de Arista",
    "lat": "19.88733",
    "lng": "-102.20636"
  },
  {
    "country": "MX",
    "name": "Tancítaro",
    "lat": "19.33843",
    "lng": "-102.36264"
  },
  {
    "country": "MX",
    "name": "Tamazula de Gordiano",
    "lat": "19.68006",
    "lng": "-103.2514"
  },
  {
    "country": "MX",
    "name": "Tamazula",
    "lat": "25.44639",
    "lng": "-108.45528"
  },
  {
    "country": "MX",
    "name": "Tamazula de Victoria",
    "lat": "24.96818",
    "lng": "-106.96717"
  },
  {
    "country": "MX",
    "name": "Tamándaro",
    "lat": "19.94941",
    "lng": "-102.28416"
  },
  {
    "country": "MX",
    "name": "Talpa de Allende",
    "lat": "20.38084",
    "lng": "-104.82213"
  },
  {
    "country": "MX",
    "name": "Tala",
    "lat": "20.6536",
    "lng": "-103.70092"
  },
  {
    "country": "MX",
    "name": "Tacuro (Santa María Tacuro)",
    "lat": "19.85696",
    "lng": "-102.05084"
  },
  {
    "country": "MX",
    "name": "Tacoaleche",
    "lat": "22.8201",
    "lng": "-102.40476"
  },
  {
    "country": "MX",
    "name": "Tacámbaro de Codallos",
    "lat": "19.23502",
    "lng": "-101.45824"
  },
  {
    "country": "MX",
    "name": "Tabasco",
    "lat": "21.86286",
    "lng": "-102.91105"
  },
  {
    "country": "MX",
    "name": "Susupuato de Guerrero",
    "lat": "19.21505",
    "lng": "-100.40798"
  },
  {
    "country": "MX",
    "name": "Susticacán",
    "lat": "22.60937",
    "lng": "-103.09671"
  },
  {
    "country": "MX",
    "name": "Suchitlán",
    "lat": "20.5332",
    "lng": "-101.0236"
  },
  {
    "country": "MX",
    "name": "Suchitlán",
    "lat": "19.37541",
    "lng": "-103.71141"
  },
  {
    "country": "MX",
    "name": "Súchil",
    "lat": "23.62193",
    "lng": "-103.9232"
  },
  {
    "country": "MX",
    "name": "Suaqui Grande",
    "lat": "28.39383",
    "lng": "-109.88798"
  },
  {
    "country": "MX",
    "name": "Soyopa",
    "lat": "28.76424",
    "lng": "-109.63453"
  },
  {
    "country": "MX",
    "name": "Soyatlán del Oro",
    "lat": "20.30194",
    "lng": "-104.28056"
  },
  {
    "country": "MX",
    "name": "Sonoita",
    "lat": "31.86165",
    "lng": "-112.85129"
  },
  {
    "country": "MX",
    "name": "Sombrerete",
    "lat": "23.63466",
    "lng": "-103.64244"
  },
  {
    "country": "MX",
    "name": "Soledad de Graciano Sánchez",
    "lat": "22.18912",
    "lng": "-100.93792"
  },
  {
    "country": "MX",
    "name": "Socavón (El Carmen)",
    "lat": "21.85139",
    "lng": "-100.87184"
  },
  {
    "country": "MX",
    "name": "Siqueros",
    "lat": "23.34177",
    "lng": "-106.24124"
  },
  {
    "country": "MX",
    "name": "Sinaloa de Leyva",
    "lat": "25.8219",
    "lng": "-108.22261"
  },
  {
    "country": "MX",
    "name": "Sinahuiza",
    "lat": "26.91105",
    "lng": "-109.43901"
  },
  {
    "country": "MX",
    "name": "Silao",
    "lat": "20.94356",
    "lng": "-101.42703"
  },
  {
    "country": "MX",
    "name": "Sierra Mojada",
    "lat": "27.28861",
    "lng": "-103.70124"
  },
  {
    "country": "MX",
    "name": "Sevina",
    "lat": "19.62898",
    "lng": "-101.90057"
  },
  {
    "country": "MX",
    "name": "Serrano",
    "lat": "20.7783",
    "lng": "-101.3954"
  },
  {
    "country": "MX",
    "name": "Senguio",
    "lat": "19.73417",
    "lng": "-100.35385"
  },
  {
    "country": "MX",
    "name": "Sayula",
    "lat": "19.88225",
    "lng": "-103.60027"
  },
  {
    "country": "MX",
    "name": "Saucillo",
    "lat": "28.03055",
    "lng": "-105.29376"
  },
  {
    "country": "MX",
    "name": "Sáric",
    "lat": "31.10328",
    "lng": "-111.37931"
  },
  {
    "country": "MX",
    "name": "Sapioris",
    "lat": "25.45248",
    "lng": "-103.71612"
  },
  {
    "country": "MX",
    "name": "San Vicente",
    "lat": "21.95043",
    "lng": "-105.2971"
  },
  {
    "country": "MX",
    "name": "Santo Tomás de los Plátanos",
    "lat": "19.18179",
    "lng": "-100.26026"
  },
  {
    "country": "MX",
    "name": "Santo Tomás Huatzindeo",
    "lat": "20.22205",
    "lng": "-100.92068"
  },
  {
    "country": "MX",
    "name": "Santo Tomás",
    "lat": "19.84524",
    "lng": "-102.08571"
  },
  {
    "country": "MX",
    "name": "Santo Domingo",
    "lat": "23.3267",
    "lng": "-101.7361"
  },
  {
    "country": "MX",
    "name": "Ejido la Pitahaya (Santo Domingo)",
    "lat": "21.60611",
    "lng": "-100.76111"
  },
  {
    "country": "MX",
    "name": "Santiaguito (Santiaguito de Velázquez)",
    "lat": "20.72533",
    "lng": "-102.23716"
  },
  {
    "country": "MX",
    "name": "Santiago Tangamandapio",
    "lat": "19.95568",
    "lng": "-102.43546"
  },
  {
    "country": "MX",
    "name": "Santiago Papasquiaro",
    "lat": "25.04389",
    "lng": "-105.41917"
  },
  {
    "country": "MX",
    "name": "Santiago Maravatío",
    "lat": "20.17297",
    "lng": "-100.99468"
  },
  {
    "country": "MX",
    "name": "Santiago Ixcuintla",
    "lat": "21.81295",
    "lng": "-105.20844"
  },
  {
    "country": "MX",
    "name": "Santiago de Cuenda",
    "lat": "20.59956",
    "lng": "-100.99405"
  },
  {
    "country": "MX",
    "name": "Santiago",
    "lat": "25.42533",
    "lng": "-100.15205"
  },
  {
    "country": "MX",
    "name": "Santiago",
    "lat": "22.45477",
    "lng": "-101.45898"
  },
  {
    "country": "MX",
    "name": "Santa Teresa",
    "lat": "22.4973",
    "lng": "-104.76547"
  },
  {
    "country": "MX",
    "name": "Santa Teresa",
    "lat": "20.95973",
    "lng": "-101.31644"
  },
  {
    "country": "MX",
    "name": "Santa Rosalía",
    "lat": "27.34045",
    "lng": "-112.26761"
  },
  {
    "country": "MX",
    "name": "Santa Rosa Jauregui",
    "lat": "20.74122",
    "lng": "-100.44843"
  },
  {
    "country": "MX",
    "name": "José María Morelos (Santa Mónica)",
    "lat": "23.60556",
    "lng": "-103.11028"
  },
  {
    "country": "MX",
    "name": "Otaéz",
    "lat": "24.70034",
    "lng": "-105.9957"
  },
  {
    "country": "MX",
    "name": "Santa María del Río",
    "lat": "21.79615",
    "lng": "-100.73815"
  },
  {
    "country": "MX",
    "name": "Santa María de los Ángeles",
    "lat": "22.17361",
    "lng": "-103.22456"
  },
  {
    "country": "MX",
    "name": "Santa María del Oro",
    "lat": "25.94944",
    "lng": "-105.36444"
  },
  {
    "country": "MX",
    "name": "Santa María del Oro",
    "lat": "21.3339",
    "lng": "-104.58696"
  },
  {
    "country": "MX",
    "name": "Veinte de Noviembre (Santa Lucía)",
    "lat": "25.78923",
    "lng": "-103.15127"
  },
  {
    "country": "MX",
    "name": "José Guadalupe Aguilera (Santa Lucía)",
    "lat": "24.4542",
    "lng": "-104.70888"
  },
  {
    "country": "MX",
    "name": "Santa Fé de la Laguna",
    "lat": "19.67257",
    "lng": "-101.55487"
  },
  {
    "country": "MX",
    "name": "Santa Cruz el Grande",
    "lat": "20.37514",
    "lng": "-102.86382"
  },
  {
    "country": "MX",
    "name": "Santa Cruz del Valle",
    "lat": "20.53333",
    "lng": "-103.43333"
  },
  {
    "country": "MX",
    "name": "Santa Cruz de las Flores",
    "lat": "20.48056",
    "lng": "-103.50278"
  },
  {
    "country": "MX",
    "name": "Santa Clara",
    "lat": "24.475",
    "lng": "-103.35694"
  },
  {
    "country": "MX",
    "name": "Santa Catarina de Tepehuanes",
    "lat": "25.33961",
    "lng": "-105.72445"
  },
  {
    "country": "MX",
    "name": "Santa Catarina",
    "lat": "25.67325",
    "lng": "-100.45813"
  },
  {
    "country": "MX",
    "name": "Xichú",
    "lat": "21.29931",
    "lng": "-100.0574"
  },
  {
    "country": "MX",
    "name": "Santa Bárbara",
    "lat": "26.80381",
    "lng": "-105.82024"
  },
  {
    "country": "MX",
    "name": "Santa Anita",
    "lat": "20.5509",
    "lng": "-103.44396"
  },
  {
    "country": "MX",
    "name": "Santa Ana Zirosto",
    "lat": "19.53512",
    "lng": "-102.32442"
  },
  {
    "country": "MX",
    "name": "Santa Ana Pacueco",
    "lat": "20.34722",
    "lng": "-102.01583"
  },
  {
    "country": "MX",
    "name": "Santa Ana Maya",
    "lat": "20.0069",
    "lng": "-101.02189"
  },
  {
    "country": "MX",
    "name": "Santa Ana Amatlán",
    "lat": "19.16097",
    "lng": "-102.54059"
  },
  {
    "country": "MX",
    "name": "Santa Ana",
    "lat": "30.54075",
    "lng": "-111.11888"
  },
  {
    "country": "MX",
    "name": "San Simón de la Laguna",
    "lat": "19.29273",
    "lng": "-100.0807"
  },
  {
    "country": "MX",
    "name": "San Simón de Guerrero",
    "lat": "19.02276",
    "lng": "-100.00645"
  },
  {
    "country": "MX",
    "name": "San Sebastián el Grande",
    "lat": "20.51667",
    "lng": "-103.41667"
  },
  {
    "country": "MX",
    "name": "San Sebastián del Oeste",
    "lat": "20.76183",
    "lng": "-104.85273"
  },
  {
    "country": "MX",
    "name": "El Salvador",
    "lat": "24.52093",
    "lng": "-100.86631"
  },
  {
    "country": "MX",
    "name": "San Roque de Torres",
    "lat": "20.97138",
    "lng": "-101.8529"
  },
  {
    "country": "MX",
    "name": "San Quintín",
    "lat": "30.5606",
    "lng": "-115.94464"
  },
  {
    "country": "MX",
    "name": "San Pedro Piedra Gorda",
    "lat": "22.44753",
    "lng": "-102.34875"
  },
  {
    "country": "MX",
    "name": "San Pedro Lagunillas",
    "lat": "21.2192",
    "lng": "-104.75228"
  },
  {
    "country": "MX",
    "name": "San Pedro Itzicán",
    "lat": "20.31724",
    "lng": "-102.95406"
  },
  {
    "country": "MX",
    "name": "San Pedro de los Naranjos",
    "lat": "20.22716",
    "lng": "-100.93782"
  },
  {
    "country": "MX",
    "name": "San Pedro del Gallo",
    "lat": "25.56411",
    "lng": "-104.29284"
  },
  {
    "country": "MX",
    "name": "San Pedro",
    "lat": "25.75602",
    "lng": "-102.98385"
  },
  {
    "country": "MX",
    "name": "San Pedro de la Cueva",
    "lat": "29.28684",
    "lng": "-109.73696"
  },
  {
    "country": "MX",
    "name": "Apulco",
    "lat": "21.38824",
    "lng": "-102.68219"
  },
  {
    "country": "MX",
    "name": "San Pedro",
    "lat": "25.43333",
    "lng": "-103.21667"
  },
  {
    "country": "MX",
    "name": "San Patricio",
    "lat": "19.22534",
    "lng": "-104.70447"
  },
  {
    "country": "MX",
    "name": "Balleza",
    "lat": "26.95154",
    "lng": "-106.34921"
  },
  {
    "country": "MX",
    "name": "San Nicolás Tolentino",
    "lat": "22.24898",
    "lng": "-100.5524"
  },
  {
    "country": "MX",
    "name": "San Nicolás de los Garza",
    "lat": "25.74167",
    "lng": "-100.30222"
  },
  {
    "country": "MX",
    "name": "San Nicolás Tolentino",
    "lat": "19.18472",
    "lng": "-100.24111"
  },
  {
    "country": "MX",
    "name": "San Miguel Zapotitlan",
    "lat": "25.94831",
    "lng": "-109.04738"
  },
  {
    "country": "MX",
    "name": "San Miguel Totolapan",
    "lat": "18.16132",
    "lng": "-100.39049"
  },
  {
    "country": "MX",
    "name": "San Miguel Octopan",
    "lat": "20.57428",
    "lng": "-100.7478"
  },
  {
    "country": "MX",
    "name": "San Miguel el Alto",
    "lat": "21.03011",
    "lng": "-102.40414"
  },
  {
    "country": "MX",
    "name": "San Miguel de Papasquiaro",
    "lat": "24.83078",
    "lng": "-105.3364"
  },
  {
    "country": "MX",
    "name": "San Miguel de Horcasitas",
    "lat": "29.48737",
    "lng": "-110.72479"
  },
  {
    "country": "MX",
    "name": "San Miguel de Allende",
    "lat": "20.91528",
    "lng": "-100.74389"
  },
  {
    "country": "MX",
    "name": "San Martín Hidalgo",
    "lat": "20.43538",
    "lng": "-103.92878"
  },
  {
    "country": "MX",
    "name": "San Marcos",
    "lat": "25.66667",
    "lng": "-103.0091"
  },
  {
    "country": "MX",
    "name": "San Marcos",
    "lat": "20.79269",
    "lng": "-104.19682"
  },
  {
    "country": "MX",
    "name": "San Marcos",
    "lat": "19.44611",
    "lng": "-103.50639"
  },
  {
    "country": "MX",
    "name": "San Luis Río Colorado",
    "lat": "32.45612",
    "lng": "-114.77186"
  },
  {
    "country": "MX",
    "name": "San Luis Potosí",
    "lat": "22.14982",
    "lng": "-100.97916"
  },
  {
    "country": "MX",
    "name": "San Luis del Cordero",
    "lat": "25.4151",
    "lng": "-104.27844"
  },
  {
    "country": "MX",
    "name": "San Luis de la Paz",
    "lat": "21.29771",
    "lng": "-100.51736"
  },
  {
    "country": "MX",
    "name": "San Luis",
    "lat": "28.43333",
    "lng": "-113.75"
  },
  {
    "country": "MX",
    "name": "San Lucas del Pulque",
    "lat": "19.10139",
    "lng": "-100.02806"
  },
  {
    "country": "MX",
    "name": "Cabo San Lucas",
    "lat": "22.89088",
    "lng": "-109.91238"
  },
  {
    "country": "MX",
    "name": "San Lucas Evangelista",
    "lat": "20.40815",
    "lng": "-103.3608"
  },
  {
    "country": "MX",
    "name": "San Lucas",
    "lat": "18.59031",
    "lng": "-100.78529"
  },
  {
    "country": "MX",
    "name": "San Julián",
    "lat": "21.01035",
    "lng": "-102.17967"
  },
  {
    "country": "MX",
    "name": "San Juan de Sabinas",
    "lat": "27.92942",
    "lng": "-101.30495"
  },
  {
    "country": "MX",
    "name": "San Juan del Rio del Centauro del Norte",
    "lat": "24.77824",
    "lng": "-104.45833"
  },
  {
    "country": "MX",
    "name": "San Juan de los Lagos",
    "lat": "21.24893",
    "lng": "-102.33036"
  },
  {
    "country": "MX",
    "name": "San Juan de la Vega",
    "lat": "20.62521",
    "lng": "-100.76141"
  },
  {
    "country": "MX",
    "name": "San Juan de Guadalupe",
    "lat": "24.63273",
    "lng": "-102.7818"
  },
  {
    "country": "MX",
    "name": "San Juan de Abajo",
    "lat": "20.81484",
    "lng": "-105.19154"
  },
  {
    "country": "MX",
    "name": "San Juan Cosalá",
    "lat": "20.28756",
    "lng": "-103.34109"
  },
  {
    "country": "MX",
    "name": "San Juan de la Vaquería",
    "lat": "25.25333",
    "lng": "-101.21833"
  },
  {
    "country": "MX",
    "name": "Xoconoxtle el Grande",
    "lat": "20.93857",
    "lng": "-100.98149"
  },
  {
    "country": "MX",
    "name": "San José Temascatío",
    "lat": "20.69536",
    "lng": "-101.26487"
  },
  {
    "country": "MX",
    "name": "San José Iturbide",
    "lat": "21.00153",
    "lng": "-100.38416"
  },
  {
    "country": "MX",
    "name": "San José el Alto",
    "lat": "20.65339",
    "lng": "-100.38218"
  },
  {
    "country": "MX",
    "name": "San José de Viñedo",
    "lat": "25.64865",
    "lng": "-103.40255"
  },
  {
    "country": "MX",
    "name": "San José del Castillo",
    "lat": "20.51405",
    "lng": "-103.23796"
  },
  {
    "country": "MX",
    "name": "San José del Cabo",
    "lat": "23.05888",
    "lng": "-109.69771"
  },
  {
    "country": "MX",
    "name": "San José de Gracia",
    "lat": "20.67474",
    "lng": "-102.56989"
  },
  {
    "country": "MX",
    "name": "San José de Aura",
    "lat": "27.58778",
    "lng": "-101.3725"
  },
  {
    "country": "MX",
    "name": "Estación San José",
    "lat": "23.18972",
    "lng": "-102.78472"
  },
  {
    "country": "MX",
    "name": "San Jerónimo Totoltepec",
    "lat": "19.31494",
    "lng": "-100.2029"
  },
  {
    "country": "MX",
    "name": "San Jerónimo de Juárez",
    "lat": "17.13915",
    "lng": "-100.47067"
  },
  {
    "country": "MX",
    "name": "San Jeronimito",
    "lat": "17.56818",
    "lng": "-101.34562"
  },
  {
    "country": "MX",
    "name": "San Javier",
    "lat": "28.59574",
    "lng": "-109.7399"
  },
  {
    "country": "MX",
    "name": "San Ignacio de Hidalgo",
    "lat": "20.91167",
    "lng": "-101.86056"
  },
  {
    "country": "MX",
    "name": "San Ignacio",
    "lat": "23.94105",
    "lng": "-106.42467"
  },
  {
    "country": "MX",
    "name": "San Ignacio Cerro Gordo",
    "lat": "20.74558",
    "lng": "-102.53466"
  },
  {
    "country": "MX",
    "name": "Doctor Miguel Silva (San Guillermo)",
    "lat": "19.96583",
    "lng": "-101.17417"
  },
  {
    "country": "MX",
    "name": "San Gabriel",
    "lat": "21.0188",
    "lng": "-103.01417"
  },
  {
    "country": "MX",
    "name": "San Gabriel",
    "lat": "19.76667",
    "lng": "-104"
  },
  {
    "country": "MX",
    "name": "Pichátaro",
    "lat": "19.57289",
    "lng": "-101.80737"
  },
  {
    "country": "MX",
    "name": "San Francisco Peribán",
    "lat": "19.55601",
    "lng": "-102.39844"
  },
  {
    "country": "MX",
    "name": "San Francisco del Rincón",
    "lat": "21.01843",
    "lng": "-101.85515"
  },
  {
    "country": "MX",
    "name": "San Francisco de los Romo",
    "lat": "22.07748",
    "lng": "-102.2714"
  },
  {
    "country": "MX",
    "name": "El Oro",
    "lat": "26.8632",
    "lng": "-105.84838"
  },
  {
    "country": "MX",
    "name": "San Francisco de Horizonte (Horizonte)",
    "lat": "25.9369",
    "lng": "-103.41688"
  },
  {
    "country": "MX",
    "name": "Conchos",
    "lat": "27.58745",
    "lng": "-105.33358"
  },
  {
    "country": "MX",
    "name": "San Francisco de Borja",
    "lat": "27.90171",
    "lng": "-106.68562"
  },
  {
    "country": "MX",
    "name": "San Felipe",
    "lat": "31.02468",
    "lng": "-114.83919"
  },
  {
    "country": "MX",
    "name": "San Felipe de Jesús",
    "lat": "29.86151",
    "lng": "-110.23827"
  },
  {
    "country": "MX",
    "name": "San Felipe Aztatán",
    "lat": "22.38374",
    "lng": "-105.4198"
  },
  {
    "country": "MX",
    "name": "San Felipe",
    "lat": "21.47831",
    "lng": "-101.21566"
  },
  {
    "country": "MX",
    "name": "San Felipe de los Herreros",
    "lat": "19.61701",
    "lng": "-102.18128"
  },
  {
    "country": "MX",
    "name": "San Diego de la Unión",
    "lat": "21.46749",
    "lng": "-100.8731"
  },
  {
    "country": "MX",
    "name": "San Diego de Alejandría",
    "lat": "20.9937",
    "lng": "-101.99549"
  },
  {
    "country": "MX",
    "name": "San Cristóbal de la Barranca",
    "lat": "21.04459",
    "lng": "-103.42819"
  },
  {
    "country": "MX",
    "name": "San Cristóbal",
    "lat": "20.65787",
    "lng": "-101.47683"
  },
  {
    "country": "MX",
    "name": "Tlaltenango de Sánchez Román",
    "lat": "21.78221",
    "lng": "-103.30298"
  },
  {
    "country": "MX",
    "name": "San Carlos",
    "lat": "29.10665",
    "lng": "-103.90722"
  },
  {
    "country": "MX",
    "name": "San Buenaventura",
    "lat": "27.06193",
    "lng": "-101.54891"
  },
  {
    "country": "MX",
    "name": "San Blas",
    "lat": "26.08019",
    "lng": "-108.7611"
  },
  {
    "country": "MX",
    "name": "San Blas",
    "lat": "21.54333",
    "lng": "-105.28558"
  },
  {
    "country": "MX",
    "name": "San Bernardo",
    "lat": "26.00059",
    "lng": "-105.52446"
  },
  {
    "country": "MX",
    "name": "Francisco Serrato (San Bartolo)",
    "lat": "19.5068",
    "lng": "-100.26"
  },
  {
    "country": "MX",
    "name": "San Bartolo",
    "lat": "19.24496",
    "lng": "-100.05329"
  },
  {
    "country": "MX",
    "name": "San Antonio la Labor",
    "lat": "19.02942",
    "lng": "-102.30075"
  },
  {
    "country": "MX",
    "name": "San Antonio",
    "lat": "25.63868",
    "lng": "-100.05844"
  },
  {
    "country": "MX",
    "name": "San Andrés Ixtlán",
    "lat": "19.81988",
    "lng": "-103.46906"
  },
  {
    "country": "MX",
    "name": "San Andrés Ziróndaro",
    "lat": "19.66943",
    "lng": "-101.63221"
  },
  {
    "country": "MX",
    "name": "Sanalona",
    "lat": "24.80222",
    "lng": "-107.14"
  },
  {
    "country": "MX",
    "name": "San Agustín del Pulque",
    "lat": "19.96267",
    "lng": "-101.07327"
  },
  {
    "country": "MX",
    "name": "Nicolás R Casillas",
    "lat": "20.54638",
    "lng": "-103.46622"
  },
  {
    "country": "MX",
    "name": "Salvatierra",
    "lat": "20.21322",
    "lng": "-100.88023"
  },
  {
    "country": "MX",
    "name": "Tepuxtepec",
    "lat": "19.99135",
    "lng": "-100.22566"
  },
  {
    "country": "MX",
    "name": "Saltillo",
    "lat": "25.42321",
    "lng": "-101.0053"
  },
  {
    "country": "MX",
    "name": "El Salitre",
    "lat": "20.66596",
    "lng": "-100.42288"
  },
  {
    "country": "MX",
    "name": "Salitral de Carrera",
    "lat": "22.86605",
    "lng": "-102.08305"
  },
  {
    "country": "MX",
    "name": "Salinas Victoria",
    "lat": "25.96329",
    "lng": "-100.29091"
  },
  {
    "country": "MX",
    "name": "Salinas de Hidalgo",
    "lat": "22.62795",
    "lng": "-101.71417"
  },
  {
    "country": "MX",
    "name": "Salamanca",
    "lat": "20.57196",
    "lng": "-101.19154"
  },
  {
    "country": "MX",
    "name": "Sain Alto",
    "lat": "23.58086",
    "lng": "-103.24807"
  },
  {
    "country": "MX",
    "name": "Sahuayo de Morelos",
    "lat": "20.05859",
    "lng": "-102.71575"
  },
  {
    "country": "MX",
    "name": "Sahuaripa",
    "lat": "29.05408",
    "lng": "-109.23399"
  },
  {
    "country": "MX",
    "name": "Sacramento",
    "lat": "27.00264",
    "lng": "-101.72463"
  },
  {
    "country": "MX",
    "name": "Ciudad Sabinas Hidalgo",
    "lat": "26.50358",
    "lng": "-100.18187"
  },
  {
    "country": "MX",
    "name": "Sabinas",
    "lat": "27.85591",
    "lng": "-101.11738"
  },
  {
    "country": "MX",
    "name": "Ruíz",
    "lat": "21.95107",
    "lng": "-105.1438"
  },
  {
    "country": "MX",
    "name": "Rosarito",
    "lat": "32.36044",
    "lng": "-117.04645"
  },
  {
    "country": "MX",
    "name": "El Rosario",
    "lat": "22.99207",
    "lng": "-105.85697"
  },
  {
    "country": "MX",
    "name": "Rosamorada",
    "lat": "22.12208",
    "lng": "-105.2064"
  },
  {
    "country": "MX",
    "name": "Rosales",
    "lat": "28.18753",
    "lng": "-105.55717"
  },
  {
    "country": "MX",
    "name": "Roque",
    "lat": "20.58228",
    "lng": "-100.83727"
  },
  {
    "country": "MX",
    "name": "Romita",
    "lat": "20.87127",
    "lng": "-101.51683"
  },
  {
    "country": "MX",
    "name": "Romero de Guzmán",
    "lat": "20.02974",
    "lng": "-102.25876"
  },
  {
    "country": "MX",
    "name": "Rodeo",
    "lat": "25.1786",
    "lng": "-104.5595"
  },
  {
    "country": "MX",
    "name": "San Andrés",
    "lat": "28.54726",
    "lng": "-106.5035"
  },
  {
    "country": "MX",
    "name": "Río Grande",
    "lat": "23.82647",
    "lng": "-103.03034"
  },
  {
    "country": "MX",
    "name": "Rincón de Tamayo",
    "lat": "20.42344",
    "lng": "-100.7547"
  },
  {
    "country": "MX",
    "name": "Rincón de Romos",
    "lat": "22.22819",
    "lng": "-102.32216"
  },
  {
    "country": "MX",
    "name": "Morelos",
    "lat": "26.67289",
    "lng": "-107.67665"
  },
  {
    "country": "MX",
    "name": "Rayones",
    "lat": "25.01799",
    "lng": "-100.07362"
  },
  {
    "country": "MX",
    "name": "Rayón",
    "lat": "29.71195",
    "lng": "-110.56749"
  },
  {
    "country": "MX",
    "name": "Lázaro Cárdenas (Rancho Grande)",
    "lat": "23.45056",
    "lng": "-102.9625"
  },
  {
    "country": "MX",
    "name": "El Coyote",
    "lat": "30.82877",
    "lng": "-112.61531"
  },
  {
    "country": "MX",
    "name": "Ramos Arizpe",
    "lat": "25.53928",
    "lng": "-100.94742"
  },
  {
    "country": "MX",
    "name": "Villa de Ramos",
    "lat": "22.83045",
    "lng": "-101.91079"
  },
  {
    "country": "MX",
    "name": "Quitupan",
    "lat": "19.92728",
    "lng": "-102.87271"
  },
  {
    "country": "MX",
    "name": "Quiroga",
    "lat": "19.66557",
    "lng": "-101.52287"
  },
  {
    "country": "MX",
    "name": "Quiriego",
    "lat": "27.51987",
    "lng": "-109.25233"
  },
  {
    "country": "MX",
    "name": "Quila",
    "lat": "24.42362",
    "lng": "-107.22186"
  },
  {
    "country": "MX",
    "name": "Santiago de Querétaro",
    "lat": "20.58806",
    "lng": "-100.38806"
  },
  {
    "country": "MX",
    "name": "Estación Queréndaro",
    "lat": "19.88285",
    "lng": "-100.94861"
  },
  {
    "country": "MX",
    "name": "Queréndaro",
    "lat": "19.80954",
    "lng": "-100.8906"
  },
  {
    "country": "MX",
    "name": "Quetchehueca",
    "lat": "27.26365",
    "lng": "-109.9492"
  },
  {
    "country": "MX",
    "name": "Puruarán",
    "lat": "19.0963",
    "lng": "-101.52234"
  },
  {
    "country": "MX",
    "name": "Puruándiro",
    "lat": "20.08886",
    "lng": "-101.51579"
  },
  {
    "country": "MX",
    "name": "Purísima de Bustos",
    "lat": "21.0315",
    "lng": "-101.87833"
  },
  {
    "country": "MX",
    "name": "Purificación",
    "lat": "19.71738",
    "lng": "-104.60534"
  },
  {
    "country": "MX",
    "name": "Puréparo de Echaíz",
    "lat": "19.91039",
    "lng": "-102.00625"
  },
  {
    "country": "MX",
    "name": "Puga",
    "lat": "21.58443",
    "lng": "-104.82318"
  },
  {
    "country": "MX",
    "name": "Puerto Vallarta",
    "lat": "20.617",
    "lng": "-105.23018"
  },
  {
    "country": "MX",
    "name": "Puerto Peñasco",
    "lat": "31.31716",
    "lng": "-113.53799"
  },
  {
    "country": "MX",
    "name": "Puerto Palomas",
    "lat": "31.77718",
    "lng": "-107.63439"
  },
  {
    "country": "MX",
    "name": "Puerta de Mangos",
    "lat": "21.71853",
    "lng": "-105.33534"
  },
  {
    "country": "MX",
    "name": "Pueblo Yaqui",
    "lat": "27.35521",
    "lng": "-110.03444"
  },
  {
    "country": "MX",
    "name": "Pueblo Nuevo",
    "lat": "20.52516",
    "lng": "-101.37196"
  },
  {
    "country": "MX",
    "name": "La Providencia",
    "lat": "28.72268",
    "lng": "-111.58687"
  },
  {
    "country": "MX",
    "name": "Progreso",
    "lat": "27.42841",
    "lng": "-100.98892"
  },
  {
    "country": "MX",
    "name": "Praxedis G. Guerrero",
    "lat": "31.37061",
    "lng": "-106.00616"
  },
  {
    "country": "MX",
    "name": "Pozos de Gamboa",
    "lat": "22.94861",
    "lng": "-102.5701"
  },
  {
    "country": "MX",
    "name": "Potam",
    "lat": "27.626",
    "lng": "-110.4158"
  },
  {
    "country": "MX",
    "name": "Poncitlán",
    "lat": "20.37963",
    "lng": "-102.92557"
  },
  {
    "country": "MX",
    "name": "Poanas",
    "lat": "25.77046",
    "lng": "-103.60707"
  },
  {
    "country": "MX",
    "name": "Plateros",
    "lat": "23.22922",
    "lng": "-102.8429"
  },
  {
    "country": "MX",
    "name": "Plan de Ayala (Campo Cinco)",
    "lat": "25.7691",
    "lng": "-109.04121"
  },
  {
    "country": "MX",
    "name": "Pitiquito",
    "lat": "30.67663",
    "lng": "-112.05466"
  },
  {
    "country": "MX",
    "name": "Santa María Pipioltepec (Pipioltepec)",
    "lat": "19.24056",
    "lng": "-100.0975"
  },
  {
    "country": "MX",
    "name": "Pinos",
    "lat": "22.29571",
    "lng": "-101.57579"
  },
  {
    "country": "MX",
    "name": "Pihuamo",
    "lat": "19.24991",
    "lng": "-103.38275"
  },
  {
    "country": "MX",
    "name": "Piedras Negras",
    "lat": "28.70007",
    "lng": "-100.52353"
  },
  {
    "country": "MX",
    "name": "Picardías",
    "lat": "25.32466",
    "lng": "-103.48588"
  },
  {
    "country": "MX",
    "name": "Petatlán",
    "lat": "17.53768",
    "lng": "-101.26798"
  },
  {
    "country": "MX",
    "name": "Pesquería",
    "lat": "25.78543",
    "lng": "-100.05098"
  },
  {
    "country": "MX",
    "name": "Pesqueira",
    "lat": "29.37972",
    "lng": "-110.89611"
  },
  {
    "country": "MX",
    "name": "Pericos",
    "lat": "22.04925",
    "lng": "-105.35402"
  },
  {
    "country": "MX",
    "name": "Peribán de Ramos",
    "lat": "19.5201",
    "lng": "-102.41397"
  },
  {
    "country": "MX",
    "name": "Peñón Blanco",
    "lat": "24.79289",
    "lng": "-104.02659"
  },
  {
    "country": "MX",
    "name": "Pénjamo",
    "lat": "20.43108",
    "lng": "-101.72261"
  },
  {
    "country": "MX",
    "name": "Penjamillo de Degollado",
    "lat": "20.1041",
    "lng": "-101.93444"
  },
  {
    "country": "MX",
    "name": "Pedro Escobedo",
    "lat": "20.49963",
    "lng": "-100.14278"
  },
  {
    "country": "MX",
    "name": "Pedernales",
    "lat": "19.14133",
    "lng": "-101.46889"
  },
  {
    "country": "MX",
    "name": "Pátzcuaro",
    "lat": "19.51594",
    "lng": "-101.60887"
  },
  {
    "country": "MX",
    "name": "Patuán",
    "lat": "19.39231",
    "lng": "-101.91651"
  },
  {
    "country": "MX",
    "name": "Pastoría",
    "lat": "22.48615",
    "lng": "-102.08184"
  },
  {
    "country": "MX",
    "name": "Paso de Hidalgo (Paso de Álamos)",
    "lat": "20.27278",
    "lng": "-102.54528"
  },
  {
    "country": "MX",
    "name": "Parras de la Fuente",
    "lat": "25.44185",
    "lng": "-102.17808"
  },
  {
    "country": "MX",
    "name": "El Paredoncito",
    "lat": "27.0592",
    "lng": "-109.91286"
  },
  {
    "country": "MX",
    "name": "Parácuaro",
    "lat": "20.14381",
    "lng": "-100.76352"
  },
  {
    "country": "MX",
    "name": "Paracho de Verduzco",
    "lat": "19.64745",
    "lng": "-102.04897"
  },
  {
    "country": "MX",
    "name": "Pánuco de Coronado",
    "lat": "24.53972",
    "lng": "-104.32707"
  },
  {
    "country": "MX",
    "name": "Pánuco",
    "lat": "22.87611",
    "lng": "-102.54116"
  },
  {
    "country": "MX",
    "name": "Panindícuaro",
    "lat": "19.98518",
    "lng": "-101.76096"
  },
  {
    "country": "MX",
    "name": "Palo Alto",
    "lat": "21.91801",
    "lng": "-101.96453"
  },
  {
    "country": "MX",
    "name": "Palmito del Verde",
    "lat": "22.65861",
    "lng": "-105.77111"
  },
  {
    "country": "MX",
    "name": "Palau",
    "lat": "27.89232",
    "lng": "-101.42319"
  },
  {
    "country": "MX",
    "name": "Pajacuarán",
    "lat": "20.11909",
    "lng": "-102.56623"
  },
  {
    "country": "MX",
    "name": "Pabellón de Hidalgo",
    "lat": "22.17871",
    "lng": "-102.34014"
  },
  {
    "country": "MX",
    "name": "Pabellón de Arteaga",
    "lat": "22.14642",
    "lng": "-102.2769"
  },
  {
    "country": "MX",
    "name": "San José de Gracia",
    "lat": "19.98966",
    "lng": "-103.02198"
  },
  {
    "country": "MX",
    "name": "Orduña de Abajo",
    "lat": "20.75806",
    "lng": "-100.78278"
  },
  {
    "country": "MX",
    "name": "Oquitoa",
    "lat": "30.74197",
    "lng": "-111.73463"
  },
  {
    "country": "MX",
    "name": "Opopeo",
    "lat": "19.41163",
    "lng": "-101.60515"
  },
  {
    "country": "MX",
    "name": "Opodepe",
    "lat": "29.92573",
    "lng": "-110.62933"
  },
  {
    "country": "MX",
    "name": "Onavas",
    "lat": "28.46083",
    "lng": "-109.53013"
  },
  {
    "country": "MX",
    "name": "Ojuelos de Jalisco",
    "lat": "21.86614",
    "lng": "-101.59269"
  },
  {
    "country": "MX",
    "name": "Ojo Caliente",
    "lat": "21.84678",
    "lng": "-100.75375"
  },
  {
    "country": "MX",
    "name": "Ojinaga",
    "lat": "29.56689",
    "lng": "-104.54487"
  },
  {
    "country": "MX",
    "name": "Ocotlán",
    "lat": "20.3553",
    "lng": "-102.77358"
  },
  {
    "country": "MX",
    "name": "Ocho de Enero",
    "lat": "26.99558",
    "lng": "-101.49755"
  },
  {
    "country": "MX",
    "name": "Ocampo",
    "lat": "28.19367",
    "lng": "-108.3676"
  },
  {
    "country": "MX",
    "name": "Ocampo",
    "lat": "27.31477",
    "lng": "-102.3966"
  },
  {
    "country": "MX",
    "name": "Ocampo",
    "lat": "21.64653",
    "lng": "-101.48012"
  },
  {
    "country": "MX",
    "name": "Ocampo",
    "lat": "19.58241",
    "lng": "-100.33913"
  },
  {
    "country": "MX",
    "name": "Obrajuelo",
    "lat": "20.1082",
    "lng": "-100.8495"
  },
  {
    "country": "MX",
    "name": "Numarán",
    "lat": "20.2558",
    "lng": "-101.94988"
  },
  {
    "country": "MX",
    "name": "Nuevo Zirosto",
    "lat": "19.54806",
    "lng": "-102.34833"
  },
  {
    "country": "MX",
    "name": "Nuevo Urecho",
    "lat": "19.16602",
    "lng": "-101.86816"
  },
  {
    "country": "MX",
    "name": "Nuevo San Juan Parangaricutiro",
    "lat": "19.41857",
    "lng": "-102.13087"
  },
  {
    "country": "MX",
    "name": "Nuevo México",
    "lat": "20.7565",
    "lng": "-103.44297"
  },
  {
    "country": "MX",
    "name": "Nuevo Ideal",
    "lat": "24.88544",
    "lng": "-105.07552"
  },
  {
    "country": "MX",
    "name": "Churumuco de Morelos",
    "lat": "18.66333",
    "lng": "-101.64741"
  },
  {
    "country": "MX",
    "name": "Nuevo Casas Grandes",
    "lat": "30.41552",
    "lng": "-107.91166"
  },
  {
    "country": "MX",
    "name": "Nueva Rosita",
    "lat": "27.94028",
    "lng": "-101.21812"
  },
  {
    "country": "MX",
    "name": "Nueva Italia de Ruiz",
    "lat": "19.02492",
    "lng": "-102.09318"
  },
  {
    "country": "MX",
    "name": "Santa Cruz",
    "lat": "31.23362",
    "lng": "-110.59618"
  },
  {
    "country": "MX",
    "name": "Noria de Ángeles",
    "lat": "22.44321",
    "lng": "-101.90846"
  },
  {
    "country": "MX",
    "name": "Nonoava",
    "lat": "27.47276",
    "lng": "-106.73535"
  },
  {
    "country": "MX",
    "name": "Nombre de Dios",
    "lat": "23.84891",
    "lng": "-104.24712"
  },
  {
    "country": "MX",
    "name": "Nocupétaro",
    "lat": "19.04392",
    "lng": "-101.16187"
  },
  {
    "country": "MX",
    "name": "Nochistlán de Mejía",
    "lat": "21.36435",
    "lng": "-102.8459"
  },
  {
    "country": "MX",
    "name": "Nieves",
    "lat": "23.99609",
    "lng": "-103.02013"
  },
  {
    "country": "MX",
    "name": "Nazas",
    "lat": "25.22462",
    "lng": "-104.11458"
  },
  {
    "country": "MX",
    "name": "Nazareno",
    "lat": "25.39916",
    "lng": "-103.42065"
  },
  {
    "country": "MX",
    "name": "Jesús María",
    "lat": "22.25056",
    "lng": "-104.51792"
  },
  {
    "country": "MX",
    "name": "Navolato",
    "lat": "24.7661",
    "lng": "-107.70225"
  },
  {
    "country": "MX",
    "name": "Navojoa",
    "lat": "27.07028",
    "lng": "-109.44372"
  },
  {
    "country": "MX",
    "name": "Nava",
    "lat": "28.42071",
    "lng": "-100.76565"
  },
  {
    "country": "MX",
    "name": "El Naranjillo",
    "lat": "20.71417",
    "lng": "-101.00056"
  },
  {
    "country": "MX",
    "name": "Naranja de Tapia",
    "lat": "19.77708",
    "lng": "-101.75947"
  },
  {
    "country": "MX",
    "name": "Namiquipa",
    "lat": "29.25173",
    "lng": "-107.414"
  },
  {
    "country": "MX",
    "name": "Naica",
    "lat": "27.85736",
    "lng": "-105.49233"
  },
  {
    "country": "MX",
    "name": "Nahuatzén",
    "lat": "19.65506",
    "lng": "-101.91704"
  },
  {
    "country": "MX",
    "name": "Nadadores",
    "lat": "27.02819",
    "lng": "-101.5942"
  },
  {
    "country": "MX",
    "name": "Nacozari Viejo",
    "lat": "30.4",
    "lng": "-109.65"
  },
  {
    "country": "MX",
    "name": "Nacozari de García",
    "lat": "30.37489",
    "lng": "-109.68898"
  },
  {
    "country": "MX",
    "name": "Nácori Chico",
    "lat": "29.68726",
    "lng": "-108.9802"
  },
  {
    "country": "MX",
    "name": "Naco",
    "lat": "31.32701",
    "lng": "-109.94669"
  },
  {
    "country": "MX",
    "name": "Mulegé",
    "lat": "26.89141",
    "lng": "-111.9826"
  },
  {
    "country": "MX",
    "name": "Moyahua de Estrada",
    "lat": "21.26658",
    "lng": "-103.1661"
  },
  {
    "country": "MX",
    "name": "Moroleón",
    "lat": "20.12571",
    "lng": "-101.19208"
  },
  {
    "country": "MX",
    "name": "Moris",
    "lat": "28.14888",
    "lng": "-108.52325"
  },
  {
    "country": "MX",
    "name": "Morelos",
    "lat": "28.40676",
    "lng": "-100.88854"
  },
  {
    "country": "MX",
    "name": "Morelos",
    "lat": "22.86215",
    "lng": "-102.61061"
  },
  {
    "country": "MX",
    "name": "Morelia",
    "lat": "19.70078",
    "lng": "-101.18443"
  },
  {
    "country": "MX",
    "name": "Morales",
    "lat": "20.77821",
    "lng": "-100.80932"
  },
  {
    "country": "MX",
    "name": "Monterrey",
    "lat": "25.67507",
    "lng": "-100.31847"
  },
  {
    "country": "MX",
    "name": "Monte Escobedo",
    "lat": "22.30362",
    "lng": "-103.56751"
  },
  {
    "country": "MX",
    "name": "Monclova",
    "lat": "26.90687",
    "lng": "-101.42056"
  },
  {
    "country": "MX",
    "name": "Mompaní",
    "lat": "20.69214",
    "lng": "-100.50679"
  },
  {
    "country": "MX",
    "name": "Momax",
    "lat": "21.9226",
    "lng": "-103.31307"
  },
  {
    "country": "MX",
    "name": "Moctezuma",
    "lat": "29.80615",
    "lng": "-109.67949"
  },
  {
    "country": "MX",
    "name": "Moctezuma",
    "lat": "22.74787",
    "lng": "-101.08219"
  },
  {
    "country": "MX",
    "name": "Mocorito",
    "lat": "25.48202",
    "lng": "-107.92008"
  },
  {
    "country": "MX",
    "name": "Mochicahui",
    "lat": "25.95095",
    "lng": "-108.92991"
  },
  {
    "country": "MX",
    "name": "Mixtlán",
    "lat": "20.439",
    "lng": "-104.40867"
  },
  {
    "country": "MX",
    "name": "Mineral de Angangueo",
    "lat": "19.62056",
    "lng": "-100.28436"
  },
  {
    "country": "MX",
    "name": "Minatitlán",
    "lat": "19.36667",
    "lng": "-104.06667"
  },
  {
    "country": "MX",
    "name": "Mina",
    "lat": "26.0011",
    "lng": "-100.52988"
  },
  {
    "country": "MX",
    "name": "Miguel Auza",
    "lat": "24.29421",
    "lng": "-103.4509"
  },
  {
    "country": "MX",
    "name": "Mier y Noriega",
    "lat": "23.42246",
    "lng": "-100.11727"
  },
  {
    "country": "MX",
    "name": "Mezquitic",
    "lat": "22.38896",
    "lng": "-103.7271"
  },
  {
    "country": "MX",
    "name": "Mezquital del Oro",
    "lat": "21.21667",
    "lng": "-103.36278"
  },
  {
    "country": "MX",
    "name": "San Francisco del Mezquital",
    "lat": "23.47444",
    "lng": "-104.3949"
  },
  {
    "country": "MX",
    "name": "Mezcala",
    "lat": "20.95278",
    "lng": "-102.84611"
  },
  {
    "country": "MX",
    "name": "Mexticacán",
    "lat": "21.26538",
    "lng": "-102.77985"
  },
  {
    "country": "MX",
    "name": "Mexquitic de Carmona",
    "lat": "22.26644",
    "lng": "-101.11274"
  },
  {
    "country": "MX",
    "name": "Mexicali",
    "lat": "32.62781",
    "lng": "-115.45446"
  },
  {
    "country": "MX",
    "name": "Mesillas",
    "lat": "23.24652",
    "lng": "-106.04783"
  },
  {
    "country": "MX",
    "name": "Meoqui",
    "lat": "28.27226",
    "lng": "-105.48046"
  },
  {
    "country": "MX",
    "name": "Menores",
    "lat": "20.92028",
    "lng": "-101.395"
  },
  {
    "country": "MX",
    "name": "Ciudad Melchor Múzquiz",
    "lat": "27.87933",
    "lng": "-101.51615"
  },
  {
    "country": "MX",
    "name": "Medina",
    "lat": "21.14972",
    "lng": "-101.6225"
  },
  {
    "country": "MX",
    "name": "Mazatlán",
    "lat": "23.2329",
    "lng": "-106.4062"
  },
  {
    "country": "MX",
    "name": "Mazatán",
    "lat": "29.00503",
    "lng": "-110.13785"
  },
  {
    "country": "MX",
    "name": "Mazapil",
    "lat": "24.63867",
    "lng": "-101.55455"
  },
  {
    "country": "MX",
    "name": "Mazamitla",
    "lat": "19.9161",
    "lng": "-103.02027"
  },
  {
    "country": "MX",
    "name": "Matehuala",
    "lat": "23.64824",
    "lng": "-100.64334"
  },
  {
    "country": "MX",
    "name": "Matanzas",
    "lat": "21.63333",
    "lng": "-101.65528"
  },
  {
    "country": "MX",
    "name": "Matancillas (San Isidro Matancillas)",
    "lat": "21.89036",
    "lng": "-101.65059"
  },
  {
    "country": "MX",
    "name": "Matamoros",
    "lat": "25.52699",
    "lng": "-103.2285"
  },
  {
    "country": "MX",
    "name": "Matachí",
    "lat": "28.84287",
    "lng": "-107.75503"
  },
  {
    "country": "MX",
    "name": "Mascota",
    "lat": "20.52613",
    "lng": "-104.78781"
  },
  {
    "country": "MX",
    "name": "Hacienda de Márquez",
    "lat": "20.78037",
    "lng": "-101.35979"
  },
  {
    "country": "MX",
    "name": "Marín",
    "lat": "25.87946",
    "lng": "-100.03028"
  },
  {
    "country": "MX",
    "name": "Jesús Gómez Portugal",
    "lat": "21.99607",
    "lng": "-102.29095"
  },
  {
    "country": "MX",
    "name": "Margaritas",
    "lat": "20.45306",
    "lng": "-102.47417"
  },
  {
    "country": "MX",
    "name": "Marfil",
    "lat": "20.99165",
    "lng": "-101.28434"
  },
  {
    "country": "MX",
    "name": "Maravatío de Ocampo",
    "lat": "19.89113",
    "lng": "-100.44443"
  },
  {
    "country": "MX",
    "name": "Mapimí",
    "lat": "25.8338",
    "lng": "-103.8461"
  },
  {
    "country": "MX",
    "name": "Manzanillo",
    "lat": "19.11695",
    "lng": "-104.34214"
  },
  {
    "country": "MX",
    "name": "Santa María del Oro",
    "lat": "19.58679",
    "lng": "-102.9095"
  },
  {
    "country": "MX",
    "name": "Rodolfo Sánchez Taboada",
    "lat": "31.72099",
    "lng": "-116.57184"
  },
  {
    "country": "MX",
    "name": "Malagana (San Antonio del Monte)",
    "lat": "21.0467",
    "lng": "-101.7535"
  },
  {
    "country": "MX",
    "name": "Maguarichi",
    "lat": "27.85908",
    "lng": "-107.99397"
  },
  {
    "country": "MX",
    "name": "Magdalena de Kino",
    "lat": "30.62789",
    "lng": "-110.96203"
  },
  {
    "country": "MX",
    "name": "Magdalena",
    "lat": "20.90741",
    "lng": "-103.978"
  },
  {
    "country": "MX",
    "name": "Madrid",
    "lat": "19.08459",
    "lng": "-103.87123"
  },
  {
    "country": "MX",
    "name": "Madera",
    "lat": "29.19366",
    "lng": "-108.14684"
  },
  {
    "country": "MX",
    "name": "Macapule",
    "lat": "25.88607",
    "lng": "-109.1482"
  },
  {
    "country": "MX",
    "name": "Villa Luvianos",
    "lat": "18.91667",
    "lng": "-100.4"
  },
  {
    "country": "MX",
    "name": "Luis Moya",
    "lat": "22.43237",
    "lng": "-102.24864"
  },
  {
    "country": "MX",
    "name": "Los Tepames",
    "lat": "19.09389",
    "lng": "-103.6225"
  },
  {
    "country": "MX",
    "name": "Los Pocitos",
    "lat": "20.53724",
    "lng": "-103.93721"
  },
  {
    "country": "MX",
    "name": "Los Pilares",
    "lat": "20.32582",
    "lng": "-102.37322"
  },
  {
    "country": "MX",
    "name": "Los Nogales",
    "lat": "19.85734",
    "lng": "-102.15612"
  },
  {
    "country": "MX",
    "name": "Los Mochis",
    "lat": "25.79302",
    "lng": "-108.99808"
  },
  {
    "country": "MX",
    "name": "Los Hoyos",
    "lat": "30.12444",
    "lng": "-109.78222"
  },
  {
    "country": "MX",
    "name": "Los Algodones",
    "lat": "32.7",
    "lng": "-114.73333"
  },
  {
    "country": "MX",
    "name": "Loreto",
    "lat": "26.01217",
    "lng": "-111.34888"
  },
  {
    "country": "MX",
    "name": "Loreto",
    "lat": "22.27248",
    "lng": "-101.98898"
  },
  {
    "country": "MX",
    "name": "Lombardía",
    "lat": "19.15806",
    "lng": "-102.05111"
  },
  {
    "country": "MX",
    "name": "Loma Pelada",
    "lat": "20.57222",
    "lng": "-101.29417"
  },
  {
    "country": "MX",
    "name": "Lo de Marcos",
    "lat": "20.95694",
    "lng": "-105.35333"
  },
  {
    "country": "MX",
    "name": "Lo Arado",
    "lat": "19.62139",
    "lng": "-104.53444"
  },
  {
    "country": "MX",
    "name": "León de los Aldama",
    "lat": "21.12908",
    "lng": "-101.67374"
  },
  {
    "country": "MX",
    "name": "La Yesca",
    "lat": "21.31871",
    "lng": "-104.01161"
  },
  {
    "country": "MX",
    "name": "La Ventilla",
    "lat": "21.77389",
    "lng": "-101.03028"
  },
  {
    "country": "MX",
    "name": "La Venta del Astillero",
    "lat": "20.72795",
    "lng": "-103.54509"
  },
  {
    "country": "MX",
    "name": "La Unión",
    "lat": "26.81961",
    "lng": "-109.60831"
  },
  {
    "country": "MX",
    "name": "La Unión",
    "lat": "17.98561",
    "lng": "-101.80655"
  },
  {
    "country": "MX",
    "name": "La Trinidad",
    "lat": "25.73367",
    "lng": "-108.48409"
  },
  {
    "country": "MX",
    "name": "San Nicolás de la Torre",
    "lat": "20.07806",
    "lng": "-100.10139"
  },
  {
    "country": "MX",
    "name": "La Tijera",
    "lat": "19.9",
    "lng": "-104.4"
  },
  {
    "country": "MX",
    "name": "Las Varas",
    "lat": "21.18021",
    "lng": "-105.13595"
  },
  {
    "country": "MX",
    "name": "Trincheras",
    "lat": "30.39806",
    "lng": "-111.53019"
  },
  {
    "country": "MX",
    "name": "San José Tepuzas",
    "lat": "20.35417",
    "lng": "-100.37528"
  },
  {
    "country": "MX",
    "name": "Las Quemazones",
    "lat": "25.68583",
    "lng": "-108.45243"
  },
  {
    "country": "MX",
    "name": "Las Pintas de Arriba",
    "lat": "20.57376",
    "lng": "-103.32345"
  },
  {
    "country": "MX",
    "name": "Las Juntas",
    "lat": "19.43061",
    "lng": "-104.70646"
  },
  {
    "country": "MX",
    "name": "Las Cuevas",
    "lat": "25.49815",
    "lng": "-103.5495"
  },
  {
    "country": "MX",
    "name": "Rosa Blanca",
    "lat": "21.12454",
    "lng": "-104.35811"
  },
  {
    "country": "MX",
    "name": "La Reforma",
    "lat": "25.08164",
    "lng": "-108.05673"
  },
  {
    "country": "MX",
    "name": "Quesería",
    "lat": "19.38708",
    "lng": "-103.57243"
  },
  {
    "country": "MX",
    "name": "La Pila",
    "lat": "22.03425",
    "lng": "-100.86786"
  },
  {
    "country": "MX",
    "name": "La Piedad",
    "lat": "20.34239",
    "lng": "-102.0305"
  },
  {
    "country": "MX",
    "name": "La Pendencia",
    "lat": "22.43778",
    "lng": "-101.57583"
  },
  {
    "country": "MX",
    "name": "La Paz",
    "lat": "24.14437",
    "lng": "-110.3005"
  },
  {
    "country": "MX",
    "name": "Villa de la Paz",
    "lat": "23.67616",
    "lng": "-100.71167"
  },
  {
    "country": "MX",
    "name": "La Palma",
    "lat": "20.52219",
    "lng": "-100.17392"
  },
  {
    "country": "MX",
    "name": "La Orilla",
    "lat": "17.99583",
    "lng": "-102.22694"
  },
  {
    "country": "MX",
    "name": "Lampazos de Naranjo",
    "lat": "27.02549",
    "lng": "-100.50528"
  },
  {
    "country": "MX",
    "name": "La Moncada",
    "lat": "20.28348",
    "lng": "-100.80502"
  },
  {
    "country": "MX",
    "name": "La Mira Tumbiscatio",
    "lat": "18.68333",
    "lng": "-102.28333"
  },
  {
    "country": "MX",
    "name": "La Manzanilla de la Paz",
    "lat": "20.00495",
    "lng": "-103.15456"
  },
  {
    "country": "MX",
    "name": "La Loma (La Loma de Quila)",
    "lat": "24.38061",
    "lng": "-107.22649"
  },
  {
    "country": "MX",
    "name": "La Lira",
    "lat": "20.47554",
    "lng": "-100.16145"
  },
  {
    "country": "MX",
    "name": "La Libertad",
    "lat": "29.91313",
    "lng": "-112.69179"
  },
  {
    "country": "MX",
    "name": "La Libertad",
    "lat": "21.59347",
    "lng": "-105.17365"
  },
  {
    "country": "MX",
    "name": "La Labor",
    "lat": "20.53388",
    "lng": "-100.702"
  },
  {
    "country": "MX",
    "name": "Ejido la Joya",
    "lat": "21.14325",
    "lng": "-101.73922"
  },
  {
    "country": "MX",
    "name": "La Jarretadera",
    "lat": "21.92501",
    "lng": "-105.04031"
  },
  {
    "country": "MX",
    "name": "La Huerta",
    "lat": "19.4844",
    "lng": "-104.64378"
  },
  {
    "country": "MX",
    "name": "La Huacana",
    "lat": "18.96312",
    "lng": "-101.8072"
  },
  {
    "country": "MX",
    "name": "La Higuera",
    "lat": "19.42354",
    "lng": "-103.40971"
  },
  {
    "country": "MX",
    "name": "Lagunillas",
    "lat": "19.56271",
    "lng": "-101.41582"
  },
  {
    "country": "MX",
    "name": "Lagos de Moreno",
    "lat": "21.35666",
    "lng": "-101.93768"
  },
  {
    "country": "MX",
    "name": "La Goma",
    "lat": "25.4846",
    "lng": "-103.68884"
  },
  {
    "country": "MX",
    "name": "La Fuente",
    "lat": "20.55255",
    "lng": "-100.03591"
  },
  {
    "country": "MX",
    "name": "La Flor",
    "lat": "25.68138",
    "lng": "-103.36837"
  },
  {
    "country": "MX",
    "name": "La Estancia",
    "lat": "20.42123",
    "lng": "-100.06616"
  },
  {
    "country": "MX",
    "name": "La Estacada",
    "lat": "20.82151",
    "lng": "-100.40763"
  },
  {
    "country": "MX",
    "name": "San José de la Era",
    "lat": "22.85073",
    "lng": "-102.42239"
  },
  {
    "country": "MX",
    "name": "La Cruz",
    "lat": "27.86359",
    "lng": "-105.19596"
  },
  {
    "country": "MX",
    "name": "La Cruz",
    "lat": "23.92126",
    "lng": "-106.8925"
  },
  {
    "country": "MX",
    "name": "La Colorada",
    "lat": "28.80348",
    "lng": "-110.57994"
  },
  {
    "country": "MX",
    "name": "La Ciudad",
    "lat": "23.73052",
    "lng": "-105.68882"
  },
  {
    "country": "MX",
    "name": "La Cañada",
    "lat": "20.60805",
    "lng": "-100.33275"
  },
  {
    "country": "MX",
    "name": "La Calera",
    "lat": "20.80119",
    "lng": "-101.33207"
  },
  {
    "country": "MX",
    "name": "La Brecha",
    "lat": "25.37078",
    "lng": "-108.41922"
  },
  {
    "country": "MX",
    "name": "La Barca",
    "lat": "20.28784",
    "lng": "-102.54514"
  },
  {
    "country": "MX",
    "name": "Banderas del Águila",
    "lat": "23.92596",
    "lng": "-105.3395"
  },
  {
    "country": "MX",
    "name": "Puente Grande",
    "lat": "20.56977",
    "lng": "-103.15377"
  },
  {
    "country": "MX",
    "name": "Ascensión",
    "lat": "31.0926",
    "lng": "-107.99687"
  },
  {
    "country": "MX",
    "name": "La Angostura",
    "lat": "20.19639",
    "lng": "-102.44167"
  },
  {
    "country": "MX",
    "name": "La Aldea",
    "lat": "20.90166",
    "lng": "-101.47852"
  },
  {
    "country": "MX",
    "name": "Juventino Rosas",
    "lat": "20.64337",
    "lng": "-100.99286"
  },
  {
    "country": "MX",
    "name": "Jungapeo de Juárez",
    "lat": "19.45915",
    "lng": "-100.49483"
  },
  {
    "country": "MX",
    "name": "Juchitlán",
    "lat": "20.08557",
    "lng": "-104.09867"
  },
  {
    "country": "MX",
    "name": "Juchipila",
    "lat": "21.40862",
    "lng": "-103.11663"
  },
  {
    "country": "MX",
    "name": "Ciudad Benito Juárez",
    "lat": "25.64724",
    "lng": "-100.09582"
  },
  {
    "country": "MX",
    "name": "Pueblo Juárez (La Magdalena)",
    "lat": "19.16722",
    "lng": "-103.93111"
  },
  {
    "country": "MX",
    "name": "Juan Escutia (Borbollón)",
    "lat": "21.16741",
    "lng": "-104.86698"
  },
  {
    "country": "MX",
    "name": "Juan Aldama",
    "lat": "24.29188",
    "lng": "-103.39272"
  },
  {
    "country": "MX",
    "name": "Juanacatlán",
    "lat": "20.50888",
    "lng": "-103.17025"
  },
  {
    "country": "MX",
    "name": "Jocotepec",
    "lat": "20.28527",
    "lng": "-103.42897"
  },
  {
    "country": "MX",
    "name": "J. Jesús Díaz Tzirio",
    "lat": "19.76667",
    "lng": "-102.39722"
  },
  {
    "country": "MX",
    "name": "Jiquílpan de Juárez",
    "lat": "19.99482",
    "lng": "-102.71969"
  },
  {
    "country": "MX",
    "name": "Jiménez del Teul",
    "lat": "23.25378",
    "lng": "-103.79855"
  },
  {
    "country": "MX",
    "name": "Jiménez",
    "lat": "29.06975",
    "lng": "-100.67895"
  },
  {
    "country": "MX",
    "name": "Jiménez",
    "lat": "28.33333",
    "lng": "-105.4"
  },
  {
    "country": "MX",
    "name": "Jilotlán de los Dolores",
    "lat": "19.37089",
    "lng": "-103.02029"
  },
  {
    "country": "MX",
    "name": "Jesús María",
    "lat": "21.96111",
    "lng": "-102.34333"
  },
  {
    "country": "MX",
    "name": "Jesús María",
    "lat": "20.60595",
    "lng": "-102.22245"
  },
  {
    "country": "MX",
    "name": "Jerez de García Salinas",
    "lat": "22.64971",
    "lng": "-102.99032"
  },
  {
    "country": "MX",
    "name": "Jerécuaro",
    "lat": "20.15467",
    "lng": "-100.5086"
  },
  {
    "country": "MX",
    "name": "Jauregui",
    "lat": "20.5928",
    "lng": "-100.7194"
  },
  {
    "country": "MX",
    "name": "Jaral del Progreso",
    "lat": "20.37237",
    "lng": "-101.06249"
  },
  {
    "country": "MX",
    "name": "Jarácuaro",
    "lat": "19.56058",
    "lng": "-101.67785"
  },
  {
    "country": "MX",
    "name": "Janos",
    "lat": "30.88909",
    "lng": "-108.19431"
  },
  {
    "country": "MX",
    "name": "Jamay",
    "lat": "20.29349",
    "lng": "-102.70754"
  },
  {
    "country": "MX",
    "name": "Jaluco",
    "lat": "19.23041",
    "lng": "-104.68451"
  },
  {
    "country": "MX",
    "name": "Jalpa",
    "lat": "21.63448",
    "lng": "-102.97919"
  },
  {
    "country": "MX",
    "name": "Jalostotitlán",
    "lat": "21.16741",
    "lng": "-102.46386"
  },
  {
    "country": "MX",
    "name": "Xalisco",
    "lat": "21.451",
    "lng": "-104.8983"
  },
  {
    "country": "MX",
    "name": "Jalcocotán",
    "lat": "21.48122",
    "lng": "-105.09851"
  },
  {
    "country": "MX",
    "name": "Jala",
    "lat": "21.10484",
    "lng": "-104.43764"
  },
  {
    "country": "MX",
    "name": "Ixtlán del Río",
    "lat": "21.03907",
    "lng": "-104.37116"
  },
  {
    "country": "MX",
    "name": "Ixtlán de los Hervores",
    "lat": "20.16895",
    "lng": "-102.3948"
  },
  {
    "country": "MX",
    "name": "Ixtlahuacán del Río",
    "lat": "20.86405",
    "lng": "-103.24029"
  },
  {
    "country": "MX",
    "name": "Ixtlahuacán de los Membrillos",
    "lat": "20.3486",
    "lng": "-103.19336"
  },
  {
    "country": "MX",
    "name": "Ixtlahuacán",
    "lat": "19.00119",
    "lng": "-103.73638"
  },
  {
    "country": "MX",
    "name": "Ixtapan del Oro",
    "lat": "19.26303",
    "lng": "-100.26459"
  },
  {
    "country": "MX",
    "name": "Ixtapa",
    "lat": "20.71641",
    "lng": "-105.20487"
  },
  {
    "country": "MX",
    "name": "Ixtapa",
    "lat": "17.66782",
    "lng": "-101.64165"
  },
  {
    "country": "MX",
    "name": "Irapuato",
    "lat": "20.67675",
    "lng": "-101.35628"
  },
  {
    "country": "MX",
    "name": "Irámuco",
    "lat": "19.96156",
    "lng": "-100.92202"
  },
  {
    "country": "MX",
    "name": "Indé",
    "lat": "25.91248",
    "lng": "-105.22319"
  },
  {
    "country": "MX",
    "name": "Indaparapeo",
    "lat": "19.78767",
    "lng": "-100.96907"
  },
  {
    "country": "MX",
    "name": "Imuris",
    "lat": "30.78955",
    "lng": "-110.84596"
  },
  {
    "country": "MX",
    "name": "Ignacio Zaragoza",
    "lat": "28.39355",
    "lng": "-107.22774"
  },
  {
    "country": "MX",
    "name": "Huiramba",
    "lat": "19.54606",
    "lng": "-101.43651"
  },
  {
    "country": "MX",
    "name": "Huimilpan",
    "lat": "20.37199",
    "lng": "-100.27737"
  },
  {
    "country": "MX",
    "name": "Huetamo de Núñez",
    "lat": "18.62926",
    "lng": "-100.897"
  },
  {
    "country": "MX",
    "name": "Huepaco",
    "lat": "25.98417",
    "lng": "-108.86056"
  },
  {
    "country": "MX",
    "name": "Huépac",
    "lat": "29.91135",
    "lng": "-110.21323"
  },
  {
    "country": "MX",
    "name": "Huejuquilla el Alto",
    "lat": "22.62547",
    "lng": "-103.89777"
  },
  {
    "country": "MX",
    "name": "Huejúcar",
    "lat": "22.35881",
    "lng": "-103.2114"
  },
  {
    "country": "MX",
    "name": "Huejotitán",
    "lat": "27.05623",
    "lng": "-106.17819"
  },
  {
    "country": "MX",
    "name": "Huatabampo",
    "lat": "26.8261",
    "lng": "-109.6422"
  },
  {
    "country": "MX",
    "name": "Huásabas",
    "lat": "29.90772",
    "lng": "-109.30098"
  },
  {
    "country": "MX",
    "name": "Huanusco",
    "lat": "21.77379",
    "lng": "-102.97322"
  },
  {
    "country": "MX",
    "name": "Huaniqueo de Morales",
    "lat": "19.89682",
    "lng": "-101.5045"
  },
  {
    "country": "MX",
    "name": "Huanímaro",
    "lat": "20.36783",
    "lng": "-101.49869"
  },
  {
    "country": "MX",
    "name": "Huandacareo",
    "lat": "19.99136",
    "lng": "-101.2761"
  },
  {
    "country": "MX",
    "name": "Huajicori",
    "lat": "22.63667",
    "lng": "-105.31972"
  },
  {
    "country": "MX",
    "name": "Huachinera",
    "lat": "30.21027",
    "lng": "-108.95854"
  },
  {
    "country": "MX",
    "name": "Hostotipaquillo",
    "lat": "21.06035",
    "lng": "-104.05091"
  },
  {
    "country": "MX",
    "name": "Hormiguero",
    "lat": "25.68386",
    "lng": "-103.34121"
  },
  {
    "country": "MX",
    "name": "Higueras de Abuya",
    "lat": "24.26058",
    "lng": "-107.0709"
  },
  {
    "country": "MX",
    "name": "Higueras",
    "lat": "25.96007",
    "lng": "-100.0152"
  },
  {
    "country": "MX",
    "name": "El Higueral",
    "lat": "24.31044",
    "lng": "-107.348"
  },
  {
    "country": "MX",
    "name": "Higuera de Zaragoza",
    "lat": "25.96892",
    "lng": "-109.3042"
  },
  {
    "country": "MX",
    "name": "Parral",
    "lat": "26.93022",
    "lng": "-105.6664"
  },
  {
    "country": "MX",
    "name": "Heróica Zitácuaro",
    "lat": "19.43612",
    "lng": "-100.35733"
  },
  {
    "country": "MX",
    "name": "Nogales",
    "lat": "31.30862",
    "lng": "-110.94217"
  },
  {
    "country": "MX",
    "name": "Heroica Caborca",
    "lat": "30.71825",
    "lng": "-112.15822"
  },
  {
    "country": "MX",
    "name": "Hermosillo",
    "lat": "29.1026",
    "lng": "-110.97732"
  },
  {
    "country": "MX",
    "name": "Hacienda Toribio",
    "lat": "23.08333",
    "lng": "-102.68333"
  },
  {
    "country": "MX",
    "name": "Guerrero",
    "lat": "28.30992",
    "lng": "-100.38048"
  },
  {
    "country": "MX",
    "name": "Heroica Guaymas",
    "lat": "27.91928",
    "lng": "-110.89755"
  },
  {
    "country": "MX",
    "name": "Guasave",
    "lat": "25.56745",
    "lng": "-108.46756"
  },
  {
    "country": "MX",
    "name": "Guanajuato",
    "lat": "21.01858",
    "lng": "-101.2591"
  },
  {
    "country": "MX",
    "name": "Guanaceví",
    "lat": "25.93125",
    "lng": "-105.95717"
  },
  {
    "country": "MX",
    "name": "Guamúchil",
    "lat": "25.4587",
    "lng": "-108.07732"
  },
  {
    "country": "MX",
    "name": "Guadalupe y Calvo",
    "lat": "26.09117",
    "lng": "-106.9626"
  },
  {
    "country": "MX",
    "name": "Guadalupe Victoria",
    "lat": "31.53396",
    "lng": "-107.73835"
  },
  {
    "country": "MX",
    "name": "Ciudad Guadalupe Victoria",
    "lat": "24.44401",
    "lng": "-104.12156"
  },
  {
    "country": "MX",
    "name": "Guadalupe Victoria",
    "lat": "21.67972",
    "lng": "-105.3275"
  },
  {
    "country": "MX",
    "name": "Guadalupe",
    "lat": "31.3895",
    "lng": "-106.10574"
  },
  {
    "country": "MX",
    "name": "Guadalupe",
    "lat": "25.67678",
    "lng": "-100.25646"
  },
  {
    "country": "MX",
    "name": "Guadalupe",
    "lat": "22.74753",
    "lng": "-102.51874"
  },
  {
    "country": "MX",
    "name": "Guadalcázar",
    "lat": "22.61804",
    "lng": "-100.39936"
  },
  {
    "country": "MX",
    "name": "Guadalajara",
    "lat": "20.66682",
    "lng": "-103.39182"
  },
  {
    "country": "MX",
    "name": "Guachochi",
    "lat": "26.82001",
    "lng": "-107.0745"
  },
  {
    "country": "MX",
    "name": "Guachinango",
    "lat": "20.57723",
    "lng": "-104.3804"
  },
  {
    "country": "MX",
    "name": "Carretas",
    "lat": "28.2492",
    "lng": "-106.51062"
  },
  {
    "country": "MX",
    "name": "Granados",
    "lat": "29.86195",
    "lng": "-109.31016"
  },
  {
    "country": "MX",
    "name": "Gómez Palacio",
    "lat": "25.56985",
    "lng": "-103.49588"
  },
  {
    "country": "MX",
    "name": "Gómez Farías",
    "lat": "29.35981",
    "lng": "-107.7396"
  },
  {
    "country": "MX",
    "name": "Gómez Farías",
    "lat": "19.79363",
    "lng": "-103.47651"
  },
  {
    "country": "MX",
    "name": "Ejido Gogorrón (Ex-Hacienda de Gogorrón)",
    "lat": "21.84019",
    "lng": "-100.91138"
  },
  {
    "country": "MX",
    "name": "General Zuazua",
    "lat": "25.89491",
    "lng": "-100.108"
  },
  {
    "country": "MX",
    "name": "Vicente Guerrero",
    "lat": "23.73429",
    "lng": "-103.98487"
  },
  {
    "country": "MX",
    "name": "Santa Isabel",
    "lat": "28.34166",
    "lng": "-106.3722"
  },
  {
    "country": "MX",
    "name": "General Simón Bolívar",
    "lat": "24.68814",
    "lng": "-103.22601"
  },
  {
    "country": "MX",
    "name": "Juan José Ríos",
    "lat": "25.75781",
    "lng": "-108.8242"
  },
  {
    "country": "MX",
    "name": "Ciudad General Escobedo",
    "lat": "25.79698",
    "lng": "-100.31791"
  },
  {
    "country": "MX",
    "name": "General Cepeda",
    "lat": "25.37767",
    "lng": "-101.47571"
  },
  {
    "country": "MX",
    "name": "Guaymitas",
    "lat": "27.11028",
    "lng": "-109.43833"
  },
  {
    "country": "MX",
    "name": "San Pedro Garza García",
    "lat": "25.6604",
    "lng": "-100.40651"
  },
  {
    "country": "MX",
    "name": "Galeana",
    "lat": "24.82455",
    "lng": "-100.07601"
  },
  {
    "country": "MX",
    "name": "Fronteras",
    "lat": "30.89753",
    "lng": "-109.55968"
  },
  {
    "country": "MX",
    "name": "Fresnillo",
    "lat": "23.18126",
    "lng": "-102.87136"
  },
  {
    "country": "MX",
    "name": "Francisco Sarabia (Cerrito Pelón)",
    "lat": "20.03086",
    "lng": "-102.70158"
  },
  {
    "country": "MX",
    "name": "Francisco I. Madero",
    "lat": "25.773",
    "lng": "-103.27127"
  },
  {
    "country": "MX",
    "name": "Flor Azul",
    "lat": "25.86987",
    "lng": "-109.00839"
  },
  {
    "country": "MX",
    "name": "Felipe Carrillo Puerto",
    "lat": "19.16325",
    "lng": "-102.70834"
  },
  {
    "country": "MX",
    "name": "Etzatlán",
    "lat": "20.76839",
    "lng": "-104.07735"
  },
  {
    "country": "MX",
    "name": "Etúcuaro",
    "lat": "19.89286",
    "lng": "-102.12945"
  },
  {
    "country": "MX",
    "name": "Etchoropo",
    "lat": "26.76727",
    "lng": "-109.68236"
  },
  {
    "country": "MX",
    "name": "Etchojoa",
    "lat": "26.91094",
    "lng": "-109.6261"
  },
  {
    "country": "MX",
    "name": "La Estanzuela",
    "lat": "20.66891",
    "lng": "-103.82609"
  },
  {
    "country": "MX",
    "name": "Las Varas (Estación Babícora)",
    "lat": "29.48083",
    "lng": "-108.02556"
  },
  {
    "country": "MX",
    "name": "Esqueda",
    "lat": "30.72412",
    "lng": "-109.5893"
  },
  {
    "country": "MX",
    "name": "Escuinapa",
    "lat": "22.83279",
    "lng": "-105.77772"
  },
  {
    "country": "MX",
    "name": "Escuadrón Doscientos Uno",
    "lat": "25.67433",
    "lng": "-103.34829"
  },
  {
    "country": "MX",
    "name": "Escalerillas",
    "lat": "22.11167",
    "lng": "-101.07305"
  },
  {
    "country": "MX",
    "name": "Erongarícuaro",
    "lat": "19.58881",
    "lng": "-101.7211"
  },
  {
    "country": "MX",
    "name": "Ensenada",
    "lat": "31.87149",
    "lng": "-116.60071"
  },
  {
    "country": "MX",
    "name": "Encarnación de Díaz",
    "lat": "21.52705",
    "lng": "-102.24013"
  },
  {
    "country": "MX",
    "name": "Empalme Escobedo",
    "lat": "20.6725",
    "lng": "-100.74675"
  },
  {
    "country": "MX",
    "name": "Empalme",
    "lat": "27.96166",
    "lng": "-110.81411"
  },
  {
    "country": "MX",
    "name": "El Verde",
    "lat": "20.55567",
    "lng": "-103.27901"
  },
  {
    "country": "MX",
    "name": "El Tule",
    "lat": "27.05376",
    "lng": "-106.26554"
  },
  {
    "country": "MX",
    "name": "El Tuito",
    "lat": "20.32042",
    "lng": "-105.32469"
  },
  {
    "country": "MX",
    "name": "El Tobarito",
    "lat": "27.37057",
    "lng": "-109.89379"
  },
  {
    "country": "MX",
    "name": "El Sauzal de Rodríguez",
    "lat": "31.89329",
    "lng": "-116.69256"
  },
  {
    "country": "MX",
    "name": "El Saúz",
    "lat": "20.47774",
    "lng": "-100.1154"
  },
  {
    "country": "MX",
    "name": "El Salto",
    "lat": "23.77781",
    "lng": "-105.36192"
  },
  {
    "country": "MX",
    "name": "Pueblo Nuevo",
    "lat": "23.37927",
    "lng": "-105.38313"
  },
  {
    "country": "MX",
    "name": "El Salto",
    "lat": "20.51895",
    "lng": "-103.18159"
  },
  {
    "country": "MX",
    "name": "El Salto",
    "lat": "20.33333",
    "lng": "-104.5"
  },
  {
    "country": "MX",
    "name": "El Salero",
    "lat": "22.38706",
    "lng": "-102.32323"
  },
  {
    "country": "MX",
    "name": "El Rosario",
    "lat": "24.25556",
    "lng": "-107.18278"
  },
  {
    "country": "MX",
    "name": "El Roble",
    "lat": "23.24556",
    "lng": "-106.20583"
  },
  {
    "country": "MX",
    "name": "El Refugio",
    "lat": "20.6714",
    "lng": "-103.73929"
  },
  {
    "country": "MX",
    "name": "El Quince",
    "lat": "20.54387",
    "lng": "-103.28467"
  },
  {
    "country": "MX",
    "name": "El Potrero de Sataya",
    "lat": "24.69",
    "lng": "-107.70917"
  },
  {
    "country": "MX",
    "name": "El Oro de Hidalgo",
    "lat": "19.80272",
    "lng": "-100.13081"
  },
  {
    "country": "MX",
    "name": "El Limón",
    "lat": "19.82546",
    "lng": "-104.15633"
  },
  {
    "country": "MX",
    "name": "El Habal",
    "lat": "23.35014",
    "lng": "-106.41834"
  },
  {
    "country": "MX",
    "name": "El Grullo",
    "lat": "19.80603",
    "lng": "-104.21805"
  },
  {
    "country": "MX",
    "name": "El Fuerte",
    "lat": "26.41686",
    "lng": "-108.61828"
  },
  {
    "country": "MX",
    "name": "El Dorado",
    "lat": "24.32283",
    "lng": "-107.36298"
  },
  {
    "country": "MX",
    "name": "Coyote",
    "lat": "25.6951",
    "lng": "-103.2842"
  },
  {
    "country": "MX",
    "name": "El Colorado",
    "lat": "20.56185",
    "lng": "-100.2452"
  },
  {
    "country": "MX",
    "name": "El Colomo",
    "lat": "19.06101",
    "lng": "-104.25853"
  },
  {
    "country": "MX",
    "name": "El Coacoyul",
    "lat": "17.6381",
    "lng": "-101.47571"
  },
  {
    "country": "MX",
    "name": "El Chayote",
    "lat": "22.28667",
    "lng": "-102.239"
  },
  {
    "country": "MX",
    "name": "El Carrizo",
    "lat": "24.01416",
    "lng": "-106.85196"
  },
  {
    "country": "MX",
    "name": "El Cambio",
    "lat": "25.64028",
    "lng": "-103.325"
  },
  {
    "country": "MX",
    "name": "Villa Insurgentes (El Calabazal)",
    "lat": "23.74306",
    "lng": "-103.8425"
  },
  {
    "country": "MX",
    "name": "El Burrión",
    "lat": "25.53878",
    "lng": "-108.41286"
  },
  {
    "country": "MX",
    "name": "El Arenal",
    "lat": "20.77538",
    "lng": "-103.69353"
  },
  {
    "country": "MX",
    "name": "Ejutla",
    "lat": "19.9054",
    "lng": "-104.16174"
  },
  {
    "country": "MX",
    "name": "Ejido Yucatán",
    "lat": "32.60435",
    "lng": "-115.0938"
  },
  {
    "country": "MX",
    "name": "Ejido Tabasco",
    "lat": "32.56187",
    "lng": "-114.92659"
  },
  {
    "country": "MX",
    "name": "Ejido Saltillo",
    "lat": "32.4243",
    "lng": "-115.1248"
  },
  {
    "country": "MX",
    "name": "Puebla",
    "lat": "32.56654",
    "lng": "-115.3534"
  },
  {
    "country": "MX",
    "name": "Ejido Plan de Ayala",
    "lat": "32.22023",
    "lng": "-115.03158"
  },
  {
    "country": "MX",
    "name": "Ejido Jiquilpan",
    "lat": "32.50131",
    "lng": "-115.06382"
  },
  {
    "country": "MX",
    "name": "Ciudad Insurgentes",
    "lat": "25.26345",
    "lng": "-111.77444"
  },
  {
    "country": "MX",
    "name": "Hermosillo",
    "lat": "32.51097",
    "lng": "-114.92278"
  },
  {
    "country": "MX",
    "name": "Ejido El Largo",
    "lat": "29.68333",
    "lng": "-108.26667"
  },
  {
    "country": "MX",
    "name": "Ecuandureo",
    "lat": "20.16188",
    "lng": "-102.1934"
  },
  {
    "country": "MX",
    "name": "Victoria de Durango",
    "lat": "24.02032",
    "lng": "-104.65756"
  },
  {
    "country": "MX",
    "name": "Duarte",
    "lat": "21.08712",
    "lng": "-101.52431"
  },
  {
    "country": "MX",
    "name": "San Lorenzo",
    "lat": "28.15352",
    "lng": "-106.47695"
  },
  {
    "country": "MX",
    "name": "Doctor Arroyo",
    "lat": "23.67211",
    "lng": "-100.18134"
  },
  {
    "country": "MX",
    "name": "Divisaderos",
    "lat": "29.61497",
    "lng": "-109.46942"
  },
  {
    "country": "MX",
    "name": "Degollado",
    "lat": "20.46702",
    "lng": "-102.14976"
  },
  {
    "country": "MX",
    "name": "San Miguel Cuyutlán",
    "lat": "20.41633",
    "lng": "-103.38987"
  },
  {
    "country": "MX",
    "name": "Cutzamala de Pinzón",
    "lat": "18.46783",
    "lng": "-100.58089"
  },
  {
    "country": "MX",
    "name": "Cusihuiriachi",
    "lat": "28.2398",
    "lng": "-106.83477"
  },
  {
    "country": "MX",
    "name": "Cuquío",
    "lat": "20.93027",
    "lng": "-103.02771"
  },
  {
    "country": "MX",
    "name": "Cupareo",
    "lat": "20.22876",
    "lng": "-101.01806"
  },
  {
    "country": "MX",
    "name": "Cumpas",
    "lat": "29.99587",
    "lng": "-109.78087"
  },
  {
    "country": "MX",
    "name": "Culiacancito",
    "lat": "24.82538",
    "lng": "-107.53445"
  },
  {
    "country": "MX",
    "name": "Culiacán",
    "lat": "24.79032",
    "lng": "-107.38782"
  },
  {
    "country": "MX",
    "name": "Cuitzeo del Porvenir",
    "lat": "19.97025",
    "lng": "-101.1429"
  },
  {
    "country": "MX",
    "name": "Cuitzeo (La Estancia)",
    "lat": "20.34278",
    "lng": "-102.78389"
  },
  {
    "country": "MX",
    "name": "San Bartolo Cuitareo",
    "lat": "19.65139",
    "lng": "-100.60111"
  },
  {
    "country": "MX",
    "name": "Cuexcomatitlán",
    "lat": "20.4281",
    "lng": "-103.36189"
  },
  {
    "country": "MX",
    "name": "Cuerámaro",
    "lat": "20.62546",
    "lng": "-101.67242"
  },
  {
    "country": "MX",
    "name": "Cuencamé de Ceniceros",
    "lat": "24.87116",
    "lng": "-103.69731"
  },
  {
    "country": "MX",
    "name": "Cucurpe",
    "lat": "30.33049",
    "lng": "-110.70609"
  },
  {
    "country": "MX",
    "name": "Palmar de Cuautla",
    "lat": "22.21972",
    "lng": "-105.6475"
  },
  {
    "country": "MX",
    "name": "Cuautla",
    "lat": "20.20139",
    "lng": "-104.4075"
  },
  {
    "country": "MX",
    "name": "Cuautitlán",
    "lat": "19.45135",
    "lng": "-104.35928"
  },
  {
    "country": "MX",
    "name": "Cuauhtémoc",
    "lat": "28.40884",
    "lng": "-106.86319"
  },
  {
    "country": "MX",
    "name": "Cuauhtémoc",
    "lat": "19.32861",
    "lng": "-103.60284"
  },
  {
    "country": "MX",
    "name": "Cuatro Ciénegas de Carranza",
    "lat": "26.98542",
    "lng": "-102.06386"
  },
  {
    "country": "MX",
    "name": "Cuanajo",
    "lat": "19.48485",
    "lng": "-101.50794"
  },
  {
    "country": "MX",
    "name": "El Crucero de Santa María",
    "lat": "20.38317",
    "lng": "-103.86131"
  },
  {
    "country": "MX",
    "name": "Creel",
    "lat": "27.75054",
    "lng": "-107.6352"
  },
  {
    "country": "MX",
    "name": "Coyula",
    "lat": "20.63333",
    "lng": "-103.2"
  },
  {
    "country": "MX",
    "name": "Coyuca de Catalán",
    "lat": "18.32614",
    "lng": "-100.69898"
  },
  {
    "country": "MX",
    "name": "Coyuca de Benítez",
    "lat": "17.00895",
    "lng": "-100.08714"
  },
  {
    "country": "MX",
    "name": "Coyame",
    "lat": "29.46141",
    "lng": "-105.09404"
  },
  {
    "country": "MX",
    "name": "Cotija de la Paz",
    "lat": "19.80922",
    "lng": "-102.70198"
  },
  {
    "country": "MX",
    "name": "Villa de Costa Rica",
    "lat": "24.59167",
    "lng": "-107.38836"
  },
  {
    "country": "MX",
    "name": "Cosío",
    "lat": "22.36625",
    "lng": "-102.30008"
  },
  {
    "country": "MX",
    "name": "Cosalá",
    "lat": "24.41501",
    "lng": "-106.69073"
  },
  {
    "country": "MX",
    "name": "Cortazar",
    "lat": "20.48362",
    "lng": "-100.96237"
  },
  {
    "country": "MX",
    "name": "Coroneo",
    "lat": "20.20001",
    "lng": "-100.36546"
  },
  {
    "country": "MX",
    "name": "Coquimatlán",
    "lat": "19.20625",
    "lng": "-103.80952"
  },
  {
    "country": "MX",
    "name": "Copándaro de Galeana",
    "lat": "19.89254",
    "lng": "-101.21394"
  },
  {
    "country": "MX",
    "name": "Copándaro (Copándaro del Cuatro)",
    "lat": "19.90057",
    "lng": "-101.65945"
  },
  {
    "country": "MX",
    "name": "Contepec",
    "lat": "19.95432",
    "lng": "-100.16385"
  },
  {
    "country": "MX",
    "name": "La Constancia",
    "lat": "24.22363",
    "lng": "-107.1861"
  },
  {
    "country": "MX",
    "name": "Congregación Ortíz",
    "lat": "28.25375",
    "lng": "-105.51922"
  },
  {
    "country": "MX",
    "name": "Coneto de Comonfort",
    "lat": "24.98089",
    "lng": "-104.77055"
  },
  {
    "country": "MX",
    "name": "Concordia",
    "lat": "25.77982",
    "lng": "-103.11696"
  },
  {
    "country": "MX",
    "name": "Concepción del Oro",
    "lat": "24.61326",
    "lng": "-101.41844"
  },
  {
    "country": "MX",
    "name": "Concepción de Buenos Aires",
    "lat": "19.97822",
    "lng": "-103.25981"
  },
  {
    "country": "MX",
    "name": "La Concha (La Concepción)",
    "lat": "22.5325",
    "lng": "-105.4525"
  },
  {
    "country": "MX",
    "name": "Compostela",
    "lat": "21.23777",
    "lng": "-104.9001"
  },
  {
    "country": "MX",
    "name": "Comonfort",
    "lat": "20.72278",
    "lng": "-100.75946"
  },
  {
    "country": "MX",
    "name": "Comala",
    "lat": "19.32717",
    "lng": "-103.75926"
  },
  {
    "country": "MX",
    "name": "Comachuén",
    "lat": "19.57132",
    "lng": "-101.90433"
  },
  {
    "country": "MX",
    "name": "Colotlán",
    "lat": "22.11299",
    "lng": "-103.26707"
  },
  {
    "country": "MX",
    "name": "Colorines",
    "lat": "19.17829",
    "lng": "-100.21817"
  },
  {
    "country": "MX",
    "name": "Vicente Guerrero",
    "lat": "30.73097",
    "lng": "-115.99071"
  },
  {
    "country": "MX",
    "name": "Antonio Rosales",
    "lat": "27.35111",
    "lng": "-109.85306"
  },
  {
    "country": "MX",
    "name": "Colonia Plenitud",
    "lat": "23.2325",
    "lng": "-103.075"
  },
  {
    "country": "MX",
    "name": "Colonia Nicolás Bravo (Kilómetro Noventa y Dos)",
    "lat": "28.09222",
    "lng": "-105.52778"
  },
  {
    "country": "MX",
    "name": "Ampliación Colonia Lázaro Cárdenas",
    "lat": "28.38333",
    "lng": "-105.61667"
  },
  {
    "country": "MX",
    "name": "San José de Gracia",
    "lat": "22.14837",
    "lng": "-102.41474"
  },
  {
    "country": "MX",
    "name": "Allende",
    "lat": "27.19201",
    "lng": "-109.9073"
  },
  {
    "country": "MX",
    "name": "Colonia Abraham González (La Quemada)",
    "lat": "28.20667",
    "lng": "-105.4075"
  },
  {
    "country": "MX",
    "name": "Colón",
    "lat": "20.78323",
    "lng": "-100.05149"
  },
  {
    "country": "MX",
    "name": "Colima",
    "lat": "19.24997",
    "lng": "-103.72714"
  },
  {
    "country": "MX",
    "name": "Cojumatlán de Régules",
    "lat": "20.11858",
    "lng": "-102.85182"
  },
  {
    "country": "MX",
    "name": "Cofradía de Navolato (Cofradía de los Rocha)",
    "lat": "24.76806",
    "lng": "-107.64806"
  },
  {
    "country": "MX",
    "name": "Cofradía",
    "lat": "19.43333",
    "lng": "-103.55"
  },
  {
    "country": "MX",
    "name": "Coeneo de la Libertad",
    "lat": "19.82195",
    "lng": "-101.5847"
  },
  {
    "country": "MX",
    "name": "Cocula",
    "lat": "20.36517",
    "lng": "-103.82215"
  },
  {
    "country": "MX",
    "name": "Cocorit",
    "lat": "27.57519",
    "lng": "-109.9591"
  },
  {
    "country": "MX",
    "name": "Coalcomán de Vázquez Pallares",
    "lat": "18.7775",
    "lng": "-103.16"
  },
  {
    "country": "MX",
    "name": "Coahuayutla de Guerrero",
    "lat": "18.31469",
    "lng": "-101.73574"
  },
  {
    "country": "MX",
    "name": "Coahuayana Viejo",
    "lat": "18.75119",
    "lng": "-103.66798"
  },
  {
    "country": "MX",
    "name": "Ciudad Obregón",
    "lat": "27.48642",
    "lng": "-109.94083"
  },
  {
    "country": "MX",
    "name": "Ciudad Manuel Doblado",
    "lat": "20.72888",
    "lng": "-101.95226"
  },
  {
    "country": "MX",
    "name": "Ciudad Lerdo",
    "lat": "25.53718",
    "lng": "-103.52456"
  },
  {
    "country": "MX",
    "name": "Juárez",
    "lat": "31.72024",
    "lng": "-106.46084"
  },
  {
    "country": "MX",
    "name": "Ciudad Hidalgo",
    "lat": "19.6927",
    "lng": "-100.55445"
  },
  {
    "country": "MX",
    "name": "Ciudad Guzmán",
    "lat": "19.70466",
    "lng": "-103.4617"
  },
  {
    "country": "MX",
    "name": "Guerrero",
    "lat": "28.54875",
    "lng": "-107.48377"
  },
  {
    "country": "MX",
    "name": "Ciudad Delicias",
    "lat": "28.19013",
    "lng": "-105.47012"
  },
  {
    "country": "MX",
    "name": "Ciudad Constitución",
    "lat": "25.0321",
    "lng": "-111.66256"
  },
  {
    "country": "MX",
    "name": "Camargo",
    "lat": "27.67842",
    "lng": "-105.17136"
  },
  {
    "country": "MX",
    "name": "Anáhuac",
    "lat": "27.24457",
    "lng": "-100.13229"
  },
  {
    "country": "MX",
    "name": "Ciudad Altamirano",
    "lat": "18.3582",
    "lng": "-100.66965"
  },
  {
    "country": "MX",
    "name": "Ciudad Acuña",
    "lat": "29.32322",
    "lng": "-100.95217"
  },
  {
    "country": "MX",
    "name": "Cieneguilla",
    "lat": "21.24833",
    "lng": "-100.27389"
  },
  {
    "country": "MX",
    "name": "Ciénega de Flores",
    "lat": "25.95467",
    "lng": "-100.16695"
  },
  {
    "country": "MX",
    "name": "Churintzio",
    "lat": "20.15056",
    "lng": "-102.06469"
  },
  {
    "country": "MX",
    "name": "Chucarit",
    "lat": "27.03157",
    "lng": "-109.58421"
  },
  {
    "country": "MX",
    "name": "Chucándiro",
    "lat": "19.90008",
    "lng": "-101.3338"
  },
  {
    "country": "MX",
    "name": "Choix",
    "lat": "26.70901",
    "lng": "-108.32545"
  },
  {
    "country": "MX",
    "name": "Jitonhueca",
    "lat": "27.06167",
    "lng": "-109.605"
  },
  {
    "country": "MX",
    "name": "Chiquilistlán",
    "lat": "20.2",
    "lng": "-103.81667"
  },
  {
    "country": "MX",
    "name": "Chiquilistlán",
    "lat": "20.08776",
    "lng": "-103.86071"
  },
  {
    "country": "MX",
    "name": "Chínipas",
    "lat": "27.39502",
    "lng": "-108.5373"
  },
  {
    "country": "MX",
    "name": "Chilchota",
    "lat": "19.84654",
    "lng": "-102.11716"
  },
  {
    "country": "MX",
    "name": "Chilapa",
    "lat": "22.03138",
    "lng": "-105.23057"
  },
  {
    "country": "MX",
    "name": "Chihuahua",
    "lat": "28.63528",
    "lng": "-106.08889"
  },
  {
    "country": "MX",
    "name": "Cherán",
    "lat": "19.68536",
    "lng": "-101.95368"
  },
  {
    "country": "MX",
    "name": "Chavinda",
    "lat": "20.00625",
    "lng": "-102.46015"
  },
  {
    "country": "MX",
    "name": "Charo",
    "lat": "19.74966",
    "lng": "-101.04571"
  },
  {
    "country": "MX",
    "name": "Charcas",
    "lat": "23.12943",
    "lng": "-101.11346"
  },
  {
    "country": "MX",
    "name": "Charapán",
    "lat": "19.65112",
    "lng": "-102.2519"
  },
  {
    "country": "MX",
    "name": "Chapala",
    "lat": "20.29616",
    "lng": "-103.19123"
  },
  {
    "country": "MX",
    "name": "Chametla",
    "lat": "22.8775",
    "lng": "-105.9575"
  },
  {
    "country": "MX",
    "name": "Chalchihuites",
    "lat": "23.47498",
    "lng": "-103.88293"
  },
  {
    "country": "MX",
    "name": "Cerro Gordo",
    "lat": "20.59294",
    "lng": "-101.12684"
  },
  {
    "country": "MX",
    "name": "Cerro de San Pedro",
    "lat": "22.2178",
    "lng": "-100.79961"
  },
  {
    "country": "MX",
    "name": "Cerritos",
    "lat": "22.42835",
    "lng": "-100.28474"
  },
  {
    "country": "MX",
    "name": "Cerano",
    "lat": "20.10877",
    "lng": "-101.3871"
  },
  {
    "country": "MX",
    "name": "Celaya",
    "lat": "20.52353",
    "lng": "-100.8157"
  },
  {
    "country": "MX",
    "name": "Los Cedros",
    "lat": "20.3898",
    "lng": "-103.2325"
  },
  {
    "country": "MX",
    "name": "Cedral",
    "lat": "23.82099",
    "lng": "-100.72527"
  },
  {
    "country": "MX",
    "name": "Ceballos",
    "lat": "26.5258",
    "lng": "-104.1295"
  },
  {
    "country": "MX",
    "name": "Castaños",
    "lat": "26.78932",
    "lng": "-101.43211"
  },
  {
    "country": "MX",
    "name": "La Resolana",
    "lat": "19.6052",
    "lng": "-104.43433"
  },
  {
    "country": "MX",
    "name": "Casas Grandes",
    "lat": "30.38269",
    "lng": "-107.95628"
  },
  {
    "country": "MX",
    "name": "Carranco",
    "lat": "21.82002",
    "lng": "-101.09699"
  },
  {
    "country": "MX",
    "name": "Carmen",
    "lat": "25.9365",
    "lng": "-100.36396"
  },
  {
    "country": "MX",
    "name": "Carichí",
    "lat": "27.91651",
    "lng": "-107.05664"
  },
  {
    "country": "MX",
    "name": "Carácuaro",
    "lat": "19.01966",
    "lng": "-101.12494"
  },
  {
    "country": "MX",
    "name": "Capula",
    "lat": "19.7",
    "lng": "-101.8"
  },
  {
    "country": "MX",
    "name": "El Capomal",
    "lat": "21.83935",
    "lng": "-105.12116"
  },
  {
    "country": "MX",
    "name": "Capilla de Guadalupe",
    "lat": "20.82739",
    "lng": "-102.59185"
  },
  {
    "country": "MX",
    "name": "Capácuaro",
    "lat": "19.54741",
    "lng": "-102.05184"
  },
  {
    "country": "MX",
    "name": "Cañitas de Felipe Pescador",
    "lat": "23.60371",
    "lng": "-102.72704"
  },
  {
    "country": "MX",
    "name": "Canelas",
    "lat": "25.12341",
    "lng": "-106.54622"
  },
  {
    "country": "MX",
    "name": "Candela",
    "lat": "26.8384",
    "lng": "-100.6663"
  },
  {
    "country": "MX",
    "name": "Canatlán",
    "lat": "24.52576",
    "lng": "-104.77327"
  },
  {
    "country": "MX",
    "name": "Cananea",
    "lat": "30.98699",
    "lng": "-110.29062"
  },
  {
    "country": "MX",
    "name": "Cañada de Caracheo",
    "lat": "20.37552",
    "lng": "-100.94549"
  },
  {
    "country": "MX",
    "name": "Campo Sesenta",
    "lat": "27.45",
    "lng": "-110.1"
  },
  {
    "country": "MX",
    "name": "Villa Juárez",
    "lat": "24.65869",
    "lng": "-107.54059"
  },
  {
    "country": "MX",
    "name": "Calvillo",
    "lat": "21.84583",
    "lng": "-102.71849"
  },
  {
    "country": "MX",
    "name": "Víctor Rosales",
    "lat": "22.94889",
    "lng": "-102.70222"
  },
  {
    "country": "MX",
    "name": "Cajititlán",
    "lat": "20.43174",
    "lng": "-103.3094"
  },
  {
    "country": "MX",
    "name": "Bustamante",
    "lat": "26.53498",
    "lng": "-100.50608"
  },
  {
    "country": "MX",
    "name": "Buenos Aires",
    "lat": "19.07499",
    "lng": "-102.17999"
  },
  {
    "country": "MX",
    "name": "Buena Vista Tomatlán",
    "lat": "19.21281",
    "lng": "-102.58735"
  },
  {
    "country": "MX",
    "name": "San Buenaventura",
    "lat": "29.8432",
    "lng": "-107.46067"
  },
  {
    "country": "MX",
    "name": "Bucerías",
    "lat": "20.75626",
    "lng": "-105.33438"
  },
  {
    "country": "MX",
    "name": "Briseñas de Matamoros",
    "lat": "20.26821",
    "lng": "-102.56195"
  },
  {
    "country": "MX",
    "name": "San Martín de Bolaños",
    "lat": "21.68257",
    "lng": "-103.81325"
  },
  {
    "country": "MX",
    "name": "Bocoyna",
    "lat": "27.84133",
    "lng": "-107.58918"
  },
  {
    "country": "MX",
    "name": "Bimbaletes Aguascalientes (El Álamo)",
    "lat": "22.23444",
    "lng": "-102.01917"
  },
  {
    "country": "MX",
    "name": "Bermejillo",
    "lat": "25.88682",
    "lng": "-103.62069"
  },
  {
    "country": "MX",
    "name": "Benjamín Hill",
    "lat": "30.16904",
    "lng": "-111.11403"
  },
  {
    "country": "MX",
    "name": "Benito Juárez",
    "lat": "29.74624",
    "lng": "-107.93966"
  },
  {
    "country": "MX",
    "name": "Benito Juárez",
    "lat": "19.23333",
    "lng": "-100.46667"
  },
  {
    "country": "MX",
    "name": "Bellavista",
    "lat": "20.43408",
    "lng": "-103.63742"
  },
  {
    "country": "MX",
    "name": "Bavispe",
    "lat": "30.47931",
    "lng": "-108.93982"
  },
  {
    "country": "MX",
    "name": "Baviácora",
    "lat": "29.71349",
    "lng": "-110.16307"
  },
  {
    "country": "MX",
    "name": "Batopilas",
    "lat": "27.02846",
    "lng": "-107.74125"
  },
  {
    "country": "MX",
    "name": "Gonzales Ortega",
    "lat": "23.18056",
    "lng": "-102.47589"
  },
  {
    "country": "MX",
    "name": "Banámichi",
    "lat": "30.0074",
    "lng": "-110.21585"
  },
  {
    "country": "MX",
    "name": "Bahía de Kino",
    "lat": "28.82278",
    "lng": "-111.94083"
  },
  {
    "country": "MX",
    "name": "Bagojo Colectivo",
    "lat": "25.87417",
    "lng": "-109.11778"
  },
  {
    "country": "MX",
    "name": "Badiraguato",
    "lat": "25.36525",
    "lng": "-107.55083"
  },
  {
    "country": "MX",
    "name": "Bácum",
    "lat": "27.55142",
    "lng": "-110.0833"
  },
  {
    "country": "MX",
    "name": "Bacubirito",
    "lat": "25.80944",
    "lng": "-107.915"
  },
  {
    "country": "MX",
    "name": "Bacoachi",
    "lat": "30.63168",
    "lng": "-109.96867"
  },
  {
    "country": "MX",
    "name": "Bachomobampo Número Dos",
    "lat": "25.73888",
    "lng": "-109.14776"
  },
  {
    "country": "MX",
    "name": "Bachíniva",
    "lat": "28.76801",
    "lng": "-107.25559"
  },
  {
    "country": "MX",
    "name": "Bacerac",
    "lat": "30.35565",
    "lng": "-108.93147"
  },
  {
    "country": "MX",
    "name": "Bacanora",
    "lat": "28.98152",
    "lng": "-109.40012"
  },
  {
    "country": "MX",
    "name": "Bacadéhuachi",
    "lat": "29.80872",
    "lng": "-109.14054"
  },
  {
    "country": "MX",
    "name": "Ayutla",
    "lat": "20.12907",
    "lng": "-104.34355"
  },
  {
    "country": "MX",
    "name": "Ayotlán",
    "lat": "20.52907",
    "lng": "-102.3262"
  },
  {
    "country": "MX",
    "name": "Autlán de Navarro",
    "lat": "19.76822",
    "lng": "-104.36664"
  },
  {
    "country": "MX",
    "name": "Aután",
    "lat": "21.68973",
    "lng": "-105.3075"
  },
  {
    "country": "MX",
    "name": "Atoyac de Álvarez",
    "lat": "17.20667",
    "lng": "-100.43306"
  },
  {
    "country": "MX",
    "name": "Atoyac",
    "lat": "20.0097",
    "lng": "-103.51652"
  },
  {
    "country": "MX",
    "name": "Atotonilquillo",
    "lat": "20.39287",
    "lng": "-103.12356"
  },
  {
    "country": "MX",
    "name": "Atotonilco el Alto",
    "lat": "20.55079",
    "lng": "-102.50942"
  },
  {
    "country": "MX",
    "name": "Atolinga",
    "lat": "21.80659",
    "lng": "-103.46496"
  },
  {
    "country": "MX",
    "name": "Atil",
    "lat": "30.84361",
    "lng": "-111.58361"
  },
  {
    "country": "MX",
    "name": "Aticama",
    "lat": "21.48387",
    "lng": "-105.19787"
  },
  {
    "country": "MX",
    "name": "San Juan Atezcapan",
    "lat": "19.16722",
    "lng": "-100.18583"
  },
  {
    "country": "MX",
    "name": "Atequiza",
    "lat": "20.39006",
    "lng": "-103.14065"
  },
  {
    "country": "MX",
    "name": "Atenguillo",
    "lat": "20.41553",
    "lng": "-104.49387"
  },
  {
    "country": "MX",
    "name": "Atengo",
    "lat": "20.27412",
    "lng": "-104.23715"
  },
  {
    "country": "MX",
    "name": "Atemajac de Brizuela",
    "lat": "20.13735",
    "lng": "-103.72588"
  },
  {
    "country": "MX",
    "name": "Atapán",
    "lat": "19.65057",
    "lng": "-102.42463"
  },
  {
    "country": "MX",
    "name": "Asientos",
    "lat": "22.23836",
    "lng": "-102.0894"
  },
  {
    "country": "MX",
    "name": "Ascención",
    "lat": "31.1",
    "lng": "-107.98333"
  },
  {
    "country": "MX",
    "name": "Arteaga",
    "lat": "25.44528",
    "lng": "-100.84667"
  },
  {
    "country": "MX",
    "name": "Arteaga",
    "lat": "18.35779",
    "lng": "-102.29122"
  },
  {
    "country": "MX",
    "name": "Villa de Arriaga",
    "lat": "21.90917",
    "lng": "-101.38223"
  },
  {
    "country": "MX",
    "name": "Ciudad de Armería",
    "lat": "18.9378",
    "lng": "-103.96417"
  },
  {
    "country": "MX",
    "name": "Armadillo de los Infante",
    "lat": "22.2449",
    "lng": "-100.6558"
  },
  {
    "country": "MX",
    "name": "Arizpe",
    "lat": "30.3369",
    "lng": "-110.16649"
  },
  {
    "country": "MX",
    "name": "Arivechi",
    "lat": "28.92765",
    "lng": "-109.18681"
  },
  {
    "country": "MX",
    "name": "Villa de Arista",
    "lat": "22.64252",
    "lng": "-100.84808"
  },
  {
    "country": "MX",
    "name": "Ario de Rosales",
    "lat": "19.209",
    "lng": "-101.70743"
  },
  {
    "country": "MX",
    "name": "Ario de Rayón",
    "lat": "20.02651",
    "lng": "-102.34814"
  },
  {
    "country": "MX",
    "name": "Arcelia",
    "lat": "18.31847",
    "lng": "-100.28148"
  },
  {
    "country": "MX",
    "name": "Arandas",
    "lat": "20.70519",
    "lng": "-102.34635"
  },
  {
    "country": "MX",
    "name": "Santa Eulalia",
    "lat": "28.5945",
    "lng": "-105.88796"
  },
  {
    "country": "MX",
    "name": "Apozol",
    "lat": "21.46952",
    "lng": "-103.09076"
  },
  {
    "country": "MX",
    "name": "Aporo",
    "lat": "19.67021",
    "lng": "-100.41068"
  },
  {
    "country": "MX",
    "name": "Ciudad Apodaca",
    "lat": "25.78195",
    "lng": "-100.18839"
  },
  {
    "country": "MX",
    "name": "Apatzingán",
    "lat": "19.08864",
    "lng": "-102.35704"
  },
  {
    "country": "MX",
    "name": "Apaseo el Grande",
    "lat": "20.54495",
    "lng": "-100.68462"
  },
  {
    "country": "MX",
    "name": "Apaseo el Alto",
    "lat": "20.45798",
    "lng": "-100.62081"
  },
  {
    "country": "MX",
    "name": "Antúnez",
    "lat": "19.01451",
    "lng": "-102.20432"
  },
  {
    "country": "MX",
    "name": "Antonio Escobedo",
    "lat": "20.8",
    "lng": "-104.01667"
  },
  {
    "country": "MX",
    "name": "San Juanito de Escobedo",
    "lat": "20.79436",
    "lng": "-104.00245"
  },
  {
    "country": "MX",
    "name": "Angostura",
    "lat": "25.36586",
    "lng": "-108.16107"
  },
  {
    "country": "MX",
    "name": "Angamacutiro de la Unión",
    "lat": "20.14998",
    "lng": "-101.71113"
  },
  {
    "country": "MX",
    "name": "Angahuán",
    "lat": "19.5479",
    "lng": "-102.22563"
  },
  {
    "country": "MX",
    "name": "Anáhuac",
    "lat": "28.48396",
    "lng": "-106.7472"
  },
  {
    "country": "MX",
    "name": "Ameca",
    "lat": "20.54629",
    "lng": "-104.04508"
  },
  {
    "country": "MX",
    "name": "Amealco",
    "lat": "20.18758",
    "lng": "-100.14485"
  },
  {
    "country": "MX",
    "name": "Amatlán de Cañas",
    "lat": "20.80699",
    "lng": "-104.40408"
  },
  {
    "country": "MX",
    "name": "Amatitán",
    "lat": "20.83388",
    "lng": "-103.73076"
  },
  {
    "country": "MX",
    "name": "Amatepec",
    "lat": "18.68222",
    "lng": "-100.18583"
  },
  {
    "country": "MX",
    "name": "Amazcala",
    "lat": "20.70339",
    "lng": "-100.26511"
  },
  {
    "country": "MX",
    "name": "Amanalco de Becerra",
    "lat": "19.31667",
    "lng": "-100.01667"
  },
  {
    "country": "MX",
    "name": "Amacueca",
    "lat": "20.01069",
    "lng": "-103.59983"
  },
  {
    "country": "MX",
    "name": "Álvaro Obregón",
    "lat": "19.82096",
    "lng": "-101.04008"
  },
  {
    "country": "MX",
    "name": "Altar",
    "lat": "30.71538",
    "lng": "-111.83703"
  },
  {
    "country": "MX",
    "name": "Almoloya de las Granadas",
    "lat": "18.97309",
    "lng": "-100.13335"
  },
  {
    "country": "MX",
    "name": "Allende",
    "lat": "28.34124",
    "lng": "-100.85111"
  },
  {
    "country": "MX",
    "name": "Ciudad de Allende",
    "lat": "25.27673",
    "lng": "-100.01442"
  },
  {
    "country": "MX",
    "name": "Alista",
    "lat": "19.63487",
    "lng": "-103.78945"
  },
  {
    "country": "MX",
    "name": "Alhuey",
    "lat": "25.37806",
    "lng": "-108.13028"
  },
  {
    "country": "MX",
    "name": "Aldama",
    "lat": "28.83669",
    "lng": "-105.91423"
  },
  {
    "country": "MX",
    "name": "Aldama",
    "lat": "20.81641",
    "lng": "-101.31467"
  },
  {
    "country": "MX",
    "name": "Alcocer",
    "lat": "20.86867",
    "lng": "-100.70456"
  },
  {
    "country": "MX",
    "name": "Álamos",
    "lat": "27.02326",
    "lng": "-108.9344"
  },
  {
    "country": "MX",
    "name": "Ajuchitlán del Progreso",
    "lat": "18.15189",
    "lng": "-100.48353"
  },
  {
    "country": "MX",
    "name": "Ajuchitlán",
    "lat": "20.70713",
    "lng": "-100.02008"
  },
  {
    "country": "MX",
    "name": "Ajijic",
    "lat": "20.30325",
    "lng": "-103.25476"
  },
  {
    "country": "MX",
    "name": "Ahuirán",
    "lat": "19.66574",
    "lng": "-102.07347"
  },
  {
    "country": "MX",
    "name": "Ahualulco de Mercado",
    "lat": "20.70137",
    "lng": "-103.97461"
  },
  {
    "country": "MX",
    "name": "Ahualulco del Sonido Trece",
    "lat": "22.40019",
    "lng": "-101.16614"
  },
  {
    "country": "MX",
    "name": "Ahuacatlán",
    "lat": "21.05405",
    "lng": "-104.48398"
  },
  {
    "country": "MX",
    "name": "Ahome",
    "lat": "25.91985",
    "lng": "-109.1732"
  },
  {
    "country": "MX",
    "name": "Aguililla",
    "lat": "18.73742",
    "lng": "-102.78934"
  },
  {
    "country": "MX",
    "name": "Agua Verde",
    "lat": "22.89259",
    "lng": "-105.97355"
  },
  {
    "country": "MX",
    "name": "Aguascalientes",
    "lat": "21.88234",
    "lng": "-102.28259"
  },
  {
    "country": "MX",
    "name": "Agua Prieta",
    "lat": "31.33071",
    "lng": "-109.54876"
  },
  {
    "country": "MX",
    "name": "Agua Caliente Grande (De Gastélum)",
    "lat": "26.53762",
    "lng": "-108.34814"
  },
  {
    "country": "MX",
    "name": "Agiabampo Uno",
    "lat": "26.36686",
    "lng": "-109.14572"
  },
  {
    "country": "MX",
    "name": "Adolfo Ruíz Cortínes",
    "lat": "25.75",
    "lng": "-108.75"
  },
  {
    "country": "MX",
    "name": "Acuítzio del Canje",
    "lat": "19.49585",
    "lng": "-101.33321"
  },
  {
    "country": "MX",
    "name": "Aconchi",
    "lat": "29.82628",
    "lng": "-110.22492"
  },
  {
    "country": "MX",
    "name": "Acatlán de Juárez",
    "lat": "20.42262",
    "lng": "-103.59051"
  },
  {
    "country": "MX",
    "name": "Acatic",
    "lat": "20.77995",
    "lng": "-102.91056"
  },
  {
    "country": "MX",
    "name": "Acaponeta",
    "lat": "22.49396",
    "lng": "-105.36369"
  },
  {
    "country": "MX",
    "name": "Acapetlahuaya",
    "lat": "18.41942",
    "lng": "-100.07237"
  },
  {
    "country": "MX",
    "name": "Acámbaro",
    "lat": "20.03085",
    "lng": "-100.72194"
  },
  {
    "country": "MX",
    "name": "Abasolo",
    "lat": "27.18219",
    "lng": "-101.42757"
  },
  {
    "country": "MX",
    "name": "Abasolo",
    "lat": "25.94595",
    "lng": "-100.39584"
  },
  {
    "country": "MX",
    "name": "Abasolo",
    "lat": "20.44997",
    "lng": "-101.53073"
  },
  {
    "country": "MX",
    "name": "Ramón Corona",
    "lat": "24.18611",
    "lng": "-103.63028"
  },
  {
    "country": "MX",
    "name": "La Presa",
    "lat": "22.34358",
    "lng": "-105.3935"
  },
  {
    "country": "MX",
    "name": "Mesa Grande",
    "lat": "21.805",
    "lng": "-102.72167"
  },
  {
    "country": "MX",
    "name": "La Labor",
    "lat": "21.96207",
    "lng": "-102.69626"
  },
  {
    "country": "MX",
    "name": "San Antonio de los Ríos",
    "lat": "22.16104",
    "lng": "-102.47118"
  },
  {
    "country": "MX",
    "name": "Valladolid",
    "lat": "22.02111",
    "lng": "-102.315"
  },
  {
    "country": "MX",
    "name": "Jesús Gómez Portugal (Margaritas)",
    "lat": "21.99917",
    "lng": "-102.29139"
  },
  {
    "country": "MX",
    "name": "Paseos de la Providencia [Fraccionamiento]",
    "lat": "22.02425",
    "lng": "-102.27711"
  },
  {
    "country": "MX",
    "name": "Peñuelas (El Cienegal)",
    "lat": "21.7225",
    "lng": "-102.27583"
  },
  {
    "country": "MX",
    "name": "El Refugio de Providencia (Providencia)",
    "lat": "22.34667",
    "lng": "-102.25778"
  },
  {
    "country": "MX",
    "name": "Puertecito de la Virgen",
    "lat": "21.96028",
    "lng": "-102.26889"
  },
  {
    "country": "MX",
    "name": "San Jacinto",
    "lat": "22.34861",
    "lng": "-102.23361"
  },
  {
    "country": "MX",
    "name": "Jaltomate",
    "lat": "22.01528",
    "lng": "-102.14583"
  },
  {
    "country": "MX",
    "name": "Villa Juárez",
    "lat": "22.09447",
    "lng": "-102.0693"
  },
  {
    "country": "MX",
    "name": "Noria del Borrego (Norias)",
    "lat": "22.28722",
    "lng": "-102.04194"
  },
  {
    "country": "MX",
    "name": "Guadalupe de Atlas",
    "lat": "22.26778",
    "lng": "-102.03139"
  },
  {
    "country": "MX",
    "name": "Bahía Asunción",
    "lat": "27.14231",
    "lng": "-114.29582"
  },
  {
    "country": "MX",
    "name": "Villa Morelos",
    "lat": "24.93",
    "lng": "-111.62806"
  },
  {
    "country": "MX",
    "name": "El Pescadero",
    "lat": "23.36417",
    "lng": "-110.16833"
  },
  {
    "country": "MX",
    "name": "Hidalgo",
    "lat": "25.97205",
    "lng": "-100.45029"
  },
  {
    "country": "MX",
    "name": "Victoria",
    "lat": "21.21183",
    "lng": "-100.21545"
  },
  {
    "country": "MX",
    "name": "Doctor Mora",
    "lat": "21.14246",
    "lng": "-100.31966"
  },
  {
    "country": "MX",
    "name": "Palo Colorado",
    "lat": "21.00836",
    "lng": "-100.72917"
  },
  {
    "country": "MX",
    "name": "San Isidro de la Estacada",
    "lat": "21.14746",
    "lng": "-100.68473"
  },
  {
    "country": "MX",
    "name": "Dolores Hidalgo Cuna de la Independencia Nacional",
    "lat": "21.15611",
    "lng": "-100.9325"
  },
  {
    "country": "MX",
    "name": "El Refugio de los Sauces",
    "lat": "21.01488",
    "lng": "-101.53084"
  },
  {
    "country": "MX",
    "name": "San José del Torreón",
    "lat": "21.47444",
    "lng": "-101.47056"
  },
  {
    "country": "MX",
    "name": "El Tejocote (El Domingo)",
    "lat": "21.67611",
    "lng": "-100.915"
  },
  {
    "country": "MX",
    "name": "Chirimoya (Estación Chirimoya)",
    "lat": "21.59278",
    "lng": "-101.09139"
  },
  {
    "country": "MX",
    "name": "Maravatío del Encinal",
    "lat": "20.20513",
    "lng": "-100.96211"
  },
  {
    "country": "MX",
    "name": "Mezquite de Luna",
    "lat": "20.29765",
    "lng": "-101.8926"
  },
  {
    "country": "MX",
    "name": "Zapote de Barajas",
    "lat": "20.37536",
    "lng": "-101.69964"
  },
  {
    "country": "MX",
    "name": "Pastor Ortíz",
    "lat": "20.30552",
    "lng": "-101.59588"
  },
  {
    "country": "MX",
    "name": "El Sauz (El Sauz de Villaseñor)",
    "lat": "20.41056",
    "lng": "-100.79667"
  },
  {
    "country": "MX",
    "name": "La Calera",
    "lat": "20.30164",
    "lng": "-100.84517"
  },
  {
    "country": "MX",
    "name": "San Juan Bautista Cacalote",
    "lat": "20.34806",
    "lng": "-100.78833"
  },
  {
    "country": "MX",
    "name": "El Salto de Espejo",
    "lat": "20.45045",
    "lng": "-100.50587"
  },
  {
    "country": "MX",
    "name": "San Cayetano",
    "lat": "20.60333",
    "lng": "-100.81944"
  },
  {
    "country": "MX",
    "name": "Gasca",
    "lat": "20.60444",
    "lng": "-100.85639"
  },
  {
    "country": "MX",
    "name": "Franco Tavera",
    "lat": "20.60595",
    "lng": "-100.927"
  },
  {
    "country": "MX",
    "name": "El Divisador",
    "lat": "20.57722",
    "lng": "-101.15806"
  },
  {
    "country": "MX",
    "name": "San José de la Montaña",
    "lat": "20.60037",
    "lng": "-101.07228"
  },
  {
    "country": "MX",
    "name": "Sarabia",
    "lat": "20.52256",
    "lng": "-101.06163"
  },
  {
    "country": "MX",
    "name": "Mexicanos",
    "lat": "20.52903",
    "lng": "-101.07064"
  },
  {
    "country": "MX",
    "name": "La Tinaja",
    "lat": "20.49028",
    "lng": "-101.21556"
  },
  {
    "country": "MX",
    "name": "La Capilla",
    "lat": "20.55655",
    "lng": "-101.30019"
  },
  {
    "country": "MX",
    "name": "San Vicente de Flores",
    "lat": "20.62172",
    "lng": "-101.25296"
  },
  {
    "country": "MX",
    "name": "Cuchicuato",
    "lat": "20.66092",
    "lng": "-101.46203"
  },
  {
    "country": "MX",
    "name": "Colonia Morelos de Guadalupe de Rivera",
    "lat": "20.59556",
    "lng": "-101.44833"
  },
  {
    "country": "MX",
    "name": "San Ignacio de Rivera (Ojo de Agua)",
    "lat": "20.55926",
    "lng": "-101.46127"
  },
  {
    "country": "MX",
    "name": "Plan Guanajuato (La Sandía)",
    "lat": "20.92167",
    "lng": "-101.69694"
  },
  {
    "country": "MX",
    "name": "Medio Sitio",
    "lat": "20.86948",
    "lng": "-101.35689"
  },
  {
    "country": "MX",
    "name": "Bajío de Bonillas",
    "lat": "20.94944",
    "lng": "-101.49528"
  },
  {
    "country": "MX",
    "name": "Colonia Nuevo México",
    "lat": "20.98475",
    "lng": "-101.48502"
  },
  {
    "country": "MX",
    "name": "San José del Rodeo",
    "lat": "20.92083",
    "lng": "-101.21639"
  },
  {
    "country": "MX",
    "name": "Santa Catarina",
    "lat": "21.14187",
    "lng": "-100.06994"
  },
  {
    "country": "MX",
    "name": "Potrerillos (Guanajal)",
    "lat": "21.08154",
    "lng": "-101.86986"
  },
  {
    "country": "MX",
    "name": "La Ortiga",
    "lat": "19.96222",
    "lng": "-101.00056"
  },
  {
    "country": "MX",
    "name": "Los Fierros",
    "lat": "20.19353",
    "lng": "-100.75941"
  },
  {
    "country": "MX",
    "name": "Ansihuacuaro",
    "lat": "20.19972",
    "lng": "-101.80778"
  },
  {
    "country": "MX",
    "name": "Isaac Arriaga (Santa Ana Mancera)",
    "lat": "20.24583",
    "lng": "-101.49361"
  },
  {
    "country": "MX",
    "name": "Cuamio",
    "lat": "20.0325",
    "lng": "-101.14889"
  },
  {
    "country": "MX",
    "name": "San Antonio Molinos",
    "lat": "20.07533",
    "lng": "-100.21501"
  },
  {
    "country": "MX",
    "name": "Santa María de los Ángeles",
    "lat": "19.78629",
    "lng": "-100.19938"
  },
  {
    "country": "MX",
    "name": "Manzana de San Luis",
    "lat": "19.56236",
    "lng": "-100.27703"
  },
  {
    "country": "MX",
    "name": "Irimbo",
    "lat": "19.70083",
    "lng": "-100.47847"
  },
  {
    "country": "MX",
    "name": "Mesón Nuevo (Cañada de la Magdalena)",
    "lat": "19.81474",
    "lng": "-101.16597"
  },
  {
    "country": "MX",
    "name": "Santiago Azajo",
    "lat": "19.70667",
    "lng": "-101.68639"
  },
  {
    "country": "MX",
    "name": "Zopoco",
    "lat": "19.84029",
    "lng": "-102.07483"
  },
  {
    "country": "MX",
    "name": "Las Cañas",
    "lat": "18.56583",
    "lng": "-101.97611"
  },
  {
    "country": "MX",
    "name": "Guacamayas",
    "lat": "18.01932",
    "lng": "-102.21225"
  },
  {
    "country": "MX",
    "name": "Ciudad Lázaro Cárdenas",
    "lat": "17.97066",
    "lng": "-102.22124"
  },
  {
    "country": "MX",
    "name": "Infiernillo (Morelos de Infiernillo)",
    "lat": "18.2825",
    "lng": "-101.90111"
  },
  {
    "country": "MX",
    "name": "Santa Ana Zicatecoyan",
    "lat": "18.57167",
    "lng": "-100.22"
  },
  {
    "country": "MX",
    "name": "San Pedro Tenayac",
    "lat": "19.04667",
    "lng": "-100.17694"
  },
  {
    "country": "MX",
    "name": "Zacazonapan",
    "lat": "19.07317",
    "lng": "-100.25515"
  },
  {
    "country": "MX",
    "name": "Otzoloapan",
    "lat": "19.11728",
    "lng": "-100.29684"
  },
  {
    "country": "MX",
    "name": "Cuadrilla de Dolores",
    "lat": "19.14",
    "lng": "-100.06944"
  },
  {
    "country": "MX",
    "name": "Casas Viejas",
    "lat": "19.15167",
    "lng": "-100.10778"
  },
  {
    "country": "MX",
    "name": "Amanalco de Becerra",
    "lat": "19.25374",
    "lng": "-100.0198"
  },
  {
    "country": "MX",
    "name": "Santa Rosa de Lima",
    "lat": "19.78587",
    "lng": "-100.09606"
  },
  {
    "country": "MX",
    "name": "San José del Rincón Centro",
    "lat": "19.66216",
    "lng": "-100.15315"
  },
  {
    "country": "MX",
    "name": "Las Rosas",
    "lat": "19.54631",
    "lng": "-100.15986"
  },
  {
    "country": "MX",
    "name": "San Ildefonso",
    "lat": "19.34919",
    "lng": "-100.1379"
  },
  {
    "country": "MX",
    "name": "Pantla",
    "lat": "17.73861",
    "lng": "-101.63639"
  },
  {
    "country": "MX",
    "name": "San José Ixtapa (Barrio Viejo)",
    "lat": "17.70222",
    "lng": "-101.61944"
  },
  {
    "country": "MX",
    "name": "Los Almendros",
    "lat": "17.61167",
    "lng": "-101.43917"
  },
  {
    "country": "MX",
    "name": "San Jerónimo el Grande",
    "lat": "18.21167",
    "lng": "-100.50179"
  },
  {
    "country": "MX",
    "name": "El Ticui",
    "lat": "17.21639",
    "lng": "-100.44472"
  },
  {
    "country": "MX",
    "name": "Arenal de Álvarez (Arenal de Paco)",
    "lat": "17.12611",
    "lng": "-100.455"
  },
  {
    "country": "MX",
    "name": "Colonia Luces en el Mar",
    "lat": "16.92162",
    "lng": "-100.01526"
  },
  {
    "country": "MX",
    "name": "Colonia Emiliano Zapata",
    "lat": "21.82861",
    "lng": "-105.21972"
  },
  {
    "country": "MX",
    "name": "Las Jarretaderas",
    "lat": "20.6925",
    "lng": "-105.27389"
  },
  {
    "country": "MX",
    "name": "Las Lajitas",
    "lat": "20.8036",
    "lng": "-100.40107"
  },
  {
    "country": "MX",
    "name": "Montenegro",
    "lat": "20.76333",
    "lng": "-100.42861"
  },
  {
    "country": "MX",
    "name": "Santa Catarina",
    "lat": "20.77678",
    "lng": "-100.45233"
  },
  {
    "country": "MX",
    "name": "La Luz",
    "lat": "20.86857",
    "lng": "-100.43839"
  },
  {
    "country": "MX",
    "name": "Colonia los Ángeles",
    "lat": "20.53523",
    "lng": "-100.48828"
  },
  {
    "country": "MX",
    "name": "Los Cerritos",
    "lat": "20.56204",
    "lng": "-100.06338"
  },
  {
    "country": "MX",
    "name": "Apapátaro",
    "lat": "20.46806",
    "lng": "-100.36861"
  },
  {
    "country": "MX",
    "name": "Charco Blanco",
    "lat": "20.43404",
    "lng": "-100.47244"
  },
  {
    "country": "MX",
    "name": "Las Taponas",
    "lat": "20.41667",
    "lng": "-100.38333"
  },
  {
    "country": "MX",
    "name": "Santiago Mexquititlán Barrio 4to.",
    "lat": "20.06306",
    "lng": "-100.06833"
  },
  {
    "country": "MX",
    "name": "San Juan De Los Platanos",
    "lat": "19.1371",
    "lng": "-102.43929"
  },
  {
    "country": "MX",
    "name": "Huapinol",
    "lat": "17.92285",
    "lng": "-92.9109"
  },
  {
    "country": "MX",
    "name": "Zapopan2",
    "lat": "20.7167",
    "lng": "-103.4"
  },
  {
    "country": "MX",
    "name": "Colonia del Valle",
    "lat": "19.38611",
    "lng": "-99.16204"
  },
  {
    "country": "MX",
    "name": "Colonia Lindavista",
    "lat": "19.49156",
    "lng": "-99.12475"
  },
  {
    "country": "MX",
    "name": "Col. Bosques de las Lomas",
    "lat": "19.37893",
    "lng": "-99.26587"
  },
  {
    "country": "MX",
    "name": "Colonia Nativitas",
    "lat": "19.38119",
    "lng": "-99.13685"
  },
  {
    "country": "MX",
    "name": "El Castillo",
    "lat": "20.58072",
    "lng": "-100.49297"
  },
  {
    "country": "MX",
    "name": "Las Higuerillas",
    "lat": "25.26222",
    "lng": "-97.43611"
  },
  {
    "country": "MX",
    "name": "El Barrancón del Tío Blas (El Barrancón)",
    "lat": "25.01556",
    "lng": "-97.71694"
  },
  {
    "country": "MX",
    "name": "La Isla Km 10",
    "lat": "20.60677",
    "lng": "-97.4995"
  },
  {
    "country": "MX",
    "name": "Poblado Lázaro Cárdenas (La Veintiocho)",
    "lat": "32.37333",
    "lng": "-115.06528"
  },
  {
    "country": "MX",
    "name": "Ejido Doctor Alberto Oviedo Mota (El Indiviso)",
    "lat": "32.02444",
    "lng": "-114.98361"
  },
  {
    "country": "MX",
    "name": "San Luis",
    "lat": "32.43167",
    "lng": "-116.95361"
  },
  {
    "country": "MX",
    "name": "Las Delicias",
    "lat": "32.40889",
    "lng": "-116.94361"
  },
  {
    "country": "MX",
    "name": "Ejido Javier Rojo Gómez",
    "lat": "32.49389",
    "lng": "-116.82222"
  },
  {
    "country": "MX",
    "name": "Ejido Ojo de Agua",
    "lat": "32.47556",
    "lng": "-116.78917"
  },
  {
    "country": "MX",
    "name": "San Pedro Garza Garcia",
    "lat": "25.65716",
    "lng": "-100.40268"
  },
  {
    "country": "MX",
    "name": "La Nueva Victoria",
    "lat": "18.65639",
    "lng": "-95.25806"
  },
  {
    "country": "MX",
    "name": "Estación Santa Engracia",
    "lat": "24.01528",
    "lng": "-99.20194"
  },
  {
    "country": "MX",
    "name": "Maya Balam",
    "lat": "18.93917",
    "lng": "-88.39972"
  },
  {
    "country": "MX",
    "name": "Morocoy",
    "lat": "18.60324",
    "lng": "-88.81097"
  },
  {
    "country": "MX",
    "name": "Don Samuel",
    "lat": "18.36",
    "lng": "-90.85722"
  },
  {
    "country": "MX",
    "name": "Xbacab",
    "lat": "18.94139",
    "lng": "-90.72194"
  },
  {
    "country": "MX",
    "name": "Aurelio Manrique",
    "lat": "22.2875",
    "lng": "-98.65083"
  },
  {
    "country": "MX",
    "name": "Ponciano Arriaga",
    "lat": "22.26222",
    "lng": "-98.58972"
  },
  {
    "country": "MX",
    "name": "Guayalejo",
    "lat": "22.38306",
    "lng": "-98.48306"
  },
  {
    "country": "MX",
    "name": "Plan de Ayala",
    "lat": "22.54028",
    "lng": "-98.76722"
  },
  {
    "country": "MX",
    "name": "Estación Tamuín",
    "lat": "22.0775",
    "lng": "-98.81111"
  },
  {
    "country": "MX",
    "name": "San José",
    "lat": "21.06917",
    "lng": "-98.59444"
  },
  {
    "country": "MX",
    "name": "Machetla",
    "lat": "21.05946",
    "lng": "-98.49445"
  },
  {
    "country": "MX",
    "name": "Chililico",
    "lat": "21.13444",
    "lng": "-98.43556"
  },
  {
    "country": "MX",
    "name": "Ricardo Flores Magón",
    "lat": "20.51444",
    "lng": "-97.495"
  },
  {
    "country": "MX",
    "name": "Rancho Nuevo",
    "lat": "20.6725",
    "lng": "-97.20611"
  },
  {
    "country": "MX",
    "name": "San Lorenzo",
    "lat": "20.35054",
    "lng": "-97.9363"
  },
  {
    "country": "MX",
    "name": "San Antonio Ocopetlatlán",
    "lat": "20.24703",
    "lng": "-97.94621"
  },
  {
    "country": "MX",
    "name": "Ahuaxintitla",
    "lat": "20.25325",
    "lng": "-97.89561"
  },
  {
    "country": "MX",
    "name": "El Chote",
    "lat": "20.40167",
    "lng": "-97.34389"
  },
  {
    "country": "MX",
    "name": "La Unión Paso Largo",
    "lat": "20.14224",
    "lng": "-96.99995"
  },
  {
    "country": "MX",
    "name": "Las Sabinas",
    "lat": "21.31806",
    "lng": "-97.88083"
  },
  {
    "country": "MX",
    "name": "El Lindero",
    "lat": "21.31278",
    "lng": "-98.22"
  },
  {
    "country": "MX",
    "name": "La Unión",
    "lat": "20.89222",
    "lng": "-97.66528"
  },
  {
    "country": "MX",
    "name": "La Palma",
    "lat": "28.05028",
    "lng": "-110.70111"
  },
  {
    "country": "MX",
    "name": "Estación Zamora",
    "lat": "29.26116",
    "lng": "-110.88653"
  },
  {
    "country": "MX",
    "name": "Carbo",
    "lat": "29.68306",
    "lng": "-110.95619"
  },
  {
    "country": "MX",
    "name": "Bacobampo",
    "lat": "26.98278",
    "lng": "-109.65194"
  },
  {
    "country": "MX",
    "name": "Hacienda Santa Fe",
    "lat": "20.51806",
    "lng": "-103.38056"
  },
  {
    "country": "MX",
    "name": "Fuentes del Valle",
    "lat": "19.6325",
    "lng": "-99.13861"
  },
  {
    "country": "MX",
    "name": "San Salvador Tizatlalli",
    "lat": "19.26028",
    "lng": "-99.59083"
  },
  {
    "country": "MX",
    "name": "Jardines de la Silla (Jardines)",
    "lat": "25.62944",
    "lng": "-100.18778"
  },
  {
    "country": "MX",
    "name": "San Buenaventura",
    "lat": "19.3025",
    "lng": "-98.86306"
  },
  {
    "country": "MX",
    "name": "Colonia Santa Teresa",
    "lat": "19.845",
    "lng": "-99.23333"
  },
  {
    "country": "MX",
    "name": "San Jerónimo Cuatro Vientos",
    "lat": "19.29306",
    "lng": "-98.84167"
  },
  {
    "country": "MX",
    "name": "San Martín Azcatepec",
    "lat": "19.68667",
    "lng": "-98.97278"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Real Palmas",
    "lat": "25.90417",
    "lng": "-100.15972"
  },
  {
    "country": "MX",
    "name": "Pórticos de San Antonio",
    "lat": "32.4425",
    "lng": "-117.03417"
  },
  {
    "country": "MX",
    "name": "San Isidro",
    "lat": "19.33972",
    "lng": "-98.95056"
  },
  {
    "country": "MX",
    "name": "Centro Familiar la Soledad",
    "lat": "21.135",
    "lng": "-101.74972"
  },
  {
    "country": "MX",
    "name": "San José Guadalupe Otzacatipan",
    "lat": "19.34472",
    "lng": "-99.59194"
  },
  {
    "country": "MX",
    "name": "Las Pintitas",
    "lat": "20.56444",
    "lng": "-103.30222"
  },
  {
    "country": "MX",
    "name": "Emiliano Zapata",
    "lat": "19.34361",
    "lng": "-98.97472"
  },
  {
    "country": "MX",
    "name": "San Antonio Tecómitl",
    "lat": "19.21778",
    "lng": "-98.98806"
  },
  {
    "country": "MX",
    "name": "Licenciado Benito Juárez (Campo Gobierno)",
    "lat": "24.65667",
    "lng": "-107.545"
  },
  {
    "country": "MX",
    "name": "Teotihuacán de Arista",
    "lat": "19.68972",
    "lng": "-98.86083"
  },
  {
    "country": "MX",
    "name": "Jesús del Monte",
    "lat": "19.375",
    "lng": "-99.29444"
  },
  {
    "country": "MX",
    "name": "San Jorge Pueblo Nuevo",
    "lat": "19.25417",
    "lng": "-99.62778"
  },
  {
    "country": "MX",
    "name": "Manuel Ojinaga",
    "lat": "29.56444",
    "lng": "-104.41639"
  },
  {
    "country": "MX",
    "name": "Terrazas del Valle",
    "lat": "32.4875",
    "lng": "-116.82667"
  },
  {
    "country": "MX",
    "name": "La Ermita",
    "lat": "21.15194",
    "lng": "-101.73306"
  },
  {
    "country": "MX",
    "name": "Lomas del Sur",
    "lat": "20.4925",
    "lng": "-103.4175"
  },
  {
    "country": "MX",
    "name": "Parque Industrial Ciudad Mitras",
    "lat": "25.78861",
    "lng": "-100.44778"
  },
  {
    "country": "MX",
    "name": "Mitras Poniente",
    "lat": "25.77583",
    "lng": "-100.42583"
  },
  {
    "country": "MX",
    "name": "Villa del Prado 2da Sección",
    "lat": "32.42389",
    "lng": "-116.97167"
  },
  {
    "country": "MX",
    "name": "Tres de Mayo",
    "lat": "18.86861",
    "lng": "-99.20833"
  },
  {
    "country": "MX",
    "name": "Don Antonio",
    "lat": "19.87444",
    "lng": "-98.93472"
  },
  {
    "country": "MX",
    "name": "Casa Blanca",
    "lat": "19.04222",
    "lng": "-98.11889"
  },
  {
    "country": "MX",
    "name": "La Providencia Siglo XXI",
    "lat": "20.06417",
    "lng": "-98.71722"
  },
  {
    "country": "MX",
    "name": "Ampliación San Mateo (Colonia Solidaridad)",
    "lat": "19.61639",
    "lng": "-99.14722"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Ciudad Olmeca",
    "lat": "18.15056",
    "lng": "-94.5525"
  },
  {
    "country": "MX",
    "name": "San Rafael Tlanalapan",
    "lat": "19.29167",
    "lng": "-98.46806"
  },
  {
    "country": "MX",
    "name": "Tecámac de Felipe Villanueva",
    "lat": "19.71306",
    "lng": "-98.96833"
  },
  {
    "country": "MX",
    "name": "Venceremos",
    "lat": "20.55083",
    "lng": "-100.39806"
  },
  {
    "country": "MX",
    "name": "Alborada Jaltenco",
    "lat": "19.66194",
    "lng": "-99.06889"
  },
  {
    "country": "MX",
    "name": "Crucecita",
    "lat": "15.76889",
    "lng": "-96.135"
  },
  {
    "country": "MX",
    "name": "Progreso",
    "lat": "18.88008",
    "lng": "-99.1526"
  },
  {
    "country": "MX",
    "name": "Palmira",
    "lat": "18.88278",
    "lng": "-97.11139"
  },
  {
    "country": "MX",
    "name": "Real del Valle (El Paraíso) [Fraccionamiento]",
    "lat": "20.54556",
    "lng": "-103.36972"
  },
  {
    "country": "MX",
    "name": "Villa del Campo",
    "lat": "32.5075",
    "lng": "-116.73833"
  },
  {
    "country": "MX",
    "name": "Vicente Guerrero",
    "lat": "16.93306",
    "lng": "-96.70139"
  },
  {
    "country": "MX",
    "name": "Morelos",
    "lat": "19.64889",
    "lng": "-101.23889"
  },
  {
    "country": "MX",
    "name": "Centro de Readaptación Social",
    "lat": "20.55444",
    "lng": "-103.19361"
  },
  {
    "country": "MX",
    "name": "Veintidós de Febrero",
    "lat": "19.61139",
    "lng": "-99.34667"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Geovillas los Pinos",
    "lat": "19.21722",
    "lng": "-96.22639"
  },
  {
    "country": "MX",
    "name": "Juan Morales",
    "lat": "18.81139",
    "lng": "-98.92194"
  },
  {
    "country": "MX",
    "name": "Santa María Zacatepec",
    "lat": "19.12333",
    "lng": "-98.36528"
  },
  {
    "country": "MX",
    "name": "La Tijera",
    "lat": "20.58167",
    "lng": "-103.44056"
  },
  {
    "country": "MX",
    "name": "Lomas de San Agustín",
    "lat": "20.5275",
    "lng": "-103.46778"
  },
  {
    "country": "MX",
    "name": "Córdoba (Santa Leticia)",
    "lat": "18.90861",
    "lng": "-96.97889"
  },
  {
    "country": "MX",
    "name": "Las Palmas",
    "lat": "22.93672",
    "lng": "-109.94235"
  },
  {
    "country": "MX",
    "name": "San Francisco Tecoxpa",
    "lat": "19.19167",
    "lng": "-99.00639"
  },
  {
    "country": "MX",
    "name": "Villas de la Hacienda [Fraccionamiento]",
    "lat": "20.53111",
    "lng": "-103.38278"
  },
  {
    "country": "MX",
    "name": "Conjunto Habitacional Villas del Pedregal",
    "lat": "19.68361",
    "lng": "-101.30361"
  },
  {
    "country": "MX",
    "name": "Pomoca",
    "lat": "18.04972",
    "lng": "-92.93056"
  },
  {
    "country": "MX",
    "name": "Puerto Escondido (Tepeolulco Puerto Escondido)",
    "lat": "19.55194",
    "lng": "-99.09806"
  },
  {
    "country": "MX",
    "name": "Unidad Habitacional José María Morelos y Pavón",
    "lat": "18.82028",
    "lng": "-99.26222"
  },
  {
    "country": "MX",
    "name": "Nueva Palestina",
    "lat": "16.81722",
    "lng": "-91.26"
  },
  {
    "country": "MX",
    "name": "Las Veredas",
    "lat": "23.15028",
    "lng": "-109.70611"
  },
  {
    "country": "MX",
    "name": "Profesor Carlos Hank González",
    "lat": "19.37222",
    "lng": "-98.93889"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento la Trinidad",
    "lat": "19.82917",
    "lng": "-99.08278"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Amilpas",
    "lat": "17.05833",
    "lng": "-96.68333"
  },
  {
    "country": "MX",
    "name": "Paseos de San Juan",
    "lat": "19.78194",
    "lng": "-99.0175"
  },
  {
    "country": "MX",
    "name": "Valle Dorado Inn",
    "lat": "20.52444",
    "lng": "-103.36194"
  },
  {
    "country": "MX",
    "name": "Buenos Aires",
    "lat": "18.02444",
    "lng": "-102.28583"
  },
  {
    "country": "MX",
    "name": "General Ángel Flores (La Palma)",
    "lat": "24.81917",
    "lng": "-107.65667"
  },
  {
    "country": "MX",
    "name": "Brisas de Zicatela",
    "lat": "15.83694",
    "lng": "-97.04194"
  },
  {
    "country": "MX",
    "name": "San Antonio del Coyote",
    "lat": "25.69444",
    "lng": "-103.28556"
  },
  {
    "country": "MX",
    "name": "Jorge Jiménez Cantú",
    "lat": "19.30972",
    "lng": "-98.84667"
  },
  {
    "country": "MX",
    "name": "Galaxia Bonito Jalisco",
    "lat": "20.505",
    "lng": "-103.20472"
  },
  {
    "country": "MX",
    "name": "Antúnez (Morelos)",
    "lat": "19.01278",
    "lng": "-102.20389"
  },
  {
    "country": "MX",
    "name": "La Alameda",
    "lat": "20.49528",
    "lng": "-103.24833"
  },
  {
    "country": "MX",
    "name": "El Niño",
    "lat": "32.5075",
    "lng": "-116.79194"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Lomas de Ahuatlán",
    "lat": "18.95444",
    "lng": "-99.25722"
  },
  {
    "country": "MX",
    "name": "Lomas de Barrillas",
    "lat": "18.14806",
    "lng": "-94.52639"
  },
  {
    "country": "MX",
    "name": "Marte R. Gómez (Tobarito)",
    "lat": "27.36778",
    "lng": "-109.88583"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Misión del Valle",
    "lat": "19.76556",
    "lng": "-101.12167"
  },
  {
    "country": "MX",
    "name": "Colonia Santa Bárbara",
    "lat": "19.50191",
    "lng": "-96.87817"
  },
  {
    "country": "MX",
    "name": "Bosque de Saloya",
    "lat": "18.01611",
    "lng": "-92.95806"
  },
  {
    "country": "MX",
    "name": "San Lucas el Grande",
    "lat": "19.30583",
    "lng": "-98.47833"
  },
  {
    "country": "MX",
    "name": "San Andrés Azumiatla",
    "lat": "18.90417",
    "lng": "-98.25278"
  },
  {
    "country": "MX",
    "name": "Rancho Alegre [Fraccionamiento]",
    "lat": "20.47361",
    "lng": "-103.25778"
  },
  {
    "country": "MX",
    "name": "Ex-Rancho San Dimas",
    "lat": "19.17389",
    "lng": "-99.56528"
  },
  {
    "country": "MX",
    "name": "Jacarandas",
    "lat": "19.49556",
    "lng": "-96.85278"
  },
  {
    "country": "MX",
    "name": "El Pino",
    "lat": "19.35139",
    "lng": "-98.94833"
  },
  {
    "country": "MX",
    "name": "Unión y Progreso",
    "lat": "18.87278",
    "lng": "-97.11917"
  },
  {
    "country": "MX",
    "name": "Misión San Pablo",
    "lat": "25.74",
    "lng": "-100.14417"
  },
  {
    "country": "MX",
    "name": "Tenextepango",
    "lat": "18.72889",
    "lng": "-98.95778"
  },
  {
    "country": "MX",
    "name": "Ejido San Lorenzo Cuauhtenco",
    "lat": "19.30139",
    "lng": "-99.75028"
  },
  {
    "country": "MX",
    "name": "Santa Catarina Ayometla",
    "lat": "19.19833",
    "lng": "-98.21361"
  },
  {
    "country": "MX",
    "name": "Cuichapa",
    "lat": "17.93889",
    "lng": "-94.28"
  },
  {
    "country": "MX",
    "name": "La Selva",
    "lat": "18.02333",
    "lng": "-92.96306"
  },
  {
    "country": "MX",
    "name": "Los Olivos",
    "lat": "20.43917",
    "lng": "-103.23778"
  },
  {
    "country": "MX",
    "name": "Villa Luvianos",
    "lat": "18.92",
    "lng": "-100.29833"
  },
  {
    "country": "MX",
    "name": "Los Ruiseñores",
    "lat": "20.71083",
    "lng": "-103.69139"
  },
  {
    "country": "MX",
    "name": "Barrio de México",
    "lat": "19.2825",
    "lng": "-99.82833"
  },
  {
    "country": "MX",
    "name": "Tenango de las Flores",
    "lat": "20.20583",
    "lng": "-97.98806"
  },
  {
    "country": "MX",
    "name": "Independencia",
    "lat": "18.87716",
    "lng": "-99.12237"
  },
  {
    "country": "MX",
    "name": "Maclovio Rojas",
    "lat": "32.47306",
    "lng": "-116.80278"
  },
  {
    "country": "MX",
    "name": "San Sebastián del Sur",
    "lat": "19.79444",
    "lng": "-103.47306"
  },
  {
    "country": "MX",
    "name": "Chiconcuac",
    "lat": "18.78278",
    "lng": "-99.20722"
  },
  {
    "country": "MX",
    "name": "Chanal",
    "lat": "16.6575",
    "lng": "-92.2575"
  },
  {
    "country": "MX",
    "name": "El Súchil",
    "lat": "17.22694",
    "lng": "-100.63917"
  },
  {
    "country": "MX",
    "name": "El Campanario y Oradel",
    "lat": "27.47306",
    "lng": "-99.62"
  },
  {
    "country": "MX",
    "name": "El Diez",
    "lat": "24.72389",
    "lng": "-107.45194"
  },
  {
    "country": "MX",
    "name": "Villa Alberto Andrés Alvarado Arámburo",
    "lat": "27.64444",
    "lng": "-113.38472"
  },
  {
    "country": "MX",
    "name": "San Antonio Mihuacán",
    "lat": "19.15333",
    "lng": "-98.30472"
  },
  {
    "country": "MX",
    "name": "Raudales Malpaso",
    "lat": "17.18833",
    "lng": "-93.60583"
  },
  {
    "country": "MX",
    "name": "San Nicolás Tolentino",
    "lat": "19.35889",
    "lng": "-99.57167"
  },
  {
    "country": "MX",
    "name": "Santa Cruz del Monte",
    "lat": "19.76702",
    "lng": "-99.22867"
  },
  {
    "country": "MX",
    "name": "Arenal",
    "lat": "19.38111",
    "lng": "-98.94278"
  },
  {
    "country": "MX",
    "name": "San Sebastián de Aparicio",
    "lat": "19.10333",
    "lng": "-98.16083"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Colinas del Sol",
    "lat": "19.37222",
    "lng": "-99.74028"
  },
  {
    "country": "MX",
    "name": "La Pradera",
    "lat": "20.65889",
    "lng": "-100.34222"
  },
  {
    "country": "MX",
    "name": "Lomas de Santa Anita",
    "lat": "32.54278",
    "lng": "-116.65139"
  },
  {
    "country": "MX",
    "name": "Benito García (El Zorrillo)",
    "lat": "31.67111",
    "lng": "-116.51139"
  },
  {
    "country": "MX",
    "name": "Lomas Verdes",
    "lat": "19.50446",
    "lng": "-96.88899"
  },
  {
    "country": "MX",
    "name": "Vida Mejor I",
    "lat": "14.86972",
    "lng": "-92.30778"
  },
  {
    "country": "MX",
    "name": "La Constitución Toltepec",
    "lat": "19.34861",
    "lng": "-99.54917"
  },
  {
    "country": "MX",
    "name": "Kilómetro 30",
    "lat": "16.99778",
    "lng": "-99.78"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento los Ángeles",
    "lat": "23.18833",
    "lng": "-106.33"
  },
  {
    "country": "MX",
    "name": "Rincón de Nicolás Romero (Cedros Tercera Manzana)",
    "lat": "19.41361",
    "lng": "-100.2975"
  },
  {
    "country": "MX",
    "name": "Campestre Villas del Álamo",
    "lat": "20.10167",
    "lng": "-98.70722"
  },
  {
    "country": "MX",
    "name": "Conjunto Urbano la Loma I",
    "lat": "19.32639",
    "lng": "-99.73194"
  },
  {
    "country": "MX",
    "name": "Javier Rojo Gómez",
    "lat": "20.06972",
    "lng": "-98.41778"
  },
  {
    "country": "MX",
    "name": "Emiliano Zapata",
    "lat": "25.91028",
    "lng": "-100.28056"
  },
  {
    "country": "MX",
    "name": "Parque Urbano Napateco",
    "lat": "20.14278",
    "lng": "-98.34083"
  },
  {
    "country": "MX",
    "name": "La Aldea",
    "lat": "19.74306",
    "lng": "-101.135"
  },
  {
    "country": "MX",
    "name": "Guadalupe Victoria",
    "lat": "19.55472",
    "lng": "-96.96056"
  },
  {
    "country": "MX",
    "name": "El Cóporo",
    "lat": "19.28306",
    "lng": "-99.83528"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Arboledas San Ramón",
    "lat": "19.09417",
    "lng": "-96.15667"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Galaxia Tarímbaro",
    "lat": "19.76167",
    "lng": "-101.19444"
  },
  {
    "country": "MX",
    "name": "Real del Sol",
    "lat": "25.93833",
    "lng": "-100.18111"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Metrópolis II",
    "lat": "19.75639",
    "lng": "-101.20444"
  },
  {
    "country": "MX",
    "name": "Ciudad de Cuetzalan",
    "lat": "20.01861",
    "lng": "-97.52111"
  },
  {
    "country": "MX",
    "name": "Colinas del Roble",
    "lat": "20.50417",
    "lng": "-103.39833"
  },
  {
    "country": "MX",
    "name": "Granjas Ampliación Santa Rosa",
    "lat": "19.59278",
    "lng": "-98.96667"
  },
  {
    "country": "MX",
    "name": "Héctor Caballero",
    "lat": "25.63556",
    "lng": "-100.12667"
  },
  {
    "country": "MX",
    "name": "Quinto Barrio (Ejido Cahuacán)",
    "lat": "19.62222",
    "lng": "-99.41806"
  },
  {
    "country": "MX",
    "name": "Valle de Lincoln",
    "lat": "25.79333",
    "lng": "-100.47778"
  },
  {
    "country": "MX",
    "name": "Emiliano Zapata",
    "lat": "30.75417",
    "lng": "-116.00306"
  },
  {
    "country": "MX",
    "name": "Quinta del Cedro",
    "lat": "32.4375",
    "lng": "-117.06583"
  },
  {
    "country": "MX",
    "name": "Lomas de Altavista",
    "lat": "19.36139",
    "lng": "-98.94472"
  },
  {
    "country": "MX",
    "name": "Unidad Minera 11 de Julio",
    "lat": "20.10472",
    "lng": "-98.72278"
  },
  {
    "country": "MX",
    "name": "Galaxia la Noria",
    "lat": "20.45722",
    "lng": "-103.41889"
  },
  {
    "country": "MX",
    "name": "Monte Kristal",
    "lat": "25.62611",
    "lng": "-100.15694"
  },
  {
    "country": "MX",
    "name": "La Lima",
    "lat": "17.91056",
    "lng": "-92.93389"
  },
  {
    "country": "MX",
    "name": "Loma la Paz",
    "lat": "25.71111",
    "lng": "-100.13472"
  },
  {
    "country": "MX",
    "name": "Ciudad Coahuila (Kilómetro Cincuenta y Siete)",
    "lat": "32.19556",
    "lng": "-115.0025"
  },
  {
    "country": "MX",
    "name": "Pedro Amaro",
    "lat": "18.59639",
    "lng": "-99.17306"
  },
  {
    "country": "MX",
    "name": "Adolfo López Mateos (El Tamarindo)",
    "lat": "24.89639",
    "lng": "-107.63278"
  },
  {
    "country": "MX",
    "name": "Los Arcos",
    "lat": "18.88722",
    "lng": "-99.02417"
  },
  {
    "country": "MX",
    "name": "Villas de Alcalá",
    "lat": "25.91528",
    "lng": "-100.18528"
  },
  {
    "country": "MX",
    "name": "Calera Chica",
    "lat": "18.85833",
    "lng": "-99.18194"
  },
  {
    "country": "MX",
    "name": "El Rincón Citlaltépetl",
    "lat": "19.15556",
    "lng": "-97.89444"
  },
  {
    "country": "MX",
    "name": "San Francisco de Asís",
    "lat": "20.59694",
    "lng": "-102.56361"
  },
  {
    "country": "MX",
    "name": "Jicaltepec Autopan",
    "lat": "19.37167",
    "lng": "-99.64083"
  },
  {
    "country": "MX",
    "name": "Villas de Irapuato",
    "lat": "20.68722",
    "lng": "-101.40528"
  },
  {
    "country": "MX",
    "name": "Arbolada los Sauces",
    "lat": "19.81583",
    "lng": "-99.04417"
  },
  {
    "country": "MX",
    "name": "Atoluca",
    "lat": "19.855",
    "lng": "-97.35361"
  },
  {
    "country": "MX",
    "name": "Frontera Corozal",
    "lat": "16.82111",
    "lng": "-90.89028"
  },
  {
    "country": "MX",
    "name": "Pocitos",
    "lat": "21.92167",
    "lng": "-102.33472"
  },
  {
    "country": "MX",
    "name": "Anacleto Canabal 2da. Sección",
    "lat": "17.97556",
    "lng": "-93.02417"
  },
  {
    "country": "MX",
    "name": "La Pastoría",
    "lat": "19.54306",
    "lng": "-98.91111"
  },
  {
    "country": "MX",
    "name": "Los Tuzos",
    "lat": "20.05389",
    "lng": "-98.75639"
  },
  {
    "country": "MX",
    "name": "Ex-Hacienda Santa Inés",
    "lat": "19.70667",
    "lng": "-99.0725"
  },
  {
    "country": "MX",
    "name": "San Lorenzo Axocomanitla",
    "lat": "19.22389",
    "lng": "-98.24861"
  },
  {
    "country": "MX",
    "name": "Nueva Santa Rosa",
    "lat": "19.59028",
    "lng": "-98.96"
  },
  {
    "country": "MX",
    "name": "Las Torres",
    "lat": "25.95167",
    "lng": "-100.31806"
  },
  {
    "country": "MX",
    "name": "Colonia Venustiano Carranza",
    "lat": "28.63861",
    "lng": "-100.55667"
  },
  {
    "country": "MX",
    "name": "San José el Cuartel",
    "lat": "18.95972",
    "lng": "-99.57722"
  },
  {
    "country": "MX",
    "name": "Colinas de Plata",
    "lat": "20.07833",
    "lng": "-98.72667"
  },
  {
    "country": "MX",
    "name": "Palomar",
    "lat": "20.5925",
    "lng": "-103.46056"
  },
  {
    "country": "MX",
    "name": "Unidad Acaquilpan",
    "lat": "19.36694",
    "lng": "-98.93917"
  },
  {
    "country": "MX",
    "name": "Paseo del Prado",
    "lat": "20.56444",
    "lng": "-103.38917"
  },
  {
    "country": "MX",
    "name": "El Centenario",
    "lat": "24.1025",
    "lng": "-110.41444"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Ocuiltzapotlán Dos",
    "lat": "18.10889",
    "lng": "-92.86778"
  },
  {
    "country": "MX",
    "name": "Los Torrentes",
    "lat": "19.20194",
    "lng": "-96.21139"
  },
  {
    "country": "MX",
    "name": "Santa Justina Ecatepec",
    "lat": "19.31083",
    "lng": "-98.355"
  },
  {
    "country": "MX",
    "name": "Aquiles Serdán (San Fernando)",
    "lat": "17.80556",
    "lng": "-92.48972"
  },
  {
    "country": "MX",
    "name": "Tungareo",
    "lat": "19.90833",
    "lng": "-100.36639"
  },
  {
    "country": "MX",
    "name": "Villa Magna",
    "lat": "19.68361",
    "lng": "-101.32667"
  },
  {
    "country": "MX",
    "name": "Tianguistengo (La Romera)",
    "lat": "19.91417",
    "lng": "-99.32583"
  },
  {
    "country": "MX",
    "name": "San Felipe",
    "lat": "25.69278",
    "lng": "-103.3825"
  },
  {
    "country": "MX",
    "name": "Hacienda los Fresnos",
    "lat": "20.51944",
    "lng": "-103.39306"
  },
  {
    "country": "MX",
    "name": "El Pedregal de Guadalupe Hidalgo",
    "lat": "19.25278",
    "lng": "-99.465"
  },
  {
    "country": "MX",
    "name": "Campestre las Palomas [Fraccionamiento]",
    "lat": "20.81778",
    "lng": "-103.45167"
  },
  {
    "country": "MX",
    "name": "Villa Licenciado Jesús Terán (Calvillito)",
    "lat": "21.82528",
    "lng": "-102.18778"
  },
  {
    "country": "MX",
    "name": "Tenango",
    "lat": "16.90472",
    "lng": "-92.26139"
  },
  {
    "country": "MX",
    "name": "Panuaya",
    "lat": "20.195",
    "lng": "-99.27083"
  },
  {
    "country": "MX",
    "name": "Lo de Juárez",
    "lat": "20.76833",
    "lng": "-101.34111"
  },
  {
    "country": "MX",
    "name": "Santiago Etla",
    "lat": "17.1525",
    "lng": "-96.78972"
  },
  {
    "country": "MX",
    "name": "San Bernabé Temoxtitla",
    "lat": "18.99722",
    "lng": "-98.33083"
  },
  {
    "country": "MX",
    "name": "Villas de la Loma",
    "lat": "19.69",
    "lng": "-101.29944"
  },
  {
    "country": "MX",
    "name": "Molino Abajo",
    "lat": "19.44972",
    "lng": "-99.60222"
  },
  {
    "country": "MX",
    "name": "Jicaltepec Cuexcontitlán",
    "lat": "19.37306",
    "lng": "-99.6275"
  },
  {
    "country": "MX",
    "name": "General Lázaro Cárdenas (El Colorado)",
    "lat": "20.56389",
    "lng": "-100.24389"
  },
  {
    "country": "MX",
    "name": "Tatoxcac",
    "lat": "19.86944",
    "lng": "-97.57306"
  },
  {
    "country": "MX",
    "name": "Cereso del Hongo",
    "lat": "32.48417",
    "lng": "-116.25056"
  },
  {
    "country": "MX",
    "name": "Villa Jiménez",
    "lat": "19.92306",
    "lng": "-101.74694"
  },
  {
    "country": "MX",
    "name": "Tacopan",
    "lat": "19.8375",
    "lng": "-97.43111"
  },
  {
    "country": "MX",
    "name": "Santa María de Guadalupe",
    "lat": "19.82111",
    "lng": "-99.12778"
  },
  {
    "country": "MX",
    "name": "Santa María la Asunción",
    "lat": "19.2675",
    "lng": "-99.5525"
  },
  {
    "country": "MX",
    "name": "2da. Sección de Medio Monte",
    "lat": "14.88194",
    "lng": "-92.18444"
  },
  {
    "country": "MX",
    "name": "San Francisco Tepeyecac",
    "lat": "19.24861",
    "lng": "-98.43833"
  },
  {
    "country": "MX",
    "name": "Axotlán",
    "lat": "19.69417",
    "lng": "-99.23944"
  },
  {
    "country": "MX",
    "name": "La Galarza",
    "lat": "18.66778",
    "lng": "-98.45528"
  },
  {
    "country": "MX",
    "name": "San Buenaventura Tecaltzingo",
    "lat": "19.24778",
    "lng": "-98.46056"
  },
  {
    "country": "MX",
    "name": "Campestre Flamboyanes",
    "lat": "21.21",
    "lng": "-89.65778"
  },
  {
    "country": "MX",
    "name": "Villas de la Laguna",
    "lat": "19.83611",
    "lng": "-99.09"
  },
  {
    "country": "MX",
    "name": "Alianza Real",
    "lat": "25.85139",
    "lng": "-100.38278"
  },
  {
    "country": "MX",
    "name": "Colonia Revolución",
    "lat": "28.24167",
    "lng": "-105.44361"
  },
  {
    "country": "MX",
    "name": "Loma Larga",
    "lat": "19.6275",
    "lng": "-99.34611"
  },
  {
    "country": "MX",
    "name": "Nejapa",
    "lat": "17.61389",
    "lng": "-99.145"
  },
  {
    "country": "MX",
    "name": "La Trinidad Chautenco",
    "lat": "19.09",
    "lng": "-98.26389"
  },
  {
    "country": "MX",
    "name": "Real Hacienda (Metrópolis)",
    "lat": "19.75056",
    "lng": "-101.19694"
  },
  {
    "country": "MX",
    "name": "C-32 (Licenciado Francisco Trujillo Gurría)",
    "lat": "17.96833",
    "lng": "-93.50139"
  },
  {
    "country": "MX",
    "name": "Hércules",
    "lat": "28.04306",
    "lng": "-103.79111"
  },
  {
    "country": "MX",
    "name": "Santa Cruz",
    "lat": "20.71361",
    "lng": "-100.30361"
  },
  {
    "country": "MX",
    "name": "Delfino Victoria (Santa Fe)",
    "lat": "19.2075",
    "lng": "-96.27333"
  },
  {
    "country": "MX",
    "name": "San Antonio",
    "lat": "19.66722",
    "lng": "-101.26806"
  },
  {
    "country": "MX",
    "name": "San Pedro Zacachimalpa",
    "lat": "18.94278",
    "lng": "-98.15611"
  },
  {
    "country": "MX",
    "name": "Ichán",
    "lat": "19.85806",
    "lng": "-102.05417"
  },
  {
    "country": "MX",
    "name": "Peña Flores (Palo Verde)",
    "lat": "18.86722",
    "lng": "-98.96833"
  },
  {
    "country": "MX",
    "name": "La Trinidad",
    "lat": "18.96639",
    "lng": "-99.58083"
  },
  {
    "country": "MX",
    "name": "Puerto Esmeralda",
    "lat": "18.14778",
    "lng": "-94.51778"
  },
  {
    "country": "MX",
    "name": "Melchor Ocampo",
    "lat": "18.03694",
    "lng": "-93.3625"
  },
  {
    "country": "MX",
    "name": "La Providencia",
    "lat": "19.75833",
    "lng": "-99.14667"
  },
  {
    "country": "MX",
    "name": "Colonia Lomas de San Ramón (Triquis)",
    "lat": "30.70167",
    "lng": "-116.00278"
  },
  {
    "country": "MX",
    "name": "La Joya",
    "lat": "19.27639",
    "lng": "-99.75889"
  },
  {
    "country": "MX",
    "name": "San Bartolomé Aguas Calientes",
    "lat": "20.49556",
    "lng": "-100.54833"
  },
  {
    "country": "MX",
    "name": "General Felipe Ángeles (Los Ángeles)",
    "lat": "19.8975",
    "lng": "-98.92611"
  },
  {
    "country": "MX",
    "name": "Colinas del Aeropuerto",
    "lat": "25.81705",
    "lng": "-100.10258"
  },
  {
    "country": "MX",
    "name": "San Bartolomé Cuahuixmatlac",
    "lat": "19.29333",
    "lng": "-98.14806"
  },
  {
    "country": "MX",
    "name": "Vistas del Maguey [Fraccionamiento]",
    "lat": "20.52806",
    "lng": "-102.52333"
  },
  {
    "country": "MX",
    "name": "Barrio Santa Cruz",
    "lat": "19.35139",
    "lng": "-99.66278"
  },
  {
    "country": "MX",
    "name": "Santa María Texmelucan",
    "lat": "19.29417",
    "lng": "-98.53778"
  },
  {
    "country": "MX",
    "name": "El Saucillo (Fraccionamiento)",
    "lat": "20.06778",
    "lng": "-98.73194"
  },
  {
    "country": "MX",
    "name": "Santiago Chimalpa (Chimalpa)",
    "lat": "19.56917",
    "lng": "-98.89167"
  },
  {
    "country": "MX",
    "name": "San Esteban (San Miguel Tateposco)",
    "lat": "20.79889",
    "lng": "-103.37444"
  },
  {
    "country": "MX",
    "name": "Plutarco Elías Calles (La Y Griega)",
    "lat": "30.80194",
    "lng": "-112.71833"
  },
  {
    "country": "MX",
    "name": "Yoshib",
    "lat": "16.84528",
    "lng": "-92.44611"
  },
  {
    "country": "MX",
    "name": "Hacienda San Pedro",
    "lat": "25.91472",
    "lng": "-100.16278"
  },
  {
    "country": "MX",
    "name": "Forjadores de Pachuca",
    "lat": "20.055",
    "lng": "-98.76333"
  },
  {
    "country": "MX",
    "name": "Unidad Habitacional José María Morelos y Pavón",
    "lat": "18.62137",
    "lng": "-99.22178"
  },
  {
    "country": "MX",
    "name": "San Miguel Jaltocan",
    "lat": "19.72306",
    "lng": "-99.05028"
  },
  {
    "country": "MX",
    "name": "C-41 (Licenciado Carlos A. Madrazo)",
    "lat": "17.92306",
    "lng": "-93.44806"
  },
  {
    "country": "MX",
    "name": "Santiago Puriatzícuaro",
    "lat": "19.88306",
    "lng": "-100.58861"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Costa Dorada",
    "lat": "19.20833",
    "lng": "-96.21639"
  },
  {
    "country": "MX",
    "name": "Colonia 2 de Septiembre",
    "lat": "19.70056",
    "lng": "-99.11667"
  },
  {
    "country": "MX",
    "name": "Toreo Bajo (El Toreo Bajo)",
    "lat": "19.44472",
    "lng": "-102.00444"
  },
  {
    "country": "MX",
    "name": "Santa Rosa (Santa Bárbara)",
    "lat": "19.38333",
    "lng": "-102.03611"
  },
  {
    "country": "MX",
    "name": "Villa URBI del Rey",
    "lat": "19.84132",
    "lng": "-99.25719"
  },
  {
    "country": "MX",
    "name": "Chalchocoyo",
    "lat": "21.31444",
    "lng": "-98.79194"
  },
  {
    "country": "MX",
    "name": "Barrio Cuarto (La Loma)",
    "lat": "19.76861",
    "lng": "-99.67694"
  },
  {
    "country": "MX",
    "name": "Cristeros [Fraccionamiento]",
    "lat": "21.32111",
    "lng": "-101.97333"
  },
  {
    "country": "MX",
    "name": "Zacango",
    "lat": "18.95611",
    "lng": "-99.69806"
  },
  {
    "country": "MX",
    "name": "San Nicolás Zoyapetlayoca",
    "lat": "18.92417",
    "lng": "-97.86528"
  },
  {
    "country": "MX",
    "name": "Colonia el Salado",
    "lat": "19.58389",
    "lng": "-98.99139"
  },
  {
    "country": "MX",
    "name": "Sosa",
    "lat": "19.80111",
    "lng": "-97.39611"
  },
  {
    "country": "MX",
    "name": "San Antonio Portezuelo",
    "lat": "18.99889",
    "lng": "-97.71361"
  },
  {
    "country": "MX",
    "name": "Jardines de San Sebastián",
    "lat": "20.51889",
    "lng": "-103.42222"
  },
  {
    "country": "MX",
    "name": "Ex-Viñedos Guadalupe",
    "lat": "21.95944",
    "lng": "-102.27417"
  },
  {
    "country": "MX",
    "name": "Chipilo de Francisco Javier Mina",
    "lat": "19.00611",
    "lng": "-98.33056"
  },
  {
    "country": "MX",
    "name": "Zacualpan de Amilpas",
    "lat": "18.78389",
    "lng": "-98.76583"
  },
  {
    "country": "MX",
    "name": "San Francisco Ayotuzco",
    "lat": "19.36583",
    "lng": "-99.35694"
  },
  {
    "country": "MX",
    "name": "Alfonso G. Calderón (Poblado Siete)",
    "lat": "26.06528",
    "lng": "-109.01972"
  },
  {
    "country": "MX",
    "name": "San Antonio Gallardo",
    "lat": "20.62833",
    "lng": "-100.76778"
  },
  {
    "country": "MX",
    "name": "PRI Chacón",
    "lat": "20.08139",
    "lng": "-98.73694"
  },
  {
    "country": "MX",
    "name": "Los Tigres (San Marcos)",
    "lat": "17.89056",
    "lng": "-95.34944"
  },
  {
    "country": "MX",
    "name": "Villa Santiago",
    "lat": "18.97972",
    "lng": "-99.18528"
  },
  {
    "country": "MX",
    "name": "San Bartolo",
    "lat": "18.09222",
    "lng": "-96.1075"
  },
  {
    "country": "MX",
    "name": "Colonia Santa Cecilia (La Sauceda)",
    "lat": "21.2525",
    "lng": "-102.35139"
  },
  {
    "country": "MX",
    "name": "Samarkanda",
    "lat": "18.04216",
    "lng": "-92.9105"
  },
  {
    "country": "MX",
    "name": "Genaro Estrada",
    "lat": "25.93611",
    "lng": "-108.39639"
  },
  {
    "country": "MX",
    "name": "Colonia Lázaro Cárdenas (Los Hornos)",
    "lat": "19.63167",
    "lng": "-99.15333"
  },
  {
    "country": "MX",
    "name": "Atzingo (La Cumbre)",
    "lat": "19.97972",
    "lng": "-97.96861"
  },
  {
    "country": "MX",
    "name": "Unidades Habitacionales",
    "lat": "20.06389",
    "lng": "-98.42056"
  },
  {
    "country": "MX",
    "name": "Colinas de Santa Cruz Segunda Sección",
    "lat": "20.62361",
    "lng": "-100.46667"
  },
  {
    "country": "MX",
    "name": "Oasis",
    "lat": "19.20167",
    "lng": "-96.21917"
  },
  {
    "country": "MX",
    "name": "Francisco Sarabia",
    "lat": "16.94583",
    "lng": "-93.01306"
  },
  {
    "country": "MX",
    "name": "Ocopulco",
    "lat": "19.58972",
    "lng": "-98.89694"
  },
  {
    "country": "MX",
    "name": "Poblado 10",
    "lat": "17.27722",
    "lng": "-94.45194"
  },
  {
    "country": "MX",
    "name": "Arboledas Paso Blanco [Fraccionamiento]",
    "lat": "21.96361",
    "lng": "-102.30194"
  },
  {
    "country": "MX",
    "name": "San Miguel Tianguistenco",
    "lat": "19.29389",
    "lng": "-98.53083"
  },
  {
    "country": "MX",
    "name": "Barrio Tlatenco",
    "lat": "19.73917",
    "lng": "-99.19167"
  },
  {
    "country": "MX",
    "name": "Amatillo",
    "lat": "16.82028",
    "lng": "-99.66611"
  },
  {
    "country": "MX",
    "name": "Colonia Gustavo Baz Prada",
    "lat": "19.42139",
    "lng": "-99.01361"
  },
  {
    "country": "MX",
    "name": "Tlamaco (San Gerónimo Tlamaco)",
    "lat": "20.03472",
    "lng": "-99.22917"
  },
  {
    "country": "MX",
    "name": "Atecucario de la Constitución (Atecuario)",
    "lat": "20.06444",
    "lng": "-102.23861"
  },
  {
    "country": "MX",
    "name": "Agrícola Lázaro Cárdenas",
    "lat": "18.81361",
    "lng": "-97.19833"
  },
  {
    "country": "MX",
    "name": "Jagüey de Téllez (Estación Téllez)",
    "lat": "19.98056",
    "lng": "-98.78833"
  },
  {
    "country": "MX",
    "name": "Nachig",
    "lat": "16.73056",
    "lng": "-92.72528"
  },
  {
    "country": "MX",
    "name": "Arroyo del Maíz Uno",
    "lat": "20.53667",
    "lng": "-97.41528"
  },
  {
    "country": "MX",
    "name": "Colonia Nueva Era",
    "lat": "30.50667",
    "lng": "-115.9225"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Valle Dorado",
    "lat": "18.86889",
    "lng": "-97.12222"
  },
  {
    "country": "MX",
    "name": "Las Colonias de Hidalgo",
    "lat": "20.19611",
    "lng": "-97.97667"
  },
  {
    "country": "MX",
    "name": "San Diego los Padres Cuexcontitlán Sección 5 B",
    "lat": "19.37611",
    "lng": "-99.61222"
  },
  {
    "country": "MX",
    "name": "Belén Atzitzimititlán",
    "lat": "19.34694",
    "lng": "-98.19"
  },
  {
    "country": "MX",
    "name": "Colonia Emiliano Zapata",
    "lat": "19.39111",
    "lng": "-99.52528"
  },
  {
    "country": "MX",
    "name": "Unidad Habitacional Rinconada Acolapa",
    "lat": "18.89722",
    "lng": "-99.13139"
  },
  {
    "country": "MX",
    "name": "El Saucito (El Horno)",
    "lat": "22.73111",
    "lng": "-102.09528"
  },
  {
    "country": "MX",
    "name": "San Isidro Vista Hermosa",
    "lat": "18.50556",
    "lng": "-97.40028"
  },
  {
    "country": "MX",
    "name": "Simeprodeso (Colectivo Nuevo)",
    "lat": "25.85306",
    "lng": "-100.29167"
  },
  {
    "country": "MX",
    "name": "Corral de Barrancos",
    "lat": "21.95028",
    "lng": "-102.33222"
  },
  {
    "country": "MX",
    "name": "San Pedro Benito Juárez",
    "lat": "18.94722",
    "lng": "-98.55139"
  },
  {
    "country": "MX",
    "name": "Juárez Coronaco",
    "lat": "19.36056",
    "lng": "-98.525"
  },
  {
    "country": "MX",
    "name": "Los Valles",
    "lat": "32.3925",
    "lng": "-116.955"
  },
  {
    "country": "MX",
    "name": "Pochahuizco",
    "lat": "17.66472",
    "lng": "-99.22278"
  },
  {
    "country": "MX",
    "name": "Corral Falso",
    "lat": "18.24472",
    "lng": "-100.56"
  },
  {
    "country": "MX",
    "name": "Santo Nombre",
    "lat": "18.67389",
    "lng": "-97.67611"
  },
  {
    "country": "MX",
    "name": "Joshil",
    "lat": "17.24667",
    "lng": "-92.36278"
  },
  {
    "country": "MX",
    "name": "Tezoquipa",
    "lat": "20.05639",
    "lng": "-99.20472"
  },
  {
    "country": "MX",
    "name": "Colonia los Cedros",
    "lat": "19.31167",
    "lng": "-99.54111"
  },
  {
    "country": "MX",
    "name": "Prados de San Juan",
    "lat": "19.63998",
    "lng": "-98.97519"
  },
  {
    "country": "MX",
    "name": "Changata",
    "lat": "18.27306",
    "lng": "-100.58528"
  },
  {
    "country": "MX",
    "name": "San Lucas Pío",
    "lat": "19.79361",
    "lng": "-100.92472"
  },
  {
    "country": "MX",
    "name": "Los Cafetales",
    "lat": "14.86745",
    "lng": "-92.302"
  },
  {
    "country": "MX",
    "name": "San Francisco",
    "lat": "19.77722",
    "lng": "-97.32806"
  },
  {
    "country": "MX",
    "name": "Arena 1ra. Sección",
    "lat": "18.20139",
    "lng": "-93.36694"
  },
  {
    "country": "MX",
    "name": "Colonia Vista Bella (Lomas del Peaje)",
    "lat": "19.49083",
    "lng": "-101.59389"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento las Fuentes",
    "lat": "19.49611",
    "lng": "-96.88639"
  },
  {
    "country": "MX",
    "name": "Nuevo San Miguel",
    "lat": "25.96306",
    "lng": "-109.05401"
  },
  {
    "country": "MX",
    "name": "Xoloateno",
    "lat": "19.83111",
    "lng": "-97.36944"
  },
  {
    "country": "MX",
    "name": "El Hielo",
    "lat": "19.42583",
    "lng": "-99.35556"
  },
  {
    "country": "MX",
    "name": "Buena Vista 1ra. Sección",
    "lat": "18.14417",
    "lng": "-92.74972"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Cosmópolis Octavo Sector",
    "lat": "25.82528",
    "lng": "-100.24611"
  },
  {
    "country": "MX",
    "name": "La Mesa",
    "lat": "31.15972",
    "lng": "-110.97444"
  },
  {
    "country": "MX",
    "name": "La Colonia",
    "lat": "20.05472",
    "lng": "-98.77028"
  },
  {
    "country": "MX",
    "name": "Cuarta Brigada",
    "lat": "20.62194",
    "lng": "-101.28001"
  },
  {
    "country": "MX",
    "name": "La Libertad",
    "lat": "19.75583",
    "lng": "-97.60722"
  },
  {
    "country": "MX",
    "name": "Rincones de la Hacienda",
    "lat": "20.12",
    "lng": "-98.40167"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Real de San Pablo",
    "lat": "19.38944",
    "lng": "-99.64861"
  },
  {
    "country": "MX",
    "name": "Colonia las Flores",
    "lat": "21.36167",
    "lng": "-97.69306"
  },
  {
    "country": "MX",
    "name": "El Saucillo",
    "lat": "20.07694",
    "lng": "-98.73722"
  },
  {
    "country": "MX",
    "name": "Barrio San Joaquín el Junco",
    "lat": "19.56417",
    "lng": "-99.77333"
  },
  {
    "country": "MX",
    "name": "Puerto de Buenavista (Lázaro Cárdenas)",
    "lat": "19.68806",
    "lng": "-101.12722"
  },
  {
    "country": "MX",
    "name": "Iquinuapa",
    "lat": "18.19583",
    "lng": "-93.12056"
  },
  {
    "country": "MX",
    "name": "Javier Rojo Gómez",
    "lat": "18.27389",
    "lng": "-88.68111"
  },
  {
    "country": "MX",
    "name": "Valle de Vaquerías",
    "lat": "25.6325",
    "lng": "-100.14694"
  },
  {
    "country": "MX",
    "name": "Río Medio [Granja]",
    "lat": "19.20972",
    "lng": "-96.20889"
  },
  {
    "country": "MX",
    "name": "Necoxtla",
    "lat": "18.77861",
    "lng": "-97.15361"
  },
  {
    "country": "MX",
    "name": "Juan Aldama (El Tigre)",
    "lat": "24.93972",
    "lng": "-107.82083"
  },
  {
    "country": "MX",
    "name": "Lomas de Río Medio Cuatro",
    "lat": "19.19333",
    "lng": "-96.21056"
  },
  {
    "country": "MX",
    "name": "Jardínes del Grijalva",
    "lat": "16.72847",
    "lng": "-93.03463"
  },
  {
    "country": "MX",
    "name": "Colonia la Asunción",
    "lat": "19.69083",
    "lng": "-99.06417"
  },
  {
    "country": "MX",
    "name": "Santa Mónica",
    "lat": "18.99306",
    "lng": "-99.42361"
  },
  {
    "country": "MX",
    "name": "Bahía de Lobos",
    "lat": "27.35167",
    "lng": "-110.45472"
  },
  {
    "country": "MX",
    "name": "San Martín Coapaxtongo",
    "lat": "18.99417",
    "lng": "-99.57"
  },
  {
    "country": "MX",
    "name": "Miguel Hidalgo",
    "lat": "28.15361",
    "lng": "-105.39389"
  },
  {
    "country": "MX",
    "name": "Galaxia la Calera",
    "lat": "18.999",
    "lng": "-98.1525"
  },
  {
    "country": "MX",
    "name": "Zapotlán",
    "lat": "19.54667",
    "lng": "-98.90306"
  },
  {
    "country": "MX",
    "name": "La Ciénega",
    "lat": "18.95611",
    "lng": "-99.58139"
  },
  {
    "country": "MX",
    "name": "Sector H Tres",
    "lat": "15.76611",
    "lng": "-96.14694"
  },
  {
    "country": "MX",
    "name": "Tlatempan",
    "lat": "19.33167",
    "lng": "-98.20306"
  },
  {
    "country": "MX",
    "name": "Ixtlahuaca Barrio",
    "lat": "19.83889",
    "lng": "-98.01444"
  },
  {
    "country": "MX",
    "name": "Jesús Nazareno",
    "lat": "18.87667",
    "lng": "-97.62306"
  },
  {
    "country": "MX",
    "name": "Guadalupe Zaragoza",
    "lat": "19.35833",
    "lng": "-98.5375"
  },
  {
    "country": "MX",
    "name": "San Pedro Tepetitlán",
    "lat": "19.62944",
    "lng": "-98.88972"
  },
  {
    "country": "MX",
    "name": "Bosques de la Magdalena",
    "lat": "19.35778",
    "lng": "-98.9475"
  },
  {
    "country": "MX",
    "name": "El Huaxtho",
    "lat": "20.23444",
    "lng": "-98.96222"
  },
  {
    "country": "MX",
    "name": "Tamazulápam del Espíritu Santo",
    "lat": "17.055",
    "lng": "-96.06528"
  },
  {
    "country": "MX",
    "name": "Poblado C-33 20 de Noviembre",
    "lat": "17.9675",
    "lng": "-93.565"
  },
  {
    "country": "MX",
    "name": "Santiago Acozac",
    "lat": "18.95694",
    "lng": "-97.81167"
  },
  {
    "country": "MX",
    "name": "Colorines",
    "lat": "18.88472",
    "lng": "-96.97833"
  },
  {
    "country": "MX",
    "name": "Rancho Verde",
    "lat": "31.91611",
    "lng": "-116.58833"
  },
  {
    "country": "MX",
    "name": "Entronque Laredo-Salinas Victoria",
    "lat": "25.855",
    "lng": "-100.24722"
  },
  {
    "country": "MX",
    "name": "Leona Vicario",
    "lat": "20.90944",
    "lng": "-89.60111"
  },
  {
    "country": "MX",
    "name": "San Felipe los Alzati (Colonia Nueva)",
    "lat": "19.48972",
    "lng": "-100.37389"
  },
  {
    "country": "MX",
    "name": "Rinconada de los Ángeles",
    "lat": "20.02611",
    "lng": "-98.71139"
  },
  {
    "country": "MX",
    "name": "Manuel Ávila Camacho",
    "lat": "20.11194",
    "lng": "-98.70694"
  },
  {
    "country": "MX",
    "name": "Sitio Ejido",
    "lat": "19.45334",
    "lng": "-99.90069"
  },
  {
    "country": "MX",
    "name": "Constitución",
    "lat": "18.07278",
    "lng": "-92.87194"
  },
  {
    "country": "MX",
    "name": "Conjunto Habitacional Ecológico SUTEYM",
    "lat": "19.36889",
    "lng": "-99.77861"
  },
  {
    "country": "MX",
    "name": "San José el Saladillo (El Saladillo)",
    "lat": "22.685",
    "lng": "-102.03778"
  },
  {
    "country": "MX",
    "name": "El Huarache (El Guarache)",
    "lat": "25.52",
    "lng": "-103.48667"
  },
  {
    "country": "MX",
    "name": "El Boxtha",
    "lat": "20.25972",
    "lng": "-98.97417"
  },
  {
    "country": "MX",
    "name": "Colonia San Luis Rey",
    "lat": "20.93556",
    "lng": "-100.73611"
  },
  {
    "country": "MX",
    "name": "El Progreso",
    "lat": "16.87694",
    "lng": "-93.22222"
  },
  {
    "country": "MX",
    "name": "Amuco de la Reforma",
    "lat": "18.29361",
    "lng": "-100.63972"
  },
  {
    "country": "MX",
    "name": "Colonia Progreso",
    "lat": "16.80111",
    "lng": "-95.07972"
  },
  {
    "country": "MX",
    "name": "Los Mangos",
    "lat": "18.24361",
    "lng": "-95.12222"
  },
  {
    "country": "MX",
    "name": "Rizos de la Joya (Rizos del Saucillo)",
    "lat": "21.14861",
    "lng": "-101.76194"
  },
  {
    "country": "MX",
    "name": "San Pedro Yancuitlalpan",
    "lat": "19.0775",
    "lng": "-98.48333"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento San Miguel",
    "lat": "20.07111",
    "lng": "-102.68667"
  },
  {
    "country": "MX",
    "name": "Colonia Agrícola México (Palmitas)",
    "lat": "25.10972",
    "lng": "-107.94472"
  },
  {
    "country": "MX",
    "name": "Cerrillos (Campo 35)",
    "lat": "25.87806",
    "lng": "-108.90139"
  },
  {
    "country": "MX",
    "name": "El Varal (San Sebastián Número Uno)",
    "lat": "25.64278",
    "lng": "-108.425"
  },
  {
    "country": "MX",
    "name": "Portal de las Salinas",
    "lat": "25.98222",
    "lng": "-100.14333"
  },
  {
    "country": "MX",
    "name": "Paseo Puente Viejo",
    "lat": "20.56917",
    "lng": "-103.19056"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Tetela",
    "lat": "19.2925",
    "lng": "-98.20778"
  },
  {
    "country": "MX",
    "name": "Almoloya",
    "lat": "20.02278",
    "lng": "-98.31667"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Misión de San Javier",
    "lat": "25.74556",
    "lng": "-100.15194"
  },
  {
    "country": "MX",
    "name": "Zona Urbana Ejido Isla Mujeres",
    "lat": "21.22472",
    "lng": "-86.85361"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento los Prados",
    "lat": "17.97778",
    "lng": "-94.63917"
  },
  {
    "country": "MX",
    "name": "Laguna del Rey (Químicas del Rey)",
    "lat": "27.03056",
    "lng": "-103.36667"
  },
  {
    "country": "MX",
    "name": "Poblado Número Cinco",
    "lat": "26.2225",
    "lng": "-109.06167"
  },
  {
    "country": "MX",
    "name": "Charco Blanco",
    "lat": "23.86306",
    "lng": "-103.6575"
  },
  {
    "country": "MX",
    "name": "Capoluca",
    "lat": "18.80639",
    "lng": "-97.02722"
  },
  {
    "country": "MX",
    "name": "Chicahuaxtla",
    "lat": "20.1425",
    "lng": "-97.94556"
  },
  {
    "country": "MX",
    "name": "Paraje el Mirador",
    "lat": "19.39944",
    "lng": "-99.32694"
  },
  {
    "country": "MX",
    "name": "Santa María Aranzazú (Santa María)",
    "lat": "18.98833",
    "lng": "-99.65056"
  },
  {
    "country": "MX",
    "name": "Macuilxóchitl de Artigas Carranza",
    "lat": "17.01583",
    "lng": "-96.54"
  },
  {
    "country": "MX",
    "name": "Cuauhtémoc (Campo Cinco)",
    "lat": "27.43333",
    "lng": "-110.01667"
  },
  {
    "country": "MX",
    "name": "San Francisco Independencia (Santa María Aserradero)",
    "lat": "19.06889",
    "lng": "-97.43028"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Ex-Hacienda el Refugio",
    "lat": "19.95083",
    "lng": "-102.25639"
  },
  {
    "country": "MX",
    "name": "San Juan Benito Juárez (San Juan Tararameo)",
    "lat": "19.91694",
    "lng": "-101.12861"
  },
  {
    "country": "MX",
    "name": "La Aurora",
    "lat": "20.62667",
    "lng": "-100.7575"
  },
  {
    "country": "MX",
    "name": "San Vicente la Mesilla",
    "lat": "16.17861",
    "lng": "-92.29333"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Rinconada del Valle",
    "lat": "19.41111",
    "lng": "-99.57417"
  },
  {
    "country": "MX",
    "name": "Unidad Habitacional Santa Teresa",
    "lat": "19.21611",
    "lng": "-99.55222"
  },
  {
    "country": "MX",
    "name": "Prados San Francisco",
    "lat": "19.72154",
    "lng": "-99.08366"
  },
  {
    "country": "MX",
    "name": "Hualcaltzinco",
    "lat": "19.40056",
    "lng": "-98.16"
  },
  {
    "country": "MX",
    "name": "Uruétaro",
    "lat": "19.79056",
    "lng": "-101.08778"
  },
  {
    "country": "MX",
    "name": "El Ámbar (El Ámbar de Echeverría)",
    "lat": "16.09639",
    "lng": "-92.83333"
  },
  {
    "country": "MX",
    "name": "Santa María Huiramangaro (San Juan Tumbio)",
    "lat": "19.51306",
    "lng": "-101.76528"
  },
  {
    "country": "MX",
    "name": "Anacleto Canabal 3ra. Sección",
    "lat": "18.0183",
    "lng": "-92.98992"
  },
  {
    "country": "MX",
    "name": "Metepec",
    "lat": "18.87889",
    "lng": "-98.74667"
  },
  {
    "country": "MX",
    "name": "Carmen Zacatal",
    "lat": "17.08083",
    "lng": "-92.8025"
  },
  {
    "country": "MX",
    "name": "El Cid",
    "lat": "19.86722",
    "lng": "-98.92694"
  },
  {
    "country": "MX",
    "name": "San José Tejamanil",
    "lat": "19.43139",
    "lng": "-99.35889"
  },
  {
    "country": "MX",
    "name": "San Nicolás Zecalacoayan",
    "lat": "19.19917",
    "lng": "-98.48833"
  },
  {
    "country": "MX",
    "name": "Xochimilco",
    "lat": "18.84167",
    "lng": "-97.72583"
  },
  {
    "country": "MX",
    "name": "El Llano",
    "lat": "21.94389",
    "lng": "-102.32278"
  },
  {
    "country": "MX",
    "name": "Tuncingo",
    "lat": "16.85083",
    "lng": "-99.78917"
  },
  {
    "country": "MX",
    "name": "Pueblo Mayo",
    "lat": "27.20361",
    "lng": "-109.555"
  },
  {
    "country": "MX",
    "name": "Coahuixco",
    "lat": "19.80556",
    "lng": "-97.41028"
  },
  {
    "country": "MX",
    "name": "Colonia Morelos",
    "lat": "19.63778",
    "lng": "-99.33917"
  },
  {
    "country": "MX",
    "name": "Zoatecpan",
    "lat": "19.93444",
    "lng": "-97.62028"
  },
  {
    "country": "MX",
    "name": "José María Pino Suárez (Nuevo Nahuapa)",
    "lat": "19.94889",
    "lng": "-105.32778"
  },
  {
    "country": "MX",
    "name": "La Planada",
    "lat": "19.78129",
    "lng": "-99.18267"
  },
  {
    "country": "MX",
    "name": "Llano de la Y",
    "lat": "19.40278",
    "lng": "-99.61639"
  },
  {
    "country": "MX",
    "name": "San Gregorio Aztotoacan",
    "lat": "19.26444",
    "lng": "-98.49194"
  },
  {
    "country": "MX",
    "name": "Loma de San José",
    "lat": "19.64222",
    "lng": "-99.32778"
  },
  {
    "country": "MX",
    "name": "San Diego la Huerta",
    "lat": "19.14472",
    "lng": "-99.63333"
  },
  {
    "country": "MX",
    "name": "Santa María Chimalapa",
    "lat": "16.90639",
    "lng": "-94.68333"
  },
  {
    "country": "MX",
    "name": "San Lorenzo Queréndaro",
    "lat": "19.6675",
    "lng": "-100.48861"
  },
  {
    "country": "MX",
    "name": "La Ermita (Nueva Jerusalén)",
    "lat": "19.07444",
    "lng": "-101.50667"
  },
  {
    "country": "MX",
    "name": "Gabriel Leyva Velázquez",
    "lat": "25.79111",
    "lng": "-108.56333"
  },
  {
    "country": "MX",
    "name": "Analco de Ponciano Arriaga (Santa Cruz Analco)",
    "lat": "19.26444",
    "lng": "-98.50028"
  },
  {
    "country": "MX",
    "name": "San Isidro",
    "lat": "19.79639",
    "lng": "-97.38361"
  },
  {
    "country": "MX",
    "name": "Cala Sur",
    "lat": "19.83278",
    "lng": "-97.42111"
  },
  {
    "country": "MX",
    "name": "Viñas del Sol",
    "lat": "32.62694",
    "lng": "-115.54667"
  },
  {
    "country": "MX",
    "name": "Kotolte",
    "lat": "16.86444",
    "lng": "-92.46111"
  },
  {
    "country": "MX",
    "name": "Tepetzingo",
    "lat": "18.93806",
    "lng": "-99.6125"
  },
  {
    "country": "MX",
    "name": "Apango de Zaragoza",
    "lat": "19.06833",
    "lng": "-97.94028"
  },
  {
    "country": "MX",
    "name": "Cartagena [Fraccionamiento]",
    "lat": "21.95639",
    "lng": "-102.27639"
  },
  {
    "country": "MX",
    "name": "Bellavista de Victoria (San José Bellavista)",
    "lat": "18.87639",
    "lng": "-97.54389"
  },
  {
    "country": "MX",
    "name": "Ninguno [Centro de Readaptación Social de Atlacholoaya]",
    "lat": "18.75778",
    "lng": "-99.22944"
  },
  {
    "country": "MX",
    "name": "Suchilapan del Río",
    "lat": "17.38611",
    "lng": "-94.98806"
  },
  {
    "country": "MX",
    "name": "Polígonos",
    "lat": "19.41612",
    "lng": "-98.99091"
  },
  {
    "country": "MX",
    "name": "San Jerónimo Almoloya",
    "lat": "18.94111",
    "lng": "-98.01056"
  },
  {
    "country": "MX",
    "name": "Tlalnepantla",
    "lat": "21.18",
    "lng": "-98.84611"
  },
  {
    "country": "MX",
    "name": "Rinconada la Loma [Fraccionamiento]",
    "lat": "20.45417",
    "lng": "-103.21917"
  },
  {
    "country": "MX",
    "name": "Llano Suchiapa",
    "lat": "16.86611",
    "lng": "-95.05389"
  },
  {
    "country": "MX",
    "name": "Colonia Paraíso Escondido",
    "lat": "21.05333",
    "lng": "-105.23833"
  },
  {
    "country": "MX",
    "name": "Colonia Emiliano Zapata Ejido de Tenancingo",
    "lat": "18.95361",
    "lng": "-99.55889"
  },
  {
    "country": "MX",
    "name": "Progreso",
    "lat": "20.01972",
    "lng": "-99.23861"
  },
  {
    "country": "MX",
    "name": "Acxotla del Río",
    "lat": "19.32417",
    "lng": "-98.2375"
  },
  {
    "country": "MX",
    "name": "El Rincón (Santa Cruz del Rincón)",
    "lat": "16.99611",
    "lng": "-98.73528"
  },
  {
    "country": "MX",
    "name": "El Nabo",
    "lat": "20.69389",
    "lng": "-100.48028"
  },
  {
    "country": "MX",
    "name": "Jorobas",
    "lat": "19.82389",
    "lng": "-99.24833"
  },
  {
    "country": "MX",
    "name": "Lomas de la Maestranza",
    "lat": "19.6875",
    "lng": "-101.33028"
  },
  {
    "country": "MX",
    "name": "Paseos del Pedregal",
    "lat": "20.66417",
    "lng": "-100.39806"
  },
  {
    "country": "MX",
    "name": "Las Esperanzas (El Ranchito)",
    "lat": "23.84972",
    "lng": "-103.13111"
  },
  {
    "country": "MX",
    "name": "Centro de Readaptación Social",
    "lat": "19.625",
    "lng": "-97.22028"
  },
  {
    "country": "MX",
    "name": "Ejido de Mozoquilpan",
    "lat": "19.42417",
    "lng": "-99.52833"
  },
  {
    "country": "MX",
    "name": "San Pedro Xochiteotla",
    "lat": "19.30667",
    "lng": "-98.14"
  },
  {
    "country": "MX",
    "name": "La Noria",
    "lat": "16.25444",
    "lng": "-95.22056"
  },
  {
    "country": "MX",
    "name": "Colonia San Isidro",
    "lat": "19.41167",
    "lng": "-98.11278"
  },
  {
    "country": "MX",
    "name": "Chiloljá",
    "lat": "16.88528",
    "lng": "-92.42472"
  },
  {
    "country": "MX",
    "name": "Pantitlán",
    "lat": "17.63972",
    "lng": "-99.10972"
  },
  {
    "country": "MX",
    "name": "San Francisco (El Calvito)",
    "lat": "16.32167",
    "lng": "-92.56194"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Ciudad Yagul",
    "lat": "16.9775",
    "lng": "-96.46194"
  },
  {
    "country": "MX",
    "name": "San Miguel del Progreso",
    "lat": "19.98972",
    "lng": "-97.66667"
  },
  {
    "country": "MX",
    "name": "El Recuerdo de Ancón (Xoconoxtle de Arriba)",
    "lat": "20.63806",
    "lng": "-101.12694"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Ex-Hacienda Catano",
    "lat": "17.2275",
    "lng": "-96.81556"
  },
  {
    "country": "MX",
    "name": "Tlacotepec de José Manzo",
    "lat": "19.27194",
    "lng": "-98.48472"
  },
  {
    "country": "MX",
    "name": "San José Tenería (Tenería)",
    "lat": "18.95028",
    "lng": "-99.54306"
  },
  {
    "country": "MX",
    "name": "Palma Grande",
    "lat": "21.99333",
    "lng": "-105.38944"
  },
  {
    "country": "MX",
    "name": "Colonia las Malvinas (Colonia Antorcha)",
    "lat": "19.87833",
    "lng": "-102.22583"
  },
  {
    "country": "MX",
    "name": "Manzana Quinta (La Cañada)",
    "lat": "19.54222",
    "lng": "-99.6025"
  },
  {
    "country": "MX",
    "name": "Carrillo Puerto",
    "lat": "22.43139",
    "lng": "-97.96417"
  },
  {
    "country": "MX",
    "name": "Cherán Atzicuirín (Cheranástico)",
    "lat": "19.7",
    "lng": "-102.01556"
  },
  {
    "country": "MX",
    "name": "Ejido la Soledad",
    "lat": "19.645",
    "lng": "-100.10639"
  },
  {
    "country": "MX",
    "name": "Tehuilotepec",
    "lat": "18.55167",
    "lng": "-99.58111"
  },
  {
    "country": "MX",
    "name": "Villa de Guadalupe",
    "lat": "25.51444",
    "lng": "-103.48917"
  },
  {
    "country": "MX",
    "name": "Hacienda la Cruz [Fraccionamiento]",
    "lat": "20.63333",
    "lng": "-100.26278"
  },
  {
    "country": "MX",
    "name": "San Salvador (Naranjillo)",
    "lat": "19.83139",
    "lng": "-97.315"
  },
  {
    "country": "MX",
    "name": "Colonia Campesina",
    "lat": "28.14028",
    "lng": "-105.52667"
  },
  {
    "country": "MX",
    "name": "San Miguel Tianguizolco",
    "lat": "19.15861",
    "lng": "-98.44083"
  },
  {
    "country": "MX",
    "name": "San Cosme Atlamaxac",
    "lat": "19.23833",
    "lng": "-98.22583"
  },
  {
    "country": "MX",
    "name": "Mismaloya (Fraccionamiento Pedregal de Santa Martha)",
    "lat": "20.60694",
    "lng": "-103.17139"
  },
  {
    "country": "MX",
    "name": "La Roca",
    "lat": "20.51278",
    "lng": "-103.42639"
  },
  {
    "country": "MX",
    "name": "El Cuervero (Cuerveros)",
    "lat": "21.86056",
    "lng": "-102.68389"
  },
  {
    "country": "MX",
    "name": "San Bartolo del Llano (San Isidro)",
    "lat": "19.30528",
    "lng": "-99.8275"
  },
  {
    "country": "MX",
    "name": "San Isidro Gallinero (El Gallinero)",
    "lat": "16.88139",
    "lng": "-99.71417"
  },
  {
    "country": "MX",
    "name": "Guadalupe Victoria",
    "lat": "16.75611",
    "lng": "-98.18167"
  },
  {
    "country": "MX",
    "name": "Amacuitlapilco",
    "lat": "18.69611",
    "lng": "-98.81167"
  },
  {
    "country": "MX",
    "name": "Loma Bonita",
    "lat": "18.93144",
    "lng": "-99.17564"
  },
  {
    "country": "MX",
    "name": "Colonia Río Lerma (Tic Ti)",
    "lat": "19.80556",
    "lng": "-99.89722"
  },
  {
    "country": "MX",
    "name": "San Mateo Capultitlán",
    "lat": "19.195",
    "lng": "-98.41528"
  },
  {
    "country": "MX",
    "name": "Ignacio Zaragoza",
    "lat": "18.40139",
    "lng": "-92.95944"
  },
  {
    "country": "MX",
    "name": "San Juan Ahuehueyo",
    "lat": "18.715",
    "lng": "-98.93278"
  },
  {
    "country": "MX",
    "name": "San José Carpinteros",
    "lat": "18.99472",
    "lng": "-97.91167"
  },
  {
    "country": "MX",
    "name": "Colonia Ricardo Flores Magón",
    "lat": "19.26833",
    "lng": "-99.75833"
  },
  {
    "country": "MX",
    "name": "Santa Martha",
    "lat": "19.43145",
    "lng": "-98.91744"
  },
  {
    "country": "MX",
    "name": "Hermenegildo J. Aldana",
    "lat": "18.00611",
    "lng": "-94.61222"
  },
  {
    "country": "MX",
    "name": "Colonia Guadalupe Victoria (La Capilla)",
    "lat": "19.40222",
    "lng": "-99.45417"
  },
  {
    "country": "MX",
    "name": "Corral del Risco (Punta de Mita)",
    "lat": "20.77361",
    "lng": "-105.51667"
  },
  {
    "country": "MX",
    "name": "El Curtidor",
    "lat": "19.29167",
    "lng": "-99.835"
  },
  {
    "country": "MX",
    "name": "San Andrés",
    "lat": "19.79",
    "lng": "-97.33889"
  },
  {
    "country": "MX",
    "name": "Poblado C-21 Licenciado Benito Juárez García",
    "lat": "18.06778",
    "lng": "-93.56139"
  },
  {
    "country": "MX",
    "name": "Cima del Sol (Fraccionamiento Cima del Sol)",
    "lat": "20.46889",
    "lng": "-103.41722"
  },
  {
    "country": "MX",
    "name": "Pueblos Unidos",
    "lat": "24.2925",
    "lng": "-107.15139"
  },
  {
    "country": "MX",
    "name": "Luis Rodríguez (El Vergel)",
    "lat": "30.40722",
    "lng": "-115.88722"
  },
  {
    "country": "MX",
    "name": "Betania",
    "lat": "16.60639",
    "lng": "-92.52194"
  },
  {
    "country": "MX",
    "name": "San Miguel Espejo",
    "lat": "19.095",
    "lng": "-98.06667"
  },
  {
    "country": "MX",
    "name": "Alfonso G. Calderón Velarde",
    "lat": "25.78556",
    "lng": "-108.60222"
  },
  {
    "country": "MX",
    "name": "Colonia San Ramón",
    "lat": "18.96833",
    "lng": "-99.57222"
  },
  {
    "country": "MX",
    "name": "Paso de Arena",
    "lat": "18.30333",
    "lng": "-100.84639"
  },
  {
    "country": "MX",
    "name": "Tulipanes",
    "lat": "20.06028",
    "lng": "-98.76722"
  },
  {
    "country": "MX",
    "name": "San Francisco Temetzontla",
    "lat": "19.35028",
    "lng": "-98.28861"
  },
  {
    "country": "MX",
    "name": "Los Laureles",
    "lat": "19.48778",
    "lng": "-89.99444"
  },
  {
    "country": "MX",
    "name": "Panales Jamaica (Cañones)",
    "lat": "20.29556",
    "lng": "-100.82306"
  },
  {
    "country": "MX",
    "name": "Loma Bonita",
    "lat": "19.18722",
    "lng": "-100.215"
  },
  {
    "country": "MX",
    "name": "Cereso 14 (El Amate)",
    "lat": "16.59472",
    "lng": "-93.80278"
  },
  {
    "country": "MX",
    "name": "Acatepec",
    "lat": "17.32472",
    "lng": "-98.90944"
  },
  {
    "country": "MX",
    "name": "Bonifacio Moreno (El Aguaje)",
    "lat": "18.99167",
    "lng": "-102.71083"
  },
  {
    "country": "MX",
    "name": "Las Cañadas",
    "lat": "20.2975",
    "lng": "-101.97806"
  },
  {
    "country": "MX",
    "name": "Santa Catarina Villanueva",
    "lat": "18.99917",
    "lng": "-97.61472"
  },
  {
    "country": "MX",
    "name": "Doctor Rodulfo Figueroa (Tierra Blanca)",
    "lat": "15.85083",
    "lng": "-92.06222"
  },
  {
    "country": "MX",
    "name": "Ignacio Zaragoza",
    "lat": "20.88167",
    "lng": "-87.525"
  },
  {
    "country": "MX",
    "name": "Unión Ejidal Tierra y Libertad",
    "lat": "19.6575",
    "lng": "-98.3375"
  },
  {
    "country": "MX",
    "name": "El Tigre",
    "lat": "18.10194",
    "lng": "-92.94194"
  },
  {
    "country": "MX",
    "name": "Veinte de Noviembre",
    "lat": "16.62",
    "lng": "-92.08194"
  },
  {
    "country": "MX",
    "name": "Barrio de Centro del Cerrillo",
    "lat": "19.53694",
    "lng": "-99.95417"
  },
  {
    "country": "MX",
    "name": "Centro de Readaptación Social Nuevo",
    "lat": "31.18444",
    "lng": "-110.96778"
  },
  {
    "country": "MX",
    "name": "Santa Rosa de Lima",
    "lat": "16.07111",
    "lng": "-97.62333"
  },
  {
    "country": "MX",
    "name": "San Antonio del Monte",
    "lat": "16.76028",
    "lng": "-92.65306"
  },
  {
    "country": "MX",
    "name": "Loma Larga (Barrio de Loma Larga)",
    "lat": "19.86722",
    "lng": "-99.11611"
  },
  {
    "country": "MX",
    "name": "Xhixhata",
    "lat": "19.97056",
    "lng": "-99.54611"
  },
  {
    "country": "MX",
    "name": "Nuevo Paso Nazareno (Chichicazapa)",
    "lat": "18.29667",
    "lng": "-96.34722"
  },
  {
    "country": "MX",
    "name": "Llano Largo",
    "lat": "20.30111",
    "lng": "-99.76556"
  },
  {
    "country": "MX",
    "name": "El Encanto del Cerril",
    "lat": "18.93194",
    "lng": "-98.42556"
  },
  {
    "country": "MX",
    "name": "La Mesa de Chosto",
    "lat": "19.8525",
    "lng": "-99.89028"
  },
  {
    "country": "MX",
    "name": "Magisterio Digno",
    "lat": "20.05694",
    "lng": "-98.76889"
  },
  {
    "country": "MX",
    "name": "Pañhé",
    "lat": "20.52167",
    "lng": "-99.69667"
  },
  {
    "country": "MX",
    "name": "El Carmen (El Limón)",
    "lat": "17.89056",
    "lng": "-93.16528"
  },
  {
    "country": "MX",
    "name": "El Romereño (INFONAVIT)",
    "lat": "20.38083",
    "lng": "-102.94944"
  },
  {
    "country": "MX",
    "name": "Lindavista",
    "lat": "20.02611",
    "lng": "-98.79778"
  },
  {
    "country": "MX",
    "name": "Tz'Aquiviljok",
    "lat": "16.85528",
    "lng": "-92.45972"
  },
  {
    "country": "MX",
    "name": "Tonalá",
    "lat": "16.86167",
    "lng": "-99.05444"
  },
  {
    "country": "MX",
    "name": "Tecpantzacoalco",
    "lat": "18.47694",
    "lng": "-97.03944"
  },
  {
    "country": "MX",
    "name": "Barrio de Jesús Fracción Primera",
    "lat": "19.36778",
    "lng": "-99.68694"
  },
  {
    "country": "MX",
    "name": "Colonia Morelos (El Nueve)",
    "lat": "20.225",
    "lng": "-99.14111"
  },
  {
    "country": "MX",
    "name": "Arboledas",
    "lat": "19.20722",
    "lng": "-96.21444"
  },
  {
    "country": "MX",
    "name": "Texcaltitán Xoteapan (Texcaltitán)",
    "lat": "18.44667",
    "lng": "-95.25333"
  },
  {
    "country": "MX",
    "name": "Fredepo",
    "lat": "18.88056",
    "lng": "-96.97694"
  },
  {
    "country": "MX",
    "name": "Diamante de Echeverría",
    "lat": "16.11333",
    "lng": "-92.88"
  },
  {
    "country": "MX",
    "name": "San Francisco",
    "lat": "27.645",
    "lng": "-113.41917"
  },
  {
    "country": "MX",
    "name": "Octaviano López",
    "lat": "27.0025",
    "lng": "-105.03306"
  },
  {
    "country": "MX",
    "name": "Progreso",
    "lat": "22.22833",
    "lng": "-100.12806"
  },
  {
    "country": "MX",
    "name": "Texalpan de Arriba",
    "lat": "18.42944",
    "lng": "-95.24417"
  },
  {
    "country": "MX",
    "name": "Gunyo Poniente (San José Gunyo)",
    "lat": "20.11149",
    "lng": "-99.83861"
  },
  {
    "country": "MX",
    "name": "Chulum Juárez",
    "lat": "17.33194",
    "lng": "-92.53389"
  },
  {
    "country": "MX",
    "name": "El Salto",
    "lat": "23.19556",
    "lng": "-103.0675"
  },
  {
    "country": "MX",
    "name": "Barrio de Guadalupe",
    "lat": "19.23054",
    "lng": "-98.9309"
  },
  {
    "country": "MX",
    "name": "Ladrillera (Entronque Pesquería)",
    "lat": "25.80306",
    "lng": "-100.10111"
  },
  {
    "country": "MX",
    "name": "San Francisco (Mata Clara)",
    "lat": "18.81444",
    "lng": "-96.74611"
  },
  {
    "country": "MX",
    "name": "Cipreses",
    "lat": "20.05889",
    "lng": "-98.7675"
  },
  {
    "country": "MX",
    "name": "Colonia el Renacimiento",
    "lat": "19.21889",
    "lng": "-96.21639"
  },
  {
    "country": "MX",
    "name": "Macario J. Gómez [Colonia]",
    "lat": "21.98056",
    "lng": "-102.25139"
  },
  {
    "country": "MX",
    "name": "Unidad Habitacional Antonio Osorio de León (Bojay)",
    "lat": "20.04389",
    "lng": "-99.24472"
  },
  {
    "country": "MX",
    "name": "Taniperla",
    "lat": "16.82222",
    "lng": "-91.52333"
  },
  {
    "country": "MX",
    "name": "San José Monte Chiquito",
    "lat": "18.49611",
    "lng": "-97.43806"
  },
  {
    "country": "MX",
    "name": "Xonalpu",
    "lat": "20.12833",
    "lng": "-97.61056"
  },
  {
    "country": "MX",
    "name": "Morelos Piedra 3ra. Sección",
    "lat": "18.14389",
    "lng": "-93.22"
  },
  {
    "country": "MX",
    "name": "San Francisco Tlaltica",
    "lat": "19.65833",
    "lng": "-98.775"
  },
  {
    "country": "MX",
    "name": "San Francisco Zacapexpan",
    "lat": "19.88028",
    "lng": "-97.59611"
  },
  {
    "country": "MX",
    "name": "Cliserio Alanís (San Gaspar)",
    "lat": "18.86111",
    "lng": "-99.16"
  },
  {
    "country": "MX",
    "name": "Tinajitas",
    "lat": "19.61806",
    "lng": "-96.4425"
  },
  {
    "country": "MX",
    "name": "Nuevo Vicente Guerrero (El Chichonal)",
    "lat": "16.48528",
    "lng": "-92.87139"
  },
  {
    "country": "MX",
    "name": "San Isidro (El Reservado)",
    "lat": "19.30694",
    "lng": "-99.77889"
  },
  {
    "country": "MX",
    "name": "Mariano Balleza",
    "lat": "26.95389",
    "lng": "-106.34611"
  },
  {
    "country": "MX",
    "name": "Brisas del Carrizal",
    "lat": "18.01556",
    "lng": "-92.97083"
  },
  {
    "country": "MX",
    "name": "Rafael Yáñez Sosa (El Mezquite)",
    "lat": "23.32833",
    "lng": "-102.61028"
  },
  {
    "country": "MX",
    "name": "Bocaneo (San Pedro)",
    "lat": "19.83861",
    "lng": "-100.81722"
  },
  {
    "country": "MX",
    "name": "CEFERESO Número 3",
    "lat": "25.84722",
    "lng": "-97.63333"
  },
  {
    "country": "MX",
    "name": "Tzeltal",
    "lat": "16.93944",
    "lng": "-92.47778"
  },
  {
    "country": "MX",
    "name": "Alfredo V. Bonfil (Chacampalco)",
    "lat": "18.65528",
    "lng": "-99.15417"
  },
  {
    "country": "MX",
    "name": "San Buenaventura Atempan",
    "lat": "19.32667",
    "lng": "-98.22194"
  },
  {
    "country": "MX",
    "name": "Tocob Leglemal",
    "lat": "17.23389",
    "lng": "-92.37833"
  },
  {
    "country": "MX",
    "name": "Altus Bosques",
    "lat": "20.56806",
    "lng": "-103.3725"
  },
  {
    "country": "MX",
    "name": "Barrio de Nuevo León",
    "lat": "19.08861",
    "lng": "-98.29"
  },
  {
    "country": "MX",
    "name": "Colonia 18 de Marzo",
    "lat": "20.55556",
    "lng": "-101.03556"
  },
  {
    "country": "MX",
    "name": "Heriberto Valdez Romero (El Guayabo)",
    "lat": "25.94056",
    "lng": "-109.13722"
  },
  {
    "country": "MX",
    "name": "San José Chapayal",
    "lat": "17.30056",
    "lng": "-92.89028"
  },
  {
    "country": "MX",
    "name": "Seis de Octubre (Santo Niño)",
    "lat": "25.76389",
    "lng": "-103.23889"
  },
  {
    "country": "MX",
    "name": "La Escalera",
    "lat": "17.84361",
    "lng": "-92.52556"
  },
  {
    "country": "MX",
    "name": "Papatlazolco",
    "lat": "20.1775",
    "lng": "-97.99167"
  },
  {
    "country": "MX",
    "name": "Colonia Felipe Ángeles",
    "lat": "20.05417",
    "lng": "-98.41861"
  },
  {
    "country": "MX",
    "name": "San Francisco (Baños de Agua Caliente)",
    "lat": "21.07389",
    "lng": "-101.47278"
  },
  {
    "country": "MX",
    "name": "Ciudad Morelos",
    "lat": "32.34389",
    "lng": "-117.01056"
  },
  {
    "country": "MX",
    "name": "El Copalar",
    "lat": "16.87694",
    "lng": "-93.21389"
  },
  {
    "country": "MX",
    "name": "San Diego",
    "lat": "19.85667",
    "lng": "-97.36111"
  },
  {
    "country": "MX",
    "name": "San Pedro Xalcaltzinco",
    "lat": "19.22778",
    "lng": "-98.22806"
  },
  {
    "country": "MX",
    "name": "Campo Real",
    "lat": "20.78722",
    "lng": "-103.44306"
  },
  {
    "country": "MX",
    "name": "Taxco",
    "lat": "18.13917",
    "lng": "-93.00528"
  },
  {
    "country": "MX",
    "name": "Belisario Domínguez",
    "lat": "15.29944",
    "lng": "-92.38056"
  },
  {
    "country": "MX",
    "name": "Sierra de Guadalupe",
    "lat": "19.5925",
    "lng": "-99.15944"
  },
  {
    "country": "MX",
    "name": "Ninguno [CERESO]",
    "lat": "28.60972",
    "lng": "-105.94028"
  },
  {
    "country": "MX",
    "name": "Acatempa",
    "lat": "17.64333",
    "lng": "-99.36639"
  },
  {
    "country": "MX",
    "name": "Chimalapa",
    "lat": "20.18806",
    "lng": "-98.16"
  },
  {
    "country": "MX",
    "name": "Xoxonacatla",
    "lat": "20.0075",
    "lng": "-97.94056"
  },
  {
    "country": "MX",
    "name": "Otilpan",
    "lat": "19.55722",
    "lng": "-96.97667"
  },
  {
    "country": "MX",
    "name": "Progreso de Juárez",
    "lat": "18.96167",
    "lng": "-97.75556"
  },
  {
    "country": "MX",
    "name": "San Rafael Tepatlaxco",
    "lat": "19.29833",
    "lng": "-98.11972"
  },
  {
    "country": "MX",
    "name": "Vallecitos de Zaragoza",
    "lat": "17.92028",
    "lng": "-101.32361"
  },
  {
    "country": "MX",
    "name": "Monte Grande",
    "lat": "20.99806",
    "lng": "-101.86333"
  },
  {
    "country": "MX",
    "name": "San José del Cerrito de Camargo",
    "lat": "20.41917",
    "lng": "-101.04222"
  },
  {
    "country": "MX",
    "name": "Barrio de España",
    "lat": "19.86139",
    "lng": "-99.08167"
  },
  {
    "country": "MX",
    "name": "Río Grande",
    "lat": "20.34417",
    "lng": "-102.00556"
  },
  {
    "country": "MX",
    "name": "Techachaltitla",
    "lat": "19.365",
    "lng": "-98.94056"
  },
  {
    "country": "MX",
    "name": "Francisco I. Madero",
    "lat": "16.87427",
    "lng": "-93.21678"
  },
  {
    "country": "MX",
    "name": "Ricardo Flores Magón",
    "lat": "25.74056",
    "lng": "-108.99583"
  },
  {
    "country": "MX",
    "name": "San Francisco Tlacuilohcan",
    "lat": "19.40167",
    "lng": "-98.19278"
  },
  {
    "country": "MX",
    "name": "Valle Huejúcar (Fraccionamiento Popular) [Fraccionamiento]",
    "lat": "21.83111",
    "lng": "-102.75028"
  },
  {
    "country": "MX",
    "name": "San Antonio Tecolco",
    "lat": "18.85222",
    "lng": "-97.77806"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Hacienda del Bosque",
    "lat": "19.72667",
    "lng": "-98.96861"
  },
  {
    "country": "MX",
    "name": "Oso Viejo",
    "lat": "24.39944",
    "lng": "-107.17139"
  },
  {
    "country": "MX",
    "name": "El Cortijo",
    "lat": "16.98972",
    "lng": "-99.14889"
  },
  {
    "country": "MX",
    "name": "Colonia Montemariana (Colonia Mariana)",
    "lat": "23.32639",
    "lng": "-103.11222"
  },
  {
    "country": "MX",
    "name": "Santa Ana",
    "lat": "21.05917",
    "lng": "-101.67583"
  },
  {
    "country": "MX",
    "name": "Colonia Latinoamericana",
    "lat": "21.03028",
    "lng": "-101.70583"
  },
  {
    "country": "MX",
    "name": "Zahuatlán de Morelos (San José)",
    "lat": "18.98333",
    "lng": "-97.8675"
  },
  {
    "country": "MX",
    "name": "El Pozole",
    "lat": "22.91472",
    "lng": "-105.91333"
  },
  {
    "country": "MX",
    "name": "Tatauzoquico",
    "lat": "19.82833",
    "lng": "-97.52694"
  },
  {
    "country": "MX",
    "name": "Guadalupe Minerva",
    "lat": "20.12583",
    "lng": "-98.71389"
  },
  {
    "country": "MX",
    "name": "San José",
    "lat": "19.80306",
    "lng": "-97.33389"
  },
  {
    "country": "MX",
    "name": "San Lorenzo Tlaxipehuala",
    "lat": "20.13028",
    "lng": "-97.97361"
  },
  {
    "country": "MX",
    "name": "Paseo de las Cañadas",
    "lat": "20.62139",
    "lng": "-103.19778"
  },
  {
    "country": "MX",
    "name": "Constancio Farfán (La Pascuala)",
    "lat": "18.74194",
    "lng": "-98.95389"
  },
  {
    "country": "MX",
    "name": "Villas Fundadores [Fraccionamiento]",
    "lat": "20.37778",
    "lng": "-99.90944"
  },
  {
    "country": "MX",
    "name": "Bella Vista del Río",
    "lat": "20.69",
    "lng": "-99.57139"
  },
  {
    "country": "MX",
    "name": "Abelardo L. Rodríguez",
    "lat": "18.7375",
    "lng": "-98.98528"
  },
  {
    "country": "MX",
    "name": "El Rincón de San Felipe (Tercera Manzana San Felipe)",
    "lat": "19.50639",
    "lng": "-100.37278"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Monte Olivo",
    "lat": "19.98472",
    "lng": "-102.25111"
  },
  {
    "country": "MX",
    "name": "Tlamanca de Hernández",
    "lat": "19.95597",
    "lng": "-97.81489"
  },
  {
    "country": "MX",
    "name": "Purísima del Progreso",
    "lat": "20.79333",
    "lng": "-101.33028"
  },
  {
    "country": "MX",
    "name": "Calvario Buenavista",
    "lat": "19.70417",
    "lng": "-99.95694"
  },
  {
    "country": "MX",
    "name": "El Jacal",
    "lat": "19.405",
    "lng": "-100.08944"
  },
  {
    "country": "MX",
    "name": "San Pedro de los Sauces",
    "lat": "19.78639",
    "lng": "-101.13778"
  },
  {
    "country": "MX",
    "name": "La Azozuca",
    "lat": "16.82139",
    "lng": "-99.04194"
  },
  {
    "country": "MX",
    "name": "Colonia Agrícola Álvaro Obregón",
    "lat": "19.22806",
    "lng": "-99.55583"
  },
  {
    "country": "MX",
    "name": "Cuatzoquitengo",
    "lat": "17.28822",
    "lng": "-98.61523"
  },
  {
    "country": "MX",
    "name": "Palmillas",
    "lat": "19.69361",
    "lng": "-99.95028"
  },
  {
    "country": "MX",
    "name": "Lagartera 1ra. Sección",
    "lat": "18.06277",
    "lng": "-92.88563"
  },
  {
    "country": "MX",
    "name": "Hacienda Vieja del Castillo (Castillo Viejo)",
    "lat": "20.54",
    "lng": "-103.24417"
  },
  {
    "country": "MX",
    "name": "Ceiba 1ra. Sección (Jahuactal)",
    "lat": "18.06222",
    "lng": "-93.11306"
  },
  {
    "country": "MX",
    "name": "San Vicente Zoyatlán",
    "lat": "17.3225",
    "lng": "-98.36417"
  },
  {
    "country": "MX",
    "name": "Tenochtitlán",
    "lat": "19.80917",
    "lng": "-96.91611"
  },
  {
    "country": "MX",
    "name": "Huehuetán",
    "lat": "16.63583",
    "lng": "-98.55889"
  },
  {
    "country": "MX",
    "name": "Chichicaxtle",
    "lat": "19.34306",
    "lng": "-96.46861"
  },
  {
    "country": "MX",
    "name": "Manuel Villalongín",
    "lat": "20.2375",
    "lng": "-101.52667"
  },
  {
    "country": "MX",
    "name": "La Versolilla",
    "lat": "20.87306",
    "lng": "-100.37889"
  },
  {
    "country": "MX",
    "name": "Colonia Tulteca Teopan",
    "lat": "19.56139",
    "lng": "-98.84417"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Paseo de las Torres",
    "lat": "21.16833",
    "lng": "-101.75806"
  },
  {
    "country": "MX",
    "name": "El Cahulote de Santa Ana",
    "lat": "19.07611",
    "lng": "-101.5825"
  },
  {
    "country": "MX",
    "name": "Colonia Agrícola de Ocotepec (Colonia San José)",
    "lat": "18.92972",
    "lng": "-98.54444"
  },
  {
    "country": "MX",
    "name": "Apeo",
    "lat": "19.88722",
    "lng": "-100.34194"
  },
  {
    "country": "MX",
    "name": "Leacaman",
    "lat": "20.09861",
    "lng": "-97.64306"
  },
  {
    "country": "MX",
    "name": "Yashanal",
    "lat": "16.82889",
    "lng": "-92.45194"
  },
  {
    "country": "MX",
    "name": "Santa Elena",
    "lat": "19.85861",
    "lng": "-100.40833"
  },
  {
    "country": "MX",
    "name": "Cinco de Mayo",
    "lat": "20.13167",
    "lng": "-97.63"
  },
  {
    "country": "MX",
    "name": "Buenavista de Juárez",
    "lat": "18.945",
    "lng": "-97.82778"
  },
  {
    "country": "MX",
    "name": "Colonia Emiliano Zapata (San Juan Zitácuaro)",
    "lat": "19.44778",
    "lng": "-100.30583"
  },
  {
    "country": "MX",
    "name": "Caparroso",
    "lat": "18.345",
    "lng": "-92.80361"
  },
  {
    "country": "MX",
    "name": "Colonia Diana Laura Riojas de Colosio",
    "lat": "26.97722",
    "lng": "-101.48083"
  },
  {
    "country": "MX",
    "name": "Tlaxinga (Clatzinga)",
    "lat": "17.52106",
    "lng": "-99.19331"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento San Miguel",
    "lat": "17.21278",
    "lng": "-96.78694"
  },
  {
    "country": "MX",
    "name": "Paso Nacional",
    "lat": "18.76639",
    "lng": "-95.74861"
  },
  {
    "country": "MX",
    "name": "San Pedro Nichtalucum",
    "lat": "17.03444",
    "lng": "-92.72694"
  },
  {
    "country": "MX",
    "name": "Hermenegildo Galeana 2da. Sección",
    "lat": "18.17054",
    "lng": "-93.13508"
  },
  {
    "country": "MX",
    "name": "La Gloria",
    "lat": "15.96389",
    "lng": "-91.965"
  },
  {
    "country": "MX",
    "name": "Hacienda Tecate",
    "lat": "32.565",
    "lng": "-116.525"
  },
  {
    "country": "MX",
    "name": "San Javier",
    "lat": "20.7525",
    "lng": "-99.71778"
  },
  {
    "country": "MX",
    "name": "San Antonio la Portilla",
    "lat": "18.79611",
    "lng": "-97.76278"
  },
  {
    "country": "MX",
    "name": "San Bartolomé Hueyapan",
    "lat": "19.02528",
    "lng": "-97.93056"
  },
  {
    "country": "MX",
    "name": "Marcelino Rodríguez (San Ignacio)",
    "lat": "18.57889",
    "lng": "-98.74361"
  },
  {
    "country": "MX",
    "name": "Francisco I. Madero",
    "lat": "18.32667",
    "lng": "-95.3625"
  },
  {
    "country": "MX",
    "name": "San Sebastián [Fraccionamiento]",
    "lat": "21.82139",
    "lng": "-102.27111"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Universo",
    "lat": "18.96167",
    "lng": "-99.18639"
  },
  {
    "country": "MX",
    "name": "El Esclavo",
    "lat": "19.67667",
    "lng": "-99.37139"
  },
  {
    "country": "MX",
    "name": "Ahuacatlán",
    "lat": "20.13722",
    "lng": "-98.0075"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Acapa",
    "lat": "18.40556",
    "lng": "-97.32611"
  },
  {
    "country": "MX",
    "name": "San Miguel Monteverde",
    "lat": "17.53111",
    "lng": "-97.7925"
  },
  {
    "country": "MX",
    "name": "Ampliación la Hincada",
    "lat": "22.21528",
    "lng": "-99.23611"
  },
  {
    "country": "MX",
    "name": "Pueblo Nuevo Tlalmimilolpan",
    "lat": "19.39222",
    "lng": "-99.50167"
  },
  {
    "country": "MX",
    "name": "El Mirador",
    "lat": "20.03",
    "lng": "-98.81056"
  },
  {
    "country": "MX",
    "name": "San Atenógenes (La Villita)",
    "lat": "23.99056",
    "lng": "-104.01722"
  },
  {
    "country": "MX",
    "name": "Cerro las Iguanas",
    "lat": "18.41083",
    "lng": "-95.19972"
  },
  {
    "country": "MX",
    "name": "Texcaltepec",
    "lat": "20.03028",
    "lng": "-98.32417"
  },
  {
    "country": "MX",
    "name": "San Roque de Montes",
    "lat": "21.01",
    "lng": "-101.81083"
  },
  {
    "country": "MX",
    "name": "Jardines del Edén",
    "lat": "20.5325",
    "lng": "-103.36278"
  },
  {
    "country": "MX",
    "name": "Caserío de Cortés",
    "lat": "19.19861",
    "lng": "-98.95444"
  },
  {
    "country": "MX",
    "name": "Alpuyecancingo de las Montañas",
    "lat": "17.67083",
    "lng": "-98.85194"
  },
  {
    "country": "MX",
    "name": "San Cayetano",
    "lat": "16.96119",
    "lng": "-92.76016"
  },
  {
    "country": "MX",
    "name": "Buena Vista",
    "lat": "25.85222",
    "lng": "-100.36"
  },
  {
    "country": "MX",
    "name": "Emiliano Zapata (El Ranchito)",
    "lat": "19.24394",
    "lng": "-104.71863"
  },
  {
    "country": "MX",
    "name": "Tezhuatepec",
    "lat": "19.81167",
    "lng": "-97.4625"
  },
  {
    "country": "MX",
    "name": "Santiago Jaltepec",
    "lat": "20.10972",
    "lng": "-98.71111"
  },
  {
    "country": "MX",
    "name": "Olintepec",
    "lat": "18.74056",
    "lng": "-98.98722"
  },
  {
    "country": "MX",
    "name": "La Joya",
    "lat": "23.8375",
    "lng": "-103.99861"
  },
  {
    "country": "MX",
    "name": "El Arco",
    "lat": "19.22528",
    "lng": "-100.13167"
  },
  {
    "country": "MX",
    "name": "San Francisco de la Palma",
    "lat": "20.66028",
    "lng": "-100.51528"
  },
  {
    "country": "MX",
    "name": "Colonia Lázaro Cárdenas",
    "lat": "19.51306",
    "lng": "-98.92"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Real del Valle",
    "lat": "16.93278",
    "lng": "-96.76778"
  },
  {
    "country": "MX",
    "name": "San José del Puente",
    "lat": "19.72056",
    "lng": "-99.19667"
  },
  {
    "country": "MX",
    "name": "Bosques de San Pedro",
    "lat": "25.60139",
    "lng": "-100.17972"
  },
  {
    "country": "MX",
    "name": "Pejelagartero 1ra. Sección (Plataforma)",
    "lat": "18.055",
    "lng": "-93.82472"
  },
  {
    "country": "MX",
    "name": "Ahuacatlán de Guadalupe",
    "lat": "21.21472",
    "lng": "-99.54056"
  },
  {
    "country": "MX",
    "name": "Monte Calvario",
    "lat": "19.10444",
    "lng": "-99.59528"
  },
  {
    "country": "MX",
    "name": "San Pedro Atmatla",
    "lat": "19.91083",
    "lng": "-97.9675"
  },
  {
    "country": "MX",
    "name": "La Mohonera",
    "lat": "17.63839",
    "lng": "-99.20222"
  },
  {
    "country": "MX",
    "name": "Mecoacán 2da. Sección (San Lorenzo)",
    "lat": "18.2779",
    "lng": "-93.09095"
  },
  {
    "country": "MX",
    "name": "Guásimas (De Belem)",
    "lat": "27.88583",
    "lng": "-110.58167"
  },
  {
    "country": "MX",
    "name": "Colonia Adolfo López Mateos",
    "lat": "19.40056",
    "lng": "-99.45944"
  },
  {
    "country": "MX",
    "name": "Colonia el Refugio",
    "lat": "19.22694",
    "lng": "-99.69417"
  },
  {
    "country": "MX",
    "name": "Nuevo Milenio Valdivia",
    "lat": "15.50306",
    "lng": "-92.94861"
  },
  {
    "country": "MX",
    "name": "Estación Corral",
    "lat": "27.62889",
    "lng": "-109.96611"
  },
  {
    "country": "MX",
    "name": "San Pedro Ozumacín",
    "lat": "17.67861",
    "lng": "-96.22556"
  },
  {
    "country": "MX",
    "name": "Coamilpa de Juárez",
    "lat": "19.19778",
    "lng": "-99.44361"
  },
  {
    "country": "MX",
    "name": "Los Ángeles",
    "lat": "20.55361",
    "lng": "-100.94167"
  },
  {
    "country": "MX",
    "name": "Los Dolores (Las Quince Letras)",
    "lat": "21.31778",
    "lng": "-100.56583"
  },
  {
    "country": "MX",
    "name": "Colonia Militar",
    "lat": "20.11139",
    "lng": "-98.70306"
  },
  {
    "country": "MX",
    "name": "Coachiti",
    "lat": "20.55944",
    "lng": "-100.58944"
  },
  {
    "country": "MX",
    "name": "Vamos Tamaulipas",
    "lat": "25.98667",
    "lng": "-98.22167"
  },
  {
    "country": "MX",
    "name": "Loma Alta Taxhimay",
    "lat": "19.84222",
    "lng": "-99.40806"
  },
  {
    "country": "MX",
    "name": "Cuaxuxpa",
    "lat": "18.46211",
    "lng": "-97.03556"
  },
  {
    "country": "MX",
    "name": "Atenxoxola",
    "lat": "17.48819",
    "lng": "-99.14285"
  },
  {
    "country": "MX",
    "name": "San Pedro Arriba 3ra. Sección",
    "lat": "19.50083",
    "lng": "-99.55722"
  },
  {
    "country": "MX",
    "name": "Colonia 28 de Mayo (Santa Rosa)",
    "lat": "20.16611",
    "lng": "-98.39"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento y Club de Golf los Encinos",
    "lat": "19.28917",
    "lng": "-99.48"
  },
  {
    "country": "MX",
    "name": "Guadalupe Victoria",
    "lat": "16.405",
    "lng": "-92.5525"
  },
  {
    "country": "MX",
    "name": "El Limón",
    "lat": "16.99556",
    "lng": "-99.3775"
  },
  {
    "country": "MX",
    "name": "Mezapa la Fábrica",
    "lat": "19.17556",
    "lng": "-99.44528"
  },
  {
    "country": "MX",
    "name": "San Jerónimo Yahuiche",
    "lat": "17.10861",
    "lng": "-96.76972"
  },
  {
    "country": "MX",
    "name": "Buenos Aires",
    "lat": "32.42278",
    "lng": "-116.94111"
  },
  {
    "country": "MX",
    "name": "Colonia Antorcha Campesina (Santa Rosa)",
    "lat": "19.68",
    "lng": "-100.52611"
  },
  {
    "country": "MX",
    "name": "Manzana Sexta Parte Centro",
    "lat": "19.5275",
    "lng": "-99.60528"
  },
  {
    "country": "MX",
    "name": "El Pozo",
    "lat": "16.92034",
    "lng": "-92.41166"
  },
  {
    "country": "MX",
    "name": "San Isidro Alta Huerta",
    "lat": "19.72472",
    "lng": "-100.63889"
  },
  {
    "country": "MX",
    "name": "Colonia San Francisco de Asís",
    "lat": "19.57861",
    "lng": "-99.75444"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento la Florida",
    "lat": "20.58667",
    "lng": "-97.42833"
  },
  {
    "country": "MX",
    "name": "Cruztón",
    "lat": "16.76167",
    "lng": "-92.57917"
  },
  {
    "country": "MX",
    "name": "La Cruz",
    "lat": "20.45694",
    "lng": "-100.79583"
  },
  {
    "country": "MX",
    "name": "Artemio Treviño",
    "lat": "25.83528",
    "lng": "-100.14278"
  },
  {
    "country": "MX",
    "name": "La Pimienta",
    "lat": "17.14111",
    "lng": "-92.76222"
  },
  {
    "country": "MX",
    "name": "Geovillas Laureles del Campanario",
    "lat": "21.33056",
    "lng": "-101.92361"
  },
  {
    "country": "MX",
    "name": "Guadalupe Totoltepec",
    "lat": "19.34833",
    "lng": "-99.56417"
  },
  {
    "country": "MX",
    "name": "Plan de Agua Prieta",
    "lat": "16.13111",
    "lng": "-92.79139"
  },
  {
    "country": "MX",
    "name": "José María Morelos (La Yegüería)",
    "lat": "19.86389",
    "lng": "-100.87917"
  },
  {
    "country": "MX",
    "name": "Ejido Cajón Ojo de Agua Número Dos",
    "lat": "22.9",
    "lng": "-105.97139"
  },
  {
    "country": "MX",
    "name": "Huapacal 2da. Sección (Punta Brava)",
    "lat": "18.19722",
    "lng": "-93.17194"
  },
  {
    "country": "MX",
    "name": "Los Parques",
    "lat": "25.78694",
    "lng": "-100.47639"
  },
  {
    "country": "MX",
    "name": "Sitalá",
    "lat": "17.02417",
    "lng": "-92.30694"
  },
  {
    "country": "MX",
    "name": "Atlamajac",
    "lat": "17.55528",
    "lng": "-98.54722"
  },
  {
    "country": "MX",
    "name": "San Antonio Texas",
    "lat": "20.98556",
    "lng": "-101.49"
  },
  {
    "country": "MX",
    "name": "Capitán Felipe Castellanos Díaz (San Pedro)",
    "lat": "17.77306",
    "lng": "-91.1475"
  },
  {
    "country": "MX",
    "name": "Cuautotolapan (San José)",
    "lat": "18.43299",
    "lng": "-97.12091"
  },
  {
    "country": "MX",
    "name": "La Fundición (Quinta Manzana)",
    "lat": "19.45528",
    "lng": "-100.30361"
  },
  {
    "country": "MX",
    "name": "Parque de Poblamiento Solidaridad",
    "lat": "21.15194",
    "lng": "-98.38611"
  },
  {
    "country": "MX",
    "name": "Tanamacoyan",
    "lat": "19.89056",
    "lng": "-97.42972"
  },
  {
    "country": "MX",
    "name": "El Encanto",
    "lat": "14.73083",
    "lng": "-92.41028"
  },
  {
    "country": "MX",
    "name": "San José del Jagüey",
    "lat": "20.73722",
    "lng": "-99.92444"
  },
  {
    "country": "MX",
    "name": "Colonia Adolfo Ruiz Cortines (Colonia Obrera)",
    "lat": "18.25694",
    "lng": "-96.16139"
  },
  {
    "country": "MX",
    "name": "Colonia Guadalupe Victoria",
    "lat": "19.49917",
    "lng": "-98.91917"
  },
  {
    "country": "MX",
    "name": "Barrio Bordo Nuevo",
    "lat": "19.37917",
    "lng": "-99.67333"
  },
  {
    "country": "MX",
    "name": "Shoctic",
    "lat": "17.22361",
    "lng": "-92.48806"
  },
  {
    "country": "MX",
    "name": "San Pedro Tulixtlahuaca",
    "lat": "16.53972",
    "lng": "-98.03472"
  },
  {
    "country": "MX",
    "name": "Santana 2da. Sección B (La Palma)",
    "lat": "18.17505",
    "lng": "-93.4318"
  },
  {
    "country": "MX",
    "name": "El Refugio",
    "lat": "22.37028",
    "lng": "-101.76083"
  },
  {
    "country": "MX",
    "name": "Zacapalco",
    "lat": "18.63917",
    "lng": "-98.95944"
  },
  {
    "country": "MX",
    "name": "Zapotitlán Tablas",
    "lat": "17.42417",
    "lng": "-98.78056"
  },
  {
    "country": "MX",
    "name": "Sebastián Lerdo de Tejada",
    "lat": "23.95444",
    "lng": "-104.63639"
  },
  {
    "country": "MX",
    "name": "La Cuchilla (Extramuros de Tesistán)",
    "lat": "20.78",
    "lng": "-103.46222"
  },
  {
    "country": "MX",
    "name": "Colonia Agrícola Analco",
    "lat": "19.34972",
    "lng": "-99.475"
  },
  {
    "country": "MX",
    "name": "Rancho Chico",
    "lat": "18.74667",
    "lng": "-97.665"
  },
  {
    "country": "MX",
    "name": "Buenos Aires",
    "lat": "20.15333",
    "lng": "-97.74833"
  },
  {
    "country": "MX",
    "name": "Paso Blanco",
    "lat": "21.97361",
    "lng": "-102.31694"
  },
  {
    "country": "MX",
    "name": "Crescencio Morales (San Mateo)",
    "lat": "19.49111",
    "lng": "-100.24306"
  },
  {
    "country": "MX",
    "name": "Campo la Arrocera",
    "lat": "25.845",
    "lng": "-108.91833"
  },
  {
    "country": "MX",
    "name": "Pueblo Nuevo",
    "lat": "23.99111",
    "lng": "-106.95639"
  },
  {
    "country": "MX",
    "name": "San Andrés Ocotepec",
    "lat": "18.90361",
    "lng": "-100.04667"
  },
  {
    "country": "MX",
    "name": "San José la Hacienda",
    "lat": "16.97944",
    "lng": "-99.06667"
  },
  {
    "country": "MX",
    "name": "Los Reyes Tlanechicolpan",
    "lat": "19.0325",
    "lng": "-98.3525"
  },
  {
    "country": "MX",
    "name": "Rancho Bellavista [Fraccionamiento]",
    "lat": "20.60667",
    "lng": "-100.44972"
  },
  {
    "country": "MX",
    "name": "El Cerrito",
    "lat": "19.35528",
    "lng": "-99.34833"
  },
  {
    "country": "MX",
    "name": "Apatauyan",
    "lat": "19.79911",
    "lng": "-97.4444"
  },
  {
    "country": "MX",
    "name": "Solalpan 1ra. Sección",
    "lat": "19.49278",
    "lng": "-99.57444"
  },
  {
    "country": "MX",
    "name": "San José Neria",
    "lat": "18.99333",
    "lng": "-96.99917"
  },
  {
    "country": "MX",
    "name": "Paintla",
    "lat": "18.50333",
    "lng": "-99.65528"
  },
  {
    "country": "MX",
    "name": "Colonia Ignacio Allende",
    "lat": "19.35667",
    "lng": "-97.78389"
  },
  {
    "country": "MX",
    "name": "Santa Catarina Roatina",
    "lat": "16.27917",
    "lng": "-96.51778"
  },
  {
    "country": "MX",
    "name": "San Bernabé de las Canteras",
    "lat": "19.76639",
    "lng": "-101.16333"
  },
  {
    "country": "MX",
    "name": "Villa de las Flores",
    "lat": "20.57639",
    "lng": "-97.43361"
  },
  {
    "country": "MX",
    "name": "Villas del Campo",
    "lat": "19.18028",
    "lng": "-99.61222"
  },
  {
    "country": "MX",
    "name": "El Llano Santa María",
    "lat": "19.78389",
    "lng": "-99.08639"
  },
  {
    "country": "MX",
    "name": "Centro de Readaptación Social",
    "lat": "18.13667",
    "lng": "-94.51861"
  },
  {
    "country": "MX",
    "name": "Tepetates",
    "lat": "21.95667",
    "lng": "-102.32167"
  },
  {
    "country": "MX",
    "name": "El Jazmín",
    "lat": "20.34444",
    "lng": "-100.04667"
  },
  {
    "country": "MX",
    "name": "La Cabecera Concepción",
    "lat": "19.70361",
    "lng": "-99.94111"
  },
  {
    "country": "MX",
    "name": "Loma de San Miguel",
    "lat": "19.34194",
    "lng": "-99.79167"
  },
  {
    "country": "MX",
    "name": "Zona Urbana Ejidal",
    "lat": "18.5325",
    "lng": "-96.58917"
  },
  {
    "country": "MX",
    "name": "Sebastián Lerdo de Tejada",
    "lat": "19.38972",
    "lng": "-99.72528"
  },
  {
    "country": "MX",
    "name": "El Porvenir (El Porvenir de Arriba)",
    "lat": "25.77444",
    "lng": "-103.32528"
  },
  {
    "country": "MX",
    "name": "San José Atoyatenco",
    "lat": "19.25083",
    "lng": "-98.35528"
  },
  {
    "country": "MX",
    "name": "Chula Vista",
    "lat": "27.04083",
    "lng": "-103.36611"
  },
  {
    "country": "MX",
    "name": "Galaxias Toluca",
    "lat": "19.39806",
    "lng": "-99.65"
  },
  {
    "country": "MX",
    "name": "Monclova Primer Sector",
    "lat": "25.81472",
    "lng": "-100.40306"
  },
  {
    "country": "MX",
    "name": "San Antonio Coyahuacán",
    "lat": "17.86194",
    "lng": "-98.68"
  },
  {
    "country": "MX",
    "name": "Tikinmul",
    "lat": "19.76611",
    "lng": "-90.22306"
  },
  {
    "country": "MX",
    "name": "Aguas Calientes",
    "lat": "16.8425",
    "lng": "-99.64056"
  },
  {
    "country": "MX",
    "name": "Salvador Urbina",
    "lat": "16.63556",
    "lng": "-93.00278"
  },
  {
    "country": "MX",
    "name": "Pénjamo",
    "lat": "18.43444",
    "lng": "-93.09306"
  },
  {
    "country": "MX",
    "name": "San Martín Ahuatepec",
    "lat": "19.68139",
    "lng": "-98.72806"
  },
  {
    "country": "MX",
    "name": "Héroes de Chapultepec (Rodeo de San Antonio)",
    "lat": "20.31111",
    "lng": "-101.5025"
  },
  {
    "country": "MX",
    "name": "Barrio San Miguel Dorami",
    "lat": "19.44622",
    "lng": "-99.34296"
  },
  {
    "country": "MX",
    "name": "Santa Ana",
    "lat": "18.9875",
    "lng": "-99.41333"
  },
  {
    "country": "MX",
    "name": "Santa Martha Hidalgo",
    "lat": "18.985",
    "lng": "-98.32444"
  },
  {
    "country": "MX",
    "name": "Cuonetzingo",
    "lat": "17.52722",
    "lng": "-99.26583"
  },
  {
    "country": "MX",
    "name": "Ladrilleras del Refugio",
    "lat": "21.08472",
    "lng": "-101.55361"
  },
  {
    "country": "MX",
    "name": "La Candelaria",
    "lat": "17.21833",
    "lng": "-95.93306"
  },
  {
    "country": "MX",
    "name": "Habanero 1ra. Sección (Venustiano Carranza)",
    "lat": "17.96778",
    "lng": "-93.32806"
  },
  {
    "country": "MX",
    "name": "Nueva Tenochtitlán (Rizo de Oro)",
    "lat": "16.47639",
    "lng": "-94.08056"
  },
  {
    "country": "MX",
    "name": "Buena Vista (Apasco)",
    "lat": "17.65556",
    "lng": "-92.44389"
  },
  {
    "country": "MX",
    "name": "Cañada del Tabaco",
    "lat": "21.70972",
    "lng": "-105.35417"
  },
  {
    "country": "MX",
    "name": "San Martín Tlamapa",
    "lat": "18.9775",
    "lng": "-98.39694"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Santa Cruz",
    "lat": "17.97194",
    "lng": "-94.895"
  },
  {
    "country": "MX",
    "name": "San Antonio las Palmas",
    "lat": "17.67167",
    "lng": "-96.09083"
  },
  {
    "country": "MX",
    "name": "Gobernadores",
    "lat": "18.24694",
    "lng": "-93.18528"
  },
  {
    "country": "MX",
    "name": "San José de Cervera",
    "lat": "20.96778",
    "lng": "-101.3025"
  },
  {
    "country": "MX",
    "name": "Cristóbal Colón",
    "lat": "17.19194",
    "lng": "-91.62917"
  },
  {
    "country": "MX",
    "name": "Vista Hermosa",
    "lat": "17.79639",
    "lng": "-97.75694"
  },
  {
    "country": "MX",
    "name": "Los Cues",
    "lat": "20.50194",
    "lng": "-100.26417"
  },
  {
    "country": "MX",
    "name": "Estación Obispo",
    "lat": "24.29306",
    "lng": "-107.15944"
  },
  {
    "country": "MX",
    "name": "Hueyitlalpan",
    "lat": "17.67528",
    "lng": "-99.29556"
  },
  {
    "country": "MX",
    "name": "Colonia Azteca",
    "lat": "19.07806",
    "lng": "-99.65417"
  },
  {
    "country": "MX",
    "name": "Colonia Aeropuerto",
    "lat": "17.62028",
    "lng": "-101.45889"
  },
  {
    "country": "MX",
    "name": "El Venado",
    "lat": "20.06472",
    "lng": "-98.75861"
  },
  {
    "country": "MX",
    "name": "San Lorenzo Joya de Rodríguez",
    "lat": "19.05444",
    "lng": "-97.85333"
  },
  {
    "country": "MX",
    "name": "Joaquín Miguel Gutiérrez (Margaritas)",
    "lat": "15.55028",
    "lng": "-93.09306"
  },
  {
    "country": "MX",
    "name": "Guadalupe Coté",
    "lat": "19.61075",
    "lng": "-99.98499"
  },
  {
    "country": "MX",
    "name": "Valle Verde",
    "lat": "19.4725",
    "lng": "-100.35528"
  },
  {
    "country": "MX",
    "name": "Nueva División del Bayo (Guatemala)",
    "lat": "17.84",
    "lng": "-92.48889"
  },
  {
    "country": "MX",
    "name": "Gómez Poniente",
    "lat": "19.7725",
    "lng": "-97.48694"
  },
  {
    "country": "MX",
    "name": "La Trinidad Tianguismanalco",
    "lat": "18.89417",
    "lng": "-98.0325"
  },
  {
    "country": "MX",
    "name": "Temalacaco",
    "lat": "21.41389",
    "lng": "-98.84694"
  },
  {
    "country": "MX",
    "name": "Chiquinshulum",
    "lat": "17.07194",
    "lng": "-92.59806"
  },
  {
    "country": "MX",
    "name": "La Y",
    "lat": "19.39806",
    "lng": "-99.58972"
  },
  {
    "country": "MX",
    "name": "Narciso Mendoza",
    "lat": "18.87417",
    "lng": "-98.96972"
  },
  {
    "country": "MX",
    "name": "Cucharas",
    "lat": "21.61611",
    "lng": "-97.66139"
  },
  {
    "country": "MX",
    "name": "Santa Lucía Potrerillo",
    "lat": "18.96917",
    "lng": "-97.02417"
  },
  {
    "country": "MX",
    "name": "San Isidro",
    "lat": "25.97722",
    "lng": "-109.25111"
  },
  {
    "country": "MX",
    "name": "Chicumtantic",
    "lat": "16.86556",
    "lng": "-92.60528"
  },
  {
    "country": "MX",
    "name": "Matzam",
    "lat": "16.78917",
    "lng": "-92.47694"
  },
  {
    "country": "MX",
    "name": "Primero de Mayo",
    "lat": "19.08167",
    "lng": "-98.09778"
  },
  {
    "country": "MX",
    "name": "San Lorenzo",
    "lat": "19.98917",
    "lng": "-101.64583"
  },
  {
    "country": "MX",
    "name": "Paseos de las Haciendas [Fraccionamiento]",
    "lat": "21.99222",
    "lng": "-102.34361"
  },
  {
    "country": "MX",
    "name": "Las Margaritas",
    "lat": "27.61833",
    "lng": "-113.45361"
  },
  {
    "country": "MX",
    "name": "El Tzay",
    "lat": "16.86361",
    "lng": "-92.31222"
  },
  {
    "country": "MX",
    "name": "Melitón Albáñez Domínguez",
    "lat": "23.66139",
    "lng": "-110.42083"
  },
  {
    "country": "MX",
    "name": "El Muey",
    "lat": "20.50278",
    "lng": "-103.22083"
  },
  {
    "country": "MX",
    "name": "La Candelaria Teotlalpan",
    "lat": "19.33306",
    "lng": "-98.22556"
  },
  {
    "country": "MX",
    "name": "San Isidro Monjas",
    "lat": "17.00167",
    "lng": "-96.74861"
  },
  {
    "country": "MX",
    "name": "Hacienda Sotavento",
    "lat": "19.13361",
    "lng": "-96.18139"
  },
  {
    "country": "MX",
    "name": "El CERESO",
    "lat": "21.02222",
    "lng": "-101.68917"
  },
  {
    "country": "MX",
    "name": "Texmola",
    "lat": "18.93972",
    "lng": "-97.24389"
  },
  {
    "country": "MX",
    "name": "Las Flechas",
    "lat": "16.70028",
    "lng": "-93.02639"
  },
  {
    "country": "MX",
    "name": "Llano de la Lima",
    "lat": "14.86596",
    "lng": "-92.29714"
  },
  {
    "country": "MX",
    "name": "Colonia Veintitrés de Mayo",
    "lat": "21.01",
    "lng": "-102.19778"
  },
  {
    "country": "MX",
    "name": "La Lima",
    "lat": "21.92722",
    "lng": "-99.10278"
  },
  {
    "country": "MX",
    "name": "Casa Nueva",
    "lat": "19.83333",
    "lng": "-99.20944"
  },
  {
    "country": "MX",
    "name": "Ocotlán de Venustiano Carranza",
    "lat": "18.79111",
    "lng": "-97.66917"
  },
  {
    "country": "MX",
    "name": "Mezquitic de la Magdalena",
    "lat": "21.22111",
    "lng": "-102.30444"
  },
  {
    "country": "MX",
    "name": "Praxedis de Guerrero",
    "lat": "16.72",
    "lng": "-96.64"
  },
  {
    "country": "MX",
    "name": "Arroyo Choápam",
    "lat": "17.97028",
    "lng": "-96.15722"
  },
  {
    "country": "MX",
    "name": "Martínez Domínguez",
    "lat": "22.74806",
    "lng": "-102.48111"
  },
  {
    "country": "MX",
    "name": "San Francisco Atotonilco",
    "lat": "20.19472",
    "lng": "-98.15167"
  },
  {
    "country": "MX",
    "name": "Santa Clara",
    "lat": "19.69889",
    "lng": "-98.57778"
  },
  {
    "country": "MX",
    "name": "Laguna de Tabernillas (El Resbaloso)",
    "lat": "19.46139",
    "lng": "-99.87833"
  },
  {
    "country": "MX",
    "name": "San Martín",
    "lat": "19.7825",
    "lng": "-97.34028"
  },
  {
    "country": "MX",
    "name": "Istaro",
    "lat": "19.32806",
    "lng": "-101.75361"
  },
  {
    "country": "MX",
    "name": "Xocoyolzintla",
    "lat": "17.71278",
    "lng": "-98.98194"
  },
  {
    "country": "MX",
    "name": "Camelia Roja",
    "lat": "18.02833",
    "lng": "-96.20806"
  },
  {
    "country": "MX",
    "name": "El Palmar",
    "lat": "19.13972",
    "lng": "-97.05306"
  },
  {
    "country": "MX",
    "name": "Los Cristales (Talican)",
    "lat": "19.87237",
    "lng": "-97.59424"
  },
  {
    "country": "MX",
    "name": "Emilio Carranza (Santa Cruz)",
    "lat": "19.71278",
    "lng": "-97.65278"
  },
  {
    "country": "MX",
    "name": "Benito Juárez II (San Martín)",
    "lat": "18.14056",
    "lng": "-96.46139"
  },
  {
    "country": "MX",
    "name": "Colonia el Pedregal",
    "lat": "18.34961",
    "lng": "-99.85642"
  },
  {
    "country": "MX",
    "name": "Primera de Analco",
    "lat": "18.9025",
    "lng": "-99.77556"
  },
  {
    "country": "MX",
    "name": "San Lucas",
    "lat": "18.97806",
    "lng": "-99.66056"
  },
  {
    "country": "MX",
    "name": "Ixticpan",
    "lat": "19.81419",
    "lng": "-97.34454"
  },
  {
    "country": "MX",
    "name": "Arenal Santa Ana",
    "lat": "17.78972",
    "lng": "-95.77028"
  },
  {
    "country": "MX",
    "name": "Jolotichán",
    "lat": "16.75222",
    "lng": "-98.73056"
  },
  {
    "country": "MX",
    "name": "Colonia Doctor Gustavo Baz",
    "lat": "19.41056",
    "lng": "-99.92167"
  },
  {
    "country": "MX",
    "name": "Zaragoza",
    "lat": "19.31861",
    "lng": "-98.26389"
  },
  {
    "country": "MX",
    "name": "Barrio de la Barranca",
    "lat": "19.43583",
    "lng": "-99.55833"
  },
  {
    "country": "MX",
    "name": "Tierras Coloradas",
    "lat": "20.72889",
    "lng": "-102.86083"
  },
  {
    "country": "MX",
    "name": "Fracción Milpillas",
    "lat": "22.22778",
    "lng": "-100.96417"
  },
  {
    "country": "MX",
    "name": "Colonia Pedro María Anaya",
    "lat": "20.52611",
    "lng": "-100.87778"
  },
  {
    "country": "MX",
    "name": "Soyatlán de Afuera",
    "lat": "19.69083",
    "lng": "-103.28278"
  },
  {
    "country": "MX",
    "name": "La Rosa",
    "lat": "19.48519",
    "lng": "-99.32984"
  },
  {
    "country": "MX",
    "name": "Arroyo de Enmedio",
    "lat": "18.4975",
    "lng": "-96.54722"
  },
  {
    "country": "MX",
    "name": "Ninguno [CERESO]",
    "lat": "20.67361",
    "lng": "-100.36028"
  },
  {
    "country": "MX",
    "name": "Querendas",
    "lat": "18.3425",
    "lng": "-100.63444"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Xaltetela",
    "lat": "19.87417",
    "lng": "-97.58083"
  },
  {
    "country": "MX",
    "name": "El Chinaco (El Pujido)",
    "lat": "20.52222",
    "lng": "-100.91972"
  },
  {
    "country": "MX",
    "name": "Ex-Hacienda de Guadalupe",
    "lat": "19.80889",
    "lng": "-98.9725"
  },
  {
    "country": "MX",
    "name": "Unidad Habitacional 10 de Abril",
    "lat": "18.75444",
    "lng": "-98.91611"
  },
  {
    "country": "MX",
    "name": "Colonia los Aguiluchos",
    "lat": "19.72611",
    "lng": "-99.09028"
  },
  {
    "country": "MX",
    "name": "Miguel Valdez Quintero (El Corazón)",
    "lat": "24.49417",
    "lng": "-107.31778"
  },
  {
    "country": "MX",
    "name": "Toxtla",
    "lat": "20.06632",
    "lng": "-97.94748"
  },
  {
    "country": "MX",
    "name": "San José Ozumba",
    "lat": "19.23306",
    "lng": "-97.72833"
  },
  {
    "country": "MX",
    "name": "San Miguel Papaxtla",
    "lat": "19.06278",
    "lng": "-98.39"
  },
  {
    "country": "MX",
    "name": "Monte Alegre",
    "lat": "19.9825",
    "lng": "-99.34139"
  },
  {
    "country": "MX",
    "name": "Salvador Rosas Magallón",
    "lat": "31.90139",
    "lng": "-116.54778"
  },
  {
    "country": "MX",
    "name": "Barrio de San Juan",
    "lat": "19.4142",
    "lng": "-99.53717"
  },
  {
    "country": "MX",
    "name": "La Loma de los Negritos",
    "lat": "21.87056",
    "lng": "-102.35"
  },
  {
    "country": "MX",
    "name": "Villa Hermosa (Las Pozas)",
    "lat": "17.63361",
    "lng": "-101.46639"
  },
  {
    "country": "MX",
    "name": "Cerro de San Francisco",
    "lat": "19.37038",
    "lng": "-99.35162"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento la Virgen",
    "lat": "19.32306",
    "lng": "-98.27389"
  },
  {
    "country": "MX",
    "name": "Tlaltempanapa",
    "lat": "17.73611",
    "lng": "-99.17722"
  },
  {
    "country": "MX",
    "name": "Guadalupe Victoria",
    "lat": "19.55972",
    "lng": "-97.66"
  },
  {
    "country": "MX",
    "name": "Eureka y Belén",
    "lat": "17.55968",
    "lng": "-92.92899"
  },
  {
    "country": "MX",
    "name": "Paseo de San Javier",
    "lat": "25.73972",
    "lng": "-100.13444"
  },
  {
    "country": "MX",
    "name": "La Península",
    "lat": "17.94347",
    "lng": "-93.36148"
  },
  {
    "country": "MX",
    "name": "El Porvenir I",
    "lat": "19.31694",
    "lng": "-99.72889"
  },
  {
    "country": "MX",
    "name": "Ejido Pátzcuaro",
    "lat": "32.35139",
    "lng": "-115.06583"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento las Liebres",
    "lat": "20.6475",
    "lng": "-101.39556"
  },
  {
    "country": "MX",
    "name": "Chixtontic",
    "lat": "16.8908",
    "lng": "-92.45793"
  },
  {
    "country": "MX",
    "name": "La Cañada",
    "lat": "19.48639",
    "lng": "-99.59889"
  },
  {
    "country": "MX",
    "name": "Santiago Tepeticpac",
    "lat": "19.33476",
    "lng": "-98.22692"
  },
  {
    "country": "MX",
    "name": "Gaviotas Sur (El Cedral)",
    "lat": "17.95373",
    "lng": "-92.89071"
  },
  {
    "country": "MX",
    "name": "Lázaro Cárdenas (El Empalme)",
    "lat": "18.93222",
    "lng": "-99.02528"
  },
  {
    "country": "MX",
    "name": "Barrio de Canales",
    "lat": "19.37333",
    "lng": "-99.37556"
  },
  {
    "country": "MX",
    "name": "Cozotlán Norte",
    "lat": "19.70833",
    "lng": "-98.86"
  },
  {
    "country": "MX",
    "name": "Encrucijada 3ra. Sección (Las Calzadas)",
    "lat": "18.25491",
    "lng": "-93.55619"
  },
  {
    "country": "MX",
    "name": "Chichicastle 1ra. Sección",
    "lat": "18.30417",
    "lng": "-92.43139"
  },
  {
    "country": "MX",
    "name": "Corriente 1ra. Sección",
    "lat": "18.15767",
    "lng": "-92.99372"
  },
  {
    "country": "MX",
    "name": "Tzintzimeo",
    "lat": "19.87028",
    "lng": "-100.97778"
  },
  {
    "country": "MX",
    "name": "Francisco Sarabia",
    "lat": "16.2475",
    "lng": "-91.96278"
  },
  {
    "country": "MX",
    "name": "Francisco Rueda",
    "lat": "17.82917",
    "lng": "-93.93389"
  },
  {
    "country": "MX",
    "name": "Agua Zarca",
    "lat": "15.63417",
    "lng": "-92.14472"
  },
  {
    "country": "MX",
    "name": "Tapias de Santa Cruz (Pedro Ruiz González)",
    "lat": "23.18889",
    "lng": "-103.13111"
  },
  {
    "country": "MX",
    "name": "Rincón de Cedeños (Rincón de Dolores)",
    "lat": "19.67806",
    "lng": "-100.57639"
  },
  {
    "country": "MX",
    "name": "Piletas",
    "lat": "19.58806",
    "lng": "-96.97861"
  },
  {
    "country": "MX",
    "name": "El Sauz de Abajo",
    "lat": "20.075",
    "lng": "-102.26833"
  },
  {
    "country": "MX",
    "name": "Villa de los Niños",
    "lat": "20.40667",
    "lng": "-103.54167"
  },
  {
    "country": "MX",
    "name": "Santo Tomás",
    "lat": "18.04194",
    "lng": "-96.51389"
  },
  {
    "country": "MX",
    "name": "San Antonio",
    "lat": "19.75611",
    "lng": "-97.35694"
  },
  {
    "country": "MX",
    "name": "Norte 1ra. Sección (San Julián)",
    "lat": "18.30139",
    "lng": "-93.20944"
  },
  {
    "country": "MX",
    "name": "Santa Teresita de Don Diego",
    "lat": "20.88",
    "lng": "-100.77861"
  },
  {
    "country": "MX",
    "name": "Mexcala",
    "lat": "18.69556",
    "lng": "-97.16472"
  },
  {
    "country": "MX",
    "name": "Tlacoapa",
    "lat": "17.26361",
    "lng": "-98.74861"
  },
  {
    "country": "MX",
    "name": "Vicente Guerrero",
    "lat": "20.12322",
    "lng": "-97.65417"
  },
  {
    "country": "MX",
    "name": "Colonia 24 de Febrero",
    "lat": "25.64722",
    "lng": "-108.64917"
  },
  {
    "country": "MX",
    "name": "Apas",
    "lat": "16.71066",
    "lng": "-92.79335"
  },
  {
    "country": "MX",
    "name": "Zoquitlán",
    "lat": "17.34194",
    "lng": "-98.94917"
  },
  {
    "country": "MX",
    "name": "Ejido del Tejocote",
    "lat": "19.48474",
    "lng": "-99.27847"
  },
  {
    "country": "MX",
    "name": "Lipuntahuaca",
    "lat": "20.09119",
    "lng": "-97.63026"
  },
  {
    "country": "MX",
    "name": "San Martín Obispo (San Martín San Pedro)",
    "lat": "19.31944",
    "lng": "-100.07472"
  },
  {
    "country": "MX",
    "name": "Taza de Agua Ojo Zarco",
    "lat": "18.78333",
    "lng": "-97.20222"
  },
  {
    "country": "MX",
    "name": "Los Nicolases",
    "lat": "20.85806",
    "lng": "-101.3175"
  },
  {
    "country": "MX",
    "name": "La Estancia",
    "lat": "20.29889",
    "lng": "-98.68944"
  },
  {
    "country": "MX",
    "name": "Muquén",
    "lat": "16.80641",
    "lng": "-92.61006"
  },
  {
    "country": "MX",
    "name": "Tepechicotlán",
    "lat": "17.48317",
    "lng": "-99.41549"
  },
  {
    "country": "MX",
    "name": "El Tepetatal",
    "lat": "19.34581",
    "lng": "-99.77086"
  },
  {
    "country": "MX",
    "name": "Valle de los Girasoles [Fraccionamiento]",
    "lat": "20.42667",
    "lng": "-103.19889"
  },
  {
    "country": "MX",
    "name": "Colonia Isidro Fabela",
    "lat": "19.30056",
    "lng": "-99.52278"
  },
  {
    "country": "MX",
    "name": "El Palmar (San Gabriel)",
    "lat": "16.84556",
    "lng": "-93.01639"
  },
  {
    "country": "MX",
    "name": "Primer Cantón",
    "lat": "15.12056",
    "lng": "-92.44"
  },
  {
    "country": "MX",
    "name": "Puxtla",
    "lat": "18.81",
    "lng": "-98.9825"
  },
  {
    "country": "MX",
    "name": "San Juan Pancoac",
    "lat": "19.14917",
    "lng": "-98.44194"
  },
  {
    "country": "MX",
    "name": "Purísima de Cubos (La Purísima)",
    "lat": "20.60028",
    "lng": "-100.11833"
  },
  {
    "country": "MX",
    "name": "Benito Juárez",
    "lat": "15.055",
    "lng": "-92.19111"
  },
  {
    "country": "MX",
    "name": "El Sibal",
    "lat": "16.98",
    "lng": "-91.49111"
  },
  {
    "country": "MX",
    "name": "La Concepción",
    "lat": "19.69611",
    "lng": "-99.30028"
  },
  {
    "country": "MX",
    "name": "Santa María Urapicho",
    "lat": "19.68139",
    "lng": "-102.11194"
  },
  {
    "country": "MX",
    "name": "Colonia Chalchihuecan",
    "lat": "19.21417",
    "lng": "-96.21444"
  },
  {
    "country": "MX",
    "name": "Ángel Albino Corzo (Guadalupe)",
    "lat": "17.12639",
    "lng": "-93.275"
  },
  {
    "country": "MX",
    "name": "Entronque de Matehuala (El Huizache)",
    "lat": "22.925",
    "lng": "-100.45889"
  },
  {
    "country": "MX",
    "name": "Estación Mogoñé",
    "lat": "16.99472",
    "lng": "-95.03667"
  },
  {
    "country": "MX",
    "name": "El Molino",
    "lat": "19.81333",
    "lng": "-97.58028"
  },
  {
    "country": "MX",
    "name": "San José Cuaro",
    "lat": "19.98833",
    "lng": "-101.25194"
  },
  {
    "country": "MX",
    "name": "Chacoma",
    "lat": "16.87611",
    "lng": "-92.49139"
  },
  {
    "country": "MX",
    "name": "El Potrerillo (Potrerillo del Rincón)",
    "lat": "16.95806",
    "lng": "-98.73083"
  },
  {
    "country": "MX",
    "name": "Gildardo Magaña (Los Ángeles)",
    "lat": "19.54889",
    "lng": "-102.45861"
  },
  {
    "country": "MX",
    "name": "Santiago",
    "lat": "19.81194",
    "lng": "-97.32361"
  },
  {
    "country": "MX",
    "name": "Fermín Rabadán Cervantes",
    "lat": "18.31528",
    "lng": "-99.56722"
  },
  {
    "country": "MX",
    "name": "Colonia Palma",
    "lat": "19.56444",
    "lng": "-99.42417"
  },
  {
    "country": "MX",
    "name": "Goros Número Dos",
    "lat": "25.87694",
    "lng": "-109.04417"
  },
  {
    "country": "MX",
    "name": "Orizaba",
    "lat": "23.9575",
    "lng": "-104.07389"
  },
  {
    "country": "MX",
    "name": "Barrio los Tules",
    "lat": "19.42917",
    "lng": "-100.07472"
  },
  {
    "country": "MX",
    "name": "Majomut",
    "lat": "16.84917",
    "lng": "-92.65944"
  },
  {
    "country": "MX",
    "name": "Usipa",
    "lat": "17.50028",
    "lng": "-92.43806"
  },
  {
    "country": "MX",
    "name": "Gabriel Leyva Solano (Zapotillo Dos)",
    "lat": "25.88306",
    "lng": "-109.00917"
  },
  {
    "country": "MX",
    "name": "Tetecolala",
    "lat": "18.9225",
    "lng": "-99.16278"
  },
  {
    "country": "MX",
    "name": "Vista Hermosa (Cuasinada)",
    "lat": "20.36861",
    "lng": "-100.0125"
  },
  {
    "country": "MX",
    "name": "Ciudad Satélite",
    "lat": "22.11083",
    "lng": "-100.79583"
  },
  {
    "country": "MX",
    "name": "San Isidro",
    "lat": "20.79111",
    "lng": "-103.35111"
  },
  {
    "country": "MX",
    "name": "Monte Largo 1ra. Sección",
    "lat": "17.83567",
    "lng": "-92.60664"
  },
  {
    "country": "MX",
    "name": "San Francisco Tláloc",
    "lat": "19.36972",
    "lng": "-98.47722"
  },
  {
    "country": "MX",
    "name": "Colonia Aviación Autopan",
    "lat": "19.37917",
    "lng": "-99.69278"
  },
  {
    "country": "MX",
    "name": "Paisanos",
    "lat": "22.20361",
    "lng": "-101.03583"
  },
  {
    "country": "MX",
    "name": "San José Villarreal",
    "lat": "19.53278",
    "lng": "-97.8975"
  },
  {
    "country": "MX",
    "name": "Poblado Chulavista (El Chorizo)",
    "lat": "30.74722",
    "lng": "-116.00306"
  },
  {
    "country": "MX",
    "name": "Las Trojas",
    "lat": "20.71111",
    "lng": "-100.78083"
  },
  {
    "country": "MX",
    "name": "Paraje la Pera",
    "lat": "19.38056",
    "lng": "-99.345"
  },
  {
    "country": "MX",
    "name": "Conjunto Habitacional el Trébol",
    "lat": "19.76694",
    "lng": "-101.15472"
  },
  {
    "country": "MX",
    "name": "31 de Octubre",
    "lat": "27.29583",
    "lng": "-110.0375"
  },
  {
    "country": "MX",
    "name": "Estación de Apulco",
    "lat": "20.28611",
    "lng": "-98.3475"
  },
  {
    "country": "MX",
    "name": "San Jerónimo Coaltepec",
    "lat": "20.00389",
    "lng": "-97.86639"
  },
  {
    "country": "MX",
    "name": "La Laguna",
    "lat": "18.79944",
    "lng": "-97.73667"
  },
  {
    "country": "MX",
    "name": "Rio de la Soledad",
    "lat": "20.115",
    "lng": "-98.71194"
  },
  {
    "country": "MX",
    "name": "Tacubaya",
    "lat": "25.68361",
    "lng": "-103.06861"
  },
  {
    "country": "MX",
    "name": "Benito Juárez (La Playita)",
    "lat": "17.93231",
    "lng": "-93.36472"
  },
  {
    "country": "MX",
    "name": "Lázaro Cárdenas (Santana)",
    "lat": "20.225",
    "lng": "-97.59306"
  },
  {
    "country": "MX",
    "name": "Nuevo Pumpuapa (Cereso)",
    "lat": "14.92562",
    "lng": "-92.36533"
  },
  {
    "country": "MX",
    "name": "Ex-Hacienda del Copal",
    "lat": "20.74083",
    "lng": "-101.33528"
  },
  {
    "country": "MX",
    "name": "Déxtho de Victoria",
    "lat": "20.32528",
    "lng": "-99.02389"
  },
  {
    "country": "MX",
    "name": "Javier Rojo Gómez",
    "lat": "25.49472",
    "lng": "-108.3775"
  },
  {
    "country": "MX",
    "name": "Juan del Grijalva",
    "lat": "16.72806",
    "lng": "-92.9775"
  },
  {
    "country": "MX",
    "name": "Colonia Obrera",
    "lat": "15.09806",
    "lng": "-92.49806"
  },
  {
    "country": "MX",
    "name": "San Pablo Huacano",
    "lat": "17.19583",
    "lng": "-93.2075"
  },
  {
    "country": "MX",
    "name": "Jilotzingo",
    "lat": "20.0325",
    "lng": "-97.9025"
  },
  {
    "country": "MX",
    "name": "Cantioc",
    "lat": "17.26222",
    "lng": "-92.40694"
  },
  {
    "country": "MX",
    "name": "Nuevo Michoacán (Estación Riíto)",
    "lat": "32.16611",
    "lng": "-114.96167"
  },
  {
    "country": "MX",
    "name": "Abrevadero",
    "lat": "18.28222",
    "lng": "-95.21444"
  },
  {
    "country": "MX",
    "name": "Tronconal",
    "lat": "18.805",
    "lng": "-98.48361"
  },
  {
    "country": "MX",
    "name": "La Magdalena de los Reyes (La Magdalena)",
    "lat": "19.18972",
    "lng": "-99.41"
  },
  {
    "country": "MX",
    "name": "Temastián (La Cantera)",
    "lat": "21.97722",
    "lng": "-103.525"
  },
  {
    "country": "MX",
    "name": "Polvillos (San Bartolo Quinta Sección)",
    "lat": "19.23611",
    "lng": "-100.08"
  },
  {
    "country": "MX",
    "name": "Cuaxoxpan",
    "lat": "19.80806",
    "lng": "-97.34583"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Praderas de la Venta",
    "lat": "20.53611",
    "lng": "-101"
  },
  {
    "country": "MX",
    "name": "Sibaniljá Pocolum",
    "lat": "16.87639",
    "lng": "-92.46111"
  },
  {
    "country": "MX",
    "name": "Los Condes",
    "lat": "23.83889",
    "lng": "-103.07861"
  },
  {
    "country": "MX",
    "name": "La Playa",
    "lat": "23.06417",
    "lng": "-109.66833"
  },
  {
    "country": "MX",
    "name": "San Pablo de los Gallos",
    "lat": "19.67722",
    "lng": "-99.24611"
  },
  {
    "country": "MX",
    "name": "El Polvorín",
    "lat": "16.57833",
    "lng": "-98.80139"
  },
  {
    "country": "MX",
    "name": "Buena Vista (Puxcatán)",
    "lat": "17.73073",
    "lng": "-92.61996"
  },
  {
    "country": "MX",
    "name": "San Antonio Xoquitla",
    "lat": "19.34056",
    "lng": "-97.165"
  },
  {
    "country": "MX",
    "name": "El Águila (La Mesa)",
    "lat": "19.16694",
    "lng": "-99.40639"
  },
  {
    "country": "MX",
    "name": "Adolfo Moreno",
    "lat": "19.72472",
    "lng": "-97.23806"
  },
  {
    "country": "MX",
    "name": "Mérida",
    "lat": "16.5675",
    "lng": "-93.81722"
  },
  {
    "country": "MX",
    "name": "Nuevo Guerrero",
    "lat": "18.22583",
    "lng": "-100.52583"
  },
  {
    "country": "MX",
    "name": "Colonia las Arboledas",
    "lat": "18.78528",
    "lng": "-98.93972"
  },
  {
    "country": "MX",
    "name": "Morelos",
    "lat": "19.75472",
    "lng": "-97.5775"
  },
  {
    "country": "MX",
    "name": "Cuauhtamingo",
    "lat": "19.76472",
    "lng": "-97.31417"
  },
  {
    "country": "MX",
    "name": "Santa Anita",
    "lat": "17.42583",
    "lng": "-98.71889"
  },
  {
    "country": "MX",
    "name": "Orba (Infiernito)",
    "lat": "25.68944",
    "lng": "-108.36278"
  },
  {
    "country": "MX",
    "name": "Paso de la Mina 2da. Sección (Barrial)",
    "lat": "17.95278",
    "lng": "-93.69083"
  },
  {
    "country": "MX",
    "name": "Ignacio Manuel Altamirano",
    "lat": "19.36722",
    "lng": "-98.58306"
  },
  {
    "country": "MX",
    "name": "Rancho Nuevo de Morelos (De Guadalupe)",
    "lat": "22.34056",
    "lng": "-101.78528"
  },
  {
    "country": "MX",
    "name": "San Isidro Monterrosas",
    "lat": "18.85667",
    "lng": "-97.57528"
  },
  {
    "country": "MX",
    "name": "Villa Rotaria",
    "lat": "17.19444",
    "lng": "-100.66917"
  },
  {
    "country": "MX",
    "name": "Buenavista",
    "lat": "16.24278",
    "lng": "-91.98778"
  },
  {
    "country": "MX",
    "name": "La Amistad",
    "lat": "20.00833",
    "lng": "-99.32028"
  },
  {
    "country": "MX",
    "name": "Atotonilco",
    "lat": "19.94111",
    "lng": "-100.22306"
  },
  {
    "country": "MX",
    "name": "Veintiuno de Agosto",
    "lat": "19.725",
    "lng": "-97.27222"
  },
  {
    "country": "MX",
    "name": "Oriente 6ta. Sección (Los Mulatos)",
    "lat": "18.16722",
    "lng": "-93.23583"
  },
  {
    "country": "MX",
    "name": "Ignacio Allende",
    "lat": "16.52556",
    "lng": "-92.99222"
  },
  {
    "country": "MX",
    "name": "Las Masas (La Luz Masas)",
    "lat": "20.59917",
    "lng": "-101.54278"
  },
  {
    "country": "MX",
    "name": "La Joya",
    "lat": "18.9725",
    "lng": "-99.65278"
  },
  {
    "country": "MX",
    "name": "Rancho Nuevo",
    "lat": "18.58139",
    "lng": "-97.22472"
  },
  {
    "country": "MX",
    "name": "Belisario Domínguez",
    "lat": "17.40611",
    "lng": "-91.98361"
  },
  {
    "country": "MX",
    "name": "Lomas de Tepemecatl",
    "lat": "19.23861",
    "lng": "-99.23944"
  },
  {
    "country": "MX",
    "name": "El Mirador",
    "lat": "18.77139",
    "lng": "-99.34139"
  },
  {
    "country": "MX",
    "name": "Residencial las Olas",
    "lat": "18.11861",
    "lng": "-94.56611"
  },
  {
    "country": "MX",
    "name": "Zoquiapa",
    "lat": "17.54472",
    "lng": "-99.27694"
  },
  {
    "country": "MX",
    "name": "Colonia Reforma Tlalmimilolpan",
    "lat": "19.38806",
    "lng": "-99.48889"
  },
  {
    "country": "MX",
    "name": "San Andrés Enguaro",
    "lat": "20.19472",
    "lng": "-101.23639"
  },
  {
    "country": "MX",
    "name": "Cebadilla 1ra. Sección",
    "lat": "14.86381",
    "lng": "-92.27969"
  },
  {
    "country": "MX",
    "name": "Zaragoza (Puerto de Medina)",
    "lat": "19.87389",
    "lng": "-100.11778"
  },
  {
    "country": "MX",
    "name": "San Andrés de la Cal",
    "lat": "18.95694",
    "lng": "-99.11444"
  },
  {
    "country": "MX",
    "name": "Ixcatla",
    "lat": "17.4225",
    "lng": "-98.99944"
  },
  {
    "country": "MX",
    "name": "Cuauhtémoc",
    "lat": "19.22306",
    "lng": "-97.33833"
  },
  {
    "country": "MX",
    "name": "Las Tazas",
    "lat": "16.75722",
    "lng": "-91.615"
  },
  {
    "country": "MX",
    "name": "Ejido los Huastecos",
    "lat": "21.95917",
    "lng": "-98.65028"
  },
  {
    "country": "MX",
    "name": "Estanzuela",
    "lat": "22.26889",
    "lng": "-101.00806"
  },
  {
    "country": "MX",
    "name": "San José de Abajo",
    "lat": "18.77583",
    "lng": "-96.77722"
  },
  {
    "country": "MX",
    "name": "Álamos Tepetitlán",
    "lat": "19.19619",
    "lng": "-97.43858"
  },
  {
    "country": "MX",
    "name": "San Bernardo",
    "lat": "20.47389",
    "lng": "-101.0975"
  },
  {
    "country": "MX",
    "name": "Loma de los Hoyos",
    "lat": "19.03556",
    "lng": "-102.44278"
  },
  {
    "country": "MX",
    "name": "Atzalán",
    "lat": "19.82472",
    "lng": "-97.44417"
  },
  {
    "country": "MX",
    "name": "Tepeteno de Iturbide",
    "lat": "19.79583",
    "lng": "-97.49722"
  },
  {
    "country": "MX",
    "name": "Ciudad Chemuyil",
    "lat": "20.34861",
    "lng": "-87.35306"
  },
  {
    "country": "MX",
    "name": "Tandzumadz",
    "lat": "21.56528",
    "lng": "-98.98028"
  },
  {
    "country": "MX",
    "name": "Cajelitos",
    "lat": "17.26778",
    "lng": "-99.49306"
  },
  {
    "country": "MX",
    "name": "Huitzmaloc",
    "lat": "18.45639",
    "lng": "-96.94056"
  },
  {
    "country": "MX",
    "name": "Pezmatlán",
    "lat": "19.84664",
    "lng": "-97.48529"
  },
  {
    "country": "MX",
    "name": "Santa Anita",
    "lat": "20.47028",
    "lng": "-100.815"
  },
  {
    "country": "MX",
    "name": "Lázaro Cárdenas",
    "lat": "20.94556",
    "lng": "-103.02222"
  },
  {
    "country": "MX",
    "name": "El Copetillo",
    "lat": "22.14333",
    "lng": "-102.00139"
  },
  {
    "country": "MX",
    "name": "Apalani",
    "lat": "16.85361",
    "lng": "-99.58944"
  },
  {
    "country": "MX",
    "name": "Barrio el Vivero",
    "lat": "19.45306",
    "lng": "-100.03528"
  },
  {
    "country": "MX",
    "name": "El Embarcadero",
    "lat": "16.96417",
    "lng": "-100.00167"
  },
  {
    "country": "MX",
    "name": "Tlacoaxtla",
    "lat": "17.55485",
    "lng": "-99.20081"
  },
  {
    "country": "MX",
    "name": "Tierra Blanca",
    "lat": "19.50667",
    "lng": "-99.58389"
  },
  {
    "country": "MX",
    "name": "La Higuerita (Colonia San Rafael)",
    "lat": "19.61861",
    "lng": "-102.48444"
  },
  {
    "country": "MX",
    "name": "Buen Retiro (El Retiro)",
    "lat": "25.46194",
    "lng": "-108.47833"
  },
  {
    "country": "MX",
    "name": "Colonia Gómez Morín",
    "lat": "31.88167",
    "lng": "-116.54389"
  },
  {
    "country": "MX",
    "name": "Colinas del Sol",
    "lat": "32.40306",
    "lng": "-117.03056"
  },
  {
    "country": "MX",
    "name": "Xochicalco (Cirenio Longares)",
    "lat": "18.78722",
    "lng": "-99.29944"
  },
  {
    "country": "MX",
    "name": "Tierra Blanca",
    "lat": "23.82722",
    "lng": "-103.07667"
  },
  {
    "country": "MX",
    "name": "Zangarro (Zangarro Nuevo)",
    "lat": "20.85806",
    "lng": "-101.27278"
  },
  {
    "country": "MX",
    "name": "Artículo Primero Constitucional",
    "lat": "18.97412",
    "lng": "-98.15848"
  },
  {
    "country": "MX",
    "name": "Álvaro Obregón",
    "lat": "25.51417",
    "lng": "-103.505"
  },
  {
    "country": "MX",
    "name": "Pueblo Nuevo",
    "lat": "18.94806",
    "lng": "-99.58417"
  },
  {
    "country": "MX",
    "name": "Villa Hermosa",
    "lat": "16.93861",
    "lng": "-99.33"
  },
  {
    "country": "MX",
    "name": "Ignacio Zaragoza",
    "lat": "17.53556",
    "lng": "-95.89361"
  },
  {
    "country": "MX",
    "name": "Cala Norte",
    "lat": "19.84778",
    "lng": "-97.42306"
  },
  {
    "country": "MX",
    "name": "Xochitepec",
    "lat": "17.1825",
    "lng": "-99.22639"
  },
  {
    "country": "MX",
    "name": "Colonia la Libertad",
    "lat": "19.18528",
    "lng": "-99.50278"
  },
  {
    "country": "MX",
    "name": "Lomas de San Pablo",
    "lat": "19.2025",
    "lng": "-98.91778"
  },
  {
    "country": "MX",
    "name": "San Pedro Cacahuatepec",
    "lat": "16.815",
    "lng": "-99.66833"
  },
  {
    "country": "MX",
    "name": "Acachapan y Colmena 3ra. Sección",
    "lat": "18.04858",
    "lng": "-92.7775"
  },
  {
    "country": "MX",
    "name": "Ejido Palma (Ejido San Francisco)",
    "lat": "19.56889",
    "lng": "-99.40889"
  },
  {
    "country": "MX",
    "name": "Sinahua",
    "lat": "18.28111",
    "lng": "-100.60028"
  },
  {
    "country": "MX",
    "name": "Colonia Ecológica Asociación de Lucha Social (Lucha Social)",
    "lat": "19.68833",
    "lng": "-100.60917"
  },
  {
    "country": "MX",
    "name": "Coxolico",
    "lat": "18.45104",
    "lng": "-97.02991"
  },
  {
    "country": "MX",
    "name": "Saclamantón",
    "lat": "16.78833",
    "lng": "-92.635"
  },
  {
    "country": "MX",
    "name": "San Antonio el Paso",
    "lat": "20.14722",
    "lng": "-98.61611"
  },
  {
    "country": "MX",
    "name": "Colonia Emiliano Zapata",
    "lat": "19.12417",
    "lng": "-99.58083"
  },
  {
    "country": "MX",
    "name": "Lázaro Cárdenas (La Purísima)",
    "lat": "19.86972",
    "lng": "-101.02306"
  },
  {
    "country": "MX",
    "name": "San Lucas Huarirapeo (La Mesa de San Lucas)",
    "lat": "19.67861",
    "lng": "-100.62389"
  },
  {
    "country": "MX",
    "name": "Miguel Hidalgo 2da. Sección B (La Natividad)",
    "lat": "18.07861",
    "lng": "-93.35056"
  },
  {
    "country": "MX",
    "name": "Colonia Juárez",
    "lat": "19.99583",
    "lng": "-99.14944"
  },
  {
    "country": "MX",
    "name": "San Juan Colón",
    "lat": "18.57722",
    "lng": "-98.55833"
  },
  {
    "country": "MX",
    "name": "Alfredo V. Bonfil (Siete Ejidos)",
    "lat": "25.64306",
    "lng": "-108.23333"
  },
  {
    "country": "MX",
    "name": "San Juan Hueyapan",
    "lat": "20.03",
    "lng": "-98.28194"
  },
  {
    "country": "MX",
    "name": "Paseos del Marqués",
    "lat": "20.60389",
    "lng": "-100.24028"
  },
  {
    "country": "MX",
    "name": "Ixtlilco el Chico",
    "lat": "18.55833",
    "lng": "-98.84694"
  },
  {
    "country": "MX",
    "name": "Ocoxaltepec",
    "lat": "18.935",
    "lng": "-98.7525"
  },
  {
    "country": "MX",
    "name": "Felipe Neri (Cuatepec)",
    "lat": "19.03944",
    "lng": "-98.94361"
  },
  {
    "country": "MX",
    "name": "Cumbres III",
    "lat": "21.92222",
    "lng": "-102.2375"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Villas de la Llave",
    "lat": "18.91583",
    "lng": "-96.99111"
  },
  {
    "country": "MX",
    "name": "San Andrés Playa Encantada (El Podrido)",
    "lat": "16.69222",
    "lng": "-99.63389"
  },
  {
    "country": "MX",
    "name": "Barrio de Ensido",
    "lat": "19.49389",
    "lng": "-99.37444"
  },
  {
    "country": "MX",
    "name": "Pilotos",
    "lat": "22.03722",
    "lng": "-101.95917"
  },
  {
    "country": "MX",
    "name": "Santa Ana",
    "lat": "19.58222",
    "lng": "-100.46889"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Villa Jardín",
    "lat": "20.99167",
    "lng": "-101.85194"
  },
  {
    "country": "MX",
    "name": "Lomas de San Martín",
    "lat": "25.74722",
    "lng": "-100.11972"
  },
  {
    "country": "MX",
    "name": "Tlixco",
    "lat": "18.27389",
    "lng": "-96.99972"
  },
  {
    "country": "MX",
    "name": "Santa Clara del Tule",
    "lat": "19.82389",
    "lng": "-100.82694"
  },
  {
    "country": "MX",
    "name": "San José Viborillas",
    "lat": "20.56778",
    "lng": "-100.63361"
  },
  {
    "country": "MX",
    "name": "Ejido Jesús María",
    "lat": "21.14194",
    "lng": "-100.91167"
  },
  {
    "country": "MX",
    "name": "Colonia Sesenta y Dos",
    "lat": "20.00528",
    "lng": "-99.34583"
  },
  {
    "country": "MX",
    "name": "El Coloso",
    "lat": "19.09778",
    "lng": "-99.59778"
  },
  {
    "country": "MX",
    "name": "San Francisco Jaconá",
    "lat": "17.26278",
    "lng": "-93.0325"
  },
  {
    "country": "MX",
    "name": "Barrio de San Miguel",
    "lat": "19.64333",
    "lng": "-97.12389"
  },
  {
    "country": "MX",
    "name": "Barrio Chiquichuca",
    "lat": "19.32139",
    "lng": "-100.21278"
  },
  {
    "country": "MX",
    "name": "Putlunichuchut (Vista Hermosa)",
    "lat": "20.15593",
    "lng": "-97.61557"
  },
  {
    "country": "MX",
    "name": "Doctor Samuel León Brindis",
    "lat": "17.43528",
    "lng": "-91.93194"
  },
  {
    "country": "MX",
    "name": "Ahuihuiyuco",
    "lat": "17.62958",
    "lng": "-99.22738"
  },
  {
    "country": "MX",
    "name": "Santa Rita",
    "lat": "22.91194",
    "lng": "-102.41833"
  },
  {
    "country": "MX",
    "name": "Catishtic",
    "lat": "16.78028",
    "lng": "-92.73778"
  },
  {
    "country": "MX",
    "name": "San Andrés Cohamiata",
    "lat": "22.18944",
    "lng": "-104.24083"
  },
  {
    "country": "MX",
    "name": "Barrio San Diego",
    "lat": "17.27917",
    "lng": "-97.67417"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento del Magisterio Tulancinguense",
    "lat": "20.07639",
    "lng": "-98.39972"
  },
  {
    "country": "MX",
    "name": "Colonia Obrera",
    "lat": "18.93167",
    "lng": "-99.03889"
  },
  {
    "country": "MX",
    "name": "Banus Vallarta (Verde Vallarta)",
    "lat": "20.71611",
    "lng": "-105.22306"
  },
  {
    "country": "MX",
    "name": "San Juan Tomasquillo Herradura",
    "lat": "19.17222",
    "lng": "-99.40389"
  },
  {
    "country": "MX",
    "name": "Residencial Tajín",
    "lat": "20.59806",
    "lng": "-97.41694"
  },
  {
    "country": "MX",
    "name": "Colonia San Francisco (San Francisco)",
    "lat": "22.30361",
    "lng": "-101.82056"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento la Noria",
    "lat": "25.55722",
    "lng": "-103.34361"
  },
  {
    "country": "MX",
    "name": "Ahuacachahue (Ndog'yo Itún Tichi)",
    "lat": "16.82861",
    "lng": "-98.98556"
  },
  {
    "country": "MX",
    "name": "Progreso",
    "lat": "19.48833",
    "lng": "-97.67722"
  },
  {
    "country": "MX",
    "name": "Banderas",
    "lat": "20.99083",
    "lng": "-97.39361"
  },
  {
    "country": "MX",
    "name": "Ixtahuiata (La Legua)",
    "lat": "19.84389",
    "lng": "-97.33556"
  },
  {
    "country": "MX",
    "name": "Romerillo",
    "lat": "16.76528",
    "lng": "-92.5675"
  },
  {
    "country": "MX",
    "name": "San Isidro las Banderas",
    "lat": "17.23028",
    "lng": "-93.06028"
  },
  {
    "country": "MX",
    "name": "Tepetitán Reyeshogpan de Hidalgo",
    "lat": "20.08361",
    "lng": "-97.49361"
  },
  {
    "country": "MX",
    "name": "La Ibérica (La Gotera)",
    "lat": "19.16472",
    "lng": "-101.91611"
  },
  {
    "country": "MX",
    "name": "Cerritos",
    "lat": "20.35306",
    "lng": "-99.01222"
  },
  {
    "country": "MX",
    "name": "Colonia San Juan",
    "lat": "20.19028",
    "lng": "-99.28278"
  },
  {
    "country": "MX",
    "name": "El Progreso",
    "lat": "20.01917",
    "lng": "-97.36472"
  },
  {
    "country": "MX",
    "name": "Álvaro Obregón (Santa Cruz)",
    "lat": "18.39422",
    "lng": "-92.79982"
  },
  {
    "country": "MX",
    "name": "Las Lomas",
    "lat": "16.98194",
    "lng": "-100.095"
  },
  {
    "country": "MX",
    "name": "Los Bahuises",
    "lat": "27.11667",
    "lng": "-109.46722"
  },
  {
    "country": "MX",
    "name": "Jolochero 2da. Sección",
    "lat": "18.12",
    "lng": "-92.79833"
  },
  {
    "country": "MX",
    "name": "La Soledad",
    "lat": "16.92",
    "lng": "-98.16694"
  },
  {
    "country": "MX",
    "name": "La Calera (Nacimientos)",
    "lat": "20.27528",
    "lng": "-101.57556"
  },
  {
    "country": "MX",
    "name": "El Triunfo de las Tres Maravillas",
    "lat": "15.64694",
    "lng": "-92.15639"
  },
  {
    "country": "MX",
    "name": "Potrerillo",
    "lat": "18.25472",
    "lng": "-93.13472"
  },
  {
    "country": "MX",
    "name": "San Pedro Huitzapula Norte (Huitzapula Norte)",
    "lat": "17.42642",
    "lng": "-98.80588"
  },
  {
    "country": "MX",
    "name": "Tzoeptic",
    "lat": "16.88278",
    "lng": "-92.56806"
  },
  {
    "country": "MX",
    "name": "La Unión Ejido Mexcaltepec",
    "lat": "19.60806",
    "lng": "-97.71056"
  },
  {
    "country": "MX",
    "name": "Francisco Sarabia",
    "lat": "18.96417",
    "lng": "-98.31389"
  },
  {
    "country": "MX",
    "name": "Mitzitón",
    "lat": "16.64639",
    "lng": "-92.54333"
  },
  {
    "country": "MX",
    "name": "Alcozacán",
    "lat": "17.50444",
    "lng": "-99.095"
  },
  {
    "country": "MX",
    "name": "Granadillas (La Colonia)",
    "lat": "21.37972",
    "lng": "-101.90139"
  },
  {
    "country": "MX",
    "name": "Tlahuapa",
    "lat": "17.375",
    "lng": "-98.3375"
  },
  {
    "country": "MX",
    "name": "Plaza Nueva",
    "lat": "18.92944",
    "lng": "-99.43444"
  },
  {
    "country": "MX",
    "name": "La Manga 2da. Sección (El Jobal)",
    "lat": "18.01917",
    "lng": "-92.86944"
  },
  {
    "country": "MX",
    "name": "Los Mancera",
    "lat": "20.47028",
    "lng": "-100.80389"
  },
  {
    "country": "MX",
    "name": "Palo Seco (El Gato)",
    "lat": "22.35417",
    "lng": "-100.19194"
  },
  {
    "country": "MX",
    "name": "Colonia Renacimiento",
    "lat": "16.76278",
    "lng": "-98.18222"
  },
  {
    "country": "MX",
    "name": "Santa Cruz de la Loma (Tepetates)",
    "lat": "20.48806",
    "lng": "-103.54972"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Laureles Eréndira",
    "lat": "19.77222",
    "lng": "-101.13056"
  },
  {
    "country": "MX",
    "name": "Las Nieves",
    "lat": "18.18361",
    "lng": "-98.04611"
  },
  {
    "country": "MX",
    "name": "Colonia Bellavista",
    "lat": "19.2982",
    "lng": "-99.80879"
  },
  {
    "country": "MX",
    "name": "Nicolás Bravo 5ta. Sección (Punta Brava)",
    "lat": "18.27827",
    "lng": "-93.12872"
  },
  {
    "country": "MX",
    "name": "Almoloya",
    "lat": "20.15139",
    "lng": "-98.44861"
  },
  {
    "country": "MX",
    "name": "La Loma",
    "lat": "20.6",
    "lng": "-100.23889"
  },
  {
    "country": "MX",
    "name": "Yibeljoj",
    "lat": "16.9575",
    "lng": "-92.50361"
  },
  {
    "country": "MX",
    "name": "San Pedro Matamoros",
    "lat": "19.36972",
    "lng": "-98.55472"
  },
  {
    "country": "MX",
    "name": "Santa Anita",
    "lat": "32.10083",
    "lng": "-116.86917"
  },
  {
    "country": "MX",
    "name": "Colonia Morelos",
    "lat": "19.89056",
    "lng": "-98.81667"
  },
  {
    "country": "MX",
    "name": "La Mesa (La Mesa de Cedano)",
    "lat": "19.44861",
    "lng": "-100.32722"
  },
  {
    "country": "MX",
    "name": "Ranchería de Pocitos",
    "lat": "19.39389",
    "lng": "-97.75944"
  },
  {
    "country": "MX",
    "name": "San Roque",
    "lat": "19.48028",
    "lng": "-99.96056"
  },
  {
    "country": "MX",
    "name": "Patria Nueva (San José el Contento)",
    "lat": "16.92778",
    "lng": "-92.11361"
  },
  {
    "country": "MX",
    "name": "San Cristóbal Hidalgo",
    "lat": "19.02194",
    "lng": "-97.81028"
  },
  {
    "country": "MX",
    "name": "San Andrés (San Andrés Chichayotla)",
    "lat": "20.92667",
    "lng": "-98.56333"
  },
  {
    "country": "MX",
    "name": "San Antonio Chiverías",
    "lat": "18.65222",
    "lng": "-99.22139"
  },
  {
    "country": "MX",
    "name": "Colonia 3 de Mayo (La Cruz)",
    "lat": "19.98083",
    "lng": "-99.16361"
  },
  {
    "country": "MX",
    "name": "La Glorieta",
    "lat": "19.41154",
    "lng": "-99.38562"
  },
  {
    "country": "MX",
    "name": "Ejido San José Xilatzén",
    "lat": "21.67472",
    "lng": "-98.9275"
  },
  {
    "country": "MX",
    "name": "Villa Hidalgo (El Cubo)",
    "lat": "18.16167",
    "lng": "-100.315"
  },
  {
    "country": "MX",
    "name": "La Magdalena Tenexpan",
    "lat": "19.46333",
    "lng": "-99.58861"
  },
  {
    "country": "MX",
    "name": "Vega del Sol",
    "lat": "17.80972",
    "lng": "-96.21694"
  },
  {
    "country": "MX",
    "name": "Tlanipatla",
    "lat": "17.80806",
    "lng": "-99.45139"
  },
  {
    "country": "MX",
    "name": "San Martín Itunyoso",
    "lat": "17.22806",
    "lng": "-97.88083"
  },
  {
    "country": "MX",
    "name": "Cuchulumtic",
    "lat": "16.77722",
    "lng": "-92.70417"
  },
  {
    "country": "MX",
    "name": "Barrio la Tenería",
    "lat": "19.69361",
    "lng": "-99.79194"
  },
  {
    "country": "MX",
    "name": "San Rafael",
    "lat": "17.22667",
    "lng": "-98.42417"
  },
  {
    "country": "MX",
    "name": "Paso Bonito",
    "lat": "22.32528",
    "lng": "-101.26167"
  },
  {
    "country": "MX",
    "name": "Playa Chica",
    "lat": "18.06139",
    "lng": "-96.51833"
  },
  {
    "country": "MX",
    "name": "Iztacapa",
    "lat": "21.37",
    "lng": "-98.94167"
  },
  {
    "country": "MX",
    "name": "Acatla",
    "lat": "18.74944",
    "lng": "-97.21833"
  },
  {
    "country": "MX",
    "name": "Loma de Guadalupe (La Biznaga)",
    "lat": "19.65219",
    "lng": "-99.36873"
  },
  {
    "country": "MX",
    "name": "Metepec Primero",
    "lat": "20.14167",
    "lng": "-98.43222"
  },
  {
    "country": "MX",
    "name": "Tanhuixco",
    "lat": "19.82056",
    "lng": "-97.46722"
  },
  {
    "country": "MX",
    "name": "Guadalupe Hidalgo",
    "lat": "19.22611",
    "lng": "-98.1875"
  },
  {
    "country": "MX",
    "name": "El Palacio",
    "lat": "19.35139",
    "lng": "-99.35667"
  },
  {
    "country": "MX",
    "name": "Empaque Tarriba",
    "lat": "23.90028",
    "lng": "-106.93111"
  },
  {
    "country": "MX",
    "name": "Zapuyo",
    "lat": "21.35472",
    "lng": "-98.92139"
  },
  {
    "country": "MX",
    "name": "Cerro Armadillo Grande",
    "lat": "17.86611",
    "lng": "-96.30861"
  },
  {
    "country": "MX",
    "name": "Estación Dobladero",
    "lat": "18.115",
    "lng": "-95.76611"
  },
  {
    "country": "MX",
    "name": "Puerto de Providencia",
    "lat": "22.36528",
    "lng": "-101.06556"
  },
  {
    "country": "MX",
    "name": "Estación Capomas",
    "lat": "25.60111",
    "lng": "-108.22361"
  },
  {
    "country": "MX",
    "name": "Los Pinos",
    "lat": "18.44389",
    "lng": "-95.24333"
  },
  {
    "country": "MX",
    "name": "Huixcolotla",
    "lat": "18.66556",
    "lng": "-96.4975"
  },
  {
    "country": "MX",
    "name": "Colonia Lázaro Cárdenas",
    "lat": "19.44611",
    "lng": "-98.90472"
  },
  {
    "country": "MX",
    "name": "San Miguel Tenango",
    "lat": "19.90877",
    "lng": "-97.93474"
  },
  {
    "country": "MX",
    "name": "El Calvario",
    "lat": "17.2175",
    "lng": "-92.55694"
  },
  {
    "country": "MX",
    "name": "José Refugio Salcido",
    "lat": "23.96444",
    "lng": "-104.51806"
  },
  {
    "country": "MX",
    "name": "José María Morelos (San José)",
    "lat": "19.6825",
    "lng": "-98.57639"
  },
  {
    "country": "MX",
    "name": "Los Encinos",
    "lat": "19.17917",
    "lng": "-98.39833"
  },
  {
    "country": "MX",
    "name": "Privada del Álamo",
    "lat": "20.09833",
    "lng": "-98.70028"
  },
  {
    "country": "MX",
    "name": "Cuapinolito (Azulillo)",
    "lat": "15.82194",
    "lng": "-96.31833"
  },
  {
    "country": "MX",
    "name": "Los Dulces Nombres",
    "lat": "20.64806",
    "lng": "-100.96472"
  },
  {
    "country": "MX",
    "name": "Colonia Obrera",
    "lat": "19.22944",
    "lng": "-97.7975"
  },
  {
    "country": "MX",
    "name": "Sección 23",
    "lat": "19.78778",
    "lng": "-97.37917"
  },
  {
    "country": "MX",
    "name": "Mixtlalcingo",
    "lat": "18.80333",
    "lng": "-98.90028"
  },
  {
    "country": "MX",
    "name": "Zoyatitla",
    "lat": "19.82343",
    "lng": "-97.81831"
  },
  {
    "country": "MX",
    "name": "Tonalapan",
    "lat": "18.46833",
    "lng": "-95.22"
  },
  {
    "country": "MX",
    "name": "Gabriel Hernández (Mancinas)",
    "lat": "23.81167",
    "lng": "-104.02444"
  },
  {
    "country": "MX",
    "name": "Higuera de los Vega",
    "lat": "25.655",
    "lng": "-107.95778"
  },
  {
    "country": "MX",
    "name": "San Isidro Xoteapan (San Isidro Texcaltitán)",
    "lat": "18.46778",
    "lng": "-95.23806"
  },
  {
    "country": "MX",
    "name": "La Luz de Juárez",
    "lat": "17.535",
    "lng": "-98.34833"
  },
  {
    "country": "MX",
    "name": "Colonia Aquiles Córdoba Morán",
    "lat": "19.70667",
    "lng": "-100.53528"
  },
  {
    "country": "MX",
    "name": "Banderas (Guatacalca 2da. Sección)",
    "lat": "18.15167",
    "lng": "-92.89881"
  },
  {
    "country": "MX",
    "name": "Ejido Hidalgo",
    "lat": "22.30083",
    "lng": "-102.03861"
  },
  {
    "country": "MX",
    "name": "Maya Tecún I",
    "lat": "19.15361",
    "lng": "-90.50556"
  },
  {
    "country": "MX",
    "name": "Tepozcuautla",
    "lat": "17.62222",
    "lng": "-99.22778"
  },
  {
    "country": "MX",
    "name": "La Providencia",
    "lat": "30.96889",
    "lng": "-116.15861"
  },
  {
    "country": "MX",
    "name": "Barrio la Joya",
    "lat": "19.42",
    "lng": "-100.09972"
  },
  {
    "country": "MX",
    "name": "Loma de San Francisco",
    "lat": "19.28333",
    "lng": "-99.80917"
  },
  {
    "country": "MX",
    "name": "Arimatea",
    "lat": "17.34139",
    "lng": "-91.87639"
  },
  {
    "country": "MX",
    "name": "Las Huertas Tercera Sección",
    "lat": "20.65278",
    "lng": "-101.39306"
  },
  {
    "country": "MX",
    "name": "Francisco Primo de Verdad (Ciénega de Mata)",
    "lat": "21.74472",
    "lng": "-101.82611"
  },
  {
    "country": "MX",
    "name": "Pablo L. Sidar",
    "lat": "17.90028",
    "lng": "-93.02917"
  },
  {
    "country": "MX",
    "name": "San José el Nuevo",
    "lat": "20.44389",
    "lng": "-100.77194"
  },
  {
    "country": "MX",
    "name": "Paso de Núñez (Buenavista)",
    "lat": "18.89472",
    "lng": "-100.94667"
  },
  {
    "country": "MX",
    "name": "San Pedro Cuitlapan",
    "lat": "16.97306",
    "lng": "-98.25167"
  },
  {
    "country": "MX",
    "name": "La Herradura",
    "lat": "21.4425",
    "lng": "-98.94917"
  },
  {
    "country": "MX",
    "name": "Santo Domingo de las Palmas",
    "lat": "16.13667",
    "lng": "-91.32194"
  },
  {
    "country": "MX",
    "name": "El Mogote",
    "lat": "20.16583",
    "lng": "-99.91444"
  },
  {
    "country": "MX",
    "name": "Colonia Wenceslao Labra",
    "lat": "19.82773",
    "lng": "-99.12435"
  },
  {
    "country": "MX",
    "name": "Cementeras del Pital",
    "lat": "20.17694",
    "lng": "-96.89583"
  },
  {
    "country": "MX",
    "name": "Puebla",
    "lat": "16.91583",
    "lng": "-92.50389"
  },
  {
    "country": "MX",
    "name": "Tzopilja",
    "lat": "16.73972",
    "lng": "-92.30917"
  },
  {
    "country": "MX",
    "name": "Tonalixco",
    "lat": "20.23167",
    "lng": "-98.25528"
  },
  {
    "country": "MX",
    "name": "Cerro Grande",
    "lat": "20.23861",
    "lng": "-97.68194"
  },
  {
    "country": "MX",
    "name": "Oriente 1ra. Sección (Santo Domingo)",
    "lat": "18.26417",
    "lng": "-93.20306"
  },
  {
    "country": "MX",
    "name": "Quintana Roo",
    "lat": "16.60667",
    "lng": "-93.56194"
  },
  {
    "country": "MX",
    "name": "El Porvenir",
    "lat": "18.92083",
    "lng": "-96.92583"
  },
  {
    "country": "MX",
    "name": "Barrio del Cajón",
    "lat": "19.39139",
    "lng": "-99.65806"
  },
  {
    "country": "MX",
    "name": "Hidalgo Amajac",
    "lat": "20.905",
    "lng": "-97.62944"
  },
  {
    "country": "MX",
    "name": "Tierra Blanca",
    "lat": "18.97222",
    "lng": "-99.59194"
  },
  {
    "country": "MX",
    "name": "Tomaquilapa",
    "lat": "19.75635",
    "lng": "-97.32161"
  },
  {
    "country": "MX",
    "name": "Licenciado Gustavo Díaz Ordaz (18 de Marzo)",
    "lat": "18.63222",
    "lng": "-91.00278"
  },
  {
    "country": "MX",
    "name": "Zizicazapa",
    "lat": "17.51556",
    "lng": "-99.1525"
  },
  {
    "country": "MX",
    "name": "Sergio Villaseñor",
    "lat": "20.645",
    "lng": "-100.42083"
  },
  {
    "country": "MX",
    "name": "San Miguel del Arenal",
    "lat": "20.99083",
    "lng": "-101.48556"
  },
  {
    "country": "MX",
    "name": "Cuatro Caminos",
    "lat": "18.4913",
    "lng": "-97.12901"
  },
  {
    "country": "MX",
    "name": "La Soledad",
    "lat": "20.16944",
    "lng": "-100.19111"
  },
  {
    "country": "MX",
    "name": "Chiconamel",
    "lat": "21.36806",
    "lng": "-98.71917"
  },
  {
    "country": "MX",
    "name": "San José de Abajo [Unidad Habitacional]",
    "lat": "18.91972",
    "lng": "-96.96361"
  },
  {
    "country": "MX",
    "name": "Patlicha",
    "lat": "17.43944",
    "lng": "-98.72167"
  },
  {
    "country": "MX",
    "name": "San Antonio Xahuento",
    "lat": "19.69167",
    "lng": "-99.10722"
  },
  {
    "country": "MX",
    "name": "Colonia Ángel Bocanegra (Adolfo López Mateos)",
    "lat": "18.92639",
    "lng": "-99.02972"
  },
  {
    "country": "MX",
    "name": "Colonia Hidalgo (El Tecolote)",
    "lat": "22.32972",
    "lng": "-102.03583"
  },
  {
    "country": "MX",
    "name": "Carmen Serdán",
    "lat": "19.03639",
    "lng": "-97.81194"
  },
  {
    "country": "MX",
    "name": "Colonia Guadalupe",
    "lat": "19.93917",
    "lng": "-98.76556"
  },
  {
    "country": "MX",
    "name": "Emiliano Zapata",
    "lat": "15.66917",
    "lng": "-92.23861"
  },
  {
    "country": "MX",
    "name": "San Bernardo Peña Blanca",
    "lat": "20.46167",
    "lng": "-101.4825"
  },
  {
    "country": "MX",
    "name": "Izotepec",
    "lat": "17.585",
    "lng": "-99.95444"
  },
  {
    "country": "MX",
    "name": "Rancho de las Lomas",
    "lat": "17.73972",
    "lng": "-99.24583"
  },
  {
    "country": "MX",
    "name": "San Juan del Río",
    "lat": "16.8825",
    "lng": "-96.16139"
  },
  {
    "country": "MX",
    "name": "Arroyo Chical (Nuevo Arroyo Chicali)",
    "lat": "18.21611",
    "lng": "-96.33667"
  },
  {
    "country": "MX",
    "name": "Buenavista",
    "lat": "17.22556",
    "lng": "-92.52667"
  },
  {
    "country": "MX",
    "name": "Tres Cerros",
    "lat": "16.91556",
    "lng": "-92.47278"
  },
  {
    "country": "MX",
    "name": "Atlamajalcingo del Río",
    "lat": "17.52667",
    "lng": "-98.65556"
  },
  {
    "country": "MX",
    "name": "Xalatlaco",
    "lat": "19.04972",
    "lng": "-97.04111"
  },
  {
    "country": "MX",
    "name": "CERESO Nuevo",
    "lat": "25.89139",
    "lng": "-109.04222"
  },
  {
    "country": "MX",
    "name": "Pascala del Oro",
    "lat": "17.05472",
    "lng": "-98.80972"
  },
  {
    "country": "MX",
    "name": "Ladrilleras de Ocoro",
    "lat": "25.59806",
    "lng": "-108.44944"
  },
  {
    "country": "MX",
    "name": "Puerta del Llano",
    "lat": "20.78528",
    "lng": "-103.46139"
  },
  {
    "country": "MX",
    "name": "El Obraje",
    "lat": "19.72269",
    "lng": "-99.96259"
  },
  {
    "country": "MX",
    "name": "Ignacio Zaragoza",
    "lat": "17.29",
    "lng": "-92.93806"
  },
  {
    "country": "MX",
    "name": "El Refugio",
    "lat": "17.03833",
    "lng": "-99.20056"
  },
  {
    "country": "MX",
    "name": "Majastic",
    "lat": "17.28944",
    "lng": "-92.62833"
  },
  {
    "country": "MX",
    "name": "Las Letras",
    "lat": "20.23083",
    "lng": "-101.43361"
  },
  {
    "country": "MX",
    "name": "El Pozo",
    "lat": "20.6375",
    "lng": "-100.33306"
  },
  {
    "country": "MX",
    "name": "Oriente 2da. Sección (Palma Huaca)",
    "lat": "18.32917",
    "lng": "-93.18528"
  },
  {
    "country": "MX",
    "name": "Molinos",
    "lat": "22.16278",
    "lng": "-102.09472"
  },
  {
    "country": "MX",
    "name": "Maclovio Herrera (Colonia Aviación)",
    "lat": "32.54194",
    "lng": "-116.63611"
  },
  {
    "country": "MX",
    "name": "Cumbre de Barranca Honda",
    "lat": "16.73167",
    "lng": "-98.33667"
  },
  {
    "country": "MX",
    "name": "Colonia Arboledas (San Andrés)",
    "lat": "19.2025",
    "lng": "-99.58083"
  },
  {
    "country": "MX",
    "name": "Fracción San Roque (El Prieto)",
    "lat": "19.68722",
    "lng": "-99.17222"
  },
  {
    "country": "MX",
    "name": "San Cristóbal los Nava",
    "lat": "18.99528",
    "lng": "-97.83194"
  },
  {
    "country": "MX",
    "name": "Lucio Blanco (Los Gavilanes)",
    "lat": "21.11528",
    "lng": "-101.55111"
  },
  {
    "country": "MX",
    "name": "Los Palacios",
    "lat": "14.85718",
    "lng": "-92.25821"
  },
  {
    "country": "MX",
    "name": "Oxeloco",
    "lat": "20.91889",
    "lng": "-98.32556"
  },
  {
    "country": "MX",
    "name": "El Césped",
    "lat": "19.8825",
    "lng": "-100.13972"
  },
  {
    "country": "MX",
    "name": "San Antonio Matlahuacales",
    "lat": "19.75528",
    "lng": "-98.08194"
  },
  {
    "country": "MX",
    "name": "Piedra Blanca",
    "lat": "16.98861",
    "lng": "-95.01278"
  },
  {
    "country": "MX",
    "name": "La Purísima",
    "lat": "20.51444",
    "lng": "-100.6725"
  },
  {
    "country": "MX",
    "name": "Praderas de San Francisco",
    "lat": "25.81833",
    "lng": "-100.4025"
  },
  {
    "country": "MX",
    "name": "Alejo González (Bilbao)",
    "lat": "25.82194",
    "lng": "-103.19472"
  },
  {
    "country": "MX",
    "name": "Colonia Patria Nueva",
    "lat": "20.52833",
    "lng": "-100.87944"
  },
  {
    "country": "MX",
    "name": "Colonia Guadalupana",
    "lat": "20.56667",
    "lng": "-103.21889"
  },
  {
    "country": "MX",
    "name": "Xalticpac",
    "lat": "19.84301",
    "lng": "-97.59556"
  },
  {
    "country": "MX",
    "name": "Santa Ana Nichi Ejido",
    "lat": "19.58441",
    "lng": "-99.98905"
  },
  {
    "country": "MX",
    "name": "Tequila 1ra. Sección (La Aurora)",
    "lat": "17.88",
    "lng": "-92.72306"
  },
  {
    "country": "MX",
    "name": "Primero de Mayo (Chupaderos)",
    "lat": "21.46611",
    "lng": "-101.82722"
  },
  {
    "country": "MX",
    "name": "Prados del Rosario",
    "lat": "21.02194",
    "lng": "-100.3925"
  },
  {
    "country": "MX",
    "name": "San Antonio Bulujib",
    "lat": "16.99667",
    "lng": "-92.29667"
  },
  {
    "country": "MX",
    "name": "San Ignacio",
    "lat": "21.28194",
    "lng": "-100.53722"
  },
  {
    "country": "MX",
    "name": "Colonia los Remedios",
    "lat": "19.73444",
    "lng": "-98.79111"
  },
  {
    "country": "MX",
    "name": "San Antonio de Corrales",
    "lat": "20.74556",
    "lng": "-100.96361"
  },
  {
    "country": "MX",
    "name": "El Salvador (Ranchito San José del Carmen)",
    "lat": "20.2875",
    "lng": "-100.87722"
  },
  {
    "country": "MX",
    "name": "Potrero de los Sánchez (Estación Techa)",
    "lat": "25.11",
    "lng": "-107.90111"
  },
  {
    "country": "MX",
    "name": "Oriente 2da. Sección (San Cayetano)",
    "lat": "18.18667",
    "lng": "-93.22944"
  },
  {
    "country": "MX",
    "name": "Rincón Verde",
    "lat": "19.49639",
    "lng": "-99.29083"
  },
  {
    "country": "MX",
    "name": "La Palmita y Anexos (La Presita)",
    "lat": "24.90917",
    "lng": "-107.45194"
  },
  {
    "country": "MX",
    "name": "San Carlos Autopan",
    "lat": "19.38583",
    "lng": "-99.68722"
  },
  {
    "country": "MX",
    "name": "Patria Nueva",
    "lat": "20.63222",
    "lng": "-100.47694"
  },
  {
    "country": "MX",
    "name": "Zequentic",
    "lat": "16.71694",
    "lng": "-92.82667"
  },
  {
    "country": "MX",
    "name": "Eureka de Media Luna (Eureka)",
    "lat": "25.79889",
    "lng": "-103.37361"
  },
  {
    "country": "MX",
    "name": "San Vicente (Calpulalpan Tercera Manzana)",
    "lat": "20.03722",
    "lng": "-99.64167"
  },
  {
    "country": "MX",
    "name": "Las Yerbitas [Aserradero]",
    "lat": "26.08025",
    "lng": "-106.77969"
  },
  {
    "country": "MX",
    "name": "San José de Bernalejo (El Guayabo)",
    "lat": "20.64",
    "lng": "-101.40139"
  },
  {
    "country": "MX",
    "name": "Buenavista (Matasanos)",
    "lat": "17.10778",
    "lng": "-93.06694"
  },
  {
    "country": "MX",
    "name": "Río Jordán",
    "lat": "17.24611",
    "lng": "-91.93306"
  },
  {
    "country": "MX",
    "name": "Escalerilla Lagunas",
    "lat": "17.37806",
    "lng": "-98.84667"
  },
  {
    "country": "MX",
    "name": "El Mirador",
    "lat": "19.55694",
    "lng": "-97.77194"
  },
  {
    "country": "MX",
    "name": "Cuesta de Laja",
    "lat": "18.29333",
    "lng": "-95.22111"
  },
  {
    "country": "MX",
    "name": "La Sábana",
    "lat": "18.44461",
    "lng": "-92.88411"
  },
  {
    "country": "MX",
    "name": "La Trinidad Chimalpa",
    "lat": "19.32944",
    "lng": "-98.24528"
  },
  {
    "country": "MX",
    "name": "La Colonia",
    "lat": "19.14444",
    "lng": "-98.78667"
  },
  {
    "country": "MX",
    "name": "Playa de la Libertad",
    "lat": "19.08306",
    "lng": "-96.09778"
  },
  {
    "country": "MX",
    "name": "Macutzio",
    "lat": "19.49917",
    "lng": "-100.355"
  },
  {
    "country": "MX",
    "name": "San Lorenzo",
    "lat": "17.58306",
    "lng": "-95.77722"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Riberas de San Jerónimo",
    "lat": "17.1125",
    "lng": "-96.77722"
  },
  {
    "country": "MX",
    "name": "El Silencio",
    "lat": "27.46801",
    "lng": "-113.29987"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Texmalaquilla",
    "lat": "18.94306",
    "lng": "-97.2875"
  },
  {
    "country": "MX",
    "name": "Lomas de Santa Cruz",
    "lat": "18.92444",
    "lng": "-97.73"
  },
  {
    "country": "MX",
    "name": "El Mollejon",
    "lat": "20.54222",
    "lng": "-97.41111"
  },
  {
    "country": "MX",
    "name": "Tacuba Nueva",
    "lat": "17.09028",
    "lng": "-92.37028"
  },
  {
    "country": "MX",
    "name": "Cálido",
    "lat": "17.09889",
    "lng": "-92.7875"
  },
  {
    "country": "MX",
    "name": "Paso de Pirules",
    "lat": "20.95028",
    "lng": "-101.29972"
  },
  {
    "country": "MX",
    "name": "Las Lomas",
    "lat": "17.95556",
    "lng": "-94.56111"
  },
  {
    "country": "MX",
    "name": "Alfonso Garzón [Granjas Familiares]",
    "lat": "32.54667",
    "lng": "-116.61722"
  },
  {
    "country": "MX",
    "name": "San José de Durán (Los Troncoso)",
    "lat": "21.06306",
    "lng": "-101.67417"
  },
  {
    "country": "MX",
    "name": "Ococh",
    "lat": "16.83806",
    "lng": "-92.47528"
  },
  {
    "country": "MX",
    "name": "Lázaro Cárdenas",
    "lat": "19.14306",
    "lng": "-97.40056"
  },
  {
    "country": "MX",
    "name": "Boquilla de Babisas (La Boquilla de Conchos)",
    "lat": "27.54861",
    "lng": "-105.40361"
  },
  {
    "country": "MX",
    "name": "Colonia Constitución",
    "lat": "17.53667",
    "lng": "-98.59944"
  },
  {
    "country": "MX",
    "name": "Chichicapa",
    "lat": "18.40056",
    "lng": "-97.04694"
  },
  {
    "country": "MX",
    "name": "Tulimanca",
    "lat": "18.46944",
    "lng": "-97.14"
  },
  {
    "country": "MX",
    "name": "Nueva Libertad (El Colorado)",
    "lat": "15.89861",
    "lng": "-92.05917"
  },
  {
    "country": "MX",
    "name": "El Colegio",
    "lat": "19.77333",
    "lng": "-101.1775"
  },
  {
    "country": "MX",
    "name": "Colonia Jordán",
    "lat": "16.38893",
    "lng": "-95.20203"
  },
  {
    "country": "MX",
    "name": "José María Morelos",
    "lat": "23.32278",
    "lng": "-103.01444"
  },
  {
    "country": "MX",
    "name": "Pechucalco 2da. Sección (Las Cruces)",
    "lat": "18.12694",
    "lng": "-93.19056"
  },
  {
    "country": "MX",
    "name": "Xolostitla de Morelos (Xolostitla)",
    "lat": "20.06639",
    "lng": "-98.63861"
  },
  {
    "country": "MX",
    "name": "La Independencia (Las Pilas)",
    "lat": "16.6775",
    "lng": "-93.24944"
  },
  {
    "country": "MX",
    "name": "Colonia Guadalupe",
    "lat": "19.71306",
    "lng": "-99.24972"
  },
  {
    "country": "MX",
    "name": "Lázaro Cárdenas (Chilil)",
    "lat": "16.67611",
    "lng": "-92.48917"
  },
  {
    "country": "MX",
    "name": "Cuesta Amarilla",
    "lat": "18.34667",
    "lng": "-95.23389"
  },
  {
    "country": "MX",
    "name": "Ignacio Allende (Concepción)",
    "lat": "20.01055",
    "lng": "-97.63448"
  },
  {
    "country": "MX",
    "name": "Ejido General Leandro Valle",
    "lat": "30.62167",
    "lng": "-115.96583"
  },
  {
    "country": "MX",
    "name": "El Llano del Compromiso",
    "lat": "19.25472",
    "lng": "-99.47917"
  },
  {
    "country": "MX",
    "name": "Arroyo Zapotillo",
    "lat": "18.07639",
    "lng": "-96.54417"
  },
  {
    "country": "MX",
    "name": "Tenexio",
    "lat": "21.37667",
    "lng": "-98.87944"
  },
  {
    "country": "MX",
    "name": "La Esperanza [Granjas Familiares]",
    "lat": "32.46278",
    "lng": "-117.105"
  },
  {
    "country": "MX",
    "name": "Bautista Chico",
    "lat": "16.79972",
    "lng": "-92.71194"
  },
  {
    "country": "MX",
    "name": "Profresor Roberto Barrios",
    "lat": "17.32583",
    "lng": "-91.92639"
  },
  {
    "country": "MX",
    "name": "San José de Rancho Nuevo (Los Arrieros)",
    "lat": "21.59639",
    "lng": "-101.00389"
  },
  {
    "country": "MX",
    "name": "El Pedregal",
    "lat": "19.51083",
    "lng": "-101.44917"
  },
  {
    "country": "MX",
    "name": "Buenavista Tetela",
    "lat": "18.91967",
    "lng": "-98.17632"
  },
  {
    "country": "MX",
    "name": "Barrio Nuevo de los Muertos",
    "lat": "16.89278",
    "lng": "-99.54389"
  },
  {
    "country": "MX",
    "name": "Progreso (Campo 47)",
    "lat": "27.34028",
    "lng": "-110.09361"
  },
  {
    "country": "MX",
    "name": "Colonia el Mirador",
    "lat": "19.67167",
    "lng": "-99.35722"
  },
  {
    "country": "MX",
    "name": "Soyata",
    "lat": "18.36889",
    "lng": "-95.28222"
  },
  {
    "country": "MX",
    "name": "La Palmita (La Palmita de San Gabriel)",
    "lat": "20.49806",
    "lng": "-100.87806"
  },
  {
    "country": "MX",
    "name": "Colonia Francisco Javier Mina",
    "lat": "20.97944",
    "lng": "-101.41639"
  },
  {
    "country": "MX",
    "name": "Cupuán del Río",
    "lat": "18.77806",
    "lng": "-102.18778"
  },
  {
    "country": "MX",
    "name": "Tierra Blanca",
    "lat": "20.875",
    "lng": "-97.46"
  },
  {
    "country": "MX",
    "name": "Colonia Miguel Hidalgo",
    "lat": "19.78583",
    "lng": "-101.10139"
  },
  {
    "country": "MX",
    "name": "Ignacio Bastida (Santa Catarina Tlayca)",
    "lat": "18.94028",
    "lng": "-99.01444"
  },
  {
    "country": "MX",
    "name": "Santiago Ixtaltepec",
    "lat": "16.68833",
    "lng": "-94.90583"
  },
  {
    "country": "MX",
    "name": "San Francisco Javier",
    "lat": "17.02861",
    "lng": "-96.7775"
  },
  {
    "country": "MX",
    "name": "Rincón del Porvenir",
    "lat": "22.32306",
    "lng": "-101.17639"
  },
  {
    "country": "MX",
    "name": "El Escribano",
    "lat": "18.41028",
    "lng": "-93.22167"
  },
  {
    "country": "MX",
    "name": "Matacapan",
    "lat": "18.43472",
    "lng": "-95.16583"
  },
  {
    "country": "MX",
    "name": "Ixcuinatoyac",
    "lat": "17.36944",
    "lng": "-98.3425"
  },
  {
    "country": "MX",
    "name": "Los Achotes",
    "lat": "17.60056",
    "lng": "-101.4175"
  },
  {
    "country": "MX",
    "name": "Pochálcatl",
    "lat": "20.00295",
    "lng": "-97.85408"
  },
  {
    "country": "MX",
    "name": "Zolonquiapa",
    "lat": "18.57611",
    "lng": "-98.52722"
  },
  {
    "country": "MX",
    "name": "Hermenegildo Galeana",
    "lat": "15.55278",
    "lng": "-93.00694"
  },
  {
    "country": "MX",
    "name": "Octeyuco Dos Mil",
    "lat": "19.96333",
    "lng": "-99.58806"
  },
  {
    "country": "MX",
    "name": "Santa Ana de Guerrero (El Cascabel)",
    "lat": "19.27639",
    "lng": "-100.44139"
  },
  {
    "country": "MX",
    "name": "Arena 6ta. Sección (La Bolsa)",
    "lat": "18.16218",
    "lng": "-93.39539"
  },
  {
    "country": "MX",
    "name": "Nuevo Cereso Regional de Altamira",
    "lat": "22.46056",
    "lng": "-98.00833"
  },
  {
    "country": "MX",
    "name": "El Ámbar",
    "lat": "17.025",
    "lng": "-92.83417"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Paraíso Real",
    "lat": "21.1125",
    "lng": "-101.58083"
  },
  {
    "country": "MX",
    "name": "El Canario",
    "lat": "20.15694",
    "lng": "-101.33556"
  },
  {
    "country": "MX",
    "name": "San Miguel Amazcala",
    "lat": "20.75056",
    "lng": "-100.23556"
  },
  {
    "country": "MX",
    "name": "Morelia (Victórico Rodolfo Grajales)",
    "lat": "16.72306",
    "lng": "-91.96778"
  },
  {
    "country": "MX",
    "name": "Reforma y Planada",
    "lat": "17.38694",
    "lng": "-92.86583"
  },
  {
    "country": "MX",
    "name": "El Carmen",
    "lat": "19.24167",
    "lng": "-97.20111"
  },
  {
    "country": "MX",
    "name": "Boquiapa",
    "lat": "18.16111",
    "lng": "-93.1375"
  },
  {
    "country": "MX",
    "name": "Santa Isabel",
    "lat": "20.19222",
    "lng": "-97.52917"
  },
  {
    "country": "MX",
    "name": "Colonia de Guadalupe",
    "lat": "19.80083",
    "lng": "-100.91556"
  },
  {
    "country": "MX",
    "name": "Guadalupe Victoria",
    "lat": "22.16333",
    "lng": "-101.07"
  },
  {
    "country": "MX",
    "name": "Jagüey Blanco",
    "lat": "20.27639",
    "lng": "-99.15222"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Colinas Universidad",
    "lat": "20.01833",
    "lng": "-102.73694"
  },
  {
    "country": "MX",
    "name": "Estrella de Belén",
    "lat": "17.38722",
    "lng": "-91.95861"
  },
  {
    "country": "MX",
    "name": "Jerusalén",
    "lat": "17.36806",
    "lng": "-92.06083"
  },
  {
    "country": "MX",
    "name": "Lázaro Cárdenas",
    "lat": "17.19788",
    "lng": "-92.38107"
  },
  {
    "country": "MX",
    "name": "Gambino",
    "lat": "25.65167",
    "lng": "-108.38639"
  },
  {
    "country": "MX",
    "name": "Los Caños",
    "lat": "21.78167",
    "lng": "-102.4675"
  },
  {
    "country": "MX",
    "name": "Ventoquipa",
    "lat": "20.03361",
    "lng": "-98.33778"
  },
  {
    "country": "MX",
    "name": "Colonia Independencia",
    "lat": "19.61556",
    "lng": "-100.32389"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento los Álamos",
    "lat": "18.92389",
    "lng": "-96.97528"
  },
  {
    "country": "MX",
    "name": "La Isla (Kilómetro 10)",
    "lat": "20.60806",
    "lng": "-97.50139"
  },
  {
    "country": "MX",
    "name": "Chipahuatlán",
    "lat": "20.06111",
    "lng": "-97.68861"
  },
  {
    "country": "MX",
    "name": "Río Seco 2da. Sección (Santiaguito)",
    "lat": "18.1375",
    "lng": "-93.27583"
  },
  {
    "country": "MX",
    "name": "San Cristóbal Chacón",
    "lat": "20.08028",
    "lng": "-98.73278"
  },
  {
    "country": "MX",
    "name": "El Ojuelo",
    "lat": "21.40167",
    "lng": "-101.8375"
  },
  {
    "country": "MX",
    "name": "Las Mercedes [Agropecuaria]",
    "lat": "29.36389",
    "lng": "-110.95167"
  },
  {
    "country": "MX",
    "name": "Loma Bonita",
    "lat": "19.26333",
    "lng": "-99.44722"
  },
  {
    "country": "MX",
    "name": "Ex-Hacienda de Guadalupe",
    "lat": "19.78417",
    "lng": "-101.21472"
  },
  {
    "country": "MX",
    "name": "Colinas del Sol",
    "lat": "32.46583",
    "lng": "-117.03694"
  },
  {
    "country": "MX",
    "name": "El Barrido",
    "lat": "20.45028",
    "lng": "-99.19083"
  },
  {
    "country": "MX",
    "name": "Barrio de San Miguel",
    "lat": "18.93139",
    "lng": "-97.125"
  },
  {
    "country": "MX",
    "name": "Nigromante",
    "lat": "20.96194",
    "lng": "-100.78028"
  },
  {
    "country": "MX",
    "name": "Colonia el Pirame",
    "lat": "19.24083",
    "lng": "-99.47194"
  },
  {
    "country": "MX",
    "name": "La Soledad",
    "lat": "19.52111",
    "lng": "-100.48333"
  },
  {
    "country": "MX",
    "name": "San Juan Tezongo",
    "lat": "19.84472",
    "lng": "-97.36389"
  },
  {
    "country": "MX",
    "name": "Chimhucum",
    "lat": "16.89",
    "lng": "-92.53139"
  },
  {
    "country": "MX",
    "name": "Sierra de Agua",
    "lat": "18.75028",
    "lng": "-97.24167"
  },
  {
    "country": "MX",
    "name": "El Triunfo 1ra. Sección (Cardona)",
    "lat": "17.60778",
    "lng": "-93.23306"
  },
  {
    "country": "MX",
    "name": "Estación de San Francisco",
    "lat": "21.03722",
    "lng": "-101.82472"
  },
  {
    "country": "MX",
    "name": "Chimalpa Viejo",
    "lat": "19.44956",
    "lng": "-99.34435"
  },
  {
    "country": "MX",
    "name": "Pechucalco",
    "lat": "18.09361",
    "lng": "-93.16611"
  },
  {
    "country": "MX",
    "name": "San José del Caliche (El Caliche)",
    "lat": "21.12528",
    "lng": "-101.93"
  },
  {
    "country": "MX",
    "name": "Colonia Rincón Villa del Valle",
    "lat": "19.20966",
    "lng": "-100.11917"
  },
  {
    "country": "MX",
    "name": "Arroyo Palenque",
    "lat": "17.39167",
    "lng": "-92.10444"
  },
  {
    "country": "MX",
    "name": "Aurora Ermita",
    "lat": "17.23583",
    "lng": "-92.87389"
  },
  {
    "country": "MX",
    "name": "Coyahualco",
    "lat": "17.74139",
    "lng": "-98.56667"
  },
  {
    "country": "MX",
    "name": "Cantinela",
    "lat": "20.45778",
    "lng": "-99.21028"
  },
  {
    "country": "MX",
    "name": "Los Naranjos Esquipulas",
    "lat": "15.98167",
    "lng": "-96.45889"
  },
  {
    "country": "MX",
    "name": "Las Golondrinas [Fraccionamiento]",
    "lat": "22.10528",
    "lng": "-103.25417"
  },
  {
    "country": "MX",
    "name": "Colonia la Central",
    "lat": "18.08666",
    "lng": "-96.51619"
  },
  {
    "country": "MX",
    "name": "Congregación Reforma",
    "lat": "14.78186",
    "lng": "-92.31336"
  },
  {
    "country": "MX",
    "name": "Los Naranjos",
    "lat": "18.33111",
    "lng": "-95.24167"
  },
  {
    "country": "MX",
    "name": "Turuachi",
    "lat": "26.13139",
    "lng": "-106.70417"
  },
  {
    "country": "MX",
    "name": "Paseos de la Pradera",
    "lat": "19.89111",
    "lng": "-99.23806"
  },
  {
    "country": "MX",
    "name": "Xiloxochico de Rafael Ávila Camacho",
    "lat": "20.04583",
    "lng": "-97.49083"
  },
  {
    "country": "MX",
    "name": "Cerrito de Jaral",
    "lat": "22.22361",
    "lng": "-101.0625"
  },
  {
    "country": "MX",
    "name": "San Simón",
    "lat": "18.23778",
    "lng": "-93.03417"
  },
  {
    "country": "MX",
    "name": "El Cuitzillo Grande",
    "lat": "19.77972",
    "lng": "-101.11694"
  },
  {
    "country": "MX",
    "name": "Nuevo Xcán",
    "lat": "20.86917",
    "lng": "-87.60306"
  },
  {
    "country": "MX",
    "name": "La Albarrada (San Francisco la Albarrada)",
    "lat": "19.0675",
    "lng": "-100.07528"
  },
  {
    "country": "MX",
    "name": "Los Garcías",
    "lat": "18.80333",
    "lng": "-97.39417"
  },
  {
    "country": "MX",
    "name": "Las Pilas",
    "lat": "22.84",
    "lng": "-102.61278"
  },
  {
    "country": "MX",
    "name": "Montaña Monarca (Punta Altozano)",
    "lat": "19.66056",
    "lng": "-101.16556"
  },
  {
    "country": "MX",
    "name": "La Concepción (La Concha)",
    "lat": "18.76778",
    "lng": "-99.6925"
  },
  {
    "country": "MX",
    "name": "General Juan José Baz (San José del Corral)",
    "lat": "18.82167",
    "lng": "-96.81806"
  },
  {
    "country": "MX",
    "name": "Álvaro Obregón",
    "lat": "16.84361",
    "lng": "-93.19278"
  },
  {
    "country": "MX",
    "name": "Chulum Cárdenas",
    "lat": "17.38417",
    "lng": "-92.57389"
  },
  {
    "country": "MX",
    "name": "Santa Ana",
    "lat": "20.37306",
    "lng": "-101.1125"
  },
  {
    "country": "MX",
    "name": "San Isidro",
    "lat": "19.76806",
    "lng": "-100.20361"
  },
  {
    "country": "MX",
    "name": "Caxitepec",
    "lat": "17.29449",
    "lng": "-98.96741"
  },
  {
    "country": "MX",
    "name": "Betania",
    "lat": "18.28003",
    "lng": "-93.32081"
  },
  {
    "country": "MX",
    "name": "Octavio Paz",
    "lat": "14.85778",
    "lng": "-92.26389"
  },
  {
    "country": "MX",
    "name": "Estación la Piedad",
    "lat": "20.3675",
    "lng": "-101.99806"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Otlatla",
    "lat": "19.37222",
    "lng": "-98.6225"
  },
  {
    "country": "MX",
    "name": "Agua Señora",
    "lat": "22.2375",
    "lng": "-101.04222"
  },
  {
    "country": "MX",
    "name": "Ejido la Piña (Maromilla)",
    "lat": "19.02861",
    "lng": "-96.78361"
  },
  {
    "country": "MX",
    "name": "Ahuexotitlán",
    "lat": "17.52849",
    "lng": "-99.24398"
  },
  {
    "country": "MX",
    "name": "Cerro Quemado",
    "lat": "18.15417",
    "lng": "-96.575"
  },
  {
    "country": "MX",
    "name": "El Bajío",
    "lat": "17.98173",
    "lng": "-92.78229"
  },
  {
    "country": "MX",
    "name": "Tentic",
    "lat": "16.86333",
    "lng": "-92.68222"
  },
  {
    "country": "MX",
    "name": "Doxteje Centro",
    "lat": "19.97528",
    "lng": "-99.95472"
  },
  {
    "country": "MX",
    "name": "Sección del Cerrito",
    "lat": "19.55889",
    "lng": "-99.67833"
  },
  {
    "country": "MX",
    "name": "General Lauro G. Caloca (El Rascón)",
    "lat": "22.37806",
    "lng": "-102.0575"
  },
  {
    "country": "MX",
    "name": "Tierras Coloradas (San Pedro)",
    "lat": "19.71889",
    "lng": "-100.64639"
  },
  {
    "country": "MX",
    "name": "Emiliano Zapata (Casahuates)",
    "lat": "18.93056",
    "lng": "-98.95889"
  },
  {
    "country": "MX",
    "name": "Lacapan Camallagne",
    "lat": "20.12862",
    "lng": "-97.65343"
  },
  {
    "country": "MX",
    "name": "Jiquilpan (Estación Bonanza)",
    "lat": "15.34194",
    "lng": "-92.7475"
  },
  {
    "country": "MX",
    "name": "Nuevo Naranjo",
    "lat": "17.15444",
    "lng": "-93.43333"
  },
  {
    "country": "MX",
    "name": "Rancho Viejo",
    "lat": "16.865",
    "lng": "-99.28944"
  },
  {
    "country": "MX",
    "name": "San Pedro Denxhi Centro",
    "lat": "20.25026",
    "lng": "-99.96731"
  },
  {
    "country": "MX",
    "name": "Valle de Juárez",
    "lat": "25.63778",
    "lng": "-100.15833"
  },
  {
    "country": "MX",
    "name": "Nexticapan",
    "lat": "19.82722",
    "lng": "-97.55417"
  },
  {
    "country": "MX",
    "name": "Colonia Padre Hidalgo",
    "lat": "21.17056",
    "lng": "-100.93556"
  },
  {
    "country": "MX",
    "name": "San Antonio de los Tepetates",
    "lat": "21.04472",
    "lng": "-101.67611"
  },
  {
    "country": "MX",
    "name": "San Felipe Tílpam",
    "lat": "18.18889",
    "lng": "-96.58639"
  },
  {
    "country": "MX",
    "name": "San Félix Rijo",
    "lat": "18.62028",
    "lng": "-98.55028"
  },
  {
    "country": "MX",
    "name": "Barranca de Otates (Barranca de Otatán)",
    "lat": "20.26806",
    "lng": "-103.66472"
  },
  {
    "country": "MX",
    "name": "La Planada (El Arenal)",
    "lat": "19.33333",
    "lng": "-99.67694"
  },
  {
    "country": "MX",
    "name": "San Felipe Sultepec",
    "lat": "19.59083",
    "lng": "-98.61528"
  },
  {
    "country": "MX",
    "name": "Los Benitos",
    "lat": "20.685",
    "lng": "-99.95611"
  },
  {
    "country": "MX",
    "name": "Las Trancas",
    "lat": "19.50444",
    "lng": "-96.86444"
  },
  {
    "country": "MX",
    "name": "Ojite Rancho Nuevo",
    "lat": "20.96944",
    "lng": "-97.52806"
  },
  {
    "country": "MX",
    "name": "Santa Fe y la Mar",
    "lat": "17.76611",
    "lng": "-96.31611"
  },
  {
    "country": "MX",
    "name": "De Parral",
    "lat": "20.45611",
    "lng": "-101.00778"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Villas de Guanajuato",
    "lat": "20.96028",
    "lng": "-101.29806"
  },
  {
    "country": "MX",
    "name": "Barrio el Boncho",
    "lat": "19.42611",
    "lng": "-100.10639"
  },
  {
    "country": "MX",
    "name": "Miguel Utrilla (Los Chorros)",
    "lat": "16.94278",
    "lng": "-92.47972"
  },
  {
    "country": "MX",
    "name": "Ojo de Agua de Morán",
    "lat": "20.59472",
    "lng": "-102.52972"
  },
  {
    "country": "MX",
    "name": "El Bellote (Miguel de la Madrid)",
    "lat": "18.42528",
    "lng": "-93.15083"
  },
  {
    "country": "MX",
    "name": "Jomanichim",
    "lat": "16.90056",
    "lng": "-92.47222"
  },
  {
    "country": "MX",
    "name": "Tazaquil",
    "lat": "21.49111",
    "lng": "-98.94"
  },
  {
    "country": "MX",
    "name": "Los Pozos",
    "lat": "23.00944",
    "lng": "-106.1525"
  },
  {
    "country": "MX",
    "name": "San José Yashitinín",
    "lat": "16.65472",
    "lng": "-92.445"
  },
  {
    "country": "MX",
    "name": "Zapote de Palomas",
    "lat": "20.58444",
    "lng": "-101.115"
  },
  {
    "country": "MX",
    "name": "Llano de Agua",
    "lat": "18.10611",
    "lng": "-96.81083"
  },
  {
    "country": "MX",
    "name": "Luis Espinoza",
    "lat": "17.03167",
    "lng": "-93.02694"
  },
  {
    "country": "MX",
    "name": "Arvenza Uno",
    "lat": "16.77972",
    "lng": "-92.72028"
  },
  {
    "country": "MX",
    "name": "Colonia 3 de Mayo",
    "lat": "18.82726",
    "lng": "-99.69304"
  },
  {
    "country": "MX",
    "name": "San Miguel Aguacomulican",
    "lat": "18.82222",
    "lng": "-98.55056"
  },
  {
    "country": "MX",
    "name": "Cuauhtamazaco",
    "lat": "20.025",
    "lng": "-97.48722"
  },
  {
    "country": "MX",
    "name": "Tzinil",
    "lat": "16.25778",
    "lng": "-92.32222"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Privadas del Sol",
    "lat": "19.75222",
    "lng": "-101.19139"
  },
  {
    "country": "MX",
    "name": "Gregorio Méndez",
    "lat": "18.19639",
    "lng": "-93.10222"
  },
  {
    "country": "MX",
    "name": "Ocotequila",
    "lat": "17.44944",
    "lng": "-98.6775"
  },
  {
    "country": "MX",
    "name": "Santa María Xigui",
    "lat": "20.46111",
    "lng": "-99.345"
  },
  {
    "country": "MX",
    "name": "El Salitre",
    "lat": "18.67583",
    "lng": "-98.95806"
  },
  {
    "country": "MX",
    "name": "Santa María Zapotitlán",
    "lat": "16.12806",
    "lng": "-95.85194"
  },
  {
    "country": "MX",
    "name": "General Alatriste (San Joaquín)",
    "lat": "18.84028",
    "lng": "-96.79361"
  },
  {
    "country": "MX",
    "name": "Constitución",
    "lat": "17.07556",
    "lng": "-92.52417"
  },
  {
    "country": "MX",
    "name": "Jolsibaquil",
    "lat": "17.25972",
    "lng": "-92.48167"
  },
  {
    "country": "MX",
    "name": "Residencial Arboledas",
    "lat": "20.06444",
    "lng": "-99.30167"
  },
  {
    "country": "MX",
    "name": "Paseos del Valle [Fraccionamiento]",
    "lat": "20.52222",
    "lng": "-103.33333"
  },
  {
    "country": "MX",
    "name": "Concepción Caro",
    "lat": "19.77139",
    "lng": "-99.90917"
  },
  {
    "country": "MX",
    "name": "San Antonio el Llanito",
    "lat": "19.2775",
    "lng": "-99.495"
  },
  {
    "country": "MX",
    "name": "La Higuerilla (Los Lirios)",
    "lat": "19.9225",
    "lng": "-100.27639"
  },
  {
    "country": "MX",
    "name": "Chiquinival",
    "lat": "16.99111",
    "lng": "-91.96028"
  },
  {
    "country": "MX",
    "name": "Santiago Centro",
    "lat": "21.20528",
    "lng": "-98.86361"
  },
  {
    "country": "MX",
    "name": "Guadalupe Calderón",
    "lat": "18.96611",
    "lng": "-97.85833"
  },
  {
    "country": "MX",
    "name": "J. Jesús González Ortega (San Mateo)",
    "lat": "22.88722",
    "lng": "-103.48528"
  },
  {
    "country": "MX",
    "name": "Zacate Colorado Segundo (Fraternidad)",
    "lat": "18.68333",
    "lng": "-95.97111"
  },
  {
    "country": "MX",
    "name": "Vallejo (Porvenir Vallejo)",
    "lat": "25.88278",
    "lng": "-109.07361"
  },
  {
    "country": "MX",
    "name": "Los Sauces",
    "lat": "18.03335",
    "lng": "-92.91693"
  },
  {
    "country": "MX",
    "name": "Los Liros",
    "lat": "16.73972",
    "lng": "-98.21722"
  },
  {
    "country": "MX",
    "name": "Nexpan",
    "lat": "19.88389",
    "lng": "-97.42333"
  },
  {
    "country": "MX",
    "name": "Ahuehueyo Primero Centro",
    "lat": "21.345",
    "lng": "-98.83722"
  },
  {
    "country": "MX",
    "name": "Barrancas y Amate 3ra. Sección",
    "lat": "17.971",
    "lng": "-92.76173"
  },
  {
    "country": "MX",
    "name": "Francisco Villa",
    "lat": "19.875",
    "lng": "-100.93583"
  },
  {
    "country": "MX",
    "name": "El Progreso",
    "lat": "20.11417",
    "lng": "-97.01444"
  },
  {
    "country": "MX",
    "name": "El Cabi",
    "lat": "19.18986",
    "lng": "-98.85371"
  },
  {
    "country": "MX",
    "name": "Agua Blanca",
    "lat": "19.22056",
    "lng": "-99.47056"
  },
  {
    "country": "MX",
    "name": "Nicolás Blanco (San Pancho)",
    "lat": "19.3525",
    "lng": "-96.33833"
  },
  {
    "country": "MX",
    "name": "Techichili",
    "lat": "19.17139",
    "lng": "-99.42222"
  },
  {
    "country": "MX",
    "name": "Peña del Panal",
    "lat": "19.77333",
    "lng": "-101.18944"
  },
  {
    "country": "MX",
    "name": "El Pueblito (Garbanzal)",
    "lat": "19.59389",
    "lng": "-96.92417"
  },
  {
    "country": "MX",
    "name": "La Corregidora",
    "lat": "21.44417",
    "lng": "-104.81222"
  },
  {
    "country": "MX",
    "name": "Bochojbo Alto",
    "lat": "16.73583",
    "lng": "-92.71694"
  },
  {
    "country": "MX",
    "name": "San José Manzanitos",
    "lat": "19.26111",
    "lng": "-97.21472"
  },
  {
    "country": "MX",
    "name": "Misija",
    "lat": "17.26611",
    "lng": "-92.38167"
  },
  {
    "country": "MX",
    "name": "Colonia Fraccionamiento el Puente",
    "lat": "20.52361",
    "lng": "-100.89667"
  },
  {
    "country": "MX",
    "name": "Lomas de Romero",
    "lat": "18.91444",
    "lng": "-97.71722"
  },
  {
    "country": "MX",
    "name": "Lomas de Tlatelolco",
    "lat": "32.48306",
    "lng": "-116.80167"
  },
  {
    "country": "MX",
    "name": "Ciudad Guzmán [CERESO]",
    "lat": "19.65194",
    "lng": "-103.5"
  },
  {
    "country": "MX",
    "name": "Kilómetro 40",
    "lat": "17.04944",
    "lng": "-99.77056"
  },
  {
    "country": "MX",
    "name": "Barrio de Guadalupe del Mezquitillo",
    "lat": "20.94417",
    "lng": "-101.80083"
  },
  {
    "country": "MX",
    "name": "La Loma Cuexcontitlán",
    "lat": "19.38",
    "lng": "-99.64889"
  },
  {
    "country": "MX",
    "name": "El Plan",
    "lat": "19.37452",
    "lng": "-99.80049"
  },
  {
    "country": "MX",
    "name": "El Metlapil",
    "lat": "16.84167",
    "lng": "-99.74889"
  },
  {
    "country": "MX",
    "name": "El Cortijo",
    "lat": "20.46917",
    "lng": "-103.42194"
  },
  {
    "country": "MX",
    "name": "San Benito Encinal",
    "lat": "17.98722",
    "lng": "-95.91056"
  },
  {
    "country": "MX",
    "name": "Guadalupe Victoria",
    "lat": "19.10444",
    "lng": "-97.60556"
  },
  {
    "country": "MX",
    "name": "Santiago Tlacochcalco",
    "lat": "19.26861",
    "lng": "-98.22306"
  },
  {
    "country": "MX",
    "name": "Metlac Hernández (Metlac Primero)",
    "lat": "18.9775",
    "lng": "-97.14306"
  },
  {
    "country": "MX",
    "name": "El Paraíso",
    "lat": "17.24639",
    "lng": "-92.55694"
  },
  {
    "country": "MX",
    "name": "Ejido San Cristóbal",
    "lat": "19.5425",
    "lng": "-98.89417"
  },
  {
    "country": "MX",
    "name": "El Roble",
    "lat": "20.05806",
    "lng": "-98.75833"
  },
  {
    "country": "MX",
    "name": "Quetzalapa",
    "lat": "18.94056",
    "lng": "-99.59694"
  },
  {
    "country": "MX",
    "name": "Concentración 5 de Febrero",
    "lat": "25.85639",
    "lng": "-108.62944"
  },
  {
    "country": "MX",
    "name": "Cerro del Murciélago",
    "lat": "19.28194",
    "lng": "-99.75472"
  },
  {
    "country": "MX",
    "name": "Tierra Negra",
    "lat": "20.24333",
    "lng": "-97.95667"
  },
  {
    "country": "MX",
    "name": "Melchor Ocampo",
    "lat": "19.83972",
    "lng": "-97.30667"
  },
  {
    "country": "MX",
    "name": "Las Brisas",
    "lat": "30.96056",
    "lng": "-116.16444"
  },
  {
    "country": "MX",
    "name": "La Rinconada",
    "lat": "15.59333",
    "lng": "-92.26806"
  },
  {
    "country": "MX",
    "name": "San Marcos",
    "lat": "17.3469",
    "lng": "-99.00409"
  },
  {
    "country": "MX",
    "name": "Tlatilpa",
    "lat": "18.73389",
    "lng": "-97.14417"
  },
  {
    "country": "MX",
    "name": "Nueva Frontera",
    "lat": "16.88806",
    "lng": "-99.81583"
  },
  {
    "country": "MX",
    "name": "Colonia Doctor Gustavo Baz",
    "lat": "19.01306",
    "lng": "-99.39667"
  },
  {
    "country": "MX",
    "name": "San Martín Mazateopan",
    "lat": "18.45278",
    "lng": "-96.81611"
  },
  {
    "country": "MX",
    "name": "San Cristóbal Xochimilpa",
    "lat": "20.06639",
    "lng": "-97.9075"
  },
  {
    "country": "MX",
    "name": "San Isidro Palotal",
    "lat": "18.94417",
    "lng": "-96.96583"
  },
  {
    "country": "MX",
    "name": "Sargento López 2da. Sección (El Chuzo)",
    "lat": "18.19953",
    "lng": "-93.29235"
  },
  {
    "country": "MX",
    "name": "La Estancia Sector Uno (La Estancia)",
    "lat": "19.87056",
    "lng": "-99.79167"
  },
  {
    "country": "MX",
    "name": "El Colorado",
    "lat": "20.21528",
    "lng": "-99.00222"
  },
  {
    "country": "MX",
    "name": "Unidad Grajales INFONAVIT",
    "lat": "19.24126",
    "lng": "-97.81068"
  },
  {
    "country": "MX",
    "name": "El Tintal",
    "lat": "20.89194",
    "lng": "-87.46611"
  },
  {
    "country": "MX",
    "name": "Los Pinos",
    "lat": "16.92083",
    "lng": "-92.10861"
  },
  {
    "country": "MX",
    "name": "Loma de Yerbabuena",
    "lat": "21.06056",
    "lng": "-101.44944"
  },
  {
    "country": "MX",
    "name": "Tutepec",
    "lat": "16.92167",
    "lng": "-99.15639"
  },
  {
    "country": "MX",
    "name": "José María Pino Suárez",
    "lat": "20.24722",
    "lng": "-99.42111"
  },
  {
    "country": "MX",
    "name": "El Capulín (La Nueva Pochota)",
    "lat": "18.22972",
    "lng": "-96.27806"
  },
  {
    "country": "MX",
    "name": "San José Buena Vista",
    "lat": "18.40528",
    "lng": "-97.26833"
  },
  {
    "country": "MX",
    "name": "Banco Nacional",
    "lat": "25.87139",
    "lng": "-103.35667"
  },
  {
    "country": "MX",
    "name": "Rinconadas del Venado I",
    "lat": "20.06361",
    "lng": "-98.76333"
  },
  {
    "country": "MX",
    "name": "Rincón de Aguirre",
    "lat": "18.89947",
    "lng": "-100.13659"
  },
  {
    "country": "MX",
    "name": "Miravalle",
    "lat": "21.9725",
    "lng": "-102.31139"
  },
  {
    "country": "MX",
    "name": "Acuaco",
    "lat": "19.7625",
    "lng": "-97.56444"
  },
  {
    "country": "MX",
    "name": "La Presita Segundo Cuartel",
    "lat": "20.16278",
    "lng": "-99.87278"
  },
  {
    "country": "MX",
    "name": "Progreso",
    "lat": "17.04528",
    "lng": "-97.57028"
  },
  {
    "country": "MX",
    "name": "Monte Blanco",
    "lat": "20.35472",
    "lng": "-101.5275"
  },
  {
    "country": "MX",
    "name": "Adjuntas del Río",
    "lat": "21.11667",
    "lng": "-100.86806"
  },
  {
    "country": "MX",
    "name": "Colonia los Cerritos",
    "lat": "18.95389",
    "lng": "-99.1925"
  },
  {
    "country": "MX",
    "name": "San Juan Zapotitlán",
    "lat": "17.80528",
    "lng": "-96.60639"
  },
  {
    "country": "MX",
    "name": "Santa Rosa Segundo",
    "lat": "19.97778",
    "lng": "-88.2625"
  },
  {
    "country": "MX",
    "name": "Rincón de los Reyes",
    "lat": "19.19444",
    "lng": "-97.16056"
  },
  {
    "country": "MX",
    "name": "La Soledad",
    "lat": "18.81",
    "lng": "-97.76417"
  },
  {
    "country": "MX",
    "name": "Praderas del Potrero",
    "lat": "19.88472",
    "lng": "-99.23028"
  },
  {
    "country": "MX",
    "name": "Corral de Piedra",
    "lat": "18.24528",
    "lng": "-96.30556"
  },
  {
    "country": "MX",
    "name": "Zoyotla",
    "lat": "19.92778",
    "lng": "-97.69389"
  },
  {
    "country": "MX",
    "name": "Santa Isabel [Fraccionamiento]",
    "lat": "22.08111",
    "lng": "-102.26778"
  },
  {
    "country": "MX",
    "name": "La Trinidad",
    "lat": "20.56333",
    "lng": "-100.78361"
  },
  {
    "country": "MX",
    "name": "San Miguelito",
    "lat": "17.63583",
    "lng": "-101.4375"
  },
  {
    "country": "MX",
    "name": "Rancho Alegre",
    "lat": "20.20722",
    "lng": "-97.63889"
  },
  {
    "country": "MX",
    "name": "Ejido Netzahualcóyotl",
    "lat": "32.62444",
    "lng": "-115.06222"
  },
  {
    "country": "MX",
    "name": "Manzana Segunda",
    "lat": "19.56722",
    "lng": "-99.59389"
  },
  {
    "country": "MX",
    "name": "La Palma (Las Palmas)",
    "lat": "19.77111",
    "lng": "-101.14083"
  },
  {
    "country": "MX",
    "name": "La Toma",
    "lat": "19.45278",
    "lng": "-97.19361"
  },
  {
    "country": "MX",
    "name": "Ixtlahuaca",
    "lat": "19.82309",
    "lng": "-97.33496"
  },
  {
    "country": "MX",
    "name": "Veracruz",
    "lat": "16.40417",
    "lng": "-91.99944"
  },
  {
    "country": "MX",
    "name": "El Olvera",
    "lat": "20.27",
    "lng": "-99.02556"
  },
  {
    "country": "MX",
    "name": "Paraje Trejo (El Chaparral)",
    "lat": "19.40556",
    "lng": "-99.31222"
  },
  {
    "country": "MX",
    "name": "Ejido el Castillo",
    "lat": "19.43583",
    "lng": "-99.30583"
  },
  {
    "country": "MX",
    "name": "Tocoy",
    "lat": "21.63861",
    "lng": "-98.87083"
  },
  {
    "country": "MX",
    "name": "La Nueva Era",
    "lat": "17.69861",
    "lng": "-95.80833"
  },
  {
    "country": "MX",
    "name": "Ocuiltzapoyo",
    "lat": "21.32444",
    "lng": "-98.72861"
  },
  {
    "country": "MX",
    "name": "La Sala (La Caliente)",
    "lat": "20.20722",
    "lng": "-98.8725"
  },
  {
    "country": "MX",
    "name": "Joconoxtle (La Tuna)",
    "lat": "20.45222",
    "lng": "-102.67639"
  },
  {
    "country": "MX",
    "name": "Álvaro Obregón 2da. Sección (El Lechugal)",
    "lat": "18.39167",
    "lng": "-92.78806"
  },
  {
    "country": "MX",
    "name": "La Herradura",
    "lat": "19.04",
    "lng": "-99.58472"
  },
  {
    "country": "MX",
    "name": "Guadalupe Morelos",
    "lat": "19.02556",
    "lng": "-97.80417"
  },
  {
    "country": "MX",
    "name": "Santa Bárbara",
    "lat": "20.47556",
    "lng": "-101.34944"
  },
  {
    "country": "MX",
    "name": "Tlatzala",
    "lat": "18.72861",
    "lng": "-97.14111"
  },
  {
    "country": "MX",
    "name": "Miguel Hidalgo",
    "lat": "17.90639",
    "lng": "-93.1175"
  },
  {
    "country": "MX",
    "name": "La Mezquitera",
    "lat": "20.55833",
    "lng": "-103.1125"
  },
  {
    "country": "MX",
    "name": "Unidad Habitacional Mariano Matamoros",
    "lat": "18.7475",
    "lng": "-98.85222"
  },
  {
    "country": "MX",
    "name": "Manuel Edgardo Ávalos (San Isidro)",
    "lat": "19.06778",
    "lng": "-97.39194"
  },
  {
    "country": "MX",
    "name": "Tinajas 1ra. Sección",
    "lat": "14.7175",
    "lng": "-92.32861"
  },
  {
    "country": "MX",
    "name": "El Ramal (Porvenir)",
    "lat": "15.86583",
    "lng": "-92.94556"
  },
  {
    "country": "MX",
    "name": "Los Olivos",
    "lat": "19.20778",
    "lng": "-102.86194"
  },
  {
    "country": "MX",
    "name": "Molino de San José",
    "lat": "21.57083",
    "lng": "-101.26389"
  },
  {
    "country": "MX",
    "name": "San José Independencia",
    "lat": "18.75583",
    "lng": "-96.945"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento del Valle",
    "lat": "31.91139",
    "lng": "-116.26056"
  },
  {
    "country": "MX",
    "name": "Tierra Larga (Campo Nuevo)",
    "lat": "18.86444",
    "lng": "-98.94806"
  },
  {
    "country": "MX",
    "name": "Ignacio Zaragoza 1ra. Sección",
    "lat": "18.33157",
    "lng": "-93.33508"
  },
  {
    "country": "MX",
    "name": "10 de Abril",
    "lat": "16.82917",
    "lng": "-99.74083"
  },
  {
    "country": "MX",
    "name": "El Espinalillo",
    "lat": "16.98472",
    "lng": "-100.12694"
  },
  {
    "country": "MX",
    "name": "La Trinidad",
    "lat": "19.68056",
    "lng": "-99.17222"
  },
  {
    "country": "MX",
    "name": "Santa Rosa (El Huizache)",
    "lat": "21.935",
    "lng": "-102.02194"
  },
  {
    "country": "MX",
    "name": "Hoya de Cintora (La Hoya de Arriba)",
    "lat": "20.36444",
    "lng": "-101.20833"
  },
  {
    "country": "MX",
    "name": "El Recodo",
    "lat": "27.07722",
    "lng": "-109.5275"
  },
  {
    "country": "MX",
    "name": "General Luis Felipe Domínguez Suárez",
    "lat": "17.65639",
    "lng": "-91.53667"
  },
  {
    "country": "MX",
    "name": "Pugchén Mumuntic",
    "lat": "16.86389",
    "lng": "-92.82361"
  },
  {
    "country": "MX",
    "name": "Cantón Villaflor",
    "lat": "15.11424",
    "lng": "-92.35261"
  },
  {
    "country": "MX",
    "name": "San Julio",
    "lat": "25.93639",
    "lng": "-103.42083"
  },
  {
    "country": "MX",
    "name": "Coahuixtla",
    "lat": "18.57417",
    "lng": "-99.37"
  },
  {
    "country": "MX",
    "name": "El Camalote",
    "lat": "15.8725",
    "lng": "-96.62361"
  },
  {
    "country": "MX",
    "name": "Yopi",
    "lat": "19.82667",
    "lng": "-97.38028"
  },
  {
    "country": "MX",
    "name": "Tlacuilola",
    "lat": "21.2375",
    "lng": "-98.86806"
  },
  {
    "country": "MX",
    "name": "Rinconadas del Bosque",
    "lat": "20.08528",
    "lng": "-101.19833"
  },
  {
    "country": "MX",
    "name": "Atenguillo",
    "lat": "19.56361",
    "lng": "-98.87639"
  },
  {
    "country": "MX",
    "name": "Santa Ana Chapitiro",
    "lat": "19.52611",
    "lng": "-101.6525"
  },
  {
    "country": "MX",
    "name": "Loma Chapultepec",
    "lat": "18.11972",
    "lng": "-96.83917"
  },
  {
    "country": "MX",
    "name": "Campo de Águila",
    "lat": "18.0675",
    "lng": "-94.98611"
  },
  {
    "country": "MX",
    "name": "Buenos Aires (San Isidro)",
    "lat": "20.84028",
    "lng": "-97.60139"
  },
  {
    "country": "MX",
    "name": "Jarillas",
    "lat": "22.29611",
    "lng": "-102.06333"
  },
  {
    "country": "MX",
    "name": "Centro de Readaptación Social",
    "lat": "18.83806",
    "lng": "-96.93944"
  },
  {
    "country": "MX",
    "name": "Manzana la Cofradía",
    "lat": "19.54944",
    "lng": "-100.35583"
  },
  {
    "country": "MX",
    "name": "Santiago Chilixtlahuaca",
    "lat": "17.90611",
    "lng": "-97.89528"
  },
  {
    "country": "MX",
    "name": "Texocoyohuac",
    "lat": "19.77778",
    "lng": "-97.59028"
  },
  {
    "country": "MX",
    "name": "Llano de las Flores (Barrio del Hueso)",
    "lat": "19.43583",
    "lng": "-99.3225"
  },
  {
    "country": "MX",
    "name": "Colonia el Mirador (Llano del Ejido)",
    "lat": "19.67583",
    "lng": "-100.55361"
  },
  {
    "country": "MX",
    "name": "San José Boxay",
    "lat": "20.26236",
    "lng": "-99.10085"
  },
  {
    "country": "MX",
    "name": "Mariscal Subikuski",
    "lat": "17.3325",
    "lng": "-92.38083"
  },
  {
    "country": "MX",
    "name": "Lodo Grande",
    "lat": "17.60972",
    "lng": "-99.21194"
  },
  {
    "country": "MX",
    "name": "Pintillo",
    "lat": "20.79667",
    "lng": "-100.41694"
  },
  {
    "country": "MX",
    "name": "Jesús Tepactepec",
    "lat": "19.22917",
    "lng": "-98.31417"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento la Mezquitera",
    "lat": "21.00972",
    "lng": "-101.83472"
  },
  {
    "country": "MX",
    "name": "Zacamulpa",
    "lat": "20.00583",
    "lng": "-99.25694"
  },
  {
    "country": "MX",
    "name": "Cuartel la Mesa (El Asoleadero)",
    "lat": "19.56972",
    "lng": "-100.28694"
  },
  {
    "country": "MX",
    "name": "Oxinam",
    "lat": "16.86306",
    "lng": "-92.54917"
  },
  {
    "country": "MX",
    "name": "La Cañada",
    "lat": "17.07",
    "lng": "-96.77806"
  },
  {
    "country": "MX",
    "name": "El Recodo de San José Axalco",
    "lat": "19.20278",
    "lng": "-98.90278"
  },
  {
    "country": "MX",
    "name": "Puentecillas (Tercera Manzana de Zirahuato)",
    "lat": "19.505",
    "lng": "-100.405"
  },
  {
    "country": "MX",
    "name": "Calpanería Atezquilla",
    "lat": "19.65556",
    "lng": "-97.99528"
  },
  {
    "country": "MX",
    "name": "Arroyo San Isidro",
    "lat": "18.48667",
    "lng": "-95.41333"
  },
  {
    "country": "MX",
    "name": "La Esperanza (El Zapotal)",
    "lat": "15.44917",
    "lng": "-93.16417"
  },
  {
    "country": "MX",
    "name": "Pueblo Madero (El Playón)",
    "lat": "17.12611",
    "lng": "-99.6725"
  },
  {
    "country": "MX",
    "name": "Barrio de San Ramón",
    "lat": "19.37361",
    "lng": "-99.33111"
  },
  {
    "country": "MX",
    "name": "Santa Fe de la Purísima",
    "lat": "20.49556",
    "lng": "-100.89278"
  },
  {
    "country": "MX",
    "name": "El Tigre (Segunda Manzana de Crescencio Morales)",
    "lat": "19.47361",
    "lng": "-100.24417"
  },
  {
    "country": "MX",
    "name": "Tetelcingo",
    "lat": "18.23917",
    "lng": "-98.02667"
  },
  {
    "country": "MX",
    "name": "18 de Marzo",
    "lat": "18.96889",
    "lng": "-98.16028"
  },
  {
    "country": "MX",
    "name": "Ejido la Guayana (Rancho Seco)",
    "lat": "21.98028",
    "lng": "-102.27306"
  },
  {
    "country": "MX",
    "name": "Pueblo Benito García",
    "lat": "30.51583",
    "lng": "-115.93278"
  },
  {
    "country": "MX",
    "name": "Santa Rosa Caxtlahuaca",
    "lat": "17.30306",
    "lng": "-98.01694"
  },
  {
    "country": "MX",
    "name": "Buenavista",
    "lat": "19.25767",
    "lng": "-97.07531"
  },
  {
    "country": "MX",
    "name": "Apantla",
    "lat": "17.03972",
    "lng": "-99.16944"
  },
  {
    "country": "MX",
    "name": "Barrio de Puentecillas",
    "lat": "19.53558",
    "lng": "-99.98463"
  },
  {
    "country": "MX",
    "name": "Colonia San Luis",
    "lat": "16.38",
    "lng": "-95.24111"
  },
  {
    "country": "MX",
    "name": "Loma Bonita",
    "lat": "18.51333",
    "lng": "-96.86778"
  },
  {
    "country": "MX",
    "name": "Corralejo de Arriba",
    "lat": "20.89667",
    "lng": "-100.65444"
  },
  {
    "country": "MX",
    "name": "Tonalapa",
    "lat": "17.49056",
    "lng": "-99.24194"
  },
  {
    "country": "MX",
    "name": "La Mintzita (Piedra Dura)",
    "lat": "19.65194",
    "lng": "-101.2775"
  },
  {
    "country": "MX",
    "name": "Nenehuaca",
    "lat": "19.14389",
    "lng": "-97.04222"
  },
  {
    "country": "MX",
    "name": "Aguas Buenas",
    "lat": "20.97028",
    "lng": "-101.3725"
  },
  {
    "country": "MX",
    "name": "Colonia Nueva Revolución",
    "lat": "16.89833",
    "lng": "-99.80583"
  },
  {
    "country": "MX",
    "name": "El Dorado",
    "lat": "17.88323",
    "lng": "-93.36788"
  },
  {
    "country": "MX",
    "name": "El Moreno (San Miguel Moreno)",
    "lat": "20.30139",
    "lng": "-99.17361"
  },
  {
    "country": "MX",
    "name": "Derramadero Segundo (Infiernillo)",
    "lat": "21.0975",
    "lng": "-100.51417"
  },
  {
    "country": "MX",
    "name": "Las Primaveras [Invernadero]",
    "lat": "19.69472",
    "lng": "-103.83333"
  },
  {
    "country": "MX",
    "name": "Miguel Negrete",
    "lat": "18.95222",
    "lng": "-97.82917"
  },
  {
    "country": "MX",
    "name": "Camémbaro",
    "lat": "19.42722",
    "lng": "-100.39889"
  },
  {
    "country": "MX",
    "name": "San Clemente de Lima",
    "lat": "20.73722",
    "lng": "-105.27083"
  },
  {
    "country": "MX",
    "name": "El Siviral (Jigica)",
    "lat": "27.10222",
    "lng": "-109.50083"
  },
  {
    "country": "MX",
    "name": "José Colomo",
    "lat": "17.94691",
    "lng": "-92.46659"
  },
  {
    "country": "MX",
    "name": "Colonia Rafael Corrales Ayala",
    "lat": "20.90194",
    "lng": "-101.51611"
  },
  {
    "country": "MX",
    "name": "Doxteje Barrio Primero",
    "lat": "19.95972",
    "lng": "-99.95861"
  },
  {
    "country": "MX",
    "name": "Las Pintas",
    "lat": "19.89667",
    "lng": "-98.88694"
  },
  {
    "country": "MX",
    "name": "Villa Tejúpam de la Unión",
    "lat": "17.6625",
    "lng": "-97.47083"
  },
  {
    "country": "MX",
    "name": "Paso Blanco",
    "lat": "22.20611",
    "lng": "-101.07056"
  },
  {
    "country": "MX",
    "name": "Jalmolonga (La Hacienda)",
    "lat": "18.91835",
    "lng": "-99.49407"
  },
  {
    "country": "MX",
    "name": "Cuto de la Esperanza",
    "lat": "19.73083",
    "lng": "-101.34028"
  },
  {
    "country": "MX",
    "name": "El Capulo (La Quebradora)",
    "lat": "18.94944",
    "lng": "-98.26889"
  },
  {
    "country": "MX",
    "name": "San Andrés Yahuitlalpan",
    "lat": "19.67333",
    "lng": "-97.72694"
  },
  {
    "country": "MX",
    "name": "Colonia Alborada",
    "lat": "16.88151",
    "lng": "-99.81779"
  },
  {
    "country": "MX",
    "name": "La Concordia",
    "lat": "16.90583",
    "lng": "-98.97583"
  },
  {
    "country": "MX",
    "name": "Ejido Miraflores",
    "lat": "19.57",
    "lng": "-99.3975"
  },
  {
    "country": "MX",
    "name": "Fraccionamiento Carlos Salinas de Gortari",
    "lat": "20.11028",
    "lng": "-98.43028"
  },
  {
    "country": "MX",
    "name": "San José Mezapa Sección I",
    "lat": "19.16306",
    "lng": "-99.455"
  },
  {
    "country": "MX",
    "name": "Colonia la Calzada (La Olla)",
    "lat": "20.50278",
    "lng": "-100.95889"
  },
  {
    "country": "MX",
    "name": "La Junta",
    "lat": "17.82778",
    "lng": "-97.74556"
  },
  {
    "country": "MX",
    "name": "Unión Agropecuarios Lázaro Cárdenas del Norte",
    "lat": "25.83222",
    "lng": "-100.38417"
  },
  {
    "country": "MX",
    "name": "Pueblo Nuevo",
    "lat": "19.14083",
    "lng": "-99.42639"
  },
  {
    "country": "MX",
    "name": "Candelaria Portezuelo",
    "lat": "19.04194",
    "lng": "-97.70083"
  },
  {
    "country": "MX",
    "name": "Unión Juárez",
    "lat": "17.28083",
    "lng": "-92.39972"
  },
  {
    "country": "MX",
    "name": "Colonia Palo Prieto (Chipitongo)",
    "lat": "18.70417",
    "lng": "-99.11278"
  },
  {
    "country": "MX",
    "name": "Peña Colorada",
    "lat": "17.47778",
    "lng": "-97.79417"
  },
  {
    "country": "MX",
    "name": "Tetlatzinga",
    "lat": "18.69472",
    "lng": "-97.18444"
  },
  {
    "country": "MX",
    "name": "Rinconadas de San Francisco",
    "lat": "20.06611",
    "lng": "-98.76806"
  },
  {
    "country": "MX",
    "name": "Nuevo Carmen Tonapac",
    "lat": "16.69667",
    "lng": "-92.95556"
  },
  {
    "country": "MX",
    "name": "Las Plazuelas",
    "lat": "16.87417",
    "lng": "-99.78556"
  },
  {
    "country": "MX",
    "name": "El Progreso Hidalgo",
    "lat": "18.84639",
    "lng": "-99.61417"
  },
  {
    "country": "MX",
    "name": "Las Torres de Guadalupe",
    "lat": "25.80611",
    "lng": "-100.6225"
  },
  {
    "country": "MX",
    "name": "San Miguel Tlamahuco",
    "lat": "19.32417",
    "lng": "-98.23972"
  },
  {
    "country": "MX",
    "name": "El Huidero",
    "lat": "18.3875",
    "lng": "-95.17917"
  },
  {
    "country": "MX",
    "name": "San José Barbabosa",
    "lat": "19.27583",
    "lng": "-99.72"
  },
  {
    "country": "MX",
    "name": "Rancho Grande",
    "lat": "18.35389",
    "lng": "-96.34944"
  },
  {
    "country": "MX",
    "name": "Caobanal 1ra. Sección (Mezcalapa)",
    "lat": "17.64858",
    "lng": "-93.39464"
  },
  {
    "country": "MX",
    "name": "Rancho de Guadalupe",
    "lat": "21.21639",
    "lng": "-101.01"
  },
  {
    "country": "MX",
    "name": "Estación Corralejo",
    "lat": "20.47",
    "lng": "-101.61639"
  },
  {
    "country": "MX",
    "name": "Melchor Ocampo",
    "lat": "17.35895",
    "lng": "-98.44754"
  },
  {
    "country": "MX",
    "name": "Tlacpac",
    "lat": "20.14889",
    "lng": "-98.21694"
  },
  {
    "country": "MX",
    "name": "Colonia el Florido",
    "lat": "18.73833",
    "lng": "-99.36722"
  },
  {
    "country": "MX",
    "name": "Tlamaya Grande",
    "lat": "20.14689",
    "lng": "-97.80313"
  },
  {
    "country": "MX",
    "name": "Loma del Refugio",
    "lat": "27.12194",
    "lng": "-109.45917"
  },
  {
    "country": "MX",
    "name": "Unidos Avanzamos",
    "lat": "22.43389",
    "lng": "-97.97167"
  },
  {
    "country": "MX",
    "name": "El Progreso",
    "lat": "16.30278",
    "lng": "-91.92667"
  },
  {
    "country": "MX",
    "name": "Moyotepec (Moyotepec de Juárez)",
    "lat": "17.33167",
    "lng": "-98.68556"
  },
  {
    "country": "MX",
    "name": "Tlaminca",
    "lat": "19.13571",
    "lng": "-99.43999"
  },
  {
    "country": "MX",
    "name": "Cenobio Aguilar (La Trinidad)",
    "lat": "17.40472",
    "lng": "-92.31944"
  },
  {
    "country": "MX",
    "name": "Cruz Verde",
    "lat": "19.1375",
    "lng": "-97.10861"
  },
  {
    "country": "MX",
    "name": "Joltealal",
    "lat": "17.07683",
    "lng": "-92.62163"
  },
  {
    "country": "MX",
    "name": "Rancho Nuevo del Llanito",
    "lat": "20.82361",
    "lng": "-101.36861"
  },
  {
    "country": "MX",
    "name": "Oriental de Zapata",
    "lat": "19.98528",
    "lng": "-99.03167"
  },
  {
    "country": "MX",
    "name": "Colonia San Francisco",
    "lat": "18.89611",
    "lng": "-98.90361"
  },
  {
    "country": "MX",
    "name": "Ignacio Zaragoza",
    "lat": "19.27889",
    "lng": "-97.19944"
  },
  {
    "country": "MX",
    "name": "Nuevo Refugio de Afuera (Nuevo Refugio)",
    "lat": "20.54889",
    "lng": "-102.70722"
  },
  {
    "country": "MX",
    "name": "Iratzio",
    "lat": "19.64583",
    "lng": "-101.41194"
  },
  {
    "country": "MX",
    "name": "San Pedro Tlapacoyan",
    "lat": "20.05806",
    "lng": "-97.09833"
  },
  {
    "country": "MX",
    "name": "Nueva Ameyalco",
    "lat": "19.29167",
    "lng": "-99.50556"
  },
  {
    "country": "MX",
    "name": "Puerto de Chiquihuite",
    "lat": "20.70083",
    "lng": "-99.83528"
  },
  {
    "country": "MX",
    "name": "El Bajío (La Laguna)",
    "lat": "21.37944",
    "lng": "-101.95028"
  },
  {
    "country": "MX",
    "name": "El Colorado",
    "lat": "20.09639",
    "lng": "-99.76278"
  },
  {
    "country": "MX",
    "name": "Honey",
    "lat": "20.23885",
    "lng": "-98.21253"
  },
  {
    "country": "MX",
    "name": "Nuevo Necaxa",
    "lat": "20.21049",
    "lng": "-98.00657"
  },
  {
    "country": "MX",
    "name": "Espinal",
    "lat": "20.25817",
    "lng": "-97.40028"
  },
  {
    "country": "MX",
    "name": "Juamave",
    "lat": "23.40578",
    "lng": "-99.38044"
  },
  {
    "country": "MX",
    "name": "Chimaltitán",
    "lat": "21.77977",
    "lng": "-103.78071"
  },
  {
    "country": "MX",
    "name": "Benito Juárez",
    "lat": "19.31351",
    "lng": "-100.43358"
  },
  {
    "country": "MX",
    "name": "Tecoanapa",
    "lat": "16.98771",
    "lng": "-99.26002"
  },
  {
    "country": "MX",
    "name": "Santa Lucía Ocotlán",
    "lat": "16.73834",
    "lng": "-96.67962"
  },
  {
    "country": "MX",
    "name": "El Guayabito",
    "lat": "19.94956",
    "lng": "-102.44414"
  },
  {
    "country": "MX",
    "name": "Tlacolulan",
    "lat": "19.66687",
    "lng": "-97.00194"
  },
  {
    "country": "MX",
    "name": "Zumpahuacán",
    "lat": "18.83723",
    "lng": "-99.5808"
  },
  {
    "country": "MX",
    "name": "Colonia del Sol",
    "lat": "22.91273",
    "lng": "-109.92655"
  },
  {
    "country": "MX",
    "name": "Nezahualcóyotl",
    "lat": "19.38763",
    "lng": "-98.99264"
  },
  {
    "country": "MX",
    "name": "Candelaria",
    "lat": "18.18574",
    "lng": "-91.04534"
  },
  {
    "country": "MX",
    "name": "Minatitlán",
    "lat": "19.38757",
    "lng": "-104.04986"
  },
  {
    "country": "MX",
    "name": "Santa Cruz Quilehtla",
    "lat": "19.21525",
    "lng": "-98.22178"
  },
  {
    "country": "MX",
    "name": "Tres Valles",
    "lat": "18.23915",
    "lng": "-96.13569"
  },
  {
    "country": "MX",
    "name": "Ixhuatlán del Sureste",
    "lat": "18.02137",
    "lng": "-94.3886"
  },
  {
    "country": "MY",
    "name": "Padang Mat Sirat",
    "lat": "6.35423",
    "lng": "99.73404"
  },
  {
    "country": "MY",
    "name": "Ayer Hangat",
    "lat": "6.42062",
    "lng": "99.82199"
  },
  {
    "country": "MY",
    "name": "Kuah",
    "lat": "6.32649",
    "lng": "99.8432"
  },
  {
    "country": "MY",
    "name": "Jerantut",
    "lat": "3.936",
    "lng": "102.3626"
  },
  {
    "country": "MY",
    "name": "Raub",
    "lat": "3.7899",
    "lng": "101.857"
  },
  {
    "country": "MY",
    "name": "Batu Pahat",
    "lat": "1.8548",
    "lng": "102.9325"
  },
  {
    "country": "MY",
    "name": "Parit Raja",
    "lat": "1.8681",
    "lng": "103.1124"
  },
  {
    "country": "MY",
    "name": "Pekan Nenas",
    "lat": "1.51",
    "lng": "103.5141"
  },
  {
    "country": "MY",
    "name": "Pontian Kechil",
    "lat": "1.4866",
    "lng": "103.3896"
  },
  {
    "country": "MY",
    "name": "Kampung Pasir Gudang Baru",
    "lat": "1.4726",
    "lng": "103.878"
  },
  {
    "country": "MY",
    "name": "Kota Tinggi",
    "lat": "1.7381",
    "lng": "103.8999"
  },
  {
    "country": "MY",
    "name": "Taman Senai",
    "lat": "1.6006",
    "lng": "103.6419"
  },
  {
    "country": "MY",
    "name": "Kulai",
    "lat": "1.6561",
    "lng": "103.6032"
  },
  {
    "country": "MY",
    "name": "Skudai",
    "lat": "1.53741",
    "lng": "103.65779"
  },
  {
    "country": "MY",
    "name": "Johor Bahru",
    "lat": "1.4655",
    "lng": "103.7578"
  },
  {
    "country": "MY",
    "name": "Kluang",
    "lat": "2.03046",
    "lng": "103.31689"
  },
  {
    "country": "MY",
    "name": "Yong Peng",
    "lat": "2.0136",
    "lng": "103.0659"
  },
  {
    "country": "MY",
    "name": "Mersing",
    "lat": "2.4312",
    "lng": "103.8405"
  },
  {
    "country": "MY",
    "name": "Segamat",
    "lat": "2.5148",
    "lng": "102.8158"
  },
  {
    "country": "MY",
    "name": "Tangkak",
    "lat": "2.2673",
    "lng": "102.5453"
  },
  {
    "country": "MY",
    "name": "Muar",
    "lat": "2.0442",
    "lng": "102.5689"
  },
  {
    "country": "MY",
    "name": "Bakri",
    "lat": "2.0441",
    "lng": "102.6527"
  },
  {
    "country": "MY",
    "name": "Labis",
    "lat": "2.385",
    "lng": "103.021"
  },
  {
    "country": "MY",
    "name": "Chaah",
    "lat": "2.249",
    "lng": "103.048"
  },
  {
    "country": "MY",
    "name": "Kuala Selangor",
    "lat": "3.35",
    "lng": "101.25"
  },
  {
    "country": "MY",
    "name": "Batang Berjuntai",
    "lat": "3.38333",
    "lng": "101.41667"
  },
  {
    "country": "MY",
    "name": "Batu Arang",
    "lat": "3.31667",
    "lng": "101.46667"
  },
  {
    "country": "MY",
    "name": "Shah Alam",
    "lat": "3.08507",
    "lng": "101.53281"
  },
  {
    "country": "MY",
    "name": "Klang",
    "lat": "3.03333",
    "lng": "101.45"
  },
  {
    "country": "MY",
    "name": "Cukai",
    "lat": "4.25",
    "lng": "103.41667"
  },
  {
    "country": "MY",
    "name": "Kuala Lipis",
    "lat": "4.1842",
    "lng": "102.0468"
  },
  {
    "country": "MY",
    "name": "Papar",
    "lat": "5.73333",
    "lng": "115.93333"
  },
  {
    "country": "MY",
    "name": "Kota Kinabalu",
    "lat": "5.9749",
    "lng": "116.0724"
  },
  {
    "country": "MY",
    "name": "Donggongon",
    "lat": "5.90702",
    "lng": "116.10146"
  },
  {
    "country": "MY",
    "name": "Putatan",
    "lat": "5.9258",
    "lng": "116.06094"
  },
  {
    "country": "MY",
    "name": "Kinarut",
    "lat": "5.8231",
    "lng": "116.0466"
  },
  {
    "country": "MY",
    "name": "Ranau",
    "lat": "5.9538",
    "lng": "116.6641"
  },
  {
    "country": "MY",
    "name": "Semporna",
    "lat": "4.48178",
    "lng": "118.61119"
  },
  {
    "country": "MY",
    "name": "Victoria",
    "lat": "5.27667",
    "lng": "115.24167"
  },
  {
    "country": "MY",
    "name": "Beaufort",
    "lat": "5.3473",
    "lng": "115.7455"
  },
  {
    "country": "MY",
    "name": "Lahad Datu",
    "lat": "5.02298",
    "lng": "118.32897"
  },
  {
    "country": "MY",
    "name": "Sandakan",
    "lat": "5.8402",
    "lng": "118.1179"
  },
  {
    "country": "MY",
    "name": "Keningau",
    "lat": "5.3378",
    "lng": "116.1602"
  },
  {
    "country": "MY",
    "name": "Tawau",
    "lat": "4.24482",
    "lng": "117.89115"
  },
  {
    "country": "MY",
    "name": "Paka",
    "lat": "4.6374",
    "lng": "103.4368"
  },
  {
    "country": "MY",
    "name": "Kertih",
    "lat": "4.5141",
    "lng": "103.4483"
  },
  {
    "country": "MY",
    "name": "Kulim",
    "lat": "5.36499",
    "lng": "100.56177"
  },
  {
    "country": "MY",
    "name": "Bagan Serai",
    "lat": "5.0108",
    "lng": "100.54101"
  },
  {
    "country": "MY",
    "name": "Bedong",
    "lat": "5.72743",
    "lng": "100.50876"
  },
  {
    "country": "MY",
    "name": "Simpang Empat",
    "lat": "4.95",
    "lng": "100.63333"
  },
  {
    "country": "MY",
    "name": "Taiping",
    "lat": "4.85",
    "lng": "100.73333"
  },
  {
    "country": "MY",
    "name": "Kuala Kangsar",
    "lat": "4.76667",
    "lng": "100.93333"
  },
  {
    "country": "MY",
    "name": "Ipoh",
    "lat": "4.5841",
    "lng": "101.0829"
  },
  {
    "country": "MY",
    "name": "Gua Musang",
    "lat": "4.88441",
    "lng": "101.96857"
  },
  {
    "country": "MY",
    "name": "Kuala Terengganu",
    "lat": "5.3302",
    "lng": "103.1408"
  },
  {
    "country": "MY",
    "name": "Marang",
    "lat": "5.2056",
    "lng": "103.2059"
  },
  {
    "country": "MY",
    "name": "Tampin",
    "lat": "2.4701",
    "lng": "102.2302"
  },
  {
    "country": "MY",
    "name": "Alor Gajah",
    "lat": "2.3804",
    "lng": "102.2089"
  },
  {
    "country": "MY",
    "name": "Kampung Ayer Keroh",
    "lat": "2.2654",
    "lng": "102.2801"
  },
  {
    "country": "MY",
    "name": "Sungai Udang",
    "lat": "2.269",
    "lng": "102.1427"
  },
  {
    "country": "MY",
    "name": "Malacca",
    "lat": "2.196",
    "lng": "102.2405"
  },
  {
    "country": "MY",
    "name": "Pelabuhan Klang",
    "lat": "2.99959",
    "lng": "101.39287"
  },
  {
    "country": "MY",
    "name": "Banting",
    "lat": "2.8136",
    "lng": "101.50185"
  },
  {
    "country": "MY",
    "name": "Jenjarum",
    "lat": "2.8724",
    "lng": "101.49484"
  },
  {
    "country": "MY",
    "name": "Semenyih",
    "lat": "2.9516",
    "lng": "101.843"
  },
  {
    "country": "MY",
    "name": "Seremban",
    "lat": "2.7297",
    "lng": "101.9381"
  },
  {
    "country": "MY",
    "name": "Port Dickson",
    "lat": "2.53718",
    "lng": "101.80571"
  },
  {
    "country": "MY",
    "name": "Sepang",
    "lat": "2.6931",
    "lng": "101.7498"
  },
  {
    "country": "MY",
    "name": "Bahau",
    "lat": "2.8079",
    "lng": "102.4049"
  },
  {
    "country": "MY",
    "name": "Kuala Pilah",
    "lat": "2.7389",
    "lng": "102.2487"
  },
  {
    "country": "MY",
    "name": "Buloh Kasap",
    "lat": "2.5536",
    "lng": "102.764"
  },
  {
    "country": "MY",
    "name": "Kampung Tekek",
    "lat": "2.8147",
    "lng": "104.1592"
  },
  {
    "country": "MY",
    "name": "Pekan",
    "lat": "3.4836",
    "lng": "103.3996"
  },
  {
    "country": "MY",
    "name": "Mentekab",
    "lat": "3.4854",
    "lng": "102.3484"
  },
  {
    "country": "MY",
    "name": "Temerluh",
    "lat": "3.4506",
    "lng": "102.4176"
  },
  {
    "country": "MY",
    "name": "Batu Feringgi",
    "lat": "5.4709",
    "lng": "100.24529"
  },
  {
    "country": "MY",
    "name": "Butterworth",
    "lat": "5.3991",
    "lng": "100.36382"
  },
  {
    "country": "MY",
    "name": "Perai",
    "lat": "5.38333",
    "lng": "100.38333"
  },
  {
    "country": "MY",
    "name": "Bukit Mertajam",
    "lat": "5.36301",
    "lng": "100.4667"
  },
  {
    "country": "MY",
    "name": "Nibong Tebal",
    "lat": "5.16586",
    "lng": "100.47793"
  },
  {
    "country": "MY",
    "name": "Parit Buntar",
    "lat": "5.12671",
    "lng": "100.49316"
  },
  {
    "country": "MY",
    "name": "Tasek Glugor",
    "lat": "5.48032",
    "lng": "100.49849"
  },
  {
    "country": "MY",
    "name": "George Town",
    "lat": "5.41123",
    "lng": "100.33543"
  },
  {
    "country": "MY",
    "name": "Kampung Bukit Tinggi, Bentong",
    "lat": "3.34944",
    "lng": "101.82631"
  },
  {
    "country": "MY",
    "name": "Serendah",
    "lat": "3.3646",
    "lng": "101.6041"
  },
  {
    "country": "MY",
    "name": "Rawang",
    "lat": "3.3213",
    "lng": "101.5767"
  },
  {
    "country": "MY",
    "name": "Petaling Jaya",
    "lat": "3.10726",
    "lng": "101.60671"
  },
  {
    "country": "MY",
    "name": "Kuala Lumpur",
    "lat": "3.1412",
    "lng": "101.68653"
  },
  {
    "country": "MY",
    "name": "Sabak Bernam",
    "lat": "3.7698",
    "lng": "100.9879"
  },
  {
    "country": "MY",
    "name": "Sungai Besar",
    "lat": "3.6746",
    "lng": "100.9867"
  },
  {
    "country": "MY",
    "name": "Kuantan",
    "lat": "3.8077",
    "lng": "103.326"
  },
  {
    "country": "MY",
    "name": "Tanah Rata",
    "lat": "4.46361",
    "lng": "101.3763"
  },
  {
    "country": "MY",
    "name": "Batu Gajah",
    "lat": "4.46916",
    "lng": "101.04107"
  },
  {
    "country": "MY",
    "name": "Kampar",
    "lat": "4.3",
    "lng": "101.15"
  },
  {
    "country": "MY",
    "name": "Tapah Road",
    "lat": "4.16667",
    "lng": "101.2"
  },
  {
    "country": "MY",
    "name": "Bidur",
    "lat": "4.11667",
    "lng": "101.28333"
  },
  {
    "country": "MY",
    "name": "Lumut",
    "lat": "4.2323",
    "lng": "100.6298"
  },
  {
    "country": "MY",
    "name": "Teluk Intan",
    "lat": "4.02219",
    "lng": "101.02083"
  },
  {
    "country": "MY",
    "name": "Gurun",
    "lat": "5.81717",
    "lng": "100.47381"
  },
  {
    "country": "MY",
    "name": "Sungai Petani",
    "lat": "5.647",
    "lng": "100.48772"
  },
  {
    "country": "MY",
    "name": "Kepala Batas",
    "lat": "5.51707",
    "lng": "100.4265"
  },
  {
    "country": "MY",
    "name": "Ketereh",
    "lat": "5.95701",
    "lng": "102.24817"
  },
  {
    "country": "MY",
    "name": "Pulai Chondong",
    "lat": "5.87133",
    "lng": "102.23177"
  },
  {
    "country": "MY",
    "name": "Tanah Merah",
    "lat": "5.8",
    "lng": "102.15"
  },
  {
    "country": "MY",
    "name": "Kuching",
    "lat": "1.55",
    "lng": "110.33333"
  },
  {
    "country": "MY",
    "name": "Simanggang",
    "lat": "1.24722",
    "lng": "111.45278"
  },
  {
    "country": "MY",
    "name": "Sarikei",
    "lat": "2.11667",
    "lng": "111.51667"
  },
  {
    "country": "MY",
    "name": "Sibu",
    "lat": "2.3",
    "lng": "111.81667"
  },
  {
    "country": "MY",
    "name": "Kangar",
    "lat": "6.4414",
    "lng": "100.19862"
  },
  {
    "country": "MY",
    "name": "Kuala Perlis",
    "lat": "6.4",
    "lng": "100.13333"
  },
  {
    "country": "MY",
    "name": "Jitra",
    "lat": "6.26812",
    "lng": "100.42167"
  },
  {
    "country": "MY",
    "name": "Kuala Kedah",
    "lat": "6.1",
    "lng": "100.3"
  },
  {
    "country": "MY",
    "name": "Alor Setar",
    "lat": "6.12104",
    "lng": "100.36014"
  },
  {
    "country": "MY",
    "name": "Tumpat",
    "lat": "6.19775",
    "lng": "102.17098"
  },
  {
    "country": "MY",
    "name": "Pasir Mas",
    "lat": "6.04934",
    "lng": "102.13987"
  },
  {
    "country": "MY",
    "name": "Kota Bharu",
    "lat": "6.13328",
    "lng": "102.2386"
  },
  {
    "country": "MY",
    "name": "Kuala Besut",
    "lat": "5.83303",
    "lng": "102.55514"
  },
  {
    "country": "MY",
    "name": "Jertih",
    "lat": "5.7336",
    "lng": "102.4897"
  },
  {
    "country": "MY",
    "name": "Kudat",
    "lat": "6.88732",
    "lng": "116.82364"
  },
  {
    "country": "MY",
    "name": "Kota Belud",
    "lat": "6.351",
    "lng": "116.4305"
  },
  {
    "country": "MY",
    "name": "Kapit",
    "lat": "1.99546",
    "lng": "112.93254"
  },
  {
    "country": "MY",
    "name": "Bintulu",
    "lat": "3.16667",
    "lng": "113.03333"
  },
  {
    "country": "MY",
    "name": "Limbang",
    "lat": "4.75",
    "lng": "115"
  },
  {
    "country": "MY",
    "name": "Miri",
    "lat": "4.39928",
    "lng": "113.99163"
  },
  {
    "country": "MY",
    "name": "Ulu Tiram",
    "lat": "1.6",
    "lng": "103.81667"
  },
  {
    "country": "MY",
    "name": "Telaga Batu",
    "lat": "5.46667",
    "lng": "100.23333"
  },
  {
    "country": "MY",
    "name": "Tanjung Tokong",
    "lat": "5.46061",
    "lng": "100.30742"
  },
  {
    "country": "MY",
    "name": "Tanjung Sepat",
    "lat": "2.6579",
    "lng": "101.5629"
  },
  {
    "country": "MY",
    "name": "Sungai Pelek New Village",
    "lat": "2.65",
    "lng": "101.7"
  },
  {
    "country": "MY",
    "name": "Pulau Sebang",
    "lat": "2.455",
    "lng": "102.2329"
  },
  {
    "country": "MY",
    "name": "Permatang Kuching",
    "lat": "5.46339",
    "lng": "100.38144"
  },
  {
    "country": "MY",
    "name": "Peringat",
    "lat": "6.03333",
    "lng": "102.28333"
  },
  {
    "country": "MY",
    "name": "Ladang Seri Kundang",
    "lat": "3.2856",
    "lng": "101.519"
  },
  {
    "country": "MY",
    "name": "Pantai Remis",
    "lat": "4.4557",
    "lng": "100.6288"
  },
  {
    "country": "MY",
    "name": "Kuang",
    "lat": "3.2594",
    "lng": "101.5541"
  },
  {
    "country": "MY",
    "name": "Kuala Sungai Baru",
    "lat": "2.3594",
    "lng": "102.0353"
  },
  {
    "country": "MY",
    "name": "Klebang Besar",
    "lat": "2.2186",
    "lng": "102.1995"
  },
  {
    "country": "MY",
    "name": "Kelapa Sawit",
    "lat": "1.6698",
    "lng": "103.5327"
  },
  {
    "country": "MY",
    "name": "Kampung Tanjung Karang",
    "lat": "3.4242",
    "lng": "101.1849"
  },
  {
    "country": "MY",
    "name": "Kampung Sungai Ara",
    "lat": "5.32699",
    "lng": "100.27348"
  },
  {
    "country": "MY",
    "name": "Kampung Simpang Renggam",
    "lat": "1.8278",
    "lng": "103.3"
  },
  {
    "country": "MY",
    "name": "Kampong Pangkal Kalong",
    "lat": "5.91667",
    "lng": "102.21667"
  },
  {
    "country": "MY",
    "name": "Kampong Masjid Tanah",
    "lat": "2.35",
    "lng": "102.11667"
  },
  {
    "country": "MY",
    "name": "Kampong Kadok",
    "lat": "6",
    "lng": "102.25"
  },
  {
    "country": "MY",
    "name": "Kampong Dungun",
    "lat": "3.21667",
    "lng": "101.31667"
  },
  {
    "country": "MY",
    "name": "Kampung Bukit Baharu",
    "lat": "2.2152",
    "lng": "102.2851"
  },
  {
    "country": "MY",
    "name": "Kampung Batu Feringgi",
    "lat": "5.46948",
    "lng": "100.24449"
  },
  {
    "country": "MY",
    "name": "Kampung Baru Subang",
    "lat": "3.15",
    "lng": "101.53333"
  },
  {
    "country": "MY",
    "name": "Kampung Baharu Nilai",
    "lat": "2.8033",
    "lng": "101.7972"
  },
  {
    "country": "MY",
    "name": "Kampong Baharu Balakong",
    "lat": "3.03333",
    "lng": "101.75"
  },
  {
    "country": "MY",
    "name": "Kampung Ayer Molek",
    "lat": "2.2139",
    "lng": "102.3278"
  },
  {
    "country": "MY",
    "name": "Juru",
    "lat": "5.31201",
    "lng": "100.44229"
  },
  {
    "country": "MY",
    "name": "Bukit Rambai",
    "lat": "2.2594",
    "lng": "102.1838"
  },
  {
    "country": "MY",
    "name": "Bentong Town",
    "lat": "3.52229",
    "lng": "101.90866"
  },
  {
    "country": "MY",
    "name": "Bemban",
    "lat": "2.2684",
    "lng": "102.3746"
  },
  {
    "country": "MY",
    "name": "Batu Berendam",
    "lat": "2.2487",
    "lng": "102.246"
  },
  {
    "country": "MY",
    "name": "Bagan Pulau Ketam",
    "lat": "3.01667",
    "lng": "101.26667"
  },
  {
    "country": "MY",
    "name": "Putrajaya",
    "lat": "2.93527",
    "lng": "101.69112"
  },
  {
    "country": "MY",
    "name": "Kampung Kilim",
    "lat": "6.4055",
    "lng": "99.8502"
  },
  {
    "country": "MY",
    "name": "Kampung Kok",
    "lat": "6.36759",
    "lng": "99.68252"
  },
  {
    "country": "MY",
    "name": "Kuala Teriang",
    "lat": "6.36377",
    "lng": "99.71532"
  },
  {
    "country": "MY",
    "name": "Kampung Kuala Besut",
    "lat": "5.83297",
    "lng": "102.55061"
  },
  {
    "country": "MY",
    "name": "Kampung Lemal",
    "lat": "6.03021",
    "lng": "102.14126"
  },
  {
    "country": "MY",
    "name": "Bandar Labuan",
    "lat": "5.28883",
    "lng": "115.26924"
  },
  {
    "country": "MY",
    "name": "Data Kakus",
    "lat": "2.65465",
    "lng": "113.62249"
  },
  {
    "country": "MY",
    "name": "Subang Jaya",
    "lat": "3.04384",
    "lng": "101.58062"
  },
  {
    "country": "MY",
    "name": "Taman Rajawali",
    "lat": "5.89477",
    "lng": "118.04576"
  },
  {
    "country": "MY",
    "name": "Lidung Jelo",
    "lat": "2.64848",
    "lng": "114.78653"
  },
  {
    "country": "MY",
    "name": "Long Ampan Aing or Abanang",
    "lat": "2.65671",
    "lng": "114.73675"
  },
  {
    "country": "MY",
    "name": "Putra Heights",
    "lat": "2.99361",
    "lng": "101.57255"
  },
  {
    "country": "MY",
    "name": "Pantai Cenang",
    "lat": "6.29369",
    "lng": "99.72786"
  },
  {
    "country": "MZ",
    "name": "Xai-Xai",
    "lat": "-25.05194",
    "lng": "33.64417"
  },
  {
    "country": "MZ",
    "name": "Dondo",
    "lat": "-19.60944",
    "lng": "34.74306"
  },
  {
    "country": "MZ",
    "name": "Macia",
    "lat": "-25.02694",
    "lng": "33.09889"
  },
  {
    "country": "MZ",
    "name": "Tete",
    "lat": "-16.15639",
    "lng": "33.58667"
  },
  {
    "country": "MZ",
    "name": "Ressano Garcia",
    "lat": "-25.44278",
    "lng": "31.99528"
  },
  {
    "country": "MZ",
    "name": "Quelimane",
    "lat": "-17.87861",
    "lng": "36.88833"
  },
  {
    "country": "MZ",
    "name": "Pemba",
    "lat": "-12.97395",
    "lng": "40.51775"
  },
  {
    "country": "MZ",
    "name": "Nampula",
    "lat": "-15.11646",
    "lng": "39.2666"
  },
  {
    "country": "MZ",
    "name": "Nacala",
    "lat": "-14.56257",
    "lng": "40.68538"
  },
  {
    "country": "MZ",
    "name": "Montepuez",
    "lat": "-13.12556",
    "lng": "38.99972"
  },
  {
    "country": "MZ",
    "name": "Mocímboa",
    "lat": "-11.31667",
    "lng": "40.35"
  },
  {
    "country": "MZ",
    "name": "Ilha de Moçambique",
    "lat": "-15.03417",
    "lng": "40.73583"
  },
  {
    "country": "MZ",
    "name": "Maxixe",
    "lat": "-23.85972",
    "lng": "35.34722"
  },
  {
    "country": "MZ",
    "name": "Matola",
    "lat": "-25.96222",
    "lng": "32.45889"
  },
  {
    "country": "MZ",
    "name": "Maputo",
    "lat": "-25.96553",
    "lng": "32.58322"
  },
  {
    "country": "MZ",
    "name": "Manjacaze",
    "lat": "-24.71167",
    "lng": "33.88278"
  },
  {
    "country": "MZ",
    "name": "Manhiça",
    "lat": "-25.40222",
    "lng": "32.80722"
  },
  {
    "country": "MZ",
    "name": "Lichinga",
    "lat": "-13.31278",
    "lng": "35.24056"
  },
  {
    "country": "MZ",
    "name": "Inhambane",
    "lat": "-23.865",
    "lng": "35.38333"
  },
  {
    "country": "MZ",
    "name": "Cuamba",
    "lat": "-14.80306",
    "lng": "36.53722"
  },
  {
    "country": "MZ",
    "name": "Chokwé",
    "lat": "-24.53333",
    "lng": "32.98333"
  },
  {
    "country": "MZ",
    "name": "Chimoio",
    "lat": "-19.11639",
    "lng": "33.48333"
  },
  {
    "country": "MZ",
    "name": "Chibuto",
    "lat": "-24.68667",
    "lng": "33.53056"
  },
  {
    "country": "MZ",
    "name": "Beira",
    "lat": "-19.84361",
    "lng": "34.83889"
  },
  {
    "country": "MZ",
    "name": "António Enes",
    "lat": "-16.2325",
    "lng": "39.90861"
  },
  {
    "country": "MZ",
    "name": "Mutuáli",
    "lat": "-14.87056",
    "lng": "37.00444"
  },
  {
    "country": "NA",
    "name": "Katima Mulilo",
    "lat": "-17.5",
    "lng": "24.26667"
  },
  {
    "country": "NA",
    "name": "Bagani",
    "lat": "-18.11065",
    "lng": "21.61645"
  },
  {
    "country": "NA",
    "name": "Windhoek",
    "lat": "-22.55941",
    "lng": "17.08323"
  },
  {
    "country": "NA",
    "name": "Warmbad",
    "lat": "-28.45",
    "lng": "18.73333"
  },
  {
    "country": "NA",
    "name": "Usakos",
    "lat": "-22",
    "lng": "15.6"
  },
  {
    "country": "NA",
    "name": "Tsumeb",
    "lat": "-19.23333",
    "lng": "17.71667"
  },
  {
    "country": "NA",
    "name": "Tses",
    "lat": "-25.88333",
    "lng": "18"
  },
  {
    "country": "NA",
    "name": "Swakopmund",
    "lat": "-22.67842",
    "lng": "14.52663"
  },
  {
    "country": "NA",
    "name": "Rundu",
    "lat": "-17.93333",
    "lng": "19.76667"
  },
  {
    "country": "NA",
    "name": "Rehoboth",
    "lat": "-23.317",
    "lng": "17.09"
  },
  {
    "country": "NA",
    "name": "Outjo",
    "lat": "-20.11667",
    "lng": "16.15"
  },
  {
    "country": "NA",
    "name": "Otjiwarongo",
    "lat": "-20.46369",
    "lng": "16.64772"
  },
  {
    "country": "NA",
    "name": "Otjimbingwe",
    "lat": "-22.35",
    "lng": "16.13333"
  },
  {
    "country": "NA",
    "name": "Otavi",
    "lat": "-19.65",
    "lng": "17.33333"
  },
  {
    "country": "NA",
    "name": "Oshikango",
    "lat": "-17.4",
    "lng": "15.88333"
  },
  {
    "country": "NA",
    "name": "Oshakati",
    "lat": "-17.78833",
    "lng": "15.70436"
  },
  {
    "country": "NA",
    "name": "Oranjemund",
    "lat": "-28.55",
    "lng": "16.43333"
  },
  {
    "country": "NA",
    "name": "Opuwo",
    "lat": "-18.06068",
    "lng": "13.83998"
  },
  {
    "country": "NA",
    "name": "Ongwediva",
    "lat": "-17.78333",
    "lng": "15.76667"
  },
  {
    "country": "NA",
    "name": "Ongandjera",
    "lat": "-17.88333",
    "lng": "15.06667"
  },
  {
    "country": "NA",
    "name": "Ondangwa",
    "lat": "-17.91667",
    "lng": "15.95"
  },
  {
    "country": "NA",
    "name": "Omuthiya",
    "lat": "-18.36463",
    "lng": "16.58146"
  },
  {
    "country": "NA",
    "name": "Omaruru",
    "lat": "-21.43333",
    "lng": "15.93333"
  },
  {
    "country": "NA",
    "name": "Okakarara",
    "lat": "-20.58333",
    "lng": "17.43333"
  },
  {
    "country": "NA",
    "name": "Okahandja",
    "lat": "-21.98333",
    "lng": "16.91667"
  },
  {
    "country": "NA",
    "name": "Nkurenkuru",
    "lat": "-17.61667",
    "lng": "18.6"
  },
  {
    "country": "NA",
    "name": "Mariental",
    "lat": "-24.63333",
    "lng": "17.96667"
  },
  {
    "country": "NA",
    "name": "Maltahöhe",
    "lat": "-24.83333",
    "lng": "16.98333"
  },
  {
    "country": "NA",
    "name": "Lüderitz",
    "lat": "-26.64807",
    "lng": "15.15383"
  },
  {
    "country": "NA",
    "name": "Khorixas",
    "lat": "-20.36667",
    "lng": "14.96667"
  },
  {
    "country": "NA",
    "name": "Keetmanshoop",
    "lat": "-26.58333",
    "lng": "18.13333"
  },
  {
    "country": "NA",
    "name": "Katutura",
    "lat": "-22.52306",
    "lng": "17.06028"
  },
  {
    "country": "NA",
    "name": "Karibib",
    "lat": "-21.93333",
    "lng": "15.83333"
  },
  {
    "country": "NA",
    "name": "Karasburg",
    "lat": "-28.01667",
    "lng": "18.75"
  },
  {
    "country": "NA",
    "name": "Hoachanas",
    "lat": "-23.91667",
    "lng": "18.05"
  },
  {
    "country": "NA",
    "name": "Hentiesbaai",
    "lat": "-22.11667",
    "lng": "14.28333"
  },
  {
    "country": "NA",
    "name": "Grootfontein",
    "lat": "-19.56667",
    "lng": "18.11667"
  },
  {
    "country": "NA",
    "name": "Gobabis",
    "lat": "-22.45",
    "lng": "18.96667"
  },
  {
    "country": "NA",
    "name": "Eenhana",
    "lat": "-17.46667",
    "lng": "16.33333"
  },
  {
    "country": "NA",
    "name": "Bethanie",
    "lat": "-26.48333",
    "lng": "17.15"
  },
  {
    "country": "NA",
    "name": "Aranos",
    "lat": "-24.13333",
    "lng": "19.11667"
  },
  {
    "country": "NA",
    "name": "Arandis",
    "lat": "-22.41667",
    "lng": "14.96667"
  },
  {
    "country": "NA",
    "name": "Walvis Bay",
    "lat": "-22.9575",
    "lng": "14.50528"
  },
  {
    "country": "NA",
    "name": "Outapi",
    "lat": "-17.5",
    "lng": "14.98333"
  },
  {
    "country": "NC",
    "name": "Yaté-Barrage",
    "lat": "-22.15",
    "lng": "166.88333"
  },
  {
    "country": "NC",
    "name": "Wé",
    "lat": "-20.91687",
    "lng": "167.26461"
  },
  {
    "country": "NC",
    "name": "Wala",
    "lat": "-19.71161",
    "lng": "163.64702"
  },
  {
    "country": "NC",
    "name": "Voh",
    "lat": "-20.96667",
    "lng": "164.7"
  },
  {
    "country": "NC",
    "name": "Vao",
    "lat": "-22.66645",
    "lng": "167.49627"
  },
  {
    "country": "NC",
    "name": "Touho",
    "lat": "-20.79094",
    "lng": "165.24987"
  },
  {
    "country": "NC",
    "name": "Thio",
    "lat": "-21.61667",
    "lng": "166.21667"
  },
  {
    "country": "NC",
    "name": "Tadine",
    "lat": "-21.55",
    "lng": "167.88333"
  },
  {
    "country": "NC",
    "name": "Poya",
    "lat": "-21.35",
    "lng": "165.15"
  },
  {
    "country": "NC",
    "name": "Poum",
    "lat": "-20.23333",
    "lng": "164.01667"
  },
  {
    "country": "NC",
    "name": "Pouembout",
    "lat": "-21.13333",
    "lng": "164.9"
  },
  {
    "country": "NC",
    "name": "Pouébo",
    "lat": "-20.4",
    "lng": "164.56667"
  },
  {
    "country": "NC",
    "name": "Ponérihouen",
    "lat": "-21.08333",
    "lng": "165.4"
  },
  {
    "country": "NC",
    "name": "Poindimié",
    "lat": "-20.93333",
    "lng": "165.33333"
  },
  {
    "country": "NC",
    "name": "Païta",
    "lat": "-22.13105",
    "lng": "166.35717"
  },
  {
    "country": "NC",
    "name": "Ouégoa",
    "lat": "-20.35",
    "lng": "164.43333"
  },
  {
    "country": "NC",
    "name": "Nouméa",
    "lat": "-22.27407",
    "lng": "166.44884"
  },
  {
    "country": "NC",
    "name": "Mont-Dore",
    "lat": "-22.26257",
    "lng": "166.56621"
  },
  {
    "country": "NC",
    "name": "La Foa",
    "lat": "-21.71079",
    "lng": "165.82764"
  },
  {
    "country": "NC",
    "name": "Koumac",
    "lat": "-20.56667",
    "lng": "164.28333"
  },
  {
    "country": "NC",
    "name": "Koné",
    "lat": "-21.05951",
    "lng": "164.86582"
  },
  {
    "country": "NC",
    "name": "Kaala-Gomén",
    "lat": "-20.66667",
    "lng": "164.4"
  },
  {
    "country": "NC",
    "name": "Houaïlou",
    "lat": "-21.28333",
    "lng": "165.61667"
  },
  {
    "country": "NC",
    "name": "Hienghène",
    "lat": "-20.68333",
    "lng": "164.93333"
  },
  {
    "country": "NC",
    "name": "Fayaoué",
    "lat": "-20.65284",
    "lng": "166.53641"
  },
  {
    "country": "NC",
    "name": "Dumbéa",
    "lat": "-22.15757",
    "lng": "166.4572"
  },
  {
    "country": "NC",
    "name": "Canala",
    "lat": "-21.53333",
    "lng": "165.95"
  },
  {
    "country": "NC",
    "name": "Bourail",
    "lat": "-21.5669",
    "lng": "165.49736"
  },
  {
    "country": "NC",
    "name": "Bouloupari",
    "lat": "-21.86226",
    "lng": "166.05122"
  },
  {
    "country": "NE",
    "name": "Birnin Gaouré",
    "lat": "13.08173",
    "lng": "2.91099"
  },
  {
    "country": "NE",
    "name": "Birni N Konni",
    "lat": "13.79599",
    "lng": "5.25026"
  },
  {
    "country": "NE",
    "name": "Zinder",
    "lat": "13.80716",
    "lng": "8.9881"
  },
  {
    "country": "NE",
    "name": "Tillabéri",
    "lat": "14.20711",
    "lng": "1.45418"
  },
  {
    "country": "NE",
    "name": "Tibiri",
    "lat": "13.56271",
    "lng": "7.04848"
  },
  {
    "country": "NE",
    "name": "Tessaoua",
    "lat": "13.75737",
    "lng": "7.9874"
  },
  {
    "country": "NE",
    "name": "Téra",
    "lat": "14.00776",
    "lng": "0.75306"
  },
  {
    "country": "NE",
    "name": "Tchintabaraden",
    "lat": "15.8969",
    "lng": "5.7985"
  },
  {
    "country": "NE",
    "name": "Tanout",
    "lat": "14.97089",
    "lng": "8.88786"
  },
  {
    "country": "NE",
    "name": "Tahoua",
    "lat": "14.8888",
    "lng": "5.2692"
  },
  {
    "country": "NE",
    "name": "Say",
    "lat": "13.1007",
    "lng": "2.3689"
  },
  {
    "country": "NE",
    "name": "Ouallam",
    "lat": "14.31641",
    "lng": "2.08597"
  },
  {
    "country": "NE",
    "name": "Niamey",
    "lat": "13.51366",
    "lng": "2.1098"
  },
  {
    "country": "NE",
    "name": "Nguigmi",
    "lat": "14.24953",
    "lng": "13.10921"
  },
  {
    "country": "NE",
    "name": "Mirriah",
    "lat": "13.70727",
    "lng": "9.15013"
  },
  {
    "country": "NE",
    "name": "Mayahi",
    "lat": "13.95532",
    "lng": "7.67122"
  },
  {
    "country": "NE",
    "name": "Matamey",
    "lat": "13.42309",
    "lng": "8.47485"
  },
  {
    "country": "NE",
    "name": "Maradi",
    "lat": "13.5",
    "lng": "7.10174"
  },
  {
    "country": "NE",
    "name": "Maïné Soroa",
    "lat": "13.21139",
    "lng": "12.0241"
  },
  {
    "country": "NE",
    "name": "Magaria",
    "lat": "12.99826",
    "lng": "8.90991"
  },
  {
    "country": "NE",
    "name": "Madarounfa",
    "lat": "13.30867",
    "lng": "7.15602"
  },
  {
    "country": "NE",
    "name": "Madaoua",
    "lat": "14.073",
    "lng": "5.96"
  },
  {
    "country": "NE",
    "name": "Loga",
    "lat": "13.6132",
    "lng": "3.2358"
  },
  {
    "country": "NE",
    "name": "Kollo",
    "lat": "13.3043",
    "lng": "2.339"
  },
  {
    "country": "NE",
    "name": "Keïta",
    "lat": "14.7551",
    "lng": "5.7749"
  },
  {
    "country": "NE",
    "name": "Kantché",
    "lat": "13.53926",
    "lng": "8.46293"
  },
  {
    "country": "NE",
    "name": "Illéla",
    "lat": "14.4605",
    "lng": "5.2437"
  },
  {
    "country": "NE",
    "name": "Guidan Roumdji",
    "lat": "13.6576",
    "lng": "6.69567"
  },
  {
    "country": "NE",
    "name": "Gouré",
    "lat": "13.9835",
    "lng": "10.27035"
  },
  {
    "country": "NE",
    "name": "Gaya",
    "lat": "11.88435",
    "lng": "3.44919"
  },
  {
    "country": "NE",
    "name": "Filingué",
    "lat": "14.3521",
    "lng": "3.3168"
  },
  {
    "country": "NE",
    "name": "Dosso",
    "lat": "13.049",
    "lng": "3.1937"
  },
  {
    "country": "NE",
    "name": "Dogondoutchi",
    "lat": "13.6403",
    "lng": "4.02649"
  },
  {
    "country": "NE",
    "name": "Diffa",
    "lat": "13.31536",
    "lng": "12.61135"
  },
  {
    "country": "NE",
    "name": "Dakoro",
    "lat": "14.51056",
    "lng": "6.765"
  },
  {
    "country": "NE",
    "name": "Bouza",
    "lat": "14.42293",
    "lng": "6.04278"
  },
  {
    "country": "NE",
    "name": "Bilma",
    "lat": "18.68532",
    "lng": "12.91643"
  },
  {
    "country": "NE",
    "name": "Ayorou",
    "lat": "14.73075",
    "lng": "0.91739"
  },
  {
    "country": "NE",
    "name": "Arlit",
    "lat": "18.73694",
    "lng": "7.38528"
  },
  {
    "country": "NE",
    "name": "Alaghsas",
    "lat": "17.0187",
    "lng": "8.0168"
  },
  {
    "country": "NE",
    "name": "Aguié",
    "lat": "13.50601",
    "lng": "7.77863"
  },
  {
    "country": "NE",
    "name": "Agadez",
    "lat": "16.97333",
    "lng": "7.99111"
  },
  {
    "country": "NE",
    "name": "Abalak",
    "lat": "15.4509",
    "lng": "6.2793"
  },
  {
    "country": "NE",
    "name": "Tchirozérine",
    "lat": "17.22096",
    "lng": "7.7614"
  },
  {
    "country": "NF",
    "name": "Kingston",
    "lat": "-29.05459",
    "lng": "167.96628"
  },
  {
    "country": "NG",
    "name": "Zuru",
    "lat": "11.43522",
    "lng": "5.23494"
  },
  {
    "country": "NG",
    "name": "Zurmi",
    "lat": "12.77675",
    "lng": "6.78404"
  },
  {
    "country": "NG",
    "name": "Zungeru",
    "lat": "9.80726",
    "lng": "6.15238"
  },
  {
    "country": "NG",
    "name": "Zonkwa",
    "lat": "9.78453",
    "lng": "8.29056"
  },
  {
    "country": "NG",
    "name": "Zing",
    "lat": "8.99064",
    "lng": "11.74763"
  },
  {
    "country": "NG",
    "name": "Zaria",
    "lat": "11.11128",
    "lng": "7.7227"
  },
  {
    "country": "NG",
    "name": "Zango",
    "lat": "13.05313",
    "lng": "8.48574"
  },
  {
    "country": "NG",
    "name": "Zalanga",
    "lat": "10.61432",
    "lng": "10.17647"
  },
  {
    "country": "NG",
    "name": "Zakirai",
    "lat": "12.10033",
    "lng": "8.88524"
  },
  {
    "country": "NG",
    "name": "Zaki Biam",
    "lat": "7.50671",
    "lng": "9.6104"
  },
  {
    "country": "NG",
    "name": "Zadawa",
    "lat": "11.4496",
    "lng": "10.3672"
  },
  {
    "country": "NG",
    "name": "Yuli",
    "lat": "9.69707",
    "lng": "10.2735"
  },
  {
    "country": "NG",
    "name": "Yola",
    "lat": "9.20839",
    "lng": "12.48146"
  },
  {
    "country": "NG",
    "name": "Yenagoa",
    "lat": "4.92675",
    "lng": "6.26764"
  },
  {
    "country": "NG",
    "name": "Yelwa",
    "lat": "10.83505",
    "lng": "4.74244"
  },
  {
    "country": "NG",
    "name": "Yelwa",
    "lat": "8.83333",
    "lng": "9.63333"
  },
  {
    "country": "NG",
    "name": "Yashikera",
    "lat": "9.76667",
    "lng": "3.4"
  },
  {
    "country": "NG",
    "name": "Yandev",
    "lat": "7.36308",
    "lng": "9.04235"
  },
  {
    "country": "NG",
    "name": "Yanda Bayo",
    "lat": "11.5071",
    "lng": "10.7459"
  },
  {
    "country": "NG",
    "name": "Yamrat",
    "lat": "10.11161",
    "lng": "9.82604"
  },
  {
    "country": "NG",
    "name": "Yajiwa",
    "lat": "11.38623",
    "lng": "12.71992"
  },
  {
    "country": "NG",
    "name": "Yabo",
    "lat": "12.72217",
    "lng": "5.01329"
  },
  {
    "country": "NG",
    "name": "Wuyo",
    "lat": "10.38522",
    "lng": "11.69678"
  },
  {
    "country": "NG",
    "name": "Wushishi",
    "lat": "9.73035",
    "lng": "6.07305"
  },
  {
    "country": "NG",
    "name": "Wurno",
    "lat": "13.29048",
    "lng": "5.42373"
  },
  {
    "country": "NG",
    "name": "Wukari",
    "lat": "7.87139",
    "lng": "9.77786"
  },
  {
    "country": "NG",
    "name": "Wudil",
    "lat": "11.80937",
    "lng": "8.84422"
  },
  {
    "country": "NG",
    "name": "Wawa",
    "lat": "9.90222",
    "lng": "4.41917"
  },
  {
    "country": "NG",
    "name": "Wase",
    "lat": "9.09424",
    "lng": "9.95605"
  },
  {
    "country": "NG",
    "name": "Wasagu",
    "lat": "11.3764",
    "lng": "5.79536"
  },
  {
    "country": "NG",
    "name": "Warri",
    "lat": "5.51737",
    "lng": "5.75006"
  },
  {
    "country": "NG",
    "name": "Wannune",
    "lat": "7.56384",
    "lng": "8.88534"
  },
  {
    "country": "NG",
    "name": "Wamba",
    "lat": "8.94153",
    "lng": "8.60315"
  },
  {
    "country": "NG",
    "name": "Wamako",
    "lat": "13.03054",
    "lng": "5.10433"
  },
  {
    "country": "NG",
    "name": "Wagini",
    "lat": "12.68781",
    "lng": "7.19579"
  },
  {
    "country": "NG",
    "name": "Vom",
    "lat": "9.7291",
    "lng": "8.79138"
  },
  {
    "country": "NG",
    "name": "Vandeikya",
    "lat": "6.78481",
    "lng": "9.06799"
  },
  {
    "country": "NG",
    "name": "Uyo",
    "lat": "5.05127",
    "lng": "7.9335"
  },
  {
    "country": "NG",
    "name": "Utu Etim Ekpo",
    "lat": "5.00485",
    "lng": "7.61028"
  },
  {
    "country": "NG",
    "name": "Ozoro",
    "lat": "5.54692",
    "lng": "6.22649"
  },
  {
    "country": "NG",
    "name": "Uselu",
    "lat": "6.38429",
    "lng": "5.60984"
  },
  {
    "country": "NG",
    "name": "Uruobo-Okija",
    "lat": "5.90016",
    "lng": "6.84312"
  },
  {
    "country": "NG",
    "name": "Urualla",
    "lat": "5.85397",
    "lng": "7.09906"
  },
  {
    "country": "NG",
    "name": "Uromi",
    "lat": "6.7",
    "lng": "6.33333"
  },
  {
    "country": "NG",
    "name": "Uquo",
    "lat": "4.65832",
    "lng": "8.05868"
  },
  {
    "country": "NG",
    "name": "Ukpor",
    "lat": "5.94211",
    "lng": "6.92931"
  },
  {
    "country": "NG",
    "name": "Ungogo",
    "lat": "12.09171",
    "lng": "8.49531"
  },
  {
    "country": "NG",
    "name": "Umuneke-Ngor",
    "lat": "5.33558",
    "lng": "7.15187"
  },
  {
    "country": "NG",
    "name": "Umunede",
    "lat": "6.26549",
    "lng": "6.30962"
  },
  {
    "country": "NG",
    "name": "Umulona",
    "lat": "6.50789",
    "lng": "7.09743"
  },
  {
    "country": "NG",
    "name": "Umuelemai",
    "lat": "5.68786",
    "lng": "7.24334"
  },
  {
    "country": "NG",
    "name": "Umuahia",
    "lat": "5.52491",
    "lng": "7.49461"
  },
  {
    "country": "NG",
    "name": "Ukpo",
    "lat": "6.21407",
    "lng": "6.96657"
  },
  {
    "country": "NG",
    "name": "Ukata",
    "lat": "10.83122",
    "lng": "5.82494"
  },
  {
    "country": "NG",
    "name": "Ughelli",
    "lat": "5.48956",
    "lng": "6.00407"
  },
  {
    "country": "NG",
    "name": "Ugep",
    "lat": "5.80865",
    "lng": "8.08098"
  },
  {
    "country": "NG",
    "name": "Ugba",
    "lat": "7.507",
    "lng": "9.34804"
  },
  {
    "country": "NG",
    "name": "Uga",
    "lat": "5.93576",
    "lng": "7.0793"
  },
  {
    "country": "NG",
    "name": "Udi",
    "lat": "6.31592",
    "lng": "7.42086"
  },
  {
    "country": "NG",
    "name": "Ubiaja",
    "lat": "6.65581",
    "lng": "6.38494"
  },
  {
    "country": "NG",
    "name": "Uba",
    "lat": "10.45509",
    "lng": "13.22233"
  },
  {
    "country": "NG",
    "name": "Tureta",
    "lat": "12.59367",
    "lng": "5.54391"
  },
  {
    "country": "NG",
    "name": "Tudun Wada",
    "lat": "11.24848",
    "lng": "8.40109"
  },
  {
    "country": "NG",
    "name": "Tsanyawa",
    "lat": "12.29559",
    "lng": "7.98654"
  },
  {
    "country": "NG",
    "name": "Toungo",
    "lat": "8.11733",
    "lng": "12.04611"
  },
  {
    "country": "NG",
    "name": "Toto",
    "lat": "8.3876",
    "lng": "7.07751"
  },
  {
    "country": "NG",
    "name": "Toro",
    "lat": "10.05889",
    "lng": "9.0691"
  },
  {
    "country": "NG",
    "name": "Tokombere",
    "lat": "11.22135",
    "lng": "13.48783"
  },
  {
    "country": "NG",
    "name": "Tofa",
    "lat": "12.05789",
    "lng": "8.27309"
  },
  {
    "country": "NG",
    "name": "Tegina",
    "lat": "10.0706",
    "lng": "6.1906"
  },
  {
    "country": "NG",
    "name": "Tede",
    "lat": "8.55625",
    "lng": "3.44638"
  },
  {
    "country": "NG",
    "name": "Taura",
    "lat": "12.22712",
    "lng": "9.28306"
  },
  {
    "country": "NG",
    "name": "Tambuwal",
    "lat": "12.40592",
    "lng": "4.64605"
  },
  {
    "country": "NG",
    "name": "Talata Mafara",
    "lat": "12.56841",
    "lng": "6.06225"
  },
  {
    "country": "NG",
    "name": "Talasse",
    "lat": "9.96843",
    "lng": "11.67945"
  },
  {
    "country": "NG",
    "name": "Takum",
    "lat": "7.26667",
    "lng": "9.98333"
  },
  {
    "country": "NG",
    "name": "Bunza",
    "lat": "12.08821",
    "lng": "4.0152"
  },
  {
    "country": "NG",
    "name": "Takai",
    "lat": "11.57569",
    "lng": "9.1088"
  },
  {
    "country": "NG",
    "name": "Tafawa Balewa",
    "lat": "9.76017",
    "lng": "9.55172"
  },
  {
    "country": "NG",
    "name": "Suya",
    "lat": "9.46667",
    "lng": "3.18333"
  },
  {
    "country": "NG",
    "name": "Surulere",
    "lat": "6.50153",
    "lng": "3.35808"
  },
  {
    "country": "NG",
    "name": "Sumaila",
    "lat": "11.53011",
    "lng": "8.95593"
  },
  {
    "country": "NG",
    "name": "Sule Tankarkar",
    "lat": "12.66686",
    "lng": "9.22828"
  },
  {
    "country": "NG",
    "name": "Suleja",
    "lat": "9.18059",
    "lng": "7.17939"
  },
  {
    "country": "NG",
    "name": "Song",
    "lat": "9.82675",
    "lng": "12.6238"
  },
  {
    "country": "NG",
    "name": "Sokoto",
    "lat": "13.06269",
    "lng": "5.24322"
  },
  {
    "country": "NG",
    "name": "Soba",
    "lat": "10.98133",
    "lng": "8.05749"
  },
  {
    "country": "NG",
    "name": "Siluko",
    "lat": "6.53589",
    "lng": "5.16005"
  },
  {
    "country": "NG",
    "name": "Silame",
    "lat": "13.03921",
    "lng": "4.84593"
  },
  {
    "country": "NG",
    "name": "Somolu",
    "lat": "6.53891",
    "lng": "3.3742"
  },
  {
    "country": "NG",
    "name": "Shinkafi",
    "lat": "13.07296",
    "lng": "6.50574"
  },
  {
    "country": "NG",
    "name": "Shendam",
    "lat": "8.87866",
    "lng": "9.53464"
  },
  {
    "country": "NG",
    "name": "Shelleng",
    "lat": "9.89647",
    "lng": "12.00572"
  },
  {
    "country": "NG",
    "name": "Share",
    "lat": "8.82086",
    "lng": "4.97342"
  },
  {
    "country": "NG",
    "name": "Shanono",
    "lat": "12.05154",
    "lng": "7.992"
  },
  {
    "country": "NG",
    "name": "Shani",
    "lat": "10.21824",
    "lng": "12.06059"
  },
  {
    "country": "NG",
    "name": "Shanga",
    "lat": "11.21374",
    "lng": "4.57941"
  },
  {
    "country": "NG",
    "name": "Saki",
    "lat": "8.66762",
    "lng": "3.39393"
  },
  {
    "country": "NG",
    "name": "Shagari",
    "lat": "12.62727",
    "lng": "4.99295"
  },
  {
    "country": "NG",
    "name": "Shagamu",
    "lat": "6.8485",
    "lng": "3.64633"
  },
  {
    "country": "NG",
    "name": "Shaffa",
    "lat": "10.50673",
    "lng": "12.33315"
  },
  {
    "country": "NG",
    "name": "Serti",
    "lat": "7.50574",
    "lng": "11.3631"
  },
  {
    "country": "NG",
    "name": "Sauri",
    "lat": "11.72655",
    "lng": "6.78374"
  },
  {
    "country": "NG",
    "name": "Sarkin Pawa",
    "lat": "10.02094",
    "lng": "7.11244"
  },
  {
    "country": "NG",
    "name": "Sapele",
    "lat": "5.89405",
    "lng": "5.67666"
  },
  {
    "country": "NG",
    "name": "Sankwala",
    "lat": "6.54753",
    "lng": "9.22258"
  },
  {
    "country": "NG",
    "name": "Sankera",
    "lat": "7.5353",
    "lng": "9.65223"
  },
  {
    "country": "NG",
    "name": "Sandamu",
    "lat": "12.96163",
    "lng": "8.36017"
  },
  {
    "country": "NG",
    "name": "Samamiya",
    "lat": "11.34873",
    "lng": "9.63989"
  },
  {
    "country": "NG",
    "name": "Sakaba",
    "lat": "11.06513",
    "lng": "5.5961"
  },
  {
    "country": "NG",
    "name": "Sagbama",
    "lat": "5.15915",
    "lng": "6.19666"
  },
  {
    "country": "NG",
    "name": "Safana",
    "lat": "12.41075",
    "lng": "7.41456"
  },
  {
    "country": "NG",
    "name": "Sade",
    "lat": "11.3595",
    "lng": "10.6732"
  },
  {
    "country": "NG",
    "name": "Sabuwa",
    "lat": "11.17372",
    "lng": "7.12113"
  },
  {
    "country": "NG",
    "name": "Sabongida-Ora",
    "lat": "6.90231",
    "lng": "5.93117"
  },
  {
    "country": "NG",
    "name": "Sabon Birni",
    "lat": "13.56387",
    "lng": "6.32355"
  },
  {
    "country": "NG",
    "name": "Runka",
    "lat": "12.44788",
    "lng": "7.30918"
  },
  {
    "country": "NG",
    "name": "Ruma",
    "lat": "12.8626",
    "lng": "7.23469"
  },
  {
    "country": "NG",
    "name": "Roni",
    "lat": "12.65862",
    "lng": "8.26505"
  },
  {
    "country": "NG",
    "name": "Rogo",
    "lat": "11.55237",
    "lng": "7.82253"
  },
  {
    "country": "NG",
    "name": "Riyom",
    "lat": "9.63681",
    "lng": "8.75694"
  },
  {
    "country": "NG",
    "name": "Riti",
    "lat": "7.90844",
    "lng": "9.61688"
  },
  {
    "country": "NG",
    "name": "Ririwai",
    "lat": "10.74025",
    "lng": "8.74128"
  },
  {
    "country": "NG",
    "name": "Ringim",
    "lat": "12.15143",
    "lng": "9.16216"
  },
  {
    "country": "NG",
    "name": "Rimin Gado",
    "lat": "11.9672",
    "lng": "8.2476"
  },
  {
    "country": "NG",
    "name": "Rimi",
    "lat": "12.8503",
    "lng": "7.70974"
  },
  {
    "country": "NG",
    "name": "Rijau",
    "lat": "11.10389",
    "lng": "5.25556"
  },
  {
    "country": "NG",
    "name": "Ribah",
    "lat": "11.39637",
    "lng": "5.48631"
  },
  {
    "country": "NG",
    "name": "Rano",
    "lat": "11.55684",
    "lng": "8.58065"
  },
  {
    "country": "NG",
    "name": "Rann",
    "lat": "12.26938",
    "lng": "14.46552"
  },
  {
    "country": "NG",
    "name": "Saminaka",
    "lat": "10.41227",
    "lng": "8.68748"
  },
  {
    "country": "NG",
    "name": "Rabah",
    "lat": "13.12257",
    "lng": "5.50762"
  },
  {
    "country": "NG",
    "name": "Potiskum",
    "lat": "11.71391",
    "lng": "11.08108"
  },
  {
    "country": "NG",
    "name": "Port Harcourt",
    "lat": "4.77742",
    "lng": "7.0134"
  },
  {
    "country": "NG",
    "name": "Pindiga",
    "lat": "9.98433",
    "lng": "10.95229"
  },
  {
    "country": "NG",
    "name": "Patigi",
    "lat": "8.72851",
    "lng": "5.75561"
  },
  {
    "country": "NG",
    "name": "Patani",
    "lat": "5.22885",
    "lng": "6.19139"
  },
  {
    "country": "NG",
    "name": "Panyam",
    "lat": "9.40756",
    "lng": "9.21481"
  },
  {
    "country": "NG",
    "name": "Pantisawa",
    "lat": "8.94504",
    "lng": "11.51176"
  },
  {
    "country": "NG",
    "name": "Pankshin",
    "lat": "9.32541",
    "lng": "9.4352"
  },
  {
    "country": "NG",
    "name": "Paiko",
    "lat": "9.43685",
    "lng": "6.63357"
  },
  {
    "country": "NG",
    "name": "Ozubulu",
    "lat": "5.95753",
    "lng": "6.85305"
  },
  {
    "country": "NG",
    "name": "Oyo",
    "lat": "7.85257",
    "lng": "3.93125"
  },
  {
    "country": "NG",
    "name": "Oye-Ekiti",
    "lat": "7.79976",
    "lng": "5.33242"
  },
  {
    "country": "NG",
    "name": "Oyan",
    "lat": "8.05",
    "lng": "4.76667"
  },
  {
    "country": "NG",
    "name": "Owu-Isin",
    "lat": "8.2809",
    "lng": "5.0194"
  },
  {
    "country": "NG",
    "name": "Owode",
    "lat": "6.94851",
    "lng": "3.50561"
  },
  {
    "country": "NG",
    "name": "Owo",
    "lat": "7.1962",
    "lng": "5.58681"
  },
  {
    "country": "NG",
    "name": "Owerri",
    "lat": "5.48363",
    "lng": "7.03325"
  },
  {
    "country": "NG",
    "name": "Owena",
    "lat": "7.19414",
    "lng": "5.02264"
  },
  {
    "country": "NG",
    "name": "Owa-Oyibu",
    "lat": "6.18267",
    "lng": "6.19902"
  },
  {
    "country": "NG",
    "name": "Otuocha",
    "lat": "6.33908",
    "lng": "6.84636"
  },
  {
    "country": "NG",
    "name": "Otun-Ekiti",
    "lat": "7.98858",
    "lng": "5.12291"
  },
  {
    "country": "NG",
    "name": "Otukpa",
    "lat": "7.10168",
    "lng": "7.65945"
  },
  {
    "country": "NG",
    "name": "Otu-Jeremi",
    "lat": "5.43818",
    "lng": "5.87829"
  },
  {
    "country": "NG",
    "name": "Otor-Udu",
    "lat": "5.45341",
    "lng": "5.8693"
  },
  {
    "country": "NG",
    "name": "Otu",
    "lat": "8.2065",
    "lng": "3.40735"
  },
  {
    "country": "NG",
    "name": "Ota",
    "lat": "6.68867",
    "lng": "3.23202"
  },
  {
    "country": "NG",
    "name": "Otan Ayegbaju",
    "lat": "7.94783",
    "lng": "4.78836"
  },
  {
    "country": "NG",
    "name": "Osu",
    "lat": "7.58585",
    "lng": "4.6226"
  },
  {
    "country": "NG",
    "name": "Osogbo",
    "lat": "7.77104",
    "lng": "4.55698"
  },
  {
    "country": "NG",
    "name": "Oshodi",
    "lat": "6.55504",
    "lng": "3.34363"
  },
  {
    "country": "NG",
    "name": "Afor-Oru",
    "lat": "5.5411",
    "lng": "7.26845"
  },
  {
    "country": "NG",
    "name": "Oron",
    "lat": "4.82171",
    "lng": "8.23504"
  },
  {
    "country": "NG",
    "name": "Orodo",
    "lat": "5.61667",
    "lng": "7.03333"
  },
  {
    "country": "NG",
    "name": "Orlu",
    "lat": "5.79565",
    "lng": "7.03513"
  },
  {
    "country": "NG",
    "name": "Orita Eruwa",
    "lat": "7.55",
    "lng": "3.43333"
  },
  {
    "country": "NG",
    "name": "Orerokpe",
    "lat": "5.63747",
    "lng": "5.89013"
  },
  {
    "country": "NG",
    "name": "Ore",
    "lat": "6.74716",
    "lng": "4.8761"
  },
  {
    "country": "NG",
    "name": "Oporoma",
    "lat": "4.80604",
    "lng": "6.08016"
  },
  {
    "country": "NG",
    "name": "Opobo",
    "lat": "4.51388",
    "lng": "7.53794"
  },
  {
    "country": "NG",
    "name": "Ikot Abasi",
    "lat": "4.56851",
    "lng": "7.55262"
  },
  {
    "country": "NG",
    "name": "Opi",
    "lat": "6.78223",
    "lng": "7.43319"
  },
  {
    "country": "NG",
    "name": "Onyedega",
    "lat": "6.88209",
    "lng": "6.67585"
  },
  {
    "country": "NG",
    "name": "Onitsha",
    "lat": "6.14978",
    "lng": "6.78569"
  },
  {
    "country": "NG",
    "name": "Ondo",
    "lat": "7.09316",
    "lng": "4.83528"
  },
  {
    "country": "NG",
    "name": "Omuo-Ekiti",
    "lat": "7.75833",
    "lng": "5.72227"
  },
  {
    "country": "NG",
    "name": "Omu-Aran",
    "lat": "8.13857",
    "lng": "5.1026"
  },
  {
    "country": "NG",
    "name": "Omoku",
    "lat": "5.34388",
    "lng": "6.65684"
  },
  {
    "country": "NG",
    "name": "Olupona",
    "lat": "7.6",
    "lng": "4.18333"
  },
  {
    "country": "NG",
    "name": "Oleh",
    "lat": "5.46186",
    "lng": "6.20624"
  },
  {
    "country": "NG",
    "name": "Okpoga",
    "lat": "7.03911",
    "lng": "7.81225"
  },
  {
    "country": "NG",
    "name": "Okwe",
    "lat": "5.77743",
    "lng": "7.21794"
  },
  {
    "country": "NG",
    "name": "Okuta",
    "lat": "9.21667",
    "lng": "3.18333"
  },
  {
    "country": "NG",
    "name": "Okrika",
    "lat": "4.74215",
    "lng": "7.08368"
  },
  {
    "country": "NG",
    "name": "Okpoma",
    "lat": "6.59679",
    "lng": "8.63728"
  },
  {
    "country": "NG",
    "name": "Okpo",
    "lat": "7.21626",
    "lng": "7.56022"
  },
  {
    "country": "NG",
    "name": "Okoroete",
    "lat": "4.54077",
    "lng": "7.74858"
  },
  {
    "country": "NG",
    "name": "Okopedi",
    "lat": "4.84918",
    "lng": "8.12564"
  },
  {
    "country": "NG",
    "name": "Oko Ita",
    "lat": "5.192",
    "lng": "7.89531"
  },
  {
    "country": "NG",
    "name": "Okigwe",
    "lat": "5.82917",
    "lng": "7.35056"
  },
  {
    "country": "NG",
    "name": "Oke-Oyi",
    "lat": "8.58263",
    "lng": "4.71622"
  },
  {
    "country": "NG",
    "name": "Okene",
    "lat": "7.55122",
    "lng": "6.23589"
  },
  {
    "country": "NG",
    "name": "Oke Mesi",
    "lat": "7.81667",
    "lng": "4.91667"
  },
  {
    "country": "NG",
    "name": "Oke Ila",
    "lat": "7.95",
    "lng": "4.98333"
  },
  {
    "country": "NG",
    "name": "Okeho",
    "lat": "8.03386",
    "lng": "3.34759"
  },
  {
    "country": "NG",
    "name": "Okehi",
    "lat": "5.13895",
    "lng": "7.13915"
  },
  {
    "country": "NG",
    "name": "Oke-Agbe",
    "lat": "7.64314",
    "lng": "5.75943"
  },
  {
    "country": "NG",
    "name": "Okada",
    "lat": "6.73488",
    "lng": "5.39447"
  },
  {
    "country": "NG",
    "name": "Oka",
    "lat": "7.46012",
    "lng": "5.80174"
  },
  {
    "country": "NG",
    "name": "Oju",
    "lat": "6.84526",
    "lng": "8.41914"
  },
  {
    "country": "NG",
    "name": "Ojoto",
    "lat": "6.05842",
    "lng": "6.86124"
  },
  {
    "country": "NG",
    "name": "Oji River",
    "lat": "6.25563",
    "lng": "7.27025"
  },
  {
    "country": "NG",
    "name": "Ohafia-Ifigh",
    "lat": "5.61455",
    "lng": "7.81191"
  },
  {
    "country": "NG",
    "name": "Ogwashi-Uku",
    "lat": "6.17811",
    "lng": "6.52461"
  },
  {
    "country": "NG",
    "name": "Oguta",
    "lat": "5.71044",
    "lng": "6.80936"
  },
  {
    "country": "NG",
    "name": "Ogurugu",
    "lat": "6.78636",
    "lng": "6.95017"
  },
  {
    "country": "NG",
    "name": "Oguma",
    "lat": "7.89635",
    "lng": "7.06229"
  },
  {
    "country": "NG",
    "name": "Ogu",
    "lat": "4.72247",
    "lng": "7.19859"
  },
  {
    "country": "NG",
    "name": "Ogoja",
    "lat": "6.6584",
    "lng": "8.79923"
  },
  {
    "country": "NG",
    "name": "Ogidi",
    "lat": "6.15209",
    "lng": "6.86343"
  },
  {
    "country": "NG",
    "name": "Ogbomoso",
    "lat": "8.13373",
    "lng": "4.24014"
  },
  {
    "country": "NG",
    "name": "Ogbere",
    "lat": "6.73948",
    "lng": "4.16102"
  },
  {
    "country": "NG",
    "name": "Ogbede",
    "lat": "6.67295",
    "lng": "7.37441"
  },
  {
    "country": "NG",
    "name": "Ogaminana",
    "lat": "7.59383",
    "lng": "6.21798"
  },
  {
    "country": "NG",
    "name": "Offa",
    "lat": "8.14911",
    "lng": "4.72074"
  },
  {
    "country": "NG",
    "name": "Odukpani",
    "lat": "5.13375",
    "lng": "8.33814"
  },
  {
    "country": "NG",
    "name": "Odot",
    "lat": "4.83095",
    "lng": "8.03839"
  },
  {
    "country": "NG",
    "name": "Odoro Ikpe",
    "lat": "5.35835",
    "lng": "7.75184"
  },
  {
    "country": "NG",
    "name": "Odogbolu",
    "lat": "6.84035",
    "lng": "3.76285"
  },
  {
    "country": "NG",
    "name": "Odo-Ere",
    "lat": "8.25057",
    "lng": "5.54979"
  },
  {
    "country": "NG",
    "name": "Odeda",
    "lat": "7.23251",
    "lng": "3.52819"
  },
  {
    "country": "NG",
    "name": "Ode",
    "lat": "7.7899",
    "lng": "5.7117"
  },
  {
    "country": "NG",
    "name": "Ode-Ekiti",
    "lat": "7.64813",
    "lng": "5.54948"
  },
  {
    "country": "NG",
    "name": "Ochobo",
    "lat": "7.18045",
    "lng": "7.9824"
  },
  {
    "country": "NG",
    "name": "Obudu",
    "lat": "6.66819",
    "lng": "9.16453"
  },
  {
    "country": "NG",
    "name": "Obubra",
    "lat": "6.07672",
    "lng": "8.33241"
  },
  {
    "country": "NG",
    "name": "Obonoma",
    "lat": "4.71131",
    "lng": "6.79084"
  },
  {
    "country": "NG",
    "name": "Obolo-Eke (1)",
    "lat": "6.88333",
    "lng": "7.63333"
  },
  {
    "country": "NG",
    "name": "Obollo-Afor",
    "lat": "6.91624",
    "lng": "7.51849"
  },
  {
    "country": "NG",
    "name": "Obiaruku",
    "lat": "5.84672",
    "lng": "6.1529"
  },
  {
    "country": "NG",
    "name": "Obi",
    "lat": "8.36922",
    "lng": "8.77383"
  },
  {
    "country": "NG",
    "name": "Nzam",
    "lat": "6.45296",
    "lng": "6.72882"
  },
  {
    "country": "NG",
    "name": "Nung Udoe",
    "lat": "4.91657",
    "lng": "7.96314"
  },
  {
    "country": "NG",
    "name": "Numan",
    "lat": "9.46374",
    "lng": "12.03062"
  },
  {
    "country": "NG",
    "name": "Nto Edino",
    "lat": "5.25704",
    "lng": "7.57569"
  },
  {
    "country": "NG",
    "name": "Nteje",
    "lat": "6.2681",
    "lng": "6.92062"
  },
  {
    "country": "NG",
    "name": "Nsukka",
    "lat": "6.85783",
    "lng": "7.39577"
  },
  {
    "country": "NG",
    "name": "Isiokpo",
    "lat": "5.00243",
    "lng": "6.87262"
  },
  {
    "country": "NG",
    "name": "Nnewi",
    "lat": "6.01962",
    "lng": "6.91729"
  },
  {
    "country": "NG",
    "name": "Nkwerre",
    "lat": "5.75917",
    "lng": "7.10384"
  },
  {
    "country": "NG",
    "name": "Nkpor",
    "lat": "6.15038",
    "lng": "6.83042"
  },
  {
    "country": "NG",
    "name": "Mkpat Enin",
    "lat": "4.73478",
    "lng": "7.74897"
  },
  {
    "country": "NG",
    "name": "Ningi",
    "lat": "11.07837",
    "lng": "9.56886"
  },
  {
    "country": "NG",
    "name": "Nguzu Edda",
    "lat": "5.75543",
    "lng": "7.81721"
  },
  {
    "country": "NG",
    "name": "Nguru",
    "lat": "12.87695",
    "lng": "10.45536"
  },
  {
    "country": "NG",
    "name": "Ngurore",
    "lat": "9.28871",
    "lng": "12.24026"
  },
  {
    "country": "NG",
    "name": "Ngo",
    "lat": "4.48388",
    "lng": "7.41446"
  },
  {
    "country": "NG",
    "name": "Ngala",
    "lat": "12.34053",
    "lng": "14.1867"
  },
  {
    "country": "NG",
    "name": "Wara",
    "lat": "10.22884",
    "lng": "4.62363"
  },
  {
    "country": "NG",
    "name": "New Shagunnu",
    "lat": "10.33957",
    "lng": "4.4688"
  },
  {
    "country": "NG",
    "name": "New Bussa",
    "lat": "9.88644",
    "lng": "4.50854"
  },
  {
    "country": "NG",
    "name": "Neni",
    "lat": "6.09511",
    "lng": "7.02426"
  },
  {
    "country": "NG",
    "name": "Nembe",
    "lat": "4.53673",
    "lng": "6.40332"
  },
  {
    "country": "NG",
    "name": "Ndeaboh",
    "lat": "6.03405",
    "lng": "7.56843"
  },
  {
    "country": "NG",
    "name": "Nasarawa Egon",
    "lat": "8.71226",
    "lng": "8.5406"
  },
  {
    "country": "NG",
    "name": "Nasarawa",
    "lat": "8.53895",
    "lng": "7.70821"
  },
  {
    "country": "NG",
    "name": "Nafada",
    "lat": "11.09596",
    "lng": "11.33261"
  },
  {
    "country": "NG",
    "name": "Mutum Biyu",
    "lat": "8.64138",
    "lng": "10.77355"
  },
  {
    "country": "NG",
    "name": "Mushin",
    "lat": "6.52799",
    "lng": "3.35411"
  },
  {
    "country": "NG",
    "name": "Musawa",
    "lat": "12.12949",
    "lng": "7.67023"
  },
  {
    "country": "NG",
    "name": "Mubi",
    "lat": "10.26858",
    "lng": "13.26701"
  },
  {
    "country": "NG",
    "name": "Moriki",
    "lat": "12.87405",
    "lng": "6.48754"
  },
  {
    "country": "NG",
    "name": "Mopa",
    "lat": "8.10387",
    "lng": "5.8928"
  },
  {
    "country": "NG",
    "name": "Moniya",
    "lat": "7.52843",
    "lng": "3.91156"
  },
  {
    "country": "NG",
    "name": "Monguno",
    "lat": "12.67059",
    "lng": "13.61224"
  },
  {
    "country": "NG",
    "name": "Mangu",
    "lat": "9.5206",
    "lng": "9.09769"
  },
  {
    "country": "NG",
    "name": "Mokwa",
    "lat": "9.29482",
    "lng": "5.05412"
  },
  {
    "country": "NG",
    "name": "Modakeke",
    "lat": "7.38333",
    "lng": "4.26667"
  },
  {
    "country": "NG",
    "name": "Bolorunduro",
    "lat": "7.16586",
    "lng": "4.9637"
  },
  {
    "country": "NG",
    "name": "Misau",
    "lat": "11.3137",
    "lng": "10.46664"
  },
  {
    "country": "NG",
    "name": "Miringa",
    "lat": "10.73115",
    "lng": "12.14626"
  },
  {
    "country": "NG",
    "name": "Minna",
    "lat": "9.61524",
    "lng": "6.54776"
  },
  {
    "country": "NG",
    "name": "Minjibir",
    "lat": "12.17765",
    "lng": "8.65782"
  },
  {
    "country": "NG",
    "name": "Miga",
    "lat": "12.2388",
    "lng": "9.71362"
  },
  {
    "country": "NG",
    "name": "Michika",
    "lat": "10.62042",
    "lng": "13.38928"
  },
  {
    "country": "NG",
    "name": "Imeko",
    "lat": "7.44888",
    "lng": "2.84289"
  },
  {
    "country": "NG",
    "name": "Mgbidi",
    "lat": "5.73236",
    "lng": "6.88869"
  },
  {
    "country": "NG",
    "name": "Mberubu",
    "lat": "6.1731",
    "lng": "7.63017"
  },
  {
    "country": "NG",
    "name": "Mbalano",
    "lat": "5.73432",
    "lng": "7.50238"
  },
  {
    "country": "NG",
    "name": "Mayo-Belwa",
    "lat": "9.05421",
    "lng": "12.05794"
  },
  {
    "country": "NG",
    "name": "Machina",
    "lat": "13.13639",
    "lng": "10.04924"
  },
  {
    "country": "NG",
    "name": "Matazu",
    "lat": "12.23549",
    "lng": "7.67426"
  },
  {
    "country": "NG",
    "name": "Mashi",
    "lat": "12.98044",
    "lng": "7.94703"
  },
  {
    "country": "NG",
    "name": "Maru",
    "lat": "12.3336",
    "lng": "6.40372"
  },
  {
    "country": "NG",
    "name": "Marte",
    "lat": "12.36532",
    "lng": "13.8293"
  },
  {
    "country": "NG",
    "name": "Maradun",
    "lat": "12.56704",
    "lng": "6.24407"
  },
  {
    "country": "NG",
    "name": "Mani",
    "lat": "12.85426",
    "lng": "7.87526"
  },
  {
    "country": "NG",
    "name": "Mando",
    "lat": "10.71667",
    "lng": "6.56667"
  },
  {
    "country": "NG",
    "name": "Malumfashi",
    "lat": "11.78935",
    "lng": "7.62061"
  },
  {
    "country": "NG",
    "name": "Mallam Sidi",
    "lat": "10.4683",
    "lng": "11.29294"
  },
  {
    "country": "NG",
    "name": "Mallammaduri",
    "lat": "12.56427",
    "lng": "9.95727"
  },
  {
    "country": "NG",
    "name": "Makurdi",
    "lat": "7.73375",
    "lng": "8.52139"
  },
  {
    "country": "NG",
    "name": "Makoko",
    "lat": "6.49611",
    "lng": "3.38778"
  },
  {
    "country": "NG",
    "name": "Makera",
    "lat": "10.4714",
    "lng": "7.41026"
  },
  {
    "country": "NG",
    "name": "Makarfi",
    "lat": "11.37734",
    "lng": "7.88098"
  },
  {
    "country": "NG",
    "name": "Maiyama",
    "lat": "12.08225",
    "lng": "4.36907"
  },
  {
    "country": "NG",
    "name": "Maikunkele",
    "lat": "9.6843",
    "lng": "6.47889"
  },
  {
    "country": "NG",
    "name": "Maiha",
    "lat": "9.99672",
    "lng": "13.21665"
  },
  {
    "country": "NG",
    "name": "Maigatari",
    "lat": "12.80783",
    "lng": "9.44516"
  },
  {
    "country": "NG",
    "name": "Maigana",
    "lat": "11.02707",
    "lng": "7.93844"
  },
  {
    "country": "NG",
    "name": "Maiduguri",
    "lat": "11.84692",
    "lng": "13.15712"
  },
  {
    "country": "NG",
    "name": "Mai’Adua",
    "lat": "13.17986",
    "lng": "8.2304"
  },
  {
    "country": "NG",
    "name": "Mahuta",
    "lat": "11.55338",
    "lng": "4.98138"
  },
  {
    "country": "NG",
    "name": "Magumeri",
    "lat": "12.11451",
    "lng": "12.8262"
  },
  {
    "country": "NG",
    "name": "Mafa",
    "lat": "11.92417",
    "lng": "13.60066"
  },
  {
    "country": "NG",
    "name": "Madobi",
    "lat": "11.77725",
    "lng": "8.28801"
  },
  {
    "country": "NG",
    "name": "Madara",
    "lat": "11.7798",
    "lng": "10.4479"
  },
  {
    "country": "NG",
    "name": "Madala",
    "lat": "9.10444",
    "lng": "7.21333"
  },
  {
    "country": "NG",
    "name": "Madagali",
    "lat": "10.88942",
    "lng": "13.62832"
  },
  {
    "country": "NG",
    "name": "Lokoja",
    "lat": "7.79688",
    "lng": "6.74048"
  },
  {
    "country": "NG",
    "name": "Lere",
    "lat": "10.38584",
    "lng": "8.57286"
  },
  {
    "country": "NG",
    "name": "Lere",
    "lat": "9.71052",
    "lng": "9.34029"
  },
  {
    "country": "NG",
    "name": "Lemu",
    "lat": "9.39637",
    "lng": "6.02791"
  },
  {
    "country": "NG",
    "name": "Lau",
    "lat": "9.20827",
    "lng": "11.27541"
  },
  {
    "country": "NG",
    "name": "Lapai",
    "lat": "9.04439",
    "lng": "6.57089"
  },
  {
    "country": "NG",
    "name": "Langtang",
    "lat": "9.14164",
    "lng": "9.79101"
  },
  {
    "country": "NG",
    "name": "Lamurde",
    "lat": "9.60816",
    "lng": "11.79315"
  },
  {
    "country": "NG",
    "name": "Lame",
    "lat": "10.44154",
    "lng": "9.23955"
  },
  {
    "country": "NG",
    "name": "Lalupon",
    "lat": "7.46667",
    "lng": "4.06667"
  },
  {
    "country": "NG",
    "name": "Lagos",
    "lat": "6.45407",
    "lng": "3.39467"
  },
  {
    "country": "NG",
    "name": "Lafiagi",
    "lat": "8.85299",
    "lng": "5.41641"
  },
  {
    "country": "NG",
    "name": "Lafia",
    "lat": "8.4939",
    "lng": "8.51532"
  },
  {
    "country": "NG",
    "name": "Kwolla",
    "lat": "8.90361",
    "lng": "9.29086"
  },
  {
    "country": "NG",
    "name": "Kwoi",
    "lat": "9.45745",
    "lng": "8.00684"
  },
  {
    "country": "NG",
    "name": "Kwaya Kusar",
    "lat": "10.50296",
    "lng": "11.84331"
  },
  {
    "country": "NG",
    "name": "Kwatarkwashi",
    "lat": "12.14082",
    "lng": "6.82196"
  },
  {
    "country": "NG",
    "name": "Kware",
    "lat": "13.21969",
    "lng": "5.26596"
  },
  {
    "country": "NG",
    "name": "Kwali",
    "lat": "8.88346",
    "lng": "7.01858"
  },
  {
    "country": "NG",
    "name": "Kwale",
    "lat": "5.70773",
    "lng": "6.43402"
  },
  {
    "country": "NG",
    "name": "Kutigi",
    "lat": "9.20103",
    "lng": "5.59498"
  },
  {
    "country": "NG",
    "name": "Kuta",
    "lat": "9.86864",
    "lng": "6.71042"
  },
  {
    "country": "NG",
    "name": "Kusheriki",
    "lat": "10.53283",
    "lng": "6.44222"
  },
  {
    "country": "NG",
    "name": "Kusada",
    "lat": "12.4656",
    "lng": "7.97848"
  },
  {
    "country": "NG",
    "name": "Kurfi",
    "lat": "12.6663",
    "lng": "7.48478"
  },
  {
    "country": "NG",
    "name": "Kura",
    "lat": "11.77232",
    "lng": "8.42631"
  },
  {
    "country": "NG",
    "name": "Kunchi",
    "lat": "12.5026",
    "lng": "8.27092"
  },
  {
    "country": "NG",
    "name": "Kumo",
    "lat": "10.04807",
    "lng": "11.21055"
  },
  {
    "country": "NG",
    "name": "Kumbotso",
    "lat": "11.89002",
    "lng": "8.503"
  },
  {
    "country": "NG",
    "name": "Kumagunnam",
    "lat": "13.15498",
    "lng": "10.63468"
  },
  {
    "country": "NG",
    "name": "Kukawa",
    "lat": "12.92475",
    "lng": "13.56617"
  },
  {
    "country": "NG",
    "name": "Kuje",
    "lat": "8.87952",
    "lng": "7.22756"
  },
  {
    "country": "NG",
    "name": "Kujama",
    "lat": "10.45767",
    "lng": "7.63808"
  },
  {
    "country": "NG",
    "name": "Kpor",
    "lat": "4.65265",
    "lng": "7.28397"
  },
  {
    "country": "NG",
    "name": "Koton-Karfe",
    "lat": "8.0912",
    "lng": "6.79782"
  },
  {
    "country": "NG",
    "name": "Kosubosu",
    "lat": "9.55107",
    "lng": "3.22841"
  },
  {
    "country": "NG",
    "name": "Kontagora",
    "lat": "10.40319",
    "lng": "5.4708"
  },
  {
    "country": "NG",
    "name": "Konkwesso",
    "lat": "10.84686",
    "lng": "4.09835"
  },
  {
    "country": "NG",
    "name": "Konduga",
    "lat": "11.65331",
    "lng": "13.41787"
  },
  {
    "country": "NG",
    "name": "Koko",
    "lat": "6.00084",
    "lng": "5.45523"
  },
  {
    "country": "NG",
    "name": "Kiyawa",
    "lat": "11.78442",
    "lng": "9.6069"
  },
  {
    "country": "NG",
    "name": "Kisi",
    "lat": "9.08297",
    "lng": "3.85196"
  },
  {
    "country": "NG",
    "name": "Kiru",
    "lat": "11.7021",
    "lng": "8.13481"
  },
  {
    "country": "NG",
    "name": "Karkarna",
    "lat": "12.76653",
    "lng": "8.50981"
  },
  {
    "country": "NG",
    "name": "Kiri Kasamma",
    "lat": "12.69273",
    "lng": "10.25456"
  },
  {
    "country": "NG",
    "name": "Kirfi",
    "lat": "10.40556",
    "lng": "10.40451"
  },
  {
    "country": "NG",
    "name": "Auyo",
    "lat": "12.33338",
    "lng": "9.93891"
  },
  {
    "country": "NG",
    "name": "Kibiya",
    "lat": "11.528",
    "lng": "8.66108"
  },
  {
    "country": "NG",
    "name": "Kende",
    "lat": "11.51966",
    "lng": "4.2603"
  },
  {
    "country": "NG",
    "name": "Kafin Hausa",
    "lat": "12.23933",
    "lng": "9.91105"
  },
  {
    "country": "NG",
    "name": "Keffi",
    "lat": "8.84651",
    "lng": "7.87354"
  },
  {
    "country": "NG",
    "name": "Kebbe",
    "lat": "12.12861",
    "lng": "4.73433"
  },
  {
    "country": "NG",
    "name": "Keana",
    "lat": "8.14724",
    "lng": "8.79601"
  },
  {
    "country": "NG",
    "name": "Kazaure",
    "lat": "12.64846",
    "lng": "8.41178"
  },
  {
    "country": "NG",
    "name": "Kauru",
    "lat": "10.57601",
    "lng": "8.15096"
  },
  {
    "country": "NG",
    "name": "Kaura Namoda",
    "lat": "12.59371",
    "lng": "6.58648"
  },
  {
    "country": "NG",
    "name": "Kaugama",
    "lat": "12.47431",
    "lng": "9.73671"
  },
  {
    "country": "NG",
    "name": "Katsina-Ala",
    "lat": "7.16938",
    "lng": "9.28465"
  },
  {
    "country": "NG",
    "name": "Katsina",
    "lat": "12.99082",
    "lng": "7.60177"
  },
  {
    "country": "NG",
    "name": "Katcha",
    "lat": "8.76076",
    "lng": "6.312"
  },
  {
    "country": "NG",
    "name": "Warji",
    "lat": "11.17756",
    "lng": "9.75241"
  },
  {
    "country": "NG",
    "name": "Katagum",
    "lat": "12.28507",
    "lng": "10.35027"
  },
  {
    "country": "NG",
    "name": "Karim Lamido",
    "lat": "9.3143",
    "lng": "11.18731"
  },
  {
    "country": "NG",
    "name": "Kari",
    "lat": "11.2471",
    "lng": "10.561"
  },
  {
    "country": "NG",
    "name": "Karaye",
    "lat": "11.7836",
    "lng": "8.01504"
  },
  {
    "country": "NG",
    "name": "Kano",
    "lat": "12.00012",
    "lng": "8.51672"
  },
  {
    "country": "NG",
    "name": "Kankia",
    "lat": "12.54637",
    "lng": "7.82254"
  },
  {
    "country": "NG",
    "name": "Kankara",
    "lat": "11.93114",
    "lng": "7.41115"
  },
  {
    "country": "NG",
    "name": "Kamba",
    "lat": "11.85172",
    "lng": "3.65478"
  },
  {
    "country": "NG",
    "name": "Kaltungo",
    "lat": "9.81998",
    "lng": "11.30871"
  },
  {
    "country": "NG",
    "name": "Kalgo",
    "lat": "12.32666",
    "lng": "4.2004"
  },
  {
    "country": "NG",
    "name": "Kajuru",
    "lat": "10.32281",
    "lng": "7.68462"
  },
  {
    "country": "NG",
    "name": "Kaita",
    "lat": "13.08346",
    "lng": "7.74092"
  },
  {
    "country": "NG",
    "name": "Kangiwa",
    "lat": "12.55339",
    "lng": "3.81814"
  },
  {
    "country": "NG",
    "name": "Kaiama",
    "lat": "9.6053",
    "lng": "3.94101"
  },
  {
    "country": "NG",
    "name": "Kaiama",
    "lat": "5.1197",
    "lng": "6.30101"
  },
  {
    "country": "NG",
    "name": "Kagoro",
    "lat": "9.60776",
    "lng": "8.39043"
  },
  {
    "country": "NG",
    "name": "Kagarko",
    "lat": "9.4911",
    "lng": "7.69771"
  },
  {
    "country": "NG",
    "name": "Kagara",
    "lat": "10.18662",
    "lng": "6.25485"
  },
  {
    "country": "NG",
    "name": "Kafur",
    "lat": "11.64589",
    "lng": "7.69068"
  },
  {
    "country": "NG",
    "name": "Kafin Madaki",
    "lat": "10.68856",
    "lng": "9.76051"
  },
  {
    "country": "NG",
    "name": "Kafarati",
    "lat": "10.38304",
    "lng": "11.09567"
  },
  {
    "country": "NG",
    "name": "Kafanchan",
    "lat": "9.58126",
    "lng": "8.2926"
  },
  {
    "country": "NG",
    "name": "Lissam",
    "lat": "7.1961",
    "lng": "10.0462"
  },
  {
    "country": "NG",
    "name": "Kaduna",
    "lat": "10.52641",
    "lng": "7.43879"
  },
  {
    "country": "NG",
    "name": "Kachia",
    "lat": "9.87342",
    "lng": "7.95407"
  },
  {
    "country": "NG",
    "name": "Kabo",
    "lat": "11.85606",
    "lng": "8.1702"
  },
  {
    "country": "NG",
    "name": "Kabba",
    "lat": "7.82719",
    "lng": "6.07502"
  },
  {
    "country": "NG",
    "name": "Jos",
    "lat": "9.92849",
    "lng": "8.89212"
  },
  {
    "country": "NG",
    "name": "Jobele",
    "lat": "7.763",
    "lng": "3.91935"
  },
  {
    "country": "NG",
    "name": "Jimeta",
    "lat": "9.27949",
    "lng": "12.45819"
  },
  {
    "country": "NG",
    "name": "Jikamshi",
    "lat": "12.17328",
    "lng": "7.77424"
  },
  {
    "country": "NG",
    "name": "Jibia",
    "lat": "13.09378",
    "lng": "7.22624"
  },
  {
    "country": "NG",
    "name": "Jega",
    "lat": "12.22336",
    "lng": "4.37971"
  },
  {
    "country": "NG",
    "name": "Jebba",
    "lat": "9.11972",
    "lng": "4.8236"
  },
  {
    "country": "NG",
    "name": "Angware",
    "lat": "9.99105",
    "lng": "9.10811"
  },
  {
    "country": "NG",
    "name": "Jama’are",
    "lat": "11.6698",
    "lng": "9.928"
  },
  {
    "country": "NG",
    "name": "Jalingo",
    "lat": "8.89367",
    "lng": "11.3596"
  },
  {
    "country": "NG",
    "name": "Jakusko",
    "lat": "12.37093",
    "lng": "10.77373"
  },
  {
    "country": "NG",
    "name": "Jajimaji",
    "lat": "12.8985",
    "lng": "10.80688"
  },
  {
    "country": "NG",
    "name": "Lajere",
    "lat": "11.98022",
    "lng": "11.44002"
  },
  {
    "country": "NG",
    "name": "Jahun",
    "lat": "12.07629",
    "lng": "9.62757"
  },
  {
    "country": "NG",
    "name": "Jada",
    "lat": "8.75682",
    "lng": "12.15537"
  },
  {
    "country": "NG",
    "name": "Iye-Ekiti",
    "lat": "7.95457",
    "lng": "5.23314"
  },
  {
    "country": "NG",
    "name": "Iyara",
    "lat": "7.84325",
    "lng": "5.97061"
  },
  {
    "country": "NG",
    "name": "Iwo",
    "lat": "7.63527",
    "lng": "4.18156"
  },
  {
    "country": "NG",
    "name": "Iwere-Ile",
    "lat": "7.99919",
    "lng": "3.08827"
  },
  {
    "country": "NG",
    "name": "Itu",
    "lat": "5.46395",
    "lng": "7.33078"
  },
  {
    "country": "NG",
    "name": "Itu",
    "lat": "5.20131",
    "lng": "7.98373"
  },
  {
    "country": "NG",
    "name": "Itori",
    "lat": "6.93123",
    "lng": "3.22147"
  },
  {
    "country": "NG",
    "name": "Obarike-Ito",
    "lat": "7.0245",
    "lng": "8.32358"
  },
  {
    "country": "NG",
    "name": "Itigidi",
    "lat": "5.89147",
    "lng": "8.02187"
  },
  {
    "country": "NG",
    "name": "Itas",
    "lat": "11.8575",
    "lng": "9.96394"
  },
  {
    "country": "NG",
    "name": "Ita-Ogbolu",
    "lat": "7.36838",
    "lng": "5.24684"
  },
  {
    "country": "NG",
    "name": "Isu",
    "lat": "6.15002",
    "lng": "7.80131"
  },
  {
    "country": "NG",
    "name": "Issele-Uku",
    "lat": "6.31584",
    "lng": "6.47599"
  },
  {
    "country": "NG",
    "name": "Isiokolo",
    "lat": "5.59586",
    "lng": "6.00028"
  },
  {
    "country": "NG",
    "name": "Isieke",
    "lat": "6.38186",
    "lng": "8.03736"
  },
  {
    "country": "NG",
    "name": "Isua",
    "lat": "7.45361",
    "lng": "5.91047"
  },
  {
    "country": "NG",
    "name": "Iseyin",
    "lat": "7.97022",
    "lng": "3.59626"
  },
  {
    "country": "NG",
    "name": "Ise-Ekiti",
    "lat": "7.46478",
    "lng": "5.42333"
  },
  {
    "country": "NG",
    "name": "Isara",
    "lat": "6.99345",
    "lng": "3.68148"
  },
  {
    "country": "NG",
    "name": "Isanlu-Itedoijowa",
    "lat": "8.27445",
    "lng": "5.83528"
  },
  {
    "country": "NG",
    "name": "Isanlu",
    "lat": "8.28823",
    "lng": "5.81837"
  },
  {
    "country": "NG",
    "name": "Isa",
    "lat": "13.20066",
    "lng": "6.40487"
  },
  {
    "country": "NG",
    "name": "Iresa-Adu",
    "lat": "8.08747",
    "lng": "4.39264"
  },
  {
    "country": "NG",
    "name": "Ode-Irele",
    "lat": "6.49418",
    "lng": "4.87036"
  },
  {
    "country": "NG",
    "name": "Iragbiji",
    "lat": "7.904",
    "lng": "4.68705"
  },
  {
    "country": "NG",
    "name": "Ipoti",
    "lat": "7.87377",
    "lng": "5.07691"
  },
  {
    "country": "NG",
    "name": "Ipokia",
    "lat": "6.52499",
    "lng": "2.84246"
  },
  {
    "country": "NG",
    "name": "Ipetumodu",
    "lat": "7.52152",
    "lng": "4.44477"
  },
  {
    "country": "NG",
    "name": "Iperu",
    "lat": "6.91002",
    "lng": "3.66557"
  },
  {
    "country": "NG",
    "name": "Iperindo",
    "lat": "7.50119",
    "lng": "4.82477"
  },
  {
    "country": "NG",
    "name": "Inisa",
    "lat": "7.85",
    "lng": "4.33333"
  },
  {
    "country": "NG",
    "name": "Ingawa",
    "lat": "12.64138",
    "lng": "8.05162"
  },
  {
    "country": "NG",
    "name": "Ilorin",
    "lat": "8.49664",
    "lng": "4.54214"
  },
  {
    "country": "NG",
    "name": "Iloffa",
    "lat": "8.09343",
    "lng": "5.14233"
  },
  {
    "country": "NG",
    "name": "Ilobu",
    "lat": "7.84036",
    "lng": "4.48557"
  },
  {
    "country": "NG",
    "name": "Illushi",
    "lat": "6.67033",
    "lng": "6.62907"
  },
  {
    "country": "NG",
    "name": "Illela",
    "lat": "13.73064",
    "lng": "5.29777"
  },
  {
    "country": "NG",
    "name": "Ilesa",
    "lat": "7.62789",
    "lng": "4.74161"
  },
  {
    "country": "NG",
    "name": "Ile-Oluji",
    "lat": "7.21309",
    "lng": "4.86902"
  },
  {
    "country": "NG",
    "name": "Ilemona",
    "lat": "8.10992",
    "lng": "4.66059"
  },
  {
    "country": "NG",
    "name": "Ile-Ogbo",
    "lat": "7.62129",
    "lng": "4.24531"
  },
  {
    "country": "NG",
    "name": "Ilawe-Ekiti",
    "lat": "7.59881",
    "lng": "5.1047"
  },
  {
    "country": "NG",
    "name": "Ilaro",
    "lat": "6.88901",
    "lng": "3.01416"
  },
  {
    "country": "NG",
    "name": "Ilare",
    "lat": "7.35067",
    "lng": "5.11333"
  },
  {
    "country": "NG",
    "name": "Ila Orangun",
    "lat": "8.01714",
    "lng": "4.90421"
  },
  {
    "country": "NG",
    "name": "Ikoyi-Ile",
    "lat": "8.2444",
    "lng": "4.17181"
  },
  {
    "country": "NG",
    "name": "Ikoyi",
    "lat": "6.45254",
    "lng": "3.43584"
  },
  {
    "country": "NG",
    "name": "Ikotun",
    "lat": "6.54433",
    "lng": "3.26379"
  },
  {
    "country": "NG",
    "name": "Ikot Nakanda",
    "lat": "4.88426",
    "lng": "8.48379"
  },
  {
    "country": "NG",
    "name": "Ikot Ibritam",
    "lat": "4.81171",
    "lng": "7.61401"
  },
  {
    "country": "NG",
    "name": "Ikot Ekpene",
    "lat": "5.18194",
    "lng": "7.71481"
  },
  {
    "country": "NG",
    "name": "Afaha Ikot Ebak",
    "lat": "5.12504",
    "lng": "7.65716"
  },
  {
    "country": "NG",
    "name": "Ikorodu",
    "lat": "6.61526",
    "lng": "3.5069"
  },
  {
    "country": "NG",
    "name": "Ikom",
    "lat": "5.96669",
    "lng": "8.70632"
  },
  {
    "country": "NG",
    "name": "Ikole-Ekiti",
    "lat": "7.79148",
    "lng": "5.50865"
  },
  {
    "country": "NG",
    "name": "Ikirun",
    "lat": "7.91283",
    "lng": "4.66741"
  },
  {
    "country": "NG",
    "name": "Ikire",
    "lat": "7.37241",
    "lng": "4.18739"
  },
  {
    "country": "NG",
    "name": "Ikere-Ekiti",
    "lat": "7.49748",
    "lng": "5.23041"
  },
  {
    "country": "NG",
    "name": "Ikenne",
    "lat": "6.86579",
    "lng": "3.71518"
  },
  {
    "country": "NG",
    "name": "Ikem",
    "lat": "6.77993",
    "lng": "7.71484"
  },
  {
    "country": "NG",
    "name": "Ikeja",
    "lat": "6.59651",
    "lng": "3.34205"
  },
  {
    "country": "NG",
    "name": "Ikare",
    "lat": "7.52591",
    "lng": "5.75342"
  },
  {
    "country": "NG",
    "name": "Ikara",
    "lat": "11.17511",
    "lng": "8.22466"
  },
  {
    "country": "NG",
    "name": "Ikang",
    "lat": "4.78978",
    "lng": "8.5316"
  },
  {
    "country": "NG",
    "name": "Iju",
    "lat": "7.39452",
    "lng": "5.25919"
  },
  {
    "country": "NG",
    "name": "Ijero-Ekiti",
    "lat": "7.81514",
    "lng": "5.06716"
  },
  {
    "country": "NG",
    "name": "Ijebu-Ode",
    "lat": "6.81944",
    "lng": "3.91731"
  },
  {
    "country": "NG",
    "name": "Ijebu-Jesa",
    "lat": "7.68267",
    "lng": "4.81436"
  },
  {
    "country": "NG",
    "name": "Ijebu-Igbo",
    "lat": "6.97198",
    "lng": "3.99938"
  },
  {
    "country": "NG",
    "name": "Ijebu-Ife",
    "lat": "6.77837",
    "lng": "4.03386"
  },
  {
    "country": "NG",
    "name": "Iho",
    "lat": "5.58225",
    "lng": "7.09896"
  },
  {
    "country": "NG",
    "name": "Ihiala",
    "lat": "5.85475",
    "lng": "6.85944"
  },
  {
    "country": "NG",
    "name": "Iguobazuwa",
    "lat": "6.56585",
    "lng": "5.35455"
  },
  {
    "country": "NG",
    "name": "Igumale",
    "lat": "6.79792",
    "lng": "7.96794"
  },
  {
    "country": "NG",
    "name": "Igede-Ekiti",
    "lat": "7.6685",
    "lng": "5.12627"
  },
  {
    "country": "NG",
    "name": "Igbo-Ukwu",
    "lat": "6.01798",
    "lng": "7.02027"
  },
  {
    "country": "NG",
    "name": "Igbor",
    "lat": "7.45123",
    "lng": "8.60805"
  },
  {
    "country": "NG",
    "name": "Igbo-Ora",
    "lat": "7.43383",
    "lng": "3.28788"
  },
  {
    "country": "NG",
    "name": "Igbokoda",
    "lat": "6.35266",
    "lng": "4.80406"
  },
  {
    "country": "NG",
    "name": "Igboho",
    "lat": "8.83784",
    "lng": "3.75628"
  },
  {
    "country": "NG",
    "name": "Igbeti",
    "lat": "8.74921",
    "lng": "4.13113"
  },
  {
    "country": "NG",
    "name": "Igbekebo",
    "lat": "6.35521",
    "lng": "4.86221"
  },
  {
    "country": "NG",
    "name": "Igbara-Oke",
    "lat": "7.41172",
    "lng": "5.05805"
  },
  {
    "country": "NG",
    "name": "Igbara-Odo",
    "lat": "7.50251",
    "lng": "5.06258"
  },
  {
    "country": "NG",
    "name": "Igarra",
    "lat": "7.29366",
    "lng": "6.10432"
  },
  {
    "country": "NG",
    "name": "Igabi",
    "lat": "10.80603",
    "lng": "7.71443"
  },
  {
    "country": "NG",
    "name": "Ifon",
    "lat": "7.85992",
    "lng": "4.47621"
  },
  {
    "country": "NG",
    "name": "Ifon",
    "lat": "6.92973",
    "lng": "5.77368"
  },
  {
    "country": "NG",
    "name": "Ifo",
    "lat": "6.81491",
    "lng": "3.19518"
  },
  {
    "country": "NG",
    "name": "Ifetedo",
    "lat": "7.18419",
    "lng": "4.70046"
  },
  {
    "country": "NG",
    "name": "Ile-Ife",
    "lat": "7.4824",
    "lng": "4.56032"
  },
  {
    "country": "NG",
    "name": "Ifaki",
    "lat": "7.78942",
    "lng": "5.24852"
  },
  {
    "country": "NG",
    "name": "Idu",
    "lat": "5.03005",
    "lng": "8.01716"
  },
  {
    "country": "NG",
    "name": "Idogbo",
    "lat": "6.26812",
    "lng": "5.71296"
  },
  {
    "country": "NG",
    "name": "Idi Iroko",
    "lat": "6.63333",
    "lng": "2.73333"
  },
  {
    "country": "NG",
    "name": "Idi-Ayunre",
    "lat": "7.23292",
    "lng": "3.86152"
  },
  {
    "country": "NG",
    "name": "Ido-Ekiti",
    "lat": "7.84598",
    "lng": "5.18314"
  },
  {
    "country": "NG",
    "name": "Ido",
    "lat": "7.47103",
    "lng": "3.7574"
  },
  {
    "country": "NG",
    "name": "Idanre",
    "lat": "7.1127",
    "lng": "5.1159"
  },
  {
    "country": "NG",
    "name": "Idah",
    "lat": "7.11345",
    "lng": "6.73866"
  },
  {
    "country": "NG",
    "name": "Icheu",
    "lat": "7.7067",
    "lng": "6.7718"
  },
  {
    "country": "NG",
    "name": "Ibokun",
    "lat": "7.78492",
    "lng": "4.72653"
  },
  {
    "country": "NG",
    "name": "Iboko",
    "lat": "6.40655",
    "lng": "8.23329"
  },
  {
    "country": "NG",
    "name": "Ibi",
    "lat": "8.18122",
    "lng": "9.74431"
  },
  {
    "country": "NG",
    "name": "Ibeto",
    "lat": "10.48536",
    "lng": "5.14501"
  },
  {
    "country": "NG",
    "name": "Ibagwa-Aka",
    "lat": "6.91854",
    "lng": "7.39895"
  },
  {
    "country": "NG",
    "name": "Ibadan",
    "lat": "7.37756",
    "lng": "3.90591"
  },
  {
    "country": "NG",
    "name": "Hunkuyi",
    "lat": "11.2668",
    "lng": "7.64916"
  },
  {
    "country": "NG",
    "name": "Hong",
    "lat": "10.23305",
    "lng": "12.92805"
  },
  {
    "country": "NG",
    "name": "Holma",
    "lat": "9.89863",
    "lng": "13.0545"
  },
  {
    "country": "NG",
    "name": "Hinna",
    "lat": "10.30426",
    "lng": "11.49905"
  },
  {
    "country": "NG",
    "name": "Hadejia",
    "lat": "12.45347",
    "lng": "10.04115"
  },
  {
    "country": "NG",
    "name": "Gwoza",
    "lat": "11.08313",
    "lng": "13.69595"
  },
  {
    "country": "NG",
    "name": "Ugwolawo",
    "lat": "7.23672",
    "lng": "6.92302"
  },
  {
    "country": "NG",
    "name": "Gwiwa",
    "lat": "12.78169",
    "lng": "8.33722"
  },
  {
    "country": "NG",
    "name": "Gwio Kura",
    "lat": "12.67479",
    "lng": "11.0669"
  },
  {
    "country": "NG",
    "name": "Gwasero",
    "lat": "9.48333",
    "lng": "3.5"
  },
  {
    "country": "NG",
    "name": "Gwarzo",
    "lat": "11.91597",
    "lng": "7.9337"
  },
  {
    "country": "NG",
    "name": "Gwaram",
    "lat": "11.27727",
    "lng": "9.88385"
  },
  {
    "country": "NG",
    "name": "Gwaram",
    "lat": "10.23295",
    "lng": "10.28572"
  },
  {
    "country": "NG",
    "name": "Gwantu",
    "lat": "9.22899",
    "lng": "8.45807"
  },
  {
    "country": "NG",
    "name": "Gwandu",
    "lat": "12.50204",
    "lng": "4.64295"
  },
  {
    "country": "NG",
    "name": "Gwagwalada",
    "lat": "8.94342",
    "lng": "7.08165"
  },
  {
    "country": "NG",
    "name": "Gwadabawa",
    "lat": "13.35819",
    "lng": "5.23812"
  },
  {
    "country": "NG",
    "name": "Guyuk",
    "lat": "9.90663",
    "lng": "11.92753"
  },
  {
    "country": "NG",
    "name": "Gusau",
    "lat": "12.17024",
    "lng": "6.66412"
  },
  {
    "country": "NG",
    "name": "Guri",
    "lat": "12.7281",
    "lng": "10.41989"
  },
  {
    "country": "NG",
    "name": "Gummi",
    "lat": "12.14484",
    "lng": "5.11776"
  },
  {
    "country": "NG",
    "name": "Gumel",
    "lat": "12.6269",
    "lng": "9.38807"
  },
  {
    "country": "NG",
    "name": "Gulma",
    "lat": "12.64231",
    "lng": "4.35545"
  },
  {
    "country": "NG",
    "name": "Gulak",
    "lat": "10.8053",
    "lng": "13.45824"
  },
  {
    "country": "NG",
    "name": "Gujba",
    "lat": "11.49959",
    "lng": "11.93396"
  },
  {
    "country": "NG",
    "name": "Gudumbali",
    "lat": "12.94284",
    "lng": "13.17831"
  },
  {
    "country": "NG",
    "name": "Gubio",
    "lat": "12.49749",
    "lng": "12.78089"
  },
  {
    "country": "NG",
    "name": "Goronyo",
    "lat": "13.44226",
    "lng": "5.67234"
  },
  {
    "country": "NG",
    "name": "Gorgoram",
    "lat": "12.63958",
    "lng": "10.70422"
  },
  {
    "country": "NG",
    "name": "Gora",
    "lat": "11.91294",
    "lng": "7.66531"
  },
  {
    "country": "NG",
    "name": "Goniri",
    "lat": "11.48451",
    "lng": "12.31264"
  },
  {
    "country": "NG",
    "name": "Gombi",
    "lat": "10.16756",
    "lng": "12.73684"
  },
  {
    "country": "NG",
    "name": "Gombe",
    "lat": "10.28969",
    "lng": "11.16729"
  },
  {
    "country": "NG",
    "name": "Giwa",
    "lat": "11.31568",
    "lng": "7.44957"
  },
  {
    "country": "NG",
    "name": "Girei",
    "lat": "9.36526",
    "lng": "12.54621"
  },
  {
    "country": "NG",
    "name": "Gidan Madi",
    "lat": "13.29575",
    "lng": "4.97467"
  },
  {
    "country": "NG",
    "name": "Giade",
    "lat": "11.39083",
    "lng": "10.19987"
  },
  {
    "country": "NG",
    "name": "Gezawa",
    "lat": "12.10157",
    "lng": "8.75029"
  },
  {
    "country": "NG",
    "name": "Gembu",
    "lat": "6.72556",
    "lng": "11.25652"
  },
  {
    "country": "NG",
    "name": "Gella",
    "lat": "10.15738",
    "lng": "13.30004"
  },
  {
    "country": "NG",
    "name": "Geidam",
    "lat": "12.89439",
    "lng": "11.92649"
  },
  {
    "country": "NG",
    "name": "Buruku",
    "lat": "7.45961",
    "lng": "9.20455"
  },
  {
    "country": "NG",
    "name": "Gbongan",
    "lat": "7.47734",
    "lng": "4.35351"
  },
  {
    "country": "NG",
    "name": "Gboko",
    "lat": "7.32275",
    "lng": "9.00108"
  },
  {
    "country": "NG",
    "name": "Gbajimba",
    "lat": "7.8204",
    "lng": "8.85955"
  },
  {
    "country": "NG",
    "name": "Gaya",
    "lat": "11.86064",
    "lng": "9.0027"
  },
  {
    "country": "NG",
    "name": "Gassol",
    "lat": "8.53535",
    "lng": "10.44615"
  },
  {
    "country": "NG",
    "name": "Gashua",
    "lat": "12.87398",
    "lng": "11.04057"
  },
  {
    "country": "NG",
    "name": "Garun Malam",
    "lat": "11.68566",
    "lng": "8.36986"
  },
  {
    "country": "NG",
    "name": "Garko",
    "lat": "11.64974",
    "lng": "8.80328"
  },
  {
    "country": "NG",
    "name": "Garko",
    "lat": "10.17506",
    "lng": "11.16458"
  },
  {
    "country": "NG",
    "name": "Garki",
    "lat": "12.43456",
    "lng": "9.19028"
  },
  {
    "country": "NG",
    "name": "Garaku",
    "lat": "8.84717",
    "lng": "8.13021"
  },
  {
    "country": "NG",
    "name": "Ganye",
    "lat": "8.43497",
    "lng": "12.05107"
  },
  {
    "country": "NG",
    "name": "Gantsa",
    "lat": "11.66312",
    "lng": "9.72639"
  },
  {
    "country": "NG",
    "name": "Gandi",
    "lat": "12.96358",
    "lng": "5.74337"
  },
  {
    "country": "NG",
    "name": "Gamboru",
    "lat": "12.37299",
    "lng": "14.2069"
  },
  {
    "country": "NG",
    "name": "Gamawa",
    "lat": "12.13379",
    "lng": "10.53785"
  },
  {
    "country": "NG",
    "name": "Gakem",
    "lat": "6.76963",
    "lng": "8.9912"
  },
  {
    "country": "NG",
    "name": "Gajiram",
    "lat": "12.49149",
    "lng": "13.21191"
  },
  {
    "country": "NG",
    "name": "Gagarawa",
    "lat": "12.40848",
    "lng": "9.52881"
  },
  {
    "country": "NG",
    "name": "Gada",
    "lat": "13.7543",
    "lng": "5.65723"
  },
  {
    "country": "NG",
    "name": "Gabarin",
    "lat": "11.1093",
    "lng": "10.4441"
  },
  {
    "country": "NG",
    "name": "Funtua",
    "lat": "11.52351",
    "lng": "7.31174"
  },
  {
    "country": "NG",
    "name": "Fugar",
    "lat": "7.09076",
    "lng": "6.49828"
  },
  {
    "country": "NG",
    "name": "Fufu",
    "lat": "8.44838",
    "lng": "4.72077"
  },
  {
    "country": "NG",
    "name": "Fufore",
    "lat": "9.22175",
    "lng": "12.64975"
  },
  {
    "country": "NG",
    "name": "Fika",
    "lat": "11.28674",
    "lng": "11.30772"
  },
  {
    "country": "NG",
    "name": "Fiditi",
    "lat": "7.71361",
    "lng": "3.91722"
  },
  {
    "country": "NG",
    "name": "Faskari",
    "lat": "11.72108",
    "lng": "7.02991"
  },
  {
    "country": "NG",
    "name": "Ezza-Ohu",
    "lat": "6.44094",
    "lng": "8.08432"
  },
  {
    "country": "NG",
    "name": "Ezzamgbo",
    "lat": "6.39895",
    "lng": "7.96155"
  },
  {
    "country": "NG",
    "name": "Etinan",
    "lat": "4.84262",
    "lng": "7.85252"
  },
  {
    "country": "NG",
    "name": "Ete",
    "lat": "7.08956",
    "lng": "7.45341"
  },
  {
    "country": "NG",
    "name": "Esuk Oron",
    "lat": "4.80293",
    "lng": "8.25341"
  },
  {
    "country": "NG",
    "name": "Eruwa",
    "lat": "7.53365",
    "lng": "3.41796"
  },
  {
    "country": "NG",
    "name": "Epe",
    "lat": "6.58412",
    "lng": "3.98336"
  },
  {
    "country": "NG",
    "name": "Enwang",
    "lat": "4.65643",
    "lng": "8.25206"
  },
  {
    "country": "NG",
    "name": "Umunze",
    "lat": "5.96694",
    "lng": "7.23664"
  },
  {
    "country": "NG",
    "name": "Enugu-Ukwu",
    "lat": "6.17146",
    "lng": "7.00525"
  },
  {
    "country": "NG",
    "name": "Enugu-Ezike",
    "lat": "6.9827",
    "lng": "7.45534"
  },
  {
    "country": "NG",
    "name": "Enugu",
    "lat": "6.44132",
    "lng": "7.49883"
  },
  {
    "country": "NG",
    "name": "Enagi",
    "lat": "9.12734",
    "lng": "5.54387"
  },
  {
    "country": "NG",
    "name": "Emure-Ekiti",
    "lat": "7.43636",
    "lng": "5.45925"
  },
  {
    "country": "NG",
    "name": "Emuoha",
    "lat": "4.884",
    "lng": "6.8601"
  },
  {
    "country": "NG",
    "name": "Elele",
    "lat": "5.1009",
    "lng": "6.81411"
  },
  {
    "country": "NG",
    "name": "Ekpoma",
    "lat": "6.743",
    "lng": "6.14029"
  },
  {
    "country": "NG",
    "name": "Eket",
    "lat": "4.64231",
    "lng": "7.92438"
  },
  {
    "country": "NG",
    "name": "Ekeremor",
    "lat": "5.05805",
    "lng": "5.78048"
  },
  {
    "country": "NG",
    "name": "Ejirin",
    "lat": "6.61423",
    "lng": "3.90019"
  },
  {
    "country": "NG",
    "name": "Ejigbo",
    "lat": "7.90292",
    "lng": "4.31419"
  },
  {
    "country": "NG",
    "name": "Ehor",
    "lat": "6.6155",
    "lng": "5.98238"
  },
  {
    "country": "NG",
    "name": "Eha Amufu",
    "lat": "6.65915",
    "lng": "7.75961"
  },
  {
    "country": "NG",
    "name": "Egbeda",
    "lat": "7.3772",
    "lng": "4.04975"
  },
  {
    "country": "NG",
    "name": "Egbe",
    "lat": "8.21667",
    "lng": "5.51667"
  },
  {
    "country": "NG",
    "name": "Effurun",
    "lat": "5.55629",
    "lng": "5.78459"
  },
  {
    "country": "NG",
    "name": "Efon-Alaaye",
    "lat": "7.65649",
    "lng": "4.92235"
  },
  {
    "country": "NG",
    "name": "Effium",
    "lat": "6.63105",
    "lng": "8.05814"
  },
  {
    "country": "NG",
    "name": "Effraya",
    "lat": "5.85926",
    "lng": "8.72301"
  },
  {
    "country": "NG",
    "name": "Ede",
    "lat": "7.73635",
    "lng": "4.43536"
  },
  {
    "country": "NG",
    "name": "Ebute-Metta",
    "lat": "6.48799",
    "lng": "3.38166"
  },
  {
    "country": "NG",
    "name": "Ebute Ikorodu",
    "lat": "6.60086",
    "lng": "3.48818"
  },
  {
    "country": "NG",
    "name": "Eberi",
    "lat": "5.09117",
    "lng": "7.2337"
  },
  {
    "country": "NG",
    "name": "Ebem Ohafia",
    "lat": "5.63108",
    "lng": "7.83024"
  },
  {
    "country": "NG",
    "name": "Dutsin-Ma",
    "lat": "12.45392",
    "lng": "7.49723"
  },
  {
    "country": "NG",
    "name": "Dutsi",
    "lat": "12.82862",
    "lng": "8.1398"
  },
  {
    "country": "NG",
    "name": "Dutsen Wai",
    "lat": "10.85009",
    "lng": "8.199"
  },
  {
    "country": "NG",
    "name": "Dutse",
    "lat": "11.75618",
    "lng": "9.33896"
  },
  {
    "country": "NG",
    "name": "Malam Madori",
    "lat": "12.56473",
    "lng": "9.88084"
  },
  {
    "country": "NG",
    "name": "Duku",
    "lat": "11.2361",
    "lng": "4.90727"
  },
  {
    "country": "NG",
    "name": "Dukku",
    "lat": "10.82379",
    "lng": "10.77221"
  },
  {
    "country": "NG",
    "name": "Donga",
    "lat": "7.72175",
    "lng": "10.04526"
  },
  {
    "country": "NG",
    "name": "Doma",
    "lat": "8.39307",
    "lng": "8.35544"
  },
  {
    "country": "NG",
    "name": "Disina",
    "lat": "11.48135",
    "lng": "9.91903"
  },
  {
    "country": "NG",
    "name": "Dindima",
    "lat": "10.22629",
    "lng": "10.15132"
  },
  {
    "country": "NG",
    "name": "Dikwa",
    "lat": "12.03609",
    "lng": "13.91815"
  },
  {
    "country": "NG",
    "name": "Dikenafai",
    "lat": "5.77015",
    "lng": "7.15473"
  },
  {
    "country": "NG",
    "name": "Dengi",
    "lat": "9.36872",
    "lng": "9.96223"
  },
  {
    "country": "NG",
    "name": "Demsa",
    "lat": "9.45566",
    "lng": "12.15249"
  },
  {
    "country": "NG",
    "name": "Dekina",
    "lat": "7.68967",
    "lng": "7.0438"
  },
  {
    "country": "NG",
    "name": "Degema",
    "lat": "4.74807",
    "lng": "6.76618"
  },
  {
    "country": "NG",
    "name": "Deba",
    "lat": "10.21187",
    "lng": "11.3871"
  },
  {
    "country": "NG",
    "name": "Dawakin Tofa",
    "lat": "12.10452",
    "lng": "8.32999"
  },
  {
    "country": "NG",
    "name": "Dawakin Kudu",
    "lat": "11.83727",
    "lng": "8.59699"
  },
  {
    "country": "NG",
    "name": "Daura",
    "lat": "13.03299",
    "lng": "8.32351"
  },
  {
    "country": "NG",
    "name": "Daura",
    "lat": "11.5541",
    "lng": "11.406"
  },
  {
    "country": "NG",
    "name": "Darazo",
    "lat": "10.9992",
    "lng": "10.41062"
  },
  {
    "country": "NG",
    "name": "Dapchi",
    "lat": "12.49536",
    "lng": "11.49977"
  },
  {
    "country": "NG",
    "name": "Dan Sadau",
    "lat": "11.29621",
    "lng": "6.4952"
  },
  {
    "country": "NG",
    "name": "Dan Musa",
    "lat": "12.26157",
    "lng": "7.33409"
  },
  {
    "country": "NG",
    "name": "Dankama",
    "lat": "13.29782",
    "lng": "7.79492"
  },
  {
    "country": "NG",
    "name": "Dankalwa",
    "lat": "11.74449",
    "lng": "12.18545"
  },
  {
    "country": "NG",
    "name": "Danja",
    "lat": "11.3771",
    "lng": "7.56097"
  },
  {
    "country": "NG",
    "name": "Dan Gora",
    "lat": "11.53485",
    "lng": "8.15224"
  },
  {
    "country": "NG",
    "name": "Dange",
    "lat": "12.85313",
    "lng": "5.34572"
  },
  {
    "country": "NG",
    "name": "Dandume",
    "lat": "11.4588",
    "lng": "7.12602"
  },
  {
    "country": "NG",
    "name": "Damboa",
    "lat": "11.15534",
    "lng": "12.75638"
  },
  {
    "country": "NG",
    "name": "Dambatta",
    "lat": "12.435",
    "lng": "8.51531"
  },
  {
    "country": "NG",
    "name": "Dambam",
    "lat": "11.67893",
    "lng": "10.70792"
  },
  {
    "country": "NG",
    "name": "Damaturu",
    "lat": "11.74697",
    "lng": "11.96083"
  },
  {
    "country": "NG",
    "name": "Damasak",
    "lat": "13.10518",
    "lng": "12.50854"
  },
  {
    "country": "NG",
    "name": "Damagum",
    "lat": "11.67824",
    "lng": "11.33517"
  },
  {
    "country": "NG",
    "name": "Dakingari",
    "lat": "11.64809",
    "lng": "4.06177"
  },
  {
    "country": "NG",
    "name": "Dadiya",
    "lat": "9.61667",
    "lng": "11.43333"
  },
  {
    "country": "NG",
    "name": "Dabai",
    "lat": "11.47651",
    "lng": "5.20625"
  },
  {
    "country": "NG",
    "name": "Chibok",
    "lat": "10.86949",
    "lng": "12.84657"
  },
  {
    "country": "NG",
    "name": "Charanchi",
    "lat": "12.67155",
    "lng": "7.72929"
  },
  {
    "country": "NG",
    "name": "Tsafe",
    "lat": "11.95775",
    "lng": "6.92083"
  },
  {
    "country": "NG",
    "name": "Calabar",
    "lat": "4.95893",
    "lng": "8.32695"
  },
  {
    "country": "NG",
    "name": "Bwari",
    "lat": "9.27995",
    "lng": "7.38045"
  },
  {
    "country": "NG",
    "name": "Burutu",
    "lat": "5.35328",
    "lng": "5.50826"
  },
  {
    "country": "NG",
    "name": "Burumburum",
    "lat": "11.39106",
    "lng": "8.72341"
  },
  {
    "country": "NG",
    "name": "Bununu",
    "lat": "9.88224",
    "lng": "9.68058"
  },
  {
    "country": "NG",
    "name": "Dass",
    "lat": "10.00065",
    "lng": "9.51596"
  },
  {
    "country": "NG",
    "name": "Bunkure",
    "lat": "11.69924",
    "lng": "8.54127"
  },
  {
    "country": "NG",
    "name": "Bungudu",
    "lat": "12.26848",
    "lng": "6.55288"
  },
  {
    "country": "NG",
    "name": "Bukuru",
    "lat": "9.79399",
    "lng": "8.86397"
  },
  {
    "country": "NG",
    "name": "Bukkuyum",
    "lat": "12.1372",
    "lng": "5.46821"
  },
  {
    "country": "NG",
    "name": "Buguma",
    "lat": "4.73614",
    "lng": "6.86236"
  },
  {
    "country": "NG",
    "name": "Buga",
    "lat": "8.49056",
    "lng": "7.34139"
  },
  {
    "country": "NG",
    "name": "Briyel",
    "lat": "10.34764",
    "lng": "11.6099"
  },
  {
    "country": "NG",
    "name": "Twon-Brass",
    "lat": "4.31231",
    "lng": "6.24091"
  },
  {
    "country": "NG",
    "name": "Bornu Yassu",
    "lat": "12.27503",
    "lng": "12.56856"
  },
  {
    "country": "NG",
    "name": "Bori",
    "lat": "4.67629",
    "lng": "7.36519"
  },
  {
    "country": "NG",
    "name": "Ugbokpo",
    "lat": "7.65321",
    "lng": "7.8841"
  },
  {
    "country": "NG",
    "name": "Bonny",
    "lat": "4.4516",
    "lng": "7.17074"
  },
  {
    "country": "NG",
    "name": "Bomadi",
    "lat": "5.16073",
    "lng": "5.92375"
  },
  {
    "country": "NG",
    "name": "Bokkos",
    "lat": "9.29921",
    "lng": "8.99467"
  },
  {
    "country": "NG",
    "name": "Bokani",
    "lat": "9.43333",
    "lng": "5.2"
  },
  {
    "country": "NG",
    "name": "Boju",
    "lat": "7.35572",
    "lng": "7.89303"
  },
  {
    "country": "NG",
    "name": "Boje",
    "lat": "6.28428",
    "lng": "8.92062"
  },
  {
    "country": "NG",
    "name": "Boi",
    "lat": "9.56109",
    "lng": "9.50154"
  },
  {
    "country": "NG",
    "name": "Bogoro",
    "lat": "9.66904",
    "lng": "9.60528"
  },
  {
    "country": "NG",
    "name": "Bodinga",
    "lat": "12.84413",
    "lng": "5.15001"
  },
  {
    "country": "NG",
    "name": "Bode Saadu",
    "lat": "8.939",
    "lng": "4.78227"
  },
  {
    "country": "NG",
    "name": "Bode Osi",
    "lat": "7.75103",
    "lng": "4.2298"
  },
  {
    "country": "NG",
    "name": "Biu",
    "lat": "10.61285",
    "lng": "12.19458"
  },
  {
    "country": "NG",
    "name": "Mallam Fatori",
    "lat": "13.6746",
    "lng": "13.33952"
  },
  {
    "country": "NG",
    "name": "Birniwa",
    "lat": "12.7907",
    "lng": "10.23614"
  },
  {
    "country": "NG",
    "name": "Birnin Kudu",
    "lat": "11.45207",
    "lng": "9.47856"
  },
  {
    "country": "NG",
    "name": "Birnin Kebbi",
    "lat": "12.45389",
    "lng": "4.1975"
  },
  {
    "country": "NG",
    "name": "Sofo-Birnin-Gwari",
    "lat": "11.01537",
    "lng": "6.78036"
  },
  {
    "country": "NG",
    "name": "Birnin Gwari",
    "lat": "10.66374",
    "lng": "6.54003"
  },
  {
    "country": "NG",
    "name": "Bin Yauri",
    "lat": "10.7823",
    "lng": "4.81135"
  },
  {
    "country": "NG",
    "name": "Binji",
    "lat": "13.22294",
    "lng": "4.90888"
  },
  {
    "country": "NG",
    "name": "Bindawa",
    "lat": "12.66987",
    "lng": "7.80865"
  },
  {
    "country": "NG",
    "name": "Billiri",
    "lat": "9.89024",
    "lng": "11.21794"
  },
  {
    "country": "NG",
    "name": "Billiri",
    "lat": "9.86545",
    "lng": "11.22624"
  },
  {
    "country": "NG",
    "name": "Bida",
    "lat": "9.08044",
    "lng": "6.0099"
  },
  {
    "country": "NG",
    "name": "Bichi",
    "lat": "12.23385",
    "lng": "8.24063"
  },
  {
    "country": "NG",
    "name": "Besse",
    "lat": "11.26676",
    "lng": "4.43114"
  },
  {
    "country": "NG",
    "name": "Benisheikh",
    "lat": "11.80919",
    "lng": "12.49151"
  },
  {
    "country": "NG",
    "name": "Benin City",
    "lat": "6.33815",
    "lng": "5.62575"
  },
  {
    "country": "NG",
    "name": "Bende",
    "lat": "5.55874",
    "lng": "7.63359"
  },
  {
    "country": "NG",
    "name": "Bena",
    "lat": "11.28444",
    "lng": "5.93472"
  },
  {
    "country": "NG",
    "name": "Beli",
    "lat": "7.85868",
    "lng": "10.97187"
  },
  {
    "country": "NG",
    "name": "Bebeji",
    "lat": "11.66768",
    "lng": "8.262"
  },
  {
    "country": "NG",
    "name": "Baure",
    "lat": "12.83772",
    "lng": "8.74513"
  },
  {
    "country": "NG",
    "name": "Bauchi",
    "lat": "10.31032",
    "lng": "9.84388"
  },
  {
    "country": "NG",
    "name": "Batsari",
    "lat": "12.75551",
    "lng": "7.24809"
  },
  {
    "country": "NG",
    "name": "Batagarawa",
    "lat": "12.90611",
    "lng": "7.60586"
  },
  {
    "country": "NG",
    "name": "Bassa",
    "lat": "9.94249",
    "lng": "8.74042"
  },
  {
    "country": "NG",
    "name": "Baro",
    "lat": "8.6",
    "lng": "6.41667"
  },
  {
    "country": "NG",
    "name": "Barkin Ladi",
    "lat": "9.53812",
    "lng": "8.8927"
  },
  {
    "country": "NG",
    "name": "Bara",
    "lat": "10.93605",
    "lng": "11.68242"
  },
  {
    "country": "NG",
    "name": "Bara",
    "lat": "10.37444",
    "lng": "10.72884"
  },
  {
    "country": "NG",
    "name": "Bama",
    "lat": "11.52134",
    "lng": "13.68952"
  },
  {
    "country": "NG",
    "name": "Balle",
    "lat": "13.47029",
    "lng": "4.68119"
  },
  {
    "country": "NG",
    "name": "Bakura",
    "lat": "12.71141",
    "lng": "5.87367"
  },
  {
    "country": "NG",
    "name": "Bakori",
    "lat": "11.55559",
    "lng": "7.42419"
  },
  {
    "country": "NG",
    "name": "Bajoga",
    "lat": "10.85152",
    "lng": "11.43169"
  },
  {
    "country": "NG",
    "name": "Baissa",
    "lat": "7.23087",
    "lng": "10.62444"
  },
  {
    "country": "NG",
    "name": "Bagwai",
    "lat": "12.1577",
    "lng": "8.1358"
  },
  {
    "country": "NG",
    "name": "Bagudo",
    "lat": "11.40351",
    "lng": "4.22571"
  },
  {
    "country": "NG",
    "name": "Bugana",
    "lat": "7.99917",
    "lng": "7.58361"
  },
  {
    "country": "NG",
    "name": "Obagaji",
    "lat": "7.89169",
    "lng": "7.90938"
  },
  {
    "country": "NG",
    "name": "Badeggi",
    "lat": "9.0563",
    "lng": "6.143"
  },
  {
    "country": "NG",
    "name": "Badagry",
    "lat": "6.41502",
    "lng": "2.88132"
  },
  {
    "country": "NG",
    "name": "Babura",
    "lat": "12.77256",
    "lng": "9.01525"
  },
  {
    "country": "NG",
    "name": "Babban Gida",
    "lat": "12.15482",
    "lng": "11.7709"
  },
  {
    "country": "NG",
    "name": "Babana",
    "lat": "10.42949",
    "lng": "3.81495"
  },
  {
    "country": "NG",
    "name": "Azare",
    "lat": "11.67478",
    "lng": "10.19069"
  },
  {
    "country": "NG",
    "name": "Awo-Idemili",
    "lat": "5.82648",
    "lng": "6.93374"
  },
  {
    "country": "NG",
    "name": "Awo",
    "lat": "7.76764",
    "lng": "4.39515"
  },
  {
    "country": "NG",
    "name": "Awka",
    "lat": "6.21269",
    "lng": "7.07199"
  },
  {
    "country": "NG",
    "name": "Awgu",
    "lat": "6.07278",
    "lng": "7.47739"
  },
  {
    "country": "NG",
    "name": "Awe",
    "lat": "8.10445",
    "lng": "9.14011"
  },
  {
    "country": "NG",
    "name": "Auna",
    "lat": "10.18805",
    "lng": "4.72318"
  },
  {
    "country": "NG",
    "name": "Augie",
    "lat": "12.89027",
    "lng": "4.59965"
  },
  {
    "country": "NG",
    "name": "Auchi",
    "lat": "7.06756",
    "lng": "6.2636"
  },
  {
    "country": "NG",
    "name": "Atani",
    "lat": "6.01277",
    "lng": "6.74768"
  },
  {
    "country": "NG",
    "name": "Askira",
    "lat": "10.65086",
    "lng": "12.90883"
  },
  {
    "country": "NG",
    "name": "Azare",
    "lat": "10.52583",
    "lng": "12.29115"
  },
  {
    "country": "NG",
    "name": "Asaba",
    "lat": "6.19824",
    "lng": "6.73187"
  },
  {
    "country": "NG",
    "name": "Arochukwu",
    "lat": "5.38941",
    "lng": "7.91235"
  },
  {
    "country": "NG",
    "name": "Argungu",
    "lat": "12.74482",
    "lng": "4.52514"
  },
  {
    "country": "NG",
    "name": "Araromi-Opin",
    "lat": "8.06527",
    "lng": "5.25398"
  },
  {
    "country": "NG",
    "name": "Aramoko-Ekiti",
    "lat": "7.70483",
    "lng": "5.04054"
  },
  {
    "country": "NG",
    "name": "Apomu",
    "lat": "7.35156",
    "lng": "4.18335"
  },
  {
    "country": "NG",
    "name": "Apapa",
    "lat": "6.4488",
    "lng": "3.35901"
  },
  {
    "country": "NG",
    "name": "Ankpa",
    "lat": "7.40249",
    "lng": "7.63196"
  },
  {
    "country": "NG",
    "name": "Anka",
    "lat": "12.11347",
    "lng": "5.92681"
  },
  {
    "country": "NG",
    "name": "Anchau",
    "lat": "10.96245",
    "lng": "8.39233"
  },
  {
    "country": "NG",
    "name": "Anaku",
    "lat": "6.46875",
    "lng": "6.92893"
  },
  {
    "country": "NG",
    "name": "Amper",
    "lat": "9.35509",
    "lng": "9.70121"
  },
  {
    "country": "NG",
    "name": "Amaigbo",
    "lat": "5.73016",
    "lng": "7.1151"
  },
  {
    "country": "NG",
    "name": "Amassoma",
    "lat": "4.97032",
    "lng": "6.10915"
  },
  {
    "country": "NG",
    "name": "Umundugba",
    "lat": "5.67597",
    "lng": "7.07184"
  },
  {
    "country": "NG",
    "name": "Amaigbo",
    "lat": "5.78917",
    "lng": "7.83829"
  },
  {
    "country": "NG",
    "name": "Amagunze",
    "lat": "6.33063",
    "lng": "7.65247"
  },
  {
    "country": "NG",
    "name": "Alkaleri",
    "lat": "10.26688",
    "lng": "10.33238"
  },
  {
    "country": "NG",
    "name": "Aliero",
    "lat": "12.28835",
    "lng": "4.47139"
  },
  {
    "country": "NG",
    "name": "Aliade",
    "lat": "7.29627",
    "lng": "8.48278"
  },
  {
    "country": "NG",
    "name": "Albasu",
    "lat": "11.67403",
    "lng": "9.14059"
  },
  {
    "country": "NG",
    "name": "Alapa",
    "lat": "8.61667",
    "lng": "4.38333"
  },
  {
    "country": "NG",
    "name": "Akwukwu-Igbo",
    "lat": "6.35753",
    "lng": "6.59066"
  },
  {
    "country": "NG",
    "name": "Akwete",
    "lat": "4.88688",
    "lng": "7.35686"
  },
  {
    "country": "NG",
    "name": "Akwanga",
    "lat": "8.91077",
    "lng": "8.40655"
  },
  {
    "country": "NG",
    "name": "Akure",
    "lat": "7.25256",
    "lng": "5.19312"
  },
  {
    "country": "NG",
    "name": "Aku",
    "lat": "6.70902",
    "lng": "7.31826"
  },
  {
    "country": "NG",
    "name": "Akodo",
    "lat": "6.43787",
    "lng": "3.9309"
  },
  {
    "country": "NG",
    "name": "Akko",
    "lat": "10.28899",
    "lng": "10.9732"
  },
  {
    "country": "NG",
    "name": "Ake-Eze",
    "lat": "5.91677",
    "lng": "7.67615"
  },
  {
    "country": "NG",
    "name": "Akanran",
    "lat": "7.28124",
    "lng": "4.02553"
  },
  {
    "country": "NG",
    "name": "Akamkpa",
    "lat": "5.31246",
    "lng": "8.35515"
  },
  {
    "country": "NG",
    "name": "Akankpa",
    "lat": "5.1264",
    "lng": "8.1898"
  },
  {
    "country": "NG",
    "name": "Ajingi",
    "lat": "11.96826",
    "lng": "9.03679"
  },
  {
    "country": "NG",
    "name": "Ajaawa",
    "lat": "7.93118",
    "lng": "4.12654"
  },
  {
    "country": "NG",
    "name": "Ajasse Ipo",
    "lat": "8.23333",
    "lng": "4.81667"
  },
  {
    "country": "NG",
    "name": "Ajaokuta",
    "lat": "7.56229",
    "lng": "6.65497"
  },
  {
    "country": "NG",
    "name": "Ajalli",
    "lat": "6.04427",
    "lng": "7.20864"
  },
  {
    "country": "NG",
    "name": "Ajaka",
    "lat": "7.17416",
    "lng": "6.82535"
  },
  {
    "country": "NG",
    "name": "Ayetoro",
    "lat": "7.24281",
    "lng": "3.02639"
  },
  {
    "country": "NG",
    "name": "Ayete",
    "lat": "7.54286",
    "lng": "3.22263"
  },
  {
    "country": "NG",
    "name": "Ahoada",
    "lat": "5.0828",
    "lng": "6.64981"
  },
  {
    "country": "NG",
    "name": "Agwara",
    "lat": "10.70611",
    "lng": "4.58125"
  },
  {
    "country": "NG",
    "name": "Agulu",
    "lat": "6.10045",
    "lng": "7.061"
  },
  {
    "country": "NG",
    "name": "Aguata",
    "lat": "6.01634",
    "lng": "7.08782"
  },
  {
    "country": "NG",
    "name": "Akpet Central",
    "lat": "5.62105",
    "lng": "8.10163"
  },
  {
    "country": "NG",
    "name": "Ago Are",
    "lat": "8.5",
    "lng": "3.41667"
  },
  {
    "country": "NG",
    "name": "Ago-Amodu",
    "lat": "8.62314",
    "lng": "3.61419"
  },
  {
    "country": "NG",
    "name": "Agenebode",
    "lat": "7.10512",
    "lng": "6.69381"
  },
  {
    "country": "NG",
    "name": "Agege",
    "lat": "6.61563",
    "lng": "3.33337"
  },
  {
    "country": "NG",
    "name": "Agbor",
    "lat": "6.25375",
    "lng": "6.1942"
  },
  {
    "country": "NG",
    "name": "Tse-Agberagba",
    "lat": "7.07668",
    "lng": "8.66551"
  },
  {
    "country": "NG",
    "name": "Agbani",
    "lat": "6.30669",
    "lng": "7.54862"
  },
  {
    "country": "NG",
    "name": "Agbabu",
    "lat": "6.58862",
    "lng": "4.8343"
  },
  {
    "country": "NG",
    "name": "Agaie",
    "lat": "9.0085",
    "lng": "6.31821"
  },
  {
    "country": "NG",
    "name": "Afuze",
    "lat": "6.96945",
    "lng": "6.04254"
  },
  {
    "country": "NG",
    "name": "Afon",
    "lat": "8.31313",
    "lng": "4.52738"
  },
  {
    "country": "NG",
    "name": "Afikpo",
    "lat": "5.89258",
    "lng": "7.93534"
  },
  {
    "country": "NG",
    "name": "Afam",
    "lat": "4.79004",
    "lng": "7.31187"
  },
  {
    "country": "NG",
    "name": "Afaha Offiong",
    "lat": "4.86226",
    "lng": "7.90626"
  },
  {
    "country": "NG",
    "name": "Adoru",
    "lat": "6.97694",
    "lng": "7.16262"
  },
  {
    "country": "NG",
    "name": "Ado Odo",
    "lat": "6.6",
    "lng": "2.93333"
  },
  {
    "country": "NG",
    "name": "Adogo",
    "lat": "7.51004",
    "lng": "6.4798"
  },
  {
    "country": "NG",
    "name": "Ado-Ekiti",
    "lat": "7.62329",
    "lng": "5.22087"
  },
  {
    "country": "NG",
    "name": "Adikpo",
    "lat": "6.89002",
    "lng": "9.23351"
  },
  {
    "country": "NG",
    "name": "Adani",
    "lat": "6.73971",
    "lng": "7.01117"
  },
  {
    "country": "NG",
    "name": "Achalla",
    "lat": "6.33465",
    "lng": "6.98863"
  },
  {
    "country": "NG",
    "name": "Abuochiche",
    "lat": "6.69132",
    "lng": "8.94337"
  },
  {
    "country": "NG",
    "name": "Abuja",
    "lat": "9.05785",
    "lng": "7.49508"
  },
  {
    "country": "NG",
    "name": "Abudu",
    "lat": "6.29489",
    "lng": "6.02995"
  },
  {
    "country": "NG",
    "name": "Abua",
    "lat": "4.85763",
    "lng": "6.64519"
  },
  {
    "country": "NG",
    "name": "Abraka",
    "lat": "5.79023",
    "lng": "6.10473"
  },
  {
    "country": "NG",
    "name": "Abonnema",
    "lat": "4.73171",
    "lng": "6.77223"
  },
  {
    "country": "NG",
    "name": "Aboh",
    "lat": "5.54781",
    "lng": "6.52588"
  },
  {
    "country": "NG",
    "name": "Abocho",
    "lat": "7.5677",
    "lng": "6.9863"
  },
  {
    "country": "NG",
    "name": "Abigi",
    "lat": "6.48676",
    "lng": "4.39531"
  },
  {
    "country": "NG",
    "name": "Abeokuta",
    "lat": "7.15571",
    "lng": "3.34509"
  },
  {
    "country": "NG",
    "name": "Abejukolo",
    "lat": "7.86808",
    "lng": "7.50907"
  },
  {
    "country": "NG",
    "name": "Abakaliki",
    "lat": "6.32485",
    "lng": "8.11368"
  },
  {
    "country": "NG",
    "name": "Abak",
    "lat": "4.98236",
    "lng": "7.78922"
  },
  {
    "country": "NG",
    "name": "Abaji",
    "lat": "8.47372",
    "lng": "6.94453"
  },
  {
    "country": "NG",
    "name": "Abagana",
    "lat": "6.19031",
    "lng": "6.99357"
  },
  {
    "country": "NG",
    "name": "Aba",
    "lat": "5.10658",
    "lng": "7.36667"
  },
  {
    "country": "NG",
    "name": "Ajegunle",
    "lat": "6.45197",
    "lng": "3.33115"
  },
  {
    "country": "NG",
    "name": "Ojota",
    "lat": "6.57806",
    "lng": "3.38686"
  },
  {
    "country": "NG",
    "name": "Ifako",
    "lat": "6.64423",
    "lng": "3.32488"
  },
  {
    "country": "NG",
    "name": "Degema Hulk",
    "lat": "4.76145",
    "lng": "6.74957"
  },
  {
    "country": "NG",
    "name": "Yana",
    "lat": "11.40724",
    "lng": "10.01345"
  },
  {
    "country": "NG",
    "name": "Buni Yadi",
    "lat": "11.27441",
    "lng": "12.00852"
  },
  {
    "country": "NG",
    "name": "Obangede",
    "lat": "7.62066",
    "lng": "6.19928"
  },
  {
    "country": "NG",
    "name": "Naka",
    "lat": "7.58331",
    "lng": "8.2044"
  },
  {
    "country": "NG",
    "name": "Ezillo",
    "lat": "6.4293",
    "lng": "7.81787"
  },
  {
    "country": "NG",
    "name": "Koguna",
    "lat": "12.38137",
    "lng": "8.45733"
  },
  {
    "country": "NG",
    "name": "Nasko",
    "lat": "10.49539",
    "lng": "4.89904"
  },
  {
    "country": "NG",
    "name": "Oghara",
    "lat": "5.93554",
    "lng": "5.6661"
  },
  {
    "country": "NG",
    "name": "Abat",
    "lat": "4.61712",
    "lng": "7.86639"
  },
  {
    "country": "NG",
    "name": "Urua Inyang",
    "lat": "5.02309",
    "lng": "7.53895"
  },
  {
    "country": "NG",
    "name": "Ibiaku Ntok Okpo",
    "lat": "5.30857",
    "lng": "7.71106"
  },
  {
    "country": "NG",
    "name": "Irrua",
    "lat": "6.73634",
    "lng": "6.21984"
  },
  {
    "country": "NG",
    "name": "Igueben",
    "lat": "6.60183",
    "lng": "6.24276"
  },
  {
    "country": "NG",
    "name": "Umumma",
    "lat": "5.7569",
    "lng": "6.94613"
  },
  {
    "country": "NG",
    "name": "Akinima",
    "lat": "5.08536",
    "lng": "6.46633"
  },
  {
    "country": "NG",
    "name": "Umuguma",
    "lat": "5.46783",
    "lng": "6.96594"
  },
  {
    "country": "NG",
    "name": "Sabon Garin Nangere",
    "lat": "11.84945",
    "lng": "11.0733"
  },
  {
    "country": "NG",
    "name": "Aguobu-Owa",
    "lat": "6.37229",
    "lng": "7.27178"
  },
  {
    "country": "NG",
    "name": "Ugbodo",
    "lat": "6.51155",
    "lng": "8.12984"
  },
  {
    "country": "NG",
    "name": "Onueke",
    "lat": "6.15537",
    "lng": "8.03735"
  },
  {
    "country": "NG",
    "name": "Lessel",
    "lat": "7.12729",
    "lng": "9.01981"
  },
  {
    "country": "NG",
    "name": "Festac Town",
    "lat": "6.4697",
    "lng": "3.28299"
  },
  {
    "country": "NG",
    "name": "Atan",
    "lat": "6.89456",
    "lng": "4.00715"
  },
  {
    "country": "NG",
    "name": "Okuku",
    "lat": "8.01807",
    "lng": "4.67253"
  },
  {
    "country": "NG",
    "name": "Iyana-Ofa",
    "lat": "7.50043",
    "lng": "4.08104"
  },
  {
    "country": "NG",
    "name": "Mashegu",
    "lat": "9.97213",
    "lng": "5.77886"
  },
  {
    "country": "NG",
    "name": "Bangi",
    "lat": "10.83368",
    "lng": "5.82688"
  },
  {
    "country": "NG",
    "name": "Gawu Babangida",
    "lat": "9.27827",
    "lng": "6.99335"
  },
  {
    "country": "NG",
    "name": "Sabon Wuse",
    "lat": "9.33424",
    "lng": "7.26114"
  },
  {
    "country": "NG",
    "name": "Birnin Magaji",
    "lat": "12.5592",
    "lng": "6.89459"
  },
  {
    "country": "NG",
    "name": "Warawa",
    "lat": "11.86621",
    "lng": "8.70146"
  },
  {
    "country": "NG",
    "name": "Kaura",
    "lat": "9.66812",
    "lng": "8.45825"
  },
  {
    "country": "NG",
    "name": "Karu",
    "lat": "9.00943",
    "lng": "7.66147"
  },
  {
    "country": "NG",
    "name": "Akpafa",
    "lat": "7.47192",
    "lng": "6.14979"
  },
  {
    "country": "NG",
    "name": "Nkwo Nike",
    "lat": "6.50921",
    "lng": "7.51006"
  },
  {
    "country": "NG",
    "name": "Isiaka",
    "lat": "5.86265",
    "lng": "7.54622"
  },
  {
    "country": "NG",
    "name": "Obiozara",
    "lat": "6.04644",
    "lng": "7.77273"
  },
  {
    "country": "NG",
    "name": "Onuebonyi Echara",
    "lat": "6.0954",
    "lng": "8.15157"
  },
  {
    "country": "NG",
    "name": "Nwaorieubi",
    "lat": "5.58182",
    "lng": "7.01651"
  },
  {
    "country": "NG",
    "name": "Aboh",
    "lat": "5.47569",
    "lng": "7.27161"
  },
  {
    "country": "NG",
    "name": "Egbema",
    "lat": "5.54435",
    "lng": "6.7609"
  },
  {
    "country": "NG",
    "name": "Isinweke",
    "lat": "5.62048",
    "lng": "7.34985"
  },
  {
    "country": "NG",
    "name": "Nnenasa",
    "lat": "5.73262",
    "lng": "7.01364"
  },
  {
    "country": "NG",
    "name": "Oke-Ikpe",
    "lat": "4.91301",
    "lng": "7.31936"
  },
  {
    "country": "NG",
    "name": "Osisioma",
    "lat": "5.15979",
    "lng": "7.32235"
  },
  {
    "country": "NG",
    "name": "Omoba",
    "lat": "5.24268",
    "lng": "7.40623"
  },
  {
    "country": "NG",
    "name": "Okpuala-Ngwa",
    "lat": "5.3571",
    "lng": "7.38765"
  },
  {
    "country": "NG",
    "name": "Nkwoagu Isuochi",
    "lat": "5.99125",
    "lng": "7.39445"
  },
  {
    "country": "NG",
    "name": "Isiala Oboro",
    "lat": "5.40632",
    "lng": "7.56816"
  },
  {
    "country": "NG",
    "name": "Ogbia",
    "lat": "4.68836",
    "lng": "6.31525"
  },
  {
    "country": "NG",
    "name": "Upenekang",
    "lat": "4.57064",
    "lng": "7.97955"
  },
  {
    "country": "NG",
    "name": "Ikot Edibon",
    "lat": "4.77022",
    "lng": "7.931"
  },
  {
    "country": "NG",
    "name": "Ikot Akpa Nkuk",
    "lat": "4.87231",
    "lng": "7.56459"
  },
  {
    "country": "NG",
    "name": "Eyofin",
    "lat": "4.7516",
    "lng": "8.23056"
  },
  {
    "country": "NG",
    "name": "Urue Offong",
    "lat": "4.75275",
    "lng": "8.1677"
  },
  {
    "country": "NG",
    "name": "Mabudi",
    "lat": "8.73037",
    "lng": "9.78512"
  },
  {
    "country": "NG",
    "name": "Tunkus",
    "lat": "9.02167",
    "lng": "9.61384"
  },
  {
    "country": "NG",
    "name": "Baap",
    "lat": "8.94321",
    "lng": "9.24126"
  },
  {
    "country": "NG",
    "name": "Kwal",
    "lat": "9.37128",
    "lng": "9.6192"
  },
  {
    "country": "NG",
    "name": "Boh",
    "lat": "9.78187",
    "lng": "11.27882"
  },
  {
    "country": "NG",
    "name": "Kanamma",
    "lat": "13.09969",
    "lng": "12.1079"
  },
  {
    "country": "NG",
    "name": "Khaddamari",
    "lat": "11.92589",
    "lng": "13.23062"
  },
  {
    "country": "NG",
    "name": "Sunkani",
    "lat": "8.70298",
    "lng": "11.25757"
  },
  {
    "country": "NG",
    "name": "Saakpenwa",
    "lat": "4.71677",
    "lng": "7.263"
  },
  {
    "country": "NG",
    "name": "Nchia",
    "lat": "4.79309",
    "lng": "7.12061"
  },
  {
    "country": "NG",
    "name": "Rumuodomaya",
    "lat": "4.89333",
    "lng": "7.00228"
  },
  {
    "country": "NI",
    "name": "Yalagüina",
    "lat": "13.48383",
    "lng": "-86.49305"
  },
  {
    "country": "NI",
    "name": "Wiwilí",
    "lat": "13.62679",
    "lng": "-85.8254"
  },
  {
    "country": "NI",
    "name": "Waspán",
    "lat": "14.74189",
    "lng": "-83.9717"
  },
  {
    "country": "NI",
    "name": "Waslala",
    "lat": "13.23333",
    "lng": "-85.38333"
  },
  {
    "country": "NI",
    "name": "Villa Sandino",
    "lat": "12.0483",
    "lng": "-84.99362"
  },
  {
    "country": "NI",
    "name": "Villanueva",
    "lat": "12.96353",
    "lng": "-86.81517"
  },
  {
    "country": "NI",
    "name": "Valle San Francisco",
    "lat": "12.51667",
    "lng": "-86.28333"
  },
  {
    "country": "NI",
    "name": "LLano de La Cruz",
    "lat": "13.12449",
    "lng": "-86.00833"
  },
  {
    "country": "NI",
    "name": "Totogalpa",
    "lat": "13.56284",
    "lng": "-86.49254"
  },
  {
    "country": "NI",
    "name": "Tonalá",
    "lat": "12.7673",
    "lng": "-87.13323"
  },
  {
    "country": "NI",
    "name": "Tola",
    "lat": "11.43927",
    "lng": "-85.93891"
  },
  {
    "country": "NI",
    "name": "Tisma",
    "lat": "12.08194",
    "lng": "-86.01739"
  },
  {
    "country": "NI",
    "name": "Tipitapa",
    "lat": "12.19732",
    "lng": "-86.09706"
  },
  {
    "country": "NI",
    "name": "Ticuantepe",
    "lat": "12.02263",
    "lng": "-86.20493"
  },
  {
    "country": "NI",
    "name": "Teustepe",
    "lat": "12.4203",
    "lng": "-85.79798"
  },
  {
    "country": "NI",
    "name": "Terrabona",
    "lat": "12.73028",
    "lng": "-85.96474"
  },
  {
    "country": "NI",
    "name": "Telpaneca",
    "lat": "13.53151",
    "lng": "-86.2871"
  },
  {
    "country": "NI",
    "name": "Telica",
    "lat": "12.522",
    "lng": "-86.85938"
  },
  {
    "country": "NI",
    "name": "Somoto",
    "lat": "13.48082",
    "lng": "-86.58208"
  },
  {
    "country": "NI",
    "name": "Somotillo",
    "lat": "13.04387",
    "lng": "-86.90506"
  },
  {
    "country": "NI",
    "name": "Siuna",
    "lat": "13.73321",
    "lng": "-84.77725"
  },
  {
    "country": "NI",
    "name": "Sébaco",
    "lat": "12.85321",
    "lng": "-86.0963"
  },
  {
    "country": "NI",
    "name": "Santo Tomás del Norte",
    "lat": "13.1861",
    "lng": "-86.92267"
  },
  {
    "country": "NI",
    "name": "Santo Tomás",
    "lat": "12.06938",
    "lng": "-85.09059"
  },
  {
    "country": "NI",
    "name": "Santo Domingo",
    "lat": "12.26438",
    "lng": "-85.08235"
  },
  {
    "country": "NI",
    "name": "Santa Teresa",
    "lat": "11.80299",
    "lng": "-86.16312"
  },
  {
    "country": "NI",
    "name": "Santa Teresa",
    "lat": "11.74321",
    "lng": "-86.21413"
  },
  {
    "country": "NI",
    "name": "Santa Rosa del Peñón",
    "lat": "12.80116",
    "lng": "-86.36994"
  },
  {
    "country": "NI",
    "name": "Santa María",
    "lat": "13.74665",
    "lng": "-86.70934"
  },
  {
    "country": "NI",
    "name": "Santa Lucía",
    "lat": "12.53262",
    "lng": "-85.71074"
  },
  {
    "country": "NI",
    "name": "San Sebastián de Yalí",
    "lat": "13.3054",
    "lng": "-86.18641"
  },
  {
    "country": "NI",
    "name": "San Ramón",
    "lat": "12.92344",
    "lng": "-85.83898"
  },
  {
    "country": "NI",
    "name": "San Rafael del Sur",
    "lat": "11.84854",
    "lng": "-86.43839"
  },
  {
    "country": "NI",
    "name": "San Rafael del Norte",
    "lat": "13.21248",
    "lng": "-86.11089"
  },
  {
    "country": "NI",
    "name": "San Pedro de Lóvago",
    "lat": "12.12943",
    "lng": "-85.11523"
  },
  {
    "country": "NI",
    "name": "San Pedro del Norte",
    "lat": "13.27611",
    "lng": "-86.87782"
  },
  {
    "country": "NI",
    "name": "San Nicolás",
    "lat": "12.93236",
    "lng": "-86.34805"
  },
  {
    "country": "NI",
    "name": "San Miguelito",
    "lat": "11.40255",
    "lng": "-84.89991"
  },
  {
    "country": "NI",
    "name": "San Marcos",
    "lat": "11.90949",
    "lng": "-86.20351"
  },
  {
    "country": "NI",
    "name": "San Lucas",
    "lat": "13.4138",
    "lng": "-86.6111"
  },
  {
    "country": "NI",
    "name": "San Lorenzo",
    "lat": "12.3783",
    "lng": "-85.66646"
  },
  {
    "country": "NI",
    "name": "San Juan de Río Coco",
    "lat": "13.54476",
    "lng": "-86.16499"
  },
  {
    "country": "NI",
    "name": "San Juan de Oriente",
    "lat": "11.90624",
    "lng": "-86.07343"
  },
  {
    "country": "NI",
    "name": "San Juan del Sur",
    "lat": "11.25292",
    "lng": "-85.87049"
  },
  {
    "country": "NI",
    "name": "Greytown",
    "lat": "10.94684",
    "lng": "-83.73467"
  },
  {
    "country": "NI",
    "name": "San Juan de Limay",
    "lat": "13.17603",
    "lng": "-86.61234"
  },
  {
    "country": "NI",
    "name": "San José de los Remates",
    "lat": "12.5975",
    "lng": "-85.76174"
  },
  {
    "country": "NI",
    "name": "San José de Cusmapa",
    "lat": "13.28841",
    "lng": "-86.65539"
  },
  {
    "country": "NI",
    "name": "San José de Bocay",
    "lat": "13.54204",
    "lng": "-85.53942"
  },
  {
    "country": "NI",
    "name": "San Jorge",
    "lat": "11.45584",
    "lng": "-85.80308"
  },
  {
    "country": "NI",
    "name": "San Isidro",
    "lat": "12.92957",
    "lng": "-86.19521"
  },
  {
    "country": "NI",
    "name": "San Francisco Libre",
    "lat": "12.50497",
    "lng": "-86.29942"
  },
  {
    "country": "NI",
    "name": "San Francisco del Norte",
    "lat": "13.19921",
    "lng": "-86.77101"
  },
  {
    "country": "NI",
    "name": "San Fernando",
    "lat": "13.67755",
    "lng": "-86.31486"
  },
  {
    "country": "NI",
    "name": "San Dionisio",
    "lat": "12.76023",
    "lng": "-85.85018"
  },
  {
    "country": "NI",
    "name": "San Carlos",
    "lat": "11.1236",
    "lng": "-84.77795"
  },
  {
    "country": "NI",
    "name": "Rivas",
    "lat": "11.43716",
    "lng": "-85.82632"
  },
  {
    "country": "NI",
    "name": "Río Blanco",
    "lat": "12.93435",
    "lng": "-85.22354"
  },
  {
    "country": "NI",
    "name": "El Rama",
    "lat": "12.15965",
    "lng": "-84.21952"
  },
  {
    "country": "NI",
    "name": "Quilalí",
    "lat": "13.56695",
    "lng": "-86.026"
  },
  {
    "country": "NI",
    "name": "Quezalguaque",
    "lat": "12.50683",
    "lng": "-86.90292"
  },
  {
    "country": "NI",
    "name": "Puerto Morazán",
    "lat": "12.85042",
    "lng": "-87.17167"
  },
  {
    "country": "NI",
    "name": "Puerto Cabezas",
    "lat": "14.03507",
    "lng": "-83.38882"
  },
  {
    "country": "NI",
    "name": "Pueblo Nuevo",
    "lat": "13.37984",
    "lng": "-86.48075"
  },
  {
    "country": "NI",
    "name": "Prinzapolka",
    "lat": "13.40708",
    "lng": "-83.56452"
  },
  {
    "country": "NI",
    "name": "Potosí",
    "lat": "11.49416",
    "lng": "-85.8568"
  },
  {
    "country": "NI",
    "name": "Posoltega",
    "lat": "12.54422",
    "lng": "-86.97982"
  },
  {
    "country": "NI",
    "name": "El Cuá",
    "lat": "13.36844",
    "lng": "-85.67335"
  },
  {
    "country": "NI",
    "name": "Palacagüina",
    "lat": "13.45566",
    "lng": "-86.40622"
  },
  {
    "country": "NI",
    "name": "Ocotal",
    "lat": "13.63208",
    "lng": "-86.47516"
  },
  {
    "country": "NI",
    "name": "El Tortuguero",
    "lat": "12.82247",
    "lng": "-84.19629"
  },
  {
    "country": "NI",
    "name": "Nueva Guinea",
    "lat": "11.68758",
    "lng": "-84.45616"
  },
  {
    "country": "NI",
    "name": "Niquinohomo",
    "lat": "11.90518",
    "lng": "-86.09446"
  },
  {
    "country": "NI",
    "name": "Nindirí",
    "lat": "12.00386",
    "lng": "-86.12128"
  },
  {
    "country": "NI",
    "name": "Nandasmo",
    "lat": "11.92411",
    "lng": "-86.12072"
  },
  {
    "country": "NI",
    "name": "Nandaime",
    "lat": "11.75696",
    "lng": "-86.05286"
  },
  {
    "country": "NI",
    "name": "Nagarote",
    "lat": "12.26593",
    "lng": "-86.56474"
  },
  {
    "country": "NI",
    "name": "Muy Muy",
    "lat": "12.76224",
    "lng": "-85.62915"
  },
  {
    "country": "NI",
    "name": "Murra",
    "lat": "13.7585",
    "lng": "-86.01843"
  },
  {
    "country": "NI",
    "name": "Mulukukú",
    "lat": "13.17611",
    "lng": "-84.95522"
  },
  {
    "country": "NI",
    "name": "Muelle de los Bueyes",
    "lat": "12.06999",
    "lng": "-84.53503"
  },
  {
    "country": "NI",
    "name": "Mozonte",
    "lat": "13.66034",
    "lng": "-86.43841"
  },
  {
    "country": "NI",
    "name": "Moyogalpa",
    "lat": "11.54006",
    "lng": "-85.69795"
  },
  {
    "country": "NI",
    "name": "Morrito",
    "lat": "11.62118",
    "lng": "-85.08052"
  },
  {
    "country": "NI",
    "name": "Matiguás",
    "lat": "12.83734",
    "lng": "-85.46218"
  },
  {
    "country": "NI",
    "name": "Mateare",
    "lat": "12.23512",
    "lng": "-86.42809"
  },
  {
    "country": "NI",
    "name": "Matagalpa",
    "lat": "12.92559",
    "lng": "-85.91747"
  },
  {
    "country": "NI",
    "name": "Masaya",
    "lat": "11.97444",
    "lng": "-86.09417"
  },
  {
    "country": "NI",
    "name": "Masatepe",
    "lat": "11.91445",
    "lng": "-86.14458"
  },
  {
    "country": "NI",
    "name": "Masachapa",
    "lat": "11.78687",
    "lng": "-86.51416"
  },
  {
    "country": "NI",
    "name": "Managua",
    "lat": "12.13282",
    "lng": "-86.2504"
  },
  {
    "country": "NI",
    "name": "Malpaisillo",
    "lat": "12.59374",
    "lng": "-86.67952"
  },
  {
    "country": "NI",
    "name": "Macuelizo",
    "lat": "13.65328",
    "lng": "-86.61297"
  },
  {
    "country": "NI",
    "name": "León",
    "lat": "12.43787",
    "lng": "-86.87804"
  },
  {
    "country": "NI",
    "name": "La Trinidad",
    "lat": "12.96881",
    "lng": "-86.23534"
  },
  {
    "country": "NI",
    "name": "Las Sabanas",
    "lat": "13.34302",
    "lng": "-86.62184"
  },
  {
    "country": "NI",
    "name": "Larreynaga",
    "lat": "12.67692",
    "lng": "-86.57193"
  },
  {
    "country": "NI",
    "name": "La Paz de Carazo",
    "lat": "11.82311",
    "lng": "-86.12781"
  },
  {
    "country": "NI",
    "name": "La Paz Centro",
    "lat": "12.34",
    "lng": "-86.67528"
  },
  {
    "country": "NI",
    "name": "La Libertad",
    "lat": "12.21635",
    "lng": "-85.16595"
  },
  {
    "country": "NI",
    "name": "Laguna de Perlas",
    "lat": "12.34294",
    "lng": "-83.67123"
  },
  {
    "country": "NI",
    "name": "La Cruz de Río Grande",
    "lat": "13.1129",
    "lng": "-84.18588"
  },
  {
    "country": "NI",
    "name": "La Conquista",
    "lat": "11.73426",
    "lng": "-86.19279"
  },
  {
    "country": "NI",
    "name": "La Concordia",
    "lat": "13.19528",
    "lng": "-86.16659"
  },
  {
    "country": "NI",
    "name": "La Concepción",
    "lat": "11.93711",
    "lng": "-86.18976"
  },
  {
    "country": "NI",
    "name": "Kukrahill",
    "lat": "12.24096",
    "lng": "-83.74517"
  },
  {
    "country": "NI",
    "name": "Karawala",
    "lat": "12.93072",
    "lng": "-83.57724"
  },
  {
    "country": "NI",
    "name": "Juigalpa",
    "lat": "12.10629",
    "lng": "-85.36452"
  },
  {
    "country": "NI",
    "name": "Jiquilillo",
    "lat": "12.74593",
    "lng": "-87.4516"
  },
  {
    "country": "NI",
    "name": "Jinotepe",
    "lat": "11.84962",
    "lng": "-86.19903"
  },
  {
    "country": "NI",
    "name": "Jinotega",
    "lat": "13.09103",
    "lng": "-86.00234"
  },
  {
    "country": "NI",
    "name": "Jalapa",
    "lat": "13.92221",
    "lng": "-86.12346"
  },
  {
    "country": "NI",
    "name": "Granada",
    "lat": "11.92988",
    "lng": "-85.95602"
  },
  {
    "country": "NI",
    "name": "Estelí",
    "lat": "13.09185",
    "lng": "-86.35384"
  },
  {
    "country": "NI",
    "name": "Esquipulas",
    "lat": "12.66446",
    "lng": "-85.78734"
  },
  {
    "country": "NI",
    "name": "El Viejo",
    "lat": "12.66348",
    "lng": "-87.16663"
  },
  {
    "country": "NI",
    "name": "El Sauce",
    "lat": "12.88687",
    "lng": "-86.53903"
  },
  {
    "country": "NI",
    "name": "El Rosario",
    "lat": "11.8328",
    "lng": "-86.16526"
  },
  {
    "country": "NI",
    "name": "El Rosario",
    "lat": "11.77756",
    "lng": "-86.37374"
  },
  {
    "country": "NI",
    "name": "El Realejo",
    "lat": "12.54333",
    "lng": "-87.16517"
  },
  {
    "country": "NI",
    "name": "El Jicaral",
    "lat": "12.72676",
    "lng": "-86.38057"
  },
  {
    "country": "NI",
    "name": "El Crucero",
    "lat": "11.99008",
    "lng": "-86.30954"
  },
  {
    "country": "NI",
    "name": "El Ayote",
    "lat": "12.19046",
    "lng": "-85.28737"
  },
  {
    "country": "NI",
    "name": "El Almendro",
    "lat": "11.67859",
    "lng": "-84.70269"
  },
  {
    "country": "NI",
    "name": "Dolores",
    "lat": "11.85672",
    "lng": "-86.21552"
  },
  {
    "country": "NI",
    "name": "Diriomo",
    "lat": "11.87631",
    "lng": "-86.05184"
  },
  {
    "country": "NI",
    "name": "Diriamba",
    "lat": "11.85812",
    "lng": "-86.23922"
  },
  {
    "country": "NI",
    "name": "Diriá",
    "lat": "11.8842",
    "lng": "-86.05508"
  },
  {
    "country": "NI",
    "name": "Dipilto",
    "lat": "13.72106",
    "lng": "-86.50619"
  },
  {
    "country": "NI",
    "name": "Cuapa",
    "lat": "12.26875",
    "lng": "-85.38205"
  },
  {
    "country": "NI",
    "name": "Corn Island",
    "lat": "12.17575",
    "lng": "-83.06145"
  },
  {
    "country": "NI",
    "name": "Corinto",
    "lat": "12.4825",
    "lng": "-87.17304"
  },
  {
    "country": "NI",
    "name": "Condega",
    "lat": "13.36502",
    "lng": "-86.39846"
  },
  {
    "country": "NI",
    "name": "Comalapa",
    "lat": "12.28345",
    "lng": "-85.51081"
  },
  {
    "country": "NI",
    "name": "El Jícaro",
    "lat": "13.7229",
    "lng": "-86.13852"
  },
  {
    "country": "NI",
    "name": "Ciudad Darío",
    "lat": "12.73143",
    "lng": "-86.12402"
  },
  {
    "country": "NI",
    "name": "Ciudad Antigua",
    "lat": "13.6406",
    "lng": "-86.30815"
  },
  {
    "country": "NI",
    "name": "Cinco Pinos",
    "lat": "13.22956",
    "lng": "-86.86808"
  },
  {
    "country": "NI",
    "name": "Chinandega",
    "lat": "12.62937",
    "lng": "-87.13105"
  },
  {
    "country": "NI",
    "name": "Chichigalpa",
    "lat": "12.57758",
    "lng": "-87.02705"
  },
  {
    "country": "NI",
    "name": "Catarina",
    "lat": "11.91197",
    "lng": "-86.07383"
  },
  {
    "country": "NI",
    "name": "Villa El Carmen",
    "lat": "11.98009",
    "lng": "-86.50571"
  },
  {
    "country": "NI",
    "name": "Cárdenas",
    "lat": "11.19639",
    "lng": "-85.5089"
  },
  {
    "country": "NI",
    "name": "Camoapa",
    "lat": "12.38383",
    "lng": "-85.51277"
  },
  {
    "country": "NI",
    "name": "Buenos Aires",
    "lat": "11.46916",
    "lng": "-85.81661"
  },
  {
    "country": "NI",
    "name": "Bonanza",
    "lat": "14.02885",
    "lng": "-84.59103"
  },
  {
    "country": "NI",
    "name": "Bocana de Paiwas",
    "lat": "12.78571",
    "lng": "-85.12269"
  },
  {
    "country": "NI",
    "name": "Boca de Sábalos",
    "lat": "11.05",
    "lng": "-84.46667"
  },
  {
    "country": "NI",
    "name": "Boaco",
    "lat": "12.47224",
    "lng": "-85.6586"
  },
  {
    "country": "NI",
    "name": "Bluefields",
    "lat": "12.01366",
    "lng": "-83.76353"
  },
  {
    "country": "NI",
    "name": "Belén",
    "lat": "11.50299",
    "lng": "-85.88935"
  },
  {
    "country": "NI",
    "name": "Altagracia",
    "lat": "11.56615",
    "lng": "-85.5784"
  },
  {
    "country": "NI",
    "name": "Acoyapa",
    "lat": "11.97028",
    "lng": "-85.17113"
  },
  {
    "country": "NI",
    "name": "Achuapa",
    "lat": "13.0537",
    "lng": "-86.59004"
  },
  {
    "country": "NI",
    "name": "Ciudad Sandino",
    "lat": "12.15889",
    "lng": "-86.34417"
  },
  {
    "country": "NI",
    "name": "Santa Maía de Pantasma",
    "lat": "13.34809",
    "lng": "-85.94451"
  },
  {
    "country": "NI",
    "name": "Wiwilí de Jinotega",
    "lat": "13.61494",
    "lng": "-85.81676"
  },
  {
    "country": "NI",
    "name": "El Coral",
    "lat": "11.91781",
    "lng": "-84.64827"
  },
  {
    "country": "NI",
    "name": "Waslala",
    "lat": "13.33581",
    "lng": "-85.37054"
  },
  {
    "country": "NI",
    "name": "El Ayote",
    "lat": "12.49952",
    "lng": "-84.81519"
  },
  {
    "country": "NI",
    "name": "La Dalia",
    "lat": "13.13652",
    "lng": "-85.73738"
  },
  {
    "country": "NI",
    "name": "Rancho Grande",
    "lat": "13.23695",
    "lng": "-85.55817"
  },
  {
    "country": "NL",
    "name": "Zwolle",
    "lat": "52.5125",
    "lng": "6.09444"
  },
  {
    "country": "NL",
    "name": "Zwijndrecht",
    "lat": "51.8175",
    "lng": "4.63333"
  },
  {
    "country": "NL",
    "name": "Zwaanshoek",
    "lat": "52.3125",
    "lng": "4.61667"
  },
  {
    "country": "NL",
    "name": "De Westereen",
    "lat": "53.25731",
    "lng": "6.0363"
  },
  {
    "country": "NL",
    "name": "Zwaagdijk-Oost",
    "lat": "52.7075",
    "lng": "5.14028"
  },
  {
    "country": "NL",
    "name": "Zutphen",
    "lat": "52.13833",
    "lng": "6.20139"
  },
  {
    "country": "NL",
    "name": "Zundert",
    "lat": "51.47167",
    "lng": "4.65556"
  },
  {
    "country": "NL",
    "name": "Zuilichem",
    "lat": "51.80917",
    "lng": "5.13611"
  },
  {
    "country": "NL",
    "name": "Zuidwijk",
    "lat": "51.87532",
    "lng": "4.48514"
  },
  {
    "country": "NL",
    "name": "Zuid-Scharwoude",
    "lat": "52.68667",
    "lng": "4.80833"
  },
  {
    "country": "NL",
    "name": "Zuidlaren",
    "lat": "53.09417",
    "lng": "6.68194"
  },
  {
    "country": "NL",
    "name": "Zuidhorn",
    "lat": "53.24667",
    "lng": "6.40278"
  },
  {
    "country": "NL",
    "name": "Zuiderburen",
    "lat": "53.1734",
    "lng": "5.84271"
  },
  {
    "country": "NL",
    "name": "Zuidbroek",
    "lat": "53.16333",
    "lng": "6.86111"
  },
  {
    "country": "NL",
    "name": "Zuid-Beijerland",
    "lat": "51.75083",
    "lng": "4.36806"
  },
  {
    "country": "NL",
    "name": "Zoutkamp",
    "lat": "53.33917",
    "lng": "6.30417"
  },
  {
    "country": "NL",
    "name": "Zoutelande",
    "lat": "51.50167",
    "lng": "3.48472"
  },
  {
    "country": "NL",
    "name": "Zonnemaat",
    "lat": "51.93115",
    "lng": "6.06235"
  },
  {
    "country": "NL",
    "name": "Zonderwijk",
    "lat": "51.41141",
    "lng": "5.39361"
  },
  {
    "country": "NL",
    "name": "Zoeterwoude-Dorp",
    "lat": "52.12",
    "lng": "4.49583"
  },
  {
    "country": "NL",
    "name": "Zoetermeer",
    "lat": "52.0575",
    "lng": "4.49306"
  },
  {
    "country": "NL",
    "name": "Zoelen",
    "lat": "51.9125",
    "lng": "5.40278"
  },
  {
    "country": "NL",
    "name": "Zijtaart",
    "lat": "51.5925",
    "lng": "5.54167"
  },
  {
    "country": "NL",
    "name": "Zierikzee",
    "lat": "51.65",
    "lng": "3.91944"
  },
  {
    "country": "NL",
    "name": "Zevenhuizen",
    "lat": "52.21816",
    "lng": "5.97841"
  },
  {
    "country": "NL",
    "name": "Zevenhoven",
    "lat": "52.18167",
    "lng": "4.77917"
  },
  {
    "country": "NL",
    "name": "Zevenbergschen Hoek",
    "lat": "51.6725",
    "lng": "4.67917"
  },
  {
    "country": "NL",
    "name": "Zevenaar",
    "lat": "51.93",
    "lng": "6.07083"
  },
  {
    "country": "NL",
    "name": "Zetten",
    "lat": "51.92833",
    "lng": "5.71389"
  },
  {
    "country": "NL",
    "name": "Zesgehuchten",
    "lat": "51.41667",
    "lng": "5.55"
  },
  {
    "country": "NL",
    "name": "Zelhem",
    "lat": "52.00667",
    "lng": "6.34861"
  },
  {
    "country": "NL",
    "name": "Zeist",
    "lat": "52.09",
    "lng": "5.23333"
  },
  {
    "country": "NL",
    "name": "Zeilberg",
    "lat": "51.45469",
    "lng": "5.81878"
  },
  {
    "country": "NL",
    "name": "Zegge",
    "lat": "51.55667",
    "lng": "4.51806"
  },
  {
    "country": "NL",
    "name": "Zeewolde",
    "lat": "52.33",
    "lng": "5.54167"
  },
  {
    "country": "NL",
    "name": "Zeelst",
    "lat": "51.42421",
    "lng": "5.41566"
  },
  {
    "country": "NL",
    "name": "Zeeland",
    "lat": "51.6975",
    "lng": "5.67639"
  },
  {
    "country": "NL",
    "name": "Zeddam",
    "lat": "51.90333",
    "lng": "6.25972"
  },
  {
    "country": "NL",
    "name": "Zandvoort",
    "lat": "52.37125",
    "lng": "4.53306"
  },
  {
    "country": "NL",
    "name": "Zandberg",
    "lat": "51.57333",
    "lng": "4.78472"
  },
  {
    "country": "NL",
    "name": "Zaltbommel",
    "lat": "51.81",
    "lng": "5.24444"
  },
  {
    "country": "NL",
    "name": "Zaanstad",
    "lat": "52.45313",
    "lng": "4.81356"
  },
  {
    "country": "NL",
    "name": "Zaandijk",
    "lat": "52.47494",
    "lng": "4.80686"
  },
  {
    "country": "NL",
    "name": "Zaandam",
    "lat": "52.43854",
    "lng": "4.82643"
  },
  {
    "country": "NL",
    "name": "Zaamslag",
    "lat": "51.3125",
    "lng": "3.9125"
  },
  {
    "country": "NL",
    "name": "Yerseke",
    "lat": "51.4925",
    "lng": "4.05"
  },
  {
    "country": "NL",
    "name": "Wouw",
    "lat": "51.52167",
    "lng": "4.39028"
  },
  {
    "country": "NL",
    "name": "Woudsend",
    "lat": "52.94357",
    "lng": "5.62843"
  },
  {
    "country": "NL",
    "name": "Woudrichem",
    "lat": "51.815",
    "lng": "5.00139"
  },
  {
    "country": "NL",
    "name": "Woudenberg",
    "lat": "52.08083",
    "lng": "5.41667"
  },
  {
    "country": "NL",
    "name": "Woubrugge",
    "lat": "52.17",
    "lng": "4.63611"
  },
  {
    "country": "NL",
    "name": "Workum",
    "lat": "52.97969",
    "lng": "5.4471"
  },
  {
    "country": "NL",
    "name": "Wooldrik",
    "lat": "52.21667",
    "lng": "6.91667"
  },
  {
    "country": "NL",
    "name": "Woolde",
    "lat": "52.2721",
    "lng": "6.75891"
  },
  {
    "country": "NL",
    "name": "Wommels",
    "lat": "53.10883",
    "lng": "5.58749"
  },
  {
    "country": "NL",
    "name": "Wolvega",
    "lat": "52.87545",
    "lng": "5.99691"
  },
  {
    "country": "NL",
    "name": "Wolphaartsdijk",
    "lat": "51.53167",
    "lng": "3.81944"
  },
  {
    "country": "NL",
    "name": "Wolfsbos",
    "lat": "52.71734",
    "lng": "6.49881"
  },
  {
    "country": "NL",
    "name": "Wolfheze",
    "lat": "52.00333",
    "lng": "5.79028"
  },
  {
    "country": "NL",
    "name": "Wolder",
    "lat": "50.83752",
    "lng": "5.65938"
  },
  {
    "country": "NL",
    "name": "Woerden",
    "lat": "52.085",
    "lng": "4.88333"
  },
  {
    "country": "NL",
    "name": "Woenselse Heide",
    "lat": "51.48333",
    "lng": "5.46667"
  },
  {
    "country": "NL",
    "name": "Woensdrecht",
    "lat": "51.42897",
    "lng": "4.30355"
  },
  {
    "country": "NL",
    "name": "Witmarsum",
    "lat": "53.10452",
    "lng": "5.46902"
  },
  {
    "country": "NL",
    "name": "Wissenkerke",
    "lat": "51.585",
    "lng": "3.74722"
  },
  {
    "country": "NL",
    "name": "Wisch",
    "lat": "51.92648",
    "lng": "6.41705"
  },
  {
    "country": "NL",
    "name": "Wirdum",
    "lat": "53.14893",
    "lng": "5.80387"
  },
  {
    "country": "NL",
    "name": "Winterswijk",
    "lat": "51.9725",
    "lng": "6.71944"
  },
  {
    "country": "NL",
    "name": "Winsum",
    "lat": "53.33",
    "lng": "6.52083"
  },
  {
    "country": "NL",
    "name": "Winschoten",
    "lat": "53.14417",
    "lng": "7.03472"
  },
  {
    "country": "NL",
    "name": "Winkel",
    "lat": "52.75417",
    "lng": "4.90278"
  },
  {
    "country": "NL",
    "name": "Wilnis",
    "lat": "52.19667",
    "lng": "4.89722"
  },
  {
    "country": "NL",
    "name": "Wilhelminadorp",
    "lat": "51.49742",
    "lng": "5.39223"
  },
  {
    "country": "NL",
    "name": "Wildervank",
    "lat": "53.08083",
    "lng": "6.8625"
  },
  {
    "country": "NL",
    "name": "Wijnjewoude",
    "lat": "53.05814",
    "lng": "6.2047"
  },
  {
    "country": "NL",
    "name": "Wijnandsrade",
    "lat": "50.90583",
    "lng": "5.88333"
  },
  {
    "country": "NL",
    "name": "Wijlre",
    "lat": "50.83333",
    "lng": "5.89583"
  },
  {
    "country": "NL",
    "name": "Wijk bij Duurstede",
    "lat": "51.97417",
    "lng": "5.34167"
  },
  {
    "country": "NL",
    "name": "Wijk aan Zee",
    "lat": "52.4936",
    "lng": "4.59409"
  },
  {
    "country": "NL",
    "name": "Wijhe",
    "lat": "52.38667",
    "lng": "6.13472"
  },
  {
    "country": "NL",
    "name": "Wijdenes",
    "lat": "52.635",
    "lng": "5.15694"
  },
  {
    "country": "NL",
    "name": "Wijchen",
    "lat": "51.80917",
    "lng": "5.725"
  },
  {
    "country": "NL",
    "name": "Wijbosch",
    "lat": "51.61667",
    "lng": "5.46806"
  },
  {
    "country": "NL",
    "name": "Wieringerwerf",
    "lat": "52.85083",
    "lng": "5.02639"
  },
  {
    "country": "NL",
    "name": "Wieringerwaard",
    "lat": "52.83583",
    "lng": "4.86528"
  },
  {
    "country": "NL",
    "name": "Wierden",
    "lat": "52.35917",
    "lng": "6.59306"
  },
  {
    "country": "NL",
    "name": "Westwoud",
    "lat": "52.685",
    "lng": "5.13472"
  },
  {
    "country": "NL",
    "name": "West-Terschelling",
    "lat": "53.35911",
    "lng": "5.21482"
  },
  {
    "country": "NL",
    "name": "West-Souburg",
    "lat": "51.46417",
    "lng": "3.59167"
  },
  {
    "country": "NL",
    "name": "Westmaas",
    "lat": "51.78667",
    "lng": "4.475"
  },
  {
    "country": "NL",
    "name": "Westlaren",
    "lat": "53.0848",
    "lng": "6.66469"
  },
  {
    "country": "NL",
    "name": "Westkapelle",
    "lat": "51.52917",
    "lng": "3.44028"
  },
  {
    "country": "NL",
    "name": "Westerzicht",
    "lat": "51.46252",
    "lng": "3.58687"
  },
  {
    "country": "NL",
    "name": "Westervoort",
    "lat": "51.95583",
    "lng": "5.97222"
  },
  {
    "country": "NL",
    "name": "Westerlee",
    "lat": "53.14583",
    "lng": "6.9875"
  },
  {
    "country": "NL",
    "name": "Westerhoven",
    "lat": "51.3325",
    "lng": "5.39583"
  },
  {
    "country": "NL",
    "name": "Westerhaar-Vriezenveensewijk",
    "lat": "52.45583",
    "lng": "6.62361"
  },
  {
    "country": "NL",
    "name": "Westerbork",
    "lat": "52.85",
    "lng": "6.60833"
  },
  {
    "country": "NL",
    "name": "Westeneng",
    "lat": "52.1275",
    "lng": "5.71528"
  },
  {
    "country": "NL",
    "name": "Westeinde",
    "lat": "53.20853",
    "lng": "5.76812"
  },
  {
    "country": "NL",
    "name": "Westdorpe",
    "lat": "51.2325",
    "lng": "3.82639"
  },
  {
    "country": "NL",
    "name": "Wessem",
    "lat": "51.15954",
    "lng": "5.88146"
  },
  {
    "country": "NL",
    "name": "Wernhout",
    "lat": "51.455",
    "lng": "4.64167"
  },
  {
    "country": "NL",
    "name": "Werkhoven",
    "lat": "52.025",
    "lng": "5.24444"
  },
  {
    "country": "NL",
    "name": "Werkendam",
    "lat": "51.81",
    "lng": "4.89444"
  },
  {
    "country": "NL",
    "name": "Wemeldinge",
    "lat": "51.51833",
    "lng": "3.99722"
  },
  {
    "country": "NL",
    "name": "Wellerlooi",
    "lat": "51.53417",
    "lng": "6.13611"
  },
  {
    "country": "NL",
    "name": "Well",
    "lat": "51.55",
    "lng": "6.08889"
  },
  {
    "country": "NL",
    "name": "Welberg",
    "lat": "51.57667",
    "lng": "4.33056"
  },
  {
    "country": "NL",
    "name": "Wekerom",
    "lat": "52.1125",
    "lng": "5.71389"
  },
  {
    "country": "NL",
    "name": "Weiteveen",
    "lat": "52.6725",
    "lng": "6.9875"
  },
  {
    "country": "NL",
    "name": "Weijpoort",
    "lat": "52.08167",
    "lng": "4.80278"
  },
  {
    "country": "NL",
    "name": "Weesp",
    "lat": "52.3075",
    "lng": "5.04167"
  },
  {
    "country": "NL",
    "name": "Weert",
    "lat": "51.25167",
    "lng": "5.70694"
  },
  {
    "country": "NL",
    "name": "Weerestein",
    "lat": "52.30381",
    "lng": "4.58861"
  },
  {
    "country": "NL",
    "name": "Waubach",
    "lat": "50.91833",
    "lng": "6.05"
  },
  {
    "country": "NL",
    "name": "Waterakkers",
    "lat": "52.5044",
    "lng": "4.65608"
  },
  {
    "country": "NL",
    "name": "Wassenaar",
    "lat": "52.14583",
    "lng": "4.40278"
  },
  {
    "country": "NL",
    "name": "Waspik",
    "lat": "51.68667",
    "lng": "4.94444"
  },
  {
    "country": "NL",
    "name": "Warnsveld",
    "lat": "52.1375",
    "lng": "6.23056"
  },
  {
    "country": "NL",
    "name": "Warmond",
    "lat": "52.19667",
    "lng": "4.50278"
  },
  {
    "country": "NL",
    "name": "Wergea",
    "lat": "53.15145",
    "lng": "5.84404"
  },
  {
    "country": "NL",
    "name": "Warffum",
    "lat": "53.3925",
    "lng": "6.55833"
  },
  {
    "country": "NL",
    "name": "Wapenveld",
    "lat": "52.42917",
    "lng": "6.07361"
  },
  {
    "country": "NL",
    "name": "Wanssum",
    "lat": "51.53583",
    "lng": "6.07639"
  },
  {
    "country": "NL",
    "name": "Wanroij",
    "lat": "51.6575",
    "lng": "5.81806"
  },
  {
    "country": "NL",
    "name": "Wageningen",
    "lat": "51.97",
    "lng": "5.66667"
  },
  {
    "country": "NL",
    "name": "Wagenborgen",
    "lat": "53.25583",
    "lng": "6.93333"
  },
  {
    "country": "NL",
    "name": "Wagenberg",
    "lat": "51.665",
    "lng": "4.74861"
  },
  {
    "country": "NL",
    "name": "Waddinxveen",
    "lat": "52.045",
    "lng": "4.65139"
  },
  {
    "country": "NL",
    "name": "Waarland",
    "lat": "52.72667",
    "lng": "4.83194"
  },
  {
    "country": "NL",
    "name": "Waarder",
    "lat": "52.06083",
    "lng": "4.82083"
  },
  {
    "country": "NL",
    "name": "Waardenburg",
    "lat": "51.8325",
    "lng": "5.25694"
  },
  {
    "country": "NL",
    "name": "Waarde",
    "lat": "51.4175",
    "lng": "4.06806"
  },
  {
    "country": "NL",
    "name": "Waalwijk",
    "lat": "51.6825",
    "lng": "5.07083"
  },
  {
    "country": "NL",
    "name": "Waalre",
    "lat": "51.38667",
    "lng": "5.44444"
  },
  {
    "country": "NL",
    "name": "Vuren",
    "lat": "51.825",
    "lng": "5.04583"
  },
  {
    "country": "NL",
    "name": "Vught",
    "lat": "51.65333",
    "lng": "5.2875"
  },
  {
    "country": "NL",
    "name": "Vroomshoop",
    "lat": "52.46083",
    "lng": "6.56528"
  },
  {
    "country": "NL",
    "name": "Vriezenveen",
    "lat": "52.40833",
    "lng": "6.62222"
  },
  {
    "country": "NL",
    "name": "Vries",
    "lat": "53.07417",
    "lng": "6.57778"
  },
  {
    "country": "NL",
    "name": "Vrieheide",
    "lat": "50.92192",
    "lng": "5.96701"
  },
  {
    "country": "NL",
    "name": "Vreewijk",
    "lat": "51.88428",
    "lng": "4.51967"
  },
  {
    "country": "NL",
    "name": "Vreeswijk",
    "lat": "52.01088",
    "lng": "5.09285"
  },
  {
    "country": "NL",
    "name": "Vredenburg",
    "lat": "51.95355",
    "lng": "5.90284"
  },
  {
    "country": "NL",
    "name": "Vorstenbosch",
    "lat": "51.6525",
    "lng": "5.55"
  },
  {
    "country": "NL",
    "name": "Vorden",
    "lat": "52.105",
    "lng": "6.30972"
  },
  {
    "country": "NL",
    "name": "Voorthuizen",
    "lat": "52.18667",
    "lng": "5.60556"
  },
  {
    "country": "NL",
    "name": "Voorst",
    "lat": "52.17",
    "lng": "6.14167"
  },
  {
    "country": "NL",
    "name": "Voorschoten",
    "lat": "52.1275",
    "lng": "4.44861"
  },
  {
    "country": "NL",
    "name": "Voorhout",
    "lat": "52.22167",
    "lng": "4.48472"
  },
  {
    "country": "NL",
    "name": "Voorburg",
    "lat": "52.07417",
    "lng": "4.35972"
  },
  {
    "country": "NL",
    "name": "Vollenhove",
    "lat": "52.68083",
    "lng": "5.95417"
  },
  {
    "country": "NL",
    "name": "Volkel",
    "lat": "51.6425",
    "lng": "5.65417"
  },
  {
    "country": "NL",
    "name": "Volendam",
    "lat": "52.495",
    "lng": "5.07083"
  },
  {
    "country": "NL",
    "name": "Voldijn",
    "lat": "51.40052",
    "lng": "5.47196"
  },
  {
    "country": "NL",
    "name": "Vogelwijk",
    "lat": "52.07631",
    "lng": "4.2479"
  },
  {
    "country": "NL",
    "name": "Vogelenzang",
    "lat": "52.31917",
    "lng": "4.57778"
  },
  {
    "country": "NL",
    "name": "Voerendaal",
    "lat": "50.88327",
    "lng": "5.92978"
  },
  {
    "country": "NL",
    "name": "Vlokhoven",
    "lat": "51.46667",
    "lng": "5.48333"
  },
  {
    "country": "NL",
    "name": "Vlodrop",
    "lat": "51.13333",
    "lng": "6.07639"
  },
  {
    "country": "NL",
    "name": "Vlissingen",
    "lat": "51.4425",
    "lng": "3.57361"
  },
  {
    "country": "NL",
    "name": "Vlietwijk",
    "lat": "52.12436",
    "lng": "4.45736"
  },
  {
    "country": "NL",
    "name": "Vlierden",
    "lat": "51.445",
    "lng": "5.75833"
  },
  {
    "country": "NL",
    "name": "Vliedberg",
    "lat": "51.68961",
    "lng": "5.19031"
  },
  {
    "country": "NL",
    "name": "Vleuten",
    "lat": "52.10583",
    "lng": "5.01528"
  },
  {
    "country": "NL",
    "name": "Vledder",
    "lat": "52.85583",
    "lng": "6.20833"
  },
  {
    "country": "NL",
    "name": "Vlagtwedde",
    "lat": "53.0275",
    "lng": "7.10833"
  },
  {
    "country": "NL",
    "name": "Vlaardingen",
    "lat": "51.9125",
    "lng": "4.34167"
  },
  {
    "country": "NL",
    "name": "Vinkeveen",
    "lat": "52.21507",
    "lng": "4.93372"
  },
  {
    "country": "NL",
    "name": "Vijlen",
    "lat": "50.78833",
    "lng": "5.96528"
  },
  {
    "country": "NL",
    "name": "Vijfhuizen",
    "lat": "52.35083",
    "lng": "4.67778"
  },
  {
    "country": "NL",
    "name": "Vierpolders",
    "lat": "51.87917",
    "lng": "4.17917"
  },
  {
    "country": "NL",
    "name": "Vianen",
    "lat": "51.9925",
    "lng": "5.09167"
  },
  {
    "country": "NL",
    "name": "Venray",
    "lat": "51.525",
    "lng": "5.975"
  },
  {
    "country": "NL",
    "name": "Venlo",
    "lat": "51.37",
    "lng": "6.16806"
  },
  {
    "country": "NL",
    "name": "Venhorst",
    "lat": "51.60833",
    "lng": "5.7375"
  },
  {
    "country": "NL",
    "name": "Ven",
    "lat": "51.64",
    "lng": "5.55"
  },
  {
    "country": "NL",
    "name": "Veltum",
    "lat": "51.51954",
    "lng": "5.96032"
  },
  {
    "country": "NL",
    "name": "Velsen-Zuid",
    "lat": "52.46",
    "lng": "4.65"
  },
  {
    "country": "NL",
    "name": "Velp",
    "lat": "51.995",
    "lng": "5.97361"
  },
  {
    "country": "NL",
    "name": "Veldhuizen",
    "lat": "52.07537",
    "lng": "5.01234"
  },
  {
    "country": "NL",
    "name": "Veldhoven",
    "lat": "51.41833",
    "lng": "5.40278"
  },
  {
    "country": "NL",
    "name": "Veghel",
    "lat": "51.61667",
    "lng": "5.54861"
  },
  {
    "country": "NL",
    "name": "Feanwâlden",
    "lat": "53.23558",
    "lng": "5.98832"
  },
  {
    "country": "NL",
    "name": "Veenoord",
    "lat": "52.71087",
    "lng": "6.84869"
  },
  {
    "country": "NL",
    "name": "Veenendaal",
    "lat": "52.02863",
    "lng": "5.55891"
  },
  {
    "country": "NL",
    "name": "Veendam",
    "lat": "53.10667",
    "lng": "6.87917"
  },
  {
    "country": "NL",
    "name": "Veen",
    "lat": "51.7775",
    "lng": "5.10833"
  },
  {
    "country": "NL",
    "name": "Varsseveld",
    "lat": "51.94333",
    "lng": "6.45833"
  },
  {
    "country": "NL",
    "name": "Valthermond",
    "lat": "52.88167",
    "lng": "6.9625"
  },
  {
    "country": "NL",
    "name": "Valthe",
    "lat": "52.84583",
    "lng": "6.89444"
  },
  {
    "country": "NL",
    "name": "Valkenswaard",
    "lat": "51.35083",
    "lng": "5.45972"
  },
  {
    "country": "NL",
    "name": "Valkenburg",
    "lat": "52.18",
    "lng": "4.43194"
  },
  {
    "country": "NL",
    "name": "Valkenburg",
    "lat": "50.86523",
    "lng": "5.83205"
  },
  {
    "country": "NL",
    "name": "Valendries",
    "lat": "51.80658",
    "lng": "5.73445"
  },
  {
    "country": "NL",
    "name": "Valburg",
    "lat": "51.91167",
    "lng": "5.79028"
  },
  {
    "country": "NL",
    "name": "Vaassen",
    "lat": "52.28583",
    "lng": "5.96667"
  },
  {
    "country": "NL",
    "name": "Vaartbroek",
    "lat": "51.47954",
    "lng": "5.49806"
  },
  {
    "country": "NL",
    "name": "Vaals",
    "lat": "50.77083",
    "lng": "6.01806"
  },
  {
    "country": "NL",
    "name": "Utrecht",
    "lat": "52.09083",
    "lng": "5.12222"
  },
  {
    "country": "NL",
    "name": "Usquert",
    "lat": "53.4025",
    "lng": "6.61111"
  },
  {
    "country": "NL",
    "name": "Urmond",
    "lat": "50.99083",
    "lng": "5.77222"
  },
  {
    "country": "NL",
    "name": "Urk",
    "lat": "52.6625",
    "lng": "5.60139"
  },
  {
    "country": "NL",
    "name": "Ureterp",
    "lat": "53.09244",
    "lng": "6.16718"
  },
  {
    "country": "NL",
    "name": "Ulvenhout",
    "lat": "51.54907",
    "lng": "4.79931"
  },
  {
    "country": "NL",
    "name": "Ulrum",
    "lat": "53.35917",
    "lng": "6.33333"
  },
  {
    "country": "NL",
    "name": "Ulestraten",
    "lat": "50.90583",
    "lng": "5.78194"
  },
  {
    "country": "NL",
    "name": "Uithuizermeeden",
    "lat": "53.41417",
    "lng": "6.72361"
  },
  {
    "country": "NL",
    "name": "Uithuizen",
    "lat": "53.4075",
    "lng": "6.67083"
  },
  {
    "country": "NL",
    "name": "Uithoorn",
    "lat": "52.2375",
    "lng": "4.82639"
  },
  {
    "country": "NL",
    "name": "Uitgeest",
    "lat": "52.52917",
    "lng": "4.70972"
  },
  {
    "country": "NL",
    "name": "Ugchelen",
    "lat": "52.18464",
    "lng": "5.93177"
  },
  {
    "country": "NL",
    "name": "Uffelte",
    "lat": "52.79",
    "lng": "6.28056"
  },
  {
    "country": "NL",
    "name": "Udenhout",
    "lat": "51.60917",
    "lng": "5.14306"
  },
  {
    "country": "NL",
    "name": "Uden",
    "lat": "51.66083",
    "lng": "5.61944"
  },
  {
    "country": "NL",
    "name": "Uddel",
    "lat": "52.25917",
    "lng": "5.78056"
  },
  {
    "country": "NL",
    "name": "Ubachsberg",
    "lat": "50.85333",
    "lng": "5.94861"
  },
  {
    "country": "NL",
    "name": "Tzummarum",
    "lat": "53.23733",
    "lng": "5.54612"
  },
  {
    "country": "NL",
    "name": "'t Zand",
    "lat": "52.83667",
    "lng": "4.75556"
  },
  {
    "country": "NL",
    "name": "Tynaarlo",
    "lat": "53.0775",
    "lng": "6.61667"
  },
  {
    "country": "NL",
    "name": "Twisk",
    "lat": "52.74083",
    "lng": "5.05278"
  },
  {
    "country": "NL",
    "name": "Twijzelerheide",
    "lat": "53.24015",
    "lng": "6.04591"
  },
  {
    "country": "NL",
    "name": "Twijzel",
    "lat": "53.23152",
    "lng": "6.08952"
  },
  {
    "country": "NL",
    "name": "Twello",
    "lat": "52.23667",
    "lng": "6.10278"
  },
  {
    "country": "NL",
    "name": "Twekkelerveld",
    "lat": "52.23064",
    "lng": "6.86004"
  },
  {
    "country": "NL",
    "name": "Tweede Exloërmond",
    "lat": "52.90917",
    "lng": "6.93333"
  },
  {
    "country": "NL",
    "name": "Tuk",
    "lat": "52.79667",
    "lng": "6.09444"
  },
  {
    "country": "NL",
    "name": "Tuindorp",
    "lat": "51.93032",
    "lng": "4.3784"
  },
  {
    "country": "NL",
    "name": "Tuikwerd",
    "lat": "53.31667",
    "lng": "6.9"
  },
  {
    "country": "NL",
    "name": "Tubbergen",
    "lat": "52.4075",
    "lng": "6.78472"
  },
  {
    "country": "NL",
    "name": "Tricht",
    "lat": "51.89083",
    "lng": "5.26806"
  },
  {
    "country": "NL",
    "name": "Tongelre",
    "lat": "51.44889",
    "lng": "5.51978"
  },
  {
    "country": "NL",
    "name": "Tolkamer",
    "lat": "51.855",
    "lng": "6.10278"
  },
  {
    "country": "NL",
    "name": "Tivoli",
    "lat": "51.42069",
    "lng": "5.50818"
  },
  {
    "country": "NL",
    "name": "Tinga",
    "lat": "53.02064",
    "lng": "5.64575"
  },
  {
    "country": "NL",
    "name": "Tilburg",
    "lat": "51.55551",
    "lng": "5.0913"
  },
  {
    "country": "NL",
    "name": "Tijnje",
    "lat": "53.03058",
    "lng": "5.99193"
  },
  {
    "country": "NL",
    "name": "Tytsjerk",
    "lat": "53.21343",
    "lng": "5.90961"
  },
  {
    "country": "NL",
    "name": "Tienray",
    "lat": "51.495",
    "lng": "6.09306"
  },
  {
    "country": "NL",
    "name": "Tiel",
    "lat": "51.88667",
    "lng": "5.42917"
  },
  {
    "country": "NL",
    "name": "Thorn",
    "lat": "51.16167",
    "lng": "5.84167"
  },
  {
    "country": "NL",
    "name": "Tholen",
    "lat": "51.53167",
    "lng": "4.22083"
  },
  {
    "country": "NL",
    "name": "'t Hofke",
    "lat": "51.44943",
    "lng": "5.51926"
  },
  {
    "country": "NL",
    "name": "Theereheide",
    "lat": "51.63843",
    "lng": "5.33729"
  },
  {
    "country": "NL",
    "name": "Teteringen",
    "lat": "51.60917",
    "lng": "4.82083"
  },
  {
    "country": "NL",
    "name": "Terwolde",
    "lat": "52.28333",
    "lng": "6.1"
  },
  {
    "country": "NL",
    "name": "Terwinselen",
    "lat": "50.86659",
    "lng": "6.02471"
  },
  {
    "country": "NL",
    "name": "Terschuur",
    "lat": "52.165",
    "lng": "5.51667"
  },
  {
    "country": "NL",
    "name": "Terneuzen",
    "lat": "51.33583",
    "lng": "3.82778"
  },
  {
    "country": "NL",
    "name": "Ternaard",
    "lat": "53.38203",
    "lng": "5.96523"
  },
  {
    "country": "NL",
    "name": "Terheijden",
    "lat": "51.64333",
    "lng": "4.75417"
  },
  {
    "country": "NL",
    "name": "Terbregge",
    "lat": "51.95328",
    "lng": "4.51537"
  },
  {
    "country": "NL",
    "name": "Terborg",
    "lat": "51.92",
    "lng": "6.35417"
  },
  {
    "country": "NL",
    "name": "Ter Apel",
    "lat": "52.87667",
    "lng": "7.05972"
  },
  {
    "country": "NL",
    "name": "Ten Boer",
    "lat": "53.27583",
    "lng": "6.69444"
  },
  {
    "country": "NL",
    "name": "Tegelen",
    "lat": "51.34417",
    "lng": "6.13611"
  },
  {
    "country": "NL",
    "name": "Surhuisterveen",
    "lat": "53.18477",
    "lng": "6.17031"
  },
  {
    "country": "NL",
    "name": "Strijp",
    "lat": "52.03083",
    "lng": "4.30139"
  },
  {
    "country": "NL",
    "name": "Strijen",
    "lat": "51.74521",
    "lng": "4.55083"
  },
  {
    "country": "NL",
    "name": "Stramproy",
    "lat": "51.19417",
    "lng": "5.71944"
  },
  {
    "country": "NL",
    "name": "Stompetoren",
    "lat": "52.61333",
    "lng": "4.82083"
  },
  {
    "country": "NL",
    "name": "Stolwijk",
    "lat": "51.9725",
    "lng": "4.77361"
  },
  {
    "country": "NL",
    "name": "Stiens",
    "lat": "53.26234",
    "lng": "5.75769"
  },
  {
    "country": "NL",
    "name": "Stepekolk",
    "lat": "51.455",
    "lng": "5.61251"
  },
  {
    "country": "NL",
    "name": "Stein",
    "lat": "52.00333",
    "lng": "4.78194"
  },
  {
    "country": "NL",
    "name": "Stein",
    "lat": "50.96917",
    "lng": "5.76667"
  },
  {
    "country": "NL",
    "name": "Stegeslag",
    "lat": "51.94151",
    "lng": "6.06194"
  },
  {
    "country": "NL",
    "name": "Steenwijkerwold",
    "lat": "52.80417",
    "lng": "6.06389"
  },
  {
    "country": "NL",
    "name": "Steenwijk",
    "lat": "52.7875",
    "lng": "6.12083"
  },
  {
    "country": "NL",
    "name": "Steensel",
    "lat": "51.37667",
    "lng": "5.35278"
  },
  {
    "country": "NL",
    "name": "Steenderen",
    "lat": "52.06417",
    "lng": "6.1875"
  },
  {
    "country": "NL",
    "name": "Steenbergen",
    "lat": "51.58417",
    "lng": "4.31944"
  },
  {
    "country": "NL",
    "name": "Stavenisse",
    "lat": "51.5875",
    "lng": "4.0125"
  },
  {
    "country": "NL",
    "name": "Statenkwartier",
    "lat": "52.09311",
    "lng": "4.27577"
  },
  {
    "country": "NL",
    "name": "Staphorst",
    "lat": "52.645",
    "lng": "6.21111"
  },
  {
    "country": "NL",
    "name": "Standdaarbuiten",
    "lat": "51.61333",
    "lng": "4.51389"
  },
  {
    "country": "NL",
    "name": "Stampersgat",
    "lat": "51.61333",
    "lng": "4.44444"
  },
  {
    "country": "NL",
    "name": "Stadskanaal",
    "lat": "52.98947",
    "lng": "6.9504"
  },
  {
    "country": "NL",
    "name": "Stadsfenne",
    "lat": "53.03987",
    "lng": "5.67844"
  },
  {
    "country": "NL",
    "name": "Stadbroek",
    "lat": "51.00187",
    "lng": "5.87656"
  },
  {
    "country": "NL",
    "name": "Sprundel",
    "lat": "51.5375",
    "lng": "4.59722"
  },
  {
    "country": "NL",
    "name": "Spoorwijk",
    "lat": "52.05347",
    "lng": "4.31339"
  },
  {
    "country": "NL",
    "name": "Spijkenisse",
    "lat": "51.845",
    "lng": "4.32917"
  },
  {
    "country": "NL",
    "name": "Spijk",
    "lat": "53.39",
    "lng": "6.8375"
  },
  {
    "country": "NL",
    "name": "Spierdijk",
    "lat": "52.65083",
    "lng": "4.94306"
  },
  {
    "country": "NL",
    "name": "Spekholzerheide",
    "lat": "50.85559",
    "lng": "6.02471"
  },
  {
    "country": "NL",
    "name": "Spaubeek",
    "lat": "50.94",
    "lng": "5.84306"
  },
  {
    "country": "NL",
    "name": "Spangen",
    "lat": "51.91688",
    "lng": "4.43539"
  },
  {
    "country": "NL",
    "name": "Spakenburg",
    "lat": "52.25",
    "lng": "5.36667"
  },
  {
    "country": "NL",
    "name": "Son",
    "lat": "51.51136",
    "lng": "5.49282"
  },
  {
    "country": "NL",
    "name": "Someren-Eind",
    "lat": "51.3575",
    "lng": "5.73333"
  },
  {
    "country": "NL",
    "name": "Someren",
    "lat": "51.385",
    "lng": "5.71111"
  },
  {
    "country": "NL",
    "name": "Soestdijk",
    "lat": "52.19083",
    "lng": "5.28472"
  },
  {
    "country": "NL",
    "name": "Soest",
    "lat": "52.17333",
    "lng": "5.29167"
  },
  {
    "country": "NL",
    "name": "Soerendonk",
    "lat": "51.30083",
    "lng": "5.575"
  },
  {
    "country": "NL",
    "name": "Sneek",
    "lat": "53.03297",
    "lng": "5.6589"
  },
  {
    "country": "NL",
    "name": "Sluiskil",
    "lat": "51.27833",
    "lng": "3.83611"
  },
  {
    "country": "NL",
    "name": "Sluis",
    "lat": "51.30833",
    "lng": "3.38611"
  },
  {
    "country": "NL",
    "name": "Slootdorp",
    "lat": "52.8425",
    "lng": "4.97222"
  },
  {
    "country": "NL",
    "name": "Slochteren",
    "lat": "53.22078",
    "lng": "6.80547"
  },
  {
    "country": "NL",
    "name": "Slikkerveer",
    "lat": "51.88531",
    "lng": "4.60494"
  },
  {
    "country": "NL",
    "name": "Sliedrecht",
    "lat": "51.82083",
    "lng": "4.77639"
  },
  {
    "country": "NL",
    "name": "Sleen",
    "lat": "52.77167",
    "lng": "6.80278"
  },
  {
    "country": "NL",
    "name": "Sittard",
    "lat": "50.99833",
    "lng": "5.86944"
  },
  {
    "country": "NL",
    "name": "Sint Willebrord",
    "lat": "51.54833",
    "lng": "4.58889"
  },
  {
    "country": "NL",
    "name": "Sint Philipsland",
    "lat": "51.61667",
    "lng": "4.16528"
  },
  {
    "country": "NL",
    "name": "Sint Pancras",
    "lat": "52.66",
    "lng": "4.78333"
  },
  {
    "country": "NL",
    "name": "Sint-Oedenrode",
    "lat": "51.5675",
    "lng": "5.45972"
  },
  {
    "country": "NL",
    "name": "Sint Odiliënberg",
    "lat": "51.14333",
    "lng": "6"
  },
  {
    "country": "NL",
    "name": "Sint Nicolaasga",
    "lat": "52.92293",
    "lng": "5.74242"
  },
  {
    "country": "NL",
    "name": "Sint-Michielsgestel",
    "lat": "51.64167",
    "lng": "5.35278"
  },
  {
    "country": "NL",
    "name": "Sint Laurens",
    "lat": "51.5275",
    "lng": "3.60278"
  },
  {
    "country": "NL",
    "name": "Sint Joost",
    "lat": "51.1175",
    "lng": "5.89861"
  },
  {
    "country": "NL",
    "name": "Sintjohannesga",
    "lat": "52.93157",
    "lng": "5.85588"
  },
  {
    "country": "NL",
    "name": "Sint Jansklooster",
    "lat": "52.6775",
    "lng": "6.00556"
  },
  {
    "country": "NL",
    "name": "Sint Jacobiparochie",
    "lat": "53.27291",
    "lng": "5.60354"
  },
  {
    "country": "NL",
    "name": "Sint Anthonis",
    "lat": "51.62667",
    "lng": "5.88194"
  },
  {
    "country": "NL",
    "name": "Sint Annaparochie",
    "lat": "53.2762",
    "lng": "5.65727"
  },
  {
    "country": "NL",
    "name": "Simpelveld",
    "lat": "50.83417",
    "lng": "5.98194"
  },
  {
    "country": "NL",
    "name": "Silvolde",
    "lat": "51.90917",
    "lng": "6.3875"
  },
  {
    "country": "NL",
    "name": "Siddeburen",
    "lat": "53.25",
    "lng": "6.86806"
  },
  {
    "country": "NL",
    "name": "Sibbe",
    "lat": "50.84417",
    "lng": "5.82639"
  },
  {
    "country": "NL",
    "name": "'s-Hertogenbosch",
    "lat": "51.69917",
    "lng": "5.30417"
  },
  {
    "country": "NL",
    "name": "'s-Heerenberg",
    "lat": "51.8767",
    "lng": "6.25877"
  },
  {
    "country": "NL",
    "name": "'s-Gravenzande",
    "lat": "52.00167",
    "lng": "4.16528"
  },
  {
    "country": "NL",
    "name": "'s Gravenmoer",
    "lat": "51.65594",
    "lng": "4.94076"
  },
  {
    "country": "NL",
    "name": "The Hague",
    "lat": "52.07667",
    "lng": "4.29861"
  },
  {
    "country": "NL",
    "name": "Sexbierum",
    "lat": "53.21823",
    "lng": "5.48402"
  },
  {
    "country": "NL",
    "name": "Sevenum",
    "lat": "51.4125",
    "lng": "6.0375"
  },
  {
    "country": "NL",
    "name": "Serooskerke",
    "lat": "51.54833",
    "lng": "3.59444"
  },
  {
    "country": "NL",
    "name": "Selwerd",
    "lat": "53.2352",
    "lng": "6.5545"
  },
  {
    "country": "NL",
    "name": "Sellingen",
    "lat": "52.94583",
    "lng": "7.15139"
  },
  {
    "country": "NL",
    "name": "Schutsboom",
    "lat": "51.46152",
    "lng": "5.6226"
  },
  {
    "country": "NL",
    "name": "Schoonrewoerd",
    "lat": "51.92083",
    "lng": "5.11667"
  },
  {
    "country": "NL",
    "name": "Schoonoord",
    "lat": "52.84583",
    "lng": "6.75556"
  },
  {
    "country": "NL",
    "name": "Schoonhoven",
    "lat": "51.9475",
    "lng": "4.84861"
  },
  {
    "country": "NL",
    "name": "Schoonebeek",
    "lat": "52.6625",
    "lng": "6.88472"
  },
  {
    "country": "NL",
    "name": "Schoondijke",
    "lat": "51.35417",
    "lng": "3.55556"
  },
  {
    "country": "NL",
    "name": "Schipluiden",
    "lat": "51.97583",
    "lng": "4.31389"
  },
  {
    "country": "NL",
    "name": "Schinveld",
    "lat": "50.96917",
    "lng": "5.97917"
  },
  {
    "country": "NL",
    "name": "Schinnen",
    "lat": "50.94333",
    "lng": "5.88889"
  },
  {
    "country": "NL",
    "name": "Schimmert",
    "lat": "50.90667",
    "lng": "5.82361"
  },
  {
    "country": "NL",
    "name": "Schildwolde",
    "lat": "53.23327",
    "lng": "6.81566"
  },
  {
    "country": "NL",
    "name": "Schilberg",
    "lat": "51.09917",
    "lng": "5.88611"
  },
  {
    "country": "NL",
    "name": "Schijndel",
    "lat": "51.6225",
    "lng": "5.43194"
  },
  {
    "country": "NL",
    "name": "Schiermonnikoog",
    "lat": "53.48025",
    "lng": "6.15209"
  },
  {
    "country": "NL",
    "name": "Schiedam",
    "lat": "51.91917",
    "lng": "4.38889"
  },
  {
    "country": "NL",
    "name": "Schiebroek",
    "lat": "51.95838",
    "lng": "4.47124"
  },
  {
    "country": "NL",
    "name": "Scheveningen",
    "lat": "52.10461",
    "lng": "4.27557"
  },
  {
    "country": "NL",
    "name": "Scherpenzeel",
    "lat": "52.08",
    "lng": "5.48889"
  },
  {
    "country": "NL",
    "name": "Scherpenisse",
    "lat": "51.54667",
    "lng": "4.10556"
  },
  {
    "country": "NL",
    "name": "Schermerhorn",
    "lat": "52.60083",
    "lng": "4.89167"
  },
  {
    "country": "NL",
    "name": "Schelluinen",
    "lat": "51.84333",
    "lng": "4.92639"
  },
  {
    "country": "NL",
    "name": "Scheemda",
    "lat": "53.17333",
    "lng": "6.97222"
  },
  {
    "country": "NL",
    "name": "Scharnegoutum",
    "lat": "53.06051",
    "lng": "5.67822"
  },
  {
    "country": "NL",
    "name": "Scharn",
    "lat": "50.85",
    "lng": "5.73333"
  },
  {
    "country": "NL",
    "name": "Scharendijke",
    "lat": "51.73583",
    "lng": "3.84306"
  },
  {
    "country": "NL",
    "name": "Schalkhaar",
    "lat": "52.26833",
    "lng": "6.19444"
  },
  {
    "country": "NL",
    "name": "Schaijk",
    "lat": "51.74583",
    "lng": "5.63194"
  },
  {
    "country": "NL",
    "name": "Schagerbrug",
    "lat": "52.8025",
    "lng": "4.75833"
  },
  {
    "country": "NL",
    "name": "Schagen",
    "lat": "52.7875",
    "lng": "4.79861"
  },
  {
    "country": "NL",
    "name": "Sas van Gent",
    "lat": "51.2275",
    "lng": "3.79861"
  },
  {
    "country": "NL",
    "name": "Sassenheim",
    "lat": "52.225",
    "lng": "4.52222"
  },
  {
    "country": "NL",
    "name": "Sappemeer",
    "lat": "53.16417",
    "lng": "6.79028"
  },
  {
    "country": "NL",
    "name": "Ruurlo",
    "lat": "52.08833",
    "lng": "6.45"
  },
  {
    "country": "NL",
    "name": "Ruinerwold",
    "lat": "52.72333",
    "lng": "6.24861"
  },
  {
    "country": "NL",
    "name": "Ruinen",
    "lat": "52.7625",
    "lng": "6.35417"
  },
  {
    "country": "NL",
    "name": "Rugge",
    "lat": "51.89921",
    "lng": "4.15231"
  },
  {
    "country": "NL",
    "name": "Rucphen",
    "lat": "51.53167",
    "lng": "4.55833"
  },
  {
    "country": "NL",
    "name": "Rozendaal",
    "lat": "52.00583",
    "lng": "5.9625"
  },
  {
    "country": "NL",
    "name": "Rozenburg",
    "lat": "51.90417",
    "lng": "4.24861"
  },
  {
    "country": "NL",
    "name": "Rottevalle",
    "lat": "53.14523",
    "lng": "6.10411"
  },
  {
    "country": "NL",
    "name": "Rotterdam",
    "lat": "51.9225",
    "lng": "4.47917"
  },
  {
    "country": "NL",
    "name": "Rothem",
    "lat": "50.87667",
    "lng": "5.73889"
  },
  {
    "country": "NL",
    "name": "Rossum",
    "lat": "52.35167",
    "lng": "6.92222"
  },
  {
    "country": "NL",
    "name": "Rossum",
    "lat": "51.80083",
    "lng": "5.33333"
  },
  {
    "country": "NL",
    "name": "Roosteren",
    "lat": "51.08333",
    "lng": "5.81806"
  },
  {
    "country": "NL",
    "name": "Roosendaal",
    "lat": "51.53083",
    "lng": "4.46528"
  },
  {
    "country": "NL",
    "name": "Rolde",
    "lat": "52.98417",
    "lng": "6.64861"
  },
  {
    "country": "NL",
    "name": "Roermond",
    "lat": "51.19417",
    "lng": "5.9875"
  },
  {
    "country": "NL",
    "name": "Roelofarendsveen",
    "lat": "52.20333",
    "lng": "4.63333"
  },
  {
    "country": "NL",
    "name": "Roden",
    "lat": "53.1375",
    "lng": "6.42083"
  },
  {
    "country": "NL",
    "name": "Rockanje",
    "lat": "51.87167",
    "lng": "4.07083"
  },
  {
    "country": "NL",
    "name": "Rijswijk",
    "lat": "52.03634",
    "lng": "4.32501"
  },
  {
    "country": "NL",
    "name": "Rijswijk",
    "lat": "51.7975",
    "lng": "5.025"
  },
  {
    "country": "NL",
    "name": "Rijsoord",
    "lat": "51.85083",
    "lng": "4.59583"
  },
  {
    "country": "NL",
    "name": "Rijsbergen",
    "lat": "51.5175",
    "lng": "4.69722"
  },
  {
    "country": "NL",
    "name": "Rijpwetering",
    "lat": "52.1925",
    "lng": "4.58333"
  },
  {
    "country": "NL",
    "name": "Rijnsburg",
    "lat": "52.19",
    "lng": "4.44167"
  },
  {
    "country": "NL",
    "name": "Rijnsaterwoude",
    "lat": "52.19583",
    "lng": "4.67083"
  },
  {
    "country": "NL",
    "name": "Rijen",
    "lat": "51.59083",
    "lng": "4.91944"
  },
  {
    "country": "NL",
    "name": "Riethoven",
    "lat": "51.35417",
    "lng": "5.3875"
  },
  {
    "country": "NL",
    "name": "Ridderkerk",
    "lat": "51.8725",
    "lng": "4.60278"
  },
  {
    "country": "NL",
    "name": "Rhoon",
    "lat": "51.8575",
    "lng": "4.42222"
  },
  {
    "country": "NL",
    "name": "Rhenen",
    "lat": "51.95917",
    "lng": "5.56806"
  },
  {
    "country": "NL",
    "name": "Rheden",
    "lat": "52.005",
    "lng": "6.02917"
  },
  {
    "country": "NL",
    "name": "Reuver",
    "lat": "51.28417",
    "lng": "6.07778"
  },
  {
    "country": "NL",
    "name": "Reusel",
    "lat": "51.3625",
    "lng": "5.16528"
  },
  {
    "country": "NL",
    "name": "Renswoude",
    "lat": "52.07333",
    "lng": "5.54028"
  },
  {
    "country": "NL",
    "name": "Renkum",
    "lat": "51.97667",
    "lng": "5.73333"
  },
  {
    "country": "NL",
    "name": "Renesse",
    "lat": "51.7325",
    "lng": "3.775"
  },
  {
    "country": "NL",
    "name": "Reeuwijk",
    "lat": "52.04667",
    "lng": "4.725"
  },
  {
    "country": "NL",
    "name": "Reek",
    "lat": "51.74583",
    "lng": "5.68194"
  },
  {
    "country": "NL",
    "name": "Ravenstein",
    "lat": "51.79667",
    "lng": "5.65"
  },
  {
    "country": "NL",
    "name": "Raamsdonksveer",
    "lat": "51.69667",
    "lng": "4.87361"
  },
  {
    "country": "NL",
    "name": "Raamsdonk",
    "lat": "51.6875",
    "lng": "4.90833"
  },
  {
    "country": "NL",
    "name": "Raam",
    "lat": "51.65967",
    "lng": "5.63637"
  },
  {
    "country": "NL",
    "name": "Raalte",
    "lat": "52.38583",
    "lng": "6.275"
  },
  {
    "country": "NL",
    "name": "Quirijnstok",
    "lat": "51.5843",
    "lng": "5.0981"
  },
  {
    "country": "NL",
    "name": "Putten",
    "lat": "52.25917",
    "lng": "5.60694"
  },
  {
    "country": "NL",
    "name": "Putte",
    "lat": "51.36",
    "lng": "4.39583"
  },
  {
    "country": "NL",
    "name": "Puth",
    "lat": "50.95417",
    "lng": "5.87361"
  },
  {
    "country": "NL",
    "name": "Purmerend",
    "lat": "52.505",
    "lng": "4.95972"
  },
  {
    "country": "NL",
    "name": "Puiflijk",
    "lat": "51.87833",
    "lng": "5.59028"
  },
  {
    "country": "NL",
    "name": "Prinsenbeek",
    "lat": "51.59833",
    "lng": "4.7125"
  },
  {
    "country": "NL",
    "name": "Princenhage",
    "lat": "51.57632",
    "lng": "4.73906"
  },
  {
    "country": "NL",
    "name": "Pottenberg",
    "lat": "50.85135",
    "lng": "5.65668"
  },
  {
    "country": "NL",
    "name": "Posterholt",
    "lat": "51.12333",
    "lng": "6.03472"
  },
  {
    "country": "NL",
    "name": "Poortvliet",
    "lat": "51.54417",
    "lng": "4.14306"
  },
  {
    "country": "NL",
    "name": "Poeldijk",
    "lat": "52.02417",
    "lng": "4.21944"
  },
  {
    "country": "NL",
    "name": "Pijnacker",
    "lat": "52.01954",
    "lng": "4.42946"
  },
  {
    "country": "NL",
    "name": "Piershil",
    "lat": "51.79333",
    "lng": "4.31389"
  },
  {
    "country": "NL",
    "name": "Pierik",
    "lat": "52.50141",
    "lng": "6.1117"
  },
  {
    "country": "NL",
    "name": "Petten",
    "lat": "52.76667",
    "lng": "4.66111"
  },
  {
    "country": "NL",
    "name": "Pernis",
    "lat": "51.88833",
    "lng": "4.38889"
  },
  {
    "country": "NL",
    "name": "Pendrecht",
    "lat": "51.87152",
    "lng": "4.46901"
  },
  {
    "country": "NL",
    "name": "Peize",
    "lat": "53.14667",
    "lng": "6.49722"
  },
  {
    "country": "NL",
    "name": "Peij",
    "lat": "51.09417",
    "lng": "5.89583"
  },
  {
    "country": "NL",
    "name": "Peelo",
    "lat": "53.01719",
    "lng": "6.56208"
  },
  {
    "country": "NL",
    "name": "Pathmos",
    "lat": "52.21397",
    "lng": "6.87555"
  },
  {
    "country": "NL",
    "name": "Paterswolde",
    "lat": "53.145",
    "lng": "6.56528"
  },
  {
    "country": "NL",
    "name": "Passart",
    "lat": "50.92389",
    "lng": "5.94674"
  },
  {
    "country": "NL",
    "name": "Papenveer",
    "lat": "52.185",
    "lng": "4.725"
  },
  {
    "country": "NL",
    "name": "Papendrecht",
    "lat": "51.83167",
    "lng": "4.6875"
  },
  {
    "country": "NL",
    "name": "Panningen",
    "lat": "51.32667",
    "lng": "5.97917"
  },
  {
    "country": "NL",
    "name": "Pannerden",
    "lat": "51.89083",
    "lng": "6.03889"
  },
  {
    "country": "NL",
    "name": "Palenstein",
    "lat": "52.05579",
    "lng": "4.50869"
  },
  {
    "country": "NL",
    "name": "Overveen",
    "lat": "52.39167",
    "lng": "4.61389"
  },
  {
    "country": "NL",
    "name": "Overschie",
    "lat": "51.93863",
    "lng": "4.42766"
  },
  {
    "country": "NL",
    "name": "Overloon",
    "lat": "51.57167",
    "lng": "5.94722"
  },
  {
    "country": "NL",
    "name": "Overhoven",
    "lat": "51.00869",
    "lng": "5.86628"
  },
  {
    "country": "NL",
    "name": "Overberg",
    "lat": "52.04",
    "lng": "5.49444"
  },
  {
    "country": "NL",
    "name": "Overasselt",
    "lat": "51.76",
    "lng": "5.78889"
  },
  {
    "country": "NL",
    "name": "Oud-Vossemeer",
    "lat": "51.57083",
    "lng": "4.19861"
  },
  {
    "country": "NL",
    "name": "Oud-Loosdrecht",
    "lat": "52.20667",
    "lng": "5.08056"
  },
  {
    "country": "NL",
    "name": "Oudkarspel",
    "lat": "52.71583",
    "lng": "4.80556"
  },
  {
    "country": "NL",
    "name": "Oud Gastel",
    "lat": "51.58667",
    "lng": "4.45972"
  },
  {
    "country": "NL",
    "name": "Oude Wetering",
    "lat": "52.21417",
    "lng": "4.64444"
  },
  {
    "country": "NL",
    "name": "Oudewater",
    "lat": "52.025",
    "lng": "4.86806"
  },
  {
    "country": "NL",
    "name": "Oudeschoot",
    "lat": "52.93343",
    "lng": "5.95579"
  },
  {
    "country": "NL",
    "name": "Oudeschild",
    "lat": "53.03917",
    "lng": "4.84722"
  },
  {
    "country": "NL",
    "name": "Ouderkerk aan den IJssel",
    "lat": "51.93417",
    "lng": "4.63611"
  },
  {
    "country": "NL",
    "name": "Ouderkerk aan de Amstel",
    "lat": "52.29504",
    "lng": "4.90746"
  },
  {
    "country": "NL",
    "name": "Oude Pekela",
    "lat": "53.10417",
    "lng": "7.00972"
  },
  {
    "country": "NL",
    "name": "Oudemirdum",
    "lat": "52.85019",
    "lng": "5.53544"
  },
  {
    "country": "NL",
    "name": "Oudehaske",
    "lat": "52.95709",
    "lng": "5.87095"
  },
  {
    "country": "NL",
    "name": "Oudega",
    "lat": "53.12504",
    "lng": "5.99888"
  },
  {
    "country": "NL",
    "name": "Ouddorp",
    "lat": "51.81167",
    "lng": "3.93472"
  },
  {
    "country": "NL",
    "name": "Oud-Caberg",
    "lat": "50.86539",
    "lng": "5.66444"
  },
  {
    "country": "NL",
    "name": "Oud-Beijerland",
    "lat": "51.82417",
    "lng": "4.4125"
  },
  {
    "country": "NL",
    "name": "Ottersum",
    "lat": "51.70333",
    "lng": "5.98333"
  },
  {
    "country": "NL",
    "name": "Otterlo",
    "lat": "52.1",
    "lng": "5.77222"
  },
  {
    "country": "NL",
    "name": "Othene",
    "lat": "51.33083",
    "lng": "3.85972"
  },
  {
    "country": "NL",
    "name": "Ossendrecht",
    "lat": "51.39417",
    "lng": "4.32639"
  },
  {
    "country": "NL",
    "name": "Oss",
    "lat": "51.765",
    "lng": "5.51806"
  },
  {
    "country": "NL",
    "name": "Ospel",
    "lat": "51.2975",
    "lng": "5.78472"
  },
  {
    "country": "NL",
    "name": "Orthen",
    "lat": "51.70613",
    "lng": "5.30468"
  },
  {
    "country": "NL",
    "name": "Orden",
    "lat": "52.20113",
    "lng": "5.93417"
  },
  {
    "country": "NL",
    "name": "Oranjewoud",
    "lat": "52.94579",
    "lng": "5.95038"
  },
  {
    "country": "NL",
    "name": "Opperdoes",
    "lat": "52.75915",
    "lng": "5.07534"
  },
  {
    "country": "NL",
    "name": "Oppenhuizen",
    "lat": "53.01194",
    "lng": "5.69495"
  },
  {
    "country": "NL",
    "name": "Opmeer",
    "lat": "52.70667",
    "lng": "4.94444"
  },
  {
    "country": "NL",
    "name": "Opijnen",
    "lat": "51.82917",
    "lng": "5.29861"
  },
  {
    "country": "NL",
    "name": "Ophoven",
    "lat": "50.99036",
    "lng": "5.85868"
  },
  {
    "country": "NL",
    "name": "Opheusden",
    "lat": "51.93167",
    "lng": "5.63194"
  },
  {
    "country": "NL",
    "name": "Ophemert",
    "lat": "51.845",
    "lng": "5.3875"
  },
  {
    "country": "NL",
    "name": "Opeinde",
    "lat": "53.1341",
    "lng": "6.05656"
  },
  {
    "country": "NL",
    "name": "Ooyerhoek",
    "lat": "52.12838",
    "lng": "6.22307"
  },
  {
    "country": "NL",
    "name": "Ootmarsum",
    "lat": "52.40833",
    "lng": "6.90139"
  },
  {
    "country": "NL",
    "name": "Oostvoorne",
    "lat": "51.9125",
    "lng": "4.09861"
  },
  {
    "country": "NL",
    "name": "Oost-Vlieland",
    "lat": "53.29703",
    "lng": "5.07431"
  },
  {
    "country": "NL",
    "name": "Oostrum",
    "lat": "51.52917",
    "lng": "6.01667"
  },
  {
    "country": "NL",
    "name": "Oostkapelle",
    "lat": "51.56667",
    "lng": "3.55139"
  },
  {
    "country": "NL",
    "name": "Oosthuizen",
    "lat": "52.5725",
    "lng": "4.99583"
  },
  {
    "country": "NL",
    "name": "Oosterzij",
    "lat": "52.585",
    "lng": "4.70556"
  },
  {
    "country": "NL",
    "name": "Oosterwolde",
    "lat": "52.99164",
    "lng": "6.29096"
  },
  {
    "country": "NL",
    "name": "Oosterpark",
    "lat": "53.2237",
    "lng": "6.5853"
  },
  {
    "country": "NL",
    "name": "Eastermar",
    "lat": "53.17466",
    "lng": "6.05999"
  },
  {
    "country": "NL",
    "name": "Oostermeenthe",
    "lat": "52.79319",
    "lng": "6.13138"
  },
  {
    "country": "NL",
    "name": "Oosterland",
    "lat": "51.65",
    "lng": "4.03611"
  },
  {
    "country": "NL",
    "name": "Oosterhout",
    "lat": "51.88",
    "lng": "5.82639"
  },
  {
    "country": "NL",
    "name": "Oosterhout",
    "lat": "51.645",
    "lng": "4.85972"
  },
  {
    "country": "NL",
    "name": "Oosterhoogebrug",
    "lat": "53.22892",
    "lng": "6.60141"
  },
  {
    "country": "NL",
    "name": "Oosterholt",
    "lat": "52.55917",
    "lng": "5.95556"
  },
  {
    "country": "NL",
    "name": "Oosterhesselen",
    "lat": "52.75417",
    "lng": "6.72222"
  },
  {
    "country": "NL",
    "name": "Oosterblokker",
    "lat": "52.66917",
    "lng": "5.11806"
  },
  {
    "country": "NL",
    "name": "Oosterbeek",
    "lat": "51.98583",
    "lng": "5.84583"
  },
  {
    "country": "NL",
    "name": "Oostendorp",
    "lat": "52.44722",
    "lng": "5.85443"
  },
  {
    "country": "NL",
    "name": "Oostelbeers",
    "lat": "51.47171",
    "lng": "5.26897"
  },
  {
    "country": "NL",
    "name": "Oosteinde",
    "lat": "52.27917",
    "lng": "4.79583"
  },
  {
    "country": "NL",
    "name": "Oosteind",
    "lat": "51.64418",
    "lng": "4.89784"
  },
  {
    "country": "NL",
    "name": "Oostdorp",
    "lat": "52.14994",
    "lng": "4.39319"
  },
  {
    "country": "NL",
    "name": "Oostburg",
    "lat": "51.32583",
    "lng": "3.4875"
  },
  {
    "country": "NL",
    "name": "Ooy",
    "lat": "51.91917",
    "lng": "6.05833"
  },
  {
    "country": "NL",
    "name": "Ooij",
    "lat": "51.85465",
    "lng": "5.93915"
  },
  {
    "country": "NL",
    "name": "Oog in Al",
    "lat": "52.08636",
    "lng": "5.0847"
  },
  {
    "country": "NL",
    "name": "Onstwedde",
    "lat": "53.035",
    "lng": "7.04028"
  },
  {
    "country": "NL",
    "name": "Onderdijk",
    "lat": "52.74333",
    "lng": "5.1375"
  },
  {
    "country": "NL",
    "name": "Ommoord",
    "lat": "51.95951",
    "lng": "4.54533"
  },
  {
    "country": "NL",
    "name": "Ommen",
    "lat": "52.52083",
    "lng": "6.42083"
  },
  {
    "country": "NL",
    "name": "Ommelanderwijk",
    "lat": "53.08917",
    "lng": "6.90556"
  },
  {
    "country": "NL",
    "name": "Olst",
    "lat": "52.3375",
    "lng": "6.10972"
  },
  {
    "country": "NL",
    "name": "Oldenzaal",
    "lat": "52.31333",
    "lng": "6.92917"
  },
  {
    "country": "NL",
    "name": "Oldemarkt",
    "lat": "52.82083",
    "lng": "5.975"
  },
  {
    "country": "NL",
    "name": "Oldehove",
    "lat": "53.30333",
    "lng": "6.39583"
  },
  {
    "country": "NL",
    "name": "Oldebroek",
    "lat": "52.445",
    "lng": "5.90139"
  },
  {
    "country": "NL",
    "name": "Aldeboarn",
    "lat": "53.05",
    "lng": "5.9"
  },
  {
    "country": "NL",
    "name": "Oldeberkoop",
    "lat": "52.93788",
    "lng": "6.13089"
  },
  {
    "country": "NL",
    "name": "Oisterwijk",
    "lat": "51.57917",
    "lng": "5.18889"
  },
  {
    "country": "NL",
    "name": "Oirschot",
    "lat": "51.505",
    "lng": "5.31389"
  },
  {
    "country": "NL",
    "name": "Oirsbeek",
    "lat": "50.95083",
    "lng": "5.90833"
  },
  {
    "country": "NL",
    "name": "Oirlo",
    "lat": "51.51167",
    "lng": "6.0375"
  },
  {
    "country": "NL",
    "name": "Offenbeek",
    "lat": "51.28225",
    "lng": "6.095"
  },
  {
    "country": "NL",
    "name": "Oerle",
    "lat": "51.42255",
    "lng": "5.37163"
  },
  {
    "country": "NL",
    "name": "Oentsjerk",
    "lat": "53.25",
    "lng": "5.9"
  },
  {
    "country": "NL",
    "name": "Oegstgeest",
    "lat": "52.18",
    "lng": "4.46944"
  },
  {
    "country": "NL",
    "name": "Odoorn",
    "lat": "52.84917",
    "lng": "6.85139"
  },
  {
    "country": "NL",
    "name": "Odiliapeel",
    "lat": "51.64333",
    "lng": "5.70556"
  },
  {
    "country": "NL",
    "name": "Odijk",
    "lat": "52.0525",
    "lng": "5.23611"
  },
  {
    "country": "NL",
    "name": "Ochten",
    "lat": "51.91",
    "lng": "5.56944"
  },
  {
    "country": "NL",
    "name": "Obergum",
    "lat": "53.33333",
    "lng": "6.51667"
  },
  {
    "country": "NL",
    "name": "Obdam",
    "lat": "52.67583",
    "lng": "4.90694"
  },
  {
    "country": "NL",
    "name": "Obbicht",
    "lat": "51.02833",
    "lng": "5.78056"
  },
  {
    "country": "NL",
    "name": "Nuth",
    "lat": "50.9175",
    "lng": "5.88611"
  },
  {
    "country": "NL",
    "name": "Nunspeet",
    "lat": "52.37917",
    "lng": "5.78611"
  },
  {
    "country": "NL",
    "name": "Numansdorp",
    "lat": "51.73167",
    "lng": "4.4375"
  },
  {
    "country": "NL",
    "name": "Nuenen",
    "lat": "51.47",
    "lng": "5.55278"
  },
  {
    "country": "NL",
    "name": "Norg",
    "lat": "53.06667",
    "lng": "6.45833"
  },
  {
    "country": "NL",
    "name": "Noordwolde",
    "lat": "52.88964",
    "lng": "6.14153"
  },
  {
    "country": "NL",
    "name": "Noordwijkerhout",
    "lat": "52.26167",
    "lng": "4.49306"
  },
  {
    "country": "NL",
    "name": "Noordwijk-Binnen",
    "lat": "52.234",
    "lng": "4.44474"
  },
  {
    "country": "NL",
    "name": "Noord-Scharwoude",
    "lat": "52.69833",
    "lng": "4.81111"
  },
  {
    "country": "NL",
    "name": "Noordhorn",
    "lat": "53.26167",
    "lng": "6.39583"
  },
  {
    "country": "NL",
    "name": "Noord-Hofland",
    "lat": "52.14059",
    "lng": "4.45864"
  },
  {
    "country": "NL",
    "name": "Noordhoek",
    "lat": "51.6425",
    "lng": "4.53194"
  },
  {
    "country": "NL",
    "name": "Noordgeest",
    "lat": "51.50917",
    "lng": "4.27917"
  },
  {
    "country": "NL",
    "name": "Noordeloos",
    "lat": "51.90333",
    "lng": "4.94167"
  },
  {
    "country": "NL",
    "name": "Noordeinde",
    "lat": "52.01667",
    "lng": "4.48333"
  },
  {
    "country": "NL",
    "name": "Noordbroek",
    "lat": "53.195",
    "lng": "6.87361"
  },
  {
    "country": "NL",
    "name": "Noardburgum",
    "lat": "53.22135",
    "lng": "6.00523"
  },
  {
    "country": "NL",
    "name": "Noordbarge",
    "lat": "52.77237",
    "lng": "6.88713"
  },
  {
    "country": "NL",
    "name": "Nistelrode",
    "lat": "51.70417",
    "lng": "5.5625"
  },
  {
    "country": "NL",
    "name": "Nispen",
    "lat": "51.48331",
    "lng": "4.46131"
  },
  {
    "country": "NL",
    "name": "Nijrees",
    "lat": "52.335",
    "lng": "6.66389"
  },
  {
    "country": "NL",
    "name": "Nijnsel",
    "lat": "51.55083",
    "lng": "5.48333"
  },
  {
    "country": "NL",
    "name": "Nijmegen",
    "lat": "51.8425",
    "lng": "5.85278"
  },
  {
    "country": "NL",
    "name": "Nijkerkerveen",
    "lat": "52.195",
    "lng": "5.46667"
  },
  {
    "country": "NL",
    "name": "Nijkerk",
    "lat": "52.22",
    "lng": "5.48611"
  },
  {
    "country": "NL",
    "name": "Nijenheim",
    "lat": "52.08689",
    "lng": "5.21852"
  },
  {
    "country": "NL",
    "name": "Nieuw-Vossemeer",
    "lat": "51.59",
    "lng": "4.21806"
  },
  {
    "country": "NL",
    "name": "Nieuwveen",
    "lat": "52.19667",
    "lng": "4.75694"
  },
  {
    "country": "NL",
    "name": "Nieuw-Roden",
    "lat": "53.13167",
    "lng": "6.39722"
  },
  {
    "country": "NL",
    "name": "Nieuwpoort",
    "lat": "51.93583",
    "lng": "4.86806"
  },
  {
    "country": "NL",
    "name": "Nieuwoord",
    "lat": "52.46667",
    "lng": "6.55"
  },
  {
    "country": "NL",
    "name": "Nieuwolda",
    "lat": "53.24417",
    "lng": "6.975"
  },
  {
    "country": "NL",
    "name": "Nieuw-Lotbroek",
    "lat": "50.91283",
    "lng": "5.92798"
  },
  {
    "country": "NL",
    "name": "Nieuw-Loosdrecht",
    "lat": "52.19917",
    "lng": "5.13889"
  },
  {
    "country": "NL",
    "name": "Nieuw-Lekkerland",
    "lat": "51.88915",
    "lng": "4.68653"
  },
  {
    "country": "NL",
    "name": "Nieuw- en Sint Joosland",
    "lat": "51.48333",
    "lng": "3.65694"
  },
  {
    "country": "NL",
    "name": "Nieuwkuijk",
    "lat": "51.69",
    "lng": "5.18194"
  },
  {
    "country": "NL",
    "name": "Nieuwkoop",
    "lat": "52.15083",
    "lng": "4.77639"
  },
  {
    "country": "NL",
    "name": "Nieuwerkerk",
    "lat": "51.65083",
    "lng": "4.00139"
  },
  {
    "country": "NL",
    "name": "Nieuwe Pekela",
    "lat": "53.07917",
    "lng": "6.96528"
  },
  {
    "country": "NL",
    "name": "Nieuwe-Niedorp",
    "lat": "52.74",
    "lng": "4.89861"
  },
  {
    "country": "NL",
    "name": "Nieuwenhoorn",
    "lat": "51.85417",
    "lng": "4.14306"
  },
  {
    "country": "NL",
    "name": "Nieuwehorne",
    "lat": "52.95113",
    "lng": "6.06342"
  },
  {
    "country": "NL",
    "name": "Nieuwegein",
    "lat": "52.02917",
    "lng": "5.08056"
  },
  {
    "country": "NL",
    "name": "Nieuwdorp",
    "lat": "50.96216",
    "lng": "5.77297"
  },
  {
    "country": "NL",
    "name": "Nieuw-Dordrecht",
    "lat": "52.74833",
    "lng": "6.96806"
  },
  {
    "country": "NL",
    "name": "Nieuw-Buinen",
    "lat": "52.9625",
    "lng": "6.95"
  },
  {
    "country": "NL",
    "name": "Nieuw-Beijerland",
    "lat": "51.8125",
    "lng": "4.34306"
  },
  {
    "country": "NL",
    "name": "Niekerk",
    "lat": "53.225",
    "lng": "6.35278"
  },
  {
    "country": "NL",
    "name": "Nes",
    "lat": "53.44502",
    "lng": "5.774"
  },
  {
    "country": "NL",
    "name": "Nes",
    "lat": "53.05207",
    "lng": "5.85223"
  },
  {
    "country": "NL",
    "name": "Neerkant",
    "lat": "51.36833",
    "lng": "5.86667"
  },
  {
    "country": "NL",
    "name": "Neerbeek",
    "lat": "50.95",
    "lng": "5.81528"
  },
  {
    "country": "NL",
    "name": "Andel",
    "lat": "51.78333",
    "lng": "5.05833"
  },
  {
    "country": "NL",
    "name": "Neede",
    "lat": "52.13417",
    "lng": "6.61389"
  },
  {
    "country": "NL",
    "name": "Nederwoud",
    "lat": "52.10083",
    "lng": "5.57083"
  },
  {
    "country": "NL",
    "name": "Nederweert",
    "lat": "51.28583",
    "lng": "5.74861"
  },
  {
    "country": "NL",
    "name": "Nederhemert-Noord",
    "lat": "51.76322",
    "lng": "5.17305"
  },
  {
    "country": "NL",
    "name": "Nederhemert",
    "lat": "51.76518",
    "lng": "5.16817"
  },
  {
    "country": "NL",
    "name": "Neder-Hardinxveld",
    "lat": "51.82879",
    "lng": "4.85489"
  },
  {
    "country": "NL",
    "name": "Naastenbest",
    "lat": "51.50484",
    "lng": "5.38579"
  },
  {
    "country": "NL",
    "name": "Naarden",
    "lat": "52.29583",
    "lng": "5.1625"
  },
  {
    "country": "NL",
    "name": "Naaldwijk",
    "lat": "51.99417",
    "lng": "4.20972"
  },
  {
    "country": "NL",
    "name": "Munstergeleen",
    "lat": "50.975",
    "lng": "5.86389"
  },
  {
    "country": "NL",
    "name": "Muiderberg",
    "lat": "52.32583",
    "lng": "5.12083"
  },
  {
    "country": "NL",
    "name": "Muiden",
    "lat": "52.33",
    "lng": "5.06944"
  },
  {
    "country": "NL",
    "name": "Mook",
    "lat": "51.7525",
    "lng": "5.88194"
  },
  {
    "country": "NL",
    "name": "Montfort",
    "lat": "51.12583",
    "lng": "5.94861"
  },
  {
    "country": "NL",
    "name": "Montfoort",
    "lat": "52.04583",
    "lng": "4.95278"
  },
  {
    "country": "NL",
    "name": "Monster",
    "lat": "52.02583",
    "lng": "4.175"
  },
  {
    "country": "NL",
    "name": "Monnickendam",
    "lat": "52.45833",
    "lng": "5.0375"
  },
  {
    "country": "NL",
    "name": "Molenhoek",
    "lat": "51.71113",
    "lng": "5.36809"
  },
  {
    "country": "NL",
    "name": "Moesel",
    "lat": "51.23828",
    "lng": "5.71778"
  },
  {
    "country": "NL",
    "name": "Moerdijk",
    "lat": "51.70167",
    "lng": "4.62639"
  },
  {
    "country": "NL",
    "name": "Minnertsga",
    "lat": "53.25104",
    "lng": "5.59513"
  },
  {
    "country": "NL",
    "name": "Milsbeek",
    "lat": "51.725",
    "lng": "5.94861"
  },
  {
    "country": "NL",
    "name": "Milheeze",
    "lat": "51.50167",
    "lng": "5.77917"
  },
  {
    "country": "NL",
    "name": "Mijnsheerenland",
    "lat": "51.79667",
    "lng": "4.4875"
  },
  {
    "country": "NL",
    "name": "Mijdrecht",
    "lat": "52.20667",
    "lng": "4.8625"
  },
  {
    "country": "NL",
    "name": "Mierlo",
    "lat": "51.44",
    "lng": "5.61944"
  },
  {
    "country": "NL",
    "name": "Midwoud",
    "lat": "52.71667",
    "lng": "5.075"
  },
  {
    "country": "NL",
    "name": "Midwolda",
    "lat": "53.195",
    "lng": "7.01389"
  },
  {
    "country": "NL",
    "name": "Middenmeer",
    "lat": "52.80667",
    "lng": "4.99861"
  },
  {
    "country": "NL",
    "name": "Middenbeemster",
    "lat": "52.54917",
    "lng": "4.9125"
  },
  {
    "country": "NL",
    "name": "Middelstum",
    "lat": "53.34667",
    "lng": "6.64167"
  },
  {
    "country": "NL",
    "name": "Middelsluis",
    "lat": "51.7425",
    "lng": "4.44167"
  },
  {
    "country": "NL",
    "name": "Middelrode",
    "lat": "51.66417",
    "lng": "5.41944"
  },
  {
    "country": "NL",
    "name": "Middelharnis",
    "lat": "51.7575",
    "lng": "4.16528"
  },
  {
    "country": "NL",
    "name": "Middelburg",
    "lat": "51.5",
    "lng": "3.61389"
  },
  {
    "country": "NL",
    "name": "Middelbeers",
    "lat": "51.46667",
    "lng": "5.25"
  },
  {
    "country": "NL",
    "name": "Meteren",
    "lat": "51.865",
    "lng": "5.28333"
  },
  {
    "country": "NL",
    "name": "Merum",
    "lat": "51.17333",
    "lng": "5.95972"
  },
  {
    "country": "NL",
    "name": "Merselo",
    "lat": "51.53",
    "lng": "5.92778"
  },
  {
    "country": "NL",
    "name": "Merkelbeek",
    "lat": "50.95389",
    "lng": "5.94069"
  },
  {
    "country": "NL",
    "name": "Merenwijk",
    "lat": "52.17655",
    "lng": "4.50885"
  },
  {
    "country": "NL",
    "name": "Meppel",
    "lat": "52.69583",
    "lng": "6.19444"
  },
  {
    "country": "NL",
    "name": "Menaam",
    "lat": "53.21797",
    "lng": "5.66124"
  },
  {
    "country": "NL",
    "name": "Melle",
    "lat": "51.66244",
    "lng": "5.63367"
  },
  {
    "country": "NL",
    "name": "Meliskerke",
    "lat": "51.51417",
    "lng": "3.50972"
  },
  {
    "country": "NL",
    "name": "Melick",
    "lat": "51.15917",
    "lng": "6.01667"
  },
  {
    "country": "NL",
    "name": "Melderslo",
    "lat": "51.46167",
    "lng": "6.08611"
  },
  {
    "country": "NL",
    "name": "Mekkelholt",
    "lat": "52.23645",
    "lng": "6.89058"
  },
  {
    "country": "NL",
    "name": "Meijel",
    "lat": "51.34417",
    "lng": "5.88472"
  },
  {
    "country": "NL",
    "name": "Megen",
    "lat": "51.82167",
    "lng": "5.5625"
  },
  {
    "country": "NL",
    "name": "Meezenbroek",
    "lat": "50.8968",
    "lng": "5.99051"
  },
  {
    "country": "NL",
    "name": "Meerveldhoven",
    "lat": "51.41705",
    "lng": "5.41618"
  },
  {
    "country": "NL",
    "name": "Meerssen",
    "lat": "50.8875",
    "lng": "5.75"
  },
  {
    "country": "NL",
    "name": "Meerlo",
    "lat": "51.51333",
    "lng": "6.08472"
  },
  {
    "country": "NL",
    "name": "Meeden",
    "lat": "53.14",
    "lng": "6.92639"
  },
  {
    "country": "NL",
    "name": "Medemblik",
    "lat": "52.77167",
    "lng": "5.10556"
  },
  {
    "country": "NL",
    "name": "Mechelen",
    "lat": "50.79583",
    "lng": "5.92639"
  },
  {
    "country": "NL",
    "name": "Maurik",
    "lat": "51.96083",
    "lng": "5.42222"
  },
  {
    "country": "NL",
    "name": "Marum",
    "lat": "53.14417",
    "lng": "6.2625"
  },
  {
    "country": "NL",
    "name": "Marsum",
    "lat": "53.2105",
    "lng": "5.72637"
  },
  {
    "country": "NL",
    "name": "Marrum",
    "lat": "53.32277",
    "lng": "5.80198"
  },
  {
    "country": "NL",
    "name": "Markelo",
    "lat": "52.235",
    "lng": "6.49861"
  },
  {
    "country": "NL",
    "name": "Mariarade",
    "lat": "50.92906",
    "lng": "5.92738"
  },
  {
    "country": "NL",
    "name": "Mariahout",
    "lat": "51.54083",
    "lng": "5.57222"
  },
  {
    "country": "NL",
    "name": "Margraten",
    "lat": "50.82083",
    "lng": "5.82083"
  },
  {
    "country": "NL",
    "name": "Mantgum",
    "lat": "53.12865",
    "lng": "5.71924"
  },
  {
    "country": "NL",
    "name": "Malta",
    "lat": "51.65",
    "lng": "3.93333"
  },
  {
    "country": "NL",
    "name": "Malburgen West",
    "lat": "51.96811",
    "lng": "5.89743"
  },
  {
    "country": "NL",
    "name": "Malberg",
    "lat": "50.86244",
    "lng": "5.65419"
  },
  {
    "country": "NL",
    "name": "Makkum",
    "lat": "53.09513",
    "lng": "5.67946"
  },
  {
    "country": "NL",
    "name": "Makkum",
    "lat": "53.05458",
    "lng": "5.40231"
  },
  {
    "country": "NL",
    "name": "Magele",
    "lat": "52.46917",
    "lng": "6.52083"
  },
  {
    "country": "NL",
    "name": "Made",
    "lat": "51.67667",
    "lng": "4.79306"
  },
  {
    "country": "NL",
    "name": "Maastricht",
    "lat": "50.84833",
    "lng": "5.68889"
  },
  {
    "country": "NL",
    "name": "Maassluis",
    "lat": "51.92333",
    "lng": "4.25"
  },
  {
    "country": "NL",
    "name": "Maasland",
    "lat": "51.93417",
    "lng": "4.27222"
  },
  {
    "country": "NL",
    "name": "Maaskantje",
    "lat": "51.65833",
    "lng": "5.37083"
  },
  {
    "country": "NL",
    "name": "Maasdijk",
    "lat": "51.95917",
    "lng": "4.21389"
  },
  {
    "country": "NL",
    "name": "Maasbree",
    "lat": "51.3575",
    "lng": "6.04861"
  },
  {
    "country": "NL",
    "name": "Maasbracht",
    "lat": "51.13929",
    "lng": "5.88627"
  },
  {
    "country": "NL",
    "name": "Maartensdijk",
    "lat": "52.155",
    "lng": "5.175"
  },
  {
    "country": "NL",
    "name": "Maarssen",
    "lat": "52.13917",
    "lng": "5.04167"
  },
  {
    "country": "NL",
    "name": "Maarn",
    "lat": "52.06417",
    "lng": "5.37083"
  },
  {
    "country": "NL",
    "name": "Maarheeze",
    "lat": "51.31167",
    "lng": "5.61667"
  },
  {
    "country": "NL",
    "name": "Luyksgestel",
    "lat": "51.28917",
    "lng": "5.32361"
  },
  {
    "country": "NL",
    "name": "Lutjebroek",
    "lat": "52.6975",
    "lng": "5.20417"
  },
  {
    "country": "NL",
    "name": "Lunteren",
    "lat": "52.085",
    "lng": "5.62222"
  },
  {
    "country": "NL",
    "name": "Loven",
    "lat": "51.5648",
    "lng": "5.09748"
  },
  {
    "country": "NL",
    "name": "Lottum",
    "lat": "51.46167",
    "lng": "6.16111"
  },
  {
    "country": "NL",
    "name": "Losser",
    "lat": "52.26083",
    "lng": "7.00417"
  },
  {
    "country": "NL",
    "name": "Loppersum",
    "lat": "53.33167",
    "lng": "6.74722"
  },
  {
    "country": "NL",
    "name": "Lopik",
    "lat": "51.9725",
    "lng": "4.94861"
  },
  {
    "country": "NL",
    "name": "Loosbroek",
    "lat": "51.67833",
    "lng": "5.50694"
  },
  {
    "country": "NL",
    "name": "Loon op Zand",
    "lat": "51.6275",
    "lng": "5.075"
  },
  {
    "country": "NL",
    "name": "Lombardijen",
    "lat": "51.8738",
    "lng": "4.52192"
  },
  {
    "country": "NL",
    "name": "Loenen",
    "lat": "52.1175",
    "lng": "6.01944"
  },
  {
    "country": "NL",
    "name": "Lochem",
    "lat": "52.15917",
    "lng": "6.41111"
  },
  {
    "country": "NL",
    "name": "Lobith",
    "lat": "51.8625",
    "lng": "6.11806"
  },
  {
    "country": "NL",
    "name": "Lith",
    "lat": "51.80583",
    "lng": "5.43889"
  },
  {
    "country": "NL",
    "name": "Lisserbroek",
    "lat": "52.25667",
    "lng": "4.57222"
  },
  {
    "country": "NL",
    "name": "Lisse",
    "lat": "52.26",
    "lng": "4.55694"
  },
  {
    "country": "NL",
    "name": "Linschoten",
    "lat": "52.0625",
    "lng": "4.91528"
  },
  {
    "country": "NL",
    "name": "Linne",
    "lat": "51.155",
    "lng": "5.93889"
  },
  {
    "country": "NL",
    "name": "Lindenholt",
    "lat": "51.8327",
    "lng": "5.7934"
  },
  {
    "country": "NL",
    "name": "Lindenheuvel",
    "lat": "50.98509",
    "lng": "5.81667"
  },
  {
    "country": "NL",
    "name": "Limmel",
    "lat": "50.86718",
    "lng": "5.70719"
  },
  {
    "country": "NL",
    "name": "Limbricht",
    "lat": "51.01167",
    "lng": "5.8375"
  },
  {
    "country": "NL",
    "name": "Lievendaal",
    "lat": "51.44219",
    "lng": "5.43405"
  },
  {
    "country": "NL",
    "name": "Liesveld",
    "lat": "51.9325",
    "lng": "4.83194"
  },
  {
    "country": "NL",
    "name": "Liessel",
    "lat": "51.41333",
    "lng": "5.82083"
  },
  {
    "country": "NL",
    "name": "Lieshout",
    "lat": "51.52036",
    "lng": "5.59479"
  },
  {
    "country": "NL",
    "name": "Lierop",
    "lat": "51.41917",
    "lng": "5.67917"
  },
  {
    "country": "NL",
    "name": "Lienden",
    "lat": "51.94833",
    "lng": "5.51806"
  },
  {
    "country": "NL",
    "name": "Liempde",
    "lat": "51.56917",
    "lng": "5.37222"
  },
  {
    "country": "NL",
    "name": "Lichtenvoorde",
    "lat": "51.98667",
    "lng": "6.56667"
  },
  {
    "country": "NL",
    "name": "Lichtenberg",
    "lat": "50.9022",
    "lng": "6.02523"
  },
  {
    "country": "NL",
    "name": "Leuth",
    "lat": "51.83917",
    "lng": "5.99167"
  },
  {
    "country": "NL",
    "name": "Leusden",
    "lat": "52.1325",
    "lng": "5.43194"
  },
  {
    "country": "NL",
    "name": "Leunen",
    "lat": "51.51",
    "lng": "5.97917"
  },
  {
    "country": "NL",
    "name": "Leuken",
    "lat": "51.25288",
    "lng": "5.7346"
  },
  {
    "country": "NL",
    "name": "Lepelstraat",
    "lat": "51.54833",
    "lng": "4.27639"
  },
  {
    "country": "NL",
    "name": "Lent",
    "lat": "51.86167",
    "lng": "5.86667"
  },
  {
    "country": "NL",
    "name": "Lemmer",
    "lat": "52.84618",
    "lng": "5.70912"
  },
  {
    "country": "NL",
    "name": "Lelystad",
    "lat": "52.50833",
    "lng": "5.475"
  },
  {
    "country": "NL",
    "name": "Leimuiden",
    "lat": "52.22417",
    "lng": "4.66944"
  },
  {
    "country": "NL",
    "name": "Leiderdorp",
    "lat": "52.15833",
    "lng": "4.52917"
  },
  {
    "country": "NL",
    "name": "Leiden",
    "lat": "52.15833",
    "lng": "4.49306"
  },
  {
    "country": "NL",
    "name": "Leeuwen",
    "lat": "51.21032",
    "lng": "5.99862"
  },
  {
    "country": "NL",
    "name": "Leeuwarden",
    "lat": "53.20139",
    "lng": "5.80859"
  },
  {
    "country": "NL",
    "name": "Leesten",
    "lat": "52.1279",
    "lng": "6.23217"
  },
  {
    "country": "NL",
    "name": "Leest",
    "lat": "51.60983",
    "lng": "5.54312"
  },
  {
    "country": "NL",
    "name": "Leersum",
    "lat": "52.01167",
    "lng": "5.42778"
  },
  {
    "country": "NL",
    "name": "Leerdam",
    "lat": "51.89333",
    "lng": "5.09167"
  },
  {
    "country": "NL",
    "name": "Leens",
    "lat": "53.36",
    "lng": "6.37917"
  },
  {
    "country": "NL",
    "name": "Leende",
    "lat": "51.35083",
    "lng": "5.55417"
  },
  {
    "country": "NL",
    "name": "Leek",
    "lat": "53.1625",
    "lng": "6.37639"
  },
  {
    "country": "NL",
    "name": "Lauradorp",
    "lat": "50.91229",
    "lng": "6.04591"
  },
  {
    "country": "NL",
    "name": "Laren",
    "lat": "52.25667",
    "lng": "5.22778"
  },
  {
    "country": "NL",
    "name": "Laren",
    "lat": "52.19417",
    "lng": "6.36528"
  },
  {
    "country": "NL",
    "name": "Langweer",
    "lat": "52.95836",
    "lng": "5.72173"
  },
  {
    "country": "NL",
    "name": "Langenoord",
    "lat": "52.18768",
    "lng": "5.38034"
  },
  {
    "country": "NL",
    "name": "Langenboom",
    "lat": "51.70417",
    "lng": "5.73056"
  },
  {
    "country": "NL",
    "name": "Langeheit",
    "lat": "52.492",
    "lng": "4.75849"
  },
  {
    "country": "NL",
    "name": "Landsmeer",
    "lat": "52.43083",
    "lng": "4.91528"
  },
  {
    "country": "NL",
    "name": "Lammerenburg",
    "lat": "51.46667",
    "lng": "3.55833"
  },
  {
    "country": "NL",
    "name": "Lage Mierde",
    "lat": "51.40583",
    "lng": "5.14722"
  },
  {
    "country": "NL",
    "name": "Kwintsheul",
    "lat": "52.01333",
    "lng": "4.25556"
  },
  {
    "country": "NL",
    "name": "Kunrade",
    "lat": "50.87769",
    "lng": "5.93107"
  },
  {
    "country": "NL",
    "name": "Kudelstaart",
    "lat": "52.23417",
    "lng": "4.75139"
  },
  {
    "country": "NL",
    "name": "Kruisland",
    "lat": "51.56917",
    "lng": "4.40972"
  },
  {
    "country": "NL",
    "name": "Kruisberg",
    "lat": "50.94234",
    "lng": "5.96519"
  },
  {
    "country": "NL",
    "name": "Krooswijk",
    "lat": "51.64665",
    "lng": "4.59203"
  },
  {
    "country": "NL",
    "name": "Krimpen aan den IJssel",
    "lat": "51.91667",
    "lng": "4.60278"
  },
  {
    "country": "NL",
    "name": "Krakeel",
    "lat": "52.72339",
    "lng": "6.51146"
  },
  {
    "country": "NL",
    "name": "Koudum",
    "lat": "52.91551",
    "lng": "5.44834"
  },
  {
    "country": "NL",
    "name": "Koudekerke",
    "lat": "51.48167",
    "lng": "3.55417"
  },
  {
    "country": "NL",
    "name": "Korvel",
    "lat": "51.54954",
    "lng": "5.07079"
  },
  {
    "country": "NL",
    "name": "Kortenhoef",
    "lat": "52.23917",
    "lng": "5.10694"
  },
  {
    "country": "NL",
    "name": "Korrewegwijk",
    "lat": "53.23235",
    "lng": "6.56804"
  },
  {
    "country": "NL",
    "name": "Kootwijkerbroek",
    "lat": "52.15083",
    "lng": "5.66944"
  },
  {
    "country": "NL",
    "name": "Kootstertille",
    "lat": "53.21261",
    "lng": "6.09209"
  },
  {
    "country": "NL",
    "name": "Koningslust",
    "lat": "51.3575",
    "lng": "5.99306"
  },
  {
    "country": "NL",
    "name": "Koningsbosch",
    "lat": "51.05167",
    "lng": "5.95833"
  },
  {
    "country": "NL",
    "name": "Kollumerzwaag",
    "lat": "53.26224",
    "lng": "6.07544"
  },
  {
    "country": "NL",
    "name": "Kollum",
    "lat": "53.27695",
    "lng": "6.15293"
  },
  {
    "country": "NL",
    "name": "Koewacht",
    "lat": "51.22833",
    "lng": "3.97361"
  },
  {
    "country": "NL",
    "name": "Koekange",
    "lat": "52.69917",
    "lng": "6.31667"
  },
  {
    "country": "NL",
    "name": "Klundert",
    "lat": "51.665",
    "lng": "4.53472"
  },
  {
    "country": "NL",
    "name": "Kloetinge",
    "lat": "51.49833",
    "lng": "3.91528"
  },
  {
    "country": "NL",
    "name": "Klimmen",
    "lat": "50.87583",
    "lng": "5.88056"
  },
  {
    "country": "NL",
    "name": "Klein-Zundert",
    "lat": "51.48083",
    "lng": "4.65417"
  },
  {
    "country": "NL",
    "name": "Klein Driene",
    "lat": "52.26935",
    "lng": "6.81613"
  },
  {
    "country": "NL",
    "name": "Klazienaveen",
    "lat": "52.72417",
    "lng": "6.99028"
  },
  {
    "country": "NL",
    "name": "Klarenbeek",
    "lat": "51.50964",
    "lng": "3.61132"
  },
  {
    "country": "NL",
    "name": "Klaaswaal",
    "lat": "51.77",
    "lng": "4.44583"
  },
  {
    "country": "NL",
    "name": "Kijkduin",
    "lat": "52.06765",
    "lng": "4.22188"
  },
  {
    "country": "NL",
    "name": "Kesteren",
    "lat": "51.935",
    "lng": "5.56944"
  },
  {
    "country": "NL",
    "name": "Kessel",
    "lat": "51.29167",
    "lng": "6.05417"
  },
  {
    "country": "NL",
    "name": "Kerschoten",
    "lat": "52.23333",
    "lng": "5.96667"
  },
  {
    "country": "NL",
    "name": "Kerkrade",
    "lat": "50.86583",
    "lng": "6.0625"
  },
  {
    "country": "NL",
    "name": "Kerkelanden",
    "lat": "52.21755",
    "lng": "5.13575"
  },
  {
    "country": "NL",
    "name": "Kerkehout",
    "lat": "52.11018",
    "lng": "4.37957"
  },
  {
    "country": "NL",
    "name": "Kerkdriel",
    "lat": "51.77167",
    "lng": "5.33472"
  },
  {
    "country": "NL",
    "name": "Marken",
    "lat": "52.45833",
    "lng": "5.10278"
  },
  {
    "country": "NL",
    "name": "Kerensheide",
    "lat": "50.9721",
    "lng": "5.77666"
  },
  {
    "country": "NL",
    "name": "Kerckebosch",
    "lat": "52.07844",
    "lng": "5.26584"
  },
  {
    "country": "NL",
    "name": "Keijenborg",
    "lat": "52.02917",
    "lng": "6.29444"
  },
  {
    "country": "NL",
    "name": "Keent",
    "lat": "51.24218",
    "lng": "5.70079"
  },
  {
    "country": "NL",
    "name": "Kedichem",
    "lat": "51.86",
    "lng": "5.05"
  },
  {
    "country": "NL",
    "name": "Katwijk aan Zee",
    "lat": "52.20333",
    "lng": "4.39861"
  },
  {
    "country": "NL",
    "name": "Katwijk aan den Rijn",
    "lat": "52.19417",
    "lng": "4.42222"
  },
  {
    "country": "NL",
    "name": "Katendrecht",
    "lat": "51.90074",
    "lng": "4.48254"
  },
  {
    "country": "NL",
    "name": "Kamperland",
    "lat": "51.57167",
    "lng": "3.70417"
  },
  {
    "country": "NL",
    "name": "Kampen",
    "lat": "52.555",
    "lng": "5.91111"
  },
  {
    "country": "NL",
    "name": "Kalsdonk",
    "lat": "51.53973",
    "lng": "4.47111"
  },
  {
    "country": "NL",
    "name": "Kakert",
    "lat": "50.90414",
    "lng": "6.00463"
  },
  {
    "country": "NL",
    "name": "Kadoelen",
    "lat": "52.4175",
    "lng": "4.90561"
  },
  {
    "country": "NL",
    "name": "Kaalheide",
    "lat": "50.86505",
    "lng": "6.03643"
  },
  {
    "country": "NL",
    "name": "Joure",
    "lat": "52.9657",
    "lng": "5.80301"
  },
  {
    "country": "NL",
    "name": "Jagershoef",
    "lat": "51.4733",
    "lng": "5.4672"
  },
  {
    "country": "NL",
    "name": "Jirnsum",
    "lat": "53.07753",
    "lng": "5.79254"
  },
  {
    "country": "NL",
    "name": "Ingen",
    "lat": "51.95917",
    "lng": "5.48472"
  },
  {
    "country": "NL",
    "name": "Ilpendam",
    "lat": "52.46333",
    "lng": "4.95"
  },
  {
    "country": "NL",
    "name": "IJzendijke",
    "lat": "51.32167",
    "lng": "3.61667"
  },
  {
    "country": "NL",
    "name": "Ysselsteyn",
    "lat": "51.49",
    "lng": "5.89722"
  },
  {
    "country": "NL",
    "name": "IJsselstein",
    "lat": "52.02",
    "lng": "5.04306"
  },
  {
    "country": "NL",
    "name": "IJlst",
    "lat": "53.01009",
    "lng": "5.62312"
  },
  {
    "country": "NL",
    "name": "Husken",
    "lat": "50.89567",
    "lng": "5.95648"
  },
  {
    "country": "NL",
    "name": "Hummelo",
    "lat": "52.00417",
    "lng": "6.23333"
  },
  {
    "country": "NL",
    "name": "Hulst",
    "lat": "51.28",
    "lng": "4.05278"
  },
  {
    "country": "NL",
    "name": "Hulsberg",
    "lat": "50.88917",
    "lng": "5.85556"
  },
  {
    "country": "NL",
    "name": "Huizen",
    "lat": "52.29917",
    "lng": "5.24167"
  },
  {
    "country": "NL",
    "name": "Huizum",
    "lat": "53.1917",
    "lng": "5.81119"
  },
  {
    "country": "NL",
    "name": "Huijbergen",
    "lat": "51.4325",
    "lng": "4.37639"
  },
  {
    "country": "NL",
    "name": "Houthem",
    "lat": "50.8725",
    "lng": "5.79306"
  },
  {
    "country": "NL",
    "name": "Houten",
    "lat": "52.02833",
    "lng": "5.16806"
  },
  {
    "country": "NL",
    "name": "Horssen",
    "lat": "51.85583",
    "lng": "5.60972"
  },
  {
    "country": "NL",
    "name": "Hopel",
    "lat": "50.89245",
    "lng": "6.05046"
  },
  {
    "country": "NL",
    "name": "Hoorn",
    "lat": "52.6425",
    "lng": "5.05972"
  },
  {
    "country": "NL",
    "name": "Hoogwoud",
    "lat": "52.71583",
    "lng": "4.93889"
  },
  {
    "country": "NL",
    "name": "Hoogmade",
    "lat": "52.16917",
    "lng": "4.58194"
  },
  {
    "country": "NL",
    "name": "Hoogland",
    "lat": "52.1825",
    "lng": "5.37361"
  },
  {
    "country": "NL",
    "name": "Hooge Zwaluwe",
    "lat": "51.6875",
    "lng": "4.74444"
  },
  {
    "country": "NL",
    "name": "Hoogezand",
    "lat": "53.16167",
    "lng": "6.76111"
  },
  {
    "country": "NL",
    "name": "Hoogeveen",
    "lat": "52.7225",
    "lng": "6.47639"
  },
  {
    "country": "NL",
    "name": "Hoogerheide",
    "lat": "51.42417",
    "lng": "4.325"
  },
  {
    "country": "NL",
    "name": "Hooge Mierde",
    "lat": "51.3875",
    "lng": "5.12917"
  },
  {
    "country": "NL",
    "name": "Hoogeloon",
    "lat": "51.3975",
    "lng": "5.26806"
  },
  {
    "country": "NL",
    "name": "Hoogblokland",
    "lat": "51.875",
    "lng": "4.97639"
  },
  {
    "country": "NL",
    "name": "Hoofddorp",
    "lat": "52.3025",
    "lng": "4.68889"
  },
  {
    "country": "NL",
    "name": "Honselersdijk",
    "lat": "52.00665",
    "lng": "4.22441"
  },
  {
    "country": "NL",
    "name": "Holz",
    "lat": "50.86415",
    "lng": "6.07424"
  },
  {
    "country": "NL",
    "name": "Holwerd",
    "lat": "53.36815",
    "lng": "5.90073"
  },
  {
    "country": "NL",
    "name": "Holtum",
    "lat": "51.0475",
    "lng": "5.82222"
  },
  {
    "country": "NL",
    "name": "Hollum",
    "lat": "53.4394",
    "lng": "5.63805"
  },
  {
    "country": "NL",
    "name": "Hollandsche Rading",
    "lat": "52.175",
    "lng": "5.17778"
  },
  {
    "country": "NL",
    "name": "Hoge Mors",
    "lat": "52.15616",
    "lng": "4.46025"
  },
  {
    "country": "NL",
    "name": "Hoge Vucht",
    "lat": "51.60794",
    "lng": "4.7915"
  },
  {
    "country": "NL",
    "name": "Hofgeest",
    "lat": "52.44333",
    "lng": "4.65833"
  },
  {
    "country": "NL",
    "name": "Hoeven",
    "lat": "51.67206",
    "lng": "5.63444"
  },
  {
    "country": "NL",
    "name": "Hoeven",
    "lat": "51.57917",
    "lng": "4.58333"
  },
  {
    "country": "NL",
    "name": "Hoensbroek",
    "lat": "50.92387",
    "lng": "5.92528"
  },
  {
    "country": "NL",
    "name": "Hoek van Holland",
    "lat": "51.9775",
    "lng": "4.13333"
  },
  {
    "country": "NL",
    "name": "Hippolytushoef",
    "lat": "52.9075",
    "lng": "4.9625"
  },
  {
    "country": "NL",
    "name": "Hilversumse Meent",
    "lat": "52.27115",
    "lng": "5.13729"
  },
  {
    "country": "NL",
    "name": "Hilversum",
    "lat": "52.22333",
    "lng": "5.17639"
  },
  {
    "country": "NL",
    "name": "Hilvarenbeek",
    "lat": "51.48583",
    "lng": "5.1375"
  },
  {
    "country": "NL",
    "name": "Hillegom",
    "lat": "52.29083",
    "lng": "4.58333"
  },
  {
    "country": "NL",
    "name": "Heythuysen",
    "lat": "51.25",
    "lng": "5.89861"
  },
  {
    "country": "NL",
    "name": "Heusdenhout",
    "lat": "51.58811",
    "lng": "4.8193"
  },
  {
    "country": "NL",
    "name": "Heusden",
    "lat": "51.73417",
    "lng": "5.13889"
  },
  {
    "country": "NL",
    "name": "Heusden",
    "lat": "51.38417",
    "lng": "5.76389"
  },
  {
    "country": "NL",
    "name": "Heumen",
    "lat": "51.765",
    "lng": "5.84444"
  },
  {
    "country": "NL",
    "name": "Heugem",
    "lat": "50.82791",
    "lng": "5.70774"
  },
  {
    "country": "NL",
    "name": "Het Oostrik",
    "lat": "52.25",
    "lng": "6.21667"
  },
  {
    "country": "NL",
    "name": "Het Loo",
    "lat": "52.2339",
    "lng": "5.95275"
  },
  {
    "country": "NL",
    "name": "Heteren",
    "lat": "51.95667",
    "lng": "5.75556"
  },
  {
    "country": "NL",
    "name": "Herwijnen",
    "lat": "51.82667",
    "lng": "5.12917"
  },
  {
    "country": "NL",
    "name": "Herten",
    "lat": "51.18083",
    "lng": "5.9625"
  },
  {
    "country": "NL",
    "name": "Herpen",
    "lat": "51.77167",
    "lng": "5.64167"
  },
  {
    "country": "NL",
    "name": "Herkenbosch",
    "lat": "51.15333",
    "lng": "6.06389"
  },
  {
    "country": "NL",
    "name": "Hensbroek",
    "lat": "52.65833",
    "lng": "4.88472"
  },
  {
    "country": "NL",
    "name": "Hengstdal",
    "lat": "51.83333",
    "lng": "5.88333"
  },
  {
    "country": "NL",
    "name": "Hengevelde",
    "lat": "52.19917",
    "lng": "6.63611"
  },
  {
    "country": "NL",
    "name": "Hengelo",
    "lat": "52.26583",
    "lng": "6.79306"
  },
  {
    "country": "NL",
    "name": "Hengelo",
    "lat": "52.05083",
    "lng": "6.30972"
  },
  {
    "country": "NL",
    "name": "Hendrik-Ido-Ambacht",
    "lat": "51.84417",
    "lng": "4.63889"
  },
  {
    "country": "NL",
    "name": "Hem",
    "lat": "52.66083",
    "lng": "5.18333"
  },
  {
    "country": "NL",
    "name": "Helvoirt",
    "lat": "51.63167",
    "lng": "5.23056"
  },
  {
    "country": "NL",
    "name": "Helpman",
    "lat": "53.19794",
    "lng": "6.57978"
  },
  {
    "country": "NL",
    "name": "Helmond",
    "lat": "51.48167",
    "lng": "5.66111"
  },
  {
    "country": "NL",
    "name": "Hellevoetsluis",
    "lat": "51.83333",
    "lng": "4.13333"
  },
  {
    "country": "NL",
    "name": "Helden",
    "lat": "51.31917",
    "lng": "6"
  },
  {
    "country": "NL",
    "name": "Heksenberg",
    "lat": "50.92068",
    "lng": "5.97373"
  },
  {
    "country": "NL",
    "name": "Heino",
    "lat": "52.43661",
    "lng": "6.23282"
  },
  {
    "country": "NL",
    "name": "Heiloo",
    "lat": "52.60252",
    "lng": "4.68815"
  },
  {
    "country": "NL",
    "name": "Heiligerlee",
    "lat": "53.15667",
    "lng": "7.00972"
  },
  {
    "country": "NL",
    "name": "Heijplaat",
    "lat": "51.89333",
    "lng": "4.42083"
  },
  {
    "country": "NL",
    "name": "Heijen",
    "lat": "51.675",
    "lng": "5.98056"
  },
  {
    "country": "NL",
    "name": "Heide",
    "lat": "51.06833",
    "lng": "5.87222"
  },
  {
    "country": "NL",
    "name": "Hegelsom",
    "lat": "51.43917",
    "lng": "6.03889"
  },
  {
    "country": "NL",
    "name": "Heeze",
    "lat": "51.3828",
    "lng": "5.57145"
  },
  {
    "country": "NL",
    "name": "Heeswijk-Dinther",
    "lat": "51.65083",
    "lng": "5.475"
  },
  {
    "country": "NL",
    "name": "Heesterakker",
    "lat": "51.4861",
    "lng": "5.49681"
  },
  {
    "country": "NL",
    "name": "Heesch",
    "lat": "51.73362",
    "lng": "5.52672"
  },
  {
    "country": "NL",
    "name": "Hees",
    "lat": "51.84136",
    "lng": "5.82846"
  },
  {
    "country": "NL",
    "name": "Heerlen",
    "lat": "50.88365",
    "lng": "5.98154"
  },
  {
    "country": "NL",
    "name": "Heerle",
    "lat": "51.51917",
    "lng": "4.35972"
  },
  {
    "country": "NL",
    "name": "Heerjansdam",
    "lat": "51.83583",
    "lng": "4.56389"
  },
  {
    "country": "NL",
    "name": "Heerhugowaard",
    "lat": "52.67144",
    "lng": "4.84862"
  },
  {
    "country": "NL",
    "name": "Heerewaarden",
    "lat": "51.81769",
    "lng": "5.393"
  },
  {
    "country": "NL",
    "name": "Heerenveen",
    "lat": "52.95929",
    "lng": "5.91854"
  },
  {
    "country": "NL",
    "name": "Heerde",
    "lat": "52.38723",
    "lng": "6.04016"
  },
  {
    "country": "NL",
    "name": "Heer",
    "lat": "50.83836",
    "lng": "5.72989"
  },
  {
    "country": "NL",
    "name": "Heemstede",
    "lat": "52.34992",
    "lng": "4.62301"
  },
  {
    "country": "NL",
    "name": "Heemskerk",
    "lat": "52.51108",
    "lng": "4.67165"
  },
  {
    "country": "NL",
    "name": "Heelsum",
    "lat": "51.98417",
    "lng": "5.75833"
  },
  {
    "country": "NL",
    "name": "Heel",
    "lat": "51.17917",
    "lng": "5.89444"
  },
  {
    "country": "NL",
    "name": "Heeg",
    "lat": "52.9686",
    "lng": "5.61075"
  },
  {
    "country": "NL",
    "name": "Heechterp",
    "lat": "53.20963",
    "lng": "5.8225"
  },
  {
    "country": "NL",
    "name": "Hedel",
    "lat": "51.74802",
    "lng": "5.26134"
  },
  {
    "country": "NL",
    "name": "Havelte",
    "lat": "52.76941",
    "lng": "6.24015"
  },
  {
    "country": "NL",
    "name": "Haulerwijk",
    "lat": "53.06468",
    "lng": "6.33453"
  },
  {
    "country": "NL",
    "name": "Hattemerbroek",
    "lat": "52.47417",
    "lng": "6.02222"
  },
  {
    "country": "NL",
    "name": "Hattem",
    "lat": "52.475",
    "lng": "6.06389"
  },
  {
    "country": "NL",
    "name": "Hatert",
    "lat": "51.80635",
    "lng": "5.83057"
  },
  {
    "country": "NL",
    "name": "Hasselt",
    "lat": "52.59267",
    "lng": "6.09527"
  },
  {
    "country": "NL",
    "name": "Harskamp",
    "lat": "52.13",
    "lng": "5.75278"
  },
  {
    "country": "NL",
    "name": "Harlingen",
    "lat": "53.17477",
    "lng": "5.42244"
  },
  {
    "country": "NL",
    "name": "Harkstede",
    "lat": "53.21333",
    "lng": "6.69861"
  },
  {
    "country": "NL",
    "name": "Harkema",
    "lat": "53.18333",
    "lng": "6.13333"
  },
  {
    "country": "NL",
    "name": "Harenkarspel",
    "lat": "52.73416",
    "lng": "4.77682"
  },
  {
    "country": "NL",
    "name": "Haren",
    "lat": "53.17209",
    "lng": "6.60931"
  },
  {
    "country": "NL",
    "name": "Harderwijk",
    "lat": "52.34167",
    "lng": "5.62083"
  },
  {
    "country": "NL",
    "name": "Hardenberg",
    "lat": "52.57583",
    "lng": "6.61944"
  },
  {
    "country": "NL",
    "name": "Hurdegaryp",
    "lat": "53.21333",
    "lng": "5.94137"
  },
  {
    "country": "NL",
    "name": "Haps",
    "lat": "51.68917",
    "lng": "5.86111"
  },
  {
    "country": "NL",
    "name": "Hapert",
    "lat": "51.36833",
    "lng": "5.25694"
  },
  {
    "country": "NL",
    "name": "Handel",
    "lat": "51.58",
    "lng": "5.70972"
  },
  {
    "country": "NL",
    "name": "Halsteren",
    "lat": "51.52834",
    "lng": "4.26785"
  },
  {
    "country": "NL",
    "name": "Hallum",
    "lat": "53.30657",
    "lng": "5.78379"
  },
  {
    "country": "NL",
    "name": "Halfweg",
    "lat": "52.52417",
    "lng": "4.92778"
  },
  {
    "country": "NL",
    "name": "Halfweg",
    "lat": "52.3825",
    "lng": "4.75417"
  },
  {
    "country": "NL",
    "name": "Haelen",
    "lat": "51.23583",
    "lng": "5.95694"
  },
  {
    "country": "NL",
    "name": "Haastrecht",
    "lat": "52.00074",
    "lng": "4.77639"
  },
  {
    "country": "NL",
    "name": "Haarsteeg",
    "lat": "51.71167",
    "lng": "5.19861"
  },
  {
    "country": "NL",
    "name": "Haarlem",
    "lat": "52.38084",
    "lng": "4.63683"
  },
  {
    "country": "NL",
    "name": "Haarle",
    "lat": "52.35917",
    "lng": "6.38056"
  },
  {
    "country": "NL",
    "name": "Haaren",
    "lat": "51.6025",
    "lng": "5.22222"
  },
  {
    "country": "NL",
    "name": "Haanrade",
    "lat": "50.87981",
    "lng": "6.07411"
  },
  {
    "country": "NL",
    "name": "Haamstede",
    "lat": "51.69682",
    "lng": "3.74299"
  },
  {
    "country": "NL",
    "name": "Haalderen",
    "lat": "51.8875",
    "lng": "5.92917"
  },
  {
    "country": "NL",
    "name": "Haaksbergen",
    "lat": "52.15667",
    "lng": "6.73889"
  },
  {
    "country": "NL",
    "name": "Haaften",
    "lat": "51.81583",
    "lng": "5.21111"
  },
  {
    "country": "NL",
    "name": "Guttecoven",
    "lat": "51.015",
    "lng": "5.81806"
  },
  {
    "country": "NL",
    "name": "Gulpen",
    "lat": "50.81583",
    "lng": "5.88889"
  },
  {
    "country": "NL",
    "name": "Grou",
    "lat": "53.09456",
    "lng": "5.83745"
  },
  {
    "country": "NL",
    "name": "Groot IJsselmonde",
    "lat": "51.88264",
    "lng": "4.54937"
  },
  {
    "country": "NL",
    "name": "Grootegast",
    "lat": "53.2125",
    "lng": "6.27361"
  },
  {
    "country": "NL",
    "name": "Groot-Ammers",
    "lat": "51.92333",
    "lng": "4.82361"
  },
  {
    "country": "NL",
    "name": "Gronsveld",
    "lat": "50.81083",
    "lng": "5.73056"
  },
  {
    "country": "NL",
    "name": "Groningen",
    "lat": "53.21917",
    "lng": "6.56667"
  },
  {
    "country": "NL",
    "name": "Groessen",
    "lat": "51.93167",
    "lng": "6.02639"
  },
  {
    "country": "NL",
    "name": "Groesbeek",
    "lat": "51.77667",
    "lng": "5.93611"
  },
  {
    "country": "NL",
    "name": "Groenewoud",
    "lat": "51.5386",
    "lng": "5.09028"
  },
  {
    "country": "NL",
    "name": "Groenekan",
    "lat": "52.12333",
    "lng": "5.15278"
  },
  {
    "country": "NL",
    "name": "Grijpskerke",
    "lat": "51.53417",
    "lng": "3.56111"
  },
  {
    "country": "NL",
    "name": "Grijpskerk",
    "lat": "53.2625",
    "lng": "6.30833"
  },
  {
    "country": "NL",
    "name": "Griffioen",
    "lat": "51.50548",
    "lng": "3.59598"
  },
  {
    "country": "NL",
    "name": "Grevenbicht",
    "lat": "51.03833",
    "lng": "5.775"
  },
  {
    "country": "NL",
    "name": "Grave",
    "lat": "51.75902",
    "lng": "5.73882"
  },
  {
    "country": "NL",
    "name": "Grashoek",
    "lat": "51.36083",
    "lng": "5.94306"
  },
  {
    "country": "NL",
    "name": "Grafhorst",
    "lat": "52.5825",
    "lng": "5.93333"
  },
  {
    "country": "NL",
    "name": "Gracht",
    "lat": "50.85175",
    "lng": "6.02793"
  },
  {
    "country": "NL",
    "name": "Gouwsluis",
    "lat": "52.11943",
    "lng": "4.66899"
  },
  {
    "country": "NL",
    "name": "Goutum",
    "lat": "53.17734",
    "lng": "5.8037"
  },
  {
    "country": "NL",
    "name": "Goudswaard",
    "lat": "51.79417",
    "lng": "4.27639"
  },
  {
    "country": "NL",
    "name": "Gouderak",
    "lat": "51.98417",
    "lng": "4.67778"
  },
  {
    "country": "NL",
    "name": "Gouda",
    "lat": "52.01667",
    "lng": "4.70833"
  },
  {
    "country": "NL",
    "name": "Gorssel",
    "lat": "52.20167",
    "lng": "6.20139"
  },
  {
    "country": "NL",
    "name": "Gorredijk",
    "lat": "53.00659",
    "lng": "6.06402"
  },
  {
    "country": "NL",
    "name": "Gorinchem",
    "lat": "51.83652",
    "lng": "4.97243"
  },
  {
    "country": "NL",
    "name": "Goor",
    "lat": "52.23333",
    "lng": "6.58611"
  },
  {
    "country": "NL",
    "name": "Goirle",
    "lat": "51.52083",
    "lng": "5.06667"
  },
  {
    "country": "NL",
    "name": "Goes",
    "lat": "51.50417",
    "lng": "3.88889"
  },
  {
    "country": "NL",
    "name": "Goedereede",
    "lat": "51.8175",
    "lng": "3.98056"
  },
  {
    "country": "NL",
    "name": "Glimmen",
    "lat": "53.13917",
    "lng": "6.62917"
  },
  {
    "country": "NL",
    "name": "Ginneken",
    "lat": "51.56593",
    "lng": "4.7931"
  },
  {
    "country": "NL",
    "name": "Gilze",
    "lat": "51.54417",
    "lng": "4.94028"
  },
  {
    "country": "NL",
    "name": "Giethoorn",
    "lat": "52.74",
    "lng": "6.07917"
  },
  {
    "country": "NL",
    "name": "Gieten",
    "lat": "53.005",
    "lng": "6.76389"
  },
  {
    "country": "NL",
    "name": "Giessendam",
    "lat": "51.83257",
    "lng": "4.83583"
  },
  {
    "country": "NL",
    "name": "Giessenburg",
    "lat": "51.85083",
    "lng": "4.89028"
  },
  {
    "country": "NL",
    "name": "Giessen",
    "lat": "51.79",
    "lng": "5.03056"
  },
  {
    "country": "NL",
    "name": "Giesbeek",
    "lat": "51.99333",
    "lng": "6.06667"
  },
  {
    "country": "NL",
    "name": "Gytsjerk",
    "lat": "53.24293",
    "lng": "5.89502"
  },
  {
    "country": "NL",
    "name": "Gerwen",
    "lat": "51.49",
    "lng": "5.5625"
  },
  {
    "country": "NL",
    "name": "Genoenhuis",
    "lat": "51.40917",
    "lng": "5.53889"
  },
  {
    "country": "NL",
    "name": "Gennep",
    "lat": "51.69833",
    "lng": "5.97361"
  },
  {
    "country": "NL",
    "name": "Gendt",
    "lat": "51.8775",
    "lng": "5.97083"
  },
  {
    "country": "NL",
    "name": "Gendringen",
    "lat": "51.87333",
    "lng": "6.37639"
  },
  {
    "country": "NL",
    "name": "Genderen",
    "lat": "51.73583",
    "lng": "5.0875"
  },
  {
    "country": "NL",
    "name": "Gemonde",
    "lat": "51.61833",
    "lng": "5.35694"
  },
  {
    "country": "NL",
    "name": "Gemert",
    "lat": "51.55583",
    "lng": "5.69028"
  },
  {
    "country": "NL",
    "name": "Geleen",
    "lat": "50.97417",
    "lng": "5.82917"
  },
  {
    "country": "NL",
    "name": "Geldrop",
    "lat": "51.42167",
    "lng": "5.55972"
  },
  {
    "country": "NL",
    "name": "Geldermalsen-West",
    "lat": "51.87968",
    "lng": "5.28015"
  },
  {
    "country": "NL",
    "name": "Geldermalsen",
    "lat": "51.88083",
    "lng": "5.28889"
  },
  {
    "country": "NL",
    "name": "Geitenkamp",
    "lat": "52.00379",
    "lng": "5.93862"
  },
  {
    "country": "NL",
    "name": "Geffen",
    "lat": "51.74",
    "lng": "5.46389"
  },
  {
    "country": "NL",
    "name": "Geertruidenberg",
    "lat": "51.70167",
    "lng": "4.85694"
  },
  {
    "country": "NL",
    "name": "Geenhoven",
    "lat": "51.35935",
    "lng": "5.46021"
  },
  {
    "country": "NL",
    "name": "Gasselternijveen",
    "lat": "52.98833",
    "lng": "6.85278"
  },
  {
    "country": "NL",
    "name": "Gasselte",
    "lat": "52.97167",
    "lng": "6.79444"
  },
  {
    "country": "NL",
    "name": "Garyp",
    "lat": "53.16667",
    "lng": "5.96667"
  },
  {
    "country": "NL",
    "name": "Garderen",
    "lat": "52.23083",
    "lng": "5.71389"
  },
  {
    "country": "NL",
    "name": "Gameren",
    "lat": "51.80083",
    "lng": "5.20417"
  },
  {
    "country": "NL",
    "name": "Gageldonk",
    "lat": "51.60167",
    "lng": "4.73889"
  },
  {
    "country": "NL",
    "name": "Frankhuis",
    "lat": "52.525",
    "lng": "6.06806"
  },
  {
    "country": "NL",
    "name": "Franeker",
    "lat": "53.18546",
    "lng": "5.54123"
  },
  {
    "country": "NL",
    "name": "Flevowijk",
    "lat": "52.54583",
    "lng": "5.91338"
  },
  {
    "country": "NL",
    "name": "Fijnaart",
    "lat": "51.6375",
    "lng": "4.46944"
  },
  {
    "country": "NL",
    "name": "Ferwert",
    "lat": "53.33784",
    "lng": "5.82533"
  },
  {
    "country": "NL",
    "name": "Feijenoord",
    "lat": "51.91169",
    "lng": "4.50645"
  },
  {
    "country": "NL",
    "name": "Farmsum",
    "lat": "53.32167",
    "lng": "6.92639"
  },
  {
    "country": "NL",
    "name": "Exloo",
    "lat": "52.8825",
    "lng": "6.86389"
  },
  {
    "country": "NL",
    "name": "Etten",
    "lat": "51.91667",
    "lng": "6.33611"
  },
  {
    "country": "NL",
    "name": "Essesteijn",
    "lat": "52.08534",
    "lng": "4.37263"
  },
  {
    "country": "NL",
    "name": "Esch",
    "lat": "51.61083",
    "lng": "5.29028"
  },
  {
    "country": "NL",
    "name": "Erp",
    "lat": "51.6",
    "lng": "5.60694"
  },
  {
    "country": "NL",
    "name": "Ermelo",
    "lat": "52.29833",
    "lng": "5.62222"
  },
  {
    "country": "NL",
    "name": "Epse",
    "lat": "52.225",
    "lng": "6.2"
  },
  {
    "country": "NL",
    "name": "Epe",
    "lat": "52.3475",
    "lng": "5.98333"
  },
  {
    "country": "NL",
    "name": "Enschot",
    "lat": "51.57846",
    "lng": "5.13885"
  },
  {
    "country": "NL",
    "name": "Enschede",
    "lat": "52.21833",
    "lng": "6.89583"
  },
  {
    "country": "NL",
    "name": "Ens",
    "lat": "52.63667",
    "lng": "5.82778"
  },
  {
    "country": "NL",
    "name": "Enkhuizen",
    "lat": "52.70333",
    "lng": "5.29167"
  },
  {
    "country": "NL",
    "name": "Emst",
    "lat": "52.31583",
    "lng": "5.97361"
  },
  {
    "country": "NL",
    "name": "Emmerschans",
    "lat": "52.80083",
    "lng": "6.93889"
  },
  {
    "country": "NL",
    "name": "Emmermeer",
    "lat": "52.80071",
    "lng": "6.89315"
  },
  {
    "country": "NL",
    "name": "Emmerhout",
    "lat": "52.78755",
    "lng": "6.93881"
  },
  {
    "country": "NL",
    "name": "Emmer-Erfscheidenveen",
    "lat": "52.80667",
    "lng": "6.98889"
  },
  {
    "country": "NL",
    "name": "Emmer-Compascuum",
    "lat": "52.81167",
    "lng": "7.04722"
  },
  {
    "country": "NL",
    "name": "Emmen",
    "lat": "52.77917",
    "lng": "6.90694"
  },
  {
    "country": "NL",
    "name": "Emmeloord",
    "lat": "52.71083",
    "lng": "5.74861"
  },
  {
    "country": "NL",
    "name": "Elst",
    "lat": "51.91917",
    "lng": "5.84167"
  },
  {
    "country": "NL",
    "name": "Elspeet",
    "lat": "52.29167",
    "lng": "5.78889"
  },
  {
    "country": "NL",
    "name": "Elsloo",
    "lat": "50.94917",
    "lng": "5.77083"
  },
  {
    "country": "NL",
    "name": "Elshout",
    "lat": "51.70083",
    "lng": "5.14167"
  },
  {
    "country": "NL",
    "name": "Ellecom",
    "lat": "52.0325",
    "lng": "6.0875"
  },
  {
    "country": "NL",
    "name": "Elden",
    "lat": "51.95833",
    "lng": "5.88194"
  },
  {
    "country": "NL",
    "name": "Elburg",
    "lat": "52.4475",
    "lng": "5.84306"
  },
  {
    "country": "NL",
    "name": "Ekenrooi",
    "lat": "51.39656",
    "lng": "5.48624"
  },
  {
    "country": "NL",
    "name": "Einighausen",
    "lat": "51.00167",
    "lng": "5.82778"
  },
  {
    "country": "NL",
    "name": "Eindhoven",
    "lat": "51.44083",
    "lng": "5.47778"
  },
  {
    "country": "NL",
    "name": "Eijsden",
    "lat": "50.78",
    "lng": "5.7177"
  },
  {
    "country": "NL",
    "name": "Eibergen",
    "lat": "52.1",
    "lng": "6.64861"
  },
  {
    "country": "NL",
    "name": "Egmond-Binnen",
    "lat": "52.59583",
    "lng": "4.65556"
  },
  {
    "country": "NL",
    "name": "Egmond aan Zee",
    "lat": "52.6204",
    "lng": "4.62705"
  },
  {
    "country": "NL",
    "name": "Egchel",
    "lat": "51.31417",
    "lng": "5.97222"
  },
  {
    "country": "NL",
    "name": "Eexta",
    "lat": "53.16386",
    "lng": "6.98344"
  },
  {
    "country": "NL",
    "name": "Eext",
    "lat": "53.0175",
    "lng": "6.73472"
  },
  {
    "country": "NL",
    "name": "Eersel",
    "lat": "51.3575",
    "lng": "5.31806"
  },
  {
    "country": "NL",
    "name": "Eerschot",
    "lat": "51.56833",
    "lng": "5.47361"
  },
  {
    "country": "NL",
    "name": "Eerde",
    "lat": "51.60417",
    "lng": "5.49861"
  },
  {
    "country": "NL",
    "name": "Eerbeek",
    "lat": "52.105",
    "lng": "6.05833"
  },
  {
    "country": "NL",
    "name": "Eenrum",
    "lat": "53.3625",
    "lng": "6.45833"
  },
  {
    "country": "NL",
    "name": "Eelde",
    "lat": "53.13583",
    "lng": "6.5625"
  },
  {
    "country": "NL",
    "name": "Eefde",
    "lat": "52.16667",
    "lng": "6.225"
  },
  {
    "country": "NL",
    "name": "Ederveen",
    "lat": "52.06333",
    "lng": "5.57778"
  },
  {
    "country": "NL",
    "name": "Ede",
    "lat": "52.03333",
    "lng": "5.65833"
  },
  {
    "country": "NL",
    "name": "Edam",
    "lat": "52.51215",
    "lng": "5.04805"
  },
  {
    "country": "NL",
    "name": "Eckart",
    "lat": "51.4732",
    "lng": "5.49449"
  },
  {
    "country": "NL",
    "name": "Echtenerbrug",
    "lat": "52.87141",
    "lng": "5.82147"
  },
  {
    "country": "NL",
    "name": "Dwingeloo",
    "lat": "52.83417",
    "lng": "6.36944"
  },
  {
    "country": "NL",
    "name": "Duizel",
    "lat": "51.36833",
    "lng": "5.29722"
  },
  {
    "country": "NL",
    "name": "Duivendrecht",
    "lat": "52.32941",
    "lng": "4.93964"
  },
  {
    "country": "NL",
    "name": "Duiven",
    "lat": "51.94667",
    "lng": "6.01389"
  },
  {
    "country": "NL",
    "name": "Duinzigt",
    "lat": "52.10485",
    "lng": "4.32494"
  },
  {
    "country": "NL",
    "name": "Duindorp",
    "lat": "52.09078",
    "lng": "4.26038"
  },
  {
    "country": "NL",
    "name": "Druten",
    "lat": "51.88833",
    "lng": "5.60556"
  },
  {
    "country": "NL",
    "name": "Drumpt",
    "lat": "51.897",
    "lng": "5.41043"
  },
  {
    "country": "NL",
    "name": "Dronten",
    "lat": "52.525",
    "lng": "5.71806"
  },
  {
    "country": "NL",
    "name": "Dronryp",
    "lat": "53.2",
    "lng": "5.65"
  },
  {
    "country": "NL",
    "name": "Drogeham",
    "lat": "53.20213",
    "lng": "6.11183"
  },
  {
    "country": "NL",
    "name": "Driemond",
    "lat": "52.30583",
    "lng": "5.01667"
  },
  {
    "country": "NL",
    "name": "Driemanspolder",
    "lat": "52.05176",
    "lng": "4.48504"
  },
  {
    "country": "NL",
    "name": "Driel",
    "lat": "51.95917",
    "lng": "5.81389"
  },
  {
    "country": "NL",
    "name": "Driehuizen",
    "lat": "52.20879",
    "lng": "5.94442"
  },
  {
    "country": "NL",
    "name": "Driebruggen",
    "lat": "52.04417",
    "lng": "4.8"
  },
  {
    "country": "NL",
    "name": "Driebergen-Rijsenburg",
    "lat": "52.05333",
    "lng": "5.28056"
  },
  {
    "country": "NL",
    "name": "Drachtstercompagnie",
    "lat": "53.13462",
    "lng": "6.14153"
  },
  {
    "country": "NL",
    "name": "Drachten",
    "lat": "53.11254",
    "lng": "6.0989"
  },
  {
    "country": "NL",
    "name": "Dorst",
    "lat": "51.59",
    "lng": "4.85694"
  },
  {
    "country": "NL",
    "name": "Dordrecht",
    "lat": "51.81",
    "lng": "4.67361"
  },
  {
    "country": "NL",
    "name": "Doorwerth",
    "lat": "51.97917",
    "lng": "5.79722"
  },
  {
    "country": "NL",
    "name": "Doornsteeg",
    "lat": "52.23",
    "lng": "5.45417"
  },
  {
    "country": "NL",
    "name": "Doornspijk",
    "lat": "52.41833",
    "lng": "5.81806"
  },
  {
    "country": "NL",
    "name": "Doornenburg",
    "lat": "51.89",
    "lng": "6"
  },
  {
    "country": "NL",
    "name": "Doorn",
    "lat": "52.03343",
    "lng": "5.34571"
  },
  {
    "country": "NL",
    "name": "Doonheide",
    "lat": "51.56667",
    "lng": "5.69444"
  },
  {
    "country": "NL",
    "name": "Donkerbroek",
    "lat": "53.01734",
    "lng": "6.23927"
  },
  {
    "country": "NL",
    "name": "Donk",
    "lat": "51.53843",
    "lng": "5.62914"
  },
  {
    "country": "NL",
    "name": "Dongen",
    "lat": "51.62667",
    "lng": "4.93889"
  },
  {
    "country": "NL",
    "name": "Dommelen",
    "lat": "51.34624",
    "lng": "5.43394"
  },
  {
    "country": "NL",
    "name": "Domburg",
    "lat": "51.56333",
    "lng": "3.49583"
  },
  {
    "country": "NL",
    "name": "Dokkum",
    "lat": "53.32224",
    "lng": "5.99697"
  },
  {
    "country": "NL",
    "name": "Doetinchem",
    "lat": "51.965",
    "lng": "6.28889"
  },
  {
    "country": "NL",
    "name": "Doesburg",
    "lat": "52.06667",
    "lng": "5.61667"
  },
  {
    "country": "NL",
    "name": "Doesburg",
    "lat": "52.0125",
    "lng": "6.13889"
  },
  {
    "country": "NL",
    "name": "Doenrade",
    "lat": "50.9675",
    "lng": "5.90694"
  },
  {
    "country": "NL",
    "name": "Dirksland",
    "lat": "51.74917",
    "lng": "4.1"
  },
  {
    "country": "NL",
    "name": "Dirkshorn",
    "lat": "52.75",
    "lng": "4.775"
  },
  {
    "country": "NL",
    "name": "Dinteloord",
    "lat": "51.635",
    "lng": "4.36944"
  },
  {
    "country": "NL",
    "name": "Diever",
    "lat": "52.85417",
    "lng": "6.31806"
  },
  {
    "country": "NL",
    "name": "Diessen",
    "lat": "51.47583",
    "lng": "5.175"
  },
  {
    "country": "NL",
    "name": "Dieren",
    "lat": "52.0525",
    "lng": "6.1"
  },
  {
    "country": "NL",
    "name": "Diepenheim",
    "lat": "52.2",
    "lng": "6.55556"
  },
  {
    "country": "NL",
    "name": "Diemen",
    "lat": "52.33964",
    "lng": "4.96256"
  },
  {
    "country": "NL",
    "name": "De Wijk",
    "lat": "52.67333",
    "lng": "6.29028"
  },
  {
    "country": "NL",
    "name": "De Wijert",
    "lat": "53.1945",
    "lng": "6.57117"
  },
  {
    "country": "NL",
    "name": "Deventer",
    "lat": "52.255",
    "lng": "6.16389"
  },
  {
    "country": "NL",
    "name": "Deuteren",
    "lat": "51.68667",
    "lng": "5.26667"
  },
  {
    "country": "NL",
    "name": "De Uithof",
    "lat": "52.08526",
    "lng": "5.17456"
  },
  {
    "country": "NL",
    "name": "De Rompert",
    "lat": "51.71667",
    "lng": "5.31667"
  },
  {
    "country": "NL",
    "name": "De Rijp",
    "lat": "52.55667",
    "lng": "4.84583"
  },
  {
    "country": "NL",
    "name": "De Reit",
    "lat": "51.56038",
    "lng": "5.04932"
  },
  {
    "country": "NL",
    "name": "De Peulen",
    "lat": "51.82362",
    "lng": "4.82165"
  },
  {
    "country": "NL",
    "name": "De Noord",
    "lat": "52.7075",
    "lng": "4.85139"
  },
  {
    "country": "NL",
    "name": "Den Oever",
    "lat": "52.93353",
    "lng": "5.03079"
  },
  {
    "country": "NL",
    "name": "Den Helder",
    "lat": "52.95988",
    "lng": "4.75933"
  },
  {
    "country": "NL",
    "name": "Den Ham",
    "lat": "52.46583",
    "lng": "6.49583"
  },
  {
    "country": "NL",
    "name": "Den Dungen",
    "lat": "51.665",
    "lng": "5.37222"
  },
  {
    "country": "NL",
    "name": "Den Burg",
    "lat": "53.05417",
    "lng": "4.79722"
  },
  {
    "country": "NL",
    "name": "De Mheen",
    "lat": "52.21954",
    "lng": "5.99141"
  },
  {
    "country": "NL",
    "name": "De Maer",
    "lat": "52.51901",
    "lng": "4.68171"
  },
  {
    "country": "NL",
    "name": "De Loo",
    "lat": "52.67167",
    "lng": "6.73967"
  },
  {
    "country": "NL",
    "name": "De Lier",
    "lat": "51.975",
    "lng": "4.24861"
  },
  {
    "country": "NL",
    "name": "Delfzijl",
    "lat": "53.33",
    "lng": "6.91806"
  },
  {
    "country": "NL",
    "name": "Delft",
    "lat": "52.00667",
    "lng": "4.35556"
  },
  {
    "country": "NL",
    "name": "Delfshaven",
    "lat": "51.90488",
    "lng": "4.45315"
  },
  {
    "country": "NL",
    "name": "Delden",
    "lat": "52.26",
    "lng": "6.71111"
  },
  {
    "country": "NL",
    "name": "De Kruiskamp",
    "lat": "51.69978",
    "lng": "5.26032"
  },
  {
    "country": "NL",
    "name": "De Koog",
    "lat": "53.0975",
    "lng": "4.76111"
  },
  {
    "country": "NL",
    "name": "De Kieviet",
    "lat": "52.12333",
    "lng": "4.35839"
  },
  {
    "country": "NL",
    "name": "Deil",
    "lat": "51.88417",
    "lng": "5.24306"
  },
  {
    "country": "NL",
    "name": "De Hoven",
    "lat": "52.24901",
    "lng": "6.14367"
  },
  {
    "country": "NL",
    "name": "De Heeg",
    "lat": "50.82454",
    "lng": "5.72309"
  },
  {
    "country": "NL",
    "name": "De Hagen",
    "lat": "51.99381",
    "lng": "5.10263"
  },
  {
    "country": "NL",
    "name": "De Greiden",
    "lat": "52.9496",
    "lng": "5.91366"
  },
  {
    "country": "NL",
    "name": "De Goorn",
    "lat": "52.62583",
    "lng": "4.94722"
  },
  {
    "country": "NL",
    "name": "De Glip",
    "lat": "52.33083",
    "lng": "4.61111"
  },
  {
    "country": "NL",
    "name": "Deest",
    "lat": "51.89",
    "lng": "5.66667"
  },
  {
    "country": "NL",
    "name": "De Drait",
    "lat": "53.09743",
    "lng": "6.06791"
  },
  {
    "country": "NL",
    "name": "De Doornakkers",
    "lat": "51.43844",
    "lng": "5.50887"
  },
  {
    "country": "NL",
    "name": "De Domp",
    "lat": "53.03113",
    "lng": "5.67716"
  },
  {
    "country": "NL",
    "name": "De Blaak",
    "lat": "51.54626",
    "lng": "5.04465"
  },
  {
    "country": "NL",
    "name": "De Bilt",
    "lat": "52.11",
    "lng": "5.18056"
  },
  {
    "country": "NL",
    "name": "Dauwendaele",
    "lat": "51.49299",
    "lng": "3.62624"
  },
  {
    "country": "NL",
    "name": "Damwâld",
    "lat": "53.29046",
    "lng": "5.99785"
  },
  {
    "country": "NL",
    "name": "Dalfsen",
    "lat": "52.51167",
    "lng": "6.25694"
  },
  {
    "country": "NL",
    "name": "Dalen",
    "lat": "52.69917",
    "lng": "6.75556"
  },
  {
    "country": "NL",
    "name": "Culemborg",
    "lat": "51.955",
    "lng": "5.22778"
  },
  {
    "country": "NL",
    "name": "Cuijk",
    "lat": "51.73083",
    "lng": "5.87917"
  },
  {
    "country": "NL",
    "name": "Cranendonck",
    "lat": "51.30417",
    "lng": "5.58889"
  },
  {
    "country": "NL",
    "name": "Cothen",
    "lat": "51.99667",
    "lng": "5.30833"
  },
  {
    "country": "NL",
    "name": "Commandeurs",
    "lat": "52.50902",
    "lng": "4.65843"
  },
  {
    "country": "NL",
    "name": "Colijnsplaat",
    "lat": "51.59917",
    "lng": "3.84861"
  },
  {
    "country": "NL",
    "name": "Coevorden",
    "lat": "52.66103",
    "lng": "6.74046"
  },
  {
    "country": "NL",
    "name": "Coevering",
    "lat": "51.41742",
    "lng": "5.57463"
  },
  {
    "country": "NL",
    "name": "Coendersborg",
    "lat": "53.1941",
    "lng": "6.58944"
  },
  {
    "country": "NL",
    "name": "Chaam",
    "lat": "51.50583",
    "lng": "4.86111"
  },
  {
    "country": "NL",
    "name": "Castricum",
    "lat": "52.54833",
    "lng": "4.66944"
  },
  {
    "country": "NL",
    "name": "Carnisse",
    "lat": "51.88932",
    "lng": "4.47758"
  },
  {
    "country": "NL",
    "name": "Capelle-West",
    "lat": "51.91667",
    "lng": "4.56667"
  },
  {
    "country": "NL",
    "name": "Capelle aan den IJssel",
    "lat": "51.92917",
    "lng": "4.57778"
  },
  {
    "country": "NL",
    "name": "Callantsoog",
    "lat": "52.84",
    "lng": "4.69583"
  },
  {
    "country": "NL",
    "name": "Bussum",
    "lat": "52.27333",
    "lng": "5.16111"
  },
  {
    "country": "NL",
    "name": "Bunschoten",
    "lat": "52.24304",
    "lng": "5.37884"
  },
  {
    "country": "NL",
    "name": "Bunnik",
    "lat": "52.06667",
    "lng": "5.19861"
  },
  {
    "country": "NL",
    "name": "Bunde",
    "lat": "50.89667",
    "lng": "5.73194"
  },
  {
    "country": "NL",
    "name": "Buitenpost",
    "lat": "53.25166",
    "lng": "6.14483"
  },
  {
    "country": "NL",
    "name": "Budschop",
    "lat": "51.28511",
    "lng": "5.75898"
  },
  {
    "country": "NL",
    "name": "Budel-Schoot",
    "lat": "51.2475",
    "lng": "5.56528"
  },
  {
    "country": "NL",
    "name": "Budel-Dorplein",
    "lat": "51.23667",
    "lng": "5.5875"
  },
  {
    "country": "NL",
    "name": "Budel",
    "lat": "51.27167",
    "lng": "5.575"
  },
  {
    "country": "NL",
    "name": "Buchten",
    "lat": "51.04333",
    "lng": "5.80972"
  },
  {
    "country": "NL",
    "name": "Brunssum",
    "lat": "50.94667",
    "lng": "5.97083"
  },
  {
    "country": "NL",
    "name": "Brunnepe",
    "lat": "52.56185",
    "lng": "5.90343"
  },
  {
    "country": "NL",
    "name": "Brummen",
    "lat": "52.09",
    "lng": "6.15556"
  },
  {
    "country": "NL",
    "name": "Brukske",
    "lat": "51.52101",
    "lng": "5.9927"
  },
  {
    "country": "NL",
    "name": "Bruinisse",
    "lat": "51.66167",
    "lng": "4.09444"
  },
  {
    "country": "NL",
    "name": "Bruchem",
    "lat": "51.78667",
    "lng": "5.23611"
  },
  {
    "country": "NL",
    "name": "Brouwershaven",
    "lat": "51.72667",
    "lng": "3.9125"
  },
  {
    "country": "NL",
    "name": "Broeksterwâld",
    "lat": "53.27466",
    "lng": "5.99648"
  },
  {
    "country": "NL",
    "name": "Broeksittard",
    "lat": "51.0029",
    "lng": "5.89511"
  },
  {
    "country": "NL",
    "name": "Broek op Langedijk",
    "lat": "52.67417",
    "lng": "4.80556"
  },
  {
    "country": "NL",
    "name": "Broek in Waterland",
    "lat": "52.43417",
    "lng": "4.99583"
  },
  {
    "country": "NL",
    "name": "Broekhoven",
    "lat": "51.54801",
    "lng": "5.09175"
  },
  {
    "country": "NL",
    "name": "Broekhem",
    "lat": "50.87119",
    "lng": "5.82069"
  },
  {
    "country": "NL",
    "name": "Brinkhorst",
    "lat": "52.21302",
    "lng": "5.95167"
  },
  {
    "country": "NL",
    "name": "Brielle",
    "lat": "51.90167",
    "lng": "4.1625"
  },
  {
    "country": "NL",
    "name": "Breukelen",
    "lat": "52.17417",
    "lng": "5.00139"
  },
  {
    "country": "NL",
    "name": "Breugel",
    "lat": "51.5175",
    "lng": "5.51111"
  },
  {
    "country": "NL",
    "name": "Breskens",
    "lat": "51.39583",
    "lng": "3.55556"
  },
  {
    "country": "NL",
    "name": "Breezand",
    "lat": "52.89",
    "lng": "4.80417"
  },
  {
    "country": "NL",
    "name": "Bredeweg",
    "lat": "51.76019",
    "lng": "5.94189"
  },
  {
    "country": "NL",
    "name": "Bredevoort",
    "lat": "51.94167",
    "lng": "6.62083"
  },
  {
    "country": "NL",
    "name": "Breda",
    "lat": "51.58656",
    "lng": "4.77596"
  },
  {
    "country": "NL",
    "name": "Brand",
    "lat": "51.45839",
    "lng": "5.62427"
  },
  {
    "country": "NL",
    "name": "Brakkenstein",
    "lat": "51.81324",
    "lng": "5.86539"
  },
  {
    "country": "NL",
    "name": "Brakel",
    "lat": "51.8175",
    "lng": "5.09028"
  },
  {
    "country": "NL",
    "name": "Brachterbeek",
    "lat": "51.14694",
    "lng": "5.90446"
  },
  {
    "country": "NL",
    "name": "Brabander",
    "lat": "51.53583",
    "lng": "5.96806"
  },
  {
    "country": "NL",
    "name": "Boxtel",
    "lat": "51.59083",
    "lng": "5.32917"
  },
  {
    "country": "NL",
    "name": "Boxmeer",
    "lat": "51.64667",
    "lng": "5.94722"
  },
  {
    "country": "NL",
    "name": "Boven-Hardinxveld",
    "lat": "51.82333",
    "lng": "4.88194"
  },
  {
    "country": "NL",
    "name": "Bosschenhoofd",
    "lat": "51.56083",
    "lng": "4.54028"
  },
  {
    "country": "NL",
    "name": "Boskoop",
    "lat": "52.075",
    "lng": "4.65556"
  },
  {
    "country": "NL",
    "name": "Boskamp",
    "lat": "52.33083",
    "lng": "6.12778"
  },
  {
    "country": "NL",
    "name": "Bosch en Duin",
    "lat": "52.11667",
    "lng": "5.24167"
  },
  {
    "country": "NL",
    "name": "Borssele",
    "lat": "51.42333",
    "lng": "3.73472"
  },
  {
    "country": "NL",
    "name": "Borne",
    "lat": "52.30136",
    "lng": "6.7482"
  },
  {
    "country": "NL",
    "name": "Born",
    "lat": "51.03167",
    "lng": "5.80972"
  },
  {
    "country": "NL",
    "name": "Borgharen",
    "lat": "50.8775",
    "lng": "5.6875"
  },
  {
    "country": "NL",
    "name": "Borger",
    "lat": "52.92333",
    "lng": "6.79306"
  },
  {
    "country": "NL",
    "name": "Borgele",
    "lat": "52.2763",
    "lng": "6.14926"
  },
  {
    "country": "NL",
    "name": "Borculo",
    "lat": "52.11583",
    "lng": "6.52222"
  },
  {
    "country": "NL",
    "name": "Boornbergum",
    "lat": "53.08284",
    "lng": "6.04578"
  },
  {
    "country": "NL",
    "name": "Bolsward",
    "lat": "53.06555",
    "lng": "5.53176"
  },
  {
    "country": "NL",
    "name": "Bolnes",
    "lat": "51.895",
    "lng": "4.57917"
  },
  {
    "country": "NL",
    "name": "Boekel",
    "lat": "51.60333",
    "lng": "5.675"
  },
  {
    "country": "NL",
    "name": "Bodegraven",
    "lat": "52.0825",
    "lng": "4.75"
  },
  {
    "country": "NL",
    "name": "Bocholtz",
    "lat": "50.81833",
    "lng": "6.00556"
  },
  {
    "country": "NL",
    "name": "Blokzijl",
    "lat": "52.72667",
    "lng": "5.96111"
  },
  {
    "country": "NL",
    "name": "Bloemhof",
    "lat": "51.89723",
    "lng": "4.49943"
  },
  {
    "country": "NL",
    "name": "Bloemendaal",
    "lat": "52.02878",
    "lng": "4.6944"
  },
  {
    "country": "NL",
    "name": "Bloemendaal",
    "lat": "52.4025",
    "lng": "4.62222"
  },
  {
    "country": "NL",
    "name": "Blitterswijck",
    "lat": "51.53083",
    "lng": "6.10833"
  },
  {
    "country": "NL",
    "name": "Blijham",
    "lat": "53.10917",
    "lng": "7.07639"
  },
  {
    "country": "NL",
    "name": "Bleskensgraaf",
    "lat": "51.8725",
    "lng": "4.78333"
  },
  {
    "country": "NL",
    "name": "Bleiswijk",
    "lat": "52.01083",
    "lng": "4.53194"
  },
  {
    "country": "NL",
    "name": "Bleijerheide",
    "lat": "50.85538",
    "lng": "6.06789"
  },
  {
    "country": "NL",
    "name": "Blaricum",
    "lat": "52.2725",
    "lng": "5.24167"
  },
  {
    "country": "NL",
    "name": "Bladel",
    "lat": "51.36833",
    "lng": "5.22083"
  },
  {
    "country": "NL",
    "name": "Blaarthem",
    "lat": "51.42501",
    "lng": "5.45784"
  },
  {
    "country": "NL",
    "name": "Bitswijk",
    "lat": "51.6687",
    "lng": "5.60921"
  },
  {
    "country": "NL",
    "name": "Burdaard",
    "lat": "53.29421",
    "lng": "5.87897"
  },
  {
    "country": "NL",
    "name": "Binnenhof",
    "lat": "52.16418",
    "lng": "4.53644"
  },
  {
    "country": "NL",
    "name": "Bilgaard",
    "lat": "53.21551",
    "lng": "5.79574"
  },
  {
    "country": "NL",
    "name": "Bijvanck",
    "lat": "52.28585",
    "lng": "5.26534"
  },
  {
    "country": "NL",
    "name": "Biesland",
    "lat": "50.8411",
    "lng": "5.67573"
  },
  {
    "country": "NL",
    "name": "Biesdonk",
    "lat": "51.60613",
    "lng": "4.78515"
  },
  {
    "country": "NL",
    "name": "Biddinghuizen",
    "lat": "52.455",
    "lng": "5.69306"
  },
  {
    "country": "NL",
    "name": "Beverwijk",
    "lat": "52.48333",
    "lng": "4.65694"
  },
  {
    "country": "NL",
    "name": "Beusichem",
    "lat": "51.95",
    "lng": "5.29167"
  },
  {
    "country": "NL",
    "name": "Beuningen",
    "lat": "51.86083",
    "lng": "5.76667"
  },
  {
    "country": "NL",
    "name": "Best",
    "lat": "51.5075",
    "lng": "5.39028"
  },
  {
    "country": "NL",
    "name": "Besoijen",
    "lat": "51.68333",
    "lng": "5.05"
  },
  {
    "country": "NL",
    "name": "Berltsum",
    "lat": "53.2437",
    "lng": "5.65101"
  },
  {
    "country": "NL",
    "name": "Berlicum",
    "lat": "51.6775",
    "lng": "5.4"
  },
  {
    "country": "NL",
    "name": "Berkum",
    "lat": "52.52395",
    "lng": "6.13655"
  },
  {
    "country": "NL",
    "name": "Berkhout",
    "lat": "52.64083",
    "lng": "5.00139"
  },
  {
    "country": "NL",
    "name": "Berkenwoude",
    "lat": "51.945",
    "lng": "4.70694"
  },
  {
    "country": "NL",
    "name": "Beringe",
    "lat": "51.33667",
    "lng": "5.94861"
  },
  {
    "country": "NL",
    "name": "Burgum",
    "lat": "53.19243",
    "lng": "5.99009"
  },
  {
    "country": "NL",
    "name": "Bergstoep",
    "lat": "51.9225",
    "lng": "4.78472"
  },
  {
    "country": "NL",
    "name": "Bergschenhoek",
    "lat": "51.99",
    "lng": "4.49861"
  },
  {
    "country": "NL",
    "name": "Berghem",
    "lat": "51.76991",
    "lng": "5.56827"
  },
  {
    "country": "NL",
    "name": "Bergharen",
    "lat": "51.85083",
    "lng": "5.66944"
  },
  {
    "country": "NL",
    "name": "Bergeijk",
    "lat": "51.31917",
    "lng": "5.35833"
  },
  {
    "country": "NL",
    "name": "Bergen op Zoom",
    "lat": "51.495",
    "lng": "4.29167"
  },
  {
    "country": "NL",
    "name": "Berg en Dal",
    "lat": "51.82167",
    "lng": "5.91667"
  },
  {
    "country": "NL",
    "name": "Berg en Bos",
    "lat": "52.22009",
    "lng": "5.9334"
  },
  {
    "country": "NL",
    "name": "Bergen",
    "lat": "52.66917",
    "lng": "4.70417"
  },
  {
    "country": "NL",
    "name": "Berg",
    "lat": "51.00417",
    "lng": "5.77083"
  },
  {
    "country": "NL",
    "name": "Berg",
    "lat": "50.86167",
    "lng": "5.78333"
  },
  {
    "country": "NL",
    "name": "Benthuizen",
    "lat": "52.0775",
    "lng": "4.54444"
  },
  {
    "country": "NL",
    "name": "Bennekom",
    "lat": "51.99833",
    "lng": "5.67639"
  },
  {
    "country": "NL",
    "name": "Bennebroek",
    "lat": "52.32083",
    "lng": "4.59861"
  },
  {
    "country": "NL",
    "name": "Bemmel",
    "lat": "51.89167",
    "lng": "5.89861"
  },
  {
    "country": "NL",
    "name": "Beltrum",
    "lat": "52.06667",
    "lng": "6.56389"
  },
  {
    "country": "NL",
    "name": "Bellingwolde",
    "lat": "53.11583",
    "lng": "7.16528"
  },
  {
    "country": "NL",
    "name": "Belfort",
    "lat": "50.84698",
    "lng": "5.65991"
  },
  {
    "country": "NL",
    "name": "Belcrum",
    "lat": "51.59911",
    "lng": "4.76994"
  },
  {
    "country": "NL",
    "name": "Beilen",
    "lat": "52.86333",
    "lng": "6.51389"
  },
  {
    "country": "NL",
    "name": "Beetsterzwaag",
    "lat": "53.05914",
    "lng": "6.07711"
  },
  {
    "country": "NL",
    "name": "Beesel",
    "lat": "51.26833",
    "lng": "6.03889"
  },
  {
    "country": "NL",
    "name": "Beesd",
    "lat": "51.8875",
    "lng": "5.19167"
  },
  {
    "country": "NL",
    "name": "Beersdal",
    "lat": "50.90597",
    "lng": "5.9644"
  },
  {
    "country": "NL",
    "name": "Beers",
    "lat": "51.72583",
    "lng": "5.82778"
  },
  {
    "country": "NL",
    "name": "Beekbergen",
    "lat": "52.16",
    "lng": "5.96389"
  },
  {
    "country": "NL",
    "name": "Beek gem Montferland",
    "lat": "51.90667",
    "lng": "6.1875"
  },
  {
    "country": "NL",
    "name": "Beek",
    "lat": "51.5289",
    "lng": "5.63382"
  },
  {
    "country": "NL",
    "name": "Beek",
    "lat": "50.94083",
    "lng": "5.79722"
  },
  {
    "country": "NL",
    "name": "Beegden",
    "lat": "51.18917",
    "lng": "5.91944"
  },
  {
    "country": "NL",
    "name": "Bedum",
    "lat": "53.30083",
    "lng": "6.60278"
  },
  {
    "country": "NL",
    "name": "Bavel",
    "lat": "51.56583",
    "lng": "4.83056"
  },
  {
    "country": "NL",
    "name": "Barneveld",
    "lat": "52.14",
    "lng": "5.58472"
  },
  {
    "country": "NL",
    "name": "Barger-Oosterveld",
    "lat": "52.77",
    "lng": "6.95833"
  },
  {
    "country": "NL",
    "name": "Bargeres",
    "lat": "52.76152",
    "lng": "6.88145"
  },
  {
    "country": "NL",
    "name": "Barendrecht",
    "lat": "51.85667",
    "lng": "4.53472"
  },
  {
    "country": "NL",
    "name": "Banholt",
    "lat": "50.79",
    "lng": "5.80833"
  },
  {
    "country": "NL",
    "name": "Bangert",
    "lat": "52.73582",
    "lng": "5.1801"
  },
  {
    "country": "NL",
    "name": "Ballast",
    "lat": "52.67218",
    "lng": "6.73299"
  },
  {
    "country": "NL",
    "name": "Balk",
    "lat": "52.89756",
    "lng": "5.57964"
  },
  {
    "country": "NL",
    "name": "Bakkeveen",
    "lat": "53.08072",
    "lng": "6.25671"
  },
  {
    "country": "NL",
    "name": "Bakhuizen",
    "lat": "52.86975",
    "lng": "5.45926"
  },
  {
    "country": "NL",
    "name": "Bakenberg",
    "lat": "52.00511",
    "lng": "5.8771"
  },
  {
    "country": "NL",
    "name": "Bakel",
    "lat": "51.50333",
    "lng": "5.74028"
  },
  {
    "country": "NL",
    "name": "Baflo",
    "lat": "53.3625",
    "lng": "6.51389"
  },
  {
    "country": "NL",
    "name": "Babberich",
    "lat": "51.9075",
    "lng": "6.11111"
  },
  {
    "country": "NL",
    "name": "Baarn",
    "lat": "52.21167",
    "lng": "5.2875"
  },
  {
    "country": "NL",
    "name": "Baarlo",
    "lat": "51.33083",
    "lng": "6.09444"
  },
  {
    "country": "NL",
    "name": "Baarle-Nassau",
    "lat": "51.4475",
    "lng": "4.92917"
  },
  {
    "country": "NL",
    "name": "Baardwijk",
    "lat": "51.69246",
    "lng": "5.09628"
  },
  {
    "country": "NL",
    "name": "Baambrugge",
    "lat": "52.24583",
    "lng": "4.98889"
  },
  {
    "country": "NL",
    "name": "Baalder",
    "lat": "52.58579",
    "lng": "6.65299"
  },
  {
    "country": "NL",
    "name": "Axel",
    "lat": "51.26667",
    "lng": "3.90833"
  },
  {
    "country": "NL",
    "name": "Avenhorn",
    "lat": "52.6175",
    "lng": "4.95139"
  },
  {
    "country": "NL",
    "name": "Austerlitz",
    "lat": "52.08",
    "lng": "5.31528"
  },
  {
    "country": "NL",
    "name": "Augustinusga",
    "lat": "53.21785",
    "lng": "6.1617"
  },
  {
    "country": "NL",
    "name": "Asten",
    "lat": "51.40417",
    "lng": "5.74861"
  },
  {
    "country": "NL",
    "name": "Assen",
    "lat": "52.99667",
    "lng": "6.5625"
  },
  {
    "country": "NL",
    "name": "Arnhem",
    "lat": "51.98",
    "lng": "5.91111"
  },
  {
    "country": "NL",
    "name": "Arnemuiden",
    "lat": "51.50167",
    "lng": "3.675"
  },
  {
    "country": "NL",
    "name": "Arkel",
    "lat": "51.86417",
    "lng": "4.99444"
  },
  {
    "country": "NL",
    "name": "Arcen",
    "lat": "51.47667",
    "lng": "6.18056"
  },
  {
    "country": "NL",
    "name": "Appingedam",
    "lat": "53.32167",
    "lng": "6.85833"
  },
  {
    "country": "NL",
    "name": "Appelscha",
    "lat": "52.95526",
    "lng": "6.35053"
  },
  {
    "country": "NL",
    "name": "Apeldoorn",
    "lat": "52.21",
    "lng": "5.96944"
  },
  {
    "country": "NL",
    "name": "Annen",
    "lat": "53.0575",
    "lng": "6.71944"
  },
  {
    "country": "NL",
    "name": "Anklaar",
    "lat": "52.23111",
    "lng": "5.98497"
  },
  {
    "country": "NL",
    "name": "Ankeveense Rade",
    "lat": "52.25891",
    "lng": "5.1016"
  },
  {
    "country": "NL",
    "name": "Angerlo",
    "lat": "51.99583",
    "lng": "6.13472"
  },
  {
    "country": "NL",
    "name": "Angeren",
    "lat": "51.91583",
    "lng": "5.95833"
  },
  {
    "country": "NL",
    "name": "Angelslo",
    "lat": "52.7809",
    "lng": "6.92645"
  },
  {
    "country": "NL",
    "name": "Andelst",
    "lat": "51.90833",
    "lng": "5.72917"
  },
  {
    "country": "NL",
    "name": "Amsterdam",
    "lat": "52.37403",
    "lng": "4.88969"
  },
  {
    "country": "NL",
    "name": "Amstenrade",
    "lat": "50.93917",
    "lng": "5.92361"
  },
  {
    "country": "NL",
    "name": "Amstelveen",
    "lat": "52.30083",
    "lng": "4.86389"
  },
  {
    "country": "NL",
    "name": "Ammerzoden",
    "lat": "51.74917",
    "lng": "5.22083"
  },
  {
    "country": "NL",
    "name": "Ammerstol",
    "lat": "51.9275",
    "lng": "4.80833"
  },
  {
    "country": "NL",
    "name": "Amersfoort",
    "lat": "52.155",
    "lng": "5.3875"
  },
  {
    "country": "NL",
    "name": "Amerongen",
    "lat": "52.0025",
    "lng": "5.45972"
  },
  {
    "country": "NL",
    "name": "America",
    "lat": "51.43667",
    "lng": "5.97917"
  },
  {
    "country": "NL",
    "name": "Amby",
    "lat": "50.86215",
    "lng": "5.73226"
  },
  {
    "country": "NL",
    "name": "Alverna",
    "lat": "51.80417",
    "lng": "5.75972"
  },
  {
    "country": "NL",
    "name": "Alphen aan den Rijn",
    "lat": "52.12917",
    "lng": "4.65546"
  },
  {
    "country": "NL",
    "name": "Alphen",
    "lat": "51.48167",
    "lng": "4.95833"
  },
  {
    "country": "NL",
    "name": "Almkerk",
    "lat": "51.77083",
    "lng": "4.95972"
  },
  {
    "country": "NL",
    "name": "Almere Stad",
    "lat": "52.37025",
    "lng": "5.21413"
  },
  {
    "country": "NL",
    "name": "Almelo",
    "lat": "52.35667",
    "lng": "6.6625"
  },
  {
    "country": "NL",
    "name": "Alkmaar",
    "lat": "52.63167",
    "lng": "4.74861"
  },
  {
    "country": "NL",
    "name": "Alblasserdam",
    "lat": "51.86583",
    "lng": "4.66111"
  },
  {
    "country": "NL",
    "name": "Akkrum",
    "lat": "53.05024",
    "lng": "5.83087"
  },
  {
    "country": "NL",
    "name": "Akert",
    "lat": "51.41407",
    "lng": "5.5596"
  },
  {
    "country": "NL",
    "name": "Afferden",
    "lat": "51.88",
    "lng": "5.63472"
  },
  {
    "country": "NL",
    "name": "Aduard",
    "lat": "53.25667",
    "lng": "6.45972"
  },
  {
    "country": "NL",
    "name": "Adegeest",
    "lat": "52.13621",
    "lng": "4.45249"
  },
  {
    "country": "NL",
    "name": "Abdissenbosch",
    "lat": "50.91667",
    "lng": "6.03333"
  },
  {
    "country": "NL",
    "name": "Abcoven",
    "lat": "51.5275",
    "lng": "5.08333"
  },
  {
    "country": "NL",
    "name": "Abcoude",
    "lat": "52.2725",
    "lng": "4.96944"
  },
  {
    "country": "NL",
    "name": "Abbekerk",
    "lat": "52.73167",
    "lng": "5.01806"
  },
  {
    "country": "NL",
    "name": "Aardenburg",
    "lat": "51.27333",
    "lng": "3.44722"
  },
  {
    "country": "NL",
    "name": "Aalten",
    "lat": "51.925",
    "lng": "6.58056"
  },
  {
    "country": "NL",
    "name": "Aalst",
    "lat": "51.39667",
    "lng": "5.47778"
  },
  {
    "country": "NL",
    "name": "Aalst",
    "lat": "51.7825",
    "lng": "5.12778"
  },
  {
    "country": "NL",
    "name": "Aalsmeer",
    "lat": "52.25917",
    "lng": "4.75972"
  },
  {
    "country": "NL",
    "name": "Aalden",
    "lat": "52.79",
    "lng": "6.71806"
  },
  {
    "country": "NL",
    "name": "Aalburg",
    "lat": "51.75482",
    "lng": "5.13156"
  },
  {
    "country": "NL",
    "name": "Aagtekerke",
    "lat": "51.54667",
    "lng": "3.50972"
  },
  {
    "country": "NL",
    "name": "Camminghaburen",
    "lat": "53.20973",
    "lng": "5.84318"
  },
  {
    "country": "NL",
    "name": "Amsterdam-Zuidoost",
    "lat": "52.3075",
    "lng": "4.97222"
  },
  {
    "country": "NL",
    "name": "Zuid-Berghuizen",
    "lat": "52.30083",
    "lng": "6.93333"
  },
  {
    "country": "NL",
    "name": "Chevremont",
    "lat": "50.87554",
    "lng": "6.05981"
  },
  {
    "country": "NL",
    "name": "Welgelegen",
    "lat": "52.21397",
    "lng": "5.97643"
  },
  {
    "country": "NL",
    "name": "Matenveld",
    "lat": "52.18767",
    "lng": "5.99879"
  },
  {
    "country": "NL",
    "name": "Matenhoeve",
    "lat": "52.19056",
    "lng": "6.01338"
  },
  {
    "country": "NL",
    "name": "Matendonk",
    "lat": "52.19766",
    "lng": "6.01115"
  },
  {
    "country": "NL",
    "name": "Matenhorst",
    "lat": "52.20482",
    "lng": "5.99304"
  },
  {
    "country": "NL",
    "name": "Matendreef",
    "lat": "52.19993",
    "lng": "5.98592"
  },
  {
    "country": "NL",
    "name": "Matengaarde",
    "lat": "52.19793",
    "lng": "5.9957"
  },
  {
    "country": "NL",
    "name": "Rivierenkwartier",
    "lat": "52.18914",
    "lng": "5.97665"
  },
  {
    "country": "NL",
    "name": "Staatsliedenkwartier",
    "lat": "52.19951",
    "lng": "5.97691"
  },
  {
    "country": "NL",
    "name": "Brummelhof",
    "lat": "52.20503",
    "lng": "5.96789"
  },
  {
    "country": "NL",
    "name": "Vogelkwartier",
    "lat": "52.19777",
    "lng": "5.96721"
  },
  {
    "country": "NL",
    "name": "Componistenkwartier",
    "lat": "52.18977",
    "lng": "5.96609"
  },
  {
    "country": "NL",
    "name": "Woudhuis",
    "lat": "52.21323",
    "lng": "6.01124"
  },
  {
    "country": "NL",
    "name": "Sluisoord",
    "lat": "52.22291",
    "lng": "5.98145"
  },
  {
    "country": "NL",
    "name": "Sprenkelaar",
    "lat": "52.22512",
    "lng": "5.99922"
  },
  {
    "country": "NL",
    "name": "De Haven",
    "lat": "52.21045",
    "lng": "5.97407"
  },
  {
    "country": "NL",
    "name": "Binnenstad",
    "lat": "52.21304",
    "lng": "5.95957"
  },
  {
    "country": "NL",
    "name": "Sprengenweg-Noord",
    "lat": "52.21839",
    "lng": "5.95068"
  },
  {
    "country": "NL",
    "name": "Sprengenbos",
    "lat": "52.21902",
    "lng": "5.94163"
  },
  {
    "country": "NL",
    "name": "Spainkbos",
    "lat": "52.22228",
    "lng": "5.94738"
  },
  {
    "country": "NL",
    "name": "De Heeze",
    "lat": "52.20061",
    "lng": "5.95365"
  },
  {
    "country": "NL",
    "name": "Westenenk",
    "lat": "52.19624",
    "lng": "5.95656"
  },
  {
    "country": "NL",
    "name": "Winkewijert",
    "lat": "52.19082",
    "lng": "5.95794"
  },
  {
    "country": "NL",
    "name": "De Bouwhof",
    "lat": "52.18546",
    "lng": "5.94704"
  },
  {
    "country": "NL",
    "name": "Speelheide",
    "lat": "51.50607",
    "lng": "5.40519"
  },
  {
    "country": "NL",
    "name": "Salderes",
    "lat": "51.51505",
    "lng": "5.38991"
  },
  {
    "country": "NL",
    "name": "Jubbega",
    "lat": "53.00396",
    "lng": "6.12183"
  },
  {
    "country": "NL",
    "name": "Meerhoven",
    "lat": "51.44267",
    "lng": "5.41102"
  },
  {
    "country": "NL",
    "name": "Grasrijk",
    "lat": "51.43916",
    "lng": "5.41544"
  },
  {
    "country": "NL",
    "name": "Hoek",
    "lat": "53.20455",
    "lng": "5.80192"
  },
  {
    "country": "NL",
    "name": "De Knipe",
    "lat": "52.96829",
    "lng": "5.97116"
  },
  {
    "country": "NL",
    "name": "Lunetten",
    "lat": "52.06178",
    "lng": "5.13474"
  },
  {
    "country": "NL",
    "name": "Aarle-Rixtel",
    "lat": "51.50976",
    "lng": "5.63839"
  },
  {
    "country": "NL",
    "name": "Kelpen-Oler",
    "lat": "51.21817",
    "lng": "5.82602"
  },
  {
    "country": "NL",
    "name": "Muschberg en Geestenberg",
    "lat": "51.44384",
    "lng": "5.52329"
  },
  {
    "country": "NL",
    "name": "Villapark",
    "lat": "51.44144",
    "lng": "5.49385"
  },
  {
    "country": "NL",
    "name": "Lakerlopen",
    "lat": "51.43791",
    "lng": "5.50106"
  },
  {
    "country": "NL",
    "name": "Berkel en Rodenrijs",
    "lat": "51.99313",
    "lng": "4.47865"
  },
  {
    "country": "NL",
    "name": "Reitdiep",
    "lat": "53.24252",
    "lng": "6.51957"
  },
  {
    "country": "NL",
    "name": "Ypenburg",
    "lat": "52.04098",
    "lng": "4.36981"
  },
  {
    "country": "NL",
    "name": "Aldlân-Oost",
    "lat": "53.1886",
    "lng": "5.82825"
  },
  {
    "country": "NL",
    "name": "Oranjewijk",
    "lat": "52.04922",
    "lng": "4.65374"
  },
  {
    "country": "NL",
    "name": "Vondelwijk",
    "lat": "52.05497",
    "lng": "4.65314"
  },
  {
    "country": "NL",
    "name": "Groenswaard",
    "lat": "52.05154",
    "lng": "4.64541"
  },
  {
    "country": "NL",
    "name": "Randenbroek",
    "lat": "52.14863",
    "lng": "5.4012"
  },
  {
    "country": "NL",
    "name": "Corlaer",
    "lat": "52.21639",
    "lng": "5.46535"
  },
  {
    "country": "NL",
    "name": "Kapelle",
    "lat": "51.48627",
    "lng": "3.95804"
  },
  {
    "country": "NL",
    "name": "Hoogkamp",
    "lat": "51.9963",
    "lng": "5.88026"
  },
  {
    "country": "NL",
    "name": "Gulden Bodem",
    "lat": "51.99428",
    "lng": "5.8908"
  },
  {
    "country": "NL",
    "name": "Sterrenberg",
    "lat": "51.9935",
    "lng": "5.88387"
  },
  {
    "country": "NL",
    "name": "Burgemeesterswijk",
    "lat": "51.98943",
    "lng": "5.89597"
  },
  {
    "country": "NL",
    "name": "Kop van Zuid",
    "lat": "51.90553",
    "lng": "4.48706"
  },
  {
    "country": "NL",
    "name": "'s-Gravenland",
    "lat": "51.92336",
    "lng": "4.55315"
  },
  {
    "country": "NL",
    "name": "Spechtenkamp",
    "lat": "52.13926",
    "lng": "5.01758"
  },
  {
    "country": "NL",
    "name": "Besterd",
    "lat": "51.5638",
    "lng": "5.08658"
  },
  {
    "country": "NL",
    "name": "Wisselaar",
    "lat": "51.61285",
    "lng": "4.78444"
  },
  {
    "country": "NL",
    "name": "Waterdonken",
    "lat": "51.60959",
    "lng": "4.80452"
  },
  {
    "country": "NL",
    "name": "Hunnerberg",
    "lat": "51.84209",
    "lng": "5.87876"
  },
  {
    "country": "NL",
    "name": "Son en Breugel",
    "lat": "51.51654",
    "lng": "5.49608"
  },
  {
    "country": "NL",
    "name": "Marsdijk",
    "lat": "53.01766",
    "lng": "6.58527"
  },
  {
    "country": "NO",
    "name": "Vardø",
    "lat": "70.37048",
    "lng": "31.11066"
  },
  {
    "country": "NO",
    "name": "Vuonnabahta",
    "lat": "70.17278",
    "lng": "28.55598"
  },
  {
    "country": "NO",
    "name": "Vadsø",
    "lat": "70.07348",
    "lng": "29.74943"
  },
  {
    "country": "NO",
    "name": "Storslett",
    "lat": "69.76783",
    "lng": "21.02466"
  },
  {
    "country": "NO",
    "name": "Skjervøy",
    "lat": "70.03114",
    "lng": "20.97141"
  },
  {
    "country": "NO",
    "name": "Olderdalen",
    "lat": "69.60407",
    "lng": "20.53272"
  },
  {
    "country": "NO",
    "name": "Øksfjord",
    "lat": "70.23936",
    "lng": "22.3507"
  },
  {
    "country": "NO",
    "name": "Mehamn",
    "lat": "71.04137",
    "lng": "27.85133"
  },
  {
    "country": "NO",
    "name": "Lyngseidet",
    "lat": "69.57629",
    "lng": "20.21887"
  },
  {
    "country": "NO",
    "name": "Lakselv",
    "lat": "70.05133",
    "lng": "24.97182"
  },
  {
    "country": "NO",
    "name": "Kvalsund",
    "lat": "70.50271",
    "lng": "23.97974"
  },
  {
    "country": "NO",
    "name": "Kjøllefjord",
    "lat": "70.94574",
    "lng": "27.3465"
  },
  {
    "country": "NO",
    "name": "Kirkenes",
    "lat": "69.72706",
    "lng": "30.04578"
  },
  {
    "country": "NO",
    "name": "Kautokeino",
    "lat": "69.01247",
    "lng": "23.04116"
  },
  {
    "country": "NO",
    "name": "Kárášjohka",
    "lat": "69.47187",
    "lng": "25.51122"
  },
  {
    "country": "NO",
    "name": "Honningsvåg",
    "lat": "70.98209",
    "lng": "25.97037"
  },
  {
    "country": "NO",
    "name": "Ávanuorri",
    "lat": "70.99634",
    "lng": "24.66217"
  },
  {
    "country": "NO",
    "name": "Hammerfest",
    "lat": "70.66336",
    "lng": "23.68209"
  },
  {
    "country": "NO",
    "name": "Burfjord",
    "lat": "69.93804",
    "lng": "22.05205"
  },
  {
    "country": "NO",
    "name": "Bjørnevatn",
    "lat": "69.66745",
    "lng": "29.98722"
  },
  {
    "country": "NO",
    "name": "Berlevåg",
    "lat": "70.85778",
    "lng": "29.08636"
  },
  {
    "country": "NO",
    "name": "Båtsfjord",
    "lat": "70.63428",
    "lng": "29.7175"
  },
  {
    "country": "NO",
    "name": "Alta",
    "lat": "69.96887",
    "lng": "23.27165"
  },
  {
    "country": "NO",
    "name": "Rypefjord",
    "lat": "70.64126",
    "lng": "23.67213"
  },
  {
    "country": "NO",
    "name": "Strai",
    "lat": "58.1893",
    "lng": "7.92826"
  },
  {
    "country": "NO",
    "name": "Skålevik",
    "lat": "58.07955",
    "lng": "8.01602"
  },
  {
    "country": "NO",
    "name": "Ytre Arna",
    "lat": "60.46175",
    "lng": "5.43265"
  },
  {
    "country": "NO",
    "name": "Voss",
    "lat": "60.62869",
    "lng": "6.41474"
  },
  {
    "country": "NO",
    "name": "Volda",
    "lat": "62.146",
    "lng": "6.07108"
  },
  {
    "country": "NO",
    "name": "Vinstra",
    "lat": "61.59496",
    "lng": "9.75134"
  },
  {
    "country": "NO",
    "name": "Vikøyri",
    "lat": "61.08707",
    "lng": "6.57914"
  },
  {
    "country": "NO",
    "name": "Vikeså",
    "lat": "58.63759",
    "lng": "6.09133"
  },
  {
    "country": "NO",
    "name": "Vikersund",
    "lat": "59.96838",
    "lng": "9.99107"
  },
  {
    "country": "NO",
    "name": "Vik",
    "lat": "65.31254",
    "lng": "12.16734"
  },
  {
    "country": "NO",
    "name": "Vigrestad",
    "lat": "58.57103",
    "lng": "5.68182"
  },
  {
    "country": "NO",
    "name": "Vigeland",
    "lat": "58.08437",
    "lng": "7.30497"
  },
  {
    "country": "NO",
    "name": "Vevelstad",
    "lat": "65.6978",
    "lng": "12.43706"
  },
  {
    "country": "NO",
    "name": "Vestbygd",
    "lat": "58.09991",
    "lng": "6.58696"
  },
  {
    "country": "NO",
    "name": "Vestby",
    "lat": "59.60511",
    "lng": "10.75233"
  },
  {
    "country": "NO",
    "name": "Verdal",
    "lat": "63.79332",
    "lng": "11.4817"
  },
  {
    "country": "NO",
    "name": "Vennesla",
    "lat": "58.26856",
    "lng": "7.97314"
  },
  {
    "country": "NO",
    "name": "Vatne",
    "lat": "62.55826",
    "lng": "6.61708"
  },
  {
    "country": "NO",
    "name": "Varhaug",
    "lat": "58.6181",
    "lng": "5.65702"
  },
  {
    "country": "NO",
    "name": "Vanse",
    "lat": "58.09812",
    "lng": "6.69184"
  },
  {
    "country": "NO",
    "name": "Vangsvika",
    "lat": "69.17057",
    "lng": "17.73416"
  },
  {
    "country": "NO",
    "name": "Valle",
    "lat": "59.21259",
    "lng": "7.53559"
  },
  {
    "country": "NO",
    "name": "Valldal",
    "lat": "62.29782",
    "lng": "7.26374"
  },
  {
    "country": "NO",
    "name": "Våler",
    "lat": "60.67122",
    "lng": "11.83477"
  },
  {
    "country": "NO",
    "name": "Vågåmo",
    "lat": "61.87505",
    "lng": "9.09671"
  },
  {
    "country": "NO",
    "name": "Utsira",
    "lat": "59.3057",
    "lng": "4.8862"
  },
  {
    "country": "NO",
    "name": "Ulvik",
    "lat": "60.56791",
    "lng": "6.91645"
  },
  {
    "country": "NO",
    "name": "Ulsteinvik",
    "lat": "62.34317",
    "lng": "5.84869"
  },
  {
    "country": "NO",
    "name": "Ulefoss",
    "lat": "59.28245",
    "lng": "9.26548"
  },
  {
    "country": "NO",
    "name": "Uggdal",
    "lat": "60.00402",
    "lng": "5.52876"
  },
  {
    "country": "NO",
    "name": "Tysvær",
    "lat": "59.33204",
    "lng": "5.48981"
  },
  {
    "country": "NO",
    "name": "Tysse",
    "lat": "60.37404",
    "lng": "5.75952"
  },
  {
    "country": "NO",
    "name": "Tynset",
    "lat": "62.27594",
    "lng": "10.78241"
  },
  {
    "country": "NO",
    "name": "Tveit",
    "lat": "58.23366",
    "lng": "8.12199"
  },
  {
    "country": "NO",
    "name": "Tvedestrand",
    "lat": "58.62203",
    "lng": "8.93147"
  },
  {
    "country": "NO",
    "name": "Innbygda",
    "lat": "61.31484",
    "lng": "12.26374"
  },
  {
    "country": "NO",
    "name": "Trondheim",
    "lat": "63.43049",
    "lng": "10.39506"
  },
  {
    "country": "NO",
    "name": "Tromsø",
    "lat": "69.6489",
    "lng": "18.95508"
  },
  {
    "country": "NO",
    "name": "Trofors",
    "lat": "65.53335",
    "lng": "13.40631"
  },
  {
    "country": "NO",
    "name": "Treungen",
    "lat": "59.02064",
    "lng": "8.5202"
  },
  {
    "country": "NO",
    "name": "Tretten",
    "lat": "61.31423",
    "lng": "10.30066"
  },
  {
    "country": "NO",
    "name": "Tranby",
    "lat": "59.8085",
    "lng": "10.26114"
  },
  {
    "country": "NO",
    "name": "Tonstad",
    "lat": "58.66263",
    "lng": "6.71694"
  },
  {
    "country": "NO",
    "name": "Tønsberg",
    "lat": "59.26754",
    "lng": "10.40762"
  },
  {
    "country": "NO",
    "name": "Tomter",
    "lat": "59.6591",
    "lng": "10.99487"
  },
  {
    "country": "NO",
    "name": "Tomra",
    "lat": "62.58118",
    "lng": "6.93106"
  },
  {
    "country": "NO",
    "name": "Tolga",
    "lat": "62.40898",
    "lng": "10.99883"
  },
  {
    "country": "NO",
    "name": "Tofte",
    "lat": "59.54275",
    "lng": "10.56138"
  },
  {
    "country": "NO",
    "name": "Tjøme",
    "lat": "59.1109",
    "lng": "10.3933"
  },
  {
    "country": "NO",
    "name": "Tjeldstø",
    "lat": "60.59623",
    "lng": "4.84449"
  },
  {
    "country": "NO",
    "name": "Tingvatn",
    "lat": "58.3757",
    "lng": "7.2197"
  },
  {
    "country": "NO",
    "name": "Terråk",
    "lat": "65.087",
    "lng": "12.37148"
  },
  {
    "country": "NO",
    "name": "Tau",
    "lat": "59.06481",
    "lng": "5.9225"
  },
  {
    "country": "NO",
    "name": "Tangvall",
    "lat": "58.09781",
    "lng": "7.81529"
  },
  {
    "country": "NO",
    "name": "Tananger",
    "lat": "58.93618",
    "lng": "5.5741"
  },
  {
    "country": "NO",
    "name": "Syfteland",
    "lat": "60.23803",
    "lng": "5.45285"
  },
  {
    "country": "NO",
    "name": "Svolvær",
    "lat": "68.23417",
    "lng": "14.56834"
  },
  {
    "country": "NO",
    "name": "Svelvik",
    "lat": "59.6137",
    "lng": "10.40872"
  },
  {
    "country": "NO",
    "name": "Svelgen",
    "lat": "61.76976",
    "lng": "5.29544"
  },
  {
    "country": "NO",
    "name": "Sveio",
    "lat": "59.5419",
    "lng": "5.35178"
  },
  {
    "country": "NO",
    "name": "Sunndalsøra",
    "lat": "62.67519",
    "lng": "8.56327"
  },
  {
    "country": "NO",
    "name": "Stryn",
    "lat": "61.90259",
    "lng": "6.7179"
  },
  {
    "country": "NO",
    "name": "Straumen",
    "lat": "67.34769",
    "lng": "15.60493"
  },
  {
    "country": "NO",
    "name": "Straumen",
    "lat": "63.87163",
    "lng": "11.29617"
  },
  {
    "country": "NO",
    "name": "Straume",
    "lat": "68.6888",
    "lng": "14.47205"
  },
  {
    "country": "NO",
    "name": "Stranda",
    "lat": "62.30864",
    "lng": "6.93717"
  },
  {
    "country": "NO",
    "name": "Storsteinnes",
    "lat": "69.24081",
    "lng": "19.23437"
  },
  {
    "country": "NO",
    "name": "Storebø",
    "lat": "60.09485",
    "lng": "5.22705"
  },
  {
    "country": "NO",
    "name": "Stokmarknes",
    "lat": "68.56462",
    "lng": "14.91075"
  },
  {
    "country": "NO",
    "name": "Stokke",
    "lat": "59.22255",
    "lng": "10.30055"
  },
  {
    "country": "NO",
    "name": "Stjørdalshalsen",
    "lat": "63.4681",
    "lng": "10.92618"
  },
  {
    "country": "NO",
    "name": "Steinshamn",
    "lat": "62.78389",
    "lng": "6.47065"
  },
  {
    "country": "NO",
    "name": "Steinkjer",
    "lat": "64.01487",
    "lng": "11.49537"
  },
  {
    "country": "NO",
    "name": "Stavern",
    "lat": "59",
    "lng": "10.03333"
  },
  {
    "country": "NO",
    "name": "Stavanger",
    "lat": "58.97005",
    "lng": "5.73332"
  },
  {
    "country": "NO",
    "name": "Stange",
    "lat": "60.71803",
    "lng": "11.19417"
  },
  {
    "country": "NO",
    "name": "Spydeberg",
    "lat": "59.61709",
    "lng": "11.08559"
  },
  {
    "country": "NO",
    "name": "Spetalen",
    "lat": "60.18333",
    "lng": "11.9"
  },
  {
    "country": "NO",
    "name": "Sørumsand",
    "lat": "59.98621",
    "lng": "11.24154"
  },
  {
    "country": "NO",
    "name": "Sortland",
    "lat": "68.69569",
    "lng": "15.40498"
  },
  {
    "country": "NO",
    "name": "Sørland",
    "lat": "67.66564",
    "lng": "12.69784"
  },
  {
    "country": "NO",
    "name": "Solfjellsjøen",
    "lat": "66.11667",
    "lng": "12.48333"
  },
  {
    "country": "NO",
    "name": "Sola",
    "lat": "58.88854",
    "lng": "5.65285"
  },
  {
    "country": "NO",
    "name": "Søgne",
    "lat": "58.09328",
    "lng": "7.78294"
  },
  {
    "country": "NO",
    "name": "Sogndalsfjøra",
    "lat": "61.22575",
    "lng": "7.10178"
  },
  {
    "country": "NO",
    "name": "Snåase",
    "lat": "64.2457",
    "lng": "12.37779"
  },
  {
    "country": "NO",
    "name": "Slemmestad",
    "lat": "59.78074",
    "lng": "10.49701"
  },
  {
    "country": "NO",
    "name": "Skui",
    "lat": "59.92746",
    "lng": "10.4475"
  },
  {
    "country": "NO",
    "name": "Skudeneshavn",
    "lat": "59.14856",
    "lng": "5.25687"
  },
  {
    "country": "NO",
    "name": "Skreia",
    "lat": "60.65257",
    "lng": "10.93564"
  },
  {
    "country": "NO",
    "name": "Skotterud",
    "lat": "59.98281",
    "lng": "12.12825"
  },
  {
    "country": "NO",
    "name": "Skoppum",
    "lat": "59.38613",
    "lng": "10.41077"
  },
  {
    "country": "NO",
    "name": "Skogn",
    "lat": "63.70374",
    "lng": "11.19262"
  },
  {
    "country": "NO",
    "name": "Skoger",
    "lat": "59.71327",
    "lng": "10.25356"
  },
  {
    "country": "NO",
    "name": "Skodje",
    "lat": "62.50468",
    "lng": "6.69322"
  },
  {
    "country": "NO",
    "name": "Skjeberg",
    "lat": "59.21148",
    "lng": "11.19025"
  },
  {
    "country": "NO",
    "name": "Skjærhalden",
    "lat": "59.02526",
    "lng": "11.03685"
  },
  {
    "country": "NO",
    "name": "Skien",
    "lat": "59.20962",
    "lng": "9.60897"
  },
  {
    "country": "NO",
    "name": "Ski",
    "lat": "59.71949",
    "lng": "10.83576"
  },
  {
    "country": "NO",
    "name": "Skaun",
    "lat": "63.25149",
    "lng": "10.05236"
  },
  {
    "country": "NO",
    "name": "Skarnes",
    "lat": "60.25391",
    "lng": "11.68485"
  },
  {
    "country": "NO",
    "name": "Skaland",
    "lat": "69.44456",
    "lng": "17.29832"
  },
  {
    "country": "NO",
    "name": "Sjøvegan",
    "lat": "68.87363",
    "lng": "17.84706"
  },
  {
    "country": "NO",
    "name": "Skjønhaug",
    "lat": "59.64069",
    "lng": "11.31591"
  },
  {
    "country": "NO",
    "name": "Sjøholt",
    "lat": "62.48263",
    "lng": "6.81376"
  },
  {
    "country": "NO",
    "name": "Sistranda",
    "lat": "63.72523",
    "lng": "8.83318"
  },
  {
    "country": "NO",
    "name": "Siljan",
    "lat": "59.28843",
    "lng": "9.71"
  },
  {
    "country": "NO",
    "name": "Setermoen",
    "lat": "68.86099",
    "lng": "18.34857"
  },
  {
    "country": "NO",
    "name": "Sem",
    "lat": "59.2823",
    "lng": "10.33004"
  },
  {
    "country": "NO",
    "name": "Selvik",
    "lat": "59.56645",
    "lng": "10.26004"
  },
  {
    "country": "NO",
    "name": "Seljord",
    "lat": "59.48477",
    "lng": "8.63017"
  },
  {
    "country": "NO",
    "name": "Selje",
    "lat": "62.0444",
    "lng": "5.34739"
  },
  {
    "country": "NO",
    "name": "Sauda",
    "lat": "59.65059",
    "lng": "6.35415"
  },
  {
    "country": "NO",
    "name": "Sarpsborg",
    "lat": "59.28391",
    "lng": "11.10962"
  },
  {
    "country": "NO",
    "name": "Sandvika",
    "lat": "64.46377",
    "lng": "13.59125"
  },
  {
    "country": "NO",
    "name": "Sandvika",
    "lat": "59.89073",
    "lng": "10.52774"
  },
  {
    "country": "NO",
    "name": "Sandnessjøen",
    "lat": "66.02166",
    "lng": "12.63158"
  },
  {
    "country": "NO",
    "name": "Sandnes",
    "lat": "58.85244",
    "lng": "5.73521"
  },
  {
    "country": "NO",
    "name": "Sandefjord",
    "lat": "59.13118",
    "lng": "10.21665"
  },
  {
    "country": "NO",
    "name": "Sande",
    "lat": "61.32511",
    "lng": "5.79773"
  },
  {
    "country": "NO",
    "name": "Sande",
    "lat": "59.58679",
    "lng": "10.20809"
  },
  {
    "country": "NO",
    "name": "Sandane",
    "lat": "61.77277",
    "lng": "6.21496"
  },
  {
    "country": "NO",
    "name": "Sand",
    "lat": "60.3922",
    "lng": "11.5403"
  },
  {
    "country": "NO",
    "name": "Sagvåg",
    "lat": "59.78139",
    "lng": "5.38996"
  },
  {
    "country": "NO",
    "name": "Sæveland",
    "lat": "59.26667",
    "lng": "5.2"
  },
  {
    "country": "NO",
    "name": "Sætre",
    "lat": "59.68129",
    "lng": "10.52749"
  },
  {
    "country": "NO",
    "name": "Rygge",
    "lat": "59.37762",
    "lng": "10.75034"
  },
  {
    "country": "NO",
    "name": "Rubbestadneset",
    "lat": "59.81559",
    "lng": "5.26822"
  },
  {
    "country": "NO",
    "name": "Røyrvik",
    "lat": "64.88394",
    "lng": "13.56256"
  },
  {
    "country": "NO",
    "name": "Røyken",
    "lat": "59.74724",
    "lng": "10.38832"
  },
  {
    "country": "NO",
    "name": "Rotnes",
    "lat": "60.05707",
    "lng": "10.86135"
  },
  {
    "country": "NO",
    "name": "Røst",
    "lat": "67.51754",
    "lng": "12.1176"
  },
  {
    "country": "NO",
    "name": "Rosendal",
    "lat": "59.98589",
    "lng": "6.01157"
  },
  {
    "country": "NO",
    "name": "Rørvik",
    "lat": "64.86185",
    "lng": "11.23969"
  },
  {
    "country": "NO",
    "name": "Røros",
    "lat": "62.57468",
    "lng": "11.3842"
  },
  {
    "country": "NO",
    "name": "Rollag",
    "lat": "59.98431",
    "lng": "9.29644"
  },
  {
    "country": "NO",
    "name": "Rognan",
    "lat": "67.10021",
    "lng": "15.39086"
  },
  {
    "country": "NO",
    "name": "Roa",
    "lat": "60.29093",
    "lng": "10.61585"
  },
  {
    "country": "NO",
    "name": "Rjukan",
    "lat": "59.87891",
    "lng": "8.59411"
  },
  {
    "country": "NO",
    "name": "Risør",
    "lat": "58.72057",
    "lng": "9.23422"
  },
  {
    "country": "NO",
    "name": "Rindal",
    "lat": "63.05547",
    "lng": "9.21151"
  },
  {
    "country": "NO",
    "name": "Rena",
    "lat": "61.13222",
    "lng": "11.37156"
  },
  {
    "country": "NO",
    "name": "Reinsvoll",
    "lat": "60.67977",
    "lng": "10.62175"
  },
  {
    "country": "NO",
    "name": "Rensvik",
    "lat": "63.09843",
    "lng": "7.82026"
  },
  {
    "country": "NO",
    "name": "Reine",
    "lat": "67.93249",
    "lng": "13.08955"
  },
  {
    "country": "NO",
    "name": "Raufoss",
    "lat": "60.72604",
    "lng": "10.6133"
  },
  {
    "country": "NO",
    "name": "Ranemsletta",
    "lat": "64.49447",
    "lng": "11.94912"
  },
  {
    "country": "NO",
    "name": "Randaberg",
    "lat": "58.99955",
    "lng": "5.61871"
  },
  {
    "country": "NO",
    "name": "Ramberg",
    "lat": "68.08991",
    "lng": "13.22989"
  },
  {
    "country": "NO",
    "name": "Rakkestad",
    "lat": "59.42513",
    "lng": "11.34535"
  },
  {
    "country": "NO",
    "name": "Råholt",
    "lat": "60.27513",
    "lng": "11.17901"
  },
  {
    "country": "NO",
    "name": "Prestfoss",
    "lat": "60.04343",
    "lng": "9.6352"
  },
  {
    "country": "NO",
    "name": "Prestestranda",
    "lat": "59.09773",
    "lng": "9.05866"
  },
  {
    "country": "NO",
    "name": "Porsgrunn",
    "lat": "59.14054",
    "lng": "9.6561"
  },
  {
    "country": "NO",
    "name": "Øystese",
    "lat": "60.38825",
    "lng": "6.19251"
  },
  {
    "country": "NO",
    "name": "Farnes",
    "lat": "61.3085",
    "lng": "7.79694"
  },
  {
    "country": "NO",
    "name": "Otta",
    "lat": "61.7712",
    "lng": "9.53529"
  },
  {
    "country": "NO",
    "name": "Osøyro",
    "lat": "60.18385",
    "lng": "5.4638"
  },
  {
    "country": "NO",
    "name": "Oslo",
    "lat": "59.91273",
    "lng": "10.74609"
  },
  {
    "country": "NO",
    "name": "Os",
    "lat": "62.49647",
    "lng": "11.22326"
  },
  {
    "country": "NO",
    "name": "Ørnes",
    "lat": "66.86878",
    "lng": "13.70579"
  },
  {
    "country": "NO",
    "name": "Orkanger",
    "lat": "63.30668",
    "lng": "9.85025"
  },
  {
    "country": "NO",
    "name": "Ørje",
    "lat": "59.48023",
    "lng": "11.66016"
  },
  {
    "country": "NO",
    "name": "Oppdal",
    "lat": "62.59431",
    "lng": "9.6912"
  },
  {
    "country": "NO",
    "name": "Ølen",
    "lat": "59.60437",
    "lng": "5.80799"
  },
  {
    "country": "NO",
    "name": "Odda",
    "lat": "60.06912",
    "lng": "6.54565"
  },
  {
    "country": "NO",
    "name": "Notodden",
    "lat": "59.55936",
    "lng": "9.25853"
  },
  {
    "country": "NO",
    "name": "Norheimsund",
    "lat": "60.37089",
    "lng": "6.14562"
  },
  {
    "country": "NO",
    "name": "Noresund",
    "lat": "60.17985",
    "lng": "9.62411"
  },
  {
    "country": "NO",
    "name": "Nordfjordeid",
    "lat": "61.9122",
    "lng": "5.98557"
  },
  {
    "country": "NO",
    "name": "Nodeland",
    "lat": "58.15517",
    "lng": "7.83576"
  },
  {
    "country": "NO",
    "name": "Nesna",
    "lat": "66.19817",
    "lng": "13.01844"
  },
  {
    "country": "NO",
    "name": "Nesbyen",
    "lat": "60.56809",
    "lng": "9.10274"
  },
  {
    "country": "NO",
    "name": "Naustdal",
    "lat": "61.51108",
    "lng": "5.71694"
  },
  {
    "country": "NO",
    "name": "Narvik",
    "lat": "68.43838",
    "lng": "17.4272"
  },
  {
    "country": "NO",
    "name": "Namsskogan",
    "lat": "64.92886",
    "lng": "13.15954"
  },
  {
    "country": "NO",
    "name": "Namsos",
    "lat": "64.46624",
    "lng": "11.49572"
  },
  {
    "country": "NO",
    "name": "Nærbø",
    "lat": "58.66546",
    "lng": "5.63788"
  },
  {
    "country": "NO",
    "name": "Mysen",
    "lat": "59.55354",
    "lng": "11.32578"
  },
  {
    "country": "NO",
    "name": "Myre",
    "lat": "69.10588",
    "lng": "15.96308"
  },
  {
    "country": "NO",
    "name": "Myra",
    "lat": "58.74921",
    "lng": "8.86254"
  },
  {
    "country": "NO",
    "name": "Mosterhamn",
    "lat": "59.69919",
    "lng": "5.38585"
  },
  {
    "country": "NO",
    "name": "Moss",
    "lat": "59.43403",
    "lng": "10.65771"
  },
  {
    "country": "NO",
    "name": "Mosjøen",
    "lat": "65.83599",
    "lng": "13.19076"
  },
  {
    "country": "NO",
    "name": "Moldjord",
    "lat": "67.00601",
    "lng": "14.5743"
  },
  {
    "country": "NO",
    "name": "Molde",
    "lat": "62.73752",
    "lng": "7.15912"
  },
  {
    "country": "NO",
    "name": "Fyresdal",
    "lat": "59.18343",
    "lng": "8.0921"
  },
  {
    "country": "NO",
    "name": "Mo i Rana",
    "lat": "66.31278",
    "lng": "14.14278"
  },
  {
    "country": "NO",
    "name": "Moi",
    "lat": "58.45674",
    "lng": "6.55184"
  },
  {
    "country": "NO",
    "name": "Moen",
    "lat": "69.13043",
    "lng": "18.61226"
  },
  {
    "country": "NO",
    "name": "Moelv",
    "lat": "60.93333",
    "lng": "10.7"
  },
  {
    "country": "NO",
    "name": "Mo",
    "lat": "60.81625",
    "lng": "5.80575"
  },
  {
    "country": "NO",
    "name": "Mjøndalen",
    "lat": "59.75075",
    "lng": "10.02477"
  },
  {
    "country": "NO",
    "name": "Midsund",
    "lat": "62.67387",
    "lng": "6.67412"
  },
  {
    "country": "NO",
    "name": "Meråker",
    "lat": "63.41406",
    "lng": "11.74298"
  },
  {
    "country": "NO",
    "name": "Melsomvik",
    "lat": "59.22394",
    "lng": "10.33616"
  },
  {
    "country": "NO",
    "name": "Melhus",
    "lat": "63.28555",
    "lng": "10.27806"
  },
  {
    "country": "NO",
    "name": "Melbu",
    "lat": "68.50246",
    "lng": "14.79962"
  },
  {
    "country": "NO",
    "name": "Maura",
    "lat": "60.2583",
    "lng": "11.03192"
  },
  {
    "country": "NO",
    "name": "Masfjorden",
    "lat": "60.79887",
    "lng": "5.30418"
  },
  {
    "country": "NO",
    "name": "Manger",
    "lat": "60.64145",
    "lng": "5.04136"
  },
  {
    "country": "NO",
    "name": "Mandal",
    "lat": "58.0274",
    "lng": "7.45342"
  },
  {
    "country": "NO",
    "name": "Malvik",
    "lat": "63.43333",
    "lng": "10.68333"
  },
  {
    "country": "NO",
    "name": "Måløy",
    "lat": "61.93535",
    "lng": "5.11362"
  },
  {
    "country": "NO",
    "name": "Malm",
    "lat": "64.07534",
    "lng": "11.22398"
  },
  {
    "country": "NO",
    "name": "Lysaker",
    "lat": "59.90994",
    "lng": "10.63545"
  },
  {
    "country": "NO",
    "name": "Lyngdal",
    "lat": "58.1376",
    "lng": "7.07002"
  },
  {
    "country": "NO",
    "name": "Lunde",
    "lat": "59.29832",
    "lng": "9.10268"
  },
  {
    "country": "NO",
    "name": "Lundamo",
    "lat": "63.15216",
    "lng": "10.28555"
  },
  {
    "country": "NO",
    "name": "Løten",
    "lat": "60.81941",
    "lng": "11.34209"
  },
  {
    "country": "NO",
    "name": "Løpsmarka",
    "lat": "67.31343",
    "lng": "14.44934"
  },
  {
    "country": "NO",
    "name": "Lonevåg",
    "lat": "60.52556",
    "lng": "5.49563"
  },
  {
    "country": "NO",
    "name": "Fossbergom",
    "lat": "61.83772",
    "lng": "8.56842"
  },
  {
    "country": "NO",
    "name": "Lødingen",
    "lat": "68.41373",
    "lng": "15.99626"
  },
  {
    "country": "NO",
    "name": "Løding",
    "lat": "67.30055",
    "lng": "14.73852"
  },
  {
    "country": "NO",
    "name": "Lindås",
    "lat": "60.73639",
    "lng": "5.16102"
  },
  {
    "country": "NO",
    "name": "Lillestrøm",
    "lat": "59.95597",
    "lng": "11.04918"
  },
  {
    "country": "NO",
    "name": "Lillesand",
    "lat": "58.24879",
    "lng": "8.3778"
  },
  {
    "country": "NO",
    "name": "Lillehammer",
    "lat": "61.11514",
    "lng": "10.46628"
  },
  {
    "country": "NO",
    "name": "Liknes",
    "lat": "58.31216",
    "lng": "6.9618"
  },
  {
    "country": "NO",
    "name": "Levanger",
    "lat": "63.74644",
    "lng": "11.29963"
  },
  {
    "country": "NO",
    "name": "Lervik",
    "lat": "59.27119",
    "lng": "10.7461"
  },
  {
    "country": "NO",
    "name": "Lensvik",
    "lat": "63.51389",
    "lng": "9.80611"
  },
  {
    "country": "NO",
    "name": "Lena",
    "lat": "60.67391",
    "lng": "10.81317"
  },
  {
    "country": "NO",
    "name": "Leland",
    "lat": "66.06406",
    "lng": "12.94325"
  },
  {
    "country": "NO",
    "name": "Leknes",
    "lat": "65.1",
    "lng": "11.7"
  },
  {
    "country": "NO",
    "name": "Leirvik",
    "lat": "59.77977",
    "lng": "5.50051"
  },
  {
    "country": "NO",
    "name": "Leirsund",
    "lat": "59.99682",
    "lng": "11.08746"
  },
  {
    "country": "NO",
    "name": "Lauvsnes",
    "lat": "64.50061",
    "lng": "10.89396"
  },
  {
    "country": "NO",
    "name": "Larvik",
    "lat": "59.05328",
    "lng": "10.03517"
  },
  {
    "country": "NO",
    "name": "Larsnes",
    "lat": "62.20282",
    "lng": "5.57729"
  },
  {
    "country": "NO",
    "name": "Larkollen",
    "lat": "59.33196",
    "lng": "10.66687"
  },
  {
    "country": "NO",
    "name": "Langevåg",
    "lat": "62.44085",
    "lng": "6.19137"
  },
  {
    "country": "NO",
    "name": "Langesund",
    "lat": "59.00071",
    "lng": "9.74876"
  },
  {
    "country": "NO",
    "name": "Lærdalsøyri",
    "lat": "61.10001",
    "lng": "7.47374"
  },
  {
    "country": "NO",
    "name": "Kyrksæterøra",
    "lat": "63.29057",
    "lng": "9.08909"
  },
  {
    "country": "NO",
    "name": "Kviteseid",
    "lat": "59.40223",
    "lng": "8.49267"
  },
  {
    "country": "NO",
    "name": "Krokstadøra",
    "lat": "63.40099",
    "lng": "9.50062"
  },
  {
    "country": "NO",
    "name": "Kristiansund",
    "lat": "63.11045",
    "lng": "7.72795"
  },
  {
    "country": "NO",
    "name": "Kristiansand",
    "lat": "58.14671",
    "lng": "7.9956"
  },
  {
    "country": "NO",
    "name": "Kragerø",
    "lat": "58.8693",
    "lng": "9.41494"
  },
  {
    "country": "NO",
    "name": "Korgen",
    "lat": "66.07662",
    "lng": "13.8216"
  },
  {
    "country": "NO",
    "name": "Koppang",
    "lat": "61.57219",
    "lng": "11.04659"
  },
  {
    "country": "NO",
    "name": "Kopervik",
    "lat": "59.28354",
    "lng": "5.30669"
  },
  {
    "country": "NO",
    "name": "Konsmo",
    "lat": "58.28529",
    "lng": "7.35598"
  },
  {
    "country": "NO",
    "name": "Kongsvinger",
    "lat": "60.19049",
    "lng": "11.99772"
  },
  {
    "country": "NO",
    "name": "Kongsberg",
    "lat": "59.66858",
    "lng": "9.65017"
  },
  {
    "country": "NO",
    "name": "Kolvereid",
    "lat": "64.86549",
    "lng": "11.60465"
  },
  {
    "country": "NO",
    "name": "Kolbotn",
    "lat": "59.81056",
    "lng": "10.80389"
  },
  {
    "country": "NO",
    "name": "Knarvik",
    "lat": "60.5453",
    "lng": "5.28208"
  },
  {
    "country": "NO",
    "name": "Knappstad",
    "lat": "59.62424",
    "lng": "11.03274"
  },
  {
    "country": "NO",
    "name": "Knappskog",
    "lat": "60.37906",
    "lng": "5.05602"
  },
  {
    "country": "NO",
    "name": "Kløfta",
    "lat": "60.07407",
    "lng": "11.13805"
  },
  {
    "country": "NO",
    "name": "Kleppestø",
    "lat": "60.40844",
    "lng": "5.2276"
  },
  {
    "country": "NO",
    "name": "Kjøpsvik",
    "lat": "68.09696",
    "lng": "16.37416"
  },
  {
    "country": "NO",
    "name": "Kirkenær",
    "lat": "60.4579",
    "lng": "12.05855"
  },
  {
    "country": "NO",
    "name": "Karlshus",
    "lat": "59.35195",
    "lng": "10.87226"
  },
  {
    "country": "NO",
    "name": "Kabelvåg",
    "lat": "68.21066",
    "lng": "14.47554"
  },
  {
    "country": "NO",
    "name": "Judaberg",
    "lat": "59.17204",
    "lng": "5.87617"
  },
  {
    "country": "NO",
    "name": "Jørpeland",
    "lat": "59.02251",
    "lng": "6.04078"
  },
  {
    "country": "NO",
    "name": "Jondal",
    "lat": "60.27561",
    "lng": "6.25229"
  },
  {
    "country": "NO",
    "name": "Jevnaker",
    "lat": "60.23979",
    "lng": "10.38709"
  },
  {
    "country": "NO",
    "name": "Jessheim",
    "lat": "60.14151",
    "lng": "11.17515"
  },
  {
    "country": "NO",
    "name": "Jaren",
    "lat": "60.39273",
    "lng": "10.56155"
  },
  {
    "country": "NO",
    "name": "Isdalstø",
    "lat": "60.55519",
    "lng": "5.26942"
  },
  {
    "country": "NO",
    "name": "Inndyr",
    "lat": "67.03353",
    "lng": "14.02663"
  },
  {
    "country": "NO",
    "name": "Hyllestad",
    "lat": "61.17109",
    "lng": "5.29603"
  },
  {
    "country": "NO",
    "name": "Hylkje",
    "lat": "60.51028",
    "lng": "5.35444"
  },
  {
    "country": "NO",
    "name": "Hvittingfoss",
    "lat": "59.48572",
    "lng": "10.01173"
  },
  {
    "country": "NO",
    "name": "Hundorp",
    "lat": "61.55523",
    "lng": "9.94069"
  },
  {
    "country": "NO",
    "name": "Høyanger",
    "lat": "61.22348",
    "lng": "6.08471"
  },
  {
    "country": "NO",
    "name": "Hovden",
    "lat": "59.56045",
    "lng": "7.3567"
  },
  {
    "country": "NO",
    "name": "Hov",
    "lat": "60.6987",
    "lng": "10.35193"
  },
  {
    "country": "NO",
    "name": "Horten",
    "lat": "59.41721",
    "lng": "10.48343"
  },
  {
    "country": "NO",
    "name": "Hopen",
    "lat": "63.46539",
    "lng": "8.01437"
  },
  {
    "country": "NO",
    "name": "Hønefoss",
    "lat": "60.16804",
    "lng": "10.25647"
  },
  {
    "country": "NO",
    "name": "Hommelvik",
    "lat": "63.41083",
    "lng": "10.79424"
  },
  {
    "country": "NO",
    "name": "Holmestrand",
    "lat": "59.48761",
    "lng": "10.31761"
  },
  {
    "country": "NO",
    "name": "Hol",
    "lat": "68.54902",
    "lng": "16.39218"
  },
  {
    "country": "NO",
    "name": "Hokksund",
    "lat": "59.77077",
    "lng": "9.90987"
  },
  {
    "country": "NO",
    "name": "Hjelset",
    "lat": "62.7805",
    "lng": "7.49277"
  },
  {
    "country": "NO",
    "name": "Herre",
    "lat": "59.10351",
    "lng": "9.56195"
  },
  {
    "country": "NO",
    "name": "Hermansverk",
    "lat": "61.18461",
    "lng": "6.85016"
  },
  {
    "country": "NO",
    "name": "Hemsedal",
    "lat": "60.86293",
    "lng": "8.55337"
  },
  {
    "country": "NO",
    "name": "Hemnesberget",
    "lat": "66.22489",
    "lng": "13.61643"
  },
  {
    "country": "NO",
    "name": "Heggenes",
    "lat": "61.14383",
    "lng": "9.06942"
  },
  {
    "country": "NO",
    "name": "Hauknes",
    "lat": "66.28333",
    "lng": "14.06667"
  },
  {
    "country": "NO",
    "name": "Haugesund",
    "lat": "59.41378",
    "lng": "5.268"
  },
  {
    "country": "NO",
    "name": "Hauge i Dalane",
    "lat": "58.34361",
    "lng": "6.28121"
  },
  {
    "country": "NO",
    "name": "Harstad",
    "lat": "68.79833",
    "lng": "16.54165"
  },
  {
    "country": "NO",
    "name": "Hareid",
    "lat": "62.37041",
    "lng": "6.02902"
  },
  {
    "country": "NO",
    "name": "Hardbakke",
    "lat": "61.07562",
    "lng": "4.84111"
  },
  {
    "country": "NO",
    "name": "Hansnes",
    "lat": "69.96701",
    "lng": "19.62752"
  },
  {
    "country": "NO",
    "name": "Hamnvik",
    "lat": "68.77927",
    "lng": "17.17179"
  },
  {
    "country": "NO",
    "name": "Hamar",
    "lat": "60.7945",
    "lng": "11.06798"
  },
  {
    "country": "NO",
    "name": "Halden",
    "lat": "59.12478",
    "lng": "11.38754"
  },
  {
    "country": "NO",
    "name": "Hagavik",
    "lat": "60.18076",
    "lng": "5.40146"
  },
  {
    "country": "NO",
    "name": "Gvarv",
    "lat": "59.38767",
    "lng": "9.1724"
  },
  {
    "country": "NO",
    "name": "Gullhaug",
    "lat": "59.5013",
    "lng": "10.25224"
  },
  {
    "country": "NO",
    "name": "Gryllefjord",
    "lat": "69.36304",
    "lng": "17.05284"
  },
  {
    "country": "NO",
    "name": "Grua",
    "lat": "60.25701",
    "lng": "10.66222"
  },
  {
    "country": "NO",
    "name": "Grong",
    "lat": "64.46459",
    "lng": "12.31601"
  },
  {
    "country": "NO",
    "name": "Grimstad",
    "lat": "58.3405",
    "lng": "8.59343"
  },
  {
    "country": "NO",
    "name": "Gravdal",
    "lat": "68.11832",
    "lng": "13.55339"
  },
  {
    "country": "NO",
    "name": "Gratangen",
    "lat": "68.65",
    "lng": "17.68333"
  },
  {
    "country": "NO",
    "name": "Granvin",
    "lat": "60.52408",
    "lng": "6.7194"
  },
  {
    "country": "NO",
    "name": "Gol",
    "lat": "60.7014",
    "lng": "8.94572"
  },
  {
    "country": "NO",
    "name": "Glomfjord",
    "lat": "66.81663",
    "lng": "13.94404"
  },
  {
    "country": "NO",
    "name": "Gladstad",
    "lat": "65.67683",
    "lng": "11.96218"
  },
  {
    "country": "NO",
    "name": "Justvik",
    "lat": "58.19691",
    "lng": "8.03107"
  },
  {
    "country": "NO",
    "name": "Gjøvik",
    "lat": "60.79574",
    "lng": "10.69155"
  },
  {
    "country": "NO",
    "name": "Gjerstad",
    "lat": "58.88083",
    "lng": "9.01861"
  },
  {
    "country": "NO",
    "name": "Geilo",
    "lat": "60.53369",
    "lng": "8.20539"
  },
  {
    "country": "NO",
    "name": "Frogner",
    "lat": "60.02463",
    "lng": "11.10284"
  },
  {
    "country": "NO",
    "name": "Frekhaug",
    "lat": "60.51321",
    "lng": "5.24252"
  },
  {
    "country": "NO",
    "name": "Fredrikstad",
    "lat": "59.2181",
    "lng": "10.9298"
  },
  {
    "country": "NO",
    "name": "Fossby",
    "lat": "59.22218",
    "lng": "11.69928"
  },
  {
    "country": "NO",
    "name": "Fosnavåg",
    "lat": "62.34194",
    "lng": "5.63396"
  },
  {
    "country": "NO",
    "name": "Førde",
    "lat": "61.45217",
    "lng": "5.85717"
  },
  {
    "country": "NO",
    "name": "Folldal",
    "lat": "62.13246",
    "lng": "9.9968"
  },
  {
    "country": "NO",
    "name": "Florø",
    "lat": "61.59957",
    "lng": "5.0328"
  },
  {
    "country": "NO",
    "name": "Flekkefjord",
    "lat": "58.29705",
    "lng": "6.66069"
  },
  {
    "country": "NO",
    "name": "Flateby",
    "lat": "59.82951",
    "lng": "11.15345"
  },
  {
    "country": "NO",
    "name": "Flå",
    "lat": "60.43021",
    "lng": "9.46197"
  },
  {
    "country": "NO",
    "name": "Fitjar",
    "lat": "59.91803",
    "lng": "5.31674"
  },
  {
    "country": "NO",
    "name": "Finnsnes",
    "lat": "69.22959",
    "lng": "17.98114"
  },
  {
    "country": "NO",
    "name": "Fillan",
    "lat": "63.60638",
    "lng": "8.96961"
  },
  {
    "country": "NO",
    "name": "Fevik",
    "lat": "58.3782",
    "lng": "8.67601"
  },
  {
    "country": "NO",
    "name": "Fetsund",
    "lat": "59.92463",
    "lng": "11.15711"
  },
  {
    "country": "NO",
    "name": "Fedje",
    "lat": "60.7789",
    "lng": "4.71485"
  },
  {
    "country": "NO",
    "name": "Fauske",
    "lat": "67.25883",
    "lng": "15.39181"
  },
  {
    "country": "NO",
    "name": "Farsund",
    "lat": "58.09479",
    "lng": "6.80468"
  },
  {
    "country": "NO",
    "name": "Fagerstrand",
    "lat": "59.73746",
    "lng": "10.59404"
  },
  {
    "country": "NO",
    "name": "Fagernes",
    "lat": "60.98584",
    "lng": "9.23236"
  },
  {
    "country": "NO",
    "name": "Evjen",
    "lat": "68.26667",
    "lng": "13.73333"
  },
  {
    "country": "NO",
    "name": "Evje",
    "lat": "58.58569",
    "lng": "7.80363"
  },
  {
    "country": "NO",
    "name": "Evenskjer",
    "lat": "68.58283",
    "lng": "16.57203"
  },
  {
    "country": "NO",
    "name": "Etne",
    "lat": "59.66528",
    "lng": "5.93708"
  },
  {
    "country": "NO",
    "name": "Espeland",
    "lat": "60.38249",
    "lng": "5.4657"
  },
  {
    "country": "NO",
    "name": "Elverum",
    "lat": "60.88191",
    "lng": "11.56231"
  },
  {
    "country": "NO",
    "name": "Eivindvik",
    "lat": "60.98133",
    "lng": "5.07497"
  },
  {
    "country": "NO",
    "name": "Eikelandsosen",
    "lat": "60.24175",
    "lng": "5.74433"
  },
  {
    "country": "NO",
    "name": "Eike",
    "lat": "59.39833",
    "lng": "5.36389"
  },
  {
    "country": "NO",
    "name": "Eidsvoll",
    "lat": "60.3311",
    "lng": "11.26264"
  },
  {
    "country": "NO",
    "name": "Eidsvåg",
    "lat": "62.77656",
    "lng": "8.0655"
  },
  {
    "country": "NO",
    "name": "Eidfjord",
    "lat": "60.4675",
    "lng": "7.07193"
  },
  {
    "country": "NO",
    "name": "Eide",
    "lat": "62.91735",
    "lng": "7.44669"
  },
  {
    "country": "NO",
    "name": "Egersund",
    "lat": "58.45133",
    "lng": "5.9997"
  },
  {
    "country": "NO",
    "name": "Drøbak",
    "lat": "59.66333",
    "lng": "10.62975"
  },
  {
    "country": "NO",
    "name": "Drammen",
    "lat": "59.74389",
    "lng": "10.20449"
  },
  {
    "country": "NO",
    "name": "Dovre",
    "lat": "61.9875",
    "lng": "9.25556"
  },
  {
    "country": "NO",
    "name": "Dombås",
    "lat": "62.07554",
    "lng": "9.12785"
  },
  {
    "country": "NO",
    "name": "Dokka",
    "lat": "60.835",
    "lng": "10.07362"
  },
  {
    "country": "NO",
    "name": "Dalen",
    "lat": "59.44499",
    "lng": "8.00492"
  },
  {
    "country": "NO",
    "name": "Dale",
    "lat": "61.36353",
    "lng": "5.40036"
  },
  {
    "country": "NO",
    "name": "Dale",
    "lat": "60.58639",
    "lng": "5.81888"
  },
  {
    "country": "NO",
    "name": "Bygland",
    "lat": "58.8285",
    "lng": "7.79616"
  },
  {
    "country": "NO",
    "name": "Bryne",
    "lat": "58.73536",
    "lng": "5.64766"
  },
  {
    "country": "NO",
    "name": "Brumunddal",
    "lat": "60.88095",
    "lng": "10.93948"
  },
  {
    "country": "NO",
    "name": "Bruflat",
    "lat": "60.88781",
    "lng": "9.64143"
  },
  {
    "country": "NO",
    "name": "Brønnøysund",
    "lat": "65.47487",
    "lng": "12.21285"
  },
  {
    "country": "NO",
    "name": "Svortland",
    "lat": "59.79284",
    "lng": "5.17226"
  },
  {
    "country": "NO",
    "name": "Brekstad",
    "lat": "63.68697",
    "lng": "9.66541"
  },
  {
    "country": "NO",
    "name": "Brattvåg",
    "lat": "62.59991",
    "lng": "6.44426"
  },
  {
    "country": "NO",
    "name": "Botngård",
    "lat": "63.76484",
    "lng": "9.80863"
  },
  {
    "country": "NO",
    "name": "Borkenes",
    "lat": "68.77261",
    "lng": "16.17115"
  },
  {
    "country": "NO",
    "name": "Ránda",
    "lat": "68.52647",
    "lng": "16.9928"
  },
  {
    "country": "NO",
    "name": "Bodø",
    "lat": "67.28",
    "lng": "14.40501"
  },
  {
    "country": "NO",
    "name": "Bø",
    "lat": "59.41299",
    "lng": "9.0693"
  },
  {
    "country": "NO",
    "name": "Blakstad",
    "lat": "59.8191",
    "lng": "10.4645"
  },
  {
    "country": "NO",
    "name": "Bjørkelangen",
    "lat": "59.88357",
    "lng": "11.56396"
  },
  {
    "country": "NO",
    "name": "Bjerkvik",
    "lat": "68.54917",
    "lng": "17.55709"
  },
  {
    "country": "NO",
    "name": "Birkeland",
    "lat": "58.33091",
    "lng": "8.23229"
  },
  {
    "country": "NO",
    "name": "Berkåk",
    "lat": "62.82496",
    "lng": "10.01177"
  },
  {
    "country": "NO",
    "name": "Berger",
    "lat": "59.54994",
    "lng": "10.38641"
  },
  {
    "country": "NO",
    "name": "Bergen",
    "lat": "60.39299",
    "lng": "5.32415"
  },
  {
    "country": "NO",
    "name": "Batnfjordsøra",
    "lat": "62.89463",
    "lng": "7.67251"
  },
  {
    "country": "NO",
    "name": "Barkåker",
    "lat": "59.31859",
    "lng": "10.38963"
  },
  {
    "country": "NO",
    "name": "Ballangen",
    "lat": "68.34283",
    "lng": "16.83145"
  },
  {
    "country": "NO",
    "name": "Balestrand",
    "lat": "61.20962",
    "lng": "6.53608"
  },
  {
    "country": "NO",
    "name": "Bagn",
    "lat": "60.82249",
    "lng": "9.55207"
  },
  {
    "country": "NO",
    "name": "Austrheim",
    "lat": "60.7774",
    "lng": "4.9323"
  },
  {
    "country": "NO",
    "name": "Aursmoen",
    "lat": "59.92763",
    "lng": "11.44275"
  },
  {
    "country": "NO",
    "name": "Aure",
    "lat": "63.2679",
    "lng": "8.52913"
  },
  {
    "country": "NO",
    "name": "Auli",
    "lat": "60.0345",
    "lng": "11.36046"
  },
  {
    "country": "NO",
    "name": "Askim",
    "lat": "59.58326",
    "lng": "11.16286"
  },
  {
    "country": "NO",
    "name": "Asker",
    "lat": "59.83333",
    "lng": "10.43721"
  },
  {
    "country": "NO",
    "name": "Ask",
    "lat": "60.07131",
    "lng": "11.0362"
  },
  {
    "country": "NO",
    "name": "Åsgårdstrand",
    "lat": "59.34889",
    "lng": "10.4675"
  },
  {
    "country": "NO",
    "name": "Aas",
    "lat": "63.05",
    "lng": "11.65"
  },
  {
    "country": "NO",
    "name": "Ås",
    "lat": "59.66472",
    "lng": "10.79465"
  },
  {
    "country": "NO",
    "name": "Åros",
    "lat": "59.7061",
    "lng": "10.51092"
  },
  {
    "country": "NO",
    "name": "Årnes",
    "lat": "63.96114",
    "lng": "10.22601"
  },
  {
    "country": "NO",
    "name": "Årnes",
    "lat": "60.12237",
    "lng": "11.47005"
  },
  {
    "country": "NO",
    "name": "Indre Arna",
    "lat": "60.41768",
    "lng": "5.47087"
  },
  {
    "country": "NO",
    "name": "Arendal",
    "lat": "58.46151",
    "lng": "8.77253"
  },
  {
    "country": "NO",
    "name": "Årdalstangen",
    "lat": "61.23581",
    "lng": "7.7037"
  },
  {
    "country": "NO",
    "name": "Åneby",
    "lat": "60.08926",
    "lng": "10.86998"
  },
  {
    "country": "NO",
    "name": "Andenes",
    "lat": "69.31428",
    "lng": "16.11939"
  },
  {
    "country": "NO",
    "name": "Åndalsnes",
    "lat": "62.56749",
    "lng": "7.68709"
  },
  {
    "country": "NO",
    "name": "Åmot",
    "lat": "59.56974",
    "lng": "7.98871"
  },
  {
    "country": "NO",
    "name": "Åmli",
    "lat": "58.76566",
    "lng": "8.48392"
  },
  {
    "country": "NO",
    "name": "Alvdal",
    "lat": "62.10766",
    "lng": "10.63073"
  },
  {
    "country": "NO",
    "name": "Ålgård",
    "lat": "58.76417",
    "lng": "5.85253"
  },
  {
    "country": "NO",
    "name": "Ålesund",
    "lat": "62.47225",
    "lng": "6.15492"
  },
  {
    "country": "NO",
    "name": "Ålen",
    "lat": "62.84185",
    "lng": "11.3013"
  },
  {
    "country": "NO",
    "name": "Ål",
    "lat": "60.63024",
    "lng": "8.56071"
  },
  {
    "country": "NO",
    "name": "Åkrehamn",
    "lat": "59.26053",
    "lng": "5.18689"
  },
  {
    "country": "NO",
    "name": "Ågotnes",
    "lat": "60.40306",
    "lng": "5.01927"
  },
  {
    "country": "NO",
    "name": "Å i Åfjord",
    "lat": "63.96068",
    "lng": "10.22468"
  },
  {
    "country": "NO",
    "name": "Vormedal",
    "lat": "59.35607",
    "lng": "5.31962"
  },
  {
    "country": "NO",
    "name": "Tingvoll",
    "lat": "62.91318",
    "lng": "8.20526"
  },
  {
    "country": "NO",
    "name": "Oppeid",
    "lat": "68.08522",
    "lng": "15.60942"
  },
  {
    "country": "NO",
    "name": "Hommersåk",
    "lat": "58.92556",
    "lng": "5.85104"
  },
  {
    "country": "NO",
    "name": "Vikevåg",
    "lat": "59.09754",
    "lng": "5.6979"
  },
  {
    "country": "NO",
    "name": "Årøysund",
    "lat": "59.18321",
    "lng": "10.45743"
  },
  {
    "country": "NO",
    "name": "Myre",
    "lat": "68.914",
    "lng": "15.07843"
  },
  {
    "country": "NO",
    "name": "Nesoddtangen",
    "lat": "59.86244",
    "lng": "10.66308"
  },
  {
    "country": "NO",
    "name": "Askøy",
    "lat": "60.4",
    "lng": "5.18333"
  },
  {
    "country": "NO",
    "name": "Ørsta",
    "lat": "62.19983",
    "lng": "6.12904"
  },
  {
    "country": "NO",
    "name": "Ryggebyen",
    "lat": "59.375",
    "lng": "10.75"
  },
  {
    "country": "NO",
    "name": "Vedavågen",
    "lat": "59.29483",
    "lng": "5.21874"
  },
  {
    "country": "NO",
    "name": "Vestnes",
    "lat": "62.62544",
    "lng": "7.08696"
  },
  {
    "country": "NO",
    "name": "Fjellfoten",
    "lat": "60.08967",
    "lng": "11.47222"
  },
  {
    "country": "NO",
    "name": "Neskollen",
    "lat": "60.12159",
    "lng": "11.33926"
  },
  {
    "country": "NO",
    "name": "Kinsarvik",
    "lat": "60.37567",
    "lng": "6.71948"
  },
  {
    "country": "NO",
    "name": "Sjølyststranda",
    "lat": "59.92105",
    "lng": "10.68017"
  },
  {
    "country": "NO",
    "name": "Skei",
    "lat": "61.5715",
    "lng": "6.4791"
  },
  {
    "country": "NO",
    "name": "Ytrebygda",
    "lat": "60.30504",
    "lng": "5.28236"
  },
  {
    "country": "NO",
    "name": "Sandsli",
    "lat": "60.30323",
    "lng": "5.28554"
  },
  {
    "country": "NO",
    "name": "Stjørdal",
    "lat": "63.46803",
    "lng": "10.91776"
  },
  {
    "country": "NO",
    "name": "Frosta",
    "lat": "63.5891",
    "lng": "10.7423"
  },
  {
    "country": "NO",
    "name": "Vik",
    "lat": "61.05712",
    "lng": "6.57806"
  },
  {
    "country": "NO",
    "name": "Sogndal",
    "lat": "61.22908",
    "lng": "7.09674"
  },
  {
    "country": "NO",
    "name": "Rømskog",
    "lat": "59.7497",
    "lng": "11.8112"
  },
  {
    "country": "NO",
    "name": "Meieribyen",
    "lat": "59.47453",
    "lng": "11.16083"
  },
  {
    "country": "NO",
    "name": "Kirkebygda",
    "lat": "59.4921",
    "lng": "10.87432"
  },
  {
    "country": "NO",
    "name": "Elvestad",
    "lat": "59.62401",
    "lng": "10.9508"
  },
  {
    "country": "NO",
    "name": "Forsand",
    "lat": "58.9033",
    "lng": "6.1048"
  },
  {
    "country": "NO",
    "name": "Fjerdingby",
    "lat": "59.92626",
    "lng": "11.06527"
  },
  {
    "country": "NO",
    "name": "Kirkebygda",
    "lat": "59.76452",
    "lng": "11.14492"
  },
  {
    "country": "NO",
    "name": "Kjenn",
    "lat": "59.93098",
    "lng": "10.95373"
  },
  {
    "country": "NO",
    "name": "Teigebyen",
    "lat": "60.22069",
    "lng": "11.0176"
  },
  {
    "country": "NO",
    "name": "Hurdal",
    "lat": "60.43518",
    "lng": "11.06707"
  },
  {
    "country": "NO",
    "name": "Flisa",
    "lat": "60.61318",
    "lng": "12.01088"
  },
  {
    "country": "NO",
    "name": "Bergset",
    "lat": "61.89126",
    "lng": "11.07769"
  },
  {
    "country": "NO",
    "name": "Engerdal",
    "lat": "61.75904",
    "lng": "11.95937"
  },
  {
    "country": "NO",
    "name": "Lesja",
    "lat": "62.11837",
    "lng": "8.86424"
  },
  {
    "country": "NO",
    "name": "Bismo",
    "lat": "61.88406",
    "lng": "8.26665"
  },
  {
    "country": "NO",
    "name": "Ringebu",
    "lat": "61.52965",
    "lng": "10.13889"
  },
  {
    "country": "NO",
    "name": "Segalstad bru",
    "lat": "61.22819",
    "lng": "10.22255"
  },
  {
    "country": "NO",
    "name": "Slidre",
    "lat": "61.08802",
    "lng": "8.98141"
  },
  {
    "country": "NO",
    "name": "Vang",
    "lat": "61.12529",
    "lng": "8.5729"
  },
  {
    "country": "NO",
    "name": "Vik",
    "lat": "60.07706",
    "lng": "10.27908"
  },
  {
    "country": "NO",
    "name": "Trøim",
    "lat": "60.86114",
    "lng": "8.56537"
  },
  {
    "country": "NO",
    "name": "Hol",
    "lat": "60.61511",
    "lng": "8.29398"
  },
  {
    "country": "NO",
    "name": "Lierbyen",
    "lat": "59.78651",
    "lng": "10.24447"
  },
  {
    "country": "NO",
    "name": "Lampeland",
    "lat": "59.83486",
    "lng": "9.57912"
  },
  {
    "country": "NO",
    "name": "Rødberg",
    "lat": "60.26722",
    "lng": "8.94721"
  },
  {
    "country": "NO",
    "name": "Revetal",
    "lat": "59.3724",
    "lng": "10.26308"
  },
  {
    "country": "NO",
    "name": "Andebu",
    "lat": "59.30592",
    "lng": "10.17653"
  },
  {
    "country": "NO",
    "name": "Borgheim",
    "lat": "59.22629",
    "lng": "10.40745"
  },
  {
    "country": "NO",
    "name": "Sauland",
    "lat": "59.6161",
    "lng": "8.93755"
  },
  {
    "country": "NO",
    "name": "Blakstad",
    "lat": "58.5046",
    "lng": "8.64648"
  },
  {
    "country": "NO",
    "name": "Birketveit",
    "lat": "58.45909",
    "lng": "7.91692"
  },
  {
    "country": "NO",
    "name": "Helland",
    "lat": "58.19344",
    "lng": "7.52431"
  },
  {
    "country": "NO",
    "name": "Kyrkjebygda",
    "lat": "58.61523",
    "lng": "7.41391"
  },
  {
    "country": "NO",
    "name": "Kleppe",
    "lat": "58.77423",
    "lng": "5.62936"
  },
  {
    "country": "NO",
    "name": "Hjelmelandsvågen",
    "lat": "59.23692",
    "lng": "6.17907"
  },
  {
    "country": "NO",
    "name": "Sand",
    "lat": "59.48468",
    "lng": "6.25109"
  },
  {
    "country": "NO",
    "name": "Ydstebøhamn",
    "lat": "59.06227",
    "lng": "5.40249"
  },
  {
    "country": "NO",
    "name": "Bokn",
    "lat": "59.23062",
    "lng": "5.43524"
  },
  {
    "country": "NO",
    "name": "Aksdal",
    "lat": "59.42408",
    "lng": "5.44553"
  },
  {
    "country": "NO",
    "name": "Skogsvågen",
    "lat": "60.25512",
    "lng": "5.10161"
  },
  {
    "country": "NO",
    "name": "Straume",
    "lat": "60.36131",
    "lng": "5.12199"
  },
  {
    "country": "NO",
    "name": "Aurlandsvangen",
    "lat": "60.90578",
    "lng": "7.18706"
  },
  {
    "country": "NO",
    "name": "Gaupne",
    "lat": "61.40472",
    "lng": "7.29458"
  },
  {
    "country": "NO",
    "name": "Askvoll",
    "lat": "61.34673",
    "lng": "5.06224"
  },
  {
    "country": "NO",
    "name": "Hornindal",
    "lat": "61.96921",
    "lng": "6.52418"
  },
  {
    "country": "NO",
    "name": "Fiskå",
    "lat": "62.10059",
    "lng": "5.55788"
  },
  {
    "country": "NO",
    "name": "Stordal",
    "lat": "62.38203",
    "lng": "6.98629"
  },
  {
    "country": "NO",
    "name": "Sykkylven",
    "lat": "62.39594",
    "lng": "6.5875"
  },
  {
    "country": "NO",
    "name": "Valderøy",
    "lat": "62.5007",
    "lng": "6.13472"
  },
  {
    "country": "NO",
    "name": "Falkhytta",
    "lat": "62.805",
    "lng": "6.88722"
  },
  {
    "country": "NO",
    "name": "Elnesvågen",
    "lat": "62.85426",
    "lng": "7.13769"
  },
  {
    "country": "NO",
    "name": "Bruhagen",
    "lat": "63.05259",
    "lng": "7.63416"
  },
  {
    "country": "NO",
    "name": "Surnadal",
    "lat": "62.97397",
    "lng": "8.72472"
  },
  {
    "country": "NO",
    "name": "Liabøen",
    "lat": "63.12249",
    "lng": "8.31587"
  },
  {
    "country": "NO",
    "name": "Rissa",
    "lat": "63.58368",
    "lng": "9.95989"
  },
  {
    "country": "NO",
    "name": "Roan",
    "lat": "64.17269",
    "lng": "10.22898"
  },
  {
    "country": "NO",
    "name": "Steinsdalen",
    "lat": "64.29875",
    "lng": "10.51284"
  },
  {
    "country": "NO",
    "name": "Meldal",
    "lat": "63.04721",
    "lng": "9.71337"
  },
  {
    "country": "NO",
    "name": "Støren",
    "lat": "63.0391",
    "lng": "10.28501"
  },
  {
    "country": "NO",
    "name": "Børsa",
    "lat": "63.32672",
    "lng": "10.0692"
  },
  {
    "country": "NO",
    "name": "Klæbu",
    "lat": "63.29762",
    "lng": "10.48261"
  },
  {
    "country": "NO",
    "name": "Mebonden",
    "lat": "63.23034",
    "lng": "11.03099"
  },
  {
    "country": "NO",
    "name": "Leksvik",
    "lat": "63.67274",
    "lng": "10.6232"
  },
  {
    "country": "NO",
    "name": "Namdalseid",
    "lat": "64.22186",
    "lng": "11.22319"
  },
  {
    "country": "NO",
    "name": "Høylandet",
    "lat": "64.62887",
    "lng": "12.30206"
  },
  {
    "country": "NO",
    "name": "Jøa",
    "lat": "64.6591",
    "lng": "11.26535"
  },
  {
    "country": "NO",
    "name": "Silvalen",
    "lat": "65.9832",
    "lng": "12.28856"
  },
  {
    "country": "NO",
    "name": "Hattfjelldal",
    "lat": "65.59736",
    "lng": "13.98791"
  },
  {
    "country": "NO",
    "name": "Lurøy",
    "lat": "66.41887",
    "lng": "12.84248"
  },
  {
    "country": "NO",
    "name": "Husøya",
    "lat": "66.50159",
    "lng": "12.09645"
  },
  {
    "country": "NO",
    "name": "Vågaholmen",
    "lat": "66.71367",
    "lng": "13.28711"
  },
  {
    "country": "NO",
    "name": "Leinesfjorden",
    "lat": "67.77548",
    "lng": "15.01545"
  },
  {
    "country": "NO",
    "name": "Leknes",
    "lat": "68.14746",
    "lng": "13.61151"
  },
  {
    "country": "NO",
    "name": "Tennevoll",
    "lat": "68.7471",
    "lng": "17.80621"
  },
  {
    "country": "NO",
    "name": "Sørreisa",
    "lat": "69.14527",
    "lng": "18.15292"
  },
  {
    "country": "NO",
    "name": "Brøstadbotn",
    "lat": "69.08873",
    "lng": "17.69489"
  },
  {
    "country": "NO",
    "name": "Hatteng",
    "lat": "69.27072",
    "lng": "19.95944"
  },
  {
    "country": "NO",
    "name": "Breivikbotn",
    "lat": "70.58877",
    "lng": "22.28712"
  },
  {
    "country": "NO",
    "name": "Tana bru",
    "lat": "70.19909",
    "lng": "28.19039"
  },
  {
    "country": "NO",
    "name": "Ulsteinvik weather pws station",
    "lat": "62.34338",
    "lng": "5.84385"
  },
  {
    "country": "NO",
    "name": "Billingstad",
    "lat": "59.87548",
    "lng": "10.4823"
  },
  {
    "country": "NO",
    "name": "Nordstranda",
    "lat": "62.51384",
    "lng": "6.13166"
  },
  {
    "country": "NO",
    "name": "Lyefjell",
    "lat": "58.73539",
    "lng": "5.73615"
  },
  {
    "country": "NP",
    "name": "Wāliṅ",
    "lat": "27.9837",
    "lng": "83.75925"
  },
  {
    "country": "NP",
    "name": "Tulsīpur",
    "lat": "28.13099",
    "lng": "82.29726"
  },
  {
    "country": "NP",
    "name": "Ṭikāpur",
    "lat": "28.52823",
    "lng": "81.11798"
  },
  {
    "country": "NP",
    "name": "Tānsen",
    "lat": "27.86731",
    "lng": "83.5467"
  },
  {
    "country": "NP",
    "name": "Siraha",
    "lat": "26.65422",
    "lng": "86.20795"
  },
  {
    "country": "NP",
    "name": "Salyān",
    "lat": "28.37858",
    "lng": "82.1703"
  },
  {
    "country": "NP",
    "name": "Rāmechhāp",
    "lat": "27.3256",
    "lng": "86.08768"
  },
  {
    "country": "NP",
    "name": "Rājbirāj",
    "lat": "26.53968",
    "lng": "86.74796"
  },
  {
    "country": "NP",
    "name": "Pyūthān",
    "lat": "28.08867",
    "lng": "82.88427"
  },
  {
    "country": "NP",
    "name": "Pokhara",
    "lat": "28.26689",
    "lng": "83.96851"
  },
  {
    "country": "NP",
    "name": "Pātan",
    "lat": "27.67658",
    "lng": "85.31417"
  },
  {
    "country": "NP",
    "name": "Panauti̇̄",
    "lat": "27.58453",
    "lng": "85.51484"
  },
  {
    "country": "NP",
    "name": "Namche Bazar",
    "lat": "27.80528",
    "lng": "86.71058"
  },
  {
    "country": "NP",
    "name": "Nagarkot",
    "lat": "27.71522",
    "lng": "85.52075"
  },
  {
    "country": "NP",
    "name": "Malaṅgawā",
    "lat": "26.85658",
    "lng": "85.5594"
  },
  {
    "country": "NP",
    "name": "Mahendranagar",
    "lat": "28.96399",
    "lng": "80.17715"
  },
  {
    "country": "NP",
    "name": "Lobujya",
    "lat": "27.95",
    "lng": "86.81667"
  },
  {
    "country": "NP",
    "name": "Lamjung",
    "lat": "28.20992",
    "lng": "84.3638"
  },
  {
    "country": "NP",
    "name": "Lahān",
    "lat": "26.72022",
    "lng": "86.48258"
  },
  {
    "country": "NP",
    "name": "Kothari",
    "lat": "27.96057",
    "lng": "85.95667"
  },
  {
    "country": "NP",
    "name": "Kirtipur",
    "lat": "27.67872",
    "lng": "85.2775"
  },
  {
    "country": "NP",
    "name": "Khanbari",
    "lat": "27.37604",
    "lng": "87.20767"
  },
  {
    "country": "NP",
    "name": "Kathmandu",
    "lat": "27.70169",
    "lng": "85.3206"
  },
  {
    "country": "NP",
    "name": "Jumla",
    "lat": "29.27472",
    "lng": "82.18383"
  },
  {
    "country": "NP",
    "name": "Janakpur",
    "lat": "26.72882",
    "lng": "85.92628"
  },
  {
    "country": "NP",
    "name": "Jaleshwar",
    "lat": "26.64921",
    "lng": "85.80017"
  },
  {
    "country": "NP",
    "name": "Titahari",
    "lat": "26.66371",
    "lng": "87.27403"
  },
  {
    "country": "NP",
    "name": "Ilām",
    "lat": "26.90943",
    "lng": "87.92824"
  },
  {
    "country": "NP",
    "name": "Hetauda",
    "lat": "27.42839",
    "lng": "85.03219"
  },
  {
    "country": "NP",
    "name": "Gulariyā",
    "lat": "28.2058",
    "lng": "81.34532"
  },
  {
    "country": "NP",
    "name": "Gaur",
    "lat": "26.76448",
    "lng": "85.27841"
  },
  {
    "country": "NP",
    "name": "Dhulikhel",
    "lat": "27.6221",
    "lng": "85.54281"
  },
  {
    "country": "NP",
    "name": "Dharān",
    "lat": "26.81436",
    "lng": "87.27972"
  },
  {
    "country": "NP",
    "name": "Dhankutā",
    "lat": "26.98333",
    "lng": "87.33333"
  },
  {
    "country": "NP",
    "name": "Dhangaḍhi̇̄",
    "lat": "28.70137",
    "lng": "80.58975"
  },
  {
    "country": "NP",
    "name": "Dārchulā",
    "lat": "29.83",
    "lng": "80.55"
  },
  {
    "country": "NP",
    "name": "Dailekh",
    "lat": "28.84434",
    "lng": "81.71011"
  },
  {
    "country": "NP",
    "name": "Dadeldhurā",
    "lat": "29.29842",
    "lng": "80.58059"
  },
  {
    "country": "NP",
    "name": "Butwāl",
    "lat": "27.70055",
    "lng": "83.44836"
  },
  {
    "country": "NP",
    "name": "Birgañj",
    "lat": "27.01709",
    "lng": "84.8808"
  },
  {
    "country": "NP",
    "name": "Biratnagar",
    "lat": "26.45505",
    "lng": "87.27007"
  },
  {
    "country": "NP",
    "name": "Bhojpur",
    "lat": "27.93565",
    "lng": "81.77555"
  },
  {
    "country": "NP",
    "name": "Bhojpur",
    "lat": "27.1715",
    "lng": "87.04607"
  },
  {
    "country": "NP",
    "name": "Bharatpur",
    "lat": "27.6768",
    "lng": "84.43589"
  },
  {
    "country": "NP",
    "name": "Bhaktapur",
    "lat": "27.67298",
    "lng": "85.43005"
  },
  {
    "country": "NP",
    "name": "Siddharthanagar",
    "lat": "27.5",
    "lng": "83.45"
  },
  {
    "country": "NP",
    "name": "Bhadrapur",
    "lat": "26.54404",
    "lng": "88.09436"
  },
  {
    "country": "NP",
    "name": "Bardiyā",
    "lat": "28.30058",
    "lng": "81.3536"
  },
  {
    "country": "NP",
    "name": "Banepā",
    "lat": "27.63245",
    "lng": "85.52192"
  },
  {
    "country": "NP",
    "name": "Bāglung",
    "lat": "28.27189",
    "lng": "83.58975"
  },
  {
    "country": "NP",
    "name": "Achhām",
    "lat": "29.05",
    "lng": "81.3"
  },
  {
    "country": "NP",
    "name": "Besisahar",
    "lat": "28.23417",
    "lng": "82.41278"
  },
  {
    "country": "NP",
    "name": "Birendranagar",
    "lat": "28.60194",
    "lng": "81.63389"
  },
  {
    "country": "NP",
    "name": "Dipayal",
    "lat": "29.26083",
    "lng": "80.94"
  },
  {
    "country": "NP",
    "name": "Nepalgunj",
    "lat": "28.05",
    "lng": "81.61667"
  },
  {
    "country": "NP",
    "name": "Chitre",
    "lat": "28.42673",
    "lng": "83.69076"
  },
  {
    "country": "NP",
    "name": "Surkhet",
    "lat": "28.51746",
    "lng": "81.7787"
  },
  {
    "country": "NP",
    "name": "Panauti",
    "lat": "27.58466",
    "lng": "85.52122"
  },
  {
    "country": "NP",
    "name": "Inaruwa",
    "lat": "26.60675",
    "lng": "87.1478"
  },
  {
    "country": "NP",
    "name": "kankrabari Dovan",
    "lat": "27.62881",
    "lng": "85.45934"
  },
  {
    "country": "NP",
    "name": "Triyuga",
    "lat": "26.7919",
    "lng": "86.699"
  },
  {
    "country": "NP",
    "name": "Madhyapur Thimi",
    "lat": "27.68056",
    "lng": "85.3875"
  },
  {
    "country": "NP",
    "name": "Hari Bdr Tamang House",
    "lat": "27.6289",
    "lng": "85.45893"
  },
  {
    "country": "NP",
    "name": "Bhattarai Danda",
    "lat": "27.88333",
    "lng": "83.93333"
  },
  {
    "country": "NP",
    "name": "Dihi",
    "lat": "27.87552",
    "lng": "83.92759"
  },
  {
    "country": "NR",
    "name": "Yangor",
    "lat": "-0.53536",
    "lng": "166.91048"
  },
  {
    "country": "NR",
    "name": "Uaboe",
    "lat": "-0.51393",
    "lng": "166.92384"
  },
  {
    "country": "NR",
    "name": "Baiti",
    "lat": "-0.50803",
    "lng": "166.92945"
  },
  {
    "country": "NR",
    "name": "Ijuw",
    "lat": "-0.521",
    "lng": "166.95813"
  },
  {
    "country": "NR",
    "name": "Anibare",
    "lat": "-0.52792",
    "lng": "166.95249"
  },
  {
    "country": "NR",
    "name": "Anabar",
    "lat": "-0.50845",
    "lng": "166.95326"
  },
  {
    "country": "NR",
    "name": "Yaren",
    "lat": "-0.55085",
    "lng": "166.9252"
  },
  {
    "country": "NR",
    "name": "Arijejen",
    "lat": "-0.52545",
    "lng": "166.91247"
  },
  {
    "country": "NR",
    "name": "Menen",
    "lat": "-0.54539",
    "lng": "166.94871"
  },
  {
    "country": "NU",
    "name": "Alofi",
    "lat": "-19.05451",
    "lng": "-169.91768"
  },
  {
    "country": "NZ",
    "name": "Woodend",
    "lat": "-43.31667",
    "lng": "172.66667"
  },
  {
    "country": "NZ",
    "name": "Whitianga",
    "lat": "-36.83333",
    "lng": "175.7"
  },
  {
    "country": "NZ",
    "name": "Whangamata",
    "lat": "-37.2",
    "lng": "175.86667"
  },
  {
    "country": "NZ",
    "name": "Wellsford",
    "lat": "-36.28333",
    "lng": "174.51667"
  },
  {
    "country": "NZ",
    "name": "Wellington",
    "lat": "-41.28664",
    "lng": "174.77557"
  },
  {
    "country": "NZ",
    "name": "Warkworth",
    "lat": "-36.4",
    "lng": "174.66667"
  },
  {
    "country": "NZ",
    "name": "Wanganui",
    "lat": "-39.93333",
    "lng": "175.05"
  },
  {
    "country": "NZ",
    "name": "Wakefield",
    "lat": "-41.4",
    "lng": "173.05"
  },
  {
    "country": "NZ",
    "name": "Waiuku",
    "lat": "-37.24806",
    "lng": "174.73489"
  },
  {
    "country": "NZ",
    "name": "Waiouru",
    "lat": "-39.47753",
    "lng": "175.66834"
  },
  {
    "country": "NZ",
    "name": "Waimate North",
    "lat": "-35.31667",
    "lng": "173.88333"
  },
  {
    "country": "NZ",
    "name": "Waihi Beach",
    "lat": "-37.4",
    "lng": "175.93333"
  },
  {
    "country": "NZ",
    "name": "Turangi",
    "lat": "-38.99037",
    "lng": "175.80837"
  },
  {
    "country": "NZ",
    "name": "Tokoroa",
    "lat": "-38.23333",
    "lng": "175.86667"
  },
  {
    "country": "NZ",
    "name": "Tinwald",
    "lat": "-43.91667",
    "lng": "171.71667"
  },
  {
    "country": "NZ",
    "name": "Timaru",
    "lat": "-44.39672",
    "lng": "171.25364"
  },
  {
    "country": "NZ",
    "name": "Te Kauwhata",
    "lat": "-37.4",
    "lng": "175.15"
  },
  {
    "country": "NZ",
    "name": "Te Anau",
    "lat": "-45.41667",
    "lng": "167.71667"
  },
  {
    "country": "NZ",
    "name": "Taupo",
    "lat": "-38.68333",
    "lng": "176.08333"
  },
  {
    "country": "NZ",
    "name": "Takaka",
    "lat": "-40.85",
    "lng": "172.8"
  },
  {
    "country": "NZ",
    "name": "Tairua",
    "lat": "-37.01667",
    "lng": "175.85"
  },
  {
    "country": "NZ",
    "name": "Taipa",
    "lat": "-34.99604",
    "lng": "173.46665"
  },
  {
    "country": "NZ",
    "name": "Rolleston",
    "lat": "-43.58333",
    "lng": "172.38333"
  },
  {
    "country": "NZ",
    "name": "Richmond",
    "lat": "-41.33333",
    "lng": "173.18333"
  },
  {
    "country": "NZ",
    "name": "Rakaia",
    "lat": "-43.75",
    "lng": "172.01667"
  },
  {
    "country": "NZ",
    "name": "Raglan",
    "lat": "-37.8",
    "lng": "174.88333"
  },
  {
    "country": "NZ",
    "name": "Pukekohe East",
    "lat": "-37.2",
    "lng": "174.95"
  },
  {
    "country": "NZ",
    "name": "Prebbleton",
    "lat": "-43.58333",
    "lng": "172.51667"
  },
  {
    "country": "NZ",
    "name": "Portobello",
    "lat": "-45.85",
    "lng": "170.65"
  },
  {
    "country": "NZ",
    "name": "Motueka",
    "lat": "-41.13333",
    "lng": "173.01667"
  },
  {
    "country": "NZ",
    "name": "Porirua",
    "lat": "-41.13333",
    "lng": "174.85"
  },
  {
    "country": "NZ",
    "name": "Pleasant Point",
    "lat": "-44.26667",
    "lng": "171.13333"
  },
  {
    "country": "NZ",
    "name": "Wanaka",
    "lat": "-44.7",
    "lng": "169.15"
  },
  {
    "country": "NZ",
    "name": "Paraparaumu",
    "lat": "-40.91667",
    "lng": "175.01667"
  },
  {
    "country": "NZ",
    "name": "Parakai",
    "lat": "-36.65",
    "lng": "174.43333"
  },
  {
    "country": "NZ",
    "name": "Papatowai",
    "lat": "-46.56069",
    "lng": "169.47068"
  },
  {
    "country": "NZ",
    "name": "Palmerston North",
    "lat": "-40.35636",
    "lng": "175.61113"
  },
  {
    "country": "NZ",
    "name": "Paihia",
    "lat": "-35.28067",
    "lng": "174.09103"
  },
  {
    "country": "NZ",
    "name": "Oxford",
    "lat": "-43.3",
    "lng": "172.18333"
  },
  {
    "country": "NZ",
    "name": "Otorohanga",
    "lat": "-38.18333",
    "lng": "175.2"
  },
  {
    "country": "NZ",
    "name": "North Shore",
    "lat": "-36.8",
    "lng": "174.75"
  },
  {
    "country": "NZ",
    "name": "Ngunguru",
    "lat": "-35.61667",
    "lng": "174.5"
  },
  {
    "country": "NZ",
    "name": "Ngatea",
    "lat": "-37.28333",
    "lng": "175.5"
  },
  {
    "country": "NZ",
    "name": "New Plymouth",
    "lat": "-39.06667",
    "lng": "174.08333"
  },
  {
    "country": "NZ",
    "name": "Nelson",
    "lat": "-41.27078",
    "lng": "173.28404"
  },
  {
    "country": "NZ",
    "name": "Napier",
    "lat": "-39.4926",
    "lng": "176.91233"
  },
  {
    "country": "NZ",
    "name": "Murupara",
    "lat": "-38.46667",
    "lng": "176.7"
  },
  {
    "country": "NZ",
    "name": "Muriwai Beach",
    "lat": "-36.81667",
    "lng": "174.45"
  },
  {
    "country": "NZ",
    "name": "Moerewa",
    "lat": "-35.38333",
    "lng": "174.03333"
  },
  {
    "country": "NZ",
    "name": "Methven",
    "lat": "-43.63333",
    "lng": "171.65"
  },
  {
    "country": "NZ",
    "name": "Maungatapere",
    "lat": "-35.75",
    "lng": "174.2"
  },
  {
    "country": "NZ",
    "name": "Mapua",
    "lat": "-41.25",
    "lng": "173.1"
  },
  {
    "country": "NZ",
    "name": "Manukau City",
    "lat": "-36.99282",
    "lng": "174.87986"
  },
  {
    "country": "NZ",
    "name": "Mangere",
    "lat": "-36.96807",
    "lng": "174.79875"
  },
  {
    "country": "NZ",
    "name": "Maketu",
    "lat": "-37.76667",
    "lng": "176.45"
  },
  {
    "country": "NZ",
    "name": "Lower Hutt",
    "lat": "-41.21667",
    "lng": "174.91667"
  },
  {
    "country": "NZ",
    "name": "Lincoln",
    "lat": "-43.65",
    "lng": "172.48333"
  },
  {
    "country": "NZ",
    "name": "Leeston",
    "lat": "-43.76667",
    "lng": "172.3"
  },
  {
    "country": "NZ",
    "name": "Kingston",
    "lat": "-45.33288",
    "lng": "168.71476"
  },
  {
    "country": "NZ",
    "name": "Kerikeri",
    "lat": "-35.22676",
    "lng": "173.94739"
  },
  {
    "country": "NZ",
    "name": "Kelburn",
    "lat": "-41.28333",
    "lng": "174.76667"
  },
  {
    "country": "NZ",
    "name": "Kawerau",
    "lat": "-38.1",
    "lng": "176.7"
  },
  {
    "country": "NZ",
    "name": "Kawakawa",
    "lat": "-35.38333",
    "lng": "174.06667"
  },
  {
    "country": "NZ",
    "name": "Katikati",
    "lat": "-37.55",
    "lng": "175.91667"
  },
  {
    "country": "NZ",
    "name": "Invercargill",
    "lat": "-46.4",
    "lng": "168.35"
  },
  {
    "country": "NZ",
    "name": "Hastings",
    "lat": "-39.6381",
    "lng": "176.84918"
  },
  {
    "country": "NZ",
    "name": "Hamilton",
    "lat": "-37.78333",
    "lng": "175.28333"
  },
  {
    "country": "NZ",
    "name": "Edgecumbe",
    "lat": "-37.98333",
    "lng": "176.83333"
  },
  {
    "country": "NZ",
    "name": "Dunedin",
    "lat": "-45.87416",
    "lng": "170.50361"
  },
  {
    "country": "NZ",
    "name": "Dargaville",
    "lat": "-35.93333",
    "lng": "173.88333"
  },
  {
    "country": "NZ",
    "name": "Darfield",
    "lat": "-43.48333",
    "lng": "172.11667"
  },
  {
    "country": "NZ",
    "name": "Coromandel",
    "lat": "-36.7611",
    "lng": "175.49634"
  },
  {
    "country": "NZ",
    "name": "Christchurch",
    "lat": "-43.53333",
    "lng": "172.63333"
  },
  {
    "country": "NZ",
    "name": "Castlepoint",
    "lat": "-40.9",
    "lng": "176.21667"
  },
  {
    "country": "NZ",
    "name": "Burnham",
    "lat": "-43.61667",
    "lng": "172.31667"
  },
  {
    "country": "NZ",
    "name": "Bulls",
    "lat": "-40.17487",
    "lng": "175.38463"
  },
  {
    "country": "NZ",
    "name": "Brooklyn",
    "lat": "-41.30586",
    "lng": "174.76257"
  },
  {
    "country": "NZ",
    "name": "Brightwater",
    "lat": "-41.38333",
    "lng": "173.11667"
  },
  {
    "country": "NZ",
    "name": "Auckland",
    "lat": "-36.84853",
    "lng": "174.76349"
  },
  {
    "country": "NZ",
    "name": "Amberley",
    "lat": "-43.15589",
    "lng": "172.72975"
  },
  {
    "country": "NZ",
    "name": "Ahipara",
    "lat": "-35.16667",
    "lng": "173.16667"
  },
  {
    "country": "NZ",
    "name": "Opunake",
    "lat": "-39.45556",
    "lng": "173.85833"
  },
  {
    "country": "NZ",
    "name": "Eltham",
    "lat": "-39.42917",
    "lng": "174.3"
  },
  {
    "country": "NZ",
    "name": "Hawera",
    "lat": "-39.59167",
    "lng": "174.28333"
  },
  {
    "country": "NZ",
    "name": "Patea",
    "lat": "-39.75833",
    "lng": "174.48333"
  },
  {
    "country": "NZ",
    "name": "Foxton",
    "lat": "-40.46667",
    "lng": "175.3"
  },
  {
    "country": "NZ",
    "name": "Levin",
    "lat": "-40.63333",
    "lng": "175.275"
  },
  {
    "country": "NZ",
    "name": "Otaki",
    "lat": "-40.75833",
    "lng": "175.15"
  },
  {
    "country": "NZ",
    "name": "Wairoa",
    "lat": "-39.03333",
    "lng": "177.36667"
  },
  {
    "country": "NZ",
    "name": "Gisborne",
    "lat": "-38.65333",
    "lng": "178.00417"
  },
  {
    "country": "NZ",
    "name": "Waipawa",
    "lat": "-41.41222",
    "lng": "175.51528"
  },
  {
    "country": "NZ",
    "name": "Masterton",
    "lat": "-40.95972",
    "lng": "175.6575"
  },
  {
    "country": "NZ",
    "name": "Hokitika",
    "lat": "-42.71667",
    "lng": "170.96667"
  },
  {
    "country": "NZ",
    "name": "Greymouth",
    "lat": "-42.46667",
    "lng": "171.2"
  },
  {
    "country": "NZ",
    "name": "Westport",
    "lat": "-41.75262",
    "lng": "171.6037"
  },
  {
    "country": "NZ",
    "name": "Bluff",
    "lat": "-46.6",
    "lng": "168.33333"
  },
  {
    "country": "NZ",
    "name": "Riverton",
    "lat": "-46.35",
    "lng": "168.01667"
  },
  {
    "country": "NZ",
    "name": "Winton",
    "lat": "-46.15",
    "lng": "168.33333"
  },
  {
    "country": "NZ",
    "name": "Tauranga",
    "lat": "-37.68611",
    "lng": "176.16667"
  },
  {
    "country": "NZ",
    "name": "Waitara",
    "lat": "-39.00158",
    "lng": "174.23836"
  },
  {
    "country": "NZ",
    "name": "Milton",
    "lat": "-46.12083",
    "lng": "169.96944"
  },
  {
    "country": "NZ",
    "name": "Balclutha",
    "lat": "-46.23389",
    "lng": "169.75"
  },
  {
    "country": "NZ",
    "name": "Paeroa",
    "lat": "-37.36667",
    "lng": "175.66667"
  },
  {
    "country": "NZ",
    "name": "Waihi",
    "lat": "-37.38333",
    "lng": "175.83333"
  },
  {
    "country": "NZ",
    "name": "Papakura",
    "lat": "-37.06573",
    "lng": "174.94393"
  },
  {
    "country": "NZ",
    "name": "Whakatane",
    "lat": "-37.95855",
    "lng": "176.98545"
  },
  {
    "country": "NZ",
    "name": "Opotiki",
    "lat": "-38.00915",
    "lng": "177.28706"
  },
  {
    "country": "NZ",
    "name": "Thames",
    "lat": "-37.13832",
    "lng": "175.54011"
  },
  {
    "country": "NZ",
    "name": "Waitangi",
    "lat": "-43.95353",
    "lng": "-176.55973"
  },
  {
    "country": "NZ",
    "name": "Gore",
    "lat": "-46.10282",
    "lng": "168.94357"
  },
  {
    "country": "NZ",
    "name": "Queenstown",
    "lat": "-45.03023",
    "lng": "168.66271"
  },
  {
    "country": "NZ",
    "name": "Arrowtown",
    "lat": "-44.93837",
    "lng": "168.81007"
  },
  {
    "country": "NZ",
    "name": "Oamaru",
    "lat": "-45.09758",
    "lng": "170.97087"
  },
  {
    "country": "NZ",
    "name": "Ashburton",
    "lat": "-43.89834",
    "lng": "171.73011"
  },
  {
    "country": "NZ",
    "name": "Kaiapoi",
    "lat": "-43.37832",
    "lng": "172.64013"
  },
  {
    "country": "NZ",
    "name": "Kaitaia",
    "lat": "-35.11485",
    "lng": "173.26366"
  },
  {
    "country": "NZ",
    "name": "Whangarei",
    "lat": "-35.73167",
    "lng": "174.32391"
  },
  {
    "country": "NZ",
    "name": "Ruakaka",
    "lat": "-35.90818",
    "lng": "174.45019"
  },
  {
    "country": "NZ",
    "name": "Takanini",
    "lat": "-37.0482",
    "lng": "174.90019"
  },
  {
    "country": "NZ",
    "name": "Red Hill",
    "lat": "-37.0582",
    "lng": "174.97019"
  },
  {
    "country": "NZ",
    "name": "Rothesay Bay",
    "lat": "-36.72602",
    "lng": "174.74064"
  },
  {
    "country": "NZ",
    "name": "Murrays Bay",
    "lat": "-36.72819",
    "lng": "174.75019"
  },
  {
    "country": "NZ",
    "name": "Wiri",
    "lat": "-36.9982",
    "lng": "174.86019"
  },
  {
    "country": "NZ",
    "name": "Pakuranga",
    "lat": "-36.88333",
    "lng": "174.91667"
  },
  {
    "country": "NZ",
    "name": "Tamaki",
    "lat": "-36.8882",
    "lng": "174.86019"
  },
  {
    "country": "NZ",
    "name": "Titirangi",
    "lat": "-36.93754",
    "lng": "174.65584"
  },
  {
    "country": "NZ",
    "name": "Matamata",
    "lat": "-37.8106",
    "lng": "175.76237"
  },
  {
    "country": "NZ",
    "name": "Cambridge",
    "lat": "-37.87822",
    "lng": "175.4402"
  },
  {
    "country": "NZ",
    "name": "Rotorua",
    "lat": "-38.13874",
    "lng": "176.24516"
  },
  {
    "country": "NZ",
    "name": "Picton",
    "lat": "-41.29067",
    "lng": "174.00801"
  },
  {
    "country": "NZ",
    "name": "Blenheim",
    "lat": "-41.51603",
    "lng": "173.9528"
  },
  {
    "country": "NZ",
    "name": "Petone",
    "lat": "-41.22827",
    "lng": "174.87019"
  },
  {
    "country": "NZ",
    "name": "Upper Hutt",
    "lat": "-41.13827",
    "lng": "175.0502"
  },
  {
    "country": "NZ",
    "name": "Taradale",
    "lat": "-39.53333",
    "lng": "176.85"
  },
  {
    "country": "NZ",
    "name": "Ngaruawahia",
    "lat": "-37.66738",
    "lng": "175.15554"
  },
  {
    "country": "NZ",
    "name": "Waitakere",
    "lat": "-36.91754",
    "lng": "174.65773"
  },
  {
    "country": "NZ",
    "name": "Kaikoura",
    "lat": "-42.40749",
    "lng": "173.68132"
  },
  {
    "country": "NZ",
    "name": "Rosebank",
    "lat": "-36.87495",
    "lng": "174.66991"
  },
  {
    "country": "NZ",
    "name": "Linton Military Camp",
    "lat": "-40.40309",
    "lng": "175.58302"
  },
  {
    "country": "OM",
    "name": "Sur",
    "lat": "22.56667",
    "lng": "59.52889"
  },
  {
    "country": "OM",
    "name": "Sohar",
    "lat": "24.34745",
    "lng": "56.70937"
  },
  {
    "country": "OM",
    "name": "Sufālat Samā’il",
    "lat": "23.31667",
    "lng": "58.01667"
  },
  {
    "country": "OM",
    "name": "Shināş",
    "lat": "24.7426",
    "lng": "56.46698"
  },
  {
    "country": "OM",
    "name": "Şalālah",
    "lat": "17.01505",
    "lng": "54.09237"
  },
  {
    "country": "OM",
    "name": "Şaḩam",
    "lat": "24.17222",
    "lng": "56.88861"
  },
  {
    "country": "OM",
    "name": "Nizwá",
    "lat": "22.93333",
    "lng": "57.53333"
  },
  {
    "country": "OM",
    "name": "Muscat",
    "lat": "23.58413",
    "lng": "58.40778"
  },
  {
    "country": "OM",
    "name": "Khasab",
    "lat": "26.17993",
    "lng": "56.24774"
  },
  {
    "country": "OM",
    "name": "Izkī",
    "lat": "22.93333",
    "lng": "57.76667"
  },
  {
    "country": "OM",
    "name": "‘Ibrī",
    "lat": "23.22573",
    "lng": "56.51572"
  },
  {
    "country": "OM",
    "name": "Ibrā’",
    "lat": "22.69057",
    "lng": "58.53337"
  },
  {
    "country": "OM",
    "name": "Haymā’",
    "lat": "19.95931",
    "lng": "56.27575"
  },
  {
    "country": "OM",
    "name": "Dib Dibba",
    "lat": "26.19778",
    "lng": "56.25778"
  },
  {
    "country": "OM",
    "name": "Bidbid",
    "lat": "23.40787",
    "lng": "58.1283"
  },
  {
    "country": "OM",
    "name": "Bawshar",
    "lat": "23.57769",
    "lng": "58.39982"
  },
  {
    "country": "OM",
    "name": "Barkā’",
    "lat": "23.67872",
    "lng": "57.88605"
  },
  {
    "country": "OM",
    "name": "Bahlā’",
    "lat": "22.97886",
    "lng": "57.3047"
  },
  {
    "country": "OM",
    "name": "Badīyah",
    "lat": "22.45",
    "lng": "58.8"
  },
  {
    "country": "OM",
    "name": "As Suwayq",
    "lat": "23.84944",
    "lng": "57.43861"
  },
  {
    "country": "OM",
    "name": "Seeb",
    "lat": "23.67027",
    "lng": "58.18911"
  },
  {
    "country": "OM",
    "name": "Rustaq",
    "lat": "23.39083",
    "lng": "57.42444"
  },
  {
    "country": "OM",
    "name": "Al Qābil",
    "lat": "22.571",
    "lng": "58.69472"
  },
  {
    "country": "OM",
    "name": "Liwá",
    "lat": "24.53077",
    "lng": "56.563"
  },
  {
    "country": "OM",
    "name": "Al Khābūrah",
    "lat": "23.97144",
    "lng": "57.09313"
  },
  {
    "country": "OM",
    "name": "Al Buraymī",
    "lat": "24.25088",
    "lng": "55.79312"
  },
  {
    "country": "OM",
    "name": "Adam",
    "lat": "22.37934",
    "lng": "57.52718"
  },
  {
    "country": "OM",
    "name": "Madḩā’ al Jadīdah",
    "lat": "25.28345",
    "lng": "56.3328"
  },
  {
    "country": "OM",
    "name": "Yanqul",
    "lat": "23.58645",
    "lng": "56.53969"
  },
  {
    "country": "OM",
    "name": "Bayt al ‘Awābī",
    "lat": "23.30324",
    "lng": "57.52459"
  },
  {
    "country": "OM",
    "name": "Al Mazyūnah",
    "lat": "17.83836",
    "lng": "52.66042"
  },
  {
    "country": "OM",
    "name": "Oman Smart Future City",
    "lat": "23.6527",
    "lng": "57.59926"
  },
  {
    "country": "PA",
    "name": "Zapotillo",
    "lat": "8.00532",
    "lng": "-81.50653"
  },
  {
    "country": "PA",
    "name": "Zangüengas",
    "lat": "8.95609",
    "lng": "-79.87037"
  },
  {
    "country": "PA",
    "name": "Yaviza",
    "lat": "8.15835",
    "lng": "-77.69276"
  },
  {
    "country": "PA",
    "name": "Yape",
    "lat": "8.09839",
    "lng": "-77.59817"
  },
  {
    "country": "PA",
    "name": "Volcán",
    "lat": "8.77291",
    "lng": "-82.63823"
  },
  {
    "country": "PA",
    "name": "Vista Hermosa",
    "lat": "8.52687",
    "lng": "-80.37486"
  },
  {
    "country": "PA",
    "name": "Vista Alegre",
    "lat": "8.92772",
    "lng": "-79.7028"
  },
  {
    "country": "PA",
    "name": "Villa Rosario",
    "lat": "8.77379",
    "lng": "-79.87547"
  },
  {
    "country": "PA",
    "name": "Villa Carmen",
    "lat": "8.79832",
    "lng": "-79.86929"
  },
  {
    "country": "PA",
    "name": "Viguí",
    "lat": "8.33921",
    "lng": "-81.49823"
  },
  {
    "country": "PA",
    "name": "Viento Frío",
    "lat": "9.58263",
    "lng": "-79.4069"
  },
  {
    "country": "PA",
    "name": "Veracruz",
    "lat": "8.88988",
    "lng": "-79.62603"
  },
  {
    "country": "PA",
    "name": "Veladero",
    "lat": "8.23136",
    "lng": "-81.65417"
  },
  {
    "country": "PA",
    "name": "Vallerriquito",
    "lat": "7.62163",
    "lng": "-80.31975"
  },
  {
    "country": "PA",
    "name": "Valle Rico",
    "lat": "7.62011",
    "lng": "-80.35076"
  },
  {
    "country": "PA",
    "name": "Utirá",
    "lat": "7.97208",
    "lng": "-81.21777"
  },
  {
    "country": "PA",
    "name": "Ustupo",
    "lat": "9.13112",
    "lng": "-77.9262"
  },
  {
    "country": "PA",
    "name": "Tucutí",
    "lat": "7.92794",
    "lng": "-77.94562"
  },
  {
    "country": "PA",
    "name": "Tubualá",
    "lat": "9.51667",
    "lng": "-79.03333"
  },
  {
    "country": "PA",
    "name": "Tres Quebradas",
    "lat": "7.84018",
    "lng": "-80.4074"
  },
  {
    "country": "PA",
    "name": "Toza",
    "lat": "8.34542",
    "lng": "-80.64012"
  },
  {
    "country": "PA",
    "name": "Tonosí",
    "lat": "7.40684",
    "lng": "-80.44217"
  },
  {
    "country": "PA",
    "name": "Tolé",
    "lat": "8.23989",
    "lng": "-81.67168"
  },
  {
    "country": "PA",
    "name": "Tocumen",
    "lat": "9.08939",
    "lng": "-79.3831"
  },
  {
    "country": "PA",
    "name": "Tobobe",
    "lat": "9.12111",
    "lng": "-81.82471"
  },
  {
    "country": "PA",
    "name": "Toabré",
    "lat": "8.65131",
    "lng": "-80.32017"
  },
  {
    "country": "PA",
    "name": "Tinajas",
    "lat": "8.55281",
    "lng": "-82.45963"
  },
  {
    "country": "PA",
    "name": "Tijeras",
    "lat": "8.47514",
    "lng": "-82.56058"
  },
  {
    "country": "PA",
    "name": "Tebario",
    "lat": "7.71369",
    "lng": "-80.97825"
  },
  {
    "country": "PA",
    "name": "Pueblo Nuevo",
    "lat": "8.15036",
    "lng": "-78.2503"
  },
  {
    "country": "PA",
    "name": "Sortova",
    "lat": "8.54642",
    "lng": "-82.6517"
  },
  {
    "country": "PA",
    "name": "Sorá",
    "lat": "8.63191",
    "lng": "-80.00888"
  },
  {
    "country": "PA",
    "name": "Soná",
    "lat": "8.01223",
    "lng": "-81.32163"
  },
  {
    "country": "PA",
    "name": "Sitio Prado",
    "lat": "8.37233",
    "lng": "-81.58141"
  },
  {
    "country": "PA",
    "name": "Sioguí Arriba",
    "lat": "8.53865",
    "lng": "-82.68619"
  },
  {
    "country": "PA",
    "name": "Sioguí Abajo",
    "lat": "8.48678",
    "lng": "-82.66539"
  },
  {
    "country": "PA",
    "name": "Sardinilla",
    "lat": "9.29828",
    "lng": "-79.63956"
  },
  {
    "country": "PA",
    "name": "San Vicente de Bique",
    "lat": "8.91143",
    "lng": "-79.6736"
  },
  {
    "country": "PA",
    "name": "San Vicente",
    "lat": "9.11445",
    "lng": "-79.59755"
  },
  {
    "country": "PA",
    "name": "Santo Tomás",
    "lat": "8.38959",
    "lng": "-82.65058"
  },
  {
    "country": "PA",
    "name": "Santo Domingo",
    "lat": "8.50803",
    "lng": "-82.71295"
  },
  {
    "country": "PA",
    "name": "Santo Domingo",
    "lat": "7.74614",
    "lng": "-80.24173"
  },
  {
    "country": "PA",
    "name": "Santiago de Veraguas",
    "lat": "8.1",
    "lng": "-80.98333"
  },
  {
    "country": "PA",
    "name": "Santa Rosa Número Uno",
    "lat": "8.86459",
    "lng": "-80.09923"
  },
  {
    "country": "PA",
    "name": "Santa Rosa",
    "lat": "8.59958",
    "lng": "-82.68489"
  },
  {
    "country": "PA",
    "name": "Santa Rita",
    "lat": "8.85681",
    "lng": "-79.87954"
  },
  {
    "country": "PA",
    "name": "Santa Rita",
    "lat": "8.49307",
    "lng": "-80.18298"
  },
  {
    "country": "PA",
    "name": "Santa Marta",
    "lat": "8.51406",
    "lng": "-82.6987"
  },
  {
    "country": "PA",
    "name": "Santa María",
    "lat": "8.11143",
    "lng": "-80.66582"
  },
  {
    "country": "PA",
    "name": "Santa Isabel",
    "lat": "9.53922",
    "lng": "-79.1957"
  },
  {
    "country": "PA",
    "name": "Santa Fé",
    "lat": "8.65525",
    "lng": "-78.1614"
  },
  {
    "country": "PA",
    "name": "Santa Fé",
    "lat": "8.51063",
    "lng": "-81.07802"
  },
  {
    "country": "PA",
    "name": "Santa Cruz",
    "lat": "8.64269",
    "lng": "-82.75939"
  },
  {
    "country": "PA",
    "name": "Santa Cruz",
    "lat": "8.23219",
    "lng": "-81.91323"
  },
  {
    "country": "PA",
    "name": "Santa Clara",
    "lat": "9.02875",
    "lng": "-79.75443"
  },
  {
    "country": "PA",
    "name": "Santa Clara",
    "lat": "8.83376",
    "lng": "-82.77945"
  },
  {
    "country": "PA",
    "name": "Santa Catalina",
    "lat": "8.78193",
    "lng": "-81.3279"
  },
  {
    "country": "PA",
    "name": "Santa Ana Arriba",
    "lat": "7.933",
    "lng": "-80.36369"
  },
  {
    "country": "PA",
    "name": "San Pedro del Espino",
    "lat": "8.14011",
    "lng": "-81.08663"
  },
  {
    "country": "PA",
    "name": "San Pablo Viejo Abajo",
    "lat": "8.45339",
    "lng": "-82.50179"
  },
  {
    "country": "PA",
    "name": "San Pablo Nuevo Abajo",
    "lat": "8.42558",
    "lng": "-82.50173"
  },
  {
    "country": "PA",
    "name": "San Miguelito",
    "lat": "9.05032",
    "lng": "-79.47068"
  },
  {
    "country": "PA",
    "name": "San Miguel",
    "lat": "8.45685",
    "lng": "-78.93695"
  },
  {
    "country": "PA",
    "name": "San Marcelo",
    "lat": "8.27252",
    "lng": "-81.15988"
  },
  {
    "country": "PA",
    "name": "San Lorenzo",
    "lat": "8.30561",
    "lng": "-82.10114"
  },
  {
    "country": "PA",
    "name": "San Juan",
    "lat": "8.30311",
    "lng": "-81.01575"
  },
  {
    "country": "PA",
    "name": "San Juan",
    "lat": "8.27724",
    "lng": "-81.99345"
  },
  {
    "country": "PA",
    "name": "San José",
    "lat": "8.93333",
    "lng": "-79.73333"
  },
  {
    "country": "PA",
    "name": "San José",
    "lat": "8.5324",
    "lng": "-79.93089"
  },
  {
    "country": "PA",
    "name": "San José",
    "lat": "8.46704",
    "lng": "-80.80514"
  },
  {
    "country": "PA",
    "name": "San José",
    "lat": "8.37261",
    "lng": "-81.40486"
  },
  {
    "country": "PA",
    "name": "San José",
    "lat": "7.67395",
    "lng": "-80.24438"
  },
  {
    "country": "PA",
    "name": "San Ignacio de Tupile",
    "lat": "9.28905",
    "lng": "-78.15206"
  },
  {
    "country": "PA",
    "name": "San Francisco",
    "lat": "8.24652",
    "lng": "-80.97472"
  },
  {
    "country": "PA",
    "name": "San Francisco",
    "lat": "8.06667",
    "lng": "-81.36667"
  },
  {
    "country": "PA",
    "name": "San Félix",
    "lat": "8.29063",
    "lng": "-81.86702"
  },
  {
    "country": "PA",
    "name": "San Felipe",
    "lat": "8.95118",
    "lng": "-79.53726"
  },
  {
    "country": "PA",
    "name": "San Carlos",
    "lat": "8.51663",
    "lng": "-82.50906"
  },
  {
    "country": "PA",
    "name": "San Carlos",
    "lat": "8.47323",
    "lng": "-79.96104"
  },
  {
    "country": "PA",
    "name": "San Bartolo",
    "lat": "8.21063",
    "lng": "-81.27572"
  },
  {
    "country": "PA",
    "name": "San Antonio",
    "lat": "8.0729",
    "lng": "-80.93187"
  },
  {
    "country": "PA",
    "name": "San Andrés",
    "lat": "8.6026",
    "lng": "-82.72588"
  },
  {
    "country": "PA",
    "name": "Salud",
    "lat": "9.19841",
    "lng": "-80.13186"
  },
  {
    "country": "PA",
    "name": "Sabanitas",
    "lat": "9.34269",
    "lng": "-79.80961"
  },
  {
    "country": "PA",
    "name": "Sabana Grande",
    "lat": "7.88002",
    "lng": "-80.63818"
  },
  {
    "country": "PA",
    "name": "Sabana Grande",
    "lat": "7.83543",
    "lng": "-80.3649"
  },
  {
    "country": "PA",
    "name": "Rovira Arriba",
    "lat": "8.63822",
    "lng": "-82.49965"
  },
  {
    "country": "PA",
    "name": "Rodeo Viejo",
    "lat": "8.11205",
    "lng": "-81.31684"
  },
  {
    "country": "PA",
    "name": "Valle del Risco",
    "lat": "9.23064",
    "lng": "-82.42748"
  },
  {
    "country": "PA",
    "name": "Río Sereno",
    "lat": "8.81741",
    "lng": "-82.85731"
  },
  {
    "country": "PA",
    "name": "Río Rita",
    "lat": "9.30296",
    "lng": "-79.79234"
  },
  {
    "country": "PA",
    "name": "Río Hondo",
    "lat": "7.71192",
    "lng": "-80.35904"
  },
  {
    "country": "PA",
    "name": "Río Hato",
    "lat": "8.3794",
    "lng": "-80.16621"
  },
  {
    "country": "PA",
    "name": "Río Grande",
    "lat": "8.61933",
    "lng": "-81.2883"
  },
  {
    "country": "PA",
    "name": "Río Grande",
    "lat": "8.42679",
    "lng": "-80.48457"
  },
  {
    "country": "PA",
    "name": "Río Grande",
    "lat": "7.71907",
    "lng": "-81.33423"
  },
  {
    "country": "PA",
    "name": "Gatún",
    "lat": "9.28922",
    "lng": "-79.77204"
  },
  {
    "country": "PA",
    "name": "Río Duque",
    "lat": "9.25688",
    "lng": "-79.67937"
  },
  {
    "country": "PA",
    "name": "Río de Jesús",
    "lat": "7.97882",
    "lng": "-81.16162"
  },
  {
    "country": "PA",
    "name": "Río Congo",
    "lat": "8.96666",
    "lng": "-79.76105"
  },
  {
    "country": "PA",
    "name": "Río Alejandro",
    "lat": "9.37149",
    "lng": "-79.78809"
  },
  {
    "country": "PA",
    "name": "Río Abajo",
    "lat": "9.01667",
    "lng": "-79.5"
  },
  {
    "country": "PA",
    "name": "Rincón Hondo",
    "lat": "7.84436",
    "lng": "-80.60397"
  },
  {
    "country": "PA",
    "name": "Rincón",
    "lat": "8.46374",
    "lng": "-82.27951"
  },
  {
    "country": "PA",
    "name": "Remedios",
    "lat": "8.22436",
    "lng": "-81.82747"
  },
  {
    "country": "PA",
    "name": "Panama City",
    "lat": "9.33404",
    "lng": "-79.89172"
  },
  {
    "country": "PA",
    "name": "Querévalo",
    "lat": "8.37174",
    "lng": "-82.5267"
  },
  {
    "country": "PA",
    "name": "Quebrada de Piedra",
    "lat": "8.09418",
    "lng": "-81.67915"
  },
  {
    "country": "PA",
    "name": "Quebrada de Oro",
    "lat": "8.03548",
    "lng": "-81.38692"
  },
  {
    "country": "PA",
    "name": "Quebrada de Loro",
    "lat": "8.35924",
    "lng": "-81.92724"
  },
  {
    "country": "PA",
    "name": "Quebrada Canoa",
    "lat": "8.43333",
    "lng": "-81.78333"
  },
  {
    "country": "PA",
    "name": "Quebrada Bonita Adentro",
    "lat": "9.29662",
    "lng": "-79.70606"
  },
  {
    "country": "PA",
    "name": "Punta Róbalo",
    "lat": "9.03631",
    "lng": "-82.24952"
  },
  {
    "country": "PA",
    "name": "Punta Laurel",
    "lat": "9.141",
    "lng": "-82.12717"
  },
  {
    "country": "PA",
    "name": "Punta Peña",
    "lat": "8.91659",
    "lng": "-82.18488"
  },
  {
    "country": "PA",
    "name": "Punta de Burica",
    "lat": "8.03333",
    "lng": "-82.86667"
  },
  {
    "country": "PA",
    "name": "Puerto Vidal",
    "lat": "8.04834",
    "lng": "-81.60499"
  },
  {
    "country": "PA",
    "name": "Puerto Pilón",
    "lat": "9.36316",
    "lng": "-79.79333"
  },
  {
    "country": "PA",
    "name": "Puerto Obaldía",
    "lat": "8.66632",
    "lng": "-77.41922"
  },
  {
    "country": "PA",
    "name": "Puerto Escondido",
    "lat": "9.19333",
    "lng": "-80.08833"
  },
  {
    "country": "PA",
    "name": "Puerto Caimito",
    "lat": "8.87022",
    "lng": "-79.71423"
  },
  {
    "country": "PA",
    "name": "Puerto Armuelles",
    "lat": "8.27775",
    "lng": "-82.86206"
  },
  {
    "country": "PA",
    "name": "Pueblo Viejo",
    "lat": "8.25081",
    "lng": "-81.66259"
  },
  {
    "country": "PA",
    "name": "Púcuro",
    "lat": "7.97876",
    "lng": "-77.48758"
  },
  {
    "country": "PA",
    "name": "Progreso",
    "lat": "8.44669",
    "lng": "-82.83859"
  },
  {
    "country": "PA",
    "name": "Potuga",
    "lat": "8.06317",
    "lng": "-80.62271"
  },
  {
    "country": "PA",
    "name": "Potrero Grande",
    "lat": "8.88051",
    "lng": "-79.82795"
  },
  {
    "country": "PA",
    "name": "Potrero de Caña",
    "lat": "8.29345",
    "lng": "-81.69903"
  },
  {
    "country": "PA",
    "name": "Potrerillos Arriba",
    "lat": "8.68547",
    "lng": "-82.4909"
  },
  {
    "country": "PA",
    "name": "Potrerillos Abajo",
    "lat": "8.63978",
    "lng": "-82.4856"
  },
  {
    "country": "PA",
    "name": "Portobelo",
    "lat": "9.55303",
    "lng": "-79.65693"
  },
  {
    "country": "PA",
    "name": "Portobelillo",
    "lat": "8.01738",
    "lng": "-80.59538"
  },
  {
    "country": "PA",
    "name": "Ponuga",
    "lat": "7.88245",
    "lng": "-80.9788"
  },
  {
    "country": "PA",
    "name": "Pocrí",
    "lat": "8.25814",
    "lng": "-80.55"
  },
  {
    "country": "PA",
    "name": "Pocrí",
    "lat": "7.65816",
    "lng": "-80.12119"
  },
  {
    "country": "PA",
    "name": "Plaza de Caisán",
    "lat": "8.73672",
    "lng": "-82.81968"
  },
  {
    "country": "PA",
    "name": "Playón Chico",
    "lat": "9.31128",
    "lng": "-78.2327"
  },
  {
    "country": "PA",
    "name": "Playa Leona",
    "lat": "8.78389",
    "lng": "-79.77547"
  },
  {
    "country": "PA",
    "name": "Playa Chiquita",
    "lat": "9.5662",
    "lng": "-79.29185"
  },
  {
    "country": "PA",
    "name": "Plan de Chorcha",
    "lat": "8.46168",
    "lng": "-82.15924"
  },
  {
    "country": "PA",
    "name": "Pinogana",
    "lat": "8.11301",
    "lng": "-77.68851"
  },
  {
    "country": "PA",
    "name": "Piedras Gordas",
    "lat": "8.63777",
    "lng": "-80.51024"
  },
  {
    "country": "PA",
    "name": "Piedras Gordas",
    "lat": "8.52419",
    "lng": "-80.91152"
  },
  {
    "country": "PA",
    "name": "Piedra Roja",
    "lat": "8.5703",
    "lng": "-81.74661"
  },
  {
    "country": "PA",
    "name": "Pesé",
    "lat": "7.90863",
    "lng": "-80.61433"
  },
  {
    "country": "PA",
    "name": "Perales",
    "lat": "7.77461",
    "lng": "-80.32494"
  },
  {
    "country": "PA",
    "name": "Penonomé",
    "lat": "8.51889",
    "lng": "-80.35727"
  },
  {
    "country": "PA",
    "name": "Peñas Chatas",
    "lat": "8.01502",
    "lng": "-80.80366"
  },
  {
    "country": "PA",
    "name": "Peña Blanca",
    "lat": "8.46171",
    "lng": "-81.6788"
  },
  {
    "country": "PA",
    "name": "Peña Blanca",
    "lat": "7.71931",
    "lng": "-80.28366"
  },
  {
    "country": "PA",
    "name": "Pedregal",
    "lat": "9.06667",
    "lng": "-79.43333"
  },
  {
    "country": "PA",
    "name": "Pedregal",
    "lat": "8.36586",
    "lng": "-82.43524"
  },
  {
    "country": "PA",
    "name": "Pedasí",
    "lat": "7.53034",
    "lng": "-80.02699"
  },
  {
    "country": "PA",
    "name": "Paya",
    "lat": "7.90071",
    "lng": "-77.38965"
  },
  {
    "country": "PA",
    "name": "Parque Lefevre",
    "lat": "9.01667",
    "lng": "-79.48333"
  },
  {
    "country": "PA",
    "name": "Paritilla",
    "lat": "7.62848",
    "lng": "-80.1724"
  },
  {
    "country": "PA",
    "name": "Parita",
    "lat": "7.99393",
    "lng": "-80.52097"
  },
  {
    "country": "PA",
    "name": "París",
    "lat": "8.05053",
    "lng": "-80.55409"
  },
  {
    "country": "PA",
    "name": "Paraíso",
    "lat": "8.65842",
    "lng": "-82.58625"
  },
  {
    "country": "PA",
    "name": "Paraíso",
    "lat": "7.6851",
    "lng": "-80.16082"
  },
  {
    "country": "PA",
    "name": "Panamá",
    "lat": "8.9936",
    "lng": "-79.51973"
  },
  {
    "country": "PA",
    "name": "Palo Grande",
    "lat": "8.34654",
    "lng": "-82.60589"
  },
  {
    "country": "PA",
    "name": "Palmira Centro",
    "lat": "8.73956",
    "lng": "-82.45228"
  },
  {
    "country": "PA",
    "name": "Palmira",
    "lat": "9.54359",
    "lng": "-79.21946"
  },
  {
    "country": "PA",
    "name": "Palmira",
    "lat": "8.73401",
    "lng": "-82.45887"
  },
  {
    "country": "PA",
    "name": "Palmira",
    "lat": "7.66347",
    "lng": "-80.35728"
  },
  {
    "country": "PA",
    "name": "Palmas Bellas",
    "lat": "9.22838",
    "lng": "-80.08503"
  },
  {
    "country": "PA",
    "name": "Palenque",
    "lat": "9.5697",
    "lng": "-79.36341"
  },
  {
    "country": "PA",
    "name": "Paja de Sombrero",
    "lat": "8.68335",
    "lng": "-82.31911"
  },
  {
    "country": "PA",
    "name": "Pacora",
    "lat": "9.07937",
    "lng": "-79.28997"
  },
  {
    "country": "PA",
    "name": "Olá",
    "lat": "8.41807",
    "lng": "-80.65123"
  },
  {
    "country": "PA",
    "name": "Ocú",
    "lat": "7.94052",
    "lng": "-80.77936"
  },
  {
    "country": "PA",
    "name": "Nuevo Vigía",
    "lat": "9.24263",
    "lng": "-79.60756"
  },
  {
    "country": "PA",
    "name": "Nuevo San Juan",
    "lat": "9.22205",
    "lng": "-79.66602"
  },
  {
    "country": "PA",
    "name": "Nuevo Emperador",
    "lat": "9.00273",
    "lng": "-79.73141"
  },
  {
    "country": "PA",
    "name": "Nuevo Chagres",
    "lat": "9.23979",
    "lng": "-80.08267"
  },
  {
    "country": "PA",
    "name": "Nuevo Arraiján",
    "lat": "8.92453",
    "lng": "-79.72004"
  },
  {
    "country": "PA",
    "name": "Nueva Providencia",
    "lat": "9.26333",
    "lng": "-79.81556"
  },
  {
    "country": "PA",
    "name": "Nueva Gorgona",
    "lat": "8.55",
    "lng": "-79.87547"
  },
  {
    "country": "PA",
    "name": "Nueva Arenosa",
    "lat": "8.86944",
    "lng": "-79.99472"
  },
  {
    "country": "PA",
    "name": "Nuestro Amo",
    "lat": "8.44485",
    "lng": "-80.58934"
  },
  {
    "country": "PA",
    "name": "Nuario",
    "lat": "7.53047",
    "lng": "-80.32692"
  },
  {
    "country": "PA",
    "name": "Nombre de Dios",
    "lat": "9.57937",
    "lng": "-79.47109"
  },
  {
    "country": "PA",
    "name": "Natá",
    "lat": "8.33209",
    "lng": "-80.51969"
  },
  {
    "country": "PA",
    "name": "Narganá",
    "lat": "9.44394",
    "lng": "-78.58666"
  },
  {
    "country": "PA",
    "name": "Mulatupo",
    "lat": "8.94672",
    "lng": "-77.7508"
  },
  {
    "country": "PA",
    "name": "Mortí",
    "lat": "8.84246",
    "lng": "-77.97539"
  },
  {
    "country": "PA",
    "name": "Montijo",
    "lat": "7.98858",
    "lng": "-81.05643"
  },
  {
    "country": "PA",
    "name": "Monte Lirio",
    "lat": "8.78935",
    "lng": "-82.82865"
  },
  {
    "country": "PA",
    "name": "La Montañuela",
    "lat": "8.02487",
    "lng": "-80.86325"
  },
  {
    "country": "PA",
    "name": "Monjarás",
    "lat": "8.36942",
    "lng": "-80.86667"
  },
  {
    "country": "PA",
    "name": "Monagrillo",
    "lat": "7.98179",
    "lng": "-80.43764"
  },
  {
    "country": "PA",
    "name": "Mogollón",
    "lat": "7.64261",
    "lng": "-80.4595"
  },
  {
    "country": "PA",
    "name": "Miramar",
    "lat": "9.57544",
    "lng": "-79.33573"
  },
  {
    "country": "PA",
    "name": "Miramar",
    "lat": "8.99482",
    "lng": "-82.24147"
  },
  {
    "country": "PA",
    "name": "Miguel de La Borda",
    "lat": "9.14544",
    "lng": "-80.30124"
  },
  {
    "country": "PA",
    "name": "Metetí",
    "lat": "8.49909",
    "lng": "-77.97897"
  },
  {
    "country": "PA",
    "name": "Mendoza",
    "lat": "9.01471",
    "lng": "-79.85073"
  },
  {
    "country": "PA",
    "name": "Mata del Nance",
    "lat": "8.45056",
    "lng": "-82.40057"
  },
  {
    "country": "PA",
    "name": "María Chiquita",
    "lat": "9.43991",
    "lng": "-79.75455"
  },
  {
    "country": "PA",
    "name": "Mariabé",
    "lat": "7.58265",
    "lng": "-80.0661"
  },
  {
    "country": "PA",
    "name": "Las Margaritas",
    "lat": "9.32603",
    "lng": "-79.89028"
  },
  {
    "country": "PA",
    "name": "Maraca",
    "lat": "8.37302",
    "lng": "-81.72741"
  },
  {
    "country": "PA",
    "name": "Macaracas",
    "lat": "7.73168",
    "lng": "-80.55364"
  },
  {
    "country": "PA",
    "name": "Los Valles",
    "lat": "8.44851",
    "lng": "-81.19886"
  },
  {
    "country": "PA",
    "name": "Los Santos",
    "lat": "7.93333",
    "lng": "-80.41667"
  },
  {
    "country": "PA",
    "name": "Los Pozos",
    "lat": "7.783",
    "lng": "-80.64524"
  },
  {
    "country": "PA",
    "name": "Los Olivos",
    "lat": "7.91589",
    "lng": "-80.48884"
  },
  {
    "country": "PA",
    "name": "Los Naranjos",
    "lat": "8.7921",
    "lng": "-82.44665"
  },
  {
    "country": "PA",
    "name": "Los Lotes",
    "lat": "9.12425",
    "lng": "-79.28929"
  },
  {
    "country": "PA",
    "name": "Los Llanitos",
    "lat": "8.59787",
    "lng": "-80.09503"
  },
  {
    "country": "PA",
    "name": "Los Higos",
    "lat": "8.20553",
    "lng": "-80.86022"
  },
  {
    "country": "PA",
    "name": "Los Corotúes",
    "lat": "8.42014",
    "lng": "-81.10421"
  },
  {
    "country": "PA",
    "name": "Los Cerros de Paja",
    "lat": "7.71821",
    "lng": "-80.67273"
  },
  {
    "country": "PA",
    "name": "Los Cerritos",
    "lat": "7.79746",
    "lng": "-80.61071"
  },
  {
    "country": "PA",
    "name": "Los Castillos",
    "lat": "8.02326",
    "lng": "-81.11941"
  },
  {
    "country": "PA",
    "name": "Los Castillos",
    "lat": "7.98565",
    "lng": "-80.61886"
  },
  {
    "country": "PA",
    "name": "Los Canelos",
    "lat": "8.11722",
    "lng": "-80.70769"
  },
  {
    "country": "PA",
    "name": "Los Asientos",
    "lat": "7.51656",
    "lng": "-80.13521"
  },
  {
    "country": "PA",
    "name": "Los Ángeles",
    "lat": "8.52271",
    "lng": "-82.19997"
  },
  {
    "country": "PA",
    "name": "Los Ángeles",
    "lat": "7.88422",
    "lng": "-80.35772"
  },
  {
    "country": "PA",
    "name": "Los Anastacios",
    "lat": "8.53027",
    "lng": "-82.42295"
  },
  {
    "country": "PA",
    "name": "Los Algarrobos",
    "lat": "8.49601",
    "lng": "-82.42417"
  },
  {
    "country": "PA",
    "name": "Los Algarrobos",
    "lat": "8.10898",
    "lng": "-81.01355"
  },
  {
    "country": "PA",
    "name": "Lolá",
    "lat": "8.09326",
    "lng": "-81.47163"
  },
  {
    "country": "PA",
    "name": "Buabidi",
    "lat": "8.47457",
    "lng": "-81.69827"
  },
  {
    "country": "PA",
    "name": "Llano Ñopo",
    "lat": "8.41996",
    "lng": "-81.61865"
  },
  {
    "country": "PA",
    "name": "Llano Marín",
    "lat": "8.47696",
    "lng": "-80.32499"
  },
  {
    "country": "PA",
    "name": "Llano Largo",
    "lat": "8.83463",
    "lng": "-79.80765"
  },
  {
    "country": "PA",
    "name": "Llano Largo",
    "lat": "7.90607",
    "lng": "-80.42561"
  },
  {
    "country": "PA",
    "name": "Llano Grande",
    "lat": "8.63817",
    "lng": "-80.43848"
  },
  {
    "country": "PA",
    "name": "Llano Grande",
    "lat": "8.45053",
    "lng": "-80.22676"
  },
  {
    "country": "PA",
    "name": "Llano Grande",
    "lat": "8.07473",
    "lng": "-81.13626"
  },
  {
    "country": "PA",
    "name": "Llano Grande",
    "lat": "7.97406",
    "lng": "-80.71103"
  },
  {
    "country": "PA",
    "name": "Llano de Piedra",
    "lat": "7.65972",
    "lng": "-80.56347"
  },
  {
    "country": "PA",
    "name": "Llano de La Cruz",
    "lat": "7.95178",
    "lng": "-80.64239"
  },
  {
    "country": "PA",
    "name": "Llano Bonito",
    "lat": "7.97637",
    "lng": "-80.41646"
  },
  {
    "country": "PA",
    "name": "Llano Abajo",
    "lat": "7.78598",
    "lng": "-80.4106"
  },
  {
    "country": "PA",
    "name": "Limones",
    "lat": "8.10007",
    "lng": "-82.86679"
  },
  {
    "country": "PA",
    "name": "Limón de Tijeras",
    "lat": "7.81756",
    "lng": "-80.91335"
  },
  {
    "country": "PA",
    "name": "Lídice",
    "lat": "8.74869",
    "lng": "-79.90974"
  },
  {
    "country": "PA",
    "name": "Leones Arriba",
    "lat": "7.7659",
    "lng": "-80.84515"
  },
  {
    "country": "PA",
    "name": "Leones Arriba",
    "lat": "7.75415",
    "lng": "-81.11556"
  },
  {
    "country": "PA",
    "name": "La Yeguada",
    "lat": "8.4306",
    "lng": "-80.85752"
  },
  {
    "country": "PA",
    "name": "La Tronosa",
    "lat": "7.43609",
    "lng": "-80.58698"
  },
  {
    "country": "PA",
    "name": "La Trinidad",
    "lat": "7.91457",
    "lng": "-80.70332"
  },
  {
    "country": "PA",
    "name": "La Tiza",
    "lat": "7.7511",
    "lng": "-80.29216"
  },
  {
    "country": "PA",
    "name": "Las Uvas",
    "lat": "8.45937",
    "lng": "-80.00075"
  },
  {
    "country": "PA",
    "name": "Las Trancas",
    "lat": "7.734",
    "lng": "-80.37384"
  },
  {
    "country": "PA",
    "name": "Las Tablas",
    "lat": "7.76472",
    "lng": "-80.27483"
  },
  {
    "country": "PA",
    "name": "Las Sabanas",
    "lat": "8.58141",
    "lng": "-80.67978"
  },
  {
    "country": "PA",
    "name": "Las Palmitas",
    "lat": "7.76523",
    "lng": "-80.2935"
  },
  {
    "country": "PA",
    "name": "Las Palmas",
    "lat": "8.13564",
    "lng": "-81.45674"
  },
  {
    "country": "PA",
    "name": "Las Palmas",
    "lat": "7.68314",
    "lng": "-80.49728"
  },
  {
    "country": "PA",
    "name": "Las Ollas Arriba",
    "lat": "8.80675",
    "lng": "-79.91311"
  },
  {
    "country": "PA",
    "name": "La Soledad",
    "lat": "7.87899",
    "lng": "-81.27611"
  },
  {
    "country": "PA",
    "name": "Las Minas",
    "lat": "8.64118",
    "lng": "-80.39432"
  },
  {
    "country": "PA",
    "name": "Las Minas",
    "lat": "7.79581",
    "lng": "-80.7457"
  },
  {
    "country": "PA",
    "name": "Las Marias",
    "lat": "8.88809",
    "lng": "-80.21893"
  },
  {
    "country": "PA",
    "name": "Las Margaritas",
    "lat": "9.18426",
    "lng": "-79.0873"
  },
  {
    "country": "PA",
    "name": "Las Lomas",
    "lat": "8.42927",
    "lng": "-82.38743"
  },
  {
    "country": "PA",
    "name": "Lajas de Tolé",
    "lat": "8.16994",
    "lng": "-81.69654"
  },
  {
    "country": "PA",
    "name": "Las Lajas",
    "lat": "8.54963",
    "lng": "-79.93521"
  },
  {
    "country": "PA",
    "name": "Las Lajas",
    "lat": "8.24184",
    "lng": "-81.86931"
  },
  {
    "country": "PA",
    "name": "Las Huacas del Quije",
    "lat": "8.46702",
    "lng": "-80.75089"
  },
  {
    "country": "PA",
    "name": "Las Huacas",
    "lat": "7.90167",
    "lng": "-81.14056"
  },
  {
    "country": "PA",
    "name": "Las Guabas",
    "lat": "7.90949",
    "lng": "-80.80706"
  },
  {
    "country": "PA",
    "name": "Las Guabas",
    "lat": "7.81469",
    "lng": "-80.50155"
  },
  {
    "country": "PA",
    "name": "Las Cumbres",
    "lat": "9.08916",
    "lng": "-79.52809"
  },
  {
    "country": "PA",
    "name": "Altos de San Francisco",
    "lat": "8.86167",
    "lng": "-79.79"
  },
  {
    "country": "PA",
    "name": "Las Cruces",
    "lat": "7.82285",
    "lng": "-80.43003"
  },
  {
    "country": "PA",
    "name": "Las Colinas",
    "lat": "8.55",
    "lng": "-80.08333"
  },
  {
    "country": "PA",
    "name": "Las Cabras",
    "lat": "7.87561",
    "lng": "-80.54912"
  },
  {
    "country": "PA",
    "name": "La Raya de Santa María",
    "lat": "8.16429",
    "lng": "-80.82143"
  },
  {
    "country": "PA",
    "name": "La Raya de Calobre",
    "lat": "8.2163",
    "lng": "-80.82729"
  },
  {
    "country": "PA",
    "name": "La Punta",
    "lat": "7.55702",
    "lng": "-81.19109"
  },
  {
    "country": "PA",
    "name": "Pitaloza Arriba",
    "lat": "7.64216",
    "lng": "-80.66788"
  },
  {
    "country": "PA",
    "name": "La Pintada",
    "lat": "8.59299",
    "lng": "-80.44349"
  },
  {
    "country": "PA",
    "name": "La Peña",
    "lat": "8.12784",
    "lng": "-81.02693"
  },
  {
    "country": "PA",
    "name": "La Pasera",
    "lat": "7.79757",
    "lng": "-80.30342"
  },
  {
    "country": "PA",
    "name": "La Palma",
    "lat": "8.40608",
    "lng": "-78.13964"
  },
  {
    "country": "PA",
    "name": "La Palma",
    "lat": "7.71667",
    "lng": "-80.38333"
  },
  {
    "country": "PA",
    "name": "La Palma",
    "lat": "7.68864",
    "lng": "-80.19647"
  },
  {
    "country": "PA",
    "name": "La Mitra",
    "lat": "8.84091",
    "lng": "-79.78648"
  },
  {
    "country": "PA",
    "name": "La Miel",
    "lat": "7.56022",
    "lng": "-80.32736"
  },
  {
    "country": "PA",
    "name": "La Mesa",
    "lat": "9.17308",
    "lng": "-79.27401"
  },
  {
    "country": "PA",
    "name": "La Mesa",
    "lat": "8.14707",
    "lng": "-81.18114"
  },
  {
    "country": "PA",
    "name": "La Mesa",
    "lat": "7.6567",
    "lng": "-80.61794"
  },
  {
    "country": "PA",
    "name": "La Loma",
    "lat": "8.16667",
    "lng": "-80.63742"
  },
  {
    "country": "PA",
    "name": "La Loma",
    "lat": "7.43708",
    "lng": "-80.89118"
  },
  {
    "country": "PA",
    "name": "La Laja",
    "lat": "7.73102",
    "lng": "-80.25298"
  },
  {
    "country": "PA",
    "name": "La Laguna",
    "lat": "9.04404",
    "lng": "-79.84215"
  },
  {
    "country": "PA",
    "name": "La Laguna",
    "lat": "8.60409",
    "lng": "-80.04716"
  },
  {
    "country": "PA",
    "name": "La Laguna",
    "lat": "8.33882",
    "lng": "-80.72949"
  },
  {
    "country": "PA",
    "name": "Lajas Adentro",
    "lat": "8.24981",
    "lng": "-81.87779"
  },
  {
    "country": "PA",
    "name": "Lajamina",
    "lat": "7.58587",
    "lng": "-80.13212"
  },
  {
    "country": "PA",
    "name": "La Herradura",
    "lat": "8.84848",
    "lng": "-79.80404"
  },
  {
    "country": "PA",
    "name": "La Guinea",
    "lat": "8.3425",
    "lng": "-78.9343"
  },
  {
    "country": "PA",
    "name": "Lagarterita",
    "lat": "9.07944",
    "lng": "-79.91389"
  },
  {
    "country": "PA",
    "name": "La Garceana",
    "lat": "7.93708",
    "lng": "-81.01643"
  },
  {
    "country": "PA",
    "name": "La Estrella",
    "lat": "8.51572",
    "lng": "-82.67212"
  },
  {
    "country": "PA",
    "name": "La Espigadilla",
    "lat": "7.88389",
    "lng": "-80.39039"
  },
  {
    "country": "PA",
    "name": "La Esperanza",
    "lat": "8.40344",
    "lng": "-82.79197"
  },
  {
    "country": "PA",
    "name": "La Esmeralda",
    "lat": "8.26817",
    "lng": "-78.9246"
  },
  {
    "country": "PA",
    "name": "La Ermita",
    "lat": "8.45622",
    "lng": "-80.06835"
  },
  {
    "country": "PA",
    "name": "La Ensenada",
    "lat": "8.36618",
    "lng": "-78.84606"
  },
  {
    "country": "PA",
    "name": "La Enea",
    "lat": "7.83333",
    "lng": "-80.27417"
  },
  {
    "country": "PA",
    "name": "La Encantada",
    "lat": "9.08703",
    "lng": "-80.19158"
  },
  {
    "country": "PA",
    "name": "La Concepción",
    "lat": "8.51212",
    "lng": "-82.61858"
  },
  {
    "country": "PA",
    "name": "La Colorada",
    "lat": "8.01319",
    "lng": "-80.9859"
  },
  {
    "country": "PA",
    "name": "La Colorada",
    "lat": "7.82362",
    "lng": "-80.55552"
  },
  {
    "country": "PA",
    "name": "La Chorrera",
    "lat": "8.88028",
    "lng": "-79.78333"
  },
  {
    "country": "PA",
    "name": "La Carrillo",
    "lat": "7.96953",
    "lng": "-80.88377"
  },
  {
    "country": "PA",
    "name": "Cabuya",
    "lat": "7.98267",
    "lng": "-80.76435"
  },
  {
    "country": "PA",
    "name": "La Cabima",
    "lat": "9.11865",
    "lng": "-79.5366"
  },
  {
    "country": "PA",
    "name": "Boca del Guásimo",
    "lat": "9.05053",
    "lng": "-80.32878"
  },
  {
    "country": "PA",
    "name": "La Arena",
    "lat": "7.96766",
    "lng": "-80.46523"
  },
  {
    "country": "PA",
    "name": "La Arena",
    "lat": "7.75033",
    "lng": "-80.59283"
  },
  {
    "country": "PA",
    "name": "Juay",
    "lat": "8.28415",
    "lng": "-81.94633"
  },
  {
    "country": "PA",
    "name": "Juan Díaz",
    "lat": "9.05",
    "lng": "-79.45"
  },
  {
    "country": "PA",
    "name": "Juan Díaz",
    "lat": "8.4624",
    "lng": "-80.2828"
  },
  {
    "country": "PA",
    "name": "Jaramillo Arriba",
    "lat": "8.79771",
    "lng": "-82.42431"
  },
  {
    "country": "PA",
    "name": "Jaqué",
    "lat": "7.51826",
    "lng": "-78.16343"
  },
  {
    "country": "PA",
    "name": "Horconcitos",
    "lat": "8.31142",
    "lng": "-82.15102"
  },
  {
    "country": "PA",
    "name": "Hato Pilón",
    "lat": "8.39813",
    "lng": "-81.86525"
  },
  {
    "country": "PA",
    "name": "Hato Montaña",
    "lat": "8.91938",
    "lng": "-79.73915"
  },
  {
    "country": "PA",
    "name": "Hato Juli",
    "lat": "8.34981",
    "lng": "-81.84503"
  },
  {
    "country": "PA",
    "name": "Hato Jobo",
    "lat": "8.39198",
    "lng": "-81.8862"
  },
  {
    "country": "PA",
    "name": "Hato Culantro",
    "lat": "8.46847",
    "lng": "-81.85714"
  },
  {
    "country": "PA",
    "name": "Hato Corotú",
    "lat": "8.33516",
    "lng": "-81.9703"
  },
  {
    "country": "PA",
    "name": "Hato Chami",
    "lat": "8.44281",
    "lng": "-81.77196"
  },
  {
    "country": "PA",
    "name": "Guzman",
    "lat": "8.51969",
    "lng": "-80.58405"
  },
  {
    "country": "PA",
    "name": "Las Guías Abajo",
    "lat": "8.19451",
    "lng": "-80.75494"
  },
  {
    "country": "PA",
    "name": "Guayabito",
    "lat": "8.54828",
    "lng": "-80.0135"
  },
  {
    "country": "PA",
    "name": "Guayabal",
    "lat": "8.62193",
    "lng": "-82.57935"
  },
  {
    "country": "PA",
    "name": "Guarumal",
    "lat": "8.34523",
    "lng": "-82.53205"
  },
  {
    "country": "PA",
    "name": "Guarumal",
    "lat": "7.79404",
    "lng": "-81.25904"
  },
  {
    "country": "PA",
    "name": "Guararé Arriba",
    "lat": "7.80023",
    "lng": "-80.35983"
  },
  {
    "country": "PA",
    "name": "Guararé",
    "lat": "7.81531",
    "lng": "-80.28345"
  },
  {
    "country": "PA",
    "name": "Gualaca",
    "lat": "8.53006",
    "lng": "-82.29959"
  },
  {
    "country": "PA",
    "name": "Guadalupe",
    "lat": "8.85452",
    "lng": "-79.81408"
  },
  {
    "country": "PA",
    "name": "Guaca Arriba",
    "lat": "8.53733",
    "lng": "-82.49281"
  },
  {
    "country": "PA",
    "name": "Guabito",
    "lat": "9.48968",
    "lng": "-82.61279"
  },
  {
    "country": "PA",
    "name": "Guabal",
    "lat": "8.57466",
    "lng": "-82.5373"
  },
  {
    "country": "PA",
    "name": "Gonzalo Vásquez",
    "lat": "8.41466",
    "lng": "-78.45612"
  },
  {
    "country": "PA",
    "name": "Gómez",
    "lat": "8.56085",
    "lng": "-82.74142"
  },
  {
    "country": "PA",
    "name": "Gobea",
    "lat": "9.15914",
    "lng": "-80.25064"
  },
  {
    "country": "PA",
    "name": "Gatuncillo",
    "lat": "9.24346",
    "lng": "-79.64856"
  },
  {
    "country": "PA",
    "name": "Gatú",
    "lat": "8.53754",
    "lng": "-80.95109"
  },
  {
    "country": "PA",
    "name": "Garachiné",
    "lat": "8.06684",
    "lng": "-78.36436"
  },
  {
    "country": "PA",
    "name": "Flores",
    "lat": "7.48157",
    "lng": "-80.40695"
  },
  {
    "country": "PA",
    "name": "Finca Blanco",
    "lat": "8.37979",
    "lng": "-82.87385"
  },
  {
    "country": "PA",
    "name": "El Espavé",
    "lat": "8.66161",
    "lng": "-79.87584"
  },
  {
    "country": "PA",
    "name": "Escobal",
    "lat": "9.14373",
    "lng": "-79.96439"
  },
  {
    "country": "PA",
    "name": "El Valle de la Unión",
    "lat": "9.2363",
    "lng": "-79.65986"
  },
  {
    "country": "PA",
    "name": "El Uvito",
    "lat": "8.11648",
    "lng": "-80.98461"
  },
  {
    "country": "PA",
    "name": "El Toro",
    "lat": "7.7511",
    "lng": "-80.86943"
  },
  {
    "country": "PA",
    "name": "El Tejar",
    "lat": "8.42973",
    "lng": "-82.57294"
  },
  {
    "country": "PA",
    "name": "El Silencio",
    "lat": "9.37222",
    "lng": "-82.52877"
  },
  {
    "country": "PA",
    "name": "Sesteadero",
    "lat": "7.73885",
    "lng": "-80.24854"
  },
  {
    "country": "PA",
    "name": "El Roble",
    "lat": "8.1685",
    "lng": "-80.65897"
  },
  {
    "country": "PA",
    "name": "El Rincón",
    "lat": "8.18422",
    "lng": "-81.43333"
  },
  {
    "country": "PA",
    "name": "El Rincón",
    "lat": "8.11923",
    "lng": "-80.61707"
  },
  {
    "country": "PA",
    "name": "El Retiro",
    "lat": "8.48014",
    "lng": "-80.15426"
  },
  {
    "country": "PA",
    "name": "Quinteño",
    "lat": "8.47102",
    "lng": "-82.39352"
  },
  {
    "country": "PA",
    "name": "El Progreso",
    "lat": "9.26667",
    "lng": "-79.11667"
  },
  {
    "country": "PA",
    "name": "El Prado",
    "lat": "8.23732",
    "lng": "-81.50422"
  },
  {
    "country": "PA",
    "name": "El Potrero",
    "lat": "8.52146",
    "lng": "-80.51681"
  },
  {
    "country": "PA",
    "name": "El Potrero",
    "lat": "8.37692",
    "lng": "-80.79434"
  },
  {
    "country": "PA",
    "name": "El Porvenir",
    "lat": "9.55276",
    "lng": "-78.9523"
  },
  {
    "country": "PA",
    "name": "El Piro",
    "lat": "8.20942",
    "lng": "-81.52706"
  },
  {
    "country": "PA",
    "name": "El Pilón",
    "lat": "7.95413",
    "lng": "-81.07637"
  },
  {
    "country": "PA",
    "name": "El Picador",
    "lat": "8.37803",
    "lng": "-81.25621"
  },
  {
    "country": "PA",
    "name": "El Peñón",
    "lat": "8.35",
    "lng": "-80.9762"
  },
  {
    "country": "PA",
    "name": "El Pedregoso",
    "lat": "7.93642",
    "lng": "-80.63807"
  },
  {
    "country": "PA",
    "name": "El Pedregoso",
    "lat": "7.69173",
    "lng": "-80.32793"
  },
  {
    "country": "PA",
    "name": "El Pantano",
    "lat": "8.53755",
    "lng": "-81.06941"
  },
  {
    "country": "PA",
    "name": "El Pájaro",
    "lat": "7.95342",
    "lng": "-81.12154"
  },
  {
    "country": "PA",
    "name": "El Pájaro",
    "lat": "7.94338",
    "lng": "-80.5701"
  },
  {
    "country": "PA",
    "name": "El Nancito",
    "lat": "8.23811",
    "lng": "-81.73218"
  },
  {
    "country": "PA",
    "name": "El Muñoz",
    "lat": "7.67582",
    "lng": "-80.3213"
  },
  {
    "country": "PA",
    "name": "El María",
    "lat": "8.02905",
    "lng": "-81.44384"
  },
  {
    "country": "PA",
    "name": "El Marañón",
    "lat": "8.03582",
    "lng": "-81.21489"
  },
  {
    "country": "PA",
    "name": "El Manantial",
    "lat": "7.78245",
    "lng": "-80.24713"
  },
  {
    "country": "PA",
    "name": "Salto Dupí",
    "lat": "8.35146",
    "lng": "-81.88659"
  },
  {
    "country": "PA",
    "name": "El Macano",
    "lat": "7.68489",
    "lng": "-80.40309"
  },
  {
    "country": "PA",
    "name": "El Limón",
    "lat": "8.05805",
    "lng": "-80.77289"
  },
  {
    "country": "PA",
    "name": "El Líbano",
    "lat": "8.61685",
    "lng": "-79.83483"
  },
  {
    "country": "PA",
    "name": "El Higo",
    "lat": "8.44731",
    "lng": "-80.03603"
  },
  {
    "country": "PA",
    "name": "El Hato",
    "lat": "7.79316",
    "lng": "-80.38267"
  },
  {
    "country": "PA",
    "name": "El Guásimo",
    "lat": "7.8064",
    "lng": "-80.52991"
  },
  {
    "country": "PA",
    "name": "El Guabo",
    "lat": "9.07842",
    "lng": "-80.08316"
  },
  {
    "country": "PA",
    "name": "El Giral",
    "lat": "9.24509",
    "lng": "-79.69266"
  },
  {
    "country": "PA",
    "name": "Farallón",
    "lat": "8.35658",
    "lng": "-80.13723"
  },
  {
    "country": "PA",
    "name": "El Espino de Santa Rosa",
    "lat": "8.09286",
    "lng": "-80.8238"
  },
  {
    "country": "PA",
    "name": "El Espino Amarillo",
    "lat": "7.67605",
    "lng": "-80.43896"
  },
  {
    "country": "PA",
    "name": "El Espino",
    "lat": "8.83795",
    "lng": "-79.84925"
  },
  {
    "country": "PA",
    "name": "El Espino",
    "lat": "8.47761",
    "lng": "-80.0128"
  },
  {
    "country": "PA",
    "name": "El Espinal",
    "lat": "7.86667",
    "lng": "-80.31936"
  },
  {
    "country": "PA",
    "name": "Entradero",
    "lat": "8.5688",
    "lng": "-80.20743"
  },
  {
    "country": "PA",
    "name": "El Empalme",
    "lat": "9.41667",
    "lng": "-82.51667"
  },
  {
    "country": "PA",
    "name": "El Ejido",
    "lat": "7.91634",
    "lng": "-80.38686"
  },
  {
    "country": "PA",
    "name": "El Cristo",
    "lat": "8.25071",
    "lng": "-80.62093"
  },
  {
    "country": "PA",
    "name": "El Cortezo",
    "lat": "8.34556",
    "lng": "-80.58721"
  },
  {
    "country": "PA",
    "name": "El Cortezo",
    "lat": "7.42661",
    "lng": "-80.63311"
  },
  {
    "country": "PA",
    "name": "El Copé",
    "lat": "8.62036",
    "lng": "-80.58433"
  },
  {
    "country": "PA",
    "name": "El Copé",
    "lat": "8.43773",
    "lng": "-80.67929"
  },
  {
    "country": "PA",
    "name": "El Coco",
    "lat": "8.87009",
    "lng": "-79.80415"
  },
  {
    "country": "PA",
    "name": "El Coco",
    "lat": "8.39716",
    "lng": "-80.35"
  },
  {
    "country": "PA",
    "name": "El Coclá",
    "lat": "8.32143",
    "lng": "-80.92069"
  },
  {
    "country": "PA",
    "name": "El Cocal",
    "lat": "7.73697",
    "lng": "-80.2798"
  },
  {
    "country": "PA",
    "name": "El Chorrillo",
    "lat": "8.94964",
    "lng": "-79.54715"
  },
  {
    "country": "PA",
    "name": "El Chirú",
    "lat": "8.39876",
    "lng": "-80.18721"
  },
  {
    "country": "PA",
    "name": "El Cedro",
    "lat": "7.68565",
    "lng": "-80.65927"
  },
  {
    "country": "PA",
    "name": "El Carate",
    "lat": "7.73124",
    "lng": "-80.29691"
  },
  {
    "country": "PA",
    "name": "El Capurí",
    "lat": "7.72571",
    "lng": "-80.64349"
  },
  {
    "country": "PA",
    "name": "El Caño",
    "lat": "8.40195",
    "lng": "-80.51791"
  },
  {
    "country": "PA",
    "name": "El Cañafístulo",
    "lat": "7.61768",
    "lng": "-80.23322"
  },
  {
    "country": "PA",
    "name": "El Calabacito",
    "lat": "7.71843",
    "lng": "-80.59757"
  },
  {
    "country": "PA",
    "name": "El Cacao",
    "lat": "8.76134",
    "lng": "-80.01294"
  },
  {
    "country": "PA",
    "name": "El Cacao",
    "lat": "7.4457",
    "lng": "-80.40938"
  },
  {
    "country": "PA",
    "name": "Bongo Arriba",
    "lat": "8.58881",
    "lng": "-82.62253"
  },
  {
    "country": "PA",
    "name": "El Bebedero",
    "lat": "7.40972",
    "lng": "-80.45641"
  },
  {
    "country": "PA",
    "name": "El Barrito",
    "lat": "7.96059",
    "lng": "-80.94801"
  },
  {
    "country": "PA",
    "name": "El Barrero",
    "lat": "7.93344",
    "lng": "-80.51358"
  },
  {
    "country": "PA",
    "name": "Cerro Banco",
    "lat": "8.45797",
    "lng": "-82.03081"
  },
  {
    "country": "PA",
    "name": "El Bale",
    "lat": "8.35745",
    "lng": "-81.36099"
  },
  {
    "country": "PA",
    "name": "El Alto",
    "lat": "8.51191",
    "lng": "-81.03646"
  },
  {
    "country": "PA",
    "name": "Dos Ríos Abajo",
    "lat": "8.52834",
    "lng": "-82.38677"
  },
  {
    "country": "PA",
    "name": "Dolega District",
    "lat": "8.56667",
    "lng": "-82.41407"
  },
  {
    "country": "PA",
    "name": "Divalá",
    "lat": "8.41066",
    "lng": "-82.71332"
  },
  {
    "country": "PA",
    "name": "David",
    "lat": "8.42729",
    "lng": "-82.43085"
  },
  {
    "country": "PA",
    "name": "Kusapín",
    "lat": "9.17823",
    "lng": "-81.88484"
  },
  {
    "country": "PA",
    "name": "Curundú",
    "lat": "8.97092",
    "lng": "-79.54612"
  },
  {
    "country": "PA",
    "name": "Cuipo",
    "lat": "9.06896",
    "lng": "-80.04878"
  },
  {
    "country": "PA",
    "name": "Cucunatí",
    "lat": "8.57508",
    "lng": "-78.25671"
  },
  {
    "country": "PA",
    "name": "Cuango",
    "lat": "9.56667",
    "lng": "-79.31667"
  },
  {
    "country": "PA",
    "name": "Cristóbal",
    "lat": "9.35222",
    "lng": "-79.90444"
  },
  {
    "country": "PA",
    "name": "Corozal",
    "lat": "8.07712",
    "lng": "-81.4399"
  },
  {
    "country": "PA",
    "name": "Cordillera",
    "lat": "8.70683",
    "lng": "-82.60327"
  },
  {
    "country": "PA",
    "name": "Colón",
    "lat": "9.35451",
    "lng": "-79.90011"
  },
  {
    "country": "PA",
    "name": "Coclé del Norte",
    "lat": "9.0754",
    "lng": "-80.57177"
  },
  {
    "country": "PA",
    "name": "Coclecito",
    "lat": "8.80817",
    "lng": "-80.55607"
  },
  {
    "country": "PA",
    "name": "Coclé",
    "lat": "8.45601",
    "lng": "-80.42899"
  },
  {
    "country": "PA",
    "name": "Cochea Abajo",
    "lat": "8.50512",
    "lng": "-82.35878"
  },
  {
    "country": "PA",
    "name": "Cirí de Los Sotos",
    "lat": "8.97206",
    "lng": "-80.09209"
  },
  {
    "country": "PA",
    "name": "Churuquita Grande",
    "lat": "8.59449",
    "lng": "-80.27182"
  },
  {
    "country": "PA",
    "name": "Churuquita Chiquita",
    "lat": "8.57555",
    "lng": "-80.27161"
  },
  {
    "country": "PA",
    "name": "Chupampa",
    "lat": "8.0762",
    "lng": "-80.77656"
  },
  {
    "country": "PA",
    "name": "Chupá",
    "lat": "7.8",
    "lng": "-80.57451"
  },
  {
    "country": "PA",
    "name": "Chumical",
    "lat": "7.84482",
    "lng": "-80.72627"
  },
  {
    "country": "PA",
    "name": "Barrio Guadalupe",
    "lat": "8.86482",
    "lng": "-82.56523"
  },
  {
    "country": "PA",
    "name": "Chitré",
    "lat": "7.96082",
    "lng": "-80.42944"
  },
  {
    "country": "PA",
    "name": "Chiriquí Grande",
    "lat": "8.94557",
    "lng": "-82.11769"
  },
  {
    "country": "PA",
    "name": "Chiriquí",
    "lat": "8.39291",
    "lng": "-82.31993"
  },
  {
    "country": "PA",
    "name": "Chimán",
    "lat": "8.69125",
    "lng": "-78.6357"
  },
  {
    "country": "PA",
    "name": "Chilibre",
    "lat": "9.15093",
    "lng": "-79.62098"
  },
  {
    "country": "PA",
    "name": "Chiguirí Arriba",
    "lat": "8.67187",
    "lng": "-80.18975"
  },
  {
    "country": "PA",
    "name": "Chigoré",
    "lat": "8.53035",
    "lng": "-80.35117"
  },
  {
    "country": "PA",
    "name": "Chichica",
    "lat": "8.35885",
    "lng": "-81.66582"
  },
  {
    "country": "PA",
    "name": "Chepo",
    "lat": "9.17019",
    "lng": "-79.10083"
  },
  {
    "country": "PA",
    "name": "Chepillo",
    "lat": "8.95396",
    "lng": "-79.12856"
  },
  {
    "country": "PA",
    "name": "Chepigana",
    "lat": "8.28628",
    "lng": "-78.05185"
  },
  {
    "country": "PA",
    "name": "Changuinola",
    "lat": "9.43",
    "lng": "-82.52"
  },
  {
    "country": "PA",
    "name": "Chame",
    "lat": "8.57753",
    "lng": "-79.88595"
  },
  {
    "country": "PA",
    "name": "Chacarero",
    "lat": "8.48899",
    "lng": "-82.59834"
  },
  {
    "country": "PA",
    "name": "Cerro Viejo",
    "lat": "8.25349",
    "lng": "-81.57658"
  },
  {
    "country": "PA",
    "name": "Cerro Venado",
    "lat": "8.22818",
    "lng": "-81.57421"
  },
  {
    "country": "PA",
    "name": "Cerro Punta",
    "lat": "8.84968",
    "lng": "-82.57261"
  },
  {
    "country": "PA",
    "name": "Cerro Plata",
    "lat": "8.47733",
    "lng": "-81.54585"
  },
  {
    "country": "PA",
    "name": "Cerro de Plata",
    "lat": "8.28777",
    "lng": "-81.36844"
  },
  {
    "country": "PA",
    "name": "Cerro Largo",
    "lat": "7.83377",
    "lng": "-80.83168"
  },
  {
    "country": "PA",
    "name": "Cerro Iglesias",
    "lat": "8.28523",
    "lng": "-81.79804"
  },
  {
    "country": "PA",
    "name": "Cerro Iglesias",
    "lat": "8.31892",
    "lng": "-81.56427"
  },
  {
    "country": "PA",
    "name": "Cerro Caña",
    "lat": "8.35174",
    "lng": "-81.6105"
  },
  {
    "country": "PA",
    "name": "Cerro Cama",
    "lat": "9.02802",
    "lng": "-79.90744"
  },
  {
    "country": "PA",
    "name": "Cerro Azul",
    "lat": "9.15735",
    "lng": "-79.42097"
  },
  {
    "country": "PA",
    "name": "Cermeño",
    "lat": "8.74082",
    "lng": "-79.85299"
  },
  {
    "country": "PA",
    "name": "Celmira",
    "lat": "8.54026",
    "lng": "-82.80022"
  },
  {
    "country": "PA",
    "name": "Cauchero",
    "lat": "9.15226",
    "lng": "-82.2645"
  },
  {
    "country": "PA",
    "name": "Cativá",
    "lat": "9.36218",
    "lng": "-79.83232"
  },
  {
    "country": "PA",
    "name": "Cascabel",
    "lat": "8.5268",
    "lng": "-81.87403"
  },
  {
    "country": "PA",
    "name": "Cartí Sugdup",
    "lat": "9.4646",
    "lng": "-78.95931"
  },
  {
    "country": "PA",
    "name": "Capira",
    "lat": "8.75636",
    "lng": "-79.87996"
  },
  {
    "country": "PA",
    "name": "Capellanía",
    "lat": "8.29858",
    "lng": "-80.5548"
  },
  {
    "country": "PA",
    "name": "San Isidro",
    "lat": "8.53032",
    "lng": "-82.8272"
  },
  {
    "country": "PA",
    "name": "Canto del Llano",
    "lat": "8.12472",
    "lng": "-80.96374"
  },
  {
    "country": "PA",
    "name": "Kankintú",
    "lat": "8.84339",
    "lng": "-81.81496"
  },
  {
    "country": "PA",
    "name": "Cañita",
    "lat": "9.22236",
    "lng": "-78.89509"
  },
  {
    "country": "PA",
    "name": "Cañazas",
    "lat": "8.32004",
    "lng": "-81.21152"
  },
  {
    "country": "PA",
    "name": "Cañaveral",
    "lat": "8.517",
    "lng": "-80.42916"
  },
  {
    "country": "PA",
    "name": "Cañas Gordas",
    "lat": "8.74309",
    "lng": "-82.91275"
  },
  {
    "country": "PA",
    "name": "Cañas",
    "lat": "7.44713",
    "lng": "-80.2648"
  },
  {
    "country": "PA",
    "name": "Cambutal",
    "lat": "7.26534",
    "lng": "-80.49105"
  },
  {
    "country": "PA",
    "name": "Camarón Arriba",
    "lat": "8.38324",
    "lng": "-81.99345"
  },
  {
    "country": "PA",
    "name": "Calzada Larga",
    "lat": "9.17272",
    "lng": "-79.56212"
  },
  {
    "country": "PA",
    "name": "Calovébora",
    "lat": "8.78703",
    "lng": "-81.21056"
  },
  {
    "country": "PA",
    "name": "Calobre",
    "lat": "8.31886",
    "lng": "-80.84067"
  },
  {
    "country": "PA",
    "name": "Calidonia",
    "lat": "7.95756",
    "lng": "-81.38633"
  },
  {
    "country": "PA",
    "name": "Caldera",
    "lat": "8.64907",
    "lng": "-82.38058"
  },
  {
    "country": "PA",
    "name": "Calabacito",
    "lat": "8.24817",
    "lng": "-81.08187"
  },
  {
    "country": "PA",
    "name": "Caimito",
    "lat": "8.81143",
    "lng": "-79.94738"
  },
  {
    "country": "PA",
    "name": "Caimito",
    "lat": "8.62271",
    "lng": "-80.23919"
  },
  {
    "country": "PA",
    "name": "Caimito",
    "lat": "8.54162",
    "lng": "-82.419"
  },
  {
    "country": "PA",
    "name": "Caimitillo",
    "lat": "9.15559",
    "lng": "-79.53974"
  },
  {
    "country": "PA",
    "name": "Cacique",
    "lat": "9.60898",
    "lng": "-79.61667"
  },
  {
    "country": "PA",
    "name": "Cabuya",
    "lat": "8.57472",
    "lng": "-79.92714"
  },
  {
    "country": "PA",
    "name": "Cabuya",
    "lat": "8.54703",
    "lng": "-80.16756"
  },
  {
    "country": "PA",
    "name": "Cabuya",
    "lat": "8.03138",
    "lng": "-80.63227"
  },
  {
    "country": "PA",
    "name": "Cabra Número Uno",
    "lat": "9.10863",
    "lng": "-79.33694"
  },
  {
    "country": "PA",
    "name": "Caballero",
    "lat": "8.54343",
    "lng": "-80.19769"
  },
  {
    "country": "PA",
    "name": "Bugabita Arriba",
    "lat": "8.52143",
    "lng": "-82.63638"
  },
  {
    "country": "PA",
    "name": "Bugaba",
    "lat": "8.48255",
    "lng": "-82.61991"
  },
  {
    "country": "PA",
    "name": "Buenos Aires",
    "lat": "8.63146",
    "lng": "-79.94775"
  },
  {
    "country": "PA",
    "name": "Buenos Aires",
    "lat": "8.41384",
    "lng": "-81.4844"
  },
  {
    "country": "PA",
    "name": "Buena Vista",
    "lat": "9.27356",
    "lng": "-79.69551"
  },
  {
    "country": "PA",
    "name": "Brujas",
    "lat": "8.58536",
    "lng": "-78.53008"
  },
  {
    "country": "PA",
    "name": "Breñón",
    "lat": "8.62491",
    "lng": "-82.81277"
  },
  {
    "country": "PA",
    "name": "Boró",
    "lat": "8.16933",
    "lng": "-81.30071"
  },
  {
    "country": "PA",
    "name": "Boquete",
    "lat": "8.78024",
    "lng": "-82.44136"
  },
  {
    "country": "PA",
    "name": "Boquerón",
    "lat": "8.5051",
    "lng": "-82.57025"
  },
  {
    "country": "PA",
    "name": "Boquerón",
    "lat": "8.24414",
    "lng": "-80.85897"
  },
  {
    "country": "PA",
    "name": "Bocas del Toro",
    "lat": "9.34031",
    "lng": "-82.24204"
  },
  {
    "country": "PA",
    "name": "Soloy",
    "lat": "8.48973",
    "lng": "-82.07136"
  },
  {
    "country": "PA",
    "name": "Boca de Parita",
    "lat": "8.00796",
    "lng": "-80.4532"
  },
  {
    "country": "PA",
    "name": "Boca de Río Indio",
    "lat": "9.18293",
    "lng": "-80.19063"
  },
  {
    "country": "PA",
    "name": "Boca del Río Chiriquí",
    "lat": "8.84517",
    "lng": "-81.57265"
  },
  {
    "country": "PA",
    "name": "Boca del Monte",
    "lat": "8.35296",
    "lng": "-82.11379"
  },
  {
    "country": "PA",
    "name": "Boca de Cupé",
    "lat": "8.03003",
    "lng": "-77.58978"
  },
  {
    "country": "PA",
    "name": "Boca Chica",
    "lat": "8.21911",
    "lng": "-82.21592"
  },
  {
    "country": "PA",
    "name": "Bisvalles",
    "lat": "8.18298",
    "lng": "-81.22092"
  },
  {
    "country": "PA",
    "name": "Bisira",
    "lat": "8.89553",
    "lng": "-81.85352"
  },
  {
    "country": "PA",
    "name": "Bijagual",
    "lat": "8.51486",
    "lng": "-82.33361"
  },
  {
    "country": "PA",
    "name": "Bella Vista",
    "lat": "7.75",
    "lng": "-80.23333"
  },
  {
    "country": "PA",
    "name": "Bejuco",
    "lat": "8.60037",
    "lng": "-79.88988"
  },
  {
    "country": "PA",
    "name": "Bayano",
    "lat": "7.63014",
    "lng": "-80.38201"
  },
  {
    "country": "PA",
    "name": "Isla Bastimentos",
    "lat": "9.3",
    "lng": "-82.13333"
  },
  {
    "country": "PA",
    "name": "Bastimentos",
    "lat": "9.34707",
    "lng": "-82.2088"
  },
  {
    "country": "PA",
    "name": "Barranco Colorado",
    "lat": "8.38937",
    "lng": "-80.63546"
  },
  {
    "country": "PA",
    "name": "Barranco",
    "lat": "9.51984",
    "lng": "-82.70424"
  },
  {
    "country": "PA",
    "name": "Barnizal",
    "lat": "8.4046",
    "lng": "-80.77765"
  },
  {
    "country": "PA",
    "name": "Bajos de Güera",
    "lat": "7.5436",
    "lng": "-80.62505"
  },
  {
    "country": "PA",
    "name": "Bajo Corral",
    "lat": "7.60463",
    "lng": "-80.26016"
  },
  {
    "country": "PA",
    "name": "Bajo Boquete",
    "lat": "8.77058",
    "lng": "-82.43306"
  },
  {
    "country": "PA",
    "name": "Bahía Honda",
    "lat": "7.70517",
    "lng": "-80.45342"
  },
  {
    "country": "PA",
    "name": "Bahía Azul",
    "lat": "9.14176",
    "lng": "-81.89425"
  },
  {
    "country": "PA",
    "name": "Bágala",
    "lat": "8.46399",
    "lng": "-82.52617"
  },
  {
    "country": "PA",
    "name": "Ave María",
    "lat": "7.32481",
    "lng": "-80.45361"
  },
  {
    "country": "PA",
    "name": "Atalaya",
    "lat": "8.04213",
    "lng": "-80.92528"
  },
  {
    "country": "PA",
    "name": "Aserrío de Gariché",
    "lat": "8.48257",
    "lng": "-82.79086"
  },
  {
    "country": "PA",
    "name": "Arraiján",
    "lat": "8.95187",
    "lng": "-79.66011"
  },
  {
    "country": "PA",
    "name": "Arosemena",
    "lat": "8.97091",
    "lng": "-79.96641"
  },
  {
    "country": "PA",
    "name": "Arenosa",
    "lat": "9.03978",
    "lng": "-79.95128"
  },
  {
    "country": "PA",
    "name": "Arenas",
    "lat": "7.36865",
    "lng": "-80.86268"
  },
  {
    "country": "PA",
    "name": "Antón",
    "lat": "8.39733",
    "lng": "-80.26063"
  },
  {
    "country": "PA",
    "name": "Ancón",
    "lat": "8.96015",
    "lng": "-79.5514"
  },
  {
    "country": "PA",
    "name": "Altos de Güera",
    "lat": "7.53002",
    "lng": "-80.62109"
  },
  {
    "country": "PA",
    "name": "Alto del Espino",
    "lat": "8.84213",
    "lng": "-79.84551"
  },
  {
    "country": "PA",
    "name": "Alto de La Estancia",
    "lat": "8.58792",
    "lng": "-80.18443"
  },
  {
    "country": "PA",
    "name": "Alto Caballero",
    "lat": "8.28989",
    "lng": "-81.67349"
  },
  {
    "country": "PA",
    "name": "Alto Boquete",
    "lat": "8.73458",
    "lng": "-82.43213"
  },
  {
    "country": "PA",
    "name": "Almirante",
    "lat": "9.30091",
    "lng": "-82.4018"
  },
  {
    "country": "PA",
    "name": "Alcalde Díaz",
    "lat": "9.12016",
    "lng": "-79.55641"
  },
  {
    "country": "PA",
    "name": "Alanje",
    "lat": "8.39791",
    "lng": "-82.55947"
  },
  {
    "country": "PA",
    "name": "Ailigandí",
    "lat": "9.2281",
    "lng": "-78.02778"
  },
  {
    "country": "PA",
    "name": "Aguas Blancas",
    "lat": "8.50351",
    "lng": "-80.31169"
  },
  {
    "country": "PA",
    "name": "Aguadulce",
    "lat": "8.24183",
    "lng": "-80.54609"
  },
  {
    "country": "PA",
    "name": "Agua de Salud",
    "lat": "8.50486",
    "lng": "-81.46397"
  },
  {
    "country": "PA",
    "name": "Agua Buena",
    "lat": "7.83465",
    "lng": "-80.39405"
  },
  {
    "country": "PA",
    "name": "Achutupo",
    "lat": "9.19827",
    "lng": "-77.98729"
  },
  {
    "country": "PA",
    "name": "Achiote",
    "lat": "9.21121",
    "lng": "-80.01338"
  },
  {
    "country": "PA",
    "name": "Pásiga",
    "lat": "8.93647",
    "lng": "-78.90917"
  },
  {
    "country": "PA",
    "name": "Jingurudó",
    "lat": "7.87962",
    "lng": "-78.07689"
  },
  {
    "country": "PA",
    "name": "Santa Rita Arriba",
    "lat": "9.33032",
    "lng": "-79.79363"
  },
  {
    "country": "PA",
    "name": "Lajas Blancas",
    "lat": "8.41482",
    "lng": "-77.81161"
  },
  {
    "country": "PA",
    "name": "Unión Chocó",
    "lat": "8.08404",
    "lng": "-77.53507"
  },
  {
    "country": "PA",
    "name": "Howard",
    "lat": "8.93942",
    "lng": "-79.59097"
  },
  {
    "country": "PA",
    "name": "Villa Lourdes",
    "lat": "7.81141",
    "lng": "-80.47029"
  },
  {
    "country": "PA",
    "name": "Cedro Arriba",
    "lat": "7.78097",
    "lng": "-80.53057"
  },
  {
    "country": "PA",
    "name": "San Juan Bautista",
    "lat": "7.96099",
    "lng": "-80.41283"
  },
  {
    "country": "PA",
    "name": "Oria Arriba",
    "lat": "7.50505",
    "lng": "-80.20567"
  },
  {
    "country": "PA",
    "name": "Villa Unida",
    "lat": "9.18908",
    "lng": "-79.62452"
  },
  {
    "country": "PA",
    "name": "San Antonio",
    "lat": "9.1729",
    "lng": "-79.54743"
  },
  {
    "country": "PA",
    "name": "Gonzalillo",
    "lat": "9.09183",
    "lng": "-79.51928"
  },
  {
    "country": "PA",
    "name": "Nuevo Belén",
    "lat": "9.07939",
    "lng": "-79.39556"
  },
  {
    "country": "PA",
    "name": "La Colorada",
    "lat": "9.10224",
    "lng": "-79.416"
  },
  {
    "country": "PA",
    "name": "Vista Hermosa",
    "lat": "9.11178",
    "lng": "-79.36113"
  },
  {
    "country": "PA",
    "name": "Nueva Esperanza",
    "lat": "9.1021",
    "lng": "-79.33414"
  },
  {
    "country": "PA",
    "name": "Unión de Azuero",
    "lat": "9.15256",
    "lng": "-79.17005"
  },
  {
    "country": "PA",
    "name": "Tortí",
    "lat": "8.92132",
    "lng": "-78.40546"
  },
  {
    "country": "PA",
    "name": "Barriales",
    "lat": "8.58402",
    "lng": "-78.38822"
  },
  {
    "country": "PA",
    "name": "Platanilla",
    "lat": "8.828",
    "lng": "-78.38435"
  },
  {
    "country": "PA",
    "name": "Setegantí",
    "lat": "8.29381",
    "lng": "-78.10025"
  },
  {
    "country": "PA",
    "name": "Camogantí",
    "lat": "8.04171",
    "lng": "-77.88682"
  },
  {
    "country": "PA",
    "name": "Corozal",
    "lat": "8.20108",
    "lng": "-77.59637"
  },
  {
    "country": "PA",
    "name": "Agua Fría Número Uno",
    "lat": "8.85839",
    "lng": "-78.1975"
  },
  {
    "country": "PA",
    "name": "Bayamón",
    "lat": "7.96817",
    "lng": "-78.21648"
  },
  {
    "country": "PA",
    "name": "Unión Santeña",
    "lat": "8.83525",
    "lng": "-78.65104"
  },
  {
    "country": "PA",
    "name": "Contadora",
    "lat": "8.62483",
    "lng": "-79.03748"
  },
  {
    "country": "PA",
    "name": "Norteño",
    "lat": "9.00308",
    "lng": "-82.31476"
  },
  {
    "country": "PA",
    "name": "Sieyic",
    "lat": "9.38323",
    "lng": "-82.65206"
  },
  {
    "country": "PA",
    "name": "Barranco Adentro",
    "lat": "9.52757",
    "lng": "-82.73344"
  },
  {
    "country": "PA",
    "name": "La Mesa",
    "lat": "9.49587",
    "lng": "-82.67534"
  },
  {
    "country": "PA",
    "name": "Quebrada del Rosario",
    "lat": "7.71238",
    "lng": "-80.74222"
  },
  {
    "country": "PA",
    "name": "Paso Canoas Arriba",
    "lat": "8.56516",
    "lng": "-82.82214"
  },
  {
    "country": "PA",
    "name": "El Palmar",
    "lat": "8.30098",
    "lng": "-82.85344"
  },
  {
    "country": "PA",
    "name": "Manaca Norte",
    "lat": "8.33419",
    "lng": "-82.81003"
  },
  {
    "country": "PA",
    "name": "Manaca Civil",
    "lat": "8.32458",
    "lng": "-82.8157"
  },
  {
    "country": "PA",
    "name": "Algarrobos Arriba",
    "lat": "8.5155",
    "lng": "-82.42263"
  },
  {
    "country": "PA",
    "name": "Nuevo San Carlitos",
    "lat": "8.45698",
    "lng": "-82.43712"
  },
  {
    "country": "PA",
    "name": "Rámbala",
    "lat": "8.92046",
    "lng": "-82.1806"
  },
  {
    "country": "PA",
    "name": "Pueblo Nuevo",
    "lat": "8.8807",
    "lng": "-82.22411"
  },
  {
    "country": "PA",
    "name": "Valle de La Mina",
    "lat": "8.66427",
    "lng": "-82.23196"
  },
  {
    "country": "PA",
    "name": "Quebrada Tula",
    "lat": "8.84037",
    "lng": "-81.99645"
  },
  {
    "country": "PA",
    "name": "Boca de Balsa",
    "lat": "8.52995",
    "lng": "-82.03132"
  },
  {
    "country": "PA",
    "name": "Cuoronte",
    "lat": "8.67457",
    "lng": "-81.78586"
  },
  {
    "country": "PA",
    "name": "Oma",
    "lat": "8.35019",
    "lng": "-81.80177"
  },
  {
    "country": "PA",
    "name": "Cabecera de Cerro Puerco",
    "lat": "8.31856",
    "lng": "-81.75951"
  },
  {
    "country": "PA",
    "name": "El Porvenir",
    "lat": "8.22919",
    "lng": "-81.83278"
  },
  {
    "country": "PA",
    "name": "Santa Lucia",
    "lat": "8.23123",
    "lng": "-81.82613"
  },
  {
    "country": "PA",
    "name": "El Puerto",
    "lat": "8.21238",
    "lng": "-81.80797"
  },
  {
    "country": "PA",
    "name": "Mirones",
    "lat": "8.55757",
    "lng": "-81.72574"
  },
  {
    "country": "PA",
    "name": "Bajo Solis",
    "lat": "8.34751",
    "lng": "-81.52912"
  },
  {
    "country": "PA",
    "name": "Bella Vista",
    "lat": "8.20617",
    "lng": "-81.62123"
  },
  {
    "country": "PA",
    "name": "Cerro Pelado",
    "lat": "8.16247",
    "lng": "-81.53917"
  },
  {
    "country": "PA",
    "name": "Lajero Arriba",
    "lat": "8.2906",
    "lng": "-81.77047"
  },
  {
    "country": "PA",
    "name": "Loma Yuca",
    "lat": "8.71817",
    "lng": "-81.40492"
  },
  {
    "country": "PA",
    "name": "Los Pollos",
    "lat": "8.39898",
    "lng": "-80.15731"
  },
  {
    "country": "PA",
    "name": "San Juan de Dios",
    "lat": "8.55119",
    "lng": "-80.22623"
  },
  {
    "country": "PA",
    "name": "Río Luís",
    "lat": "8.68361",
    "lng": "-81.21608"
  },
  {
    "country": "PA",
    "name": "Güibale",
    "lat": "8.51225",
    "lng": "-81.36257"
  },
  {
    "country": "PA",
    "name": "Paredón Arriba",
    "lat": "8.45977",
    "lng": "-81.19592"
  },
  {
    "country": "PA",
    "name": "Guayabito",
    "lat": "8.53949",
    "lng": "-81.48225"
  },
  {
    "country": "PA",
    "name": "Alto de Jesús",
    "lat": "8.26152",
    "lng": "-81.48412"
  },
  {
    "country": "PA",
    "name": "La Pesa",
    "lat": "8.85073",
    "lng": "-79.82374"
  },
  {
    "country": "PA",
    "name": "Ciricito Abajo",
    "lat": "8.7995",
    "lng": "-80.07747"
  },
  {
    "country": "PE",
    "name": "Zorritos",
    "lat": "-3.68046",
    "lng": "-80.67819"
  },
  {
    "country": "PE",
    "name": "Yurimaguas",
    "lat": "-5.90181",
    "lng": "-76.12234"
  },
  {
    "country": "PE",
    "name": "Yuracyacu",
    "lat": "-5.93139",
    "lng": "-77.22667"
  },
  {
    "country": "PE",
    "name": "Yungay",
    "lat": "-9.13833",
    "lng": "-77.74361"
  },
  {
    "country": "PE",
    "name": "Yungar",
    "lat": "-9.37778",
    "lng": "-77.59306"
  },
  {
    "country": "PE",
    "name": "Yorongos",
    "lat": "-6.13972",
    "lng": "-77.14389"
  },
  {
    "country": "PE",
    "name": "Yauya",
    "lat": "-8.98333",
    "lng": "-77.3"
  },
  {
    "country": "PE",
    "name": "Yanas",
    "lat": "-9.71417",
    "lng": "-76.74822"
  },
  {
    "country": "PE",
    "name": "Yanama",
    "lat": "-9.03333",
    "lng": "-77.48333"
  },
  {
    "country": "PE",
    "name": "Yanac",
    "lat": "-8.61667",
    "lng": "-77.86667"
  },
  {
    "country": "PE",
    "name": "Yambrasbamba",
    "lat": "-5.75",
    "lng": "-77.9"
  },
  {
    "country": "PE",
    "name": "Yamango",
    "lat": "-5.1775",
    "lng": "-79.75"
  },
  {
    "country": "PE",
    "name": "Vista Alegre",
    "lat": "-6.15139",
    "lng": "-77.30056"
  },
  {
    "country": "PE",
    "name": "Virú",
    "lat": "-8.41554",
    "lng": "-78.75201"
  },
  {
    "country": "PE",
    "name": "Vice",
    "lat": "-5.41667",
    "lng": "-80.78333"
  },
  {
    "country": "PE",
    "name": "Uticyacu",
    "lat": "-6.63333",
    "lng": "-78.8"
  },
  {
    "country": "PE",
    "name": "Usquil",
    "lat": "-7.81667",
    "lng": "-78.41667"
  },
  {
    "country": "PE",
    "name": "Ucuncha",
    "lat": "-7.13333",
    "lng": "-77.88333"
  },
  {
    "country": "PE",
    "name": "Uco",
    "lat": "-9.18839",
    "lng": "-76.92767"
  },
  {
    "country": "PE",
    "name": "Uchiza",
    "lat": "-8.45917",
    "lng": "-76.46333"
  },
  {
    "country": "PE",
    "name": "Tunal",
    "lat": "-5.20917",
    "lng": "-79.67528"
  },
  {
    "country": "PE",
    "name": "Tumbes",
    "lat": "-3.56694",
    "lng": "-80.45153"
  },
  {
    "country": "PE",
    "name": "Túcume",
    "lat": "-6.50637",
    "lng": "-79.85725"
  },
  {
    "country": "PE",
    "name": "Trujillo",
    "lat": "-8.11599",
    "lng": "-79.02998"
  },
  {
    "country": "PE",
    "name": "Trompeteros",
    "lat": "-3.81417",
    "lng": "-75.05833"
  },
  {
    "country": "PE",
    "name": "Trinidad",
    "lat": "-7.35",
    "lng": "-79.03333"
  },
  {
    "country": "PE",
    "name": "Tres Unidos",
    "lat": "-6.80694",
    "lng": "-76.22944"
  },
  {
    "country": "PE",
    "name": "Tournavista",
    "lat": "-8.92947",
    "lng": "-74.70771"
  },
  {
    "country": "PE",
    "name": "Totora",
    "lat": "-6.4925",
    "lng": "-77.47306"
  },
  {
    "country": "PE",
    "name": "Tocmoche",
    "lat": "-6.4125",
    "lng": "-79.36194"
  },
  {
    "country": "PE",
    "name": "Tocache",
    "lat": "-8.1877",
    "lng": "-76.52046"
  },
  {
    "country": "PE",
    "name": "Tingo María",
    "lat": "-9.29532",
    "lng": "-75.99574"
  },
  {
    "country": "PE",
    "name": "Tingo",
    "lat": "-6.37167",
    "lng": "-77.91194"
  },
  {
    "country": "PE",
    "name": "Tinco",
    "lat": "-9.26972",
    "lng": "-77.67944"
  },
  {
    "country": "PE",
    "name": "Ticapampa",
    "lat": "-9.75",
    "lng": "-77.45"
  },
  {
    "country": "PE",
    "name": "Tembladera",
    "lat": "-7.26667",
    "lng": "-79.15"
  },
  {
    "country": "PE",
    "name": "Tayabamba",
    "lat": "-8.27694",
    "lng": "-77.29639"
  },
  {
    "country": "PE",
    "name": "Taurija",
    "lat": "-8.30861",
    "lng": "-77.42194"
  },
  {
    "country": "PE",
    "name": "Tauca",
    "lat": "-8.48333",
    "lng": "-78.05"
  },
  {
    "country": "PE",
    "name": "Tarica",
    "lat": "-9.39361",
    "lng": "-77.57472"
  },
  {
    "country": "PE",
    "name": "Tarapoto",
    "lat": "-6.50139",
    "lng": "-76.36556"
  },
  {
    "country": "PE",
    "name": "Tantamayo",
    "lat": "-9.39114",
    "lng": "-76.72331"
  },
  {
    "country": "PE",
    "name": "Tambo Grande",
    "lat": "-4.92694",
    "lng": "-80.34472"
  },
  {
    "country": "PE",
    "name": "Tamarindo",
    "lat": "-4.87722",
    "lng": "-80.97306"
  },
  {
    "country": "PE",
    "name": "Tamanco",
    "lat": "-5.85",
    "lng": "-74.31667"
  },
  {
    "country": "PE",
    "name": "Talara",
    "lat": "-4.57722",
    "lng": "-81.27194"
  },
  {
    "country": "PE",
    "name": "Tacabamba",
    "lat": "-6.38333",
    "lng": "-78.61667"
  },
  {
    "country": "PE",
    "name": "Tabalosos",
    "lat": "-6.35",
    "lng": "-76.68333"
  },
  {
    "country": "PE",
    "name": "Tabaconas",
    "lat": "-5.31472",
    "lng": "-79.28278"
  },
  {
    "country": "PE",
    "name": "Suyo",
    "lat": "-4.51392",
    "lng": "-80.00313"
  },
  {
    "country": "PE",
    "name": "Sullana",
    "lat": "-4.90389",
    "lng": "-80.68528"
  },
  {
    "country": "PE",
    "name": "Sucre",
    "lat": "-8.95",
    "lng": "-77.85"
  },
  {
    "country": "PE",
    "name": "Sucre",
    "lat": "-6.93333",
    "lng": "-78.15"
  },
  {
    "country": "PE",
    "name": "Succha",
    "lat": "-9.83333",
    "lng": "-77.65"
  },
  {
    "country": "PE",
    "name": "Sorochuco",
    "lat": "-6.91083",
    "lng": "-78.255"
  },
  {
    "country": "PE",
    "name": "Soritor",
    "lat": "-6.13917",
    "lng": "-77.10389"
  },
  {
    "country": "PE",
    "name": "Sondorillo",
    "lat": "-5.33917",
    "lng": "-79.43028"
  },
  {
    "country": "PE",
    "name": "Sondor",
    "lat": "-5.31222",
    "lng": "-79.40639"
  },
  {
    "country": "PE",
    "name": "Soloco",
    "lat": "-6.26222",
    "lng": "-77.74444"
  },
  {
    "country": "PE",
    "name": "Sojo",
    "lat": "-4.90083",
    "lng": "-80.81583"
  },
  {
    "country": "PE",
    "name": "Socota",
    "lat": "-6.3",
    "lng": "-78.73333"
  },
  {
    "country": "PE",
    "name": "Sitabamba",
    "lat": "-8.03333",
    "lng": "-77.73333"
  },
  {
    "country": "PE",
    "name": "Sinsicap",
    "lat": "-7.83333",
    "lng": "-78.76667"
  },
  {
    "country": "PE",
    "name": "Singa",
    "lat": "-9.38745",
    "lng": "-76.81262"
  },
  {
    "country": "PE",
    "name": "Sinchao",
    "lat": "-5.41667",
    "lng": "-80.66667"
  },
  {
    "country": "PE",
    "name": "Simbal",
    "lat": "-7.97639",
    "lng": "-78.8136"
  },
  {
    "country": "PE",
    "name": "Sillapata",
    "lat": "-9.75794",
    "lng": "-76.77443"
  },
  {
    "country": "PE",
    "name": "Sihuas",
    "lat": "-8.56667",
    "lng": "-77.61667"
  },
  {
    "country": "PE",
    "name": "Shupluy",
    "lat": "-9.21778",
    "lng": "-77.69417"
  },
  {
    "country": "PE",
    "name": "Shunqui",
    "lat": "-9.73384",
    "lng": "-76.78651"
  },
  {
    "country": "PE",
    "name": "Shucushuyacu",
    "lat": "-6.01667",
    "lng": "-75.85"
  },
  {
    "country": "PE",
    "name": "Shirac",
    "lat": "-7.35",
    "lng": "-78.05"
  },
  {
    "country": "PE",
    "name": "Shilla",
    "lat": "-9.23083",
    "lng": "-77.625"
  },
  {
    "country": "PE",
    "name": "Shapaja",
    "lat": "-6.57972",
    "lng": "-76.26278"
  },
  {
    "country": "PE",
    "name": "Shamboyacu",
    "lat": "-7.02308",
    "lng": "-76.13298"
  },
  {
    "country": "PE",
    "name": "Sexi",
    "lat": "-6.56361",
    "lng": "-79.05139"
  },
  {
    "country": "PE",
    "name": "Sechura",
    "lat": "-5.55694",
    "lng": "-80.82222"
  },
  {
    "country": "PE",
    "name": "Sayapullo",
    "lat": "-7.6",
    "lng": "-78.46667"
  },
  {
    "country": "PE",
    "name": "Sauce",
    "lat": "-6.69139",
    "lng": "-76.21472"
  },
  {
    "country": "PE",
    "name": "Sartimbamba",
    "lat": "-7.69917",
    "lng": "-77.74361"
  },
  {
    "country": "PE",
    "name": "Saquena",
    "lat": "-4.66667",
    "lng": "-73.51667"
  },
  {
    "country": "PE",
    "name": "Saposoa",
    "lat": "-6.93395",
    "lng": "-76.77158"
  },
  {
    "country": "PE",
    "name": "Sapillica",
    "lat": "-4.77838",
    "lng": "-79.98263"
  },
  {
    "country": "PE",
    "name": "Sapalache",
    "lat": "-5.15111",
    "lng": "-79.43472"
  },
  {
    "country": "PE",
    "name": "Santo Domingo",
    "lat": "-5.02611",
    "lng": "-79.87417"
  },
  {
    "country": "PE",
    "name": "Santiago de Chuco",
    "lat": "-8.14099",
    "lng": "-78.17329"
  },
  {
    "country": "PE",
    "name": "Santiago de Cao",
    "lat": "-7.95889",
    "lng": "-79.23917"
  },
  {
    "country": "PE",
    "name": "Santa Rosa",
    "lat": "-6.88111",
    "lng": "-79.91972"
  },
  {
    "country": "PE",
    "name": "Santa Rosa",
    "lat": "-6.75772",
    "lng": "-79.82747"
  },
  {
    "country": "PE",
    "name": "Santa Rosa",
    "lat": "-6.68333",
    "lng": "-76.61667"
  },
  {
    "country": "PE",
    "name": "Santa Isabel",
    "lat": "-5.76667",
    "lng": "-74.51667"
  },
  {
    "country": "PE",
    "name": "Santa Elena",
    "lat": "-6.03333",
    "lng": "-74.08333"
  },
  {
    "country": "PE",
    "name": "Santa Cruz",
    "lat": "-5.55",
    "lng": "-75.8"
  },
  {
    "country": "PE",
    "name": "Santa",
    "lat": "-8.98861",
    "lng": "-78.61194"
  },
  {
    "country": "PE",
    "name": "San Rafael",
    "lat": "-7.0304",
    "lng": "-76.47499"
  },
  {
    "country": "PE",
    "name": "San Pedro de Lloc",
    "lat": "-7.4289",
    "lng": "-79.50416"
  },
  {
    "country": "PE",
    "name": "San Pablo",
    "lat": "-7.11667",
    "lng": "-78.83333"
  },
  {
    "country": "PE",
    "name": "San Pablo",
    "lat": "-6.81923",
    "lng": "-76.57578"
  },
  {
    "country": "PE",
    "name": "San Marcos",
    "lat": "-9.52491",
    "lng": "-77.15681"
  },
  {
    "country": "PE",
    "name": "San Marcos",
    "lat": "-7.33333",
    "lng": "-78.18333"
  },
  {
    "country": "PE",
    "name": "San Luis",
    "lat": "-9.08333",
    "lng": "-77.35"
  },
  {
    "country": "PE",
    "name": "San Lorenzo",
    "lat": "-4.81667",
    "lng": "-76.6"
  },
  {
    "country": "PE",
    "name": "San Juan",
    "lat": "-7.3",
    "lng": "-78.5"
  },
  {
    "country": "PE",
    "name": "Sisa",
    "lat": "-6.61085",
    "lng": "-76.69302"
  },
  {
    "country": "PE",
    "name": "San José",
    "lat": "-6.73813",
    "lng": "-79.8275"
  },
  {
    "country": "PE",
    "name": "San Jacinto",
    "lat": "-4.84333",
    "lng": "-80.87639"
  },
  {
    "country": "PE",
    "name": "San Jacinto",
    "lat": "-3.64194",
    "lng": "-80.4475"
  },
  {
    "country": "PE",
    "name": "San Ignacio",
    "lat": "-5.14583",
    "lng": "-79.00139"
  },
  {
    "country": "PE",
    "name": "San Gregorio",
    "lat": "-7.05",
    "lng": "-79.1"
  },
  {
    "country": "PE",
    "name": "San Felipe",
    "lat": "-5.76778",
    "lng": "-79.31167"
  },
  {
    "country": "PE",
    "name": "San Carlos",
    "lat": "-5.96667",
    "lng": "-77.93333"
  },
  {
    "country": "PE",
    "name": "San Bernardino",
    "lat": "-7.18333",
    "lng": "-78.83333"
  },
  {
    "country": "PE",
    "name": "San Benito",
    "lat": "-7.43333",
    "lng": "-78.93333"
  },
  {
    "country": "PE",
    "name": "San Antonio",
    "lat": "-6.36667",
    "lng": "-76.35"
  },
  {
    "country": "PE",
    "name": "Saña",
    "lat": "-6.91888",
    "lng": "-79.582"
  },
  {
    "country": "PE",
    "name": "Samanco",
    "lat": "-9.26167",
    "lng": "-78.49611"
  },
  {
    "country": "PE",
    "name": "Salpo",
    "lat": "-8",
    "lng": "-78.61667"
  },
  {
    "country": "PE",
    "name": "Sallique",
    "lat": "-5.655",
    "lng": "-79.31333"
  },
  {
    "country": "PE",
    "name": "Salitral",
    "lat": "-4.85722",
    "lng": "-80.68111"
  },
  {
    "country": "PE",
    "name": "Salinera Colán",
    "lat": "-5.03333",
    "lng": "-81.06667"
  },
  {
    "country": "PE",
    "name": "Guadalupito",
    "lat": "-8.95028",
    "lng": "-78.62278"
  },
  {
    "country": "PE",
    "name": "Salaverry",
    "lat": "-8.221",
    "lng": "-78.97698"
  },
  {
    "country": "PE",
    "name": "Salas",
    "lat": "-6.27472",
    "lng": "-79.60417"
  },
  {
    "country": "PE",
    "name": "Sacanche",
    "lat": "-7.06935",
    "lng": "-76.71484"
  },
  {
    "country": "PE",
    "name": "Roque",
    "lat": "-6.4",
    "lng": "-76.8"
  },
  {
    "country": "PE",
    "name": "Rondos",
    "lat": "-9.98372",
    "lng": "-76.68839"
  },
  {
    "country": "PE",
    "name": "Rioja",
    "lat": "-6.05675",
    "lng": "-77.16651"
  },
  {
    "country": "PE",
    "name": "Requena",
    "lat": "-5.06083",
    "lng": "-73.85028"
  },
  {
    "country": "PE",
    "name": "Reque",
    "lat": "-6.86556",
    "lng": "-79.81778"
  },
  {
    "country": "PE",
    "name": "Recuay",
    "lat": "-9.72215",
    "lng": "-77.4563"
  },
  {
    "country": "PE",
    "name": "Ranrahirca",
    "lat": "-9.17139",
    "lng": "-77.72194"
  },
  {
    "country": "PE",
    "name": "Ramón Castilla",
    "lat": "-4.26066",
    "lng": "-69.95714"
  },
  {
    "country": "PE",
    "name": "Quivilla",
    "lat": "-9.59929",
    "lng": "-76.72494"
  },
  {
    "country": "PE",
    "name": "Quiruvilca",
    "lat": "-7.96667",
    "lng": "-78.2"
  },
  {
    "country": "PE",
    "name": "Quinuabamba",
    "lat": "-8.73333",
    "lng": "-77.36667"
  },
  {
    "country": "PE",
    "name": "Quinjalca",
    "lat": "-6.09222",
    "lng": "-77.67806"
  },
  {
    "country": "PE",
    "name": "Quillo",
    "lat": "-9.32917",
    "lng": "-78.04139"
  },
  {
    "country": "PE",
    "name": "Quiches",
    "lat": "-8.395",
    "lng": "-77.49083"
  },
  {
    "country": "PE",
    "name": "Querocoto",
    "lat": "-6.35889",
    "lng": "-79.03583"
  },
  {
    "country": "PE",
    "name": "Querocotillo",
    "lat": "-6.27389",
    "lng": "-79.03806"
  },
  {
    "country": "PE",
    "name": "Querecotillo",
    "lat": "-4.83778",
    "lng": "-80.64556"
  },
  {
    "country": "PE",
    "name": "Puños",
    "lat": "-9.49735",
    "lng": "-76.88469"
  },
  {
    "country": "PE",
    "name": "Punchao",
    "lat": "-9.46221",
    "lng": "-76.81953"
  },
  {
    "country": "PE",
    "name": "Puerto Santa",
    "lat": "-8.98772",
    "lng": "-78.64727"
  },
  {
    "country": "PE",
    "name": "Puerto Rico",
    "lat": "-6.99222",
    "lng": "-76.41917"
  },
  {
    "country": "PE",
    "name": "Puerto Inca",
    "lat": "-9.377",
    "lng": "-74.96564"
  },
  {
    "country": "PE",
    "name": "Puerto Galilea",
    "lat": "-4.05743",
    "lng": "-77.75848"
  },
  {
    "country": "PE",
    "name": "Puerto Casma",
    "lat": "-9.46361",
    "lng": "-78.3825"
  },
  {
    "country": "PE",
    "name": "Chao",
    "lat": "-8.54306",
    "lng": "-78.67917"
  },
  {
    "country": "PE",
    "name": "Pueblo Nuevo",
    "lat": "-7.18806",
    "lng": "-79.51528"
  },
  {
    "country": "PE",
    "name": "Pueblo Nuevo",
    "lat": "-5.71667",
    "lng": "-79.88333"
  },
  {
    "country": "PE",
    "name": "Pucallpa",
    "lat": "-8.37915",
    "lng": "-74.55387"
  },
  {
    "country": "PE",
    "name": "Pucacaca",
    "lat": "-6.85167",
    "lng": "-76.34167"
  },
  {
    "country": "PE",
    "name": "Posic",
    "lat": "-6.01389",
    "lng": "-77.16361"
  },
  {
    "country": "PE",
    "name": "Poroto",
    "lat": "-8.01125",
    "lng": "-78.76769"
  },
  {
    "country": "PE",
    "name": "Pomalca",
    "lat": "-6.7675",
    "lng": "-79.77722"
  },
  {
    "country": "PE",
    "name": "Pomahuaca",
    "lat": "-5.92861",
    "lng": "-79.22611"
  },
  {
    "country": "PE",
    "name": "Pomabamba",
    "lat": "-8.83333",
    "lng": "-77.46667"
  },
  {
    "country": "PE",
    "name": "Piura",
    "lat": "-5.19449",
    "lng": "-80.63282"
  },
  {
    "country": "PE",
    "name": "Piscoyacu",
    "lat": "-6.97984",
    "lng": "-76.76813"
  },
  {
    "country": "PE",
    "name": "Pira",
    "lat": "-9.56667",
    "lng": "-77.71667"
  },
  {
    "country": "PE",
    "name": "Pimentel",
    "lat": "-6.83667",
    "lng": "-79.93417"
  },
  {
    "country": "PE",
    "name": "Pilluana",
    "lat": "-6.7775",
    "lng": "-76.29056"
  },
  {
    "country": "PE",
    "name": "Picsi",
    "lat": "-6.71778",
    "lng": "-79.76972"
  },
  {
    "country": "PE",
    "name": "Picota",
    "lat": "-6.92033",
    "lng": "-76.33142"
  },
  {
    "country": "PE",
    "name": "Pelejo",
    "lat": "-6.21667",
    "lng": "-75.81667"
  },
  {
    "country": "PE",
    "name": "Pebas",
    "lat": "-3.32879",
    "lng": "-71.85505"
  },
  {
    "country": "PE",
    "name": "Paucas",
    "lat": "-9.15227",
    "lng": "-76.89906"
  },
  {
    "country": "PE",
    "name": "Paltashaco",
    "lat": "-5.09972",
    "lng": "-79.88333"
  },
  {
    "country": "PE",
    "name": "Parinari",
    "lat": "-4.56667",
    "lng": "-74.43333"
  },
  {
    "country": "PE",
    "name": "Papayal",
    "lat": "-3.59667",
    "lng": "-80.20889"
  },
  {
    "country": "PE",
    "name": "Pantoja",
    "lat": "-0.96667",
    "lng": "-75.16667"
  },
  {
    "country": "PE",
    "name": "Panao",
    "lat": "-9.89778",
    "lng": "-75.99333"
  },
  {
    "country": "PE",
    "name": "Pampas",
    "lat": "-9.66667",
    "lng": "-77.83333"
  },
  {
    "country": "PE",
    "name": "Pampas",
    "lat": "-8.2",
    "lng": "-77.9"
  },
  {
    "country": "PE",
    "name": "Pamparomas",
    "lat": "-9.07361",
    "lng": "-77.98139"
  },
  {
    "country": "PE",
    "name": "Pampa Hermosa",
    "lat": "-7.2",
    "lng": "-75.3"
  },
  {
    "country": "PE",
    "name": "Pallasca",
    "lat": "-8.25",
    "lng": "-78.01667"
  },
  {
    "country": "PE",
    "name": "Paita",
    "lat": "-5.08917",
    "lng": "-81.11444"
  },
  {
    "country": "PE",
    "name": "Paimas",
    "lat": "-4.6269",
    "lng": "-79.94456"
  },
  {
    "country": "PE",
    "name": "Paiján",
    "lat": "-7.73291",
    "lng": "-79.3015"
  },
  {
    "country": "PE",
    "name": "Pacora",
    "lat": "-6.42889",
    "lng": "-79.83889"
  },
  {
    "country": "PE",
    "name": "Paclas",
    "lat": "-6.06222",
    "lng": "-77.97667"
  },
  {
    "country": "PE",
    "name": "Pachas",
    "lat": "-9.70651",
    "lng": "-76.77113"
  },
  {
    "country": "PE",
    "name": "Paccha",
    "lat": "-6.49778",
    "lng": "-78.41833"
  },
  {
    "country": "PE",
    "name": "Pacasmayo",
    "lat": "-7.40056",
    "lng": "-79.57139"
  },
  {
    "country": "PE",
    "name": "Pacanga",
    "lat": "-7.16667",
    "lng": "-79.5"
  },
  {
    "country": "PE",
    "name": "Pacaipampa",
    "lat": "-4.99502",
    "lng": "-79.66773"
  },
  {
    "country": "PE",
    "name": "Oyotún",
    "lat": "-6.84438",
    "lng": "-79.30093"
  },
  {
    "country": "PE",
    "name": "Oxamarca",
    "lat": "-7.03333",
    "lng": "-78.06667"
  },
  {
    "country": "PE",
    "name": "Otuzco",
    "lat": "-7.9",
    "lng": "-78.58333"
  },
  {
    "country": "PE",
    "name": "Orellana",
    "lat": "-6.9",
    "lng": "-75.16667"
  },
  {
    "country": "PE",
    "name": "Omia",
    "lat": "-6.46861",
    "lng": "-77.39444"
  },
  {
    "country": "PE",
    "name": "Olto",
    "lat": "-6.1025",
    "lng": "-77.95944"
  },
  {
    "country": "PE",
    "name": "Olmos",
    "lat": "-5.98472",
    "lng": "-79.74528"
  },
  {
    "country": "PE",
    "name": "Olleros",
    "lat": "-9.63333",
    "lng": "-77.48333"
  },
  {
    "country": "PE",
    "name": "Olleros",
    "lat": "-6.04861",
    "lng": "-77.64583"
  },
  {
    "country": "PE",
    "name": "Obas",
    "lat": "-9.79535",
    "lng": "-76.66557"
  },
  {
    "country": "PE",
    "name": "Nueva Arica",
    "lat": "-6.87278",
    "lng": "-79.34278"
  },
  {
    "country": "PE",
    "name": "Niepos",
    "lat": "-6.92694",
    "lng": "-79.12861"
  },
  {
    "country": "PE",
    "name": "Nepeña",
    "lat": "-9.1725",
    "lng": "-78.35889"
  },
  {
    "country": "PE",
    "name": "Negritos",
    "lat": "-4.65389",
    "lng": "-81.30472"
  },
  {
    "country": "PE",
    "name": "Navarro",
    "lat": "-6.33333",
    "lng": "-75.75"
  },
  {
    "country": "PE",
    "name": "Nauta",
    "lat": "-4.53333",
    "lng": "-73.55"
  },
  {
    "country": "PE",
    "name": "Nanchoc",
    "lat": "-6.95972",
    "lng": "-79.24222"
  },
  {
    "country": "PE",
    "name": "Namora",
    "lat": "-7.2",
    "lng": "-78.33333"
  },
  {
    "country": "PE",
    "name": "Namballe",
    "lat": "-5.00352",
    "lng": "-79.08907"
  },
  {
    "country": "PE",
    "name": "Moyobamba",
    "lat": "-6.03416",
    "lng": "-76.97168"
  },
  {
    "country": "PE",
    "name": "Motupe",
    "lat": "-6.15194",
    "lng": "-79.71417"
  },
  {
    "country": "PE",
    "name": "Morropón",
    "lat": "-5.1868",
    "lng": "-79.97076"
  },
  {
    "country": "PE",
    "name": "Mórrope",
    "lat": "-6.53536",
    "lng": "-80.01104"
  },
  {
    "country": "PE",
    "name": "Moro",
    "lat": "-9.13889",
    "lng": "-78.18194"
  },
  {
    "country": "PE",
    "name": "Montevideo",
    "lat": "-6.61583",
    "lng": "-77.8025"
  },
  {
    "country": "PE",
    "name": "Montero",
    "lat": "-4.63066",
    "lng": "-79.82855"
  },
  {
    "country": "PE",
    "name": "Monsefú",
    "lat": "-6.87431",
    "lng": "-79.86871"
  },
  {
    "country": "PE",
    "name": "Mollepata",
    "lat": "-8.2",
    "lng": "-77.95"
  },
  {
    "country": "PE",
    "name": "Mocupe",
    "lat": "-6.98944",
    "lng": "-79.61917"
  },
  {
    "country": "PE",
    "name": "Mochumí",
    "lat": "-6.54364",
    "lng": "-79.86217"
  },
  {
    "country": "PE",
    "name": "Moche",
    "lat": "-8.17111",
    "lng": "-79.00917"
  },
  {
    "country": "PE",
    "name": "Miraflores",
    "lat": "-9.49396",
    "lng": "-76.8187"
  },
  {
    "country": "PE",
    "name": "Miracosta",
    "lat": "-6.40417",
    "lng": "-79.28444"
  },
  {
    "country": "PE",
    "name": "Milpuc",
    "lat": "-6.49361",
    "lng": "-77.435"
  },
  {
    "country": "PE",
    "name": "Mendoza",
    "lat": "-6.39444",
    "lng": "-77.48167"
  },
  {
    "country": "PE",
    "name": "Matapalo",
    "lat": "-3.68271",
    "lng": "-80.19899"
  },
  {
    "country": "PE",
    "name": "Masisea",
    "lat": "-8.60528",
    "lng": "-74.30472"
  },
  {
    "country": "PE",
    "name": "Marcavelica",
    "lat": "-4.87778",
    "lng": "-80.70528"
  },
  {
    "country": "PE",
    "name": "Marcara District",
    "lat": "-9.3225",
    "lng": "-77.60361"
  },
  {
    "country": "PE",
    "name": "Marcabal",
    "lat": "-7.7",
    "lng": "-78.03333"
  },
  {
    "country": "PE",
    "name": "Mancos",
    "lat": "-9.19111",
    "lng": "-77.71333"
  },
  {
    "country": "PE",
    "name": "Máncora",
    "lat": "-4.10778",
    "lng": "-81.0475"
  },
  {
    "country": "PE",
    "name": "Malvas",
    "lat": "-9.91667",
    "lng": "-77.68333"
  },
  {
    "country": "PE",
    "name": "Maino",
    "lat": "-6.33667",
    "lng": "-77.88"
  },
  {
    "country": "PE",
    "name": "Magdalena",
    "lat": "-7.25",
    "lng": "-78.66667"
  },
  {
    "country": "PE",
    "name": "Magdalena",
    "lat": "-6.37306",
    "lng": "-77.9"
  },
  {
    "country": "PE",
    "name": "Mache",
    "lat": "-8.03333",
    "lng": "-78.53333"
  },
  {
    "country": "PE",
    "name": "Macate",
    "lat": "-8.76667",
    "lng": "-78.08333"
  },
  {
    "country": "PE",
    "name": "Luya",
    "lat": "-6.16389",
    "lng": "-77.94528"
  },
  {
    "country": "PE",
    "name": "Lucmapampa",
    "lat": "-6.95",
    "lng": "-78.1"
  },
  {
    "country": "PE",
    "name": "Lucma",
    "lat": "-8.91667",
    "lng": "-77.41667"
  },
  {
    "country": "PE",
    "name": "Lucma",
    "lat": "-7.63333",
    "lng": "-78.55"
  },
  {
    "country": "PE",
    "name": "Los Organos",
    "lat": "-4.17806",
    "lng": "-81.12472"
  },
  {
    "country": "PE",
    "name": "Lonya Grande",
    "lat": "-6.095",
    "lng": "-78.42139"
  },
  {
    "country": "PE",
    "name": "Lonya Chico",
    "lat": "-6.23111",
    "lng": "-77.95639"
  },
  {
    "country": "PE",
    "name": "Longuita",
    "lat": "-6.41417",
    "lng": "-77.96861"
  },
  {
    "country": "PE",
    "name": "Longotea",
    "lat": "-7.06667",
    "lng": "-77.91667"
  },
  {
    "country": "PE",
    "name": "Lobitos",
    "lat": "-4.45674",
    "lng": "-81.28487"
  },
  {
    "country": "PE",
    "name": "Lluchubamba",
    "lat": "-7.52167",
    "lng": "-77.97083"
  },
  {
    "country": "PE",
    "name": "Llata",
    "lat": "-9.41667",
    "lng": "-76.78333"
  },
  {
    "country": "PE",
    "name": "Llapa",
    "lat": "-6.98333",
    "lng": "-78.81667"
  },
  {
    "country": "PE",
    "name": "Llama",
    "lat": "-8.88333",
    "lng": "-77.3"
  },
  {
    "country": "PE",
    "name": "Llama",
    "lat": "-6.51444",
    "lng": "-79.12028"
  },
  {
    "country": "PE",
    "name": "Llacanora",
    "lat": "-7.2",
    "lng": "-78.43333"
  },
  {
    "country": "PE",
    "name": "Licupis",
    "lat": "-6.42444",
    "lng": "-79.24167"
  },
  {
    "country": "PE",
    "name": "Levanto",
    "lat": "-6.30833",
    "lng": "-77.89861"
  },
  {
    "country": "PE",
    "name": "La Unión",
    "lat": "-9.82702",
    "lng": "-76.80199"
  },
  {
    "country": "PE",
    "name": "La Unión",
    "lat": "-5.40232",
    "lng": "-80.74224"
  },
  {
    "country": "PE",
    "name": "Las Palmas",
    "lat": "-9.38412",
    "lng": "-76.00505"
  },
  {
    "country": "PE",
    "name": "Las Lomas",
    "lat": "-4.65333",
    "lng": "-80.24667"
  },
  {
    "country": "PE",
    "name": "Laredo",
    "lat": "-8.08965",
    "lng": "-78.9602"
  },
  {
    "country": "PE",
    "name": "La Peca",
    "lat": "-5.61111",
    "lng": "-78.435"
  },
  {
    "country": "PE",
    "name": "La Pampa",
    "lat": "-8.65",
    "lng": "-77.9"
  },
  {
    "country": "PE",
    "name": "Lamud",
    "lat": "-6.13722",
    "lng": "-77.95361"
  },
  {
    "country": "PE",
    "name": "La Merced",
    "lat": "-9.7352",
    "lng": "-77.61686"
  },
  {
    "country": "PE",
    "name": "Lambayeque",
    "lat": "-6.70111",
    "lng": "-79.90611"
  },
  {
    "country": "PE",
    "name": "Lamas",
    "lat": "-6.41667",
    "lng": "-76.53333"
  },
  {
    "country": "PE",
    "name": "Lajas",
    "lat": "-6.56667",
    "lng": "-78.73333"
  },
  {
    "country": "PE",
    "name": "La Jalca",
    "lat": "-6.48611",
    "lng": "-77.81528"
  },
  {
    "country": "PE",
    "name": "La Huaca",
    "lat": "-4.91167",
    "lng": "-80.96"
  },
  {
    "country": "PE",
    "name": "Lagunas",
    "lat": "-5.22694",
    "lng": "-75.67528"
  },
  {
    "country": "PE",
    "name": "Lagunas",
    "lat": "-4.7894",
    "lng": "-79.84439"
  },
  {
    "country": "PE",
    "name": "La Grama",
    "lat": "-7.46667",
    "lng": "-78.13333"
  },
  {
    "country": "PE",
    "name": "La Esperanza",
    "lat": "-8.0764",
    "lng": "-79.04371"
  },
  {
    "country": "PE",
    "name": "La Cuesta",
    "lat": "-7.91667",
    "lng": "-78.71667"
  },
  {
    "country": "PE",
    "name": "Lacabamba",
    "lat": "-8.26667",
    "lng": "-77.9"
  },
  {
    "country": "PE",
    "name": "La Arena",
    "lat": "-5.33333",
    "lng": "-80.73333"
  },
  {
    "country": "PE",
    "name": "Juanjuí",
    "lat": "-7.17697",
    "lng": "-76.72774"
  },
  {
    "country": "PE",
    "name": "Juan Guerra",
    "lat": "-6.58278",
    "lng": "-76.33"
  },
  {
    "country": "PE",
    "name": "Jilili",
    "lat": "-4.5827",
    "lng": "-79.79713"
  },
  {
    "country": "PE",
    "name": "Jepelacio",
    "lat": "-6.11667",
    "lng": "-76.95"
  },
  {
    "country": "PE",
    "name": "Jeberos",
    "lat": "-5.28333",
    "lng": "-76.28333"
  },
  {
    "country": "PE",
    "name": "Jayanca",
    "lat": "-6.39083",
    "lng": "-79.82194"
  },
  {
    "country": "PE",
    "name": "Jangas",
    "lat": "-9.4025",
    "lng": "-77.57583"
  },
  {
    "country": "PE",
    "name": "Jamalca",
    "lat": "-5.86722",
    "lng": "-78.26167"
  },
  {
    "country": "PE",
    "name": "Jaén",
    "lat": "-5.70729",
    "lng": "-78.80785"
  },
  {
    "country": "PE",
    "name": "Iquitos",
    "lat": "-3.74912",
    "lng": "-73.25383"
  },
  {
    "country": "PE",
    "name": "Iparia",
    "lat": "-9.3",
    "lng": "-74.53333"
  },
  {
    "country": "PE",
    "name": "Inguilpata",
    "lat": "-6.24083",
    "lng": "-77.95722"
  },
  {
    "country": "PE",
    "name": "Incahuasi",
    "lat": "-6.23556",
    "lng": "-79.31694"
  },
  {
    "country": "PE",
    "name": "Inahuaya",
    "lat": "-7.15",
    "lng": "-75.28333"
  },
  {
    "country": "PE",
    "name": "Iberia",
    "lat": "-5.66667",
    "lng": "-74.15"
  },
  {
    "country": "PE",
    "name": "Huicungo",
    "lat": "-7.3186",
    "lng": "-76.77556"
  },
  {
    "country": "PE",
    "name": "Huaylillas",
    "lat": "-8.18722",
    "lng": "-77.3425"
  },
  {
    "country": "PE",
    "name": "Huata",
    "lat": "-9.01611",
    "lng": "-77.86083"
  },
  {
    "country": "PE",
    "name": "Huarmaca",
    "lat": "-5.56583",
    "lng": "-79.52194"
  },
  {
    "country": "PE",
    "name": "Huaripampa",
    "lat": "-8.95",
    "lng": "-77.83333"
  },
  {
    "country": "PE",
    "name": "Huari",
    "lat": "-9.33333",
    "lng": "-77.23333"
  },
  {
    "country": "PE",
    "name": "Huaraz",
    "lat": "-9.52779",
    "lng": "-77.52778"
  },
  {
    "country": "PE",
    "name": "Huaranchal",
    "lat": "-7.68333",
    "lng": "-78.45"
  },
  {
    "country": "PE",
    "name": "Huánuco",
    "lat": "-9.93062",
    "lng": "-76.24223"
  },
  {
    "country": "PE",
    "name": "Huandoval",
    "lat": "-8.33333",
    "lng": "-77.98333"
  },
  {
    "country": "PE",
    "name": "Huanchay",
    "lat": "-9.73333",
    "lng": "-77.83333"
  },
  {
    "country": "PE",
    "name": "Huanchaco",
    "lat": "-8.08333",
    "lng": "-79.11667"
  },
  {
    "country": "PE",
    "name": "Huancas",
    "lat": "-6.17417",
    "lng": "-77.86528"
  },
  {
    "country": "PE",
    "name": "Huancabamba",
    "lat": "-5.23861",
    "lng": "-79.45056"
  },
  {
    "country": "PE",
    "name": "Huambos",
    "lat": "-6.46667",
    "lng": "-78.96667"
  },
  {
    "country": "PE",
    "name": "Huamachuco",
    "lat": "-7.8",
    "lng": "-78.06667"
  },
  {
    "country": "PE",
    "name": "Huallanca",
    "lat": "-9.89796",
    "lng": "-76.94089"
  },
  {
    "country": "PE",
    "name": "Huallanca",
    "lat": "-8.81667",
    "lng": "-77.86667"
  },
  {
    "country": "PE",
    "name": "Hualgayoc",
    "lat": "-6.76667",
    "lng": "-78.61667"
  },
  {
    "country": "PE",
    "name": "Huacrachuco",
    "lat": "-8.65",
    "lng": "-77.08333"
  },
  {
    "country": "PE",
    "name": "Huachis",
    "lat": "-9.41667",
    "lng": "-77.11667"
  },
  {
    "country": "PE",
    "name": "Huacchis",
    "lat": "-9.20033",
    "lng": "-76.7878"
  },
  {
    "country": "PE",
    "name": "Huacaybamba",
    "lat": "-9.03819",
    "lng": "-76.95293"
  },
  {
    "country": "PE",
    "name": "Huacaschuque",
    "lat": "-8.3",
    "lng": "-78"
  },
  {
    "country": "PE",
    "name": "Huacapampa",
    "lat": "-6.93333",
    "lng": "-78.13333"
  },
  {
    "country": "PE",
    "name": "Huacachi",
    "lat": "-9.31674",
    "lng": "-76.93953"
  },
  {
    "country": "PE",
    "name": "Honoria",
    "lat": "-8.76917",
    "lng": "-74.71008"
  },
  {
    "country": "PE",
    "name": "Habana",
    "lat": "-6.08167",
    "lng": "-77.09083"
  },
  {
    "country": "PE",
    "name": "Guzmango",
    "lat": "-7.38333",
    "lng": "-78.9"
  },
  {
    "country": "PE",
    "name": "Guadalupe",
    "lat": "-7.25",
    "lng": "-79.48333"
  },
  {
    "country": "PE",
    "name": "Granada",
    "lat": "-6.09917",
    "lng": "-77.62667"
  },
  {
    "country": "PE",
    "name": "Frias",
    "lat": "-4.92958",
    "lng": "-79.94796"
  },
  {
    "country": "PE",
    "name": "La Florida",
    "lat": "-6.86972",
    "lng": "-79.12111"
  },
  {
    "country": "PE",
    "name": "Ferreñafe",
    "lat": "-6.63889",
    "lng": "-79.78889"
  },
  {
    "country": "PE",
    "name": "Eten",
    "lat": "-6.90806",
    "lng": "-79.86417"
  },
  {
    "country": "PE",
    "name": "Encañada",
    "lat": "-7.08333",
    "lng": "-78.35"
  },
  {
    "country": "PE",
    "name": "El Prado",
    "lat": "-7.03333",
    "lng": "-79"
  },
  {
    "country": "PE",
    "name": "El Porvenir",
    "lat": "-8.08333",
    "lng": "-79"
  },
  {
    "country": "PE",
    "name": "El Parco District",
    "lat": "-5.62436",
    "lng": "-78.47594"
  },
  {
    "country": "PE",
    "name": "El Alto",
    "lat": "-4.26851",
    "lng": "-81.21719"
  },
  {
    "country": "PE",
    "name": "Dos Pueblos",
    "lat": "-5.45",
    "lng": "-80.76667"
  },
  {
    "country": "PE",
    "name": "Cutervo",
    "lat": "-6.36667",
    "lng": "-78.85"
  },
  {
    "country": "PE",
    "name": "Curgos",
    "lat": "-7.85972",
    "lng": "-77.94333"
  },
  {
    "country": "PE",
    "name": "Cumba",
    "lat": "-5.93306",
    "lng": "-78.66278"
  },
  {
    "country": "PE",
    "name": "La Caleta Culebras",
    "lat": "-9.94889",
    "lng": "-78.22528"
  },
  {
    "country": "PE",
    "name": "Cujillo",
    "lat": "-6.11667",
    "lng": "-78.53333"
  },
  {
    "country": "PE",
    "name": "Cuispes",
    "lat": "-5.91667",
    "lng": "-77.93333"
  },
  {
    "country": "PE",
    "name": "Corongo",
    "lat": "-8.58333",
    "lng": "-77.91667"
  },
  {
    "country": "PE",
    "name": "Coris",
    "lat": "-9.83333",
    "lng": "-77.75"
  },
  {
    "country": "PE",
    "name": "Contamana",
    "lat": "-7.33333",
    "lng": "-75.01667"
  },
  {
    "country": "PE",
    "name": "Concordia",
    "lat": "-4.56667",
    "lng": "-74.78333"
  },
  {
    "country": "PE",
    "name": "Conchucos",
    "lat": "-8.26667",
    "lng": "-77.85"
  },
  {
    "country": "PE",
    "name": "Colcamar",
    "lat": "-6.30111",
    "lng": "-77.9725"
  },
  {
    "country": "PE",
    "name": "Colcabamba",
    "lat": "-9.58333",
    "lng": "-77.81667"
  },
  {
    "country": "PE",
    "name": "Colasay",
    "lat": "-5.97528",
    "lng": "-79.06611"
  },
  {
    "country": "PE",
    "name": "Coishco",
    "lat": "-9.02306",
    "lng": "-78.61556"
  },
  {
    "country": "PE",
    "name": "Cochabamba",
    "lat": "-9.49361",
    "lng": "-77.85944"
  },
  {
    "country": "PE",
    "name": "Cochabamba",
    "lat": "-6.48333",
    "lng": "-78.9"
  },
  {
    "country": "PE",
    "name": "Cocabamba",
    "lat": "-6.6",
    "lng": "-78.01667"
  },
  {
    "country": "PE",
    "name": "Churuja",
    "lat": "-6.01417",
    "lng": "-77.95333"
  },
  {
    "country": "PE",
    "name": "Churubamba",
    "lat": "-9.82557",
    "lng": "-76.13327"
  },
  {
    "country": "PE",
    "name": "Chuquis",
    "lat": "-9.67658",
    "lng": "-76.70396"
  },
  {
    "country": "PE",
    "name": "Chuquibamba",
    "lat": "-6.93417",
    "lng": "-77.85222"
  },
  {
    "country": "PE",
    "name": "Chumuch",
    "lat": "-6.6",
    "lng": "-78.21667"
  },
  {
    "country": "PE",
    "name": "Chulucanas",
    "lat": "-5.0925",
    "lng": "-80.1625"
  },
  {
    "country": "PE",
    "name": "Chugur",
    "lat": "-6.66667",
    "lng": "-78.75"
  },
  {
    "country": "PE",
    "name": "Chugay",
    "lat": "-7.78167",
    "lng": "-77.86833"
  },
  {
    "country": "PE",
    "name": "Chota",
    "lat": "-6.55",
    "lng": "-78.65"
  },
  {
    "country": "PE",
    "name": "Choros",
    "lat": "-5.90139",
    "lng": "-78.69417"
  },
  {
    "country": "PE",
    "name": "Chongoyape",
    "lat": "-6.64056",
    "lng": "-79.38917"
  },
  {
    "country": "PE",
    "name": "Chocope",
    "lat": "-7.79139",
    "lng": "-79.22167"
  },
  {
    "country": "PE",
    "name": "Chisquilla",
    "lat": "-5.88333",
    "lng": "-77.73333"
  },
  {
    "country": "PE",
    "name": "Chirinos",
    "lat": "-5.305",
    "lng": "-78.89833"
  },
  {
    "country": "PE",
    "name": "Chiriaco",
    "lat": "-5.16",
    "lng": "-78.28889"
  },
  {
    "country": "PE",
    "name": "Chingas",
    "lat": "-9.11967",
    "lng": "-76.99126"
  },
  {
    "country": "PE",
    "name": "Chimbote",
    "lat": "-9.08528",
    "lng": "-78.57833"
  },
  {
    "country": "PE",
    "name": "Chillia",
    "lat": "-8.1",
    "lng": "-77.48333"
  },
  {
    "country": "PE",
    "name": "Chilete",
    "lat": "-7.23333",
    "lng": "-78.85"
  },
  {
    "country": "PE",
    "name": "Chiguirip",
    "lat": "-6.41667",
    "lng": "-78.73333"
  },
  {
    "country": "PE",
    "name": "Chiclayo",
    "lat": "-6.77137",
    "lng": "-79.84088"
  },
  {
    "country": "PE",
    "name": "Chicama",
    "lat": "-7.84472",
    "lng": "-79.14694"
  },
  {
    "country": "PE",
    "name": "Chetilla",
    "lat": "-7.15",
    "lng": "-78.66667"
  },
  {
    "country": "PE",
    "name": "Chepén",
    "lat": "-7.22436",
    "lng": "-79.42476"
  },
  {
    "country": "PE",
    "name": "Chavinillo",
    "lat": "-9.8585",
    "lng": "-76.60855"
  },
  {
    "country": "PE",
    "name": "Chazuta",
    "lat": "-6.57087",
    "lng": "-76.13753"
  },
  {
    "country": "PE",
    "name": "Charat",
    "lat": "-7.83333",
    "lng": "-78.45"
  },
  {
    "country": "PE",
    "name": "Chalaco",
    "lat": "-5.03889",
    "lng": "-79.79389"
  },
  {
    "country": "PE",
    "name": "Chaglla",
    "lat": "-9.84361",
    "lng": "-75.90306"
  },
  {
    "country": "PE",
    "name": "Chachapoyas",
    "lat": "-6.23169",
    "lng": "-77.86903"
  },
  {
    "country": "PE",
    "name": "Chacas",
    "lat": "-9.23333",
    "lng": "-77.38333"
  },
  {
    "country": "PE",
    "name": "Celendín",
    "lat": "-6.8659",
    "lng": "-78.14585"
  },
  {
    "country": "PE",
    "name": "Cauday",
    "lat": "-7.58333",
    "lng": "-78.08333"
  },
  {
    "country": "PE",
    "name": "Catache",
    "lat": "-6.67528",
    "lng": "-79.03306"
  },
  {
    "country": "PE",
    "name": "Catacaos",
    "lat": "-5.26667",
    "lng": "-80.68333"
  },
  {
    "country": "PE",
    "name": "Catac",
    "lat": "-9.8",
    "lng": "-77.43333"
  },
  {
    "country": "PE",
    "name": "Caspisapa",
    "lat": "-6.95694",
    "lng": "-76.41806"
  },
  {
    "country": "PE",
    "name": "Casma",
    "lat": "-9.47472",
    "lng": "-78.30167"
  },
  {
    "country": "PE",
    "name": "Cascas",
    "lat": "-7.48333",
    "lng": "-78.81667"
  },
  {
    "country": "PE",
    "name": "Cascapara",
    "lat": "-9.22583",
    "lng": "-77.71639"
  },
  {
    "country": "PE",
    "name": "Casa Grande",
    "lat": "-7.74389",
    "lng": "-79.18639"
  },
  {
    "country": "PE",
    "name": "Carhuaz",
    "lat": "-9.28194",
    "lng": "-77.64472"
  },
  {
    "country": "PE",
    "name": "Carás",
    "lat": "-9.04692",
    "lng": "-77.80901"
  },
  {
    "country": "PE",
    "name": "Carabamba",
    "lat": "-8.11667",
    "lng": "-78.61667"
  },
  {
    "country": "PE",
    "name": "Canchaque",
    "lat": "-5.37306",
    "lng": "-79.60028"
  },
  {
    "country": "PE",
    "name": "Cancas",
    "lat": "-3.94667",
    "lng": "-80.94167"
  },
  {
    "country": "PE",
    "name": "Cañaveral",
    "lat": "-3.94167",
    "lng": "-80.65083"
  },
  {
    "country": "PE",
    "name": "Cañaris",
    "lat": "-6.04611",
    "lng": "-79.26472"
  },
  {
    "country": "PE",
    "name": "Calzada",
    "lat": "-6.03194",
    "lng": "-77.06639"
  },
  {
    "country": "PE",
    "name": "Caleta Cruz",
    "lat": "-3.6375",
    "lng": "-80.59167"
  },
  {
    "country": "PE",
    "name": "Cajaruro",
    "lat": "-5.73639",
    "lng": "-78.42556"
  },
  {
    "country": "PE",
    "name": "Cajamarquilla",
    "lat": "-9.63333",
    "lng": "-77.75"
  },
  {
    "country": "PE",
    "name": "Cajamarca",
    "lat": "-7.16378",
    "lng": "-78.50027"
  },
  {
    "country": "PE",
    "name": "Cajabamba",
    "lat": "-7.61667",
    "lng": "-78.05"
  },
  {
    "country": "PE",
    "name": "Cahuac",
    "lat": "-9.85261",
    "lng": "-76.63035"
  },
  {
    "country": "PE",
    "name": "Cachachi",
    "lat": "-7.45",
    "lng": "-78.28333"
  },
  {
    "country": "PE",
    "name": "Cabana",
    "lat": "-8.4",
    "lng": "-78.03333"
  },
  {
    "country": "PE",
    "name": "Caballococha",
    "lat": "-3.90583",
    "lng": "-70.51639"
  },
  {
    "country": "PE",
    "name": "Buenos Aires",
    "lat": "-8.13861",
    "lng": "-79.04028"
  },
  {
    "country": "PE",
    "name": "Buenos Aires",
    "lat": "-5.26083",
    "lng": "-79.96417"
  },
  {
    "country": "PE",
    "name": "Breu",
    "lat": "-9.48333",
    "lng": "-72.71667"
  },
  {
    "country": "PE",
    "name": "Bretaña",
    "lat": "-5.26667",
    "lng": "-74.28333"
  },
  {
    "country": "PE",
    "name": "Bolognesi",
    "lat": "-8.35",
    "lng": "-78.06667"
  },
  {
    "country": "PE",
    "name": "Bernal",
    "lat": "-5.45",
    "lng": "-80.75"
  },
  {
    "country": "PE",
    "name": "Bellavista",
    "lat": "-7.05614",
    "lng": "-76.5911"
  },
  {
    "country": "PE",
    "name": "Bellavista",
    "lat": "-5.66417",
    "lng": "-78.67722"
  },
  {
    "country": "PE",
    "name": "Barranquita",
    "lat": "-6.26667",
    "lng": "-76.01667"
  },
  {
    "country": "PE",
    "name": "Barranca",
    "lat": "-4.83298",
    "lng": "-76.67582"
  },
  {
    "country": "PE",
    "name": "Bambas",
    "lat": "-8.6",
    "lng": "-78"
  },
  {
    "country": "PE",
    "name": "Bambamarca",
    "lat": "-6.68333",
    "lng": "-78.53333"
  },
  {
    "country": "PE",
    "name": "Balsas",
    "lat": "-6.83333",
    "lng": "-78.01667"
  },
  {
    "country": "PE",
    "name": "Bagua Grande",
    "lat": "-5.75611",
    "lng": "-78.44111"
  },
  {
    "country": "PE",
    "name": "Bagua",
    "lat": "-5.63311",
    "lng": "-78.53431"
  },
  {
    "country": "PE",
    "name": "Ayabaca",
    "lat": "-4.63983",
    "lng": "-79.71491"
  },
  {
    "country": "PE",
    "name": "Aucayacu",
    "lat": "-8.93139",
    "lng": "-76.11315"
  },
  {
    "country": "PE",
    "name": "Ascope",
    "lat": "-7.71444",
    "lng": "-79.10778"
  },
  {
    "country": "PE",
    "name": "Aricapampa",
    "lat": "-7.80583",
    "lng": "-77.71722"
  },
  {
    "country": "PE",
    "name": "Arenal",
    "lat": "-4.88333",
    "lng": "-81.0275"
  },
  {
    "country": "PE",
    "name": "Arancay",
    "lat": "-9.17227",
    "lng": "-76.74895"
  },
  {
    "country": "PE",
    "name": "Aramango",
    "lat": "-5.41639",
    "lng": "-78.43583"
  },
  {
    "country": "PE",
    "name": "Anta",
    "lat": "-9.35861",
    "lng": "-77.59722"
  },
  {
    "country": "PE",
    "name": "Angasmarca",
    "lat": "-8.13333",
    "lng": "-78.06667"
  },
  {
    "country": "PE",
    "name": "Amotape",
    "lat": "-4.88167",
    "lng": "-81.01556"
  },
  {
    "country": "PE",
    "name": "Amashca",
    "lat": "-9.23917",
    "lng": "-77.64639"
  },
  {
    "country": "PE",
    "name": "Aija",
    "lat": "-9.78105",
    "lng": "-77.6094"
  },
  {
    "country": "PE",
    "name": "Aguas Verdes",
    "lat": "-3.48139",
    "lng": "-80.245"
  },
  {
    "country": "PE",
    "name": "Agua Blanca",
    "lat": "-6.72343",
    "lng": "-76.69643"
  },
  {
    "country": "PE",
    "name": "Agallpampa",
    "lat": "-7.98333",
    "lng": "-78.55"
  },
  {
    "country": "PE",
    "name": "Aczo",
    "lat": "-9.15193",
    "lng": "-76.98925"
  },
  {
    "country": "PE",
    "name": "Acopampa",
    "lat": "-9.29722",
    "lng": "-77.61778"
  },
  {
    "country": "PE",
    "name": "Acomayo",
    "lat": "-9.80105",
    "lng": "-76.07194"
  },
  {
    "country": "PE",
    "name": "Aco",
    "lat": "-8.53333",
    "lng": "-77.88333"
  },
  {
    "country": "PE",
    "name": "Puerto Callao",
    "lat": "-8.35806",
    "lng": "-74.57361"
  },
  {
    "country": "PE",
    "name": "Campoverde",
    "lat": "-8.47533",
    "lng": "-74.80709"
  },
  {
    "country": "PE",
    "name": "Nueva Requena",
    "lat": "-8.31139",
    "lng": "-74.86222"
  },
  {
    "country": "PE",
    "name": "La Coipa",
    "lat": "-5.43361",
    "lng": "-78.86361"
  },
  {
    "country": "PE",
    "name": "La Sacilia",
    "lat": "-5.95167",
    "lng": "-78.72722"
  },
  {
    "country": "PE",
    "name": "Alianza Cristiana",
    "lat": "-3.47528",
    "lng": "-76.43444"
  },
  {
    "country": "PE",
    "name": "Utco",
    "lat": "-6.91667",
    "lng": "-78.05"
  },
  {
    "country": "PE",
    "name": "Las Pirias",
    "lat": "-5.62722",
    "lng": "-78.85278"
  },
  {
    "country": "PE",
    "name": "Zapatero",
    "lat": "-6.52972",
    "lng": "-76.4925"
  },
  {
    "country": "PE",
    "name": "Cuñumbuqui",
    "lat": "-6.51111",
    "lng": "-76.48"
  },
  {
    "country": "PE",
    "name": "Utcurarca",
    "lat": "-6.66306",
    "lng": "-76.28667"
  },
  {
    "country": "PE",
    "name": "Buenos Aires",
    "lat": "-6.79111",
    "lng": "-76.32639"
  },
  {
    "country": "PE",
    "name": "Manuel Antonio Mesones Muro",
    "lat": "-6.64361",
    "lng": "-79.73806"
  },
  {
    "country": "PE",
    "name": "La Breita",
    "lat": "-4.25691",
    "lng": "-80.88599"
  },
  {
    "country": "PE",
    "name": "Papayal",
    "lat": "-4.07771",
    "lng": "-80.7369"
  },
  {
    "country": "PE",
    "name": "Zarumilla",
    "lat": "-3.50306",
    "lng": "-80.27306"
  },
  {
    "country": "PE",
    "name": "Zurite",
    "lat": "-13.45472",
    "lng": "-72.25556"
  },
  {
    "country": "PE",
    "name": "Zepita",
    "lat": "-16.5",
    "lng": "-69.1"
  },
  {
    "country": "PE",
    "name": "Yura",
    "lat": "-16.25223",
    "lng": "-71.67969"
  },
  {
    "country": "PE",
    "name": "Yunguyo",
    "lat": "-16.25",
    "lng": "-69.08333"
  },
  {
    "country": "PE",
    "name": "Yunga",
    "lat": "-16.2",
    "lng": "-70.68333"
  },
  {
    "country": "PE",
    "name": "Yucay",
    "lat": "-13.32139",
    "lng": "-72.08222"
  },
  {
    "country": "PE",
    "name": "Yauyos",
    "lat": "-12.45944",
    "lng": "-75.91722"
  },
  {
    "country": "PE",
    "name": "Yaurisque",
    "lat": "-13.66694",
    "lng": "-71.92111"
  },
  {
    "country": "PE",
    "name": "Yauli",
    "lat": "-11.71366",
    "lng": "-75.47466"
  },
  {
    "country": "PE",
    "name": "Yauli",
    "lat": "-11.665",
    "lng": "-76.08639"
  },
  {
    "country": "PE",
    "name": "Yauca",
    "lat": "-15.66111",
    "lng": "-74.52722"
  },
  {
    "country": "PE",
    "name": "Yarabamba",
    "lat": "-16.54722",
    "lng": "-71.47667"
  },
  {
    "country": "PE",
    "name": "Yanque",
    "lat": "-15.64917",
    "lng": "-71.65778"
  },
  {
    "country": "PE",
    "name": "Yangas",
    "lat": "-11.695",
    "lng": "-76.84556"
  },
  {
    "country": "PE",
    "name": "Yanaquihua",
    "lat": "-15.77389",
    "lng": "-72.87667"
  },
  {
    "country": "PE",
    "name": "Yanaoca",
    "lat": "-14.21806",
    "lng": "-71.43167"
  },
  {
    "country": "PE",
    "name": "Yanahuaya",
    "lat": "-14.26667",
    "lng": "-69.2"
  },
  {
    "country": "PE",
    "name": "Yanahuanca",
    "lat": "-10.51667",
    "lng": "-76.49861"
  },
  {
    "country": "PE",
    "name": "Yanacancha",
    "lat": "-12.2",
    "lng": "-75.41667"
  },
  {
    "country": "PE",
    "name": "Yanacancha",
    "lat": "-10.24111",
    "lng": "-76.64556"
  },
  {
    "country": "PE",
    "name": "Yanaca",
    "lat": "-14.21778",
    "lng": "-73.14111"
  },
  {
    "country": "PE",
    "name": "Vizcachane",
    "lat": "-15.80861",
    "lng": "-71.20111"
  },
  {
    "country": "PE",
    "name": "Vitis",
    "lat": "-12.22361",
    "lng": "-75.80639"
  },
  {
    "country": "PE",
    "name": "Vitarte",
    "lat": "-12.03333",
    "lng": "-76.93333"
  },
  {
    "country": "PE",
    "name": "Vischongo",
    "lat": "-13.58917",
    "lng": "-73.99444"
  },
  {
    "country": "PE",
    "name": "Viraco",
    "lat": "-15.65694",
    "lng": "-72.52528"
  },
  {
    "country": "PE",
    "name": "Vinchos",
    "lat": "-13.24083",
    "lng": "-74.35306"
  },
  {
    "country": "PE",
    "name": "Viñac",
    "lat": "-12.93111",
    "lng": "-75.77861"
  },
  {
    "country": "PE",
    "name": "Vilque Chico",
    "lat": "-15.21667",
    "lng": "-69.68333"
  },
  {
    "country": "PE",
    "name": "Vilque",
    "lat": "-15.76667",
    "lng": "-70.25"
  },
  {
    "country": "PE",
    "name": "Villa Tupac Amaru",
    "lat": "-13.71135",
    "lng": "-76.1498"
  },
  {
    "country": "PE",
    "name": "Villa Rica",
    "lat": "-10.73944",
    "lng": "-75.26972"
  },
  {
    "country": "PE",
    "name": "Vilcanchos",
    "lat": "-13.61167",
    "lng": "-74.53194"
  },
  {
    "country": "PE",
    "name": "Vilcabamba",
    "lat": "-14.07556",
    "lng": "-72.62583"
  },
  {
    "country": "PE",
    "name": "Vilcabamba",
    "lat": "-10.47806",
    "lng": "-76.4475"
  },
  {
    "country": "PE",
    "name": "Vilca",
    "lat": "-12.48333",
    "lng": "-75.18333"
  },
  {
    "country": "PE",
    "name": "Vilavila",
    "lat": "-15.18694",
    "lng": "-70.66"
  },
  {
    "country": "PE",
    "name": "Ventanilla",
    "lat": "-11.87528",
    "lng": "-77.11833"
  },
  {
    "country": "PE",
    "name": "Velinga",
    "lat": "-15.27333",
    "lng": "-73.02167"
  },
  {
    "country": "PE",
    "name": "Velille",
    "lat": "-14.50889",
    "lng": "-71.88528"
  },
  {
    "country": "PE",
    "name": "Végueta",
    "lat": "-11.02253",
    "lng": "-77.64378"
  },
  {
    "country": "PE",
    "name": "Usicayos",
    "lat": "-14.12472",
    "lng": "-69.96611"
  },
  {
    "country": "PE",
    "name": "Urubamba",
    "lat": "-13.30472",
    "lng": "-72.11583"
  },
  {
    "country": "PE",
    "name": "Uripa",
    "lat": "-13.5325",
    "lng": "-73.67722"
  },
  {
    "country": "PE",
    "name": "Urcos",
    "lat": "-13.68611",
    "lng": "-71.62278"
  },
  {
    "country": "PE",
    "name": "Urasqui",
    "lat": "-16.02861",
    "lng": "-73.17056"
  },
  {
    "country": "PE",
    "name": "Upahuacho",
    "lat": "-14.90167",
    "lng": "-73.40111"
  },
  {
    "country": "PE",
    "name": "Uñon",
    "lat": "-15.72944",
    "lng": "-72.42972"
  },
  {
    "country": "PE",
    "name": "Umachiri",
    "lat": "-14.8575",
    "lng": "-70.75611"
  },
  {
    "country": "PE",
    "name": "Uchumayo",
    "lat": "-16.42508",
    "lng": "-71.67215"
  },
  {
    "country": "PE",
    "name": "Ubinas",
    "lat": "-16.4",
    "lng": "-70.86667"
  },
  {
    "country": "PE",
    "name": "Tuti",
    "lat": "-15.53306",
    "lng": "-71.55083"
  },
  {
    "country": "PE",
    "name": "Turpo",
    "lat": "-13.78528",
    "lng": "-73.47361"
  },
  {
    "country": "PE",
    "name": "Turpay",
    "lat": "-14.21917",
    "lng": "-72.62389"
  },
  {
    "country": "PE",
    "name": "Tupe",
    "lat": "-12.74083",
    "lng": "-75.80833"
  },
  {
    "country": "PE",
    "name": "Tungasuca",
    "lat": "-14.16389",
    "lng": "-71.47667"
  },
  {
    "country": "PE",
    "name": "Totos",
    "lat": "-13.56722",
    "lng": "-74.52361"
  },
  {
    "country": "PE",
    "name": "Totoral",
    "lat": "-17.4062",
    "lng": "-70.36464"
  },
  {
    "country": "PE",
    "name": "Toro",
    "lat": "-15.26417",
    "lng": "-72.92889"
  },
  {
    "country": "PE",
    "name": "Toraya",
    "lat": "-14.05056",
    "lng": "-73.29722"
  },
  {
    "country": "PE",
    "name": "Torata",
    "lat": "-17.07694",
    "lng": "-70.84333"
  },
  {
    "country": "PE",
    "name": "Tomepampa",
    "lat": "-15.17306",
    "lng": "-72.83083"
  },
  {
    "country": "PE",
    "name": "Tomay Kichwa",
    "lat": "-10.07722",
    "lng": "-76.21194"
  },
  {
    "country": "PE",
    "name": "Tomas",
    "lat": "-12.23861",
    "lng": "-75.74528"
  },
  {
    "country": "PE",
    "name": "Tocota",
    "lat": "-15.65944",
    "lng": "-74.09056"
  },
  {
    "country": "PE",
    "name": "Tibillo",
    "lat": "-14.09306",
    "lng": "-75.17194"
  },
  {
    "country": "PE",
    "name": "Tisco",
    "lat": "-15.34611",
    "lng": "-71.44778"
  },
  {
    "country": "PE",
    "name": "Tirapata",
    "lat": "-14.95",
    "lng": "-70.4"
  },
  {
    "country": "PE",
    "name": "Tiquillaca",
    "lat": "-15.81667",
    "lng": "-70.2"
  },
  {
    "country": "PE",
    "name": "Tinyahuarco",
    "lat": "-10.76771",
    "lng": "-76.27523"
  },
  {
    "country": "PE",
    "name": "Tintay",
    "lat": "-13.95917",
    "lng": "-73.18583"
  },
  {
    "country": "PE",
    "name": "Tinta",
    "lat": "-14.145",
    "lng": "-71.40694"
  },
  {
    "country": "PE",
    "name": "Ticrapo",
    "lat": "-13.35",
    "lng": "-75.41667"
  },
  {
    "country": "PE",
    "name": "Ticllos",
    "lat": "-10.25403",
    "lng": "-77.19088"
  },
  {
    "country": "PE",
    "name": "Ticllas",
    "lat": "-13.1325",
    "lng": "-74.33278"
  },
  {
    "country": "PE",
    "name": "Ticaco",
    "lat": "-17.44639",
    "lng": "-70.04694"
  },
  {
    "country": "PE",
    "name": "Tiabaya",
    "lat": "-16.45",
    "lng": "-71.59"
  },
  {
    "country": "PE",
    "name": "Taurisma",
    "lat": "-15.175",
    "lng": "-72.85028"
  },
  {
    "country": "PE",
    "name": "Tauripampa",
    "lat": "-12.58333",
    "lng": "-76.11667"
  },
  {
    "country": "PE",
    "name": "Tauria",
    "lat": "-15.35611",
    "lng": "-73.2325"
  },
  {
    "country": "PE",
    "name": "Tarucani",
    "lat": "-16.18333",
    "lng": "-71.06667"
  },
  {
    "country": "PE",
    "name": "Tarucachi",
    "lat": "-17.52472",
    "lng": "-70.02833"
  },
  {
    "country": "PE",
    "name": "Tarma",
    "lat": "-11.41899",
    "lng": "-75.68992"
  },
  {
    "country": "PE",
    "name": "Tarata",
    "lat": "-17.47444",
    "lng": "-70.03278"
  },
  {
    "country": "PE",
    "name": "Taraco",
    "lat": "-15.3",
    "lng": "-69.96667"
  },
  {
    "country": "PE",
    "name": "Taquile",
    "lat": "-15.76667",
    "lng": "-69.68333"
  },
  {
    "country": "PE",
    "name": "Tapo",
    "lat": "-11.39056",
    "lng": "-75.56361"
  },
  {
    "country": "PE",
    "name": "Tapay",
    "lat": "-15.57806",
    "lng": "-71.93917"
  },
  {
    "country": "PE",
    "name": "Tapairihua",
    "lat": "-14.14028",
    "lng": "-73.14278"
  },
  {
    "country": "PE",
    "name": "Tapacocha",
    "lat": "-10.01667",
    "lng": "-77.58333"
  },
  {
    "country": "PE",
    "name": "Tanta",
    "lat": "-12.11667",
    "lng": "-76.01667"
  },
  {
    "country": "PE",
    "name": "Tamburco",
    "lat": "-13.61667",
    "lng": "-72.87139"
  },
  {
    "country": "PE",
    "name": "Tambo Quemado",
    "lat": "-14.73333",
    "lng": "-74.68333"
  },
  {
    "country": "PE",
    "name": "Tambopata",
    "lat": "-12.67191",
    "lng": "-69.35547"
  },
  {
    "country": "PE",
    "name": "Tambobamba",
    "lat": "-13.94528",
    "lng": "-72.17139"
  },
  {
    "country": "PE",
    "name": "Tambo",
    "lat": "-14.79847",
    "lng": "-73.92438"
  },
  {
    "country": "PE",
    "name": "Tambo",
    "lat": "-12.93333",
    "lng": "-74.01667"
  },
  {
    "country": "PE",
    "name": "Tambillo",
    "lat": "-13.19194",
    "lng": "-74.11139"
  },
  {
    "country": "PE",
    "name": "Talavera",
    "lat": "-13.65306",
    "lng": "-73.42917"
  },
  {
    "country": "PE",
    "name": "Tacna",
    "lat": "-18.01465",
    "lng": "-70.25362"
  },
  {
    "country": "PE",
    "name": "Susapaya",
    "lat": "-17.35306",
    "lng": "-70.13194"
  },
  {
    "country": "PE",
    "name": "Surcubamba",
    "lat": "-12.13333",
    "lng": "-74.68333"
  },
  {
    "country": "PE",
    "name": "Santiago de Surco",
    "lat": "-12.13588",
    "lng": "-77.00742"
  },
  {
    "country": "PE",
    "name": "Surco",
    "lat": "-11.88472",
    "lng": "-76.43972"
  },
  {
    "country": "PE",
    "name": "Supe",
    "lat": "-10.7975",
    "lng": "-77.71306"
  },
  {
    "country": "PE",
    "name": "Sunampe",
    "lat": "-13.42704",
    "lng": "-76.16363"
  },
  {
    "country": "PE",
    "name": "Sumbilca",
    "lat": "-11.4075",
    "lng": "-76.82"
  },
  {
    "country": "PE",
    "name": "Suitucancha",
    "lat": "-11.78734",
    "lng": "-75.93612"
  },
  {
    "country": "PE",
    "name": "Subtanjalla",
    "lat": "-14.01889",
    "lng": "-75.75806"
  },
  {
    "country": "PE",
    "name": "Soraya",
    "lat": "-14.16278",
    "lng": "-73.3125"
  },
  {
    "country": "PE",
    "name": "Soras",
    "lat": "-14.115",
    "lng": "-73.60444"
  },
  {
    "country": "PE",
    "name": "Socos",
    "lat": "-13.215",
    "lng": "-74.28917"
  },
  {
    "country": "PE",
    "name": "Socabaya",
    "lat": "-16.47025",
    "lng": "-71.52758"
  },
  {
    "country": "PE",
    "name": "Sitajara",
    "lat": "-17.37556",
    "lng": "-70.13222"
  },
  {
    "country": "PE",
    "name": "Sincos",
    "lat": "-11.89119",
    "lng": "-75.38745"
  },
  {
    "country": "PE",
    "name": "Sina",
    "lat": "-14.5",
    "lng": "-69.28333"
  },
  {
    "country": "PE",
    "name": "Sicuani",
    "lat": "-14.26944",
    "lng": "-71.22611"
  },
  {
    "country": "PE",
    "name": "Sicaya",
    "lat": "-12.03333",
    "lng": "-75.28333"
  },
  {
    "country": "PE",
    "name": "Sibayo",
    "lat": "-15.48694",
    "lng": "-71.45833"
  },
  {
    "country": "PE",
    "name": "Sepahua",
    "lat": "-11.14583",
    "lng": "-73.04278"
  },
  {
    "country": "PE",
    "name": "Saylla",
    "lat": "-13.56139",
    "lng": "-71.84889"
  },
  {
    "country": "PE",
    "name": "Sayán",
    "lat": "-11.13333",
    "lng": "-77.1946"
  },
  {
    "country": "PE",
    "name": "Saurama",
    "lat": "-13.69361",
    "lng": "-73.75861"
  },
  {
    "country": "PE",
    "name": "Satipo",
    "lat": "-11.25222",
    "lng": "-74.63861"
  },
  {
    "country": "PE",
    "name": "Sarhua",
    "lat": "-13.67417",
    "lng": "-74.32"
  },
  {
    "country": "PE",
    "name": "Sapallanga",
    "lat": "-12.15",
    "lng": "-75.18333"
  },
  {
    "country": "PE",
    "name": "San Vicente de Cañete",
    "lat": "-13.07556",
    "lng": "-76.38528"
  },
  {
    "country": "PE",
    "name": "Santiago",
    "lat": "-14.18469",
    "lng": "-75.71124"
  },
  {
    "country": "PE",
    "name": "Santa Teresa",
    "lat": "-13.13222",
    "lng": "-72.59056"
  },
  {
    "country": "PE",
    "name": "Santa Rosa",
    "lat": "-14.61111",
    "lng": "-70.78611"
  },
  {
    "country": "PE",
    "name": "Santa Rosa",
    "lat": "-14.15",
    "lng": "-72.66667"
  },
  {
    "country": "PE",
    "name": "Santa Rosa",
    "lat": "-11.79917",
    "lng": "-77.17333"
  },
  {
    "country": "PE",
    "name": "Santa María",
    "lat": "-12.00538",
    "lng": "-76.89329"
  },
  {
    "country": "PE",
    "name": "Santa Lucía",
    "lat": "-15.69788",
    "lng": "-70.6061"
  },
  {
    "country": "PE",
    "name": "Santa Eulalia",
    "lat": "-11.90083",
    "lng": "-76.66333"
  },
  {
    "country": "PE",
    "name": "Santa Cruz",
    "lat": "-11.06",
    "lng": "-76.93028"
  },
  {
    "country": "PE",
    "name": "Santa Ana",
    "lat": "-13.05",
    "lng": "-75.13333"
  },
  {
    "country": "PE",
    "name": "Santa Ana",
    "lat": "-12.86667",
    "lng": "-72.71667"
  },
  {
    "country": "PE",
    "name": "San Salvador",
    "lat": "-13.49361",
    "lng": "-71.77389"
  },
  {
    "country": "PE",
    "name": "San Ramón",
    "lat": "-11.12417",
    "lng": "-75.35733"
  },
  {
    "country": "PE",
    "name": "San Rafael",
    "lat": "-10.33806",
    "lng": "-76.18333"
  },
  {
    "country": "PE",
    "name": "San Pedro de Cajas",
    "lat": "-11.25061",
    "lng": "-75.86116"
  },
  {
    "country": "PE",
    "name": "San Pedro",
    "lat": "-14.76667",
    "lng": "-74.1"
  },
  {
    "country": "PE",
    "name": "San Pedro",
    "lat": "-14.18667",
    "lng": "-71.34167"
  },
  {
    "country": "PE",
    "name": "San Pedro",
    "lat": "-13.39889",
    "lng": "-76.15904"
  },
  {
    "country": "PE",
    "name": "San Pablo",
    "lat": "-14.20278",
    "lng": "-71.31556"
  },
  {
    "country": "PE",
    "name": "San Miguel de Cauri",
    "lat": "-10.13818",
    "lng": "-76.62288"
  },
  {
    "country": "PE",
    "name": "San Miguel",
    "lat": "-13.0125",
    "lng": "-73.98083"
  },
  {
    "country": "PE",
    "name": "San Mateo",
    "lat": "-11.75944",
    "lng": "-76.30056"
  },
  {
    "country": "PE",
    "name": "San Luis",
    "lat": "-12.07674",
    "lng": "-76.99435"
  },
  {
    "country": "PE",
    "name": "San Lorenzo",
    "lat": "-11.84684",
    "lng": "-75.38146"
  },
  {
    "country": "PE",
    "name": "San Lorenzo",
    "lat": "-11.46667",
    "lng": "-69.3"
  },
  {
    "country": "PE",
    "name": "San Juan Bautista",
    "lat": "-14.01083",
    "lng": "-75.73583"
  },
  {
    "country": "PE",
    "name": "San Juan de Marcona",
    "lat": "-15.36528",
    "lng": "-75.16222"
  },
  {
    "country": "PE",
    "name": "San Juan",
    "lat": "-14.65",
    "lng": "-74.2"
  },
  {
    "country": "PE",
    "name": "San Juan",
    "lat": "-13.2",
    "lng": "-75.65"
  },
  {
    "country": "PE",
    "name": "San Jerónimo",
    "lat": "-13.65138",
    "lng": "-73.36388"
  },
  {
    "country": "PE",
    "name": "San Jerónimo",
    "lat": "-11.95591",
    "lng": "-75.28411"
  },
  {
    "country": "PE",
    "name": "San Isidro",
    "lat": "-12.11667",
    "lng": "-77.05"
  },
  {
    "country": "PE",
    "name": "Sangallaya",
    "lat": "-12.16667",
    "lng": "-76.26667"
  },
  {
    "country": "PE",
    "name": "San Francisco",
    "lat": "-12.6",
    "lng": "-73.81667"
  },
  {
    "country": "PE",
    "name": "Sandia",
    "lat": "-14.23333",
    "lng": "-69.43333"
  },
  {
    "country": "PE",
    "name": "San Clemente",
    "lat": "-13.66667",
    "lng": "-76.15"
  },
  {
    "country": "PE",
    "name": "San Buenaventura",
    "lat": "-11.48889",
    "lng": "-76.66194"
  },
  {
    "country": "PE",
    "name": "San Bartolo",
    "lat": "-12.38333",
    "lng": "-76.78333"
  },
  {
    "country": "PE",
    "name": "Sañayca",
    "lat": "-14.20694",
    "lng": "-73.33556"
  },
  {
    "country": "PE",
    "name": "San Agustin",
    "lat": "-11.97195",
    "lng": "-75.25562"
  },
  {
    "country": "PE",
    "name": "Samegua",
    "lat": "-17.17944",
    "lng": "-70.89889"
  },
  {
    "country": "PE",
    "name": "Sama Grande",
    "lat": "-17.7925",
    "lng": "-70.49472"
  },
  {
    "country": "PE",
    "name": "Salcabamba",
    "lat": "-12.2",
    "lng": "-74.78333"
  },
  {
    "country": "PE",
    "name": "Sacsamarca",
    "lat": "-13.94639",
    "lng": "-74.31139"
  },
  {
    "country": "PE",
    "name": "Sabandia",
    "lat": "-16.46667",
    "lng": "-71.5"
  },
  {
    "country": "PE",
    "name": "Rosaspata",
    "lat": "-15.21667",
    "lng": "-69.53333"
  },
  {
    "country": "PE",
    "name": "Río Grande",
    "lat": "-14.516",
    "lng": "-75.19933"
  },
  {
    "country": "PE",
    "name": "Ricardo Palma",
    "lat": "-11.91978",
    "lng": "-76.6561"
  },
  {
    "country": "PE",
    "name": "Ranracancha",
    "lat": "-13.53361",
    "lng": "-73.60528"
  },
  {
    "country": "PE",
    "name": "Quito-Arma",
    "lat": "-13.53333",
    "lng": "-75.33333"
  },
  {
    "country": "PE",
    "name": "Quiquijana",
    "lat": "-13.82278",
    "lng": "-71.53944"
  },
  {
    "country": "PE",
    "name": "Quinua",
    "lat": "-13.04917",
    "lng": "-74.13861"
  },
  {
    "country": "PE",
    "name": "Quiñota",
    "lat": "-14.30778",
    "lng": "-72.13611"
  },
  {
    "country": "PE",
    "name": "Quinocay",
    "lat": "-12.36667",
    "lng": "-76.23333"
  },
  {
    "country": "PE",
    "name": "Quinistaquillas",
    "lat": "-16.75",
    "lng": "-70.88333"
  },
  {
    "country": "PE",
    "name": "Quince Mil",
    "lat": "-13.23092",
    "lng": "-70.75401"
  },
  {
    "country": "PE",
    "name": "Quilmaná",
    "lat": "-12.9486",
    "lng": "-76.38112"
  },
  {
    "country": "PE",
    "name": "Quillabamba",
    "lat": "-12.86334",
    "lng": "-72.69306"
  },
  {
    "country": "PE",
    "name": "Quilcata",
    "lat": "-15.24778",
    "lng": "-73.45389"
  },
  {
    "country": "PE",
    "name": "Quilca",
    "lat": "-16.71417",
    "lng": "-72.43528"
  },
  {
    "country": "PE",
    "name": "Quilahuani",
    "lat": "-17.31778",
    "lng": "-70.25806"
  },
  {
    "country": "PE",
    "name": "Quicacha",
    "lat": "-15.62583",
    "lng": "-73.79833"
  },
  {
    "country": "PE",
    "name": "Quiaca",
    "lat": "-14.43333",
    "lng": "-69.35"
  },
  {
    "country": "PE",
    "name": "Queropalca",
    "lat": "-10.18139",
    "lng": "-76.80389"
  },
  {
    "country": "PE",
    "name": "Querobamba",
    "lat": "-14.01333",
    "lng": "-73.83972"
  },
  {
    "country": "PE",
    "name": "Quequeña",
    "lat": "-16.55778",
    "lng": "-71.45111"
  },
  {
    "country": "PE",
    "name": "Quellouno",
    "lat": "-12.63667",
    "lng": "-72.55944"
  },
  {
    "country": "PE",
    "name": "Quehue",
    "lat": "-14.38",
    "lng": "-71.455"
  },
  {
    "country": "PE",
    "name": "Quebrada Honda",
    "lat": "-12.76667",
    "lng": "-72.23333"
  },
  {
    "country": "PE",
    "name": "Putina",
    "lat": "-15.4764",
    "lng": "-69.43292"
  },
  {
    "country": "PE",
    "name": "Putina",
    "lat": "-14.91667",
    "lng": "-69.86667"
  },
  {
    "country": "PE",
    "name": "Pusi",
    "lat": "-15.43333",
    "lng": "-69.93333"
  },
  {
    "country": "PE",
    "name": "Puquio",
    "lat": "-14.7",
    "lng": "-74.13333"
  },
  {
    "country": "PE",
    "name": "Puquina",
    "lat": "-16.62361",
    "lng": "-71.18444"
  },
  {
    "country": "PE",
    "name": "Punta Hermosa",
    "lat": "-12.33333",
    "lng": "-76.81667"
  },
  {
    "country": "PE",
    "name": "Punta de Bombón",
    "lat": "-17.1719",
    "lng": "-71.7924"
  },
  {
    "country": "PE",
    "name": "Puno",
    "lat": "-15.8422",
    "lng": "-70.0199"
  },
  {
    "country": "PE",
    "name": "Pullo",
    "lat": "-15.21667",
    "lng": "-73.81667"
  },
  {
    "country": "PE",
    "name": "Pujocucho",
    "lat": "-17.15778",
    "lng": "-70.35222"
  },
  {
    "country": "PE",
    "name": "Puyca",
    "lat": "-15.06",
    "lng": "-72.69083"
  },
  {
    "country": "PE",
    "name": "Puerto Supe",
    "lat": "-10.80135",
    "lng": "-77.74333"
  },
  {
    "country": "PE",
    "name": "Puerto Ocopa",
    "lat": "-11.14694",
    "lng": "-74.30583"
  },
  {
    "country": "PE",
    "name": "Puerto Maldonado",
    "lat": "-12.59331",
    "lng": "-69.18913"
  },
  {
    "country": "PE",
    "name": "Pueblo Nuevo",
    "lat": "-14.12806",
    "lng": "-75.70667"
  },
  {
    "country": "PE",
    "name": "Pucyura",
    "lat": "-13.47889",
    "lng": "-72.11167"
  },
  {
    "country": "PE",
    "name": "Pucusana",
    "lat": "-12.48333",
    "lng": "-76.8"
  },
  {
    "country": "PE",
    "name": "Pucara",
    "lat": "-15.97993",
    "lng": "-71.45988"
  },
  {
    "country": "PE",
    "name": "Pozuzo",
    "lat": "-10.06667",
    "lng": "-75.53333"
  },
  {
    "country": "PE",
    "name": "Potoni",
    "lat": "-14.38333",
    "lng": "-70.08333"
  },
  {
    "country": "PE",
    "name": "Poroy",
    "lat": "-13.495",
    "lng": "-72.04333"
  },
  {
    "country": "PE",
    "name": "Pomata",
    "lat": "-16.26667",
    "lng": "-69.3"
  },
  {
    "country": "PE",
    "name": "Pomacocha",
    "lat": "-14.08444",
    "lng": "-73.58889"
  },
  {
    "country": "PE",
    "name": "Pomacocha",
    "lat": "-12.85",
    "lng": "-74.51667"
  },
  {
    "country": "PE",
    "name": "Pomacanchi",
    "lat": "-14.02694",
    "lng": "-71.56722"
  },
  {
    "country": "PE",
    "name": "Pomacancha",
    "lat": "-11.73828",
    "lng": "-75.62448"
  },
  {
    "country": "PE",
    "name": "Pomabamba",
    "lat": "-13.60444",
    "lng": "-74.23528"
  },
  {
    "country": "PE",
    "name": "Pocsi",
    "lat": "-16.51639",
    "lng": "-71.38833"
  },
  {
    "country": "PE",
    "name": "Pocollay",
    "lat": "-17.99167",
    "lng": "-70.21333"
  },
  {
    "country": "PE",
    "name": "Pocohuanca",
    "lat": "-14.21667",
    "lng": "-73.08333"
  },
  {
    "country": "PE",
    "name": "Pitumarca",
    "lat": "-13.97222",
    "lng": "-71.41"
  },
  {
    "country": "PE",
    "name": "Pisco",
    "lat": "-13.71029",
    "lng": "-76.20538"
  },
  {
    "country": "PE",
    "name": "Pisac",
    "lat": "-13.4225",
    "lng": "-71.84667"
  },
  {
    "country": "PE",
    "name": "Pirca",
    "lat": "-11.23444",
    "lng": "-76.65556"
  },
  {
    "country": "PE",
    "name": "Pilpichaca",
    "lat": "-13.32611",
    "lng": "-74.9975"
  },
  {
    "country": "PE",
    "name": "Pillpinto",
    "lat": "-13.95417",
    "lng": "-71.75972"
  },
  {
    "country": "PE",
    "name": "Pillcopata",
    "lat": "-13.06667",
    "lng": "-71.16667"
  },
  {
    "country": "PE",
    "name": "Pilcuyo",
    "lat": "-16.1",
    "lng": "-69.56667"
  },
  {
    "country": "PE",
    "name": "Pilcomay",
    "lat": "-12.04722",
    "lng": "-75.24931"
  },
  {
    "country": "PE",
    "name": "Pilchaca",
    "lat": "-12.4",
    "lng": "-75.1"
  },
  {
    "country": "PE",
    "name": "Pichirhua",
    "lat": "-13.86083",
    "lng": "-73.07361"
  },
  {
    "country": "PE",
    "name": "Pichigua",
    "lat": "-14.68139",
    "lng": "-71.41694"
  },
  {
    "country": "PE",
    "name": "Pichari",
    "lat": "-12.5",
    "lng": "-73.81667"
  },
  {
    "country": "PE",
    "name": "Phara",
    "lat": "-14.15167",
    "lng": "-69.66306"
  },
  {
    "country": "PE",
    "name": "Perené",
    "lat": "-10.9451",
    "lng": "-75.22394"
  },
  {
    "country": "PE",
    "name": "Pazos",
    "lat": "-12.26667",
    "lng": "-75.1"
  },
  {
    "country": "PE",
    "name": "Pausa",
    "lat": "-15.27972",
    "lng": "-73.34583"
  },
  {
    "country": "PE",
    "name": "Paucartambo",
    "lat": "-13.31522",
    "lng": "-71.59364"
  },
  {
    "country": "PE",
    "name": "Paucarcolla",
    "lat": "-15.73333",
    "lng": "-70.05"
  },
  {
    "country": "PE",
    "name": "Paucarbamba",
    "lat": "-12.55",
    "lng": "-74.55"
  },
  {
    "country": "PE",
    "name": "Paucar",
    "lat": "-10.37111",
    "lng": "-76.44361"
  },
  {
    "country": "PE",
    "name": "Pativilca",
    "lat": "-10.7",
    "lng": "-77.78333"
  },
  {
    "country": "PE",
    "name": "Pataypampa",
    "lat": "-14.175",
    "lng": "-72.67389"
  },
  {
    "country": "PE",
    "name": "Patambuco",
    "lat": "-14.35972",
    "lng": "-69.61889"
  },
  {
    "country": "PE",
    "name": "Paruro",
    "lat": "-13.76333",
    "lng": "-71.84944"
  },
  {
    "country": "PE",
    "name": "Parco",
    "lat": "-11.80015",
    "lng": "-75.54603"
  },
  {
    "country": "PE",
    "name": "Paratia",
    "lat": "-15.4525",
    "lng": "-70.59861"
  },
  {
    "country": "PE",
    "name": "Paramonga",
    "lat": "-10.66667",
    "lng": "-77.83333"
  },
  {
    "country": "PE",
    "name": "Paracas",
    "lat": "-13.86667",
    "lng": "-76.26667"
  },
  {
    "country": "PE",
    "name": "Pangoa",
    "lat": "-12.11667",
    "lng": "-73"
  },
  {
    "country": "PE",
    "name": "Pancan",
    "lat": "-11.74899",
    "lng": "-75.48635"
  },
  {
    "country": "PE",
    "name": "Pampas Chico",
    "lat": "-10.11532",
    "lng": "-77.39783"
  },
  {
    "country": "PE",
    "name": "Pampas",
    "lat": "-13.22889",
    "lng": "-73.89417"
  },
  {
    "country": "PE",
    "name": "Pampas",
    "lat": "-12.3949",
    "lng": "-74.86687"
  },
  {
    "country": "PE",
    "name": "Pampamarca",
    "lat": "-14.14639",
    "lng": "-71.45944"
  },
  {
    "country": "PE",
    "name": "Pampacolca",
    "lat": "-15.71306",
    "lng": "-72.57417"
  },
  {
    "country": "PE",
    "name": "Pampachiri",
    "lat": "-14.18694",
    "lng": "-73.54389"
  },
  {
    "country": "PE",
    "name": "Pampa Cangallo",
    "lat": "-13.55917",
    "lng": "-74.19528"
  },
  {
    "country": "PE",
    "name": "Palpacachi",
    "lat": "-13.87",
    "lng": "-72.50389"
  },
  {
    "country": "PE",
    "name": "Palpa",
    "lat": "-14.53361",
    "lng": "-75.18556"
  },
  {
    "country": "PE",
    "name": "Pallanchacra",
    "lat": "-10.41528",
    "lng": "-76.23556"
  },
  {
    "country": "PE",
    "name": "Palcamayo",
    "lat": "-11.29472",
    "lng": "-75.77361"
  },
  {
    "country": "PE",
    "name": "Palca",
    "lat": "-17.77528",
    "lng": "-69.96028"
  },
  {
    "country": "PE",
    "name": "Palca",
    "lat": "-15.23361",
    "lng": "-70.59722"
  },
  {
    "country": "PE",
    "name": "Palca",
    "lat": "-11.34611",
    "lng": "-75.56861"
  },
  {
    "country": "PE",
    "name": "Paico",
    "lat": "-14.03778",
    "lng": "-73.64361"
  },
  {
    "country": "PE",
    "name": "Pacucha",
    "lat": "-13.60889",
    "lng": "-73.34361"
  },
  {
    "country": "PE",
    "name": "Pacocha",
    "lat": "-17.64604",
    "lng": "-71.34481"
  },
  {
    "country": "PE",
    "name": "Pacobamba",
    "lat": "-13.61639",
    "lng": "-73.08611"
  },
  {
    "country": "PE",
    "name": "Pachaconas",
    "lat": "-14.2225",
    "lng": "-73.02556"
  },
  {
    "country": "PE",
    "name": "Paccho",
    "lat": "-10.95722",
    "lng": "-76.93222"
  },
  {
    "country": "PE",
    "name": "Paccha",
    "lat": "-11.85411",
    "lng": "-75.50767"
  },
  {
    "country": "PE",
    "name": "Paccha",
    "lat": "-11.47389",
    "lng": "-75.96"
  },
  {
    "country": "PE",
    "name": "Paccaritambo",
    "lat": "-13.75917",
    "lng": "-71.955"
  },
  {
    "country": "PE",
    "name": "Pacaycasa",
    "lat": "-13.05694",
    "lng": "-74.21361"
  },
  {
    "country": "PE",
    "name": "Pacaraos",
    "lat": "-11.18611",
    "lng": "-76.6475"
  },
  {
    "country": "PE",
    "name": "Pacapausa",
    "lat": "-14.95139",
    "lng": "-73.36778"
  },
  {
    "country": "PE",
    "name": "Paca",
    "lat": "-11.71539",
    "lng": "-75.51586"
  },
  {
    "country": "PE",
    "name": "Oyón",
    "lat": "-10.66846",
    "lng": "-76.77165"
  },
  {
    "country": "PE",
    "name": "Oyolo",
    "lat": "-15.17972",
    "lng": "-73.18611"
  },
  {
    "country": "PE",
    "name": "Oxapampa",
    "lat": "-10.5775",
    "lng": "-75.40167"
  },
  {
    "country": "PE",
    "name": "Otoca",
    "lat": "-14.48333",
    "lng": "-74.7"
  },
  {
    "country": "PE",
    "name": "Orurillo",
    "lat": "-14.73",
    "lng": "-70.51306"
  },
  {
    "country": "PE",
    "name": "Oropesa",
    "lat": "-14.25611",
    "lng": "-72.555"
  },
  {
    "country": "PE",
    "name": "Oropesa",
    "lat": "-13.59278",
    "lng": "-71.77194"
  },
  {
    "country": "PE",
    "name": "Orcotuna",
    "lat": "-11.96886",
    "lng": "-75.3078"
  },
  {
    "country": "PE",
    "name": "Orcopampa",
    "lat": "-15.26611",
    "lng": "-72.34167"
  },
  {
    "country": "PE",
    "name": "Ongoy",
    "lat": "-13.40361",
    "lng": "-73.66972"
  },
  {
    "country": "PE",
    "name": "Ondores",
    "lat": "-11.08651",
    "lng": "-76.14831"
  },
  {
    "country": "PE",
    "name": "Omate",
    "lat": "-16.68333",
    "lng": "-70.98333"
  },
  {
    "country": "PE",
    "name": "Omas",
    "lat": "-12.51667",
    "lng": "-76.28333"
  },
  {
    "country": "PE",
    "name": "Omacha",
    "lat": "-14.07139",
    "lng": "-71.73972"
  },
  {
    "country": "PE",
    "name": "Ollantaytambo",
    "lat": "-13.25722",
    "lng": "-72.26306"
  },
  {
    "country": "PE",
    "name": "Ollachea",
    "lat": "-13.81667",
    "lng": "-70.48333"
  },
  {
    "country": "PE",
    "name": "Ocuviri",
    "lat": "-15.11111",
    "lng": "-70.90778"
  },
  {
    "country": "PE",
    "name": "Ocucaje",
    "lat": "-14.34861",
    "lng": "-75.66917"
  },
  {
    "country": "PE",
    "name": "Ocros",
    "lat": "-13.39139",
    "lng": "-73.915"
  },
  {
    "country": "PE",
    "name": "Ocros",
    "lat": "-10.40294",
    "lng": "-77.39666"
  },
  {
    "country": "PE",
    "name": "Ocoyo",
    "lat": "-14.00806",
    "lng": "-75.02194"
  },
  {
    "country": "PE",
    "name": "Ocoruro",
    "lat": "-15.0525",
    "lng": "-71.12889"
  },
  {
    "country": "PE",
    "name": "Ocongate",
    "lat": "-13.62694",
    "lng": "-71.38528"
  },
  {
    "country": "PE",
    "name": "Ocoña",
    "lat": "-16.43306",
    "lng": "-73.10778"
  },
  {
    "country": "PE",
    "name": "Ocobamba",
    "lat": "-13.48194",
    "lng": "-73.56111"
  },
  {
    "country": "PE",
    "name": "Ocaña",
    "lat": "-14.38333",
    "lng": "-74.81667"
  },
  {
    "country": "PE",
    "name": "Ñuñoa",
    "lat": "-14.47788",
    "lng": "-70.63583"
  },
  {
    "country": "PE",
    "name": "Nuevo Imperial",
    "lat": "-13.07541",
    "lng": "-76.31719"
  },
  {
    "country": "PE",
    "name": "Ninacaca",
    "lat": "-10.85",
    "lng": "-76.11667"
  },
  {
    "country": "PE",
    "name": "Asentamiento Humano Nicolas de Pierola",
    "lat": "-11.93573",
    "lng": "-76.70611"
  },
  {
    "country": "PE",
    "name": "Nicasio",
    "lat": "-15.23333",
    "lng": "-70.25"
  },
  {
    "country": "PE",
    "name": "Nazca",
    "lat": "-14.83098",
    "lng": "-74.93895"
  },
  {
    "country": "PE",
    "name": "Muquiyauyo",
    "lat": "-11.81371",
    "lng": "-75.45482"
  },
  {
    "country": "PE",
    "name": "Muqui",
    "lat": "-11.83364",
    "lng": "-75.43462"
  },
  {
    "country": "PE",
    "name": "Mungui",
    "lat": "-15.18278",
    "lng": "-72.90556"
  },
  {
    "country": "PE",
    "name": "Muñani",
    "lat": "-14.76667",
    "lng": "-69.95"
  },
  {
    "country": "PE",
    "name": "Mosca",
    "lat": "-10.34278",
    "lng": "-76.29167"
  },
  {
    "country": "PE",
    "name": "Morococha",
    "lat": "-11.59972",
    "lng": "-76.14111"
  },
  {
    "country": "PE",
    "name": "Morcolla",
    "lat": "-14.11056",
    "lng": "-73.87139"
  },
  {
    "country": "PE",
    "name": "Moquegua",
    "lat": "-17.19832",
    "lng": "-70.93567"
  },
  {
    "country": "PE",
    "name": "Mollepampa",
    "lat": "-13.3",
    "lng": "-75.4"
  },
  {
    "country": "PE",
    "name": "Mollendo",
    "lat": "-17.02306",
    "lng": "-72.01472"
  },
  {
    "country": "PE",
    "name": "Mollebamba",
    "lat": "-14.42139",
    "lng": "-72.91194"
  },
  {
    "country": "PE",
    "name": "Molinos",
    "lat": "-11.73642",
    "lng": "-75.44356"
  },
  {
    "country": "PE",
    "name": "Moho",
    "lat": "-15.35",
    "lng": "-69.5"
  },
  {
    "country": "PE",
    "name": "Miraflores",
    "lat": "-12.27361",
    "lng": "-75.85"
  },
  {
    "country": "PE",
    "name": "Mazo Cruz",
    "lat": "-16.75",
    "lng": "-69.73333"
  },
  {
    "country": "PE",
    "name": "Mazamari",
    "lat": "-11.32583",
    "lng": "-74.53083"
  },
  {
    "country": "PE",
    "name": "Mayocc",
    "lat": "-12.78333",
    "lng": "-74.4"
  },
  {
    "country": "PE",
    "name": "Matucana",
    "lat": "-11.85",
    "lng": "-76.4"
  },
  {
    "country": "PE",
    "name": "Matalaque",
    "lat": "-16.48333",
    "lng": "-70.81667"
  },
  {
    "country": "PE",
    "name": "Mariposa",
    "lat": "-11.4025",
    "lng": "-74.75083"
  },
  {
    "country": "PE",
    "name": "Mariatana",
    "lat": "-12.25",
    "lng": "-76.33333"
  },
  {
    "country": "PE",
    "name": "Margos",
    "lat": "-10.00611",
    "lng": "-76.5225"
  },
  {
    "country": "PE",
    "name": "Minas de Marcona",
    "lat": "-15.21194",
    "lng": "-75.11028"
  },
  {
    "country": "PE",
    "name": "Marco",
    "lat": "-11.74117",
    "lng": "-75.56279"
  },
  {
    "country": "PE",
    "name": "Marcas",
    "lat": "-12.88333",
    "lng": "-74.38333"
  },
  {
    "country": "PE",
    "name": "Marcapomacocha",
    "lat": "-11.40692",
    "lng": "-76.33628"
  },
  {
    "country": "PE",
    "name": "Marcapata",
    "lat": "-13.58972",
    "lng": "-70.97222"
  },
  {
    "country": "PE",
    "name": "Marcabamba",
    "lat": "-15.15056",
    "lng": "-73.34194"
  },
  {
    "country": "PE",
    "name": "Marca",
    "lat": "-10.08833",
    "lng": "-77.47431"
  },
  {
    "country": "PE",
    "name": "Maray",
    "lat": "-10.93556",
    "lng": "-76.83389"
  },
  {
    "country": "PE",
    "name": "Maras",
    "lat": "-13.335",
    "lng": "-72.15667"
  },
  {
    "country": "PE",
    "name": "Maranura",
    "lat": "-12.96306",
    "lng": "-72.66472"
  },
  {
    "country": "PE",
    "name": "Maranganí",
    "lat": "-14.35672",
    "lng": "-71.16924"
  },
  {
    "country": "PE",
    "name": "Mara",
    "lat": "-14.08528",
    "lng": "-72.10806"
  },
  {
    "country": "PE",
    "name": "Mangas",
    "lat": "-10.37411",
    "lng": "-77.10205"
  },
  {
    "country": "PE",
    "name": "Mañazo",
    "lat": "-15.8",
    "lng": "-70.33333"
  },
  {
    "country": "PE",
    "name": "Mamara",
    "lat": "-14.22944",
    "lng": "-72.58611"
  },
  {
    "country": "PE",
    "name": "Mala",
    "lat": "-12.65806",
    "lng": "-76.63083"
  },
  {
    "country": "PE",
    "name": "Madrigal",
    "lat": "-15.60778",
    "lng": "-71.80806"
  },
  {
    "country": "PE",
    "name": "Madean",
    "lat": "-12.94444",
    "lng": "-75.77667"
  },
  {
    "country": "PE",
    "name": "Macusani",
    "lat": "-14.08333",
    "lng": "-70.43333"
  },
  {
    "country": "PE",
    "name": "Macari",
    "lat": "-14.76861",
    "lng": "-70.90194"
  },
  {
    "country": "PE",
    "name": "Macachacra",
    "lat": "-12.98333",
    "lng": "-74.2"
  },
  {
    "country": "PE",
    "name": "Maca",
    "lat": "-15.64167",
    "lng": "-71.76944"
  },
  {
    "country": "PE",
    "name": "Luricocha",
    "lat": "-12.85",
    "lng": "-74.26667"
  },
  {
    "country": "PE",
    "name": "Lucre",
    "lat": "-13.94917",
    "lng": "-73.22611"
  },
  {
    "country": "PE",
    "name": "Lucre",
    "lat": "-13.63556",
    "lng": "-71.7375"
  },
  {
    "country": "PE",
    "name": "Lucanas",
    "lat": "-14.6",
    "lng": "-74.25"
  },
  {
    "country": "PE",
    "name": "Los Aquijes",
    "lat": "-14.09667",
    "lng": "-75.69083"
  },
  {
    "country": "PE",
    "name": "Locumba",
    "lat": "-17.61333",
    "lng": "-70.76278"
  },
  {
    "country": "PE",
    "name": "Locroja",
    "lat": "-12.68333",
    "lng": "-74.43333"
  },
  {
    "country": "PE",
    "name": "Lluta",
    "lat": "-16.01472",
    "lng": "-72.01417"
  },
  {
    "country": "PE",
    "name": "Llusco",
    "lat": "-14.33111",
    "lng": "-72.11472"
  },
  {
    "country": "PE",
    "name": "Lloque",
    "lat": "-16.33333",
    "lng": "-70.73333"
  },
  {
    "country": "PE",
    "name": "Llocllapampa",
    "lat": "-11.81781",
    "lng": "-75.62382"
  },
  {
    "country": "PE",
    "name": "Llipata",
    "lat": "-14.56417",
    "lng": "-75.20778"
  },
  {
    "country": "PE",
    "name": "Llipa",
    "lat": "-10.38195",
    "lng": "-77.20579"
  },
  {
    "country": "PE",
    "name": "Llauta",
    "lat": "-14.26667",
    "lng": "-74.91667"
  },
  {
    "country": "PE",
    "name": "Llalli",
    "lat": "-14.93333",
    "lng": "-70.88278"
  },
  {
    "country": "PE",
    "name": "Llacllin",
    "lat": "-10.06667",
    "lng": "-77.61667"
  },
  {
    "country": "PE",
    "name": "Llaclla",
    "lat": "-10.29875",
    "lng": "-77.14535"
  },
  {
    "country": "PE",
    "name": "Livitaca",
    "lat": "-14.30194",
    "lng": "-71.68722"
  },
  {
    "country": "PE",
    "name": "Lircay",
    "lat": "-13",
    "lng": "-74.71667"
  },
  {
    "country": "PE",
    "name": "Lincha",
    "lat": "-12.79861",
    "lng": "-75.665"
  },
  {
    "country": "PE",
    "name": "Limbani",
    "lat": "-14.14778",
    "lng": "-69.68889"
  },
  {
    "country": "PE",
    "name": "Limatambo",
    "lat": "-13.47917",
    "lng": "-72.4425"
  },
  {
    "country": "PE",
    "name": "Lima",
    "lat": "-12.04318",
    "lng": "-77.02824"
  },
  {
    "country": "PE",
    "name": "Leticia",
    "lat": "-11.37972",
    "lng": "-75.75389"
  },
  {
    "country": "PE",
    "name": "Layo",
    "lat": "-14.49361",
    "lng": "-71.155"
  },
  {
    "country": "PE",
    "name": "La Tinguiña",
    "lat": "-14.03583",
    "lng": "-75.70028"
  },
  {
    "country": "PE",
    "name": "Las Yaras",
    "lat": "-17.86417",
    "lng": "-70.56278"
  },
  {
    "country": "PE",
    "name": "Lari",
    "lat": "-15.62222",
    "lng": "-71.76889"
  },
  {
    "country": "PE",
    "name": "Lares",
    "lat": "-13.10333",
    "lng": "-72.04389"
  },
  {
    "country": "PE",
    "name": "Laraqueri",
    "lat": "-16.13333",
    "lng": "-70.05"
  },
  {
    "country": "PE",
    "name": "Laraos",
    "lat": "-12.34667",
    "lng": "-75.78639"
  },
  {
    "country": "PE",
    "name": "Laraos",
    "lat": "-11.66472",
    "lng": "-76.53944"
  },
  {
    "country": "PE",
    "name": "Laramate",
    "lat": "-14.25",
    "lng": "-74.86667"
  },
  {
    "country": "PE",
    "name": "La Pampa",
    "lat": "-16.61361",
    "lng": "-72.69639"
  },
  {
    "country": "PE",
    "name": "La Oroya",
    "lat": "-11.51893",
    "lng": "-75.89935"
  },
  {
    "country": "PE",
    "name": "Lanlacuni Bajo",
    "lat": "-13.48333",
    "lng": "-70.41667"
  },
  {
    "country": "PE",
    "name": "Langui",
    "lat": "-14.43194",
    "lng": "-71.27306"
  },
  {
    "country": "PE",
    "name": "Lampian",
    "lat": "-11.23778",
    "lng": "-76.83972"
  },
  {
    "country": "PE",
    "name": "Lampa",
    "lat": "-15.35",
    "lng": "-70.36667"
  },
  {
    "country": "PE",
    "name": "Lampa",
    "lat": "-15.18444",
    "lng": "-73.34889"
  },
  {
    "country": "PE",
    "name": "La Molina",
    "lat": "-12.08333",
    "lng": "-76.95"
  },
  {
    "country": "PE",
    "name": "La Merced",
    "lat": "-11.06146",
    "lng": "-75.33505"
  },
  {
    "country": "PE",
    "name": "Lambrama",
    "lat": "-13.86667",
    "lng": "-72.76667"
  },
  {
    "country": "PE",
    "name": "Lamay",
    "lat": "-13.36417",
    "lng": "-71.92389"
  },
  {
    "country": "PE",
    "name": "Lahuaytambo",
    "lat": "-12.1",
    "lng": "-76.4"
  },
  {
    "country": "PE",
    "name": "La Esmeralda",
    "lat": "-12.63333",
    "lng": "-74.6"
  },
  {
    "country": "PE",
    "name": "La Curva",
    "lat": "-17.14667",
    "lng": "-71.82167"
  },
  {
    "country": "PE",
    "name": "Lachaqui",
    "lat": "-11.55333",
    "lng": "-76.62333"
  },
  {
    "country": "PE",
    "name": "La Capilla",
    "lat": "-16.75694",
    "lng": "-71.17917"
  },
  {
    "country": "PE",
    "name": "Kishuara",
    "lat": "-13.69444",
    "lng": "-73.11639"
  },
  {
    "country": "PE",
    "name": "Junín",
    "lat": "-11.15895",
    "lng": "-75.99304"
  },
  {
    "country": "PE",
    "name": "Juliaca",
    "lat": "-15.5",
    "lng": "-70.13333"
  },
  {
    "country": "PE",
    "name": "Juli",
    "lat": "-16.21667",
    "lng": "-69.45"
  },
  {
    "country": "PE",
    "name": "Julcan",
    "lat": "-11.76025",
    "lng": "-75.43587"
  },
  {
    "country": "PE",
    "name": "Julcamarca",
    "lat": "-13.01278",
    "lng": "-74.44222"
  },
  {
    "country": "PE",
    "name": "Jivia",
    "lat": "-10.02389",
    "lng": "-76.67917"
  },
  {
    "country": "PE",
    "name": "Jauja",
    "lat": "-11.77584",
    "lng": "-75.49656"
  },
  {
    "country": "PE",
    "name": "Jatun Orcochiri",
    "lat": "-15.75003",
    "lng": "-71.34641"
  },
  {
    "country": "PE",
    "name": "Jarpa",
    "lat": "-12.11667",
    "lng": "-75.46667"
  },
  {
    "country": "PE",
    "name": "Jucul",
    "lat": "-10.94861",
    "lng": "-76.745"
  },
  {
    "country": "PE",
    "name": "Izcuchaca",
    "lat": "-12.48333",
    "lng": "-75.01667"
  },
  {
    "country": "PE",
    "name": "Iray",
    "lat": "-15.85639",
    "lng": "-72.62556"
  },
  {
    "country": "PE",
    "name": "Iquipi",
    "lat": "-15.94028",
    "lng": "-73.13"
  },
  {
    "country": "PE",
    "name": "Ingenio",
    "lat": "-11.8895",
    "lng": "-75.26554"
  },
  {
    "country": "PE",
    "name": "Independencia",
    "lat": "-13.7",
    "lng": "-76.03333"
  },
  {
    "country": "PE",
    "name": "Independencia",
    "lat": "-11.99",
    "lng": "-77.04583"
  },
  {
    "country": "PE",
    "name": "Incuyo",
    "lat": "-15.25",
    "lng": "-73.58333"
  },
  {
    "country": "PE",
    "name": "Inchupalla",
    "lat": "-15",
    "lng": "-69.68333"
  },
  {
    "country": "PE",
    "name": "Iñapari",
    "lat": "-10.95",
    "lng": "-69.58333"
  },
  {
    "country": "PE",
    "name": "Imperial",
    "lat": "-13.05927",
    "lng": "-76.35269"
  },
  {
    "country": "PE",
    "name": "Ilo",
    "lat": "-17.63185",
    "lng": "-71.34108"
  },
  {
    "country": "PE",
    "name": "Ilave",
    "lat": "-16.08333",
    "lng": "-69.66667"
  },
  {
    "country": "PE",
    "name": "Ilabaya",
    "lat": "-17.42083",
    "lng": "-70.51333"
  },
  {
    "country": "PE",
    "name": "Ihuari",
    "lat": "-11.18917",
    "lng": "-76.95139"
  },
  {
    "country": "PE",
    "name": "Ichupampa",
    "lat": "-15.64972",
    "lng": "-71.6875"
  },
  {
    "country": "PE",
    "name": "Ichuña",
    "lat": "-16.15",
    "lng": "-70.56667"
  },
  {
    "country": "PE",
    "name": "Ica",
    "lat": "-14.06777",
    "lng": "-75.72861"
  },
  {
    "country": "PE",
    "name": "Iberia",
    "lat": "-11.35",
    "lng": "-69.58333"
  },
  {
    "country": "PE",
    "name": "Humay",
    "lat": "-13.71667",
    "lng": "-75.9"
  },
  {
    "country": "PE",
    "name": "Umamarca",
    "lat": "-14.05278",
    "lng": "-73.56556"
  },
  {
    "country": "PE",
    "name": "Huayucachi",
    "lat": "-12.13333",
    "lng": "-75.23333"
  },
  {
    "country": "PE",
    "name": "Huayrapata",
    "lat": "-15.3",
    "lng": "-69.33333"
  },
  {
    "country": "PE",
    "name": "Huayllay",
    "lat": "-11.00367",
    "lng": "-76.36452"
  },
  {
    "country": "PE",
    "name": "Huayllapampa",
    "lat": "-10.05",
    "lng": "-77.53333"
  },
  {
    "country": "PE",
    "name": "Huayllahuara",
    "lat": "-12.4",
    "lng": "-75.16667"
  },
  {
    "country": "PE",
    "name": "Huayllabamba",
    "lat": "-13.33806",
    "lng": "-72.06528"
  },
  {
    "country": "PE",
    "name": "Huayana",
    "lat": "-14.04833",
    "lng": "-73.60972"
  },
  {
    "country": "PE",
    "name": "Huayacundo Arma",
    "lat": "-13.53639",
    "lng": "-75.30528"
  },
  {
    "country": "PE",
    "name": "Huaura",
    "lat": "-11.07",
    "lng": "-77.59944"
  },
  {
    "country": "PE",
    "name": "Huata",
    "lat": "-15.61667",
    "lng": "-69.96667"
  },
  {
    "country": "PE",
    "name": "Huasta",
    "lat": "-10.12385",
    "lng": "-77.15733"
  },
  {
    "country": "PE",
    "name": "Huasahuasi",
    "lat": "-11.26527",
    "lng": "-75.64722"
  },
  {
    "country": "PE",
    "name": "Huaros",
    "lat": "-11.40583",
    "lng": "-76.57694"
  },
  {
    "country": "PE",
    "name": "Huarocondo",
    "lat": "-13.41333",
    "lng": "-72.20639"
  },
  {
    "country": "PE",
    "name": "Huaro",
    "lat": "-13.68833",
    "lng": "-71.63583"
  },
  {
    "country": "PE",
    "name": "Huarmey",
    "lat": "-10.06806",
    "lng": "-78.15222"
  },
  {
    "country": "PE",
    "name": "Huaripampa",
    "lat": "-11.80816",
    "lng": "-75.47143"
  },
  {
    "country": "PE",
    "name": "Huaribamba",
    "lat": "-12.26667",
    "lng": "-74.95"
  },
  {
    "country": "PE",
    "name": "Huariaca",
    "lat": "-10.44167",
    "lng": "-76.19028"
  },
  {
    "country": "PE",
    "name": "Huaral",
    "lat": "-11.495",
    "lng": "-77.20778"
  },
  {
    "country": "PE",
    "name": "Huaquirca",
    "lat": "-14.33139",
    "lng": "-72.89028"
  },
  {
    "country": "PE",
    "name": "Huanza",
    "lat": "-11.65667",
    "lng": "-76.50333"
  },
  {
    "country": "PE",
    "name": "Huanuara",
    "lat": "-17.31389",
    "lng": "-70.32194"
  },
  {
    "country": "PE",
    "name": "Huanta",
    "lat": "-12.93333",
    "lng": "-74.25"
  },
  {
    "country": "PE",
    "name": "Huanoquite",
    "lat": "-13.68278",
    "lng": "-72.01667"
  },
  {
    "country": "PE",
    "name": "Huanipaca",
    "lat": "-13.5",
    "lng": "-72.93333"
  },
  {
    "country": "PE",
    "name": "Huangascar",
    "lat": "-12.89889",
    "lng": "-75.83111"
  },
  {
    "country": "PE",
    "name": "Huancayo",
    "lat": "-12.06513",
    "lng": "-75.20486"
  },
  {
    "country": "PE",
    "name": "Huancaya",
    "lat": "-12.20306",
    "lng": "-75.79806"
  },
  {
    "country": "PE",
    "name": "Huancavelica",
    "lat": "-12.78261",
    "lng": "-74.97266"
  },
  {
    "country": "PE",
    "name": "Huancarqui",
    "lat": "-16.09583",
    "lng": "-72.47278"
  },
  {
    "country": "PE",
    "name": "Huancaray",
    "lat": "-13.75861",
    "lng": "-73.5275"
  },
  {
    "country": "PE",
    "name": "Huancarama",
    "lat": "-13.64528",
    "lng": "-73.08639"
  },
  {
    "country": "PE",
    "name": "Huancapi",
    "lat": "-13.75667",
    "lng": "-74.06667"
  },
  {
    "country": "PE",
    "name": "Huancano",
    "lat": "-13.6",
    "lng": "-75.61667"
  },
  {
    "country": "PE",
    "name": "Hacienda Huancane",
    "lat": "-15.82327",
    "lng": "-70.8854"
  },
  {
    "country": "PE",
    "name": "Huancabamba",
    "lat": "-10.35",
    "lng": "-75.53333"
  },
  {
    "country": "PE",
    "name": "Huampara",
    "lat": "-12.35",
    "lng": "-76.18333"
  },
  {
    "country": "PE",
    "name": "Huambo",
    "lat": "-15.73083",
    "lng": "-72.1075"
  },
  {
    "country": "PE",
    "name": "Huambalpa",
    "lat": "-13.74972",
    "lng": "-73.93111"
  },
  {
    "country": "PE",
    "name": "Huamatambo",
    "lat": "-13.11667",
    "lng": "-75.68333"
  },
  {
    "country": "PE",
    "name": "Huamantanga",
    "lat": "-11.49917",
    "lng": "-76.74889"
  },
  {
    "country": "PE",
    "name": "Huamanquiquia",
    "lat": "-13.73",
    "lng": "-74.27278"
  },
  {
    "country": "PE",
    "name": "Huamanguilla",
    "lat": "-13.01111",
    "lng": "-74.17806"
  },
  {
    "country": "PE",
    "name": "Huamali",
    "lat": "-11.80722",
    "lng": "-75.42439"
  },
  {
    "country": "PE",
    "name": "Hualmay",
    "lat": "-11.09639",
    "lng": "-77.61389"
  },
  {
    "country": "PE",
    "name": "Huacrapuquio",
    "lat": "-12.18333",
    "lng": "-75.21667"
  },
  {
    "country": "PE",
    "name": "Huachos",
    "lat": "-13.2",
    "lng": "-75.51667"
  },
  {
    "country": "PE",
    "name": "Huachocolpa",
    "lat": "-13.02778",
    "lng": "-74.94583"
  },
  {
    "country": "PE",
    "name": "Huacho",
    "lat": "-11.10667",
    "lng": "-77.605"
  },
  {
    "country": "PE",
    "name": "Huacar",
    "lat": "-10.16028",
    "lng": "-76.23694"
  },
  {
    "country": "PE",
    "name": "Huacaña",
    "lat": "-14.17361",
    "lng": "-73.88639"
  },
  {
    "country": "PE",
    "name": "Hongos",
    "lat": "-12.81139",
    "lng": "-75.765"
  },
  {
    "country": "PE",
    "name": "Haquira",
    "lat": "-14.21278",
    "lng": "-72.19"
  },
  {
    "country": "PE",
    "name": "Guadalupe",
    "lat": "-13.96667",
    "lng": "-75.76667"
  },
  {
    "country": "PE",
    "name": "Goyllarisquizga",
    "lat": "-10.47389",
    "lng": "-76.40944"
  },
  {
    "country": "PE",
    "name": "Gorgor",
    "lat": "-10.58333",
    "lng": "-77.03333"
  },
  {
    "country": "PE",
    "name": "Estique",
    "lat": "-17.54167",
    "lng": "-70.01861"
  },
  {
    "country": "PE",
    "name": "El Tambo",
    "lat": "-12.06667",
    "lng": "-75.21667"
  },
  {
    "country": "PE",
    "name": "Progreso",
    "lat": "-14.0725",
    "lng": "-72.47278"
  },
  {
    "country": "PE",
    "name": "El Ingenio",
    "lat": "-14.64528",
    "lng": "-75.05833"
  },
  {
    "country": "PE",
    "name": "El Descanso",
    "lat": "-14.53333",
    "lng": "-71.30556"
  },
  {
    "country": "PE",
    "name": "El Carmen",
    "lat": "-13.49714",
    "lng": "-76.05724"
  },
  {
    "country": "PE",
    "name": "El Cardo",
    "lat": "-16.60333",
    "lng": "-72.72639"
  },
  {
    "country": "PE",
    "name": "Desaguadero",
    "lat": "-16.56556",
    "lng": "-69.04167"
  },
  {
    "country": "PE",
    "name": "Cuyocuyo",
    "lat": "-14.47139",
    "lng": "-69.53722"
  },
  {
    "country": "PE",
    "name": "Cusipata",
    "lat": "-13.9075",
    "lng": "-71.49861"
  },
  {
    "country": "PE",
    "name": "Cusco",
    "lat": "-13.52264",
    "lng": "-71.96734"
  },
  {
    "country": "PE",
    "name": "Curibaya",
    "lat": "-17.3825",
    "lng": "-70.33472"
  },
  {
    "country": "PE",
    "name": "Curahuasi",
    "lat": "-13.55",
    "lng": "-72.7"
  },
  {
    "country": "PE",
    "name": "Cupi",
    "lat": "-14.90611",
    "lng": "-70.87417"
  },
  {
    "country": "PE",
    "name": "Cullhuas",
    "lat": "-12.23333",
    "lng": "-75.16667"
  },
  {
    "country": "PE",
    "name": "Cuenca",
    "lat": "-12.43333",
    "lng": "-75.03333"
  },
  {
    "country": "PE",
    "name": "Cuchumbaya",
    "lat": "-16.75",
    "lng": "-70.68333"
  },
  {
    "country": "PE",
    "name": "Cruz Blanca",
    "lat": "-11.09722",
    "lng": "-77.5925"
  },
  {
    "country": "PE",
    "name": "Crucero",
    "lat": "-14.35",
    "lng": "-70"
  },
  {
    "country": "PE",
    "name": "Coyllurqui",
    "lat": "-13.83639",
    "lng": "-72.43083"
  },
  {
    "country": "PE",
    "name": "Coya",
    "lat": "-13.38806",
    "lng": "-71.89972"
  },
  {
    "country": "PE",
    "name": "Cotaruse",
    "lat": "-14.41583",
    "lng": "-73.20778"
  },
  {
    "country": "PE",
    "name": "Cotaparaco",
    "lat": "-10",
    "lng": "-77.6"
  },
  {
    "country": "PE",
    "name": "Cotahuasi",
    "lat": "-15.21306",
    "lng": "-72.88861"
  },
  {
    "country": "PE",
    "name": "Cotabambas",
    "lat": "-13.74639",
    "lng": "-72.35667"
  },
  {
    "country": "PE",
    "name": "Corpanqui",
    "lat": "-10.28508",
    "lng": "-77.19879"
  },
  {
    "country": "PE",
    "name": "Corire",
    "lat": "-16.22361",
    "lng": "-72.47111"
  },
  {
    "country": "PE",
    "name": "Corculla",
    "lat": "-15.2625",
    "lng": "-73.20056"
  },
  {
    "country": "PE",
    "name": "Corani",
    "lat": "-13.87111",
    "lng": "-70.60667"
  },
  {
    "country": "PE",
    "name": "Coracora",
    "lat": "-15.03333",
    "lng": "-73.78333"
  },
  {
    "country": "PE",
    "name": "Coporaque",
    "lat": "-15.62722",
    "lng": "-71.64611"
  },
  {
    "country": "PE",
    "name": "Coporaque",
    "lat": "-14.8",
    "lng": "-71.5325"
  },
  {
    "country": "PE",
    "name": "Copa",
    "lat": "-10.38821",
    "lng": "-77.07956"
  },
  {
    "country": "PE",
    "name": "Copa",
    "lat": "-10.37181",
    "lng": "-77.48744"
  },
  {
    "country": "PE",
    "name": "Conima",
    "lat": "-15.43333",
    "lng": "-69.43333"
  },
  {
    "country": "PE",
    "name": "Congas",
    "lat": "-10.33712",
    "lng": "-77.44188"
  },
  {
    "country": "PE",
    "name": "Condoroma",
    "lat": "-15.24",
    "lng": "-71.08222"
  },
  {
    "country": "PE",
    "name": "Concho",
    "lat": "-11.72503",
    "lng": "-75.57086"
  },
  {
    "country": "PE",
    "name": "Conchamarca",
    "lat": "-10.03778",
    "lng": "-76.21528"
  },
  {
    "country": "PE",
    "name": "Concepción",
    "lat": "-11.91762",
    "lng": "-75.31401"
  },
  {
    "country": "PE",
    "name": "Combapata",
    "lat": "-14.10111",
    "lng": "-71.42944"
  },
  {
    "country": "PE",
    "name": "Comas",
    "lat": "-11.7174",
    "lng": "-75.08118"
  },
  {
    "country": "PE",
    "name": "Colta",
    "lat": "-15.16222",
    "lng": "-73.29472"
  },
  {
    "country": "PE",
    "name": "Colquepata",
    "lat": "-13.35583",
    "lng": "-71.66972"
  },
  {
    "country": "PE",
    "name": "Colquemarca",
    "lat": "-14.28222",
    "lng": "-72.04194"
  },
  {
    "country": "PE",
    "name": "Colpas",
    "lat": "-10.26889",
    "lng": "-76.41417"
  },
  {
    "country": "PE",
    "name": "Colonia",
    "lat": "-12.63278",
    "lng": "-75.89056"
  },
  {
    "country": "PE",
    "name": "Colcha",
    "lat": "-13.85194",
    "lng": "-71.80333"
  },
  {
    "country": "PE",
    "name": "Colcabamba",
    "lat": "-14.00778",
    "lng": "-73.24778"
  },
  {
    "country": "PE",
    "name": "Colcabamba",
    "lat": "-12.4",
    "lng": "-74.7"
  },
  {
    "country": "PE",
    "name": "Colca",
    "lat": "-13.71472",
    "lng": "-74.03306"
  },
  {
    "country": "PE",
    "name": "Colca",
    "lat": "-12.3",
    "lng": "-75.21667"
  },
  {
    "country": "PE",
    "name": "Cojata",
    "lat": "-15.01667",
    "lng": "-69.36667"
  },
  {
    "country": "PE",
    "name": "Cochas",
    "lat": "-11.65709",
    "lng": "-75.10119"
  },
  {
    "country": "PE",
    "name": "Cocharcas",
    "lat": "-13.61",
    "lng": "-73.74"
  },
  {
    "country": "PE",
    "name": "Cocas",
    "lat": "-13.26667",
    "lng": "-75.36667"
  },
  {
    "country": "PE",
    "name": "Cocachacra",
    "lat": "-17.08833",
    "lng": "-71.7575"
  },
  {
    "country": "PE",
    "name": "Cocachacra",
    "lat": "-11.91333",
    "lng": "-76.53833"
  },
  {
    "country": "PE",
    "name": "Coayllo",
    "lat": "-12.73333",
    "lng": "-76.46667"
  },
  {
    "country": "PE",
    "name": "Coata",
    "lat": "-15.56667",
    "lng": "-69.95"
  },
  {
    "country": "PE",
    "name": "Coasa",
    "lat": "-14",
    "lng": "-69.96667"
  },
  {
    "country": "PE",
    "name": "Coalaque",
    "lat": "-16.65056",
    "lng": "-71.02139"
  },
  {
    "country": "PE",
    "name": "Circa",
    "lat": "-13.87417",
    "lng": "-72.87278"
  },
  {
    "country": "PE",
    "name": "Cieneguilla",
    "lat": "-12.13333",
    "lng": "-76.81667"
  },
  {
    "country": "PE",
    "name": "Chuschi",
    "lat": "-13.58556",
    "lng": "-74.35056"
  },
  {
    "country": "PE",
    "name": "Churcampa",
    "lat": "-12.7",
    "lng": "-74.4"
  },
  {
    "country": "PE",
    "name": "Chuquibambilla",
    "lat": "-14.10194",
    "lng": "-72.70667"
  },
  {
    "country": "PE",
    "name": "Chuquibamba",
    "lat": "-15.83806",
    "lng": "-72.65361"
  },
  {
    "country": "PE",
    "name": "Chupamarca",
    "lat": "-13.03333",
    "lng": "-75.6"
  },
  {
    "country": "PE",
    "name": "Chupaca",
    "lat": "-12.06667",
    "lng": "-75.28333"
  },
  {
    "country": "PE",
    "name": "Chupa",
    "lat": "-15.1",
    "lng": "-69.98333"
  },
  {
    "country": "PE",
    "name": "Chungui",
    "lat": "-13.21861",
    "lng": "-73.61917"
  },
  {
    "country": "PE",
    "name": "Chumpi",
    "lat": "-15.1",
    "lng": "-73.76667"
  },
  {
    "country": "PE",
    "name": "Chucatamani",
    "lat": "-17.48056",
    "lng": "-70.1225"
  },
  {
    "country": "PE",
    "name": "Chosica",
    "lat": "-11.94306",
    "lng": "-76.70944"
  },
  {
    "country": "PE",
    "name": "Chontabamba",
    "lat": "-10.58333",
    "lng": "-75.48333"
  },
  {
    "country": "PE",
    "name": "Chojata",
    "lat": "-16.4",
    "lng": "-70.73333"
  },
  {
    "country": "PE",
    "name": "Chocos",
    "lat": "-12.91417",
    "lng": "-75.86306"
  },
  {
    "country": "PE",
    "name": "Choco",
    "lat": "-15.57556",
    "lng": "-72.13"
  },
  {
    "country": "PE",
    "name": "Chivay",
    "lat": "-15.63833",
    "lng": "-71.60111"
  },
  {
    "country": "PE",
    "name": "Chipispaya",
    "lat": "-17.4979",
    "lng": "-70.21714"
  },
  {
    "country": "PE",
    "name": "Chipao",
    "lat": "-14.36611",
    "lng": "-73.87667"
  },
  {
    "country": "PE",
    "name": "Chincho",
    "lat": "-12.96667",
    "lng": "-74.36667"
  },
  {
    "country": "PE",
    "name": "Chincheros",
    "lat": "-13.51833",
    "lng": "-73.72222"
  },
  {
    "country": "PE",
    "name": "Chinchero",
    "lat": "-13.39222",
    "lng": "-72.04778"
  },
  {
    "country": "PE",
    "name": "Chinchaypujio",
    "lat": "-13.63",
    "lng": "-72.23333"
  },
  {
    "country": "PE",
    "name": "Chincha Baja",
    "lat": "-13.45894",
    "lng": "-76.16325"
  },
  {
    "country": "PE",
    "name": "Chincha Alta",
    "lat": "-13.40985",
    "lng": "-76.13235"
  },
  {
    "country": "PE",
    "name": "Chilcas",
    "lat": "-13.17139",
    "lng": "-73.90694"
  },
  {
    "country": "PE",
    "name": "Chilca",
    "lat": "-12.52111",
    "lng": "-76.73722"
  },
  {
    "country": "PE",
    "name": "Chiguata",
    "lat": "-16.4",
    "lng": "-71.4"
  },
  {
    "country": "PE",
    "name": "Chicla",
    "lat": "-11.70639",
    "lng": "-76.26833"
  },
  {
    "country": "PE",
    "name": "Chichas",
    "lat": "-15.5475",
    "lng": "-72.91861"
  },
  {
    "country": "PE",
    "name": "Chicche",
    "lat": "-12.3",
    "lng": "-75.28333"
  },
  {
    "country": "PE",
    "name": "Chiara",
    "lat": "-13.86806",
    "lng": "-73.66722"
  },
  {
    "country": "PE",
    "name": "Chiara",
    "lat": "-13.27278",
    "lng": "-74.20472"
  },
  {
    "country": "PE",
    "name": "Checca",
    "lat": "-14.47278",
    "lng": "-71.39389"
  },
  {
    "country": "PE",
    "name": "Checacupe",
    "lat": "-14.02694",
    "lng": "-71.45278"
  },
  {
    "country": "PE",
    "name": "Chaviña",
    "lat": "-14.98333",
    "lng": "-73.83333"
  },
  {
    "country": "PE",
    "name": "Chaupimarca",
    "lat": "-10.40696",
    "lng": "-76.46168"
  },
  {
    "country": "PE",
    "name": "Chasquitambo",
    "lat": "-10.3",
    "lng": "-77.6"
  },
  {
    "country": "PE",
    "name": "Charcana",
    "lat": "-15.24056",
    "lng": "-73.07111"
  },
  {
    "country": "PE",
    "name": "Characato",
    "lat": "-16.46667",
    "lng": "-71.48333"
  },
  {
    "country": "PE",
    "name": "Chapimarca",
    "lat": "-13.97528",
    "lng": "-73.065"
  },
  {
    "country": "PE",
    "name": "Changuillo",
    "lat": "-14.66417",
    "lng": "-75.22333"
  },
  {
    "country": "PE",
    "name": "Chancay",
    "lat": "-11.57139",
    "lng": "-77.26722"
  },
  {
    "country": "PE",
    "name": "Chambara",
    "lat": "-12.01667",
    "lng": "-75.38333"
  },
  {
    "country": "PE",
    "name": "Chamaca",
    "lat": "-14.30833",
    "lng": "-71.84306"
  },
  {
    "country": "PE",
    "name": "Challhuahuacho",
    "lat": "-14.11667",
    "lng": "-72.25"
  },
  {
    "country": "PE",
    "name": "Challabamba",
    "lat": "-13.20417",
    "lng": "-71.65444"
  },
  {
    "country": "PE",
    "name": "Chalhuanca",
    "lat": "-14.30056",
    "lng": "-73.23083"
  },
  {
    "country": "PE",
    "name": "Chalcos",
    "lat": "-13.84778",
    "lng": "-73.75333"
  },
  {
    "country": "PE",
    "name": "Chala",
    "lat": "-15.86583",
    "lng": "-74.24694"
  },
  {
    "country": "PE",
    "name": "Chaclacayo",
    "lat": "-11.98278",
    "lng": "-76.7675"
  },
  {
    "country": "PE",
    "name": "Chaccrampa",
    "lat": "-13.95972",
    "lng": "-73.60917"
  },
  {
    "country": "PE",
    "name": "Chacapampa",
    "lat": "-12.35",
    "lng": "-75.25"
  },
  {
    "country": "PE",
    "name": "Chacapalpa",
    "lat": "-11.73315",
    "lng": "-75.75573"
  },
  {
    "country": "PE",
    "name": "Cerro de Pasco",
    "lat": "-10.66748",
    "lng": "-76.25668"
  },
  {
    "country": "PE",
    "name": "Ccorca",
    "lat": "-13.585",
    "lng": "-72.05972"
  },
  {
    "country": "PE",
    "name": "Ccapi",
    "lat": "-13.85278",
    "lng": "-72.07917"
  },
  {
    "country": "PE",
    "name": "Cayna",
    "lat": "-10.27167",
    "lng": "-76.38889"
  },
  {
    "country": "PE",
    "name": "Cayarani",
    "lat": "-14.67222",
    "lng": "-72.02194"
  },
  {
    "country": "PE",
    "name": "Cayara",
    "lat": "-13.79472",
    "lng": "-73.98889"
  },
  {
    "country": "PE",
    "name": "Cauri",
    "lat": "-10.14167",
    "lng": "-76.62472"
  },
  {
    "country": "PE",
    "name": "Ccatca",
    "lat": "-13.60472",
    "lng": "-71.55944"
  },
  {
    "country": "PE",
    "name": "Catahuasi",
    "lat": "-12.79889",
    "lng": "-75.89194"
  },
  {
    "country": "PE",
    "name": "Castrovirreyna",
    "lat": "-13.26667",
    "lng": "-75.31667"
  },
  {
    "country": "PE",
    "name": "Carumas",
    "lat": "-16.81667",
    "lng": "-70.71667"
  },
  {
    "country": "PE",
    "name": "Carmen Alto",
    "lat": "-13.18222",
    "lng": "-74.22472"
  },
  {
    "country": "PE",
    "name": "Carhuanca",
    "lat": "-13.7425",
    "lng": "-73.78833"
  },
  {
    "country": "PE",
    "name": "Carhuamayo",
    "lat": "-10.91667",
    "lng": "-76.03333"
  },
  {
    "country": "PE",
    "name": "Carapo",
    "lat": "-13.83889",
    "lng": "-74.31194"
  },
  {
    "country": "PE",
    "name": "Carania",
    "lat": "-12.34417",
    "lng": "-75.86833"
  },
  {
    "country": "PE",
    "name": "Carampoma",
    "lat": "-11.66083",
    "lng": "-76.51444"
  },
  {
    "country": "PE",
    "name": "Caracoto",
    "lat": "-15.56667",
    "lng": "-70.1"
  },
  {
    "country": "PE",
    "name": "Carac",
    "lat": "-11.19194",
    "lng": "-76.78028"
  },
  {
    "country": "PE",
    "name": "Carabayllo",
    "lat": "-11.85333",
    "lng": "-77.03778"
  },
  {
    "country": "PE",
    "name": "Capaya",
    "lat": "-14.11944",
    "lng": "-73.31806"
  },
  {
    "country": "PE",
    "name": "Capacmarca",
    "lat": "-14.00806",
    "lng": "-71.99806"
  },
  {
    "country": "PE",
    "name": "Capachica",
    "lat": "-15.63333",
    "lng": "-69.81667"
  },
  {
    "country": "PE",
    "name": "Canta",
    "lat": "-11.46722",
    "lng": "-76.62417"
  },
  {
    "country": "PE",
    "name": "Canis",
    "lat": "-10.33899",
    "lng": "-77.16943"
  },
  {
    "country": "PE",
    "name": "Cangallo",
    "lat": "-13.62861",
    "lng": "-74.14389"
  },
  {
    "country": "PE",
    "name": "Candarave",
    "lat": "-17.26778",
    "lng": "-70.24944"
  },
  {
    "country": "PE",
    "name": "Canchayllo",
    "lat": "-11.8058",
    "lng": "-75.7165"
  },
  {
    "country": "PE",
    "name": "Canaria",
    "lat": "-13.92139",
    "lng": "-73.90528"
  },
  {
    "country": "PE",
    "name": "Caminaca",
    "lat": "-15.31667",
    "lng": "-70.06667"
  },
  {
    "country": "PE",
    "name": "Camilaca",
    "lat": "-17.26806",
    "lng": "-70.37806"
  },
  {
    "country": "PE",
    "name": "Camaná",
    "lat": "-16.62375",
    "lng": "-72.71055"
  },
  {
    "country": "PE",
    "name": "Callao",
    "lat": "-12.05659",
    "lng": "-77.11814"
  },
  {
    "country": "PE",
    "name": "Callanmarca",
    "lat": "-12.86667",
    "lng": "-74.63333"
  },
  {
    "country": "PE",
    "name": "Callalli",
    "lat": "-15.50833",
    "lng": "-71.44556"
  },
  {
    "country": "PE",
    "name": "Callahuanca",
    "lat": "-11.82833",
    "lng": "-76.61639"
  },
  {
    "country": "PE",
    "name": "Caleta de Carquín",
    "lat": "-11.0925",
    "lng": "-77.62667"
  },
  {
    "country": "PE",
    "name": "Calca",
    "lat": "-13.33333",
    "lng": "-71.95"
  },
  {
    "country": "PE",
    "name": "Calapuja",
    "lat": "-15.31667",
    "lng": "-70.21667"
  },
  {
    "country": "PE",
    "name": "Calango",
    "lat": "-12.52611",
    "lng": "-76.54278"
  },
  {
    "country": "PE",
    "name": "Calana",
    "lat": "-17.94167",
    "lng": "-70.18694"
  },
  {
    "country": "PE",
    "name": "Calacoa",
    "lat": "-16.75",
    "lng": "-70.7"
  },
  {
    "country": "PE",
    "name": "Cajacay",
    "lat": "-10.15502",
    "lng": "-77.43963"
  },
  {
    "country": "PE",
    "name": "Caja",
    "lat": "-12.88333",
    "lng": "-74.46667"
  },
  {
    "country": "PE",
    "name": "Cairani",
    "lat": "-17.28583",
    "lng": "-70.36361"
  },
  {
    "country": "PE",
    "name": "Caicay",
    "lat": "-13.595",
    "lng": "-71.69944"
  },
  {
    "country": "PE",
    "name": "Cahuacho",
    "lat": "-15.50611",
    "lng": "-73.47917"
  },
  {
    "country": "PE",
    "name": "Cacra",
    "lat": "-12.81278",
    "lng": "-75.78306"
  },
  {
    "country": "PE",
    "name": "Cachora",
    "lat": "-13.51333",
    "lng": "-72.81"
  },
  {
    "country": "PE",
    "name": "Cachimayo",
    "lat": "-13.47583",
    "lng": "-72.07222"
  },
  {
    "country": "PE",
    "name": "Cabanilla",
    "lat": "-15.61667",
    "lng": "-70.35"
  },
  {
    "country": "PE",
    "name": "Cabanaconde",
    "lat": "-15.62139",
    "lng": "-71.97889"
  },
  {
    "country": "PE",
    "name": "Cabana",
    "lat": "-15.65",
    "lng": "-70.31667"
  },
  {
    "country": "PE",
    "name": "Cabana",
    "lat": "-14.29083",
    "lng": "-73.96667"
  },
  {
    "country": "PE",
    "name": "Bolognesi",
    "lat": "-10.06444",
    "lng": "-74.005"
  },
  {
    "country": "PE",
    "name": "Barranca",
    "lat": "-10.75",
    "lng": "-77.76667"
  },
  {
    "country": "PE",
    "name": "Baños",
    "lat": "-10.07667",
    "lng": "-76.73528"
  },
  {
    "country": "PE",
    "name": "Azángaro",
    "lat": "-14.90843",
    "lng": "-70.19616"
  },
  {
    "country": "PE",
    "name": "Ayrampuni",
    "lat": "-15.05",
    "lng": "-69.88333"
  },
  {
    "country": "PE",
    "name": "Ayo",
    "lat": "-15.68167",
    "lng": "-72.27417"
  },
  {
    "country": "PE",
    "name": "Ayna",
    "lat": "-12.65",
    "lng": "-73.91667"
  },
  {
    "country": "PE",
    "name": "Ayaviri",
    "lat": "-14.88639",
    "lng": "-70.58889"
  },
  {
    "country": "PE",
    "name": "Ayacucho",
    "lat": "-13.15878",
    "lng": "-74.22321"
  },
  {
    "country": "PE",
    "name": "Aucallama",
    "lat": "-11.55778",
    "lng": "-77.18083"
  },
  {
    "country": "PE",
    "name": "Atuncolla",
    "lat": "-15.68333",
    "lng": "-70.15"
  },
  {
    "country": "PE",
    "name": "Atiquipa",
    "lat": "-15.79611",
    "lng": "-74.36361"
  },
  {
    "country": "PE",
    "name": "Atico",
    "lat": "-16.20944",
    "lng": "-73.62222"
  },
  {
    "country": "PE",
    "name": "Ataura",
    "lat": "-11.80135",
    "lng": "-75.43969"
  },
  {
    "country": "PE",
    "name": "Asquipata",
    "lat": "-14.055",
    "lng": "-73.91"
  },
  {
    "country": "PE",
    "name": "Asillo",
    "lat": "-14.78333",
    "lng": "-70.35"
  },
  {
    "country": "PE",
    "name": "Asia",
    "lat": "-12.78333",
    "lng": "-76.56667"
  },
  {
    "country": "PE",
    "name": "Arma",
    "lat": "-13.11667",
    "lng": "-75.53333"
  },
  {
    "country": "PE",
    "name": "Arequipa",
    "lat": "-16.39889",
    "lng": "-71.535"
  },
  {
    "country": "PE",
    "name": "Arapa",
    "lat": "-15.13333",
    "lng": "-70.11667"
  },
  {
    "country": "PE",
    "name": "Arahuay",
    "lat": "-11.62222",
    "lng": "-76.66944"
  },
  {
    "country": "PE",
    "name": "Aquia",
    "lat": "-10.07409",
    "lng": "-77.14423"
  },
  {
    "country": "PE",
    "name": "Apongo",
    "lat": "-14.01472",
    "lng": "-73.93306"
  },
  {
    "country": "PE",
    "name": "Aplao",
    "lat": "-16.07583",
    "lng": "-72.49389"
  },
  {
    "country": "PE",
    "name": "Apata",
    "lat": "-11.85461",
    "lng": "-75.35344"
  },
  {
    "country": "PE",
    "name": "Antauta",
    "lat": "-14.4",
    "lng": "-70.36667"
  },
  {
    "country": "PE",
    "name": "Antaparco",
    "lat": "-13.07361",
    "lng": "-74.41194"
  },
  {
    "country": "PE",
    "name": "Antabamba",
    "lat": "-14.36056",
    "lng": "-72.87556"
  },
  {
    "country": "PE",
    "name": "Anta",
    "lat": "-13.47056",
    "lng": "-72.14833"
  },
  {
    "country": "PE",
    "name": "Aniso",
    "lat": "-14.80861",
    "lng": "-73.29111"
  },
  {
    "country": "PE",
    "name": "Andaray",
    "lat": "-15.79667",
    "lng": "-72.86056"
  },
  {
    "country": "PE",
    "name": "Andarapa",
    "lat": "-13.52611",
    "lng": "-73.36611"
  },
  {
    "country": "PE",
    "name": "Andamarca",
    "lat": "-14.38722",
    "lng": "-73.96083"
  },
  {
    "country": "PE",
    "name": "Andamarca",
    "lat": "-11.73194",
    "lng": "-74.80278"
  },
  {
    "country": "PE",
    "name": "Andajes",
    "lat": "-10.79222",
    "lng": "-76.90944"
  },
  {
    "country": "PE",
    "name": "Andahuaylillas",
    "lat": "-13.6725",
    "lng": "-71.67944"
  },
  {
    "country": "PE",
    "name": "Andahuaylas",
    "lat": "-13.65556",
    "lng": "-73.38722"
  },
  {
    "country": "PE",
    "name": "Anchonga",
    "lat": "-12.88333",
    "lng": "-74.7"
  },
  {
    "country": "PE",
    "name": "Ancahuasi",
    "lat": "-13.4425",
    "lng": "-72.31083"
  },
  {
    "country": "PE",
    "name": "Ananea",
    "lat": "-14.7",
    "lng": "-69.55"
  },
  {
    "country": "PE",
    "name": "Ambo",
    "lat": "-10.13083",
    "lng": "-76.20472"
  },
  {
    "country": "PE",
    "name": "Ambar",
    "lat": "-10.73333",
    "lng": "-77.26667"
  },
  {
    "country": "PE",
    "name": "Alis",
    "lat": "-12.27861",
    "lng": "-75.78694"
  },
  {
    "country": "PE",
    "name": "El Algarrobal",
    "lat": "-17.62278",
    "lng": "-71.26778"
  },
  {
    "country": "PE",
    "name": "Alca",
    "lat": "-15.13472",
    "lng": "-72.76472"
  },
  {
    "country": "PE",
    "name": "Ajoyani",
    "lat": "-14.1",
    "lng": "-70.2"
  },
  {
    "country": "PE",
    "name": "Ayrihuanca",
    "lat": "-14.10472",
    "lng": "-72.6125"
  },
  {
    "country": "PE",
    "name": "Ahuac",
    "lat": "-12.06667",
    "lng": "-75.35"
  },
  {
    "country": "PE",
    "name": "Acos",
    "lat": "-13.95083",
    "lng": "-71.73722"
  },
  {
    "country": "PE",
    "name": "Acos",
    "lat": "-11.27361",
    "lng": "-76.82083"
  },
  {
    "country": "PE",
    "name": "Acoria",
    "lat": "-12.61667",
    "lng": "-74.88333"
  },
  {
    "country": "PE",
    "name": "Acomayo",
    "lat": "-13.91667",
    "lng": "-71.68111"
  },
  {
    "country": "PE",
    "name": "Acolla",
    "lat": "-11.73193",
    "lng": "-75.54634"
  },
  {
    "country": "PE",
    "name": "Acocro",
    "lat": "-13.21778",
    "lng": "-74.04333"
  },
  {
    "country": "PE",
    "name": "Acobambilla",
    "lat": "-12.65",
    "lng": "-75.38333"
  },
  {
    "country": "PE",
    "name": "Acobamba",
    "lat": "-12.86667",
    "lng": "-74.56667"
  },
  {
    "country": "PE",
    "name": "Acobamba",
    "lat": "-11.35252",
    "lng": "-75.66211"
  },
  {
    "country": "PE",
    "name": "Accocunca",
    "lat": "-14.76944",
    "lng": "-71.25417"
  },
  {
    "country": "PE",
    "name": "Aco",
    "lat": "-11.95707",
    "lng": "-75.36996"
  },
  {
    "country": "PE",
    "name": "Aco",
    "lat": "-10.49718",
    "lng": "-77.24149"
  },
  {
    "country": "PE",
    "name": "Achoma",
    "lat": "-15.66083",
    "lng": "-71.70083"
  },
  {
    "country": "PE",
    "name": "Achaya",
    "lat": "-15.26667",
    "lng": "-70.15"
  },
  {
    "country": "PE",
    "name": "Achanizo",
    "lat": "-15.80611",
    "lng": "-73.96694"
  },
  {
    "country": "PE",
    "name": "Accomarca",
    "lat": "-13.8",
    "lng": "-73.90306"
  },
  {
    "country": "PE",
    "name": "Accha",
    "lat": "-13.97389",
    "lng": "-71.82667"
  },
  {
    "country": "PE",
    "name": "Acas",
    "lat": "-10.45778",
    "lng": "-77.32729"
  },
  {
    "country": "PE",
    "name": "Acarí",
    "lat": "-15.42393",
    "lng": "-74.61361"
  },
  {
    "country": "PE",
    "name": "Abancay",
    "lat": "-13.63389",
    "lng": "-72.88139"
  },
  {
    "country": "PE",
    "name": "Mosoc Llacta",
    "lat": "-14.12",
    "lng": "-71.47278"
  },
  {
    "country": "PE",
    "name": "Taray",
    "lat": "-13.4275",
    "lng": "-71.8675"
  },
  {
    "country": "PE",
    "name": "Huayllati",
    "lat": "-13.92778",
    "lng": "-72.48389"
  },
  {
    "country": "PE",
    "name": "Sabaino",
    "lat": "-14.30889",
    "lng": "-72.94667"
  },
  {
    "country": "PE",
    "name": "Ayahuay",
    "lat": "-14.20778",
    "lng": "-73.06639"
  },
  {
    "country": "PE",
    "name": "Huayllo",
    "lat": "-14.1325",
    "lng": "-73.26861"
  },
  {
    "country": "PE",
    "name": "Santo Tomas",
    "lat": "-14.44556",
    "lng": "-72.08417"
  },
  {
    "country": "PE",
    "name": "Caraybamba",
    "lat": "-14.37722",
    "lng": "-73.16139"
  },
  {
    "country": "PE",
    "name": "San Antonio",
    "lat": "-14.16472",
    "lng": "-72.62111"
  },
  {
    "country": "PE",
    "name": "Curpahuasi",
    "lat": "-14.06222",
    "lng": "-72.66972"
  },
  {
    "country": "PE",
    "name": "Huarancante",
    "lat": "-15.76803",
    "lng": "-71.45952"
  },
  {
    "country": "PE",
    "name": "Ccolo",
    "lat": "-15.50611",
    "lng": "-71.49184"
  },
  {
    "country": "PE",
    "name": "Huarichancara",
    "lat": "-15.63972",
    "lng": "-71.06111"
  },
  {
    "country": "PE",
    "name": "Llongasora",
    "lat": "-15.63951",
    "lng": "-71.29921"
  },
  {
    "country": "PE",
    "name": "Jayune",
    "lat": "-15.56277",
    "lng": "-71.30312"
  },
  {
    "country": "PE",
    "name": "Chuquitira",
    "lat": "-17.28891",
    "lng": "-70.04363"
  },
  {
    "country": "PE",
    "name": "Pueblo Nuevo",
    "lat": "-17.615",
    "lng": "-71.33833"
  },
  {
    "country": "PE",
    "name": "Callanca",
    "lat": "-14.18137",
    "lng": "-71.1407"
  },
  {
    "country": "PE",
    "name": "Cullcuyre",
    "lat": "-14.09272",
    "lng": "-71.33119"
  },
  {
    "country": "PE",
    "name": "Cahuanuyo",
    "lat": "-14.34147",
    "lng": "-71.46311"
  },
  {
    "country": "PE",
    "name": "Ccaquiracunca",
    "lat": "-14.27683",
    "lng": "-71.45026"
  },
  {
    "country": "PE",
    "name": "Chignayhua",
    "lat": "-14.2461",
    "lng": "-71.44442"
  },
  {
    "country": "PE",
    "name": "Ccuntuma",
    "lat": "-14.1254",
    "lng": "-71.41216"
  },
  {
    "country": "PE",
    "name": "Lima Pampa",
    "lat": "-14.08976",
    "lng": "-71.33664"
  },
  {
    "country": "PE",
    "name": "Jayobamba",
    "lat": "-14.09425",
    "lng": "-71.33922"
  },
  {
    "country": "PE",
    "name": "Queromarca",
    "lat": "-14.18391",
    "lng": "-71.38343"
  },
  {
    "country": "PE",
    "name": "Qquea",
    "lat": "-14.05417",
    "lng": "-71.38583"
  },
  {
    "country": "PE",
    "name": "Conchopata",
    "lat": "-14.46968",
    "lng": "-71.19843"
  },
  {
    "country": "PE",
    "name": "Mosoc Cancha",
    "lat": "-14.28514",
    "lng": "-71.08773"
  },
  {
    "country": "PE",
    "name": "Huayna Alcalde",
    "lat": "-14.26989",
    "lng": "-71.09599"
  },
  {
    "country": "PE",
    "name": "Aucara",
    "lat": "-14.28083",
    "lng": "-73.97611"
  },
  {
    "country": "PE",
    "name": "Caujul",
    "lat": "-10.80528",
    "lng": "-76.97889"
  },
  {
    "country": "PE",
    "name": "Bajo Pichanaqui",
    "lat": "-10.9275",
    "lng": "-74.87417"
  },
  {
    "country": "PE",
    "name": "Huaccana",
    "lat": "-13.3875",
    "lng": "-73.68972"
  },
  {
    "country": "PE",
    "name": "Echarate",
    "lat": "-12.73513",
    "lng": "-72.61568"
  },
  {
    "country": "PE",
    "name": "Genaro Herrera",
    "lat": "-4.90741",
    "lng": "-73.66779"
  },
  {
    "country": "PE",
    "name": "Coviriali",
    "lat": "-11.2925",
    "lng": "-74.6275"
  },
  {
    "country": "PE",
    "name": "Kelluyo",
    "lat": "-16.72417",
    "lng": "-69.25556"
  },
  {
    "country": "PE",
    "name": "Providencia",
    "lat": "-6.2975",
    "lng": "-78.24"
  },
  {
    "country": "PE",
    "name": "Chalamarca",
    "lat": "-6.49139",
    "lng": "-78.46861"
  },
  {
    "country": "PE",
    "name": "Choropampa",
    "lat": "-6.4375",
    "lng": "-78.34972"
  },
  {
    "country": "PE",
    "name": "Collonce",
    "lat": "-6.28111",
    "lng": "-78.21278"
  },
  {
    "country": "PE",
    "name": "Santa Catalina",
    "lat": "-6.11167",
    "lng": "-78.06139"
  },
  {
    "country": "PE",
    "name": "Duraznopampa",
    "lat": "-6.59306",
    "lng": "-77.80806"
  },
  {
    "country": "PE",
    "name": "Matacoto",
    "lat": "-9.17833",
    "lng": "-77.74917"
  },
  {
    "country": "PE",
    "name": "Carhuac",
    "lat": "-9.26167",
    "lng": "-77.69278"
  },
  {
    "country": "PE",
    "name": "Aco",
    "lat": "-9.36917",
    "lng": "-77.56333"
  },
  {
    "country": "PE",
    "name": "Cheto",
    "lat": "-6.25639",
    "lng": "-77.70028"
  },
  {
    "country": "PE",
    "name": "Daguas",
    "lat": "-6.22667",
    "lng": "-77.74056"
  },
  {
    "country": "PE",
    "name": "Longar",
    "lat": "-6.38278",
    "lng": "-77.54528"
  },
  {
    "country": "PE",
    "name": "Cochamal",
    "lat": "-6.40639",
    "lng": "-77.58333"
  },
  {
    "country": "PE",
    "name": "Huambo",
    "lat": "-6.42806",
    "lng": "-77.53611"
  },
  {
    "country": "PE",
    "name": "Parcoy",
    "lat": "-8.03389",
    "lng": "-77.47917"
  },
  {
    "country": "PE",
    "name": "Urpay",
    "lat": "-8.34722",
    "lng": "-77.38944"
  },
  {
    "country": "PE",
    "name": "Ullulluco",
    "lat": "-8.45556",
    "lng": "-77.42667"
  },
  {
    "country": "PE",
    "name": "Challas",
    "lat": "-8.43833",
    "lng": "-77.32056"
  },
  {
    "country": "PE",
    "name": "Huancaspata",
    "lat": "-8.45667",
    "lng": "-77.29833"
  },
  {
    "country": "PE",
    "name": "Naranjos",
    "lat": "-5.74278",
    "lng": "-77.49722"
  },
  {
    "country": "PE",
    "name": "Bajo Naranjillo",
    "lat": "-5.81528",
    "lng": "-77.38278"
  },
  {
    "country": "PE",
    "name": "Nueva Cajamarca",
    "lat": "-5.94056",
    "lng": "-77.30806"
  },
  {
    "country": "PE",
    "name": "Saramiriza",
    "lat": "-4.56556",
    "lng": "-77.41583"
  },
  {
    "country": "PE",
    "name": "Nuevo Progreso",
    "lat": "-8.4525",
    "lng": "-76.32389"
  },
  {
    "country": "PE",
    "name": "San Juan",
    "lat": "-3.885",
    "lng": "-73.56722"
  },
  {
    "country": "PE",
    "name": "Yanahuanca",
    "lat": "-10.49139",
    "lng": "-76.51667"
  },
  {
    "country": "PE",
    "name": "Huabal",
    "lat": "-5.61611",
    "lng": "-78.92333"
  },
  {
    "country": "PE",
    "name": "Buenos Aires",
    "lat": "-9.12417",
    "lng": "-78.4975"
  },
  {
    "country": "PE",
    "name": "Yuyapichis",
    "lat": "-9.62732",
    "lng": "-74.97658"
  },
  {
    "country": "PE",
    "name": "Pampamarca",
    "lat": "-9.70553",
    "lng": "-76.70206"
  },
  {
    "country": "PE",
    "name": "Llata",
    "lat": "-9.54999",
    "lng": "-76.81613"
  },
  {
    "country": "PE",
    "name": "Jacas Grande",
    "lat": "-9.53965",
    "lng": "-76.73639"
  },
  {
    "country": "PE",
    "name": "Cayhuayna",
    "lat": "-9.95851",
    "lng": "-76.24853"
  },
  {
    "country": "PE",
    "name": "Huancapallac",
    "lat": "-9.89412",
    "lng": "-76.41455"
  },
  {
    "country": "PE",
    "name": "Paucarbamba",
    "lat": "-9.94459",
    "lng": "-76.22323"
  },
  {
    "country": "PE",
    "name": "El Rosario",
    "lat": "-11.78531",
    "lng": "-75.67408"
  },
  {
    "country": "PE",
    "name": "Masma Chicche",
    "lat": "-11.78593",
    "lng": "-75.37849"
  },
  {
    "country": "PE",
    "name": "Sausa",
    "lat": "-11.79319",
    "lng": "-75.48414"
  },
  {
    "country": "PE",
    "name": "Huertas",
    "lat": "-11.768",
    "lng": "-75.47441"
  },
  {
    "country": "PE",
    "name": "Mucllo",
    "lat": "-11.61607",
    "lng": "-75.09115"
  },
  {
    "country": "PE",
    "name": "Masma",
    "lat": "-11.78509",
    "lng": "-75.42597"
  },
  {
    "country": "PE",
    "name": "Matahuasi",
    "lat": "-11.89161",
    "lng": "-75.3435"
  },
  {
    "country": "PE",
    "name": "Hualhuas",
    "lat": "-11.97147",
    "lng": "-75.25065"
  },
  {
    "country": "PE",
    "name": "Saño",
    "lat": "-11.95671",
    "lng": "-75.25685"
  },
  {
    "country": "PE",
    "name": "Quilcas",
    "lat": "-11.93581",
    "lng": "-75.25959"
  },
  {
    "country": "PE",
    "name": "Quichuay",
    "lat": "-11.88982",
    "lng": "-75.28571"
  },
  {
    "country": "PE",
    "name": "Rapayan",
    "lat": "-9.20273",
    "lng": "-76.75967"
  },
  {
    "country": "PE",
    "name": "Anra",
    "lat": "-9.2329",
    "lng": "-76.92328"
  },
  {
    "country": "PE",
    "name": "Cochabamba",
    "lat": "-9.09536",
    "lng": "-76.83688"
  },
  {
    "country": "PE",
    "name": "San Pedro De Cachora",
    "lat": "-13.63333",
    "lng": "-72.88333"
  },
  {
    "country": "PE",
    "name": "Ledoy",
    "lat": "-7.12823",
    "lng": "-76.65018"
  },
  {
    "country": "PE",
    "name": "Pajarillo",
    "lat": "-7.18298",
    "lng": "-76.6933"
  },
  {
    "country": "PE",
    "name": "Shatoja",
    "lat": "-6.52821",
    "lng": "-76.71823"
  },
  {
    "country": "PE",
    "name": "La Rinconada",
    "lat": "-14.63126",
    "lng": "-69.44638"
  },
  {
    "country": "PE",
    "name": "Urb. Santo Domingo",
    "lat": "-11.87655",
    "lng": "-77.03345"
  },
  {
    "country": "PE",
    "name": "Indiana",
    "lat": "-3.49989",
    "lng": "-73.05136"
  },
  {
    "country": "PF",
    "name": "Atuona",
    "lat": "-9.80342",
    "lng": "-139.04202"
  },
  {
    "country": "PF",
    "name": "Rikitea",
    "lat": "-23.12028",
    "lng": "-134.96917"
  },
  {
    "country": "PF",
    "name": "Vaitape",
    "lat": "-16.50741",
    "lng": "-151.74913"
  },
  {
    "country": "PF",
    "name": "Vairao",
    "lat": "-17.78333",
    "lng": "-149.28333"
  },
  {
    "country": "PF",
    "name": "Uturoa",
    "lat": "-16.72891",
    "lng": "-151.44482"
  },
  {
    "country": "PF",
    "name": "Tohautu",
    "lat": "-17.75",
    "lng": "-149.31667"
  },
  {
    "country": "PF",
    "name": "Tiarei",
    "lat": "-17.53333",
    "lng": "-149.33333"
  },
  {
    "country": "PF",
    "name": "Tevaitoa",
    "lat": "-16.79139",
    "lng": "-151.48893"
  },
  {
    "country": "PF",
    "name": "Teavaro",
    "lat": "-17.5",
    "lng": "-149.76667"
  },
  {
    "country": "PF",
    "name": "Teahupoo",
    "lat": "-17.83333",
    "lng": "-149.26667"
  },
  {
    "country": "PF",
    "name": "Tautira",
    "lat": "-17.73333",
    "lng": "-149.15"
  },
  {
    "country": "PF",
    "name": "Taunoa",
    "lat": "-17.75",
    "lng": "-149.35"
  },
  {
    "country": "PF",
    "name": "Punaauia",
    "lat": "-17.63333",
    "lng": "-149.6"
  },
  {
    "country": "PF",
    "name": "Pueu",
    "lat": "-17.73333",
    "lng": "-149.21667"
  },
  {
    "country": "PF",
    "name": "Pirae",
    "lat": "-17.51667",
    "lng": "-149.53333"
  },
  {
    "country": "PF",
    "name": "Papetoai",
    "lat": "-17.49538",
    "lng": "-149.87437"
  },
  {
    "country": "PF",
    "name": "Papeete",
    "lat": "-17.53733",
    "lng": "-149.5665"
  },
  {
    "country": "PF",
    "name": "Papao",
    "lat": "-17.75",
    "lng": "-149.55"
  },
  {
    "country": "PF",
    "name": "Paopao",
    "lat": "-17.51863",
    "lng": "-149.82193"
  },
  {
    "country": "PF",
    "name": "Paea",
    "lat": "-17.68333",
    "lng": "-149.58333"
  },
  {
    "country": "PF",
    "name": "Otutara",
    "lat": "-17.76667",
    "lng": "-149.41667"
  },
  {
    "country": "PF",
    "name": "Moerai",
    "lat": "-22.45133",
    "lng": "-151.34191"
  },
  {
    "country": "PF",
    "name": "Mahina",
    "lat": "-17.50648",
    "lng": "-149.48899"
  },
  {
    "country": "PF",
    "name": "Hitiaa",
    "lat": "-17.6",
    "lng": "-149.3"
  },
  {
    "country": "PF",
    "name": "Haapiti",
    "lat": "-17.56352",
    "lng": "-149.86905"
  },
  {
    "country": "PF",
    "name": "Fitii",
    "lat": "-16.73535",
    "lng": "-151.0327"
  },
  {
    "country": "PF",
    "name": "Fare",
    "lat": "-16.71085",
    "lng": "-151.03455"
  },
  {
    "country": "PF",
    "name": "Faaone",
    "lat": "-17.66667",
    "lng": "-149.3"
  },
  {
    "country": "PF",
    "name": "Faanui",
    "lat": "-16.48679",
    "lng": "-151.74102"
  },
  {
    "country": "PF",
    "name": "Faaa",
    "lat": "-17.55",
    "lng": "-149.6"
  },
  {
    "country": "PF",
    "name": "Arue",
    "lat": "-17.51667",
    "lng": "-149.5"
  },
  {
    "country": "PF",
    "name": "Anau",
    "lat": "-16.51667",
    "lng": "-151.73333"
  },
  {
    "country": "PF",
    "name": "Afareaitu",
    "lat": "-17.55",
    "lng": "-149.78333"
  },
  {
    "country": "PF",
    "name": "Afaahiti",
    "lat": "-17.74395",
    "lng": "-149.32444"
  },
  {
    "country": "PF",
    "name": "Taiohae",
    "lat": "-8.91093",
    "lng": "-140.09972"
  },
  {
    "country": "PF",
    "name": "Tapuarava",
    "lat": "-18.46647",
    "lng": "-136.46328"
  },
  {
    "country": "PG",
    "name": "Wewak",
    "lat": "-3.54964",
    "lng": "143.63229"
  },
  {
    "country": "PG",
    "name": "Wau",
    "lat": "-7.33778",
    "lng": "146.71649"
  },
  {
    "country": "PG",
    "name": "Wabag",
    "lat": "-5.49119",
    "lng": "143.72151"
  },
  {
    "country": "PG",
    "name": "Vanimo",
    "lat": "-2.68372",
    "lng": "141.30195"
  },
  {
    "country": "PG",
    "name": "Tari",
    "lat": "-5.9022",
    "lng": "142.93511"
  },
  {
    "country": "PG",
    "name": "Rabaul",
    "lat": "-4.20037",
    "lng": "152.16297"
  },
  {
    "country": "PG",
    "name": "Port Moresby",
    "lat": "-9.44314",
    "lng": "147.17972"
  },
  {
    "country": "PG",
    "name": "Porgera",
    "lat": "-5.463",
    "lng": "143.148"
  },
  {
    "country": "PG",
    "name": "Popondetta",
    "lat": "-8.76536",
    "lng": "148.23252"
  },
  {
    "country": "PG",
    "name": "Panguna",
    "lat": "-6.31639",
    "lng": "155.48483"
  },
  {
    "country": "PG",
    "name": "Mount Hagen",
    "lat": "-5.85746",
    "lng": "144.23058"
  },
  {
    "country": "PG",
    "name": "Morehead",
    "lat": "-8.71065",
    "lng": "141.63668"
  },
  {
    "country": "PG",
    "name": "Minj",
    "lat": "-5.90752",
    "lng": "144.69159"
  },
  {
    "country": "PG",
    "name": "Mendi",
    "lat": "-6.14755",
    "lng": "143.65633"
  },
  {
    "country": "PG",
    "name": "Madang",
    "lat": "-5.22152",
    "lng": "145.78695"
  },
  {
    "country": "PG",
    "name": "Lorengau",
    "lat": "-2.0341",
    "lng": "147.27173"
  },
  {
    "country": "PG",
    "name": "Lae",
    "lat": "-6.72208",
    "lng": "146.98469"
  },
  {
    "country": "PG",
    "name": "Kwikila",
    "lat": "-9.81847",
    "lng": "147.65968"
  },
  {
    "country": "PG",
    "name": "Kundiawa",
    "lat": "-6.01667",
    "lng": "144.96667"
  },
  {
    "country": "PG",
    "name": "Kokopo",
    "lat": "-4.35202",
    "lng": "152.26327"
  },
  {
    "country": "PG",
    "name": "Kokoda",
    "lat": "-8.87778",
    "lng": "147.73642"
  },
  {
    "country": "PG",
    "name": "Kiunga",
    "lat": "-6.12193",
    "lng": "141.29061"
  },
  {
    "country": "PG",
    "name": "Kimbe",
    "lat": "-5.55085",
    "lng": "150.13766"
  },
  {
    "country": "PG",
    "name": "Kieta",
    "lat": "-6.21667",
    "lng": "155.63333"
  },
  {
    "country": "PG",
    "name": "Kerema",
    "lat": "-7.96309",
    "lng": "145.77851"
  },
  {
    "country": "PG",
    "name": "Kavieng",
    "lat": "-2.57783",
    "lng": "150.80727"
  },
  {
    "country": "PG",
    "name": "Kandrian",
    "lat": "-6.2043",
    "lng": "149.53568"
  },
  {
    "country": "PG",
    "name": "Kainantu",
    "lat": "-6.28872",
    "lng": "145.86548"
  },
  {
    "country": "PG",
    "name": "Ihu",
    "lat": "-7.89569",
    "lng": "145.39405"
  },
  {
    "country": "PG",
    "name": "Ialibu",
    "lat": "-6.28208",
    "lng": "143.99354"
  },
  {
    "country": "PG",
    "name": "Goroka",
    "lat": "-6.08336",
    "lng": "145.38735"
  },
  {
    "country": "PG",
    "name": "Finschhafen",
    "lat": "-6.60243",
    "lng": "147.86814"
  },
  {
    "country": "PG",
    "name": "Daru",
    "lat": "-9.07786",
    "lng": "143.20893"
  },
  {
    "country": "PG",
    "name": "Bulolo",
    "lat": "-7.2036",
    "lng": "146.64014"
  },
  {
    "country": "PG",
    "name": "Arawa",
    "lat": "-6.22977",
    "lng": "155.56598"
  },
  {
    "country": "PG",
    "name": "Angoram",
    "lat": "-4.06253",
    "lng": "144.06609"
  },
  {
    "country": "PG",
    "name": "Ambunti",
    "lat": "-4.21717",
    "lng": "142.81832"
  },
  {
    "country": "PG",
    "name": "Aitape",
    "lat": "-3.13697",
    "lng": "142.34913"
  },
  {
    "country": "PG",
    "name": "Samarai",
    "lat": "-10.61038",
    "lng": "150.66207"
  },
  {
    "country": "PG",
    "name": "Alotau",
    "lat": "-10.31509",
    "lng": "150.45742"
  },
  {
    "country": "PG",
    "name": "Buka",
    "lat": "-5.43261",
    "lng": "154.67098"
  },
  {
    "country": "PG",
    "name": "Rauna",
    "lat": "-5.7359",
    "lng": "144.28834"
  },
  {
    "country": "PH",
    "name": "Zumarraga",
    "lat": "11.6388",
    "lng": "124.8417"
  },
  {
    "country": "PH",
    "name": "Zarraga",
    "lat": "10.81972",
    "lng": "122.60806"
  },
  {
    "country": "PH",
    "name": "Zaragoza",
    "lat": "16.3871",
    "lng": "119.9443"
  },
  {
    "country": "PH",
    "name": "Zamboanguita",
    "lat": "9.1025",
    "lng": "123.1996"
  },
  {
    "country": "PH",
    "name": "Zamboanga",
    "lat": "6.91028",
    "lng": "122.07389"
  },
  {
    "country": "PH",
    "name": "Yumbing",
    "lat": "9.2393",
    "lng": "124.6578"
  },
  {
    "country": "PH",
    "name": "Yubo",
    "lat": "10.3896",
    "lng": "123.069"
  },
  {
    "country": "PH",
    "name": "Yook",
    "lat": "13.22608",
    "lng": "121.964"
  },
  {
    "country": "PH",
    "name": "Ilaya",
    "lat": "5.81528",
    "lng": "125.22667"
  },
  {
    "country": "PH",
    "name": "Yeban Norte",
    "lat": "17.02195",
    "lng": "121.94194"
  },
  {
    "country": "PH",
    "name": "Wright",
    "lat": "11.77028",
    "lng": "125.02194"
  },
  {
    "country": "PH",
    "name": "Wines",
    "lat": "7.19389",
    "lng": "125.38917"
  },
  {
    "country": "PH",
    "name": "Wawa",
    "lat": "14.3019",
    "lng": "121.4595"
  },
  {
    "country": "PH",
    "name": "Wawa",
    "lat": "13.7401",
    "lng": "121.0529"
  },
  {
    "country": "PH",
    "name": "Wawa",
    "lat": "13.4632",
    "lng": "120.7441"
  },
  {
    "country": "PH",
    "name": "Wao",
    "lat": "7.68333",
    "lng": "124.66667"
  },
  {
    "country": "PH",
    "name": "Wañgan",
    "lat": "7.15972",
    "lng": "125.44528"
  },
  {
    "country": "PH",
    "name": "Vizal Santo Niño",
    "lat": "15.02924",
    "lng": "120.90505"
  },
  {
    "country": "PH",
    "name": "Vizal San Pablo",
    "lat": "15.06247",
    "lng": "120.90021"
  },
  {
    "country": "PH",
    "name": "Vito",
    "lat": "10.9031",
    "lng": "123.5154"
  },
  {
    "country": "PH",
    "name": "Vitali",
    "lat": "7.37111",
    "lng": "122.28861"
  },
  {
    "country": "PH",
    "name": "Vista Alegre",
    "lat": "9.9984",
    "lng": "122.7663"
  },
  {
    "country": "PH",
    "name": "Viriato",
    "lat": "12.29031",
    "lng": "124.35333"
  },
  {
    "country": "PH",
    "name": "Virac",
    "lat": "13.5848",
    "lng": "124.2374"
  },
  {
    "country": "PH",
    "name": "Vinzons",
    "lat": "14.1737",
    "lng": "122.9066"
  },
  {
    "country": "PH",
    "name": "Vintar",
    "lat": "18.2284",
    "lng": "120.6475"
  },
  {
    "country": "PH",
    "name": "Villaviciosa",
    "lat": "17.4379",
    "lng": "120.6262"
  },
  {
    "country": "PH",
    "name": "Villa Verde",
    "lat": "16.59888",
    "lng": "121.18774"
  },
  {
    "country": "PH",
    "name": "Villasis",
    "lat": "15.90167",
    "lng": "120.58833"
  },
  {
    "country": "PH",
    "name": "Villarosa",
    "lat": "15.55",
    "lng": "120.75"
  },
  {
    "country": "PH",
    "name": "Villareal",
    "lat": "11.5659",
    "lng": "124.9281"
  },
  {
    "country": "PH",
    "name": "Villanueva",
    "lat": "15.79841",
    "lng": "120.54654"
  },
  {
    "country": "PH",
    "name": "Villanueva",
    "lat": "8.58889",
    "lng": "124.77556"
  },
  {
    "country": "PH",
    "name": "Villamor",
    "lat": "6.7038",
    "lng": "124.52009"
  },
  {
    "country": "PH",
    "name": "Villa Isla",
    "lat": "15.7703",
    "lng": "120.8666"
  },
  {
    "country": "PH",
    "name": "Villahermosa",
    "lat": "13.0458",
    "lng": "123.7133"
  },
  {
    "country": "PH",
    "name": "Villaba",
    "lat": "11.2135",
    "lng": "124.3921"
  },
  {
    "country": "PH",
    "name": "Villa Aglipay",
    "lat": "15.46605",
    "lng": "120.45273"
  },
  {
    "country": "PH",
    "name": "Vigo",
    "lat": "13.82666",
    "lng": "120.17922"
  },
  {
    "country": "PH",
    "name": "Viga",
    "lat": "12.5162",
    "lng": "125.0528"
  },
  {
    "country": "PH",
    "name": "Vigan",
    "lat": "17.57472",
    "lng": "120.38694"
  },
  {
    "country": "PH",
    "name": "Biga",
    "lat": "13.90401",
    "lng": "120.64875"
  },
  {
    "country": "PH",
    "name": "Viga",
    "lat": "13.8719",
    "lng": "124.3091"
  },
  {
    "country": "PH",
    "name": "Victorias",
    "lat": "10.90154",
    "lng": "123.0705"
  },
  {
    "country": "PH",
    "name": "Victoria",
    "lat": "15.5775",
    "lng": "120.6822"
  },
  {
    "country": "PH",
    "name": "Victoria",
    "lat": "14.2277",
    "lng": "121.3292"
  },
  {
    "country": "PH",
    "name": "Victoria",
    "lat": "13.17722",
    "lng": "121.27806"
  },
  {
    "country": "PH",
    "name": "Victoria",
    "lat": "12.44722",
    "lng": "124.31111"
  },
  {
    "country": "PH",
    "name": "Biay",
    "lat": "15.7402",
    "lng": "119.9067"
  },
  {
    "country": "PH",
    "name": "Veruela",
    "lat": "8.0731",
    "lng": "125.9558"
  },
  {
    "country": "PH",
    "name": "Vargas",
    "lat": "15.59332",
    "lng": "120.48709"
  },
  {
    "country": "PH",
    "name": "Vallehermoso",
    "lat": "10.3349",
    "lng": "123.3259"
  },
  {
    "country": "PH",
    "name": "Valle Hermoso",
    "lat": "9.7939",
    "lng": "124.2365"
  },
  {
    "country": "PH",
    "name": "Valladolid",
    "lat": "10.4616",
    "lng": "122.8245"
  },
  {
    "country": "PH",
    "name": "Valenzuela",
    "lat": "14.7",
    "lng": "120.9667"
  },
  {
    "country": "PH",
    "name": "Valencia",
    "lat": "11.10889",
    "lng": "124.5725"
  },
  {
    "country": "PH",
    "name": "East Valencia",
    "lat": "10.668",
    "lng": "122.71"
  },
  {
    "country": "PH",
    "name": "Valencia",
    "lat": "10.136",
    "lng": "123.6126"
  },
  {
    "country": "PH",
    "name": "Valencia",
    "lat": "9.77158",
    "lng": "123.36742"
  },
  {
    "country": "PH",
    "name": "Valencia",
    "lat": "9.6097",
    "lng": "124.208"
  },
  {
    "country": "PH",
    "name": "Valencia",
    "lat": "9.2815",
    "lng": "123.2455"
  },
  {
    "country": "PH",
    "name": "NIA Valencia",
    "lat": "7.90639",
    "lng": "125.09417"
  },
  {
    "country": "PH",
    "name": "Valderrama",
    "lat": "11.40591",
    "lng": "122.08371"
  },
  {
    "country": "PH",
    "name": "Uyugan",
    "lat": "20.35045",
    "lng": "121.93777"
  },
  {
    "country": "PH",
    "name": "Uyong",
    "lat": "16.05002",
    "lng": "120.12074"
  },
  {
    "country": "PH",
    "name": "Uyaan",
    "lat": "7.86306",
    "lng": "124.04111"
  },
  {
    "country": "PH",
    "name": "Uson",
    "lat": "12.2253",
    "lng": "123.7834"
  },
  {
    "country": "PH",
    "name": "Usab",
    "lat": "12.32974",
    "lng": "123.58091"
  },
  {
    "country": "PH",
    "name": "Urdaneta",
    "lat": "15.97611",
    "lng": "120.57111"
  },
  {
    "country": "PH",
    "name": "Urbiztondo",
    "lat": "15.8227",
    "lng": "120.3295"
  },
  {
    "country": "PH",
    "name": "Upper San Mateo",
    "lat": "7.17306",
    "lng": "124.58222"
  },
  {
    "country": "PH",
    "name": "Upper Klinan",
    "lat": "6.22722",
    "lng": "125.12083"
  },
  {
    "country": "PH",
    "name": "Upig",
    "lat": "15.02551",
    "lng": "120.99193"
  },
  {
    "country": "PH",
    "name": "Upi",
    "lat": "17.08262",
    "lng": "121.83453"
  },
  {
    "country": "PH",
    "name": "Upi",
    "lat": "7.02583",
    "lng": "124.16667"
  },
  {
    "country": "PH",
    "name": "Unzad",
    "lat": "15.91889",
    "lng": "120.53917"
  },
  {
    "country": "PH",
    "name": "Unisan",
    "lat": "13.84132",
    "lng": "121.97522"
  },
  {
    "country": "PH",
    "name": "Union",
    "lat": "11.7612",
    "lng": "121.8963"
  },
  {
    "country": "PH",
    "name": "Union",
    "lat": "10.6695",
    "lng": "124.3252"
  },
  {
    "country": "PH",
    "name": "Union",
    "lat": "10.0475",
    "lng": "124.5151"
  },
  {
    "country": "PH",
    "name": "Union",
    "lat": "9.75667",
    "lng": "126.11028"
  },
  {
    "country": "PH",
    "name": "Unidos",
    "lat": "11.90677",
    "lng": "122.00051"
  },
  {
    "country": "PH",
    "name": "Unidos",
    "lat": "8.5942",
    "lng": "123.668"
  },
  {
    "country": "PH",
    "name": "Unidad",
    "lat": "8.53556",
    "lng": "126.22865"
  },
  {
    "country": "PH",
    "name": "Ungca",
    "lat": "10.75",
    "lng": "122.55"
  },
  {
    "country": "PH",
    "name": "Umiray",
    "lat": "15.2206",
    "lng": "121.4111"
  },
  {
    "country": "PH",
    "name": "Umingan",
    "lat": "15.90021",
    "lng": "120.79841"
  },
  {
    "country": "PH",
    "name": "Umanday Centro",
    "lat": "15.938",
    "lng": "120.2153"
  },
  {
    "country": "PH",
    "name": "Umaganhan",
    "lat": "11.3292",
    "lng": "124.377"
  },
  {
    "country": "PH",
    "name": "Umabay",
    "lat": "12.30954",
    "lng": "123.67961"
  },
  {
    "country": "PH",
    "name": "Uling",
    "lat": "10.28048",
    "lng": "123.71"
  },
  {
    "country": "PH",
    "name": "Ula",
    "lat": "7.13222",
    "lng": "125.49222"
  },
  {
    "country": "PH",
    "name": "Ugad",
    "lat": "17.3075",
    "lng": "121.80042"
  },
  {
    "country": "PH",
    "name": "Ugac Sur",
    "lat": "17.61325",
    "lng": "121.71583"
  },
  {
    "country": "PH",
    "name": "Uddiawan",
    "lat": "16.55888",
    "lng": "121.15124"
  },
  {
    "country": "PH",
    "name": "Odala",
    "lat": "13.4776",
    "lng": "120.8223"
  },
  {
    "country": "PH",
    "name": "Ubay",
    "lat": "10.056",
    "lng": "124.47294"
  },
  {
    "country": "PH",
    "name": "Ualog",
    "lat": "10.57396",
    "lng": "123.3933"
  },
  {
    "country": "PH",
    "name": "Uacon",
    "lat": "15.6787",
    "lng": "119.9403"
  },
  {
    "country": "PH",
    "name": "Tuyum",
    "lat": "9.9769",
    "lng": "122.5582"
  },
  {
    "country": "PH",
    "name": "Tuyan",
    "lat": "6",
    "lng": "125.28333"
  },
  {
    "country": "PH",
    "name": "Tuy",
    "lat": "14.0183",
    "lng": "120.7296"
  },
  {
    "country": "PH",
    "name": "Tutubigan",
    "lat": "11.83972",
    "lng": "125.06139"
  },
  {
    "country": "PH",
    "name": "Tutay",
    "lat": "10.2463",
    "lng": "123.5805"
  },
  {
    "country": "PH",
    "name": "Tupsan",
    "lat": "9.19917",
    "lng": "124.77694"
  },
  {
    "country": "PH",
    "name": "Tupi",
    "lat": "6.33444",
    "lng": "124.95278"
  },
  {
    "country": "PH",
    "name": "Tupang",
    "lat": "17.90483",
    "lng": "121.64099"
  },
  {
    "country": "PH",
    "name": "Tuod",
    "lat": "8.34333",
    "lng": "124.35417"
  },
  {
    "country": "PH",
    "name": "Tungol",
    "lat": "7.08083",
    "lng": "124.75306"
  },
  {
    "country": "PH",
    "name": "Tungawan",
    "lat": "7.50806",
    "lng": "122.37111"
  },
  {
    "country": "PH",
    "name": "Tungao",
    "lat": "8.78368",
    "lng": "125.59587"
  },
  {
    "country": "PH",
    "name": "Tunga",
    "lat": "11.24556",
    "lng": "124.75167"
  },
  {
    "country": "PH",
    "name": "Tumcon Ilawod",
    "lat": "10.91667",
    "lng": "122.66667"
  },
  {
    "country": "PH",
    "name": "Tumbagaan",
    "lat": "5.3656",
    "lng": "120.3139"
  },
  {
    "country": "PH",
    "name": "Tumauini",
    "lat": "17.27663",
    "lng": "121.80854"
  },
  {
    "country": "PH",
    "name": "Tumarbong",
    "lat": "10.37659",
    "lng": "119.4579"
  },
  {
    "country": "PH",
    "name": "Tumalim",
    "lat": "14.0801",
    "lng": "120.7231"
  },
  {
    "country": "PH",
    "name": "Tumalaytay",
    "lat": "12.27584",
    "lng": "123.23201"
  },
  {
    "country": "PH",
    "name": "Tulunan",
    "lat": "6.83444",
    "lng": "124.87694"
  },
  {
    "country": "PH",
    "name": "Tuli",
    "lat": "7.23333",
    "lng": "125.41667"
  },
  {
    "country": "PH",
    "name": "Tulay na Lupa",
    "lat": "14.0934",
    "lng": "122.7862"
  },
  {
    "country": "PH",
    "name": "Tulay",
    "lat": "14.26969",
    "lng": "120.76925"
  },
  {
    "country": "PH",
    "name": "Tucuran",
    "lat": "7.8524",
    "lng": "123.5743"
  },
  {
    "country": "PH",
    "name": "Tuhian",
    "lat": "13.6222",
    "lng": "122.2178"
  },
  {
    "country": "PH",
    "name": "Tuguegarao",
    "lat": "17.61577",
    "lng": "121.72285"
  },
  {
    "country": "PH",
    "name": "Tugos",
    "lat": "14.26667",
    "lng": "122.75"
  },
  {
    "country": "PH",
    "name": "Tugdan",
    "lat": "12.3134",
    "lng": "122.0853"
  },
  {
    "country": "PH",
    "name": "Tugbong",
    "lat": "11.01667",
    "lng": "124.6"
  },
  {
    "country": "PH",
    "name": "Tuganay",
    "lat": "7.36889",
    "lng": "125.72306"
  },
  {
    "country": "PH",
    "name": "Tuding",
    "lat": "16.41085",
    "lng": "120.6422"
  },
  {
    "country": "PH",
    "name": "Tudela",
    "lat": "10.6383",
    "lng": "124.47287"
  },
  {
    "country": "PH",
    "name": "Tudela",
    "lat": "8.2472",
    "lng": "123.8424"
  },
  {
    "country": "PH",
    "name": "Tucdao",
    "lat": "11.7011",
    "lng": "124.4719"
  },
  {
    "country": "PH",
    "name": "Tuburan",
    "lat": "13.2417",
    "lng": "123.55203"
  },
  {
    "country": "PH",
    "name": "Tuburan",
    "lat": "10.7273",
    "lng": "123.8257"
  },
  {
    "country": "PH",
    "name": "Tuburan",
    "lat": "6.64389",
    "lng": "122.27361"
  },
  {
    "country": "PH",
    "name": "Tubungan",
    "lat": "10.76405",
    "lng": "122.3177"
  },
  {
    "country": "PH",
    "name": "Tubod-dugoan",
    "lat": "10.0443",
    "lng": "123.4994"
  },
  {
    "country": "PH",
    "name": "Tubod",
    "lat": "9.99625",
    "lng": "123.57252"
  },
  {
    "country": "PH",
    "name": "Tubod",
    "lat": "9.5625",
    "lng": "125.57083"
  },
  {
    "country": "PH",
    "name": "Tubod",
    "lat": "8.0555",
    "lng": "123.7904"
  },
  {
    "country": "PH",
    "name": "Tubod",
    "lat": "7.37167",
    "lng": "125.64472"
  },
  {
    "country": "PH",
    "name": "Tubli",
    "lat": "13.9318",
    "lng": "124.1478"
  },
  {
    "country": "PH",
    "name": "Tublay",
    "lat": "16.5431",
    "lng": "120.6096"
  },
  {
    "country": "PH",
    "name": "Tibigan",
    "lat": "9.9518",
    "lng": "123.9622"
  },
  {
    "country": "PH",
    "name": "Tubigan",
    "lat": "8.53222",
    "lng": "124.31222"
  },
  {
    "country": "PH",
    "name": "Tubigagmanoc",
    "lat": "10.6282",
    "lng": "123.7489"
  },
  {
    "country": "PH",
    "name": "Tubay",
    "lat": "9.16694",
    "lng": "125.52389"
  },
  {
    "country": "PH",
    "name": "Tubaran",
    "lat": "7.76667",
    "lng": "124.16667"
  },
  {
    "country": "PH",
    "name": "Tubao",
    "lat": "16.3482",
    "lng": "120.4122"
  },
  {
    "country": "PH",
    "name": "Tuban",
    "lat": "12.8122",
    "lng": "120.8323"
  },
  {
    "country": "PH",
    "name": "Tuban",
    "lat": "6.82278",
    "lng": "125.38694"
  },
  {
    "country": "PH",
    "name": "Tubalan",
    "lat": "6.495",
    "lng": "125.56611"
  },
  {
    "country": "PH",
    "name": "Tubajon",
    "lat": "10.33167",
    "lng": "125.56194"
  },
  {
    "country": "PH",
    "name": "Tuba",
    "lat": "16.31709",
    "lng": "120.54924"
  },
  {
    "country": "PH",
    "name": "Tuao",
    "lat": "17.73641",
    "lng": "121.45635"
  },
  {
    "country": "PH",
    "name": "Tuao",
    "lat": "16.58833",
    "lng": "121.25778"
  },
  {
    "country": "PH",
    "name": "Sabang",
    "lat": "12.0746",
    "lng": "124.5414"
  },
  {
    "country": "PH",
    "name": "Trinidad",
    "lat": "10.07955",
    "lng": "124.34324"
  },
  {
    "country": "PH",
    "name": "Trento",
    "lat": "8.04583",
    "lng": "126.06361"
  },
  {
    "country": "PH",
    "name": "Trapiche",
    "lat": "10.68417",
    "lng": "122.43222"
  },
  {
    "country": "PH",
    "name": "Tranca",
    "lat": "14.11815",
    "lng": "121.05741"
  },
  {
    "country": "PH",
    "name": "Tran",
    "lat": "6.72028",
    "lng": "124.055"
  },
  {
    "country": "PH",
    "name": "Totolan",
    "lat": "9.63286",
    "lng": "123.84702"
  },
  {
    "country": "PH",
    "name": "Tortosa",
    "lat": "10.93294",
    "lng": "123.09"
  },
  {
    "country": "PH",
    "name": "Torrijos",
    "lat": "13.31676",
    "lng": "122.08205"
  },
  {
    "country": "PH",
    "name": "Toritori",
    "lat": "16.23827",
    "lng": "119.99561"
  },
  {
    "country": "PH",
    "name": "Topdac",
    "lat": "16.5553",
    "lng": "120.7116"
  },
  {
    "country": "PH",
    "name": "Toong",
    "lat": "14.07063",
    "lng": "120.76333"
  },
  {
    "country": "PH",
    "name": "Tongouson",
    "lat": "5.0214",
    "lng": "120.1328"
  },
  {
    "country": "PH",
    "name": "Tondol",
    "lat": "16.3104",
    "lng": "120.0131"
  },
  {
    "country": "PH",
    "name": "Tondod",
    "lat": "15.7182",
    "lng": "120.968"
  },
  {
    "country": "PH",
    "name": "Tominhao",
    "lat": "11.23563",
    "lng": "124.03526"
  },
  {
    "country": "PH",
    "name": "Tomingad",
    "lat": "12.44311",
    "lng": "122.02106"
  },
  {
    "country": "PH",
    "name": "Tombod",
    "lat": "15.93168",
    "lng": "120.56721"
  },
  {
    "country": "PH",
    "name": "Tamayong",
    "lat": "7.13306",
    "lng": "125.37972"
  },
  {
    "country": "PH",
    "name": "Tomas Oppus",
    "lat": "10.25056",
    "lng": "124.98306"
  },
  {
    "country": "PH",
    "name": "Tomado",
    "lat": "7.1925",
    "lng": "124.60806"
  },
  {
    "country": "PH",
    "name": "Tolosa",
    "lat": "11.1",
    "lng": "125.01667"
  },
  {
    "country": "PH",
    "name": "Toledo",
    "lat": "10.3773",
    "lng": "123.6386"
  },
  {
    "country": "PH",
    "name": "Tocok",
    "lat": "15.75",
    "lng": "120.3"
  },
  {
    "country": "PH",
    "name": "Tococ East",
    "lat": "15.82498",
    "lng": "120.42605"
  },
  {
    "country": "PH",
    "name": "Tobuan",
    "lat": "16.05562",
    "lng": "120.11024"
  },
  {
    "country": "PH",
    "name": "Toboy",
    "lat": "16.0271",
    "lng": "120.6369"
  },
  {
    "country": "PH",
    "name": "Toboso",
    "lat": "10.71435",
    "lng": "123.5162"
  },
  {
    "country": "PH",
    "name": "Tiwi",
    "lat": "13.4585",
    "lng": "123.6805"
  },
  {
    "country": "PH",
    "name": "Tiwi",
    "lat": "10.92972",
    "lng": "122.73417"
  },
  {
    "country": "PH",
    "name": "Titay",
    "lat": "7.8125",
    "lng": "122.53444"
  },
  {
    "country": "PH",
    "name": "Tiring",
    "lat": "10.85",
    "lng": "122.5067"
  },
  {
    "country": "PH",
    "name": "Tipo-Tipo",
    "lat": "6.58139",
    "lng": "122.17944"
  },
  {
    "country": "PH",
    "name": "Tipolo",
    "lat": "10.0196",
    "lng": "124.5144"
  },
  {
    "country": "PH",
    "name": "Tipaz",
    "lat": "13.8285",
    "lng": "121.42506"
  },
  {
    "country": "PH",
    "name": "Tiparak",
    "lat": "8.0341",
    "lng": "123.5288"
  },
  {
    "country": "PH",
    "name": "Tinutulan",
    "lat": "7.1",
    "lng": "124.65"
  },
  {
    "country": "PH",
    "name": "Tinongan",
    "lat": "10.215",
    "lng": "123.03528"
  },
  {
    "country": "PH",
    "name": "Tinubuan",
    "lat": "11.186",
    "lng": "124.0078"
  },
  {
    "country": "PH",
    "name": "Tinoto",
    "lat": "5.88667",
    "lng": "125.07056"
  },
  {
    "country": "PH",
    "name": "Tinogboc",
    "lat": "12.00737",
    "lng": "121.41221"
  },
  {
    "country": "PH",
    "name": "Tiniguiban",
    "lat": "11.3574",
    "lng": "119.5049"
  },
  {
    "country": "PH",
    "name": "Brgy. Tinigao, Kalibo",
    "lat": "11.7",
    "lng": "122.36667"
  },
  {
    "country": "PH",
    "name": "Tingloy",
    "lat": "13.66091",
    "lng": "120.8711"
  },
  {
    "country": "PH",
    "name": "Tinglayan",
    "lat": "17.27611",
    "lng": "121.1625"
  },
  {
    "country": "PH",
    "name": "Tindog",
    "lat": "11.1247",
    "lng": "124.0118"
  },
  {
    "country": "PH",
    "name": "Tinawagan",
    "lat": "13.65",
    "lng": "123.48333"
  },
  {
    "country": "PH",
    "name": "Tinaogan",
    "lat": "9.7791",
    "lng": "123.1503"
  },
  {
    "country": "PH",
    "name": "Tinang",
    "lat": "15.37626",
    "lng": "120.65343"
  },
  {
    "country": "PH",
    "name": "Tinampo",
    "lat": "13.22825",
    "lng": "123.50723"
  },
  {
    "country": "PH",
    "name": "Tinambacan",
    "lat": "12.0943",
    "lng": "124.5025"
  },
  {
    "country": "PH",
    "name": "Tinambac",
    "lat": "13.8164",
    "lng": "123.3261"
  },
  {
    "country": "PH",
    "name": "Tinalmud",
    "lat": "13.5941",
    "lng": "122.878"
  },
  {
    "country": "PH",
    "name": "Tinago",
    "lat": "13.18333",
    "lng": "123.65"
  },
  {
    "country": "PH",
    "name": "Tinagacan",
    "lat": "6.19917",
    "lng": "125.22944"
  },
  {
    "country": "PH",
    "name": "Tinaan",
    "lat": "11.26667",
    "lng": "123.75"
  },
  {
    "country": "PH",
    "name": "Timpas",
    "lat": "11.479",
    "lng": "122.7324"
  },
  {
    "country": "PH",
    "name": "Timonan",
    "lat": "8.2117",
    "lng": "123.0682"
  },
  {
    "country": "PH",
    "name": "Tiling",
    "lat": "9.9736",
    "lng": "122.6544"
  },
  {
    "country": "PH",
    "name": "Tilik",
    "lat": "13.81436",
    "lng": "120.20022"
  },
  {
    "country": "PH",
    "name": "Tikiw",
    "lat": "15.31193",
    "lng": "120.86116"
  },
  {
    "country": "PH",
    "name": "Ticala-an",
    "lat": "8.03528",
    "lng": "124.62083"
  },
  {
    "country": "PH",
    "name": "Tigum",
    "lat": "10.78333",
    "lng": "122.56667"
  },
  {
    "country": "PH",
    "name": "Tiguisan",
    "lat": "12.83941",
    "lng": "121.46052"
  },
  {
    "country": "PH",
    "name": "Tiguion",
    "lat": "13.3347",
    "lng": "121.861"
  },
  {
    "country": "PH",
    "name": "Tiguib",
    "lat": "9.8008",
    "lng": "123.1352"
  },
  {
    "country": "PH",
    "name": "Tigui",
    "lat": "13.2681",
    "lng": "122.0415"
  },
  {
    "country": "PH",
    "name": "Tigtabon",
    "lat": "6.89556",
    "lng": "122.16694"
  },
  {
    "country": "PH",
    "name": "Tignoan",
    "lat": "14.56522",
    "lng": "121.61786"
  },
  {
    "country": "PH",
    "name": "Tignapalan",
    "lat": "8.26389",
    "lng": "124.57472"
  },
  {
    "country": "PH",
    "name": "Tiglauigan",
    "lat": "10.9527",
    "lng": "123.3575"
  },
  {
    "country": "PH",
    "name": "Tigbinan",
    "lat": "14.18648",
    "lng": "122.46923"
  },
  {
    "country": "PH",
    "name": "Tigbauan",
    "lat": "10.67466",
    "lng": "122.3776"
  },
  {
    "country": "PH",
    "name": "Tigbao",
    "lat": "12.5546",
    "lng": "123.3389"
  },
  {
    "country": "PH",
    "name": "Tigbaw",
    "lat": "12.1483",
    "lng": "123.5909"
  },
  {
    "country": "PH",
    "name": "Tigbao",
    "lat": "7.42833",
    "lng": "122.3275"
  },
  {
    "country": "PH",
    "name": "Tigaon",
    "lat": "13.6331",
    "lng": "123.4968"
  },
  {
    "country": "PH",
    "name": "Tigao",
    "lat": "9.20889",
    "lng": "126.17611"
  },
  {
    "country": "PH",
    "name": "Tiep",
    "lat": "16.2382",
    "lng": "119.8609"
  },
  {
    "country": "PH",
    "name": "Tidman",
    "lat": "8.29861",
    "lng": "126.33889"
  },
  {
    "country": "PH",
    "name": "Tiblawan",
    "lat": "6.47834",
    "lng": "126.10828"
  },
  {
    "country": "PH",
    "name": "Tibiao",
    "lat": "11.29152",
    "lng": "122.03541"
  },
  {
    "country": "PH",
    "name": "Tibanbang",
    "lat": "6.63153",
    "lng": "126.10548"
  },
  {
    "country": "PH",
    "name": "Tibagon",
    "lat": "7.2327",
    "lng": "125.8628"
  },
  {
    "country": "PH",
    "name": "Tiaong",
    "lat": "13.96383",
    "lng": "121.32121"
  },
  {
    "country": "PH",
    "name": "Ternate",
    "lat": "14.2897",
    "lng": "120.7168"
  },
  {
    "country": "PH",
    "name": "Teresita",
    "lat": "6.41434",
    "lng": "124.70778"
  },
  {
    "country": "PH",
    "name": "Teresa",
    "lat": "14.5612",
    "lng": "121.2195"
  },
  {
    "country": "PH",
    "name": "Telbang",
    "lat": "16.17241",
    "lng": "120.06074"
  },
  {
    "country": "PH",
    "name": "Telafas",
    "lat": "6.6298",
    "lng": "124.97294"
  },
  {
    "country": "PH",
    "name": "Telabastagan",
    "lat": "15.11854",
    "lng": "120.60773"
  },
  {
    "country": "PH",
    "name": "Tebag East",
    "lat": "15.98123",
    "lng": "120.4674"
  },
  {
    "country": "PH",
    "name": "T'boli",
    "lat": "6.2",
    "lng": "124.83333"
  },
  {
    "country": "PH",
    "name": "Taywanak Ilaya",
    "lat": "14.15759",
    "lng": "120.84655"
  },
  {
    "country": "PH",
    "name": "Tayum",
    "lat": "17.6172",
    "lng": "120.6542"
  },
  {
    "country": "PH",
    "name": "Tayug",
    "lat": "16.0274",
    "lng": "120.7434"
  },
  {
    "country": "PH",
    "name": "Tayud",
    "lat": "10.37991",
    "lng": "124.00522"
  },
  {
    "country": "PH",
    "name": "Taytayan",
    "lat": "10.8787",
    "lng": "123.9771"
  },
  {
    "country": "PH",
    "name": "Taytayan",
    "lat": "7.73389",
    "lng": "126.50194"
  },
  {
    "country": "PH",
    "name": "Taytay",
    "lat": "14.55883",
    "lng": "121.13285"
  },
  {
    "country": "PH",
    "name": "Taytay",
    "lat": "14.12567",
    "lng": "121.40399"
  },
  {
    "country": "PH",
    "name": "Taytay",
    "lat": "10.81788",
    "lng": "119.49851"
  },
  {
    "country": "PH",
    "name": "Taytay",
    "lat": "8.54111",
    "lng": "124.53972"
  },
  {
    "country": "PH",
    "name": "Taysan",
    "lat": "13.8697",
    "lng": "121.0971"
  },
  {
    "country": "PH",
    "name": "Taysan",
    "lat": "13.7976",
    "lng": "121.1896"
  },
  {
    "country": "PH",
    "name": "Tayasan",
    "lat": "9.924",
    "lng": "123.1699"
  },
  {
    "country": "PH",
    "name": "Tayaman",
    "lat": "13.2295",
    "lng": "120.5726"
  },
  {
    "country": "PH",
    "name": "Tayabo",
    "lat": "15.8345",
    "lng": "121.0309"
  },
  {
    "country": "PH",
    "name": "Tayabas",
    "lat": "14.0259",
    "lng": "121.5929"
  },
  {
    "country": "PH",
    "name": "Tawan tawan",
    "lat": "7.16917",
    "lng": "125.37278"
  },
  {
    "country": "PH",
    "name": "Tawagan",
    "lat": "7.845",
    "lng": "123.47528"
  },
  {
    "country": "PH",
    "name": "Taviran",
    "lat": "7.12333",
    "lng": "124.31972"
  },
  {
    "country": "PH",
    "name": "Taungoh",
    "lat": "4.70654",
    "lng": "119.49296"
  },
  {
    "country": "PH",
    "name": "Tawala",
    "lat": "9.55421",
    "lng": "123.76955"
  },
  {
    "country": "PH",
    "name": "Tarusan",
    "lat": "8.65461",
    "lng": "117.5104"
  },
  {
    "country": "PH",
    "name": "Tartaro",
    "lat": "15.16667",
    "lng": "121.01667"
  },
  {
    "country": "PH",
    "name": "Tarragona",
    "lat": "7.0491",
    "lng": "126.44708"
  },
  {
    "country": "PH",
    "name": "Tarong",
    "lat": "11.5314",
    "lng": "123.132"
  },
  {
    "country": "PH",
    "name": "Tarlac City",
    "lat": "15.48017",
    "lng": "120.59794"
  },
  {
    "country": "PH",
    "name": "Tariric",
    "lat": "13.5723",
    "lng": "123.2235"
  },
  {
    "country": "PH",
    "name": "Tariji",
    "lat": "15.52112",
    "lng": "120.61442"
  },
  {
    "country": "PH",
    "name": "Tarangnan",
    "lat": "11.9009",
    "lng": "124.7459"
  },
  {
    "country": "PH",
    "name": "Tara",
    "lat": "13.81667",
    "lng": "122.98333"
  },
  {
    "country": "PH",
    "name": "Tapon",
    "lat": "10.0631",
    "lng": "123.4453"
  },
  {
    "country": "PH",
    "name": "Tapon",
    "lat": "9.7715",
    "lng": "123.5268"
  },
  {
    "country": "PH",
    "name": "Tapilon",
    "lat": "11.2774",
    "lng": "124.0306"
  },
  {
    "country": "PH",
    "name": "Tapikan",
    "lat": "6.85194",
    "lng": "124.3225"
  },
  {
    "country": "PH",
    "name": "Tapia",
    "lat": "7.75417",
    "lng": "126.01194"
  },
  {
    "country": "PH",
    "name": "Tapel",
    "lat": "18.28907",
    "lng": "122.02915"
  },
  {
    "country": "PH",
    "name": "Tapas",
    "lat": "11.2613",
    "lng": "122.5364"
  },
  {
    "country": "PH",
    "name": "Tapayan",
    "lat": "7.29444",
    "lng": "124.26611"
  },
  {
    "country": "PH",
    "name": "Tanza",
    "lat": "14.6753",
    "lng": "120.9389"
  },
  {
    "country": "PH",
    "name": "Tanza",
    "lat": "14.39834",
    "lng": "120.85544"
  },
  {
    "country": "PH",
    "name": "Tanza",
    "lat": "11.5825",
    "lng": "122.78361"
  },
  {
    "country": "PH",
    "name": "Tanza",
    "lat": "10.83484",
    "lng": "123.011"
  },
  {
    "country": "PH",
    "name": "Tanudan",
    "lat": "17.29556",
    "lng": "121.23778"
  },
  {
    "country": "PH",
    "name": "Tantangan",
    "lat": "6.615",
    "lng": "124.74889"
  },
  {
    "country": "PH",
    "name": "Tangke",
    "lat": "10.25451",
    "lng": "123.86516"
  },
  {
    "country": "PH",
    "name": "Tanolong",
    "lat": "15.80411",
    "lng": "120.41409"
  },
  {
    "country": "PH",
    "name": "Tanlad",
    "lat": "6.60222",
    "lng": "125.445"
  },
  {
    "country": "PH",
    "name": "Tanjay",
    "lat": "9.5162",
    "lng": "123.158"
  },
  {
    "country": "PH",
    "name": "Tangub",
    "lat": "8.0618",
    "lng": "123.7477"
  },
  {
    "country": "PH",
    "name": "Tañgo",
    "lat": "5.88083",
    "lng": "125.22194"
  },
  {
    "country": "PH",
    "name": "Tangnan",
    "lat": "9.60722",
    "lng": "123.77357"
  },
  {
    "country": "PH",
    "name": "Tangalan",
    "lat": "11.7789",
    "lng": "122.2634"
  },
  {
    "country": "PH",
    "name": "Tangal",
    "lat": "13.84536",
    "lng": "120.10082"
  },
  {
    "country": "PH",
    "name": "Tandoc",
    "lat": "15.95929",
    "lng": "120.32914"
  },
  {
    "country": "PH",
    "name": "Tandayag",
    "lat": "9.4547",
    "lng": "123.2299"
  },
  {
    "country": "PH",
    "name": "Tandag",
    "lat": "9.07833",
    "lng": "126.19861"
  },
  {
    "country": "PH",
    "name": "Tanay",
    "lat": "14.4968",
    "lng": "121.2846"
  },
  {
    "country": "PH",
    "name": "Tanauan",
    "lat": "14.08627",
    "lng": "121.14975"
  },
  {
    "country": "PH",
    "name": "Tanauan",
    "lat": "11.10944",
    "lng": "125.01556"
  },
  {
    "country": "PH",
    "name": "Tamugan",
    "lat": "7.23083",
    "lng": "125.37639"
  },
  {
    "country": "PH",
    "name": "Tampocon",
    "lat": "9.85",
    "lng": "123.13333"
  },
  {
    "country": "PH",
    "name": "Tampilisan",
    "lat": "8.01667",
    "lng": "122.68333"
  },
  {
    "country": "PH",
    "name": "Tampayan",
    "lat": "12.49411",
    "lng": "122.53309"
  },
  {
    "country": "PH",
    "name": "Tamparan",
    "lat": "7.87917",
    "lng": "124.33306"
  },
  {
    "country": "PH",
    "name": "Tampakan",
    "lat": "6.49034",
    "lng": "125.08275"
  },
  {
    "country": "PH",
    "name": "Tampakan",
    "lat": "4.92278",
    "lng": "119.79389"
  },
  {
    "country": "PH",
    "name": "Tamorong",
    "lat": "17.33333",
    "lng": "120.43333"
  },
  {
    "country": "PH",
    "name": "Tamontaka",
    "lat": "7.18056",
    "lng": "124.22556"
  },
  {
    "country": "PH",
    "name": "Tamnag",
    "lat": "6.57298",
    "lng": "124.88004"
  },
  {
    "country": "PH",
    "name": "Tamlang",
    "lat": "10.82544",
    "lng": "123.4541"
  },
  {
    "country": "PH",
    "name": "Tamiso",
    "lat": "9.6314",
    "lng": "123.0873"
  },
  {
    "country": "PH",
    "name": "Tamisan",
    "lat": "6.84372",
    "lng": "126.29838"
  },
  {
    "country": "PH",
    "name": "Tambulig",
    "lat": "8.0702",
    "lng": "123.5348"
  },
  {
    "country": "PH",
    "name": "Tambalan",
    "lat": "9.9085",
    "lng": "123.0896"
  },
  {
    "country": "PH",
    "name": "Tambongon",
    "lat": "10.9677",
    "lng": "123.9244"
  },
  {
    "country": "PH",
    "name": "Tombongon",
    "lat": "7.0792",
    "lng": "125.9486"
  },
  {
    "country": "PH",
    "name": "Tambong",
    "lat": "12.96391",
    "lng": "121.48462"
  },
  {
    "country": "PH",
    "name": "Tambo",
    "lat": "13.5468",
    "lng": "123.0358"
  },
  {
    "country": "PH",
    "name": "Tambo",
    "lat": "13.2553",
    "lng": "123.2906"
  },
  {
    "country": "PH",
    "name": "Tambo",
    "lat": "9.895",
    "lng": "123.0556"
  },
  {
    "country": "PH",
    "name": "Tambo",
    "lat": "7.15694",
    "lng": "125.69917"
  },
  {
    "country": "PH",
    "name": "Tambilil",
    "lat": "5.96222",
    "lng": "124.66972"
  },
  {
    "country": "PH",
    "name": "Tambalisa",
    "lat": "11.2698",
    "lng": "123.165"
  },
  {
    "country": "PH",
    "name": "Tambac",
    "lat": "11.6705",
    "lng": "122.4112"
  },
  {
    "country": "PH",
    "name": "Tambak",
    "lat": "6.72532",
    "lng": "124.62342"
  },
  {
    "country": "PH",
    "name": "Tamayo",
    "lat": "15.87746",
    "lng": "120.28455"
  },
  {
    "country": "PH",
    "name": "Taluya",
    "lat": "5.81167",
    "lng": "125.17278"
  },
  {
    "country": "PH",
    "name": "Talusan",
    "lat": "7.42667",
    "lng": "122.81028"
  },
  {
    "country": "PH",
    "name": "Taluksangay",
    "lat": "6.95417",
    "lng": "122.18389"
  },
  {
    "country": "PH",
    "name": "Talugtug",
    "lat": "15.7778",
    "lng": "120.8111"
  },
  {
    "country": "PH",
    "name": "Taltal",
    "lat": "15.5878",
    "lng": "119.9455"
  },
  {
    "country": "PH",
    "name": "Taloy",
    "lat": "16.33333",
    "lng": "120.5"
  },
  {
    "country": "PH",
    "name": "Taloy",
    "lat": "15.9241",
    "lng": "120.39649"
  },
  {
    "country": "PH",
    "name": "Platagata",
    "lat": "11.303",
    "lng": "123.1567"
  },
  {
    "country": "PH",
    "name": "Talospatang",
    "lat": "15.91701",
    "lng": "120.44141"
  },
  {
    "country": "PH",
    "name": "Talon",
    "lat": "11.56",
    "lng": "122.68111"
  },
  {
    "country": "PH",
    "name": "Talomo",
    "lat": "7.52861",
    "lng": "125.72278"
  },
  {
    "country": "PH",
    "name": "Talokgañgan",
    "lat": "11.00778",
    "lng": "122.845"
  },
  {
    "country": "PH",
    "name": "Taloc",
    "lat": "10.5746",
    "lng": "122.8954"
  },
  {
    "country": "PH",
    "name": "Talubatib",
    "lat": "14.1825",
    "lng": "122.7853"
  },
  {
    "country": "PH",
    "name": "Talitay",
    "lat": "7.03333",
    "lng": "124.7"
  },
  {
    "country": "PH",
    "name": "Talisayan",
    "lat": "10.95",
    "lng": "124.7"
  },
  {
    "country": "PH",
    "name": "Talisayan",
    "lat": "9.0003",
    "lng": "124.88091"
  },
  {
    "country": "PH",
    "name": "Talisayan",
    "lat": "6.98722",
    "lng": "121.92722"
  },
  {
    "country": "PH",
    "name": "Talisay",
    "lat": "14.1343",
    "lng": "122.9226"
  },
  {
    "country": "PH",
    "name": "Talisay",
    "lat": "14.0925",
    "lng": "121.02194"
  },
  {
    "country": "PH",
    "name": "Talisay",
    "lat": "13.9706",
    "lng": "121.2051"
  },
  {
    "country": "PH",
    "name": "Talisay",
    "lat": "13.91484",
    "lng": "120.62326"
  },
  {
    "country": "PH",
    "name": "Talisay",
    "lat": "13.18056",
    "lng": "122.62361"
  },
  {
    "country": "PH",
    "name": "Talisay",
    "lat": "11.24504",
    "lng": "124.05491"
  },
  {
    "country": "PH",
    "name": "Talisay",
    "lat": "10.7375",
    "lng": "122.9666"
  },
  {
    "country": "PH",
    "name": "Talisay",
    "lat": "10.24472",
    "lng": "123.84944"
  },
  {
    "country": "PH",
    "name": "Talisay",
    "lat": "9.81889",
    "lng": "125.61556"
  },
  {
    "country": "PH",
    "name": "Talisay",
    "lat": "6.71973",
    "lng": "126.09998"
  },
  {
    "country": "PH",
    "name": "Talipao",
    "lat": "5.97639",
    "lng": "121.11611"
  },
  {
    "country": "PH",
    "name": "Talipan",
    "lat": "13.93333",
    "lng": "121.68333"
  },
  {
    "country": "PH",
    "name": "Tal I Mun Doc",
    "lat": "15.2121",
    "lng": "120.6849"
  },
  {
    "country": "PH",
    "name": "Taligaman",
    "lat": "8.90444",
    "lng": "125.65583"
  },
  {
    "country": "PH",
    "name": "Talibon",
    "lat": "10.14917",
    "lng": "124.325"
  },
  {
    "country": "PH",
    "name": "Talayan",
    "lat": "6.98056",
    "lng": "124.38194"
  },
  {
    "country": "PH",
    "name": "Talavera",
    "lat": "15.5883",
    "lng": "120.9192"
  },
  {
    "country": "PH",
    "name": "Talangnan",
    "lat": "9.634",
    "lng": "123.3344"
  },
  {
    "country": "PH",
    "name": "Talang",
    "lat": "15.02488",
    "lng": "120.83782"
  },
  {
    "country": "PH",
    "name": "Talalora",
    "lat": "11.5293",
    "lng": "124.8362"
  },
  {
    "country": "PH",
    "name": "Talakag",
    "lat": "8.23361",
    "lng": "124.60028"
  },
  {
    "country": "PH",
    "name": "Talaibon",
    "lat": "13.8378",
    "lng": "121.1398"
  },
  {
    "country": "PH",
    "name": "Talahib Payap",
    "lat": "13.66083",
    "lng": "121.13639"
  },
  {
    "country": "PH",
    "name": "Talahiban I",
    "lat": "13.80645",
    "lng": "121.38116"
  },
  {
    "country": "PH",
    "name": "Talaga",
    "lat": "15.38403",
    "lng": "120.58933"
  },
  {
    "country": "PH",
    "name": "Talaga",
    "lat": "13.73646",
    "lng": "120.93618"
  },
  {
    "country": "PH",
    "name": "Talacogon",
    "lat": "8.45611",
    "lng": "125.78417"
  },
  {
    "country": "PH",
    "name": "Talaban",
    "lat": "10.1254",
    "lng": "122.8671"
  },
  {
    "country": "PH",
    "name": "Tala",
    "lat": "13.2742",
    "lng": "122.5859"
  },
  {
    "country": "PH",
    "name": "Tacub",
    "lat": "8.1875",
    "lng": "124.10806"
  },
  {
    "country": "PH",
    "name": "Takub",
    "lat": "6.85639",
    "lng": "125.4225"
  },
  {
    "country": "PH",
    "name": "Tajao",
    "lat": "10.3148",
    "lng": "123.5835"
  },
  {
    "country": "PH",
    "name": "Tagusao",
    "lat": "9.19238",
    "lng": "117.8141"
  },
  {
    "country": "PH",
    "name": "Tagum Norte",
    "lat": "10.07454",
    "lng": "124.38925"
  },
  {
    "country": "PH",
    "name": "Magugpo Poblacion",
    "lat": "7.4475",
    "lng": "125.8046"
  },
  {
    "country": "PH",
    "name": "Taguisa",
    "lat": "6.69833",
    "lng": "124.03583"
  },
  {
    "country": "PH",
    "name": "Taguing",
    "lat": "17.94636",
    "lng": "121.75521"
  },
  {
    "country": "PH",
    "name": "Taguig",
    "lat": "14.5243",
    "lng": "121.0792"
  },
  {
    "country": "PH",
    "name": "Tagudin",
    "lat": "16.9355",
    "lng": "120.4442"
  },
  {
    "country": "PH",
    "name": "Tagudin",
    "lat": "16.0806",
    "lng": "119.9539"
  },
  {
    "country": "PH",
    "name": "Tagasilay",
    "lat": "7.3025",
    "lng": "122.25861"
  },
  {
    "country": "PH",
    "name": "Taypano",
    "lat": "8.37083",
    "lng": "124.55944"
  },
  {
    "country": "PH",
    "name": "Tagoytoy",
    "lat": "13.4158",
    "lng": "123.678"
  },
  {
    "country": "PH",
    "name": "Tagoloan",
    "lat": "8.53954",
    "lng": "124.75411"
  },
  {
    "country": "PH",
    "name": "Tago",
    "lat": "9.02111",
    "lng": "126.23167"
  },
  {
    "country": "PH",
    "name": "Patikul",
    "lat": "6.08917",
    "lng": "121.10528"
  },
  {
    "country": "PH",
    "name": "Tagkawayan Sabang",
    "lat": "13.9909",
    "lng": "122.5298"
  },
  {
    "country": "PH",
    "name": "Tagdanua",
    "lat": "7.2043",
    "lng": "125.8841"
  },
  {
    "country": "PH",
    "name": "Tagcatong",
    "lat": "9.00222",
    "lng": "125.25694"
  },
  {
    "country": "PH",
    "name": "Tagburos",
    "lat": "9.82861",
    "lng": "118.73194"
  },
  {
    "country": "PH",
    "name": "Tagbubungang Diot",
    "lat": "11.1257",
    "lng": "124.4028"
  },
  {
    "country": "PH",
    "name": "Tagbina",
    "lat": "8.45194",
    "lng": "126.17139"
  },
  {
    "country": "PH",
    "name": "Tagbilaran City",
    "lat": "9.65556",
    "lng": "123.85219"
  },
  {
    "country": "PH",
    "name": "Tagbacan Ibaba",
    "lat": "13.6028",
    "lng": "122.3687"
  },
  {
    "country": "PH",
    "name": "Tagbak",
    "lat": "13.84166",
    "lng": "120.08872"
  },
  {
    "country": "PH",
    "name": "Tagaytay",
    "lat": "14.09532",
    "lng": "120.93355"
  },
  {
    "country": "PH",
    "name": "Tugaya",
    "lat": "7.88277",
    "lng": "124.174"
  },
  {
    "country": "PH",
    "name": "Tagas",
    "lat": "13.16667",
    "lng": "123.71667"
  },
  {
    "country": "PH",
    "name": "Tagapul-an",
    "lat": "12.05",
    "lng": "124.15"
  },
  {
    "country": "PH",
    "name": "Taganak",
    "lat": "6.07328",
    "lng": "118.31226"
  },
  {
    "country": "PH",
    "name": "Tagana-an",
    "lat": "9.69722",
    "lng": "125.58556"
  },
  {
    "country": "PH",
    "name": "Tagakpan",
    "lat": "7.11278",
    "lng": "125.42917"
  },
  {
    "country": "PH",
    "name": "Tayabas Ibaba",
    "lat": "13.6222",
    "lng": "122.2814"
  },
  {
    "country": "PH",
    "name": "Taft",
    "lat": "11.90111",
    "lng": "125.41889"
  },
  {
    "country": "PH",
    "name": "Tadian",
    "lat": "16.9956",
    "lng": "120.8203"
  },
  {
    "country": "PH",
    "name": "Tacurong",
    "lat": "6.6925",
    "lng": "124.67639"
  },
  {
    "country": "PH",
    "name": "Taclobo",
    "lat": "12.30744",
    "lng": "122.58601"
  },
  {
    "country": "PH",
    "name": "Tacloban",
    "lat": "11.24333",
    "lng": "125.00472"
  },
  {
    "country": "PH",
    "name": "Tacligan",
    "lat": "13.3975",
    "lng": "121.0626"
  },
  {
    "country": "PH",
    "name": "Tacadang",
    "lat": "16.7264",
    "lng": "120.6405"
  },
  {
    "country": "PH",
    "name": "Tagbita",
    "lat": "8.71331",
    "lng": "117.35046"
  },
  {
    "country": "PH",
    "name": "Tabonok",
    "lat": "10.8512",
    "lng": "123.8766"
  },
  {
    "country": "PH",
    "name": "Tabuk",
    "lat": "17.47378",
    "lng": "121.46799"
  },
  {
    "country": "PH",
    "name": "Tabug",
    "lat": "18.0343",
    "lng": "120.5488"
  },
  {
    "country": "PH",
    "name": "Tabuelan",
    "lat": "10.8209",
    "lng": "123.8689"
  },
  {
    "country": "PH",
    "name": "Tabuc Pontevedra",
    "lat": "11.48333",
    "lng": "122.81667"
  },
  {
    "country": "PH",
    "name": "Tabuating",
    "lat": "15.3921",
    "lng": "120.94084"
  },
  {
    "country": "PH",
    "name": "Tabuan",
    "lat": "9.51556",
    "lng": "122.85056"
  },
  {
    "country": "PH",
    "name": "Tabu",
    "lat": "9.8923",
    "lng": "122.7098"
  },
  {
    "country": "PH",
    "name": "Tubao",
    "lat": "8.334",
    "lng": "123.8547"
  },
  {
    "country": "PH",
    "name": "Tabontabon",
    "lat": "11.04083",
    "lng": "124.96111"
  },
  {
    "country": "PH",
    "name": "Tabunok",
    "lat": "10.77673",
    "lng": "124.01602"
  },
  {
    "country": "PH",
    "name": "Tabonoc",
    "lat": "10.35",
    "lng": "124.8"
  },
  {
    "country": "PH",
    "name": "Tabon",
    "lat": "15.27098",
    "lng": "120.91273"
  },
  {
    "country": "PH",
    "name": "Tabon",
    "lat": "10.3019",
    "lng": "123.326"
  },
  {
    "country": "PH",
    "name": "Tabon",
    "lat": "9.8042",
    "lng": "123.4563"
  },
  {
    "country": "PH",
    "name": "Tabon",
    "lat": "9.23877",
    "lng": "117.9946"
  },
  {
    "country": "PH",
    "name": "Tabogon",
    "lat": "10.9412",
    "lng": "124.0282"
  },
  {
    "country": "PH",
    "name": "Taboc",
    "lat": "8.87833",
    "lng": "124.7975"
  },
  {
    "country": "PH",
    "name": "Tablac",
    "lat": "17.21568",
    "lng": "120.45428"
  },
  {
    "country": "PH",
    "name": "Tabio",
    "lat": "16.85",
    "lng": "120.8"
  },
  {
    "country": "PH",
    "name": "Tabing",
    "lat": "11.4",
    "lng": "124.35"
  },
  {
    "country": "PH",
    "name": "Tabinay",
    "lat": "13.4871",
    "lng": "120.9566"
  },
  {
    "country": "PH",
    "name": "Tabina",
    "lat": "7.4669",
    "lng": "123.4081"
  },
  {
    "country": "PH",
    "name": "Tabid",
    "lat": "8.1085",
    "lng": "123.7801"
  },
  {
    "country": "PH",
    "name": "Tabiauan",
    "lat": "6.02806",
    "lng": "121.89355"
  },
  {
    "country": "PH",
    "name": "Tabango",
    "lat": "11.3077",
    "lng": "124.373"
  },
  {
    "country": "PH",
    "name": "Tabalong",
    "lat": "9.62157",
    "lng": "123.81231"
  },
  {
    "country": "PH",
    "name": "Tabaco",
    "lat": "13.35861",
    "lng": "123.73361"
  },
  {
    "country": "PH",
    "name": "Tabaan",
    "lat": "16.3",
    "lng": "120.51667"
  },
  {
    "country": "PH",
    "name": "Taal",
    "lat": "13.87992",
    "lng": "120.92311"
  },
  {
    "country": "PH",
    "name": "Suyo",
    "lat": "16.9762",
    "lng": "120.5254"
  },
  {
    "country": "PH",
    "name": "Suyan",
    "lat": "6.06028",
    "lng": "125.38528"
  },
  {
    "country": "PH",
    "name": "Suso",
    "lat": "17.3594",
    "lng": "120.4611"
  },
  {
    "country": "PH",
    "name": "Surup",
    "lat": "6.39035",
    "lng": "126.14558"
  },
  {
    "country": "PH",
    "name": "Surigao",
    "lat": "9.789",
    "lng": "125.495"
  },
  {
    "country": "PH",
    "name": "Surallah",
    "lat": "6.37527",
    "lng": "124.74521"
  },
  {
    "country": "PH",
    "name": "Sungai",
    "lat": "8.45139",
    "lng": "124.40278"
  },
  {
    "country": "PH",
    "name": "Sumpong",
    "lat": "8.16333",
    "lng": "125.11833"
  },
  {
    "country": "PH",
    "name": "Sumisip",
    "lat": "6.41972",
    "lng": "121.97139"
  },
  {
    "country": "PH",
    "name": "Sumilao",
    "lat": "8.28722",
    "lng": "124.94556"
  },
  {
    "country": "PH",
    "name": "Sumagui",
    "lat": "12.79532",
    "lng": "121.47401"
  },
  {
    "country": "PH",
    "name": "Sumabnit",
    "lat": "16.0303",
    "lng": "120.5832"
  },
  {
    "country": "PH",
    "name": "Sulucan",
    "lat": "14.79448",
    "lng": "120.92594"
  },
  {
    "country": "PH",
    "name": "Sultan Kudarat",
    "lat": "7.22889",
    "lng": "124.25778"
  },
  {
    "country": "PH",
    "name": "Sulop",
    "lat": "6.59861",
    "lng": "125.34361"
  },
  {
    "country": "PH",
    "name": "Sulit",
    "lat": "6.23611",
    "lng": "125.02056"
  },
  {
    "country": "PH",
    "name": "Sulat",
    "lat": "11.81028",
    "lng": "125.45444"
  },
  {
    "country": "PH",
    "name": "Sulangan",
    "lat": "11.1373",
    "lng": "123.7228"
  },
  {
    "country": "PH",
    "name": "Sulangan",
    "lat": "10.936",
    "lng": "125.8264"
  },
  {
    "country": "PH",
    "name": "Sulangan",
    "lat": "10.83",
    "lng": "122.69"
  },
  {
    "country": "PH",
    "name": "Sula",
    "lat": "15.45725",
    "lng": "120.39553"
  },
  {
    "country": "PH",
    "name": "Sugpon",
    "lat": "16.8434",
    "lng": "120.5157"
  },
  {
    "country": "PH",
    "name": "Sugod",
    "lat": "12.987",
    "lng": "124.0805"
  },
  {
    "country": "PH",
    "name": "Sugcad",
    "lat": "13.36667",
    "lng": "123.7"
  },
  {
    "country": "PH",
    "name": "Sugbongkogon",
    "lat": "8.95694",
    "lng": "124.79111"
  },
  {
    "country": "PH",
    "name": "Sugal",
    "lat": "5.66222",
    "lng": "125.46167"
  },
  {
    "country": "PH",
    "name": "Sudipen",
    "lat": "16.9056",
    "lng": "120.4617"
  },
  {
    "country": "PH",
    "name": "Suklayin",
    "lat": "15.7574",
    "lng": "121.5503"
  },
  {
    "country": "PH",
    "name": "Subusub",
    "lat": "16.22689",
    "lng": "120.49513"
  },
  {
    "country": "PH",
    "name": "Subic",
    "lat": "14.87999",
    "lng": "120.23433"
  },
  {
    "country": "PH",
    "name": "Subic",
    "lat": "13.94859",
    "lng": "120.94013"
  },
  {
    "country": "PH",
    "name": "Saaban",
    "lat": "13.13049",
    "lng": "121.36872"
  },
  {
    "country": "PH",
    "name": "Suba",
    "lat": "10.82512",
    "lng": "121.0069"
  },
  {
    "country": "PH",
    "name": "Suay",
    "lat": "10.0533",
    "lng": "122.8423"
  },
  {
    "country": "PH",
    "name": "Suz-on",
    "lat": "7.66278",
    "lng": "125.63833"
  },
  {
    "country": "PH",
    "name": "Sual",
    "lat": "16.06682",
    "lng": "120.09414"
  },
  {
    "country": "PH",
    "name": "Soyung",
    "lat": "16.7001",
    "lng": "121.6655"
  },
  {
    "country": "PH",
    "name": "South Upi",
    "lat": "6.83333",
    "lng": "124.15"
  },
  {
    "country": "PH",
    "name": "Sorsogon",
    "lat": "12.97389",
    "lng": "123.99333"
  },
  {
    "country": "PH",
    "name": "Songculan",
    "lat": "9.62965",
    "lng": "123.82897"
  },
  {
    "country": "PH",
    "name": "Solsona",
    "lat": "18.09333",
    "lng": "120.76972"
  },
  {
    "country": "PH",
    "name": "Solo",
    "lat": "13.74691",
    "lng": "120.90119"
  },
  {
    "country": "PH",
    "name": "Soledad",
    "lat": "15.42838",
    "lng": "120.98355"
  },
  {
    "country": "PH",
    "name": "Solano",
    "lat": "16.51918",
    "lng": "121.18124"
  },
  {
    "country": "PH",
    "name": "Solana",
    "lat": "17.6528",
    "lng": "121.691"
  },
  {
    "country": "PH",
    "name": "Solana",
    "lat": "8.62306",
    "lng": "124.77056"
  },
  {
    "country": "PH",
    "name": "Sogod",
    "lat": "13.83333",
    "lng": "123.31667"
  },
  {
    "country": "PH",
    "name": "Sogod",
    "lat": "12.37635",
    "lng": "122.66368"
  },
  {
    "country": "PH",
    "name": "Sogod",
    "lat": "10.75083",
    "lng": "123.99472"
  },
  {
    "country": "PH",
    "name": "Sogod",
    "lat": "10.3847",
    "lng": "124.9814"
  },
  {
    "country": "PH",
    "name": "Socorro",
    "lat": "13.0669",
    "lng": "121.39858"
  },
  {
    "country": "PH",
    "name": "Socorro",
    "lat": "9.62139",
    "lng": "125.96667"
  },
  {
    "country": "PH",
    "name": "Sitangkai",
    "lat": "4.66115",
    "lng": "119.39647"
  },
  {
    "country": "PH",
    "name": "Sison",
    "lat": "16.17389",
    "lng": "120.51528"
  },
  {
    "country": "PH",
    "name": "Sison",
    "lat": "9.66028",
    "lng": "125.52861"
  },
  {
    "country": "PH",
    "name": "Siruma",
    "lat": "14",
    "lng": "123.25"
  },
  {
    "country": "PH",
    "name": "Sirib",
    "lat": "7.13333",
    "lng": "125.40722"
  },
  {
    "country": "PH",
    "name": "Siraway",
    "lat": "7.58528",
    "lng": "122.13972"
  },
  {
    "country": "PH",
    "name": "Siquijor",
    "lat": "9.2142",
    "lng": "123.515"
  },
  {
    "country": "PH",
    "name": "Sipocot",
    "lat": "13.768",
    "lng": "122.9762"
  },
  {
    "country": "PH",
    "name": "Sipalay",
    "lat": "9.75194",
    "lng": "122.40417"
  },
  {
    "country": "PH",
    "name": "Siocon",
    "lat": "7.70611",
    "lng": "122.13528"
  },
  {
    "country": "PH",
    "name": "Sinuknipan",
    "lat": "13.8894",
    "lng": "122.6375"
  },
  {
    "country": "PH",
    "name": "Sinubong",
    "lat": "7.02806",
    "lng": "121.92528"
  },
  {
    "country": "PH",
    "name": "Sinonoc",
    "lat": "8.3096",
    "lng": "123.8461"
  },
  {
    "country": "PH",
    "name": "Sinolon",
    "lat": "6.24389",
    "lng": "124.81444"
  },
  {
    "country": "PH",
    "name": "Sinubong",
    "lat": "8.0684",
    "lng": "125.9308"
  },
  {
    "country": "PH",
    "name": "Sinisian",
    "lat": "13.9156",
    "lng": "120.84401"
  },
  {
    "country": "PH",
    "name": "Siniloan",
    "lat": "14.4216",
    "lng": "121.4463"
  },
  {
    "country": "PH",
    "name": "Sinilian First",
    "lat": "15.69327",
    "lng": "120.45936"
  },
  {
    "country": "PH",
    "name": "Sindon",
    "lat": "17.06034",
    "lng": "122.01514"
  },
  {
    "country": "PH",
    "name": "Sindangan",
    "lat": "8.2376",
    "lng": "122.9974"
  },
  {
    "country": "PH",
    "name": "Sinayawan",
    "lat": "6.7125",
    "lng": "125.30944"
  },
  {
    "country": "PH",
    "name": "Sinawilan",
    "lat": "6.75444",
    "lng": "125.24639"
  },
  {
    "country": "PH",
    "name": "Sinamar",
    "lat": "16.9",
    "lng": "121.56667"
  },
  {
    "country": "PH",
    "name": "Sinala",
    "lat": "13.8057",
    "lng": "120.97463"
  },
  {
    "country": "PH",
    "name": "Sinait",
    "lat": "17.8664",
    "lng": "120.4583"
  },
  {
    "country": "PH",
    "name": "Sinait",
    "lat": "15.5367",
    "lng": "120.5851"
  },
  {
    "country": "PH",
    "name": "Sinacaban",
    "lat": "8.2864",
    "lng": "123.8399"
  },
  {
    "country": "PH",
    "name": "Simunul",
    "lat": "4.89833",
    "lng": "119.84944"
  },
  {
    "country": "PH",
    "name": "Simimbaan",
    "lat": "17.11856",
    "lng": "121.58138"
  },
  {
    "country": "PH",
    "name": "Simanu Sur",
    "lat": "17.48523",
    "lng": "121.83426"
  },
  {
    "country": "PH",
    "name": "Simala",
    "lat": "9.97326",
    "lng": "123.61648"
  },
  {
    "country": "PH",
    "name": "Silway 7",
    "lat": "6.17711",
    "lng": "125.12068"
  },
  {
    "country": "PH",
    "name": "Silvino Lobos",
    "lat": "12.3",
    "lng": "124.83333"
  },
  {
    "country": "PH",
    "name": "Silongin",
    "lat": "13.2999",
    "lng": "122.5217"
  },
  {
    "country": "PH",
    "name": "Sillon",
    "lat": "11.199",
    "lng": "123.7675"
  },
  {
    "country": "PH",
    "name": "Sillawit",
    "lat": "16.87316",
    "lng": "121.75924"
  },
  {
    "country": "PH",
    "name": "Silanga",
    "lat": "11.81806",
    "lng": "124.84306"
  },
  {
    "country": "PH",
    "name": "Silang",
    "lat": "14.21567",
    "lng": "120.97137"
  },
  {
    "country": "PH",
    "name": "Silago",
    "lat": "10.5291",
    "lng": "125.1618"
  },
  {
    "country": "PH",
    "name": "Silae",
    "lat": "8.15889",
    "lng": "125.2825"
  },
  {
    "country": "PH",
    "name": "Silab",
    "lat": "9.4383",
    "lng": "123.1792"
  },
  {
    "country": "PH",
    "name": "Sikatuna",
    "lat": "9.6883",
    "lng": "123.9751"
  },
  {
    "country": "PH",
    "name": "Sigma",
    "lat": "11.4214",
    "lng": "122.6662"
  },
  {
    "country": "PH",
    "name": "Sigay",
    "lat": "17.08333",
    "lng": "120.6"
  },
  {
    "country": "PH",
    "name": "Cigaras",
    "lat": "14.2266",
    "lng": "121.4298"
  },
  {
    "country": "PH",
    "name": "Sierra Bullones",
    "lat": "9.8081",
    "lng": "124.2921"
  },
  {
    "country": "PH",
    "name": "Siempre Viva",
    "lat": "17.22874",
    "lng": "121.63294"
  },
  {
    "country": "PH",
    "name": "Sico Uno",
    "lat": "13.8301",
    "lng": "121.37123"
  },
  {
    "country": "PH",
    "name": "Siclong",
    "lat": "15.5808",
    "lng": "121.2239"
  },
  {
    "country": "PH",
    "name": "Sibutao",
    "lat": "8.5916",
    "lng": "123.4859"
  },
  {
    "country": "PH",
    "name": "Sibulan",
    "lat": "14.75",
    "lng": "121.93333"
  },
  {
    "country": "PH",
    "name": "Sibulan",
    "lat": "9.3584",
    "lng": "123.285"
  },
  {
    "country": "PH",
    "name": "Sibulan",
    "lat": "6.93361",
    "lng": "125.46222"
  },
  {
    "country": "PH",
    "name": "Sibul",
    "lat": "15.8",
    "lng": "121"
  },
  {
    "country": "PH",
    "name": "Sibul",
    "lat": "15.169",
    "lng": "121.0616"
  },
  {
    "country": "PH",
    "name": "Sibuco",
    "lat": "7.29111",
    "lng": "122.06556"
  },
  {
    "country": "PH",
    "name": "Sibucao",
    "lat": "10.4179",
    "lng": "122.887"
  },
  {
    "country": "PH",
    "name": "Sibonga",
    "lat": "10.0168",
    "lng": "123.6171"
  },
  {
    "country": "PH",
    "name": "Sibalom",
    "lat": "10.79",
    "lng": "122.0178"
  },
  {
    "country": "PH",
    "name": "Sibaguan",
    "lat": "11.55778",
    "lng": "122.71389"
  },
  {
    "country": "PH",
    "name": "Sibagat",
    "lat": "8.8225",
    "lng": "125.6975"
  },
  {
    "country": "PH",
    "name": "Siayan",
    "lat": "8.26667",
    "lng": "123.1"
  },
  {
    "country": "PH",
    "name": "Siay",
    "lat": "7.69611",
    "lng": "122.86306"
  },
  {
    "country": "PH",
    "name": "Siaton",
    "lat": "9.0648",
    "lng": "123.0339"
  },
  {
    "country": "PH",
    "name": "Siasi",
    "lat": "5.5462",
    "lng": "120.8145"
  },
  {
    "country": "PH",
    "name": "Siari",
    "lat": "8.3245",
    "lng": "122.9881"
  },
  {
    "country": "PH",
    "name": "Sexmoan",
    "lat": "14.9438",
    "lng": "120.6229"
  },
  {
    "country": "PH",
    "name": "Sevilla",
    "lat": "9.70383",
    "lng": "124.04829"
  },
  {
    "country": "PH",
    "name": "Sergio Osmeña Sr",
    "lat": "8.16667",
    "lng": "123.5"
  },
  {
    "country": "PH",
    "name": "Seres",
    "lat": "8.4803",
    "lng": "123.2629"
  },
  {
    "country": "PH",
    "name": "Salunayan",
    "lat": "7.15444",
    "lng": "124.4975"
  },
  {
    "country": "PH",
    "name": "Semut",
    "lat": "6.66361",
    "lng": "122.21889"
  },
  {
    "country": "PH",
    "name": "Semirara",
    "lat": "12.06967",
    "lng": "121.39861"
  },
  {
    "country": "PH",
    "name": "Siguinon",
    "lat": "10.9423",
    "lng": "124.6806"
  },
  {
    "country": "PH",
    "name": "Sebu",
    "lat": "6.22066",
    "lng": "124.69269"
  },
  {
    "country": "PH",
    "name": "Sebaste",
    "lat": "11.5901",
    "lng": "122.0945"
  },
  {
    "country": "PH",
    "name": "Sebaste",
    "lat": "10.4963",
    "lng": "122.657"
  },
  {
    "country": "PH",
    "name": "Saysain",
    "lat": "14.56111",
    "lng": "120.3925"
  },
  {
    "country": "PH",
    "name": "Satan",
    "lat": "6.86306",
    "lng": "124.40861"
  },
  {
    "country": "PH",
    "name": "Sarrat",
    "lat": "18.1574",
    "lng": "120.647"
  },
  {
    "country": "PH",
    "name": "Sariaya",
    "lat": "13.9624",
    "lng": "121.5265"
  },
  {
    "country": "PH",
    "name": "Saraza",
    "lat": "8.73556",
    "lng": "117.78"
  },
  {
    "country": "PH",
    "name": "Sarangani",
    "lat": "5.40333",
    "lng": "125.46361"
  },
  {
    "country": "PH",
    "name": "Sara",
    "lat": "11.2579",
    "lng": "123.0138"
  },
  {
    "country": "PH",
    "name": "Sapu Padidu",
    "lat": "5.91722",
    "lng": "125.26694"
  },
  {
    "country": "PH",
    "name": "Sapol",
    "lat": "13.365",
    "lng": "121.1893"
  },
  {
    "country": "PH",
    "name": "Sapian",
    "lat": "11.4943",
    "lng": "122.6027"
  },
  {
    "country": "PH",
    "name": "Sapang Dalaga",
    "lat": "8.5399",
    "lng": "123.5624"
  },
  {
    "country": "PH",
    "name": "Sapang Buho",
    "lat": "15.59038",
    "lng": "121.12454"
  },
  {
    "country": "PH",
    "name": "Sapang",
    "lat": "15.7032",
    "lng": "120.5245"
  },
  {
    "country": "PH",
    "name": "Sapadun",
    "lat": "7.48333",
    "lng": "124.25"
  },
  {
    "country": "PH",
    "name": "Sapad",
    "lat": "7.85",
    "lng": "123.83333"
  },
  {
    "country": "PH",
    "name": "Sapa",
    "lat": "5.1544",
    "lng": "120.3241"
  },
  {
    "country": "PH",
    "name": "San Vicente",
    "lat": "17.59694",
    "lng": "120.37361"
  },
  {
    "country": "PH",
    "name": "San Vicente",
    "lat": "15.2921",
    "lng": "120.65498"
  },
  {
    "country": "PH",
    "name": "San Vicente",
    "lat": "15.21324",
    "lng": "120.81901"
  },
  {
    "country": "PH",
    "name": "San Vicente",
    "lat": "14.94594",
    "lng": "120.74852"
  },
  {
    "country": "PH",
    "name": "San Vicente",
    "lat": "14.1061",
    "lng": "122.8733"
  },
  {
    "country": "PH",
    "name": "San Vicente",
    "lat": "13.8967",
    "lng": "122.2047"
  },
  {
    "country": "PH",
    "name": "San Vicente",
    "lat": "13.7",
    "lng": "123.2"
  },
  {
    "country": "PH",
    "name": "San Vicente",
    "lat": "13.5737",
    "lng": "123.0533"
  },
  {
    "country": "PH",
    "name": "San Vicente",
    "lat": "13.4527",
    "lng": "123.3729"
  },
  {
    "country": "PH",
    "name": "San Vicente",
    "lat": "13.4081",
    "lng": "123.4188"
  },
  {
    "country": "PH",
    "name": "San Vincente",
    "lat": "13.4068",
    "lng": "121.175"
  },
  {
    "country": "PH",
    "name": "San Vicente",
    "lat": "13.2615",
    "lng": "123.4334"
  },
  {
    "country": "PH",
    "name": "San Vicente",
    "lat": "12.97806",
    "lng": "123.82222"
  },
  {
    "country": "PH",
    "name": "San Vicente",
    "lat": "12.27111",
    "lng": "124.1"
  },
  {
    "country": "PH",
    "name": "San Vicente",
    "lat": "11.1183",
    "lng": "124.5657"
  },
  {
    "country": "PH",
    "name": "San Vicente",
    "lat": "10.53033",
    "lng": "119.25423"
  },
  {
    "country": "PH",
    "name": "San Vicente",
    "lat": "7.83333",
    "lng": "125.81667"
  },
  {
    "country": "PH",
    "name": "San Vicente",
    "lat": "7.65111",
    "lng": "125.03444"
  },
  {
    "country": "PH",
    "name": "San Vicente",
    "lat": "6.45375",
    "lng": "124.78005"
  },
  {
    "country": "PH",
    "name": "Santo Tomas",
    "lat": "17.39972",
    "lng": "121.76455"
  },
  {
    "country": "PH",
    "name": "Santo Tomas",
    "lat": "16.2798",
    "lng": "120.3792"
  },
  {
    "country": "PH",
    "name": "Santo Tomas",
    "lat": "15.74977",
    "lng": "120.96241"
  },
  {
    "country": "PH",
    "name": "Santo Tomas",
    "lat": "15.0333",
    "lng": "120.8"
  },
  {
    "country": "PH",
    "name": "Santo Tomas",
    "lat": "14.18333",
    "lng": "121.5"
  },
  {
    "country": "PH",
    "name": "Santo Tomas",
    "lat": "14.1079",
    "lng": "121.14136"
  },
  {
    "country": "PH",
    "name": "Santo Tomas",
    "lat": "8.18583",
    "lng": "125.80389"
  },
  {
    "country": "PH",
    "name": "Santo Tomas",
    "lat": "7.53361",
    "lng": "125.62333"
  },
  {
    "country": "PH",
    "name": "Santo Rosario",
    "lat": "15.6447",
    "lng": "120.8612"
  },
  {
    "country": "PH",
    "name": "Santo Rosario",
    "lat": "15.43425",
    "lng": "120.88981"
  },
  {
    "country": "PH",
    "name": "Santor",
    "lat": "14.09549",
    "lng": "121.10874"
  },
  {
    "country": "PH",
    "name": "Santo Niño",
    "lat": "17.8861",
    "lng": "121.5691"
  },
  {
    "country": "PH",
    "name": "Santo Niño",
    "lat": "15.33433",
    "lng": "120.62619"
  },
  {
    "country": "PH",
    "name": "Santo Niño",
    "lat": "13.8489",
    "lng": "121.1328"
  },
  {
    "country": "PH",
    "name": "Santo Niño",
    "lat": "13.7018",
    "lng": "121.0949"
  },
  {
    "country": "PH",
    "name": "Santo Niño",
    "lat": "13.1043",
    "lng": "123.9682"
  },
  {
    "country": "PH",
    "name": "Santo Niño",
    "lat": "11.9263",
    "lng": "124.4492"
  },
  {
    "country": "PH",
    "name": "Santo Niño",
    "lat": "11.06306",
    "lng": "124.56167"
  },
  {
    "country": "PH",
    "name": "Santa Nino",
    "lat": "10.689",
    "lng": "123.7884"
  },
  {
    "country": "PH",
    "name": "Santo Niño",
    "lat": "7.62361",
    "lng": "125.62528"
  },
  {
    "country": "PH",
    "name": "Santo Niño",
    "lat": "7.32778",
    "lng": "125.70528"
  },
  {
    "country": "PH",
    "name": "Santo Niño",
    "lat": "6.435",
    "lng": "124.6975"
  },
  {
    "country": "PH",
    "name": "Santol",
    "lat": "16.772",
    "lng": "120.4604"
  },
  {
    "country": "PH",
    "name": "Santol",
    "lat": "15.16222",
    "lng": "120.5675"
  },
  {
    "country": "PH",
    "name": "Santol",
    "lat": "10.1725",
    "lng": "122.9947"
  },
  {
    "country": "PH",
    "name": "Santo Domingo",
    "lat": "17.63528",
    "lng": "120.41083"
  },
  {
    "country": "PH",
    "name": "Santo Domingo",
    "lat": "17.15999",
    "lng": "121.75183"
  },
  {
    "country": "PH",
    "name": "Santo Domingo",
    "lat": "15.5873",
    "lng": "120.877"
  },
  {
    "country": "PH",
    "name": "Santo Domingo",
    "lat": "15.07289",
    "lng": "120.75703"
  },
  {
    "country": "PH",
    "name": "Santo Domingo",
    "lat": "14.9912",
    "lng": "120.74341"
  },
  {
    "country": "PH",
    "name": "Santo Domingo",
    "lat": "14.96532",
    "lng": "120.55672"
  },
  {
    "country": "PH",
    "name": "Santo Domingo",
    "lat": "14.1338",
    "lng": "122.8883"
  },
  {
    "country": "PH",
    "name": "Santo Domingo",
    "lat": "13.7",
    "lng": "123.16667"
  },
  {
    "country": "PH",
    "name": "Santo Domingo",
    "lat": "13.42",
    "lng": "123.4486"
  },
  {
    "country": "PH",
    "name": "Santo Domingo",
    "lat": "13.23528",
    "lng": "123.77722"
  },
  {
    "country": "PH",
    "name": "Santo Cristo",
    "lat": "15.33836",
    "lng": "120.59333"
  },
  {
    "country": "PH",
    "name": "Santo Cristo",
    "lat": "15.29683",
    "lng": "120.89025"
  },
  {
    "country": "PH",
    "name": "Santa Angel",
    "lat": "11.3068",
    "lng": "122.6408"
  },
  {
    "country": "PH",
    "name": "Santisimo Rosario",
    "lat": "13.99661",
    "lng": "121.30918"
  },
  {
    "country": "PH",
    "name": "Santiago",
    "lat": "17.2939",
    "lng": "120.4449"
  },
  {
    "country": "PH",
    "name": "Santiago",
    "lat": "16.68808",
    "lng": "121.5487"
  },
  {
    "country": "PH",
    "name": "Santiago",
    "lat": "14.90371",
    "lng": "120.51134"
  },
  {
    "country": "PH",
    "name": "Santiago",
    "lat": "14.0211",
    "lng": "121.2792"
  },
  {
    "country": "PH",
    "name": "Santiago",
    "lat": "11.05806",
    "lng": "122.91167"
  },
  {
    "country": "PH",
    "name": "Santiago",
    "lat": "10.5897",
    "lng": "124.3066"
  },
  {
    "country": "PH",
    "name": "Santiago",
    "lat": "7.28889",
    "lng": "126.57333"
  },
  {
    "country": "PH",
    "name": "San Teodoro",
    "lat": "13.43354",
    "lng": "121.0144"
  },
  {
    "country": "PH",
    "name": "Santa Teresita",
    "lat": "18.2472",
    "lng": "121.9127"
  },
  {
    "country": "PH",
    "name": "Santa Teresita",
    "lat": "13.86639",
    "lng": "120.98139"
  },
  {
    "country": "PH",
    "name": "Santa Teresita",
    "lat": "13.4786",
    "lng": "123.4191"
  },
  {
    "country": "PH",
    "name": "Santa Teresa First",
    "lat": "14.9265",
    "lng": "120.55791"
  },
  {
    "country": "PH",
    "name": "Santa Teresa",
    "lat": "12.25186",
    "lng": "121.11251"
  },
  {
    "country": "PH",
    "name": "Santa Teresa",
    "lat": "10.58546",
    "lng": "122.5604"
  },
  {
    "country": "PH",
    "name": "Santa Rosa Sur",
    "lat": "14.259",
    "lng": "122.7233"
  },
  {
    "country": "PH",
    "name": "Hacienda Santa Rosa",
    "lat": "10.57226",
    "lng": "123.1012"
  },
  {
    "country": "PH",
    "name": "Santa Rosa",
    "lat": "15.4238",
    "lng": "120.9378"
  },
  {
    "country": "PH",
    "name": "Santa Rosa",
    "lat": "15.36756",
    "lng": "120.61703"
  },
  {
    "country": "PH",
    "name": "Santa Rosa",
    "lat": "14.42612",
    "lng": "120.87931"
  },
  {
    "country": "PH",
    "name": "Santa Rosa",
    "lat": "14.31222",
    "lng": "121.11139"
  },
  {
    "country": "PH",
    "name": "Santa Rosa",
    "lat": "13.5591",
    "lng": "122.3776"
  },
  {
    "country": "PH",
    "name": "Santa Rita",
    "lat": "15.61923",
    "lng": "120.86962"
  },
  {
    "country": "PH",
    "name": "Santa Rita",
    "lat": "14.9993",
    "lng": "120.6117"
  },
  {
    "country": "PH",
    "name": "Santa Rita",
    "lat": "11.4502",
    "lng": "124.9425"
  },
  {
    "country": "PH",
    "name": "Santa Praxedes",
    "lat": "18.56667",
    "lng": "121"
  },
  {
    "country": "PH",
    "name": "Santa Paz",
    "lat": "10.26667",
    "lng": "124.78333"
  },
  {
    "country": "PH",
    "name": "Santander Poblacion",
    "lat": "9.42527",
    "lng": "123.33879"
  },
  {
    "country": "PH",
    "name": "Santa Monica",
    "lat": "15.35771",
    "lng": "120.72006"
  },
  {
    "country": "PH",
    "name": "Santa Monica",
    "lat": "10.73639",
    "lng": "122.45333"
  },
  {
    "country": "PH",
    "name": "Santa Monica",
    "lat": "10.02",
    "lng": "126.03833"
  },
  {
    "country": "PH",
    "name": "Santa Maria",
    "lat": "18.1414",
    "lng": "121.66473"
  },
  {
    "country": "PH",
    "name": "Santa Maria",
    "lat": "17.46639",
    "lng": "121.75222"
  },
  {
    "country": "PH",
    "name": "Santa Maria",
    "lat": "17.3665",
    "lng": "120.4808"
  },
  {
    "country": "PH",
    "name": "Santa Maria",
    "lat": "16.9518",
    "lng": "120.4445"
  },
  {
    "country": "PH",
    "name": "Santa Maria",
    "lat": "15.98083",
    "lng": "120.70028"
  },
  {
    "country": "PH",
    "name": "Santa Maria",
    "lat": "15.64365",
    "lng": "120.42635"
  },
  {
    "country": "PH",
    "name": "Santa Maria",
    "lat": "15.5232",
    "lng": "120.7925"
  },
  {
    "country": "PH",
    "name": "Santa Maria",
    "lat": "15.08672",
    "lng": "120.76991"
  },
  {
    "country": "PH",
    "name": "Santa Maria",
    "lat": "14.82083",
    "lng": "120.96361"
  },
  {
    "country": "PH",
    "name": "Santa Maria",
    "lat": "14.4719",
    "lng": "121.4286"
  },
  {
    "country": "PH",
    "name": "Santa Maria",
    "lat": "12.57883",
    "lng": "121.46041"
  },
  {
    "country": "PH",
    "name": "Santa Maria",
    "lat": "8.03333",
    "lng": "126.1625"
  },
  {
    "country": "PH",
    "name": "Santa Maria",
    "lat": "7.99167",
    "lng": "126.445"
  },
  {
    "country": "PH",
    "name": "Santa Maria",
    "lat": "6.55361",
    "lng": "125.47083"
  },
  {
    "country": "PH",
    "name": "Santa Margarita",
    "lat": "12.03778",
    "lng": "124.65778"
  },
  {
    "country": "PH",
    "name": "Santa Marcela",
    "lat": "18.28333",
    "lng": "121.43333"
  },
  {
    "country": "PH",
    "name": "Santa Magdalena",
    "lat": "12.648",
    "lng": "124.1093"
  },
  {
    "country": "PH",
    "name": "Santa Lucia",
    "lat": "17.1175",
    "lng": "120.45306"
  },
  {
    "country": "PH",
    "name": "Santa Lucia",
    "lat": "15.48184",
    "lng": "120.77456"
  },
  {
    "country": "PH",
    "name": "Santa Lucia",
    "lat": "15.36806",
    "lng": "120.48643"
  },
  {
    "country": "PH",
    "name": "Santa Lucia",
    "lat": "15.2097",
    "lng": "121.0061"
  },
  {
    "country": "PH",
    "name": "Santa Lucia",
    "lat": "14.0349",
    "lng": "121.4312"
  },
  {
    "country": "PH",
    "name": "Santa Justina",
    "lat": "13.3967",
    "lng": "123.4731"
  },
  {
    "country": "PH",
    "name": "Santa Juliana",
    "lat": "15.32826",
    "lng": "120.42863"
  },
  {
    "country": "PH",
    "name": "Santa Josefa",
    "lat": "7.99111",
    "lng": "126.03"
  },
  {
    "country": "PH",
    "name": "Santa Ines West",
    "lat": "15.55694",
    "lng": "120.46448"
  },
  {
    "country": "PH",
    "name": "Santa Ignacia",
    "lat": "15.6169",
    "lng": "120.4358"
  },
  {
    "country": "PH",
    "name": "Santa Filomena",
    "lat": "9.75181",
    "lng": "123.34463"
  },
  {
    "country": "PH",
    "name": "Santa Fe",
    "lat": "16.1595",
    "lng": "120.9381"
  },
  {
    "country": "PH",
    "name": "Santa Fe",
    "lat": "15.0103",
    "lng": "120.2102"
  },
  {
    "country": "PH",
    "name": "Santa Fe",
    "lat": "12.15656",
    "lng": "121.99411"
  },
  {
    "country": "PH",
    "name": "Santa Fe",
    "lat": "11.18556",
    "lng": "124.91611"
  },
  {
    "country": "PH",
    "name": "Santa Fe",
    "lat": "11.1544",
    "lng": "123.8058"
  },
  {
    "country": "PH",
    "name": "Santa Fe",
    "lat": "10.2375",
    "lng": "124.77194"
  },
  {
    "country": "PH",
    "name": "Santa Fe",
    "lat": "8.3425",
    "lng": "124.78083"
  },
  {
    "country": "PH",
    "name": "Santa Elena",
    "lat": "14.17023",
    "lng": "122.38246"
  },
  {
    "country": "PH",
    "name": "Santa Cruz",
    "lat": "18.51646",
    "lng": "121.31052"
  },
  {
    "country": "PH",
    "name": "Santa Cruz",
    "lat": "17.08556",
    "lng": "120.45222"
  },
  {
    "country": "PH",
    "name": "Santa Cruz",
    "lat": "15.7654",
    "lng": "119.9092"
  },
  {
    "country": "PH",
    "name": "Santa Cruz",
    "lat": "15.30815",
    "lng": "120.85318"
  },
  {
    "country": "PH",
    "name": "Santa Cruz",
    "lat": "14.9127",
    "lng": "120.56659"
  },
  {
    "country": "PH",
    "name": "Santa Cruz",
    "lat": "14.2814",
    "lng": "121.4161"
  },
  {
    "country": "PH",
    "name": "Santa Cruz",
    "lat": "14.11667",
    "lng": "121.28333"
  },
  {
    "country": "PH",
    "name": "Santa Cruz",
    "lat": "14.02056",
    "lng": "121.35722"
  },
  {
    "country": "PH",
    "name": "Santa Cruz",
    "lat": "13.865",
    "lng": "121.1887"
  },
  {
    "country": "PH",
    "name": "Santa Cruz",
    "lat": "13.4758",
    "lng": "122.0275"
  },
  {
    "country": "PH",
    "name": "Santa Cruz",
    "lat": "13.0736",
    "lng": "120.7226"
  },
  {
    "country": "PH",
    "name": "Santa Cruz",
    "lat": "12.8763",
    "lng": "124.0566"
  },
  {
    "country": "PH",
    "name": "Santa Cruz",
    "lat": "10.6514",
    "lng": "124.3386"
  },
  {
    "country": "PH",
    "name": "Santa Cruz",
    "lat": "10.63376",
    "lng": "123.0821"
  },
  {
    "country": "PH",
    "name": "Santa Cruz",
    "lat": "10.0068",
    "lng": "123.414"
  },
  {
    "country": "PH",
    "name": "Santa Cruz",
    "lat": "9.5352",
    "lng": "123.1054"
  },
  {
    "country": "PH",
    "name": "Santa Cruz",
    "lat": "6.83694",
    "lng": "125.41306"
  },
  {
    "country": "PH",
    "name": "Santa Clara",
    "lat": "13.75361",
    "lng": "121.06056"
  },
  {
    "country": "PH",
    "name": "Santa Clara",
    "lat": "6.6782",
    "lng": "122.06"
  },
  {
    "country": "PH",
    "name": "Santa Cecilia",
    "lat": "14.1054",
    "lng": "122.2016"
  },
  {
    "country": "PH",
    "name": "Santa Catalina Sur",
    "lat": "13.87384",
    "lng": "121.43104"
  },
  {
    "country": "PH",
    "name": "Santa Catalina Norte",
    "lat": "13.87083",
    "lng": "121.3575"
  },
  {
    "country": "PH",
    "name": "Santa Catalina",
    "lat": "17.59667",
    "lng": "120.35917"
  },
  {
    "country": "PH",
    "name": "Santa Catalina",
    "lat": "14.1213",
    "lng": "121.3419"
  },
  {
    "country": "PH",
    "name": "Santa Catalina",
    "lat": "9.3337",
    "lng": "122.8637"
  },
  {
    "country": "PH",
    "name": "Santa Brigida",
    "lat": "12.56783",
    "lng": "121.48901"
  },
  {
    "country": "PH",
    "name": "Santa Barbara",
    "lat": "16.0009",
    "lng": "120.4023"
  },
  {
    "country": "PH",
    "name": "Santa Barbara",
    "lat": "15.38494",
    "lng": "120.79611"
  },
  {
    "country": "PH",
    "name": "Santa Barbara",
    "lat": "10.82306",
    "lng": "122.53444"
  },
  {
    "country": "PH",
    "name": "Santa Ana",
    "lat": "18.46986",
    "lng": "122.14775"
  },
  {
    "country": "PH",
    "name": "Santa Ana",
    "lat": "15.0955",
    "lng": "120.767"
  },
  {
    "country": "PH",
    "name": "Santa Ana",
    "lat": "9.19278",
    "lng": "125.56444"
  },
  {
    "country": "PH",
    "name": "Santa Ana",
    "lat": "8.51667",
    "lng": "124.78333"
  },
  {
    "country": "PH",
    "name": "Santa",
    "lat": "17.486",
    "lng": "120.4348"
  },
  {
    "country": "PH",
    "name": "San Simon",
    "lat": "14.9996",
    "lng": "120.7808"
  },
  {
    "country": "PH",
    "name": "San Sebastian",
    "lat": "17.62327",
    "lng": "120.36352"
  },
  {
    "country": "PH",
    "name": "San Sebastian",
    "lat": "13.7283",
    "lng": "123.5939"
  },
  {
    "country": "PH",
    "name": "San Sebastian",
    "lat": "11.71",
    "lng": "125.01806"
  },
  {
    "country": "PH",
    "name": "San Roque Dau First",
    "lat": "14.97711",
    "lng": "120.57688"
  },
  {
    "country": "PH",
    "name": "San Roque",
    "lat": "13.15472",
    "lng": "123.75417"
  },
  {
    "country": "PH",
    "name": "San Roque",
    "lat": "15.26146",
    "lng": "120.65183"
  },
  {
    "country": "PH",
    "name": "San Roque",
    "lat": "15.00946",
    "lng": "120.93831"
  },
  {
    "country": "PH",
    "name": "San Roque",
    "lat": "13.2837",
    "lng": "123.7422"
  },
  {
    "country": "PH",
    "name": "San Roque",
    "lat": "12.7393",
    "lng": "124.0839"
  },
  {
    "country": "PH",
    "name": "San Roque",
    "lat": "12.53333",
    "lng": "124.86667"
  },
  {
    "country": "PH",
    "name": "San Roque",
    "lat": "11.05",
    "lng": "125.01667"
  },
  {
    "country": "PH",
    "name": "San Roque",
    "lat": "10.6043",
    "lng": "123.7441"
  },
  {
    "country": "PH",
    "name": "San Roque",
    "lat": "10.0919",
    "lng": "124.32262"
  },
  {
    "country": "PH",
    "name": "San Ricardo",
    "lat": "15.5959",
    "lng": "120.9727"
  },
  {
    "country": "PH",
    "name": "San Ricardo",
    "lat": "9.9128",
    "lng": "125.2767"
  },
  {
    "country": "PH",
    "name": "San Remigio",
    "lat": "11.0809",
    "lng": "123.9381"
  },
  {
    "country": "PH",
    "name": "San Remigio",
    "lat": "10.83278",
    "lng": "122.0875"
  },
  {
    "country": "PH",
    "name": "San Ramon",
    "lat": "17.4135",
    "lng": "120.7076"
  },
  {
    "country": "PH",
    "name": "San Ramon",
    "lat": "13.7221",
    "lng": "123.54"
  },
  {
    "country": "PH",
    "name": "San Ramon",
    "lat": "13.6181",
    "lng": "123.0383"
  },
  {
    "country": "PH",
    "name": "San Rafael",
    "lat": "14.94833",
    "lng": "120.96222"
  },
  {
    "country": "PH",
    "name": "San Rafael",
    "lat": "14.89906",
    "lng": "120.69352"
  },
  {
    "country": "PH",
    "name": "San Rafael",
    "lat": "14.1284",
    "lng": "121.4147"
  },
  {
    "country": "PH",
    "name": "San Rafael",
    "lat": "13.21667",
    "lng": "123.6"
  },
  {
    "country": "PH",
    "name": "San Rafael",
    "lat": "13.09417",
    "lng": "122.96"
  },
  {
    "country": "PH",
    "name": "San Rafael",
    "lat": "12.8905",
    "lng": "123.6823"
  },
  {
    "country": "PH",
    "name": "San Rafael",
    "lat": "11.1781",
    "lng": "122.8273"
  },
  {
    "country": "PH",
    "name": "San Rafael",
    "lat": "7.76389",
    "lng": "126.45583"
  },
  {
    "country": "PH",
    "name": "San Quintin",
    "lat": "17.5424",
    "lng": "120.5199"
  },
  {
    "country": "PH",
    "name": "San Quintin",
    "lat": "15.9854",
    "lng": "120.8132"
  },
  {
    "country": "PH",
    "name": "Sonquil",
    "lat": "15.98814",
    "lng": "120.39057"
  },
  {
    "country": "PH",
    "name": "San Policarpo",
    "lat": "12.1791",
    "lng": "125.5072"
  },
  {
    "country": "PH",
    "name": "San Policarpio",
    "lat": "12.0686",
    "lng": "124.5695"
  },
  {
    "country": "PH",
    "name": "San Pedro Apartado",
    "lat": "15.83702",
    "lng": "120.56521"
  },
  {
    "country": "PH",
    "name": "San Pedro",
    "lat": "17.2",
    "lng": "121.88333"
  },
  {
    "country": "PH",
    "name": "San Pedro",
    "lat": "14.3595",
    "lng": "121.0473"
  },
  {
    "country": "PH",
    "name": "San Pedro One",
    "lat": "14.05341",
    "lng": "121.14536"
  },
  {
    "country": "PH",
    "name": "San Pedro",
    "lat": "12.46084",
    "lng": "121.01041"
  },
  {
    "country": "PH",
    "name": "San Pedro",
    "lat": "12.01667",
    "lng": "124"
  },
  {
    "country": "PH",
    "name": "San Pedro",
    "lat": "10.961",
    "lng": "124.8197"
  },
  {
    "country": "PH",
    "name": "San Pedro",
    "lat": "10.8018",
    "lng": "121.9499"
  },
  {
    "country": "PH",
    "name": "San Pedro",
    "lat": "7.34194",
    "lng": "126.5175"
  },
  {
    "country": "PH",
    "name": "San Patricio",
    "lat": "15.09775",
    "lng": "120.72876"
  },
  {
    "country": "PH",
    "name": "Lloren",
    "lat": "16.3331",
    "lng": "120.4329"
  },
  {
    "country": "PH",
    "name": "San Pascual",
    "lat": "13.81045",
    "lng": "121.022"
  },
  {
    "country": "PH",
    "name": "San Pascual",
    "lat": "13.12888",
    "lng": "122.97709"
  },
  {
    "country": "PH",
    "name": "San Pascual",
    "lat": "9.9538",
    "lng": "124.4287"
  },
  {
    "country": "PH",
    "name": "San Pablo",
    "lat": "14.0683",
    "lng": "121.3256"
  },
  {
    "country": "PH",
    "name": "San Pablo",
    "lat": "10.91234",
    "lng": "123.1418"
  },
  {
    "country": "PH",
    "name": "San Pablo",
    "lat": "7.65639",
    "lng": "123.46083"
  },
  {
    "country": "PH",
    "name": "San Nicolas",
    "lat": "18.1725",
    "lng": "120.5953"
  },
  {
    "country": "PH",
    "name": "San Nicolas",
    "lat": "16.0703",
    "lng": "120.7624"
  },
  {
    "country": "PH",
    "name": "San Nicolas",
    "lat": "15.5841",
    "lng": "120.6765"
  },
  {
    "country": "PH",
    "name": "San Nicolas",
    "lat": "15.04176",
    "lng": "120.79443"
  },
  {
    "country": "PH",
    "name": "San Nicolas",
    "lat": "14.94909",
    "lng": "120.07703"
  },
  {
    "country": "PH",
    "name": "San Nicolas",
    "lat": "13.92825",
    "lng": "120.951"
  },
  {
    "country": "PH",
    "name": "San Nicolas",
    "lat": "11.3213",
    "lng": "122.5184"
  },
  {
    "country": "PH",
    "name": "San Nicolas",
    "lat": "10.68444",
    "lng": "122.49556"
  },
  {
    "country": "PH",
    "name": "San Narciso",
    "lat": "15.0143",
    "lng": "120.0803"
  },
  {
    "country": "PH",
    "name": "San Narciso",
    "lat": "13.5677",
    "lng": "122.5667"
  },
  {
    "country": "PH",
    "name": "San Miguel",
    "lat": "15.44397",
    "lng": "120.59923"
  },
  {
    "country": "PH",
    "name": "San Miguel",
    "lat": "15.1423",
    "lng": "120.97568"
  },
  {
    "country": "PH",
    "name": "San Miguel",
    "lat": "14.2013",
    "lng": "121.3732"
  },
  {
    "country": "PH",
    "name": "San Miguel",
    "lat": "13.874",
    "lng": "121.1983"
  },
  {
    "country": "PH",
    "name": "San Miguel",
    "lat": "13.6414",
    "lng": "124.3026"
  },
  {
    "country": "PH",
    "name": "San Miguel",
    "lat": "13.4196",
    "lng": "123.4082"
  },
  {
    "country": "PH",
    "name": "San Miguel",
    "lat": "11.26722",
    "lng": "124.8325"
  },
  {
    "country": "PH",
    "name": "San Miguel",
    "lat": "11.2146",
    "lng": "122.5425"
  },
  {
    "country": "PH",
    "name": "San Miguel",
    "lat": "10.78",
    "lng": "122.46556"
  },
  {
    "country": "PH",
    "name": "San Miguel",
    "lat": "10.59606",
    "lng": "122.5899"
  },
  {
    "country": "PH",
    "name": "San Miguel",
    "lat": "10.53856",
    "lng": "123.083"
  },
  {
    "country": "PH",
    "name": "San Miguel",
    "lat": "10.4154",
    "lng": "123.0214"
  },
  {
    "country": "PH",
    "name": "San Miguel",
    "lat": "9.9869",
    "lng": "124.3411"
  },
  {
    "country": "PH",
    "name": "San Miguel",
    "lat": "9.8851",
    "lng": "124.3264"
  },
  {
    "country": "PH",
    "name": "San Miguel",
    "lat": "9.2239",
    "lng": "123.2853"
  },
  {
    "country": "PH",
    "name": "San Miguel",
    "lat": "8.96889",
    "lng": "125.945"
  },
  {
    "country": "PH",
    "name": "San Miguel",
    "lat": "8.03",
    "lng": "124.75389"
  },
  {
    "country": "PH",
    "name": "San Miguel",
    "lat": "7.64833",
    "lng": "123.2675"
  },
  {
    "country": "PH",
    "name": "San Miguel",
    "lat": "7.485",
    "lng": "125.67639"
  },
  {
    "country": "PH",
    "name": "San Miguel",
    "lat": "6.49245",
    "lng": "124.69643"
  },
  {
    "country": "PH",
    "name": "San Mateo",
    "lat": "17.13754",
    "lng": "121.74534"
  },
  {
    "country": "PH",
    "name": "San Mateo",
    "lat": "16.88206",
    "lng": "121.58694"
  },
  {
    "country": "PH",
    "name": "San Mateo",
    "lat": "15.20008",
    "lng": "120.7946"
  },
  {
    "country": "PH",
    "name": "San Mateo",
    "lat": "14.6982",
    "lng": "121.1236"
  },
  {
    "country": "PH",
    "name": "San Martin",
    "lat": "8.56111",
    "lng": "124.77139"
  },
  {
    "country": "PH",
    "name": "San Mariano",
    "lat": "16.98265",
    "lng": "122.01404"
  },
  {
    "country": "PH",
    "name": "San Mariano",
    "lat": "15.32083",
    "lng": "120.87609"
  },
  {
    "country": "PH",
    "name": "San Mariano",
    "lat": "12.64143",
    "lng": "121.43791"
  },
  {
    "country": "PH",
    "name": "San Mariano",
    "lat": "7.5",
    "lng": "126"
  },
  {
    "country": "PH",
    "name": "San Marcelino",
    "lat": "14.97418",
    "lng": "120.15733"
  },
  {
    "country": "PH",
    "name": "San Manuel",
    "lat": "17.02375",
    "lng": "121.63574"
  },
  {
    "country": "PH",
    "name": "San Manuel",
    "lat": "16.0647",
    "lng": "120.6687"
  },
  {
    "country": "PH",
    "name": "San Manuel",
    "lat": "15.79917",
    "lng": "120.60861"
  },
  {
    "country": "PH",
    "name": "San Manuel",
    "lat": "15.49053",
    "lng": "120.66543"
  },
  {
    "country": "PH",
    "name": "San Luis",
    "lat": "16.96455",
    "lng": "121.82784"
  },
  {
    "country": "PH",
    "name": "San Luis",
    "lat": "15.7208",
    "lng": "121.5205"
  },
  {
    "country": "PH",
    "name": "San Luis",
    "lat": "15.0401",
    "lng": "120.7883"
  },
  {
    "country": "PH",
    "name": "San Luis",
    "lat": "13.85469",
    "lng": "120.91653"
  },
  {
    "country": "PH",
    "name": "San Luis",
    "lat": "8.47806",
    "lng": "125.74389"
  },
  {
    "country": "PH",
    "name": "San Luis",
    "lat": "8.48333",
    "lng": "125"
  },
  {
    "country": "PH",
    "name": "San Luis",
    "lat": "7.44139",
    "lng": "126.55111"
  },
  {
    "country": "PH",
    "name": "San Lucas",
    "lat": "13.7062",
    "lng": "123.2032"
  },
  {
    "country": "PH",
    "name": "San Lorenzo",
    "lat": "18.1323",
    "lng": "120.6305"
  },
  {
    "country": "PH",
    "name": "San Lorenzo",
    "lat": "15.4862",
    "lng": "119.9622"
  },
  {
    "country": "PH",
    "name": "Sanlibo",
    "lat": "15.91667",
    "lng": "120.55"
  },
  {
    "country": "PH",
    "name": "San Leonardo",
    "lat": "15.363",
    "lng": "120.9639"
  },
  {
    "country": "PH",
    "name": "Sankanan",
    "lat": "8.31556",
    "lng": "124.85806"
  },
  {
    "country": "PH",
    "name": "San Julian",
    "lat": "11.75361",
    "lng": "125.45583"
  },
  {
    "country": "PH",
    "name": "San Juan de Mata",
    "lat": "15.5352",
    "lng": "120.5302"
  },
  {
    "country": "PH",
    "name": "San Juan",
    "lat": "17.74222",
    "lng": "120.45833"
  },
  {
    "country": "PH",
    "name": "San Juan",
    "lat": "17.6829",
    "lng": "120.7324"
  },
  {
    "country": "PH",
    "name": "San Juan",
    "lat": "17.40562",
    "lng": "121.74745"
  },
  {
    "country": "PH",
    "name": "San Juan",
    "lat": "16.66861",
    "lng": "120.34139"
  },
  {
    "country": "PH",
    "name": "San Juan",
    "lat": "15.2897",
    "lng": "120.0648"
  },
  {
    "country": "PH",
    "name": "San Juan",
    "lat": "15.0231",
    "lng": "120.67714"
  },
  {
    "country": "PH",
    "name": "San Juan",
    "lat": "14.6",
    "lng": "121.0333"
  },
  {
    "country": "PH",
    "name": "San Juan",
    "lat": "14.05715",
    "lng": "121.22931"
  },
  {
    "country": "PH",
    "name": "San Juan",
    "lat": "13.83379",
    "lng": "121.3982"
  },
  {
    "country": "PH",
    "name": "San Juan",
    "lat": "13.5232",
    "lng": "122.5813"
  },
  {
    "country": "PH",
    "name": "San Juan",
    "lat": "11.00056",
    "lng": "124.53917"
  },
  {
    "country": "PH",
    "name": "San Juan",
    "lat": "10.3865",
    "lng": "122.8651"
  },
  {
    "country": "PH",
    "name": "San Juan",
    "lat": "10.26694",
    "lng": "125.17556"
  },
  {
    "country": "PH",
    "name": "San Juan",
    "lat": "9.1603",
    "lng": "123.4926"
  },
  {
    "country": "PH",
    "name": "Malino",
    "lat": "15.12695",
    "lng": "120.67431"
  },
  {
    "country": "PH",
    "name": "San Jose del Monte",
    "lat": "14.81389",
    "lng": "121.04528"
  },
  {
    "country": "PH",
    "name": "San Jose de Buan",
    "lat": "12.0529",
    "lng": "125.0251"
  },
  {
    "country": "PH",
    "name": "San Jose",
    "lat": "17.89269",
    "lng": "121.87125"
  },
  {
    "country": "PH",
    "name": "San Jose",
    "lat": "17.15",
    "lng": "121.6"
  },
  {
    "country": "PH",
    "name": "Tabacao",
    "lat": "15.64973",
    "lng": "120.94066"
  },
  {
    "country": "PH",
    "name": "San Jose",
    "lat": "15.0333",
    "lng": "120.7833"
  },
  {
    "country": "PH",
    "name": "San Jose",
    "lat": "13.8784",
    "lng": "121.1045"
  },
  {
    "country": "PH",
    "name": "San Jose",
    "lat": "13.85209",
    "lng": "120.94951"
  },
  {
    "country": "PH",
    "name": "San Jose",
    "lat": "13.6993",
    "lng": "123.5178"
  },
  {
    "country": "PH",
    "name": "San Jose",
    "lat": "13.35",
    "lng": "123.55"
  },
  {
    "country": "PH",
    "name": "San Jose",
    "lat": "13.24629",
    "lng": "123.37136"
  },
  {
    "country": "PH",
    "name": "San Jose",
    "lat": "12.5296",
    "lng": "124.4875"
  },
  {
    "country": "PH",
    "name": "San Jose",
    "lat": "12.35275",
    "lng": "121.06761"
  },
  {
    "country": "PH",
    "name": "Agcogon",
    "lat": "12.06146",
    "lng": "121.95911"
  },
  {
    "country": "PH",
    "name": "San Jose",
    "lat": "10.98889",
    "lng": "125.03528"
  },
  {
    "country": "PH",
    "name": "San Jose",
    "lat": "10.77028",
    "lng": "122.53389"
  },
  {
    "country": "PH",
    "name": "San Jose",
    "lat": "10.745",
    "lng": "121.9415"
  },
  {
    "country": "PH",
    "name": "San Jose",
    "lat": "10.18",
    "lng": "125.56833"
  },
  {
    "country": "PH",
    "name": "San Jose",
    "lat": "9.80056",
    "lng": "118.75694"
  },
  {
    "country": "PH",
    "name": "San Jose",
    "lat": "9.41194",
    "lng": "123.23806"
  },
  {
    "country": "PH",
    "name": "San Jose",
    "lat": "7.73667",
    "lng": "125.07028"
  },
  {
    "country": "PH",
    "name": "San Jorge",
    "lat": "11.98083",
    "lng": "124.82389"
  },
  {
    "country": "PH",
    "name": "San Joaquin",
    "lat": "14.04695",
    "lng": "121.21864"
  },
  {
    "country": "PH",
    "name": "San Joaquin",
    "lat": "12.16697",
    "lng": "124.43003"
  },
  {
    "country": "PH",
    "name": "San Joaquin",
    "lat": "10.588",
    "lng": "122.1397"
  },
  {
    "country": "PH",
    "name": "San Jacinto",
    "lat": "16.0726",
    "lng": "120.4383"
  },
  {
    "country": "PH",
    "name": "San Jacinto",
    "lat": "15.54496",
    "lng": "120.66959"
  },
  {
    "country": "PH",
    "name": "San Jacinto",
    "lat": "12.5677",
    "lng": "123.7337"
  },
  {
    "country": "PH",
    "name": "Catigbian",
    "lat": "9.8501",
    "lng": "123.9994"
  },
  {
    "country": "PH",
    "name": "Laug",
    "lat": "15.04659",
    "lng": "120.75149"
  },
  {
    "country": "PH",
    "name": "San Isidro",
    "lat": "17.465",
    "lng": "120.6035"
  },
  {
    "country": "PH",
    "name": "San Isidro",
    "lat": "16.73333",
    "lng": "121.61667"
  },
  {
    "country": "PH",
    "name": "San Isidro",
    "lat": "15.23507",
    "lng": "120.64134"
  },
  {
    "country": "PH",
    "name": "San Isidro",
    "lat": "15.02116",
    "lng": "120.82019"
  },
  {
    "country": "PH",
    "name": "San Isidro",
    "lat": "14.2086",
    "lng": "121.3983"
  },
  {
    "country": "PH",
    "name": "San Isidro",
    "lat": "14.03353",
    "lng": "121.1095"
  },
  {
    "country": "PH",
    "name": "San Isidro",
    "lat": "13.7686",
    "lng": "121.2308"
  },
  {
    "country": "PH",
    "name": "San Isidro",
    "lat": "13.6325",
    "lng": "122.2428"
  },
  {
    "country": "PH",
    "name": "San Isidro",
    "lat": "12.97417",
    "lng": "123.85722"
  },
  {
    "country": "PH",
    "name": "San Isidro",
    "lat": "12.38806",
    "lng": "124.33139"
  },
  {
    "country": "PH",
    "name": "San Isidro",
    "lat": "11.4062",
    "lng": "124.3521"
  },
  {
    "country": "PH",
    "name": "San Isidro",
    "lat": "10.9629",
    "lng": "124.4304"
  },
  {
    "country": "PH",
    "name": "San Isidro",
    "lat": "10.5508",
    "lng": "123.7335"
  },
  {
    "country": "PH",
    "name": "San Isidro",
    "lat": "9.93694",
    "lng": "126.08861"
  },
  {
    "country": "PH",
    "name": "San Isidro",
    "lat": "9.91667",
    "lng": "123.88333"
  },
  {
    "country": "PH",
    "name": "San Isidro",
    "lat": "9.7712",
    "lng": "124.2527"
  },
  {
    "country": "PH",
    "name": "San Isidro",
    "lat": "8.25833",
    "lng": "124.59306"
  },
  {
    "country": "PH",
    "name": "Batobato",
    "lat": "6.82522",
    "lng": "126.08458"
  },
  {
    "country": "PH",
    "name": "San Ildefonso",
    "lat": "17.62222",
    "lng": "120.39667"
  },
  {
    "country": "PH",
    "name": "San Ildefonso",
    "lat": "15.0809",
    "lng": "120.941"
  },
  {
    "country": "PH",
    "name": "San Ignacio",
    "lat": "7.1189",
    "lng": "126.48838"
  },
  {
    "country": "PH",
    "name": "San Guillermo",
    "lat": "16.7254",
    "lng": "121.8098"
  },
  {
    "country": "PH",
    "name": "San Gregorio",
    "lat": "14.0297",
    "lng": "121.2639"
  },
  {
    "country": "PH",
    "name": "Sanghan",
    "lat": "9.08556",
    "lng": "125.57278"
  },
  {
    "country": "PH",
    "name": "Sangay",
    "lat": "6.445",
    "lng": "124.04444"
  },
  {
    "country": "PH",
    "name": "Sangat",
    "lat": "10.136",
    "lng": "123.6896"
  },
  {
    "country": "PH",
    "name": "San Gabriel",
    "lat": "16.67556",
    "lng": "120.40306"
  },
  {
    "country": "PH",
    "name": "San Gabriel First",
    "lat": "15.7665",
    "lng": "120.45655"
  },
  {
    "country": "PH",
    "name": "San Gabriel",
    "lat": "13.56667",
    "lng": "123.1"
  },
  {
    "country": "PH",
    "name": "Del Monte",
    "lat": "14.6418",
    "lng": "121.0177"
  },
  {
    "country": "PH",
    "name": "San Francisco",
    "lat": "15.6289",
    "lng": "120.43637"
  },
  {
    "country": "PH",
    "name": "San Francisco",
    "lat": "15.35566",
    "lng": "120.84001"
  },
  {
    "country": "PH",
    "name": "San Francisco",
    "lat": "14.96154",
    "lng": "120.54526"
  },
  {
    "country": "PH",
    "name": "San Francisco",
    "lat": "13.89806",
    "lng": "121.24806"
  },
  {
    "country": "PH",
    "name": "San Francisco",
    "lat": "13.7911",
    "lng": "122.2876"
  },
  {
    "country": "PH",
    "name": "Aurora",
    "lat": "13.3476",
    "lng": "122.5195"
  },
  {
    "country": "PH",
    "name": "San Francisco",
    "lat": "13.31667",
    "lng": "123.75"
  },
  {
    "country": "PH",
    "name": "San Francisco",
    "lat": "13.0367",
    "lng": "123.7832"
  },
  {
    "country": "PH",
    "name": "San Francisco",
    "lat": "12.72472",
    "lng": "123.90639"
  },
  {
    "country": "PH",
    "name": "San Francisco",
    "lat": "11.31961",
    "lng": "122.05051"
  },
  {
    "country": "PH",
    "name": "San Francisco",
    "lat": "10.6461",
    "lng": "124.3816"
  },
  {
    "country": "PH",
    "name": "San Francisco",
    "lat": "10.16018",
    "lng": "124.31098"
  },
  {
    "country": "PH",
    "name": "San Francisco",
    "lat": "10.06",
    "lng": "125.16056"
  },
  {
    "country": "PH",
    "name": "San Francisco",
    "lat": "9.77694",
    "lng": "125.42472"
  },
  {
    "country": "PH",
    "name": "San Francisco",
    "lat": "9.52806",
    "lng": "125.48556"
  },
  {
    "country": "PH",
    "name": "San Francisco",
    "lat": "8.53556",
    "lng": "125.95"
  },
  {
    "country": "PH",
    "name": "San Fernando",
    "lat": "16.61591",
    "lng": "120.31663"
  },
  {
    "country": "PH",
    "name": "San Fernando",
    "lat": "16.3892",
    "lng": "121.1324"
  },
  {
    "country": "PH",
    "name": "San Fernando",
    "lat": "15.03425",
    "lng": "120.68445"
  },
  {
    "country": "PH",
    "name": "San Fernando",
    "lat": "13.5656",
    "lng": "123.1453"
  },
  {
    "country": "PH",
    "name": "San Fernando",
    "lat": "12.4833",
    "lng": "123.7622"
  },
  {
    "country": "PH",
    "name": "San Fernando",
    "lat": "12.30364",
    "lng": "122.60041"
  },
  {
    "country": "PH",
    "name": "San Fernando",
    "lat": "11.4585",
    "lng": "123.2499"
  },
  {
    "country": "PH",
    "name": "San Fernando",
    "lat": "10.709",
    "lng": "123.0695"
  },
  {
    "country": "PH",
    "name": "San Fernando",
    "lat": "10.1624",
    "lng": "123.7076"
  },
  {
    "country": "PH",
    "name": "San Felipe",
    "lat": "15.82608",
    "lng": "120.59755"
  },
  {
    "country": "PH",
    "name": "San Felipe Old",
    "lat": "15.5014",
    "lng": "120.9078"
  },
  {
    "country": "PH",
    "name": "Poblacion, San Felipe",
    "lat": "15.06222",
    "lng": "120.07"
  },
  {
    "country": "PH",
    "name": "San Felipe",
    "lat": "14.0184",
    "lng": "122.9295"
  },
  {
    "country": "PH",
    "name": "San Fabian",
    "lat": "16.1231",
    "lng": "120.4056"
  },
  {
    "country": "PH",
    "name": "San Fabian",
    "lat": "15.59629",
    "lng": "120.90663"
  },
  {
    "country": "PH",
    "name": "San Eugenio",
    "lat": "16.3598",
    "lng": "120.357"
  },
  {
    "country": "PH",
    "name": "San Esteban",
    "lat": "17.3299",
    "lng": "120.4451"
  },
  {
    "country": "PH",
    "name": "San Enrique",
    "lat": "11.0712",
    "lng": "122.656"
  },
  {
    "country": "PH",
    "name": "San Enrique",
    "lat": "10.6539",
    "lng": "122.7172"
  },
  {
    "country": "PH",
    "name": "San Enrique",
    "lat": "10.4161",
    "lng": "122.8504"
  },
  {
    "country": "PH",
    "name": "San Emilio",
    "lat": "17.22611",
    "lng": "120.61167"
  },
  {
    "country": "PH",
    "name": "San Eduardo",
    "lat": "12.1679",
    "lng": "125.4503"
  },
  {
    "country": "PH",
    "name": "Sandolot",
    "lat": "9.10472",
    "lng": "123.01944"
  },
  {
    "country": "PH",
    "name": "San Dionisio",
    "lat": "11.271",
    "lng": "123.0964"
  },
  {
    "country": "PH",
    "name": "San Diego",
    "lat": "14.1872",
    "lng": "121.4867"
  },
  {
    "country": "PH",
    "name": "San Diego",
    "lat": "14.0422",
    "lng": "120.6255"
  },
  {
    "country": "PH",
    "name": "Sandiat Centro",
    "lat": "17.07295",
    "lng": "121.63752"
  },
  {
    "country": "PH",
    "name": "Sandayong Sur",
    "lat": "10.49583",
    "lng": "123.99889"
  },
  {
    "country": "PH",
    "name": "San Cristobal",
    "lat": "15.55382",
    "lng": "120.76703"
  },
  {
    "country": "PH",
    "name": "San Clemente",
    "lat": "15.7124",
    "lng": "120.359"
  },
  {
    "country": "PH",
    "name": "San Celestio",
    "lat": "13.9258",
    "lng": "121.2349"
  },
  {
    "country": "PH",
    "name": "San Casimiro",
    "lat": "15.55306",
    "lng": "120.78083"
  },
  {
    "country": "PH",
    "name": "San Carlos",
    "lat": "15.5448",
    "lng": "120.8931"
  },
  {
    "country": "PH",
    "name": "San Carlos",
    "lat": "15.03966",
    "lng": "120.76285"
  },
  {
    "country": "PH",
    "name": "San Carlos",
    "lat": "13.8422",
    "lng": "121.2416"
  },
  {
    "country": "PH",
    "name": "San Carlos",
    "lat": "7.95972",
    "lng": "125.0775"
  },
  {
    "country": "PH",
    "name": "San Bernardo",
    "lat": "17.40481",
    "lng": "121.75155"
  },
  {
    "country": "PH",
    "name": "San Benito",
    "lat": "14.85155",
    "lng": "120.42693"
  },
  {
    "country": "PH",
    "name": "San Benito",
    "lat": "9.95778",
    "lng": "126.00694"
  },
  {
    "country": "PH",
    "name": "San Basilio",
    "lat": "15.03341",
    "lng": "120.58427"
  },
  {
    "country": "PH",
    "name": "San Aquilino",
    "lat": "12.59743",
    "lng": "121.48671"
  },
  {
    "country": "PH",
    "name": "San Antonio",
    "lat": "17.27329",
    "lng": "121.79121"
  },
  {
    "country": "PH",
    "name": "San Antonio",
    "lat": "16.35028",
    "lng": "121.10917"
  },
  {
    "country": "PH",
    "name": "San Antonio",
    "lat": "15.3062",
    "lng": "120.856"
  },
  {
    "country": "PH",
    "name": "San Antonio",
    "lat": "15.28636",
    "lng": "120.67163"
  },
  {
    "country": "PH",
    "name": "San Antonio",
    "lat": "15.15258",
    "lng": "120.68817"
  },
  {
    "country": "PH",
    "name": "San Antonio",
    "lat": "14.96668",
    "lng": "120.61183"
  },
  {
    "country": "PH",
    "name": "San Antonio",
    "lat": "14.94659",
    "lng": "120.08673"
  },
  {
    "country": "PH",
    "name": "San Antonio",
    "lat": "14.2",
    "lng": "121.5"
  },
  {
    "country": "PH",
    "name": "San Antonio",
    "lat": "13.89654",
    "lng": "121.29017"
  },
  {
    "country": "PH",
    "name": "San Antonio",
    "lat": "13.371",
    "lng": "123.4202"
  },
  {
    "country": "PH",
    "name": "San Antonio",
    "lat": "12.4129",
    "lng": "124.2791"
  },
  {
    "country": "PH",
    "name": "San Antonio",
    "lat": "11.27682",
    "lng": "125.01141"
  },
  {
    "country": "PH",
    "name": "San Antonio",
    "lat": "10.8",
    "lng": "122.45"
  },
  {
    "country": "PH",
    "name": "San Antonio",
    "lat": "7.12",
    "lng": "125.73972"
  },
  {
    "country": "PH",
    "name": "San Anton",
    "lat": "15.3478",
    "lng": "120.91991"
  },
  {
    "country": "PH",
    "name": "San Andres",
    "lat": "15.71928",
    "lng": "120.77752"
  },
  {
    "country": "PH",
    "name": "San Andres",
    "lat": "14.05",
    "lng": "121.21667"
  },
  {
    "country": "PH",
    "name": "San Andres",
    "lat": "14.00353",
    "lng": "121.15137"
  },
  {
    "country": "PH",
    "name": "San Andres",
    "lat": "13.6",
    "lng": "124.1"
  },
  {
    "country": "PH",
    "name": "San Andres",
    "lat": "13.3227",
    "lng": "122.6779"
  },
  {
    "country": "PH",
    "name": "San Andres",
    "lat": "13.2614",
    "lng": "123.7795"
  },
  {
    "country": "PH",
    "name": "San Alfonso",
    "lat": "7.78028",
    "lng": "126.42028"
  },
  {
    "country": "PH",
    "name": "San Alejandro",
    "lat": "15.56098",
    "lng": "120.84896"
  },
  {
    "country": "PH",
    "name": "San Agustin",
    "lat": "14.9903",
    "lng": "120.606"
  },
  {
    "country": "PH",
    "name": "San Agustin",
    "lat": "14.93333",
    "lng": "120.15"
  },
  {
    "country": "PH",
    "name": "San Agustin",
    "lat": "13.574",
    "lng": "123.2641"
  },
  {
    "country": "PH",
    "name": "San Agustin",
    "lat": "13.3263",
    "lng": "123.4177"
  },
  {
    "country": "PH",
    "name": "San Agustin",
    "lat": "13.27729",
    "lng": "121.30482"
  },
  {
    "country": "PH",
    "name": "San Agustin",
    "lat": "12.56889",
    "lng": "122.13139"
  },
  {
    "country": "PH",
    "name": "San Agustin",
    "lat": "12.41984",
    "lng": "120.98931"
  },
  {
    "country": "PH",
    "name": "San Agustin",
    "lat": "9.63333",
    "lng": "123.78333"
  },
  {
    "country": "PH",
    "name": "Sampiro",
    "lat": "13.78417",
    "lng": "121.38417"
  },
  {
    "country": "PH",
    "name": "Sampao",
    "lat": "7.59389",
    "lng": "125.66111"
  },
  {
    "country": "PH",
    "name": "Sampao",
    "lat": "6.87667",
    "lng": "124.59556"
  },
  {
    "country": "PH",
    "name": "Sampaloc",
    "lat": "14.5402",
    "lng": "121.3602"
  },
  {
    "country": "PH",
    "name": "Sampaloc",
    "lat": "15.81667",
    "lng": "120.86667"
  },
  {
    "country": "PH",
    "name": "Sampaloc",
    "lat": "14.1627",
    "lng": "121.6396"
  },
  {
    "country": "PH",
    "name": "Sampaloc",
    "lat": "14.08776",
    "lng": "120.97098"
  },
  {
    "country": "PH",
    "name": "Sampagar",
    "lat": "7.51389",
    "lng": "124.95528"
  },
  {
    "country": "PH",
    "name": "Samon",
    "lat": "15.93495",
    "lng": "120.65074"
  },
  {
    "country": "PH",
    "name": "Sambuluan",
    "lat": "6.88333",
    "lng": "124.7"
  },
  {
    "country": "PH",
    "name": "Samboan",
    "lat": "9.5276",
    "lng": "123.3069"
  },
  {
    "country": "PH",
    "name": "Samal",
    "lat": "14.76778",
    "lng": "120.54306"
  },
  {
    "country": "PH",
    "name": "Samal",
    "lat": "7.07444",
    "lng": "125.70833"
  },
  {
    "country": "PH",
    "name": "San Salvador",
    "lat": "11.00278",
    "lng": "122.83528"
  },
  {
    "country": "PH",
    "name": "Salvador",
    "lat": "7.89528",
    "lng": "123.84361"
  },
  {
    "country": "PH",
    "name": "Salvacion I",
    "lat": "15.8396",
    "lng": "120.9159"
  },
  {
    "country": "PH",
    "name": "Salvacion",
    "lat": "13.6017",
    "lng": "123.4738"
  },
  {
    "country": "PH",
    "name": "Salvacion",
    "lat": "13.4633",
    "lng": "123.3765"
  },
  {
    "country": "PH",
    "name": "Salvacion",
    "lat": "13.06667",
    "lng": "123.61667"
  },
  {
    "country": "PH",
    "name": "Salvacion",
    "lat": "12.6151",
    "lng": "125.039"
  },
  {
    "country": "PH",
    "name": "Salvacion",
    "lat": "12.13287",
    "lng": "119.93281"
  },
  {
    "country": "PH",
    "name": "Salvacion",
    "lat": "10.68333",
    "lng": "122.61667"
  },
  {
    "country": "PH",
    "name": "Salvacion",
    "lat": "10.4441",
    "lng": "122.5332"
  },
  {
    "country": "PH",
    "name": "Salvacion",
    "lat": "8.71278",
    "lng": "126.20806"
  },
  {
    "country": "PH",
    "name": "Salvacion",
    "lat": "8.6775",
    "lng": "125.69917"
  },
  {
    "country": "PH",
    "name": "Salvacion",
    "lat": "7.99954",
    "lng": "126.1248"
  },
  {
    "country": "PH",
    "name": "Salug",
    "lat": "8.11472",
    "lng": "122.78333"
  },
  {
    "country": "PH",
    "name": "Salogon",
    "lat": "13.6586",
    "lng": "123.5225"
  },
  {
    "country": "PH",
    "name": "Salinungan Proper",
    "lat": "16.86906",
    "lng": "121.61454"
  },
  {
    "country": "PH",
    "name": "Salingogan",
    "lat": "13.4333",
    "lng": "123.1923"
  },
  {
    "country": "PH",
    "name": "Salinas",
    "lat": "16.3695",
    "lng": "121.0188"
  },
  {
    "country": "PH",
    "name": "Salimbao",
    "lat": "7.2225",
    "lng": "124.25333"
  },
  {
    "country": "PH",
    "name": "Salimbalan",
    "lat": "8.27417",
    "lng": "124.72194"
  },
  {
    "country": "PH",
    "name": "Salcedo",
    "lat": "17.15472",
    "lng": "120.53944"
  },
  {
    "country": "PH",
    "name": "Salcedo",
    "lat": "15.85722",
    "lng": "120.6"
  },
  {
    "country": "PH",
    "name": "Salcedo",
    "lat": "12.81052",
    "lng": "121.46742"
  },
  {
    "country": "PH",
    "name": "Salcedo",
    "lat": "11.14694",
    "lng": "125.665"
  },
  {
    "country": "PH",
    "name": "Salaza",
    "lat": "15.4541",
    "lng": "119.9553"
  },
  {
    "country": "PH",
    "name": "Salay",
    "lat": "8.85917",
    "lng": "124.78917"
  },
  {
    "country": "PH",
    "name": "Salawagan",
    "lat": "7.70528",
    "lng": "125.115"
  },
  {
    "country": "PH",
    "name": "Salapungan",
    "lat": "15.1339",
    "lng": "120.92794"
  },
  {
    "country": "PH",
    "name": "Salamanca",
    "lat": "10.74655",
    "lng": "123.53"
  },
  {
    "country": "PH",
    "name": "Saint Bernard",
    "lat": "10.28333",
    "lng": "125.18333"
  },
  {
    "country": "PH",
    "name": "Sagurong",
    "lat": "13.7805",
    "lng": "122.9594"
  },
  {
    "country": "PH",
    "name": "Sagunto",
    "lat": "16.2007",
    "lng": "120.5149"
  },
  {
    "country": "PH",
    "name": "Saguing",
    "lat": "6.98028",
    "lng": "125.07806"
  },
  {
    "country": "PH",
    "name": "Saguiaran",
    "lat": "8.03306",
    "lng": "124.27"
  },
  {
    "country": "PH",
    "name": "Sagud-Bahley",
    "lat": "16.11693",
    "lng": "120.39105"
  },
  {
    "country": "PH",
    "name": "Saguday",
    "lat": "16.5428",
    "lng": "121.5638"
  },
  {
    "country": "PH",
    "name": "Sagrada Familia",
    "lat": "13.269",
    "lng": "123.3977"
  },
  {
    "country": "PH",
    "name": "Sagrada",
    "lat": "13.5301",
    "lng": "123.4527"
  },
  {
    "country": "PH",
    "name": "Sagpon",
    "lat": "13.15",
    "lng": "123.73333"
  },
  {
    "country": "PH",
    "name": "Sagnay",
    "lat": "13.6029",
    "lng": "123.5225"
  },
  {
    "country": "PH",
    "name": "Sagbayan",
    "lat": "9.9144",
    "lng": "124.0919"
  },
  {
    "country": "PH",
    "name": "Sagay",
    "lat": "10.94472",
    "lng": "123.42417"
  },
  {
    "country": "PH",
    "name": "Sagay",
    "lat": "9.1059",
    "lng": "124.7243"
  },
  {
    "country": "PH",
    "name": "Sagasa",
    "lat": "10.468",
    "lng": "122.8939"
  },
  {
    "country": "PH",
    "name": "Sagasa",
    "lat": "6.77405",
    "lng": "124.57408"
  },
  {
    "country": "PH",
    "name": "Sagang",
    "lat": "10.3612",
    "lng": "123.0722"
  },
  {
    "country": "PH",
    "name": "Sagana",
    "lat": "15.5689",
    "lng": "121.1522"
  },
  {
    "country": "PH",
    "name": "Sagana",
    "lat": "12.72252",
    "lng": "121.48672"
  },
  {
    "country": "PH",
    "name": "Sagada",
    "lat": "17.084",
    "lng": "120.8996"
  },
  {
    "country": "PH",
    "name": "Sadsalan",
    "lat": "6.82906",
    "lng": "124.60893"
  },
  {
    "country": "PH",
    "name": "Sadsadan",
    "lat": "16.9333",
    "lng": "120.8667"
  },
  {
    "country": "PH",
    "name": "Sadanga",
    "lat": "17.16514",
    "lng": "121.01724"
  },
  {
    "country": "PH",
    "name": "Sabtang",
    "lat": "20.33566",
    "lng": "121.87157"
  },
  {
    "country": "PH",
    "name": "Sablig",
    "lat": "16.26887",
    "lng": "119.9877"
  },
  {
    "country": "PH",
    "name": "Sablayan",
    "lat": "12.8346",
    "lng": "120.769"
  },
  {
    "country": "PH",
    "name": "Sablan",
    "lat": "16.493",
    "lng": "120.4954"
  },
  {
    "country": "PH",
    "name": "Sabangan",
    "lat": "17.0036",
    "lng": "120.9232"
  },
  {
    "country": "PH",
    "name": "Sabang",
    "lat": "14.6951",
    "lng": "120.2507"
  },
  {
    "country": "PH",
    "name": "Sabang",
    "lat": "14.30556",
    "lng": "120.80361"
  },
  {
    "country": "PH",
    "name": "Sabang Indan",
    "lat": "14.2194",
    "lng": "122.9151"
  },
  {
    "country": "PH",
    "name": "Sabang",
    "lat": "14.06333",
    "lng": "120.71111"
  },
  {
    "country": "PH",
    "name": "Sabang",
    "lat": "13.7218",
    "lng": "123.5781"
  },
  {
    "country": "PH",
    "name": "Sabang",
    "lat": "13.5092",
    "lng": "120.9737"
  },
  {
    "country": "PH",
    "name": "Sabang",
    "lat": "12.73333",
    "lng": "123.93333"
  },
  {
    "country": "PH",
    "name": "Saavedra",
    "lat": "9.98517",
    "lng": "123.37158"
  },
  {
    "country": "PH",
    "name": "Roxas",
    "lat": "17.11894",
    "lng": "121.62014"
  },
  {
    "country": "PH",
    "name": "Roxas",
    "lat": "12.5835",
    "lng": "121.5176"
  },
  {
    "country": "PH",
    "name": "Roxas City",
    "lat": "11.58528",
    "lng": "122.75111"
  },
  {
    "country": "PH",
    "name": "Roxas",
    "lat": "10.3215",
    "lng": "119.3451"
  },
  {
    "country": "PH",
    "name": "Rotonda",
    "lat": "6.49179",
    "lng": "124.88616"
  },
  {
    "country": "PH",
    "name": "Rosario",
    "lat": "16.2304",
    "lng": "120.4863"
  },
  {
    "country": "PH",
    "name": "Rosario",
    "lat": "14.41827",
    "lng": "120.8577"
  },
  {
    "country": "PH",
    "name": "Rosario",
    "lat": "13.84544",
    "lng": "121.20478"
  },
  {
    "country": "PH",
    "name": "Rosario",
    "lat": "13.8635",
    "lng": "122.2731"
  },
  {
    "country": "PH",
    "name": "Rosario",
    "lat": "12.5223",
    "lng": "124.425"
  },
  {
    "country": "PH",
    "name": "Rosario",
    "lat": "11.5832",
    "lng": "122.3019"
  },
  {
    "country": "PH",
    "name": "Rosario",
    "lat": "8.38694",
    "lng": "126.00333"
  },
  {
    "country": "PH",
    "name": "Rosales",
    "lat": "15.89444",
    "lng": "120.63278"
  },
  {
    "country": "PH",
    "name": "Ronda",
    "lat": "9.999",
    "lng": "123.4095"
  },
  {
    "country": "PH",
    "name": "Rominimbang",
    "lat": "7.5",
    "lng": "124.3"
  },
  {
    "country": "PH",
    "name": "Romblon",
    "lat": "12.57513",
    "lng": "122.27081"
  },
  {
    "country": "PH",
    "name": "Rogongon",
    "lat": "8.23333",
    "lng": "124.33333"
  },
  {
    "country": "PH",
    "name": "Rizal",
    "lat": "17.8486",
    "lng": "121.3466"
  },
  {
    "country": "PH",
    "name": "Liwan",
    "lat": "17.5191",
    "lng": "121.632"
  },
  {
    "country": "PH",
    "name": "Rizal",
    "lat": "16.71861",
    "lng": "121.55528"
  },
  {
    "country": "PH",
    "name": "Rizal",
    "lat": "15.7118",
    "lng": "121.1061"
  },
  {
    "country": "PH",
    "name": "Rizal",
    "lat": "14.10944",
    "lng": "121.3936"
  },
  {
    "country": "PH",
    "name": "Rizal",
    "lat": "13.95",
    "lng": "122.28333"
  },
  {
    "country": "PH",
    "name": "Rizal",
    "lat": "13.8765",
    "lng": "121.159"
  },
  {
    "country": "PH",
    "name": "Rizal",
    "lat": "12.97722",
    "lng": "123.91417"
  },
  {
    "country": "PH",
    "name": "Rizal",
    "lat": "12.8864",
    "lng": "124.1343"
  },
  {
    "country": "PH",
    "name": "Rizal",
    "lat": "12.46667",
    "lng": "120.96667"
  },
  {
    "country": "PH",
    "name": "Rizal",
    "lat": "11.4454",
    "lng": "122.8607"
  },
  {
    "country": "PH",
    "name": "Rizal",
    "lat": "11.17639",
    "lng": "124.57944"
  },
  {
    "country": "PH",
    "name": "Rizal",
    "lat": "10.8807",
    "lng": "123.4178"
  },
  {
    "country": "PH",
    "name": "Rizal",
    "lat": "10.68333",
    "lng": "122.63333"
  },
  {
    "country": "PH",
    "name": "Rizal",
    "lat": "9.7804",
    "lng": "125.4643"
  },
  {
    "country": "PH",
    "name": "Rizal",
    "lat": "8.92917",
    "lng": "125.39861"
  },
  {
    "country": "PH",
    "name": "Rissing",
    "lat": "16.8752",
    "lng": "120.4345"
  },
  {
    "country": "PH",
    "name": "Rio Tuba",
    "lat": "8.50613",
    "lng": "117.43169"
  },
  {
    "country": "PH",
    "name": "Rimus",
    "lat": "16.8764",
    "lng": "120.3966"
  },
  {
    "country": "PH",
    "name": "Rimpeso",
    "lat": "7.02389",
    "lng": "124.10028"
  },
  {
    "country": "PH",
    "name": "Reina Mercedes",
    "lat": "16.98545",
    "lng": "121.82664"
  },
  {
    "country": "PH",
    "name": "Hacienda Refugio",
    "lat": "10.52166",
    "lng": "123.4445"
  },
  {
    "country": "PH",
    "name": "Recodo",
    "lat": "11.94914",
    "lng": "123.73695"
  },
  {
    "country": "PH",
    "name": "Recodo",
    "lat": "6.95194",
    "lng": "121.96361"
  },
  {
    "country": "PH",
    "name": "Robonkon",
    "lat": "7.7535",
    "lng": "123.4187"
  },
  {
    "country": "PH",
    "name": "Real",
    "lat": "15.8089",
    "lng": "120.34549"
  },
  {
    "country": "PH",
    "name": "Real",
    "lat": "14.66397",
    "lng": "121.60412"
  },
  {
    "country": "PH",
    "name": "Rapu-Rapu",
    "lat": "13.1866",
    "lng": "124.1256"
  },
  {
    "country": "PH",
    "name": "Ransang",
    "lat": "8.96028",
    "lng": "117.58278"
  },
  {
    "country": "PH",
    "name": "Ranao",
    "lat": "16.2076",
    "lng": "119.8155"
  },
  {
    "country": "PH",
    "name": "Ramos West",
    "lat": "16.6984",
    "lng": "121.6136"
  },
  {
    "country": "PH",
    "name": "Ramos",
    "lat": "15.6653",
    "lng": "120.6406"
  },
  {
    "country": "PH",
    "name": "Ramon Magsaysay",
    "lat": "8.00194",
    "lng": "123.50944"
  },
  {
    "country": "PH",
    "name": "Ramon",
    "lat": "16.78416",
    "lng": "121.53504"
  },
  {
    "country": "PH",
    "name": "Ramain",
    "lat": "7.97083",
    "lng": "124.34528"
  },
  {
    "country": "PH",
    "name": "Rajal Norte",
    "lat": "15.44485",
    "lng": "120.86256"
  },
  {
    "country": "PH",
    "name": "Ragay",
    "lat": "13.8183",
    "lng": "122.7923"
  },
  {
    "country": "PH",
    "name": "Ragan Norte",
    "lat": "17.32318",
    "lng": "121.77428"
  },
  {
    "country": "PH",
    "name": "Ragandang",
    "lat": "6.66386",
    "lng": "124.12063"
  },
  {
    "country": "PH",
    "name": "Quitang",
    "lat": "13.5513",
    "lng": "123.0529"
  },
  {
    "country": "PH",
    "name": "Quisao",
    "lat": "14.4347",
    "lng": "121.3344"
  },
  {
    "country": "PH",
    "name": "Quirino",
    "lat": "17.15556",
    "lng": "120.67"
  },
  {
    "country": "PH",
    "name": "Quirino",
    "lat": "17.13333",
    "lng": "121.7"
  },
  {
    "country": "PH",
    "name": "Quipot",
    "lat": "13.9556",
    "lng": "121.31903"
  },
  {
    "country": "PH",
    "name": "Quipot",
    "lat": "11.28333",
    "lng": "123"
  },
  {
    "country": "PH",
    "name": "Quintong",
    "lat": "15.95581",
    "lng": "120.32171"
  },
  {
    "country": "PH",
    "name": "Quinipot",
    "lat": "7.18028",
    "lng": "122.22028"
  },
  {
    "country": "PH",
    "name": "Kinatakutan",
    "lat": "13.955",
    "lng": "122.4678"
  },
  {
    "country": "PH",
    "name": "Quinarayan",
    "lat": "17.4441",
    "lng": "120.4722"
  },
  {
    "country": "PH",
    "name": "Quinapundan",
    "lat": "11.15833",
    "lng": "125.52194"
  },
  {
    "country": "PH",
    "name": "Quinagaringan",
    "lat": "11.1222",
    "lng": "122.5875"
  },
  {
    "country": "PH",
    "name": "Quinabigan",
    "lat": "12.9936",
    "lng": "121.47812"
  },
  {
    "country": "PH",
    "name": "Quilo-quilo",
    "lat": "13.8638",
    "lng": "121.2209"
  },
  {
    "country": "PH",
    "name": "Quiling",
    "lat": "18.06833",
    "lng": "120.54389"
  },
  {
    "country": "PH",
    "name": "Quibal",
    "lat": "17.7159",
    "lng": "121.81135"
  },
  {
    "country": "PH",
    "name": "Quiapo",
    "lat": "14.6",
    "lng": "120.9833"
  },
  {
    "country": "PH",
    "name": "Quezon City",
    "lat": "14.6488",
    "lng": "121.0509"
  },
  {
    "country": "PH",
    "name": "Quezon",
    "lat": "17.31303",
    "lng": "121.60654"
  },
  {
    "country": "PH",
    "name": "Quezon",
    "lat": "16.5",
    "lng": "121.26667"
  },
  {
    "country": "PH",
    "name": "Quezon",
    "lat": "15.5512",
    "lng": "120.8147"
  },
  {
    "country": "PH",
    "name": "Quezon",
    "lat": "14.0057",
    "lng": "122.1838"
  },
  {
    "country": "PH",
    "name": "Quezon",
    "lat": "12.6",
    "lng": "123.95"
  },
  {
    "country": "PH",
    "name": "Quezon",
    "lat": "10.43617",
    "lng": "123.2604"
  },
  {
    "country": "PH",
    "name": "Quezon",
    "lat": "9.24111",
    "lng": "118.03139"
  },
  {
    "country": "PH",
    "name": "Quezon",
    "lat": "7.73028",
    "lng": "125.09889"
  },
  {
    "country": "PH",
    "name": "Putol",
    "lat": "13.9922",
    "lng": "120.7275"
  },
  {
    "country": "PH",
    "name": "Putlod",
    "lat": "15.3706",
    "lng": "120.8675"
  },
  {
    "country": "PH",
    "name": "Puting Kahoy",
    "lat": "14.2157",
    "lng": "121.031"
  },
  {
    "country": "PH",
    "name": "Putingkahoy",
    "lat": "13.83023",
    "lng": "121.32753"
  },
  {
    "country": "PH",
    "name": "Putiao",
    "lat": "13.0195",
    "lng": "123.7148"
  },
  {
    "country": "PH",
    "name": "Putat",
    "lat": "10.7858",
    "lng": "123.8469"
  },
  {
    "country": "PH",
    "name": "Puro Pinget",
    "lat": "17.67967",
    "lng": "120.35883"
  },
  {
    "country": "PH",
    "name": "Puro",
    "lat": "12.4841",
    "lng": "123.3827"
  },
  {
    "country": "PH",
    "name": "Puricay",
    "lat": "6.68614",
    "lng": "124.06957"
  },
  {
    "country": "PH",
    "name": "Porais",
    "lat": "15.7551",
    "lng": "121.0427"
  },
  {
    "country": "PH",
    "name": "Purac",
    "lat": "15.252",
    "lng": "120.0169"
  },
  {
    "country": "PH",
    "name": "Pura",
    "lat": "15.6248",
    "lng": "120.648"
  },
  {
    "country": "PH",
    "name": "Pontian",
    "lat": "8.28111",
    "lng": "124.90028"
  },
  {
    "country": "PH",
    "name": "Punta Silum",
    "lat": "8.38167",
    "lng": "124.26944"
  },
  {
    "country": "PH",
    "name": "Paddaya",
    "lat": "18.32361",
    "lng": "121.73866"
  },
  {
    "country": "PH",
    "name": "Punta",
    "lat": "14.2914",
    "lng": "121.3074"
  },
  {
    "country": "PH",
    "name": "Punta",
    "lat": "12.2441",
    "lng": "122.0097"
  },
  {
    "country": "PH",
    "name": "Punta",
    "lat": "8.98972",
    "lng": "125.34"
  },
  {
    "country": "PH",
    "name": "Punolu",
    "lat": "7.05",
    "lng": "124.58333"
  },
  {
    "country": "PH",
    "name": "Pongol",
    "lat": "8.27861",
    "lng": "124.74833"
  },
  {
    "country": "PH",
    "name": "Puncan",
    "lat": "15.9071",
    "lng": "120.9907"
  },
  {
    "country": "PH",
    "name": "Punay",
    "lat": "5.96139",
    "lng": "121.19806"
  },
  {
    "country": "PH",
    "name": "Punao",
    "lat": "10.56516",
    "lng": "123.408"
  },
  {
    "country": "PH",
    "name": "Punang",
    "lat": "9.0169",
    "lng": "118.0495"
  },
  {
    "country": "PH",
    "name": "Pulupandan",
    "lat": "10.5203",
    "lng": "122.8017"
  },
  {
    "country": "PH",
    "name": "Pulung Santol",
    "lat": "15.04574",
    "lng": "120.56188"
  },
  {
    "country": "PH",
    "name": "Pulungmasle",
    "lat": "15.0004",
    "lng": "120.55774"
  },
  {
    "country": "PH",
    "name": "Pulong Santa Cruz",
    "lat": "14.27324",
    "lng": "121.07643"
  },
  {
    "country": "PH",
    "name": "Pulong Sampalok",
    "lat": "14.9611",
    "lng": "121.0609"
  },
  {
    "country": "PH",
    "name": "Pulong Gubat",
    "lat": "14.85938",
    "lng": "120.90599"
  },
  {
    "country": "PH",
    "name": "Pulo",
    "lat": "15.246",
    "lng": "120.9285"
  },
  {
    "country": "PH",
    "name": "Pulo",
    "lat": "14.9622",
    "lng": "121.0147"
  },
  {
    "country": "PH",
    "name": "Pulilan",
    "lat": "14.90167",
    "lng": "120.84917"
  },
  {
    "country": "PH",
    "name": "Pulangbato",
    "lat": "13.75387",
    "lng": "121.39266"
  },
  {
    "country": "PH",
    "name": "Pugo",
    "lat": "16.3221",
    "lng": "120.467"
  },
  {
    "country": "PH",
    "name": "Puerto Princesa",
    "lat": "9.73917",
    "lng": "118.73528"
  },
  {
    "country": "PH",
    "name": "Puerto Galera",
    "lat": "13.50223",
    "lng": "120.95166"
  },
  {
    "country": "PH",
    "name": "Puerto Bello",
    "lat": "10.9733",
    "lng": "124.5351"
  },
  {
    "country": "PH",
    "name": "Puelay",
    "lat": "15.88683",
    "lng": "120.57358"
  },
  {
    "country": "PH",
    "name": "Pudoc",
    "lat": "16.9215",
    "lng": "120.4235"
  },
  {
    "country": "PH",
    "name": "Pudoc North",
    "lat": "17.6096",
    "lng": "120.36852"
  },
  {
    "country": "PH",
    "name": "Pualas",
    "lat": "8.01722",
    "lng": "123.84806"
  },
  {
    "country": "PH",
    "name": "Pualas",
    "lat": "7.81624",
    "lng": "124.07105"
  },
  {
    "country": "PH",
    "name": "Prosperidad",
    "lat": "10.51596",
    "lng": "123.3085"
  },
  {
    "country": "PH",
    "name": "Prosperidad",
    "lat": "8.58",
    "lng": "125.89639"
  },
  {
    "country": "PH",
    "name": "Progreso",
    "lat": "13.9083",
    "lng": "122.0906"
  },
  {
    "country": "PH",
    "name": "Prinza",
    "lat": "14.19607",
    "lng": "121.13696"
  },
  {
    "country": "PH",
    "name": "Prieto Diaz",
    "lat": "13.04167",
    "lng": "124.19389"
  },
  {
    "country": "PH",
    "name": "President Roxas",
    "lat": "11.431",
    "lng": "122.9279"
  },
  {
    "country": "PH",
    "name": "President Roxas",
    "lat": "7.15444",
    "lng": "125.05583"
  },
  {
    "country": "PH",
    "name": "President Quirino",
    "lat": "6.70389",
    "lng": "124.73722"
  },
  {
    "country": "PH",
    "name": "Pitogo",
    "lat": "10.1214",
    "lng": "124.5533"
  },
  {
    "country": "PH",
    "name": "Parabcan",
    "lat": "13.7088",
    "lng": "123.745"
  },
  {
    "country": "PH",
    "name": "Prinza",
    "lat": "13.99679",
    "lng": "120.65409"
  },
  {
    "country": "PH",
    "name": "Prado Siongco",
    "lat": "14.879",
    "lng": "120.51292"
  },
  {
    "country": "PH",
    "name": "Pozorrubio",
    "lat": "16.111",
    "lng": "120.544"
  },
  {
    "country": "PH",
    "name": "Pototan",
    "lat": "10.9437",
    "lng": "122.6352"
  },
  {
    "country": "PH",
    "name": "Potot",
    "lat": "12.20345",
    "lng": "123.43191"
  },
  {
    "country": "PH",
    "name": "Patong",
    "lat": "12.33643",
    "lng": "125.28521"
  },
  {
    "country": "PH",
    "name": "Potia",
    "lat": "16.85",
    "lng": "121.48333"
  },
  {
    "country": "PH",
    "name": "San Vicente",
    "lat": "18.50746",
    "lng": "122.15035"
  },
  {
    "country": "PH",
    "name": "Port Barton",
    "lat": "10.47556",
    "lng": "119.24722"
  },
  {
    "country": "PH",
    "name": "Port Area",
    "lat": "14.5833",
    "lng": "120.9667"
  },
  {
    "country": "PH",
    "name": "Poro",
    "lat": "10.6292",
    "lng": "124.4087"
  },
  {
    "country": "PH",
    "name": "Porac",
    "lat": "15.0711",
    "lng": "120.5423"
  },
  {
    "country": "PH",
    "name": "Poona-Piagapo",
    "lat": "8.08333",
    "lng": "124.11667"
  },
  {
    "country": "PH",
    "name": "Pontevedra",
    "lat": "11.4812",
    "lng": "122.8325"
  },
  {
    "country": "PH",
    "name": "Pontevedra",
    "lat": "10.3746",
    "lng": "122.8682"
  },
  {
    "country": "PH",
    "name": "Ponso",
    "lat": "13.291",
    "lng": "123.5171"
  },
  {
    "country": "PH",
    "name": "Ponot",
    "lat": "8.452",
    "lng": "123.0222"
  },
  {
    "country": "PH",
    "name": "Ponong",
    "lat": "11.0829",
    "lng": "122.6261"
  },
  {
    "country": "PH",
    "name": "Pung-Pang",
    "lat": "6.4975",
    "lng": "125.46333"
  },
  {
    "country": "PH",
    "name": "Pantukan",
    "lat": "7.16333",
    "lng": "125.89917"
  },
  {
    "country": "PH",
    "name": "Pondaguitan",
    "lat": "6.36115",
    "lng": "126.17778"
  },
  {
    "country": "PH",
    "name": "Puloypuloy",
    "lat": "6.63517",
    "lng": "124.096"
  },
  {
    "country": "PH",
    "name": "Polopina",
    "lat": "11.2068",
    "lng": "123.1659"
  },
  {
    "country": "PH",
    "name": "Polonoling",
    "lat": "6.28496",
    "lng": "124.9689"
  },
  {
    "country": "PH",
    "name": "Polong Norte",
    "lat": "15.903",
    "lng": "120.42149"
  },
  {
    "country": "PH",
    "name": "Polong",
    "lat": "15.9771",
    "lng": "120.2009"
  },
  {
    "country": "PH",
    "name": "Polomolok",
    "lat": "6.22167",
    "lng": "125.06398"
  },
  {
    "country": "PH",
    "name": "Polo",
    "lat": "16.1963",
    "lng": "119.9491"
  },
  {
    "country": "PH",
    "name": "Pulo",
    "lat": "14.71462",
    "lng": "121.63293"
  },
  {
    "country": "PH",
    "name": "Polo",
    "lat": "11.5844",
    "lng": "122.3122"
  },
  {
    "country": "PH",
    "name": "Polo",
    "lat": "9.4816",
    "lng": "123.1802"
  },
  {
    "country": "PH",
    "name": "Polo",
    "lat": "6.26472",
    "lng": "125.1125"
  },
  {
    "country": "PH",
    "name": "Polloc",
    "lat": "7.3534",
    "lng": "124.22088"
  },
  {
    "country": "PH",
    "name": "Polillo",
    "lat": "14.71699",
    "lng": "121.94889"
  },
  {
    "country": "PH",
    "name": "Polangui",
    "lat": "13.2923",
    "lng": "123.4855"
  },
  {
    "country": "PH",
    "name": "Polañge",
    "lat": "12.39667",
    "lng": "124.63111"
  },
  {
    "country": "PH",
    "name": "Polanco",
    "lat": "8.5329",
    "lng": "123.3617"
  },
  {
    "country": "PH",
    "name": "Polahongon",
    "lat": "10.5288",
    "lng": "124.9694"
  },
  {
    "country": "PH",
    "name": "Pola",
    "lat": "13.14379",
    "lng": "121.44152"
  },
  {
    "country": "PH",
    "name": "Pogonsili",
    "lat": "15.82048",
    "lng": "120.26017"
  },
  {
    "country": "PH",
    "name": "Poctol",
    "lat": "13.82095",
    "lng": "121.44184"
  },
  {
    "country": "PH",
    "name": "Plaridel",
    "lat": "15.65853",
    "lng": "121.02009"
  },
  {
    "country": "PH",
    "name": "Plaridel",
    "lat": "14.88722",
    "lng": "120.85722"
  },
  {
    "country": "PH",
    "name": "Plaridel",
    "lat": "13.9551",
    "lng": "122.0208"
  },
  {
    "country": "PH",
    "name": "Plaridel",
    "lat": "10.8974",
    "lng": "123.4894"
  },
  {
    "country": "PH",
    "name": "Plaridel",
    "lat": "10.5667",
    "lng": "124.7645"
  },
  {
    "country": "PH",
    "name": "Plaridel",
    "lat": "9.3786",
    "lng": "118.50174"
  },
  {
    "country": "PH",
    "name": "Plaridel",
    "lat": "8.6214",
    "lng": "123.7101"
  },
  {
    "country": "PH",
    "name": "Placer",
    "lat": "11.8687",
    "lng": "123.9184"
  },
  {
    "country": "PH",
    "name": "Placer",
    "lat": "9.65417",
    "lng": "125.6025"
  },
  {
    "country": "PH",
    "name": "Pitogo",
    "lat": "5.88823",
    "lng": "121.31215"
  },
  {
    "country": "PH",
    "name": "Pitogo",
    "lat": "13.7838",
    "lng": "122.0902"
  },
  {
    "country": "PH",
    "name": "Pitogo",
    "lat": "12.50744",
    "lng": "121.09041"
  },
  {
    "country": "PH",
    "name": "Pitogo",
    "lat": "7.4546",
    "lng": "123.3111"
  },
  {
    "country": "PH",
    "name": "Limbuhan",
    "lat": "11.88377",
    "lng": "124.05011"
  },
  {
    "country": "PH",
    "name": "Pio Duran",
    "lat": "13.02928",
    "lng": "123.44496"
  },
  {
    "country": "PH",
    "name": "Pio",
    "lat": "15.04741",
    "lng": "120.51891"
  },
  {
    "country": "PH",
    "name": "Pinukpuk",
    "lat": "17.61667",
    "lng": "121.4"
  },
  {
    "country": "PH",
    "name": "Pinugay",
    "lat": "14.5967",
    "lng": "121.2623"
  },
  {
    "country": "PH",
    "name": "Pintuyan",
    "lat": "9.9441",
    "lng": "125.2494"
  },
  {
    "country": "PH",
    "name": "Pinoma",
    "lat": "16.87421",
    "lng": "121.70669"
  },
  {
    "country": "PH",
    "name": "Pinokawan",
    "lat": "10.34117",
    "lng": "123.2939"
  },
  {
    "country": "PH",
    "name": "Pinit",
    "lat": "13.5686",
    "lng": "123.414"
  },
  {
    "country": "PH",
    "name": "Pinili",
    "lat": "17.9517",
    "lng": "120.5278"
  },
  {
    "country": "PH",
    "name": "Pines",
    "lat": "8.45222",
    "lng": "123.8075"
  },
  {
    "country": "PH",
    "name": "Pandasan",
    "lat": "7.2838",
    "lng": "125.8535"
  },
  {
    "country": "PH",
    "name": "Pindangan Centro",
    "lat": "15.86056",
    "lng": "120.55139"
  },
  {
    "country": "PH",
    "name": "Pinayagan Norte",
    "lat": "9.93333",
    "lng": "123.95"
  },
  {
    "country": "PH",
    "name": "Pinaring",
    "lat": "7.22889",
    "lng": "124.31056"
  },
  {
    "country": "PH",
    "name": "Pinamungahan",
    "lat": "10.2708",
    "lng": "123.5839"
  },
  {
    "country": "PH",
    "name": "Pinamopoan",
    "lat": "11.31472",
    "lng": "124.57389"
  },
  {
    "country": "PH",
    "name": "Pinambaran",
    "lat": "15.20233",
    "lng": "120.97797"
  },
  {
    "country": "PH",
    "name": "Pinamalayan",
    "lat": "13.04603",
    "lng": "121.46205"
  },
  {
    "country": "PH",
    "name": "Piñahan",
    "lat": "15.6266",
    "lng": "121.0621"
  },
  {
    "country": "PH",
    "name": "Pinagsibaan",
    "lat": "13.83479",
    "lng": "121.32118"
  },
  {
    "country": "PH",
    "name": "Pinagsabangan",
    "lat": "13.26559",
    "lng": "121.26812"
  },
  {
    "country": "PH",
    "name": "Panadtaban",
    "lat": "6.90083",
    "lng": "124.64278"
  },
  {
    "country": "PH",
    "name": "Piña",
    "lat": "10.63956",
    "lng": "122.6382"
  },
  {
    "country": "PH",
    "name": "Pimbalayan",
    "lat": "6.86917",
    "lng": "124.6725"
  },
  {
    "country": "PH",
    "name": "Pililla",
    "lat": "14.4854",
    "lng": "121.3062"
  },
  {
    "country": "PH",
    "name": "Pilig",
    "lat": "17.34278",
    "lng": "121.77389"
  },
  {
    "country": "PH",
    "name": "Pili",
    "lat": "13.66667",
    "lng": "123.31667"
  },
  {
    "country": "PH",
    "name": "Pili",
    "lat": "13.0664",
    "lng": "121.52032"
  },
  {
    "country": "PH",
    "name": "Pili",
    "lat": "12.98056",
    "lng": "123.86417"
  },
  {
    "country": "PH",
    "name": "Pili",
    "lat": "11.1196",
    "lng": "123.0147"
  },
  {
    "country": "PH",
    "name": "Pilar",
    "lat": "17.4165",
    "lng": "120.5954"
  },
  {
    "country": "PH",
    "name": "Pilar",
    "lat": "14.66",
    "lng": "120.56528"
  },
  {
    "country": "PH",
    "name": "Pilar",
    "lat": "12.9231",
    "lng": "123.6724"
  },
  {
    "country": "PH",
    "name": "Pilar",
    "lat": "11.487",
    "lng": "122.9963"
  },
  {
    "country": "PH",
    "name": "Pilar",
    "lat": "10.8065",
    "lng": "124.5661"
  },
  {
    "country": "PH",
    "name": "Pilar",
    "lat": "9.865",
    "lng": "126.09944"
  },
  {
    "country": "PH",
    "name": "Pilar",
    "lat": "9.829",
    "lng": "124.3273"
  },
  {
    "country": "PH",
    "name": "Pila",
    "lat": "14.2325",
    "lng": "121.3648"
  },
  {
    "country": "PH",
    "name": "Pikit",
    "lat": "7.05444",
    "lng": "124.67194"
  },
  {
    "country": "PH",
    "name": "Pigcawayan",
    "lat": "7.27722",
    "lng": "124.42556"
  },
  {
    "country": "PH",
    "name": "Pidsandawan",
    "lat": "6.93222",
    "lng": "124.59083"
  },
  {
    "country": "PH",
    "name": "Pidigan",
    "lat": "17.57",
    "lng": "120.5903"
  },
  {
    "country": "PH",
    "name": "Piddig",
    "lat": "18.1655",
    "lng": "120.7175"
  },
  {
    "country": "PH",
    "name": "Piat",
    "lat": "17.7905",
    "lng": "121.478"
  },
  {
    "country": "PH",
    "name": "Pias",
    "lat": "15.34525",
    "lng": "121.07473"
  },
  {
    "country": "PH",
    "name": "Pias",
    "lat": "15.01699",
    "lng": "120.56238"
  },
  {
    "country": "PH",
    "name": "Piape I",
    "lat": "10.7288",
    "lng": "121.9724"
  },
  {
    "country": "PH",
    "name": "Perrelos",
    "lat": "10.1169",
    "lng": "123.6738"
  },
  {
    "country": "PH",
    "name": "Perez",
    "lat": "14.19465",
    "lng": "121.92636"
  },
  {
    "country": "PH",
    "name": "Peñarrubia",
    "lat": "17.5647",
    "lng": "120.6519"
  },
  {
    "country": "PH",
    "name": "Peñaranda",
    "lat": "15.35116",
    "lng": "121.00393"
  },
  {
    "country": "PH",
    "name": "Peñablanca",
    "lat": "17.63342",
    "lng": "121.78117"
  },
  {
    "country": "PH",
    "name": "Piña",
    "lat": "12.19078",
    "lng": "124.4015"
  },
  {
    "country": "PH",
    "name": "Peña",
    "lat": "12.089",
    "lng": "123.9384"
  },
  {
    "country": "PH",
    "name": "Pedtad",
    "lat": "7.16056",
    "lng": "124.81444"
  },
  {
    "country": "PH",
    "name": "Paypay",
    "lat": "11.2152",
    "lng": "123.9762"
  },
  {
    "country": "PH",
    "name": "Payocpoc Sur",
    "lat": "16.49444",
    "lng": "120.32806"
  },
  {
    "country": "PH",
    "name": "Payapa",
    "lat": "13.99803",
    "lng": "120.89207"
  },
  {
    "country": "PH",
    "name": "Payao",
    "lat": "10.1785",
    "lng": "122.9236"
  },
  {
    "country": "PH",
    "name": "Payao",
    "lat": "7.58667",
    "lng": "122.80278"
  },
  {
    "country": "PH",
    "name": "Pawing",
    "lat": "11.18",
    "lng": "125.00278"
  },
  {
    "country": "PH",
    "name": "Pawili",
    "lat": "13.51667",
    "lng": "123.28333"
  },
  {
    "country": "PH",
    "name": "Pawican",
    "lat": "12.0741",
    "lng": "123.9706"
  },
  {
    "country": "PH",
    "name": "Pawak",
    "lat": "8.01634",
    "lng": "124.25647"
  },
  {
    "country": "PH",
    "name": "Pawa",
    "lat": "13.1773",
    "lng": "123.7301"
  },
  {
    "country": "PH",
    "name": "Pawa",
    "lat": "13.1335",
    "lng": "123.8915"
  },
  {
    "country": "PH",
    "name": "Pawa",
    "lat": "11.56285",
    "lng": "122.81736"
  },
  {
    "country": "PH",
    "name": "Pavia",
    "lat": "10.77611",
    "lng": "122.54556"
  },
  {
    "country": "PH",
    "name": "Paulba",
    "lat": "13.17875",
    "lng": "123.46252"
  },
  {
    "country": "PH",
    "name": "Pau",
    "lat": "15.0279",
    "lng": "120.7243"
  },
  {
    "country": "PH",
    "name": "Patuto",
    "lat": "14.11667",
    "lng": "120.96667"
  },
  {
    "country": "PH",
    "name": "Patonan",
    "lat": "10.56816",
    "lng": "123.4723"
  },
  {
    "country": "PH",
    "name": "Pattao",
    "lat": "18.24694",
    "lng": "121.8147"
  },
  {
    "country": "PH",
    "name": "Patrocinio",
    "lat": "8.6125",
    "lng": "124.84556"
  },
  {
    "country": "PH",
    "name": "Patria",
    "lat": "11.7403",
    "lng": "122.0171"
  },
  {
    "country": "PH",
    "name": "Patpata Segundo",
    "lat": "17.18333",
    "lng": "120.43333"
  },
  {
    "country": "PH",
    "name": "Pato-o",
    "lat": "12.43025",
    "lng": "122.0664"
  },
  {
    "country": "PH",
    "name": "Patnongon",
    "lat": "10.9132",
    "lng": "121.9937"
  },
  {
    "country": "PH",
    "name": "Patnanungan",
    "lat": "14.78333",
    "lng": "122.18333"
  },
  {
    "country": "PH",
    "name": "Patindeguen",
    "lat": "7.21972",
    "lng": "124.49833"
  },
  {
    "country": "PH",
    "name": "Patin-ay",
    "lat": "8.55056",
    "lng": "125.93722"
  },
  {
    "country": "PH",
    "name": "Patique",
    "lat": "10.237",
    "lng": "122.8993"
  },
  {
    "country": "PH",
    "name": "Pateros",
    "lat": "14.5391",
    "lng": "121.0726"
  },
  {
    "country": "PH",
    "name": "Patayac",
    "lat": "15.963",
    "lng": "120.42251"
  },
  {
    "country": "PH",
    "name": "Patawag",
    "lat": "8.10639",
    "lng": "122.62083"
  },
  {
    "country": "PH",
    "name": "Patao",
    "lat": "11.2202",
    "lng": "123.6925"
  },
  {
    "country": "PH",
    "name": "Patabog",
    "lat": "13.4432",
    "lng": "122.4557"
  },
  {
    "country": "PH",
    "name": "Pata",
    "lat": "17.7152",
    "lng": "121.5018"
  },
  {
    "country": "PH",
    "name": "Pasuquin",
    "lat": "18.3328",
    "lng": "120.6177"
  },
  {
    "country": "PH",
    "name": "Pastrana",
    "lat": "11.13667",
    "lng": "124.88556"
  },
  {
    "country": "PH",
    "name": "Passi",
    "lat": "11.10778",
    "lng": "122.64194"
  },
  {
    "country": "PH",
    "name": "Pasong Kawayan Primero",
    "lat": "14.34317",
    "lng": "120.88157"
  },
  {
    "country": "PH",
    "name": "Pasil",
    "lat": "17.38333",
    "lng": "121.13333"
  },
  {
    "country": "PH",
    "name": "Pasil",
    "lat": "10.8378",
    "lng": "122.6098"
  },
  {
    "country": "PH",
    "name": "Pasibi West",
    "lat": "15.8587",
    "lng": "120.37935"
  },
  {
    "country": "PH",
    "name": "Pasian",
    "lat": "7.92806",
    "lng": "126.06722"
  },
  {
    "country": "PH",
    "name": "Pasay",
    "lat": "14.53748",
    "lng": "121.00144"
  },
  {
    "country": "PH",
    "name": "Pasacao",
    "lat": "13.5118",
    "lng": "123.0426"
  },
  {
    "country": "PH",
    "name": "Parista",
    "lat": "15.8536",
    "lng": "120.9282"
  },
  {
    "country": "PH",
    "name": "Parioc Segundo",
    "lat": "17.17503",
    "lng": "120.46576"
  },
  {
    "country": "PH",
    "name": "Paringao",
    "lat": "16.57167",
    "lng": "120.32417"
  },
  {
    "country": "PH",
    "name": "Parian Dakula",
    "lat": "5.55667",
    "lng": "120.77194"
  },
  {
    "country": "PH",
    "name": "Parion",
    "lat": "11.4748",
    "lng": "122.6972"
  },
  {
    "country": "PH",
    "name": "Parangan",
    "lat": "5.08389",
    "lng": "119.93833"
  },
  {
    "country": "PH",
    "name": "Parang",
    "lat": "14.6331",
    "lng": "120.4493"
  },
  {
    "country": "PH",
    "name": "Parang",
    "lat": "9.28149",
    "lng": "125.94208"
  },
  {
    "country": "PH",
    "name": "Parang",
    "lat": "7.37035",
    "lng": "124.26973"
  },
  {
    "country": "PH",
    "name": "Parang",
    "lat": "5.9137",
    "lng": "120.9056"
  },
  {
    "country": "PH",
    "name": "Paraiso",
    "lat": "10.8849",
    "lng": "123.3627"
  },
  {
    "country": "PH",
    "name": "Paraiso",
    "lat": "6.47606",
    "lng": "124.80954"
  },
  {
    "country": "PH",
    "name": "Paradahan",
    "lat": "14.32123",
    "lng": "120.86059"
  },
  {
    "country": "PH",
    "name": "Paracelis",
    "lat": "17.26667",
    "lng": "121.46667"
  },
  {
    "country": "PH",
    "name": "Paracale",
    "lat": "14.2804",
    "lng": "122.7881"
  },
  {
    "country": "PH",
    "name": "Papaya",
    "lat": "15.32016",
    "lng": "120.83574"
  },
  {
    "country": "PH",
    "name": "Paombong",
    "lat": "14.83111",
    "lng": "120.78917"
  },
  {
    "country": "PH",
    "name": "Paulba",
    "lat": "13.7136",
    "lng": "123.2496"
  },
  {
    "country": "PH",
    "name": "Paoay",
    "lat": "18.0616",
    "lng": "120.5221"
  },
  {
    "country": "PH",
    "name": "Panukulan",
    "lat": "14.93371",
    "lng": "121.81685"
  },
  {
    "country": "PH",
    "name": "Panognawan",
    "lat": "11.1619",
    "lng": "124.005"
  },
  {
    "country": "PH",
    "name": "Pantubig",
    "lat": "14.96806",
    "lng": "120.95472"
  },
  {
    "country": "PH",
    "name": "Pantijan No 2",
    "lat": "14.23306",
    "lng": "120.80056"
  },
  {
    "country": "PH",
    "name": "Pantay Na Matanda",
    "lat": "14.1175",
    "lng": "121.12111"
  },
  {
    "country": "PH",
    "name": "Pantar",
    "lat": "8.06611",
    "lng": "124.25833"
  },
  {
    "country": "PH",
    "name": "Pantao-Ragat",
    "lat": "8.08333",
    "lng": "124.13333"
  },
  {
    "country": "PH",
    "name": "Pantao",
    "lat": "13.1944",
    "lng": "123.3271"
  },
  {
    "country": "PH",
    "name": "Pantabangan",
    "lat": "15.8113",
    "lng": "121.1443"
  },
  {
    "country": "PH",
    "name": "Pansoy",
    "lat": "13.18177",
    "lng": "122.59989"
  },
  {
    "country": "PH",
    "name": "Pansol",
    "lat": "13.8866",
    "lng": "121.2432"
  },
  {
    "country": "PH",
    "name": "Panlinlang",
    "lat": "15.18333",
    "lng": "120.7"
  },
  {
    "country": "PH",
    "name": "Panlaitan",
    "lat": "12.11907",
    "lng": "119.84861"
  },
  {
    "country": "PH",
    "name": "Panitan",
    "lat": "11.466",
    "lng": "122.7725"
  },
  {
    "country": "PH",
    "name": "Panitian",
    "lat": "9.0965",
    "lng": "118.0864"
  },
  {
    "country": "PH",
    "name": "Paniqui",
    "lat": "15.6689",
    "lng": "120.5806"
  },
  {
    "country": "PH",
    "name": "Paniqui",
    "lat": "12.4532",
    "lng": "123.3821"
  },
  {
    "country": "PH",
    "name": "Panique",
    "lat": "12.48025",
    "lng": "122.01462"
  },
  {
    "country": "PH",
    "name": "Panikihan",
    "lat": "13.9083",
    "lng": "122.131"
  },
  {
    "country": "PH",
    "name": "Panikian",
    "lat": "9.32935",
    "lng": "125.9338"
  },
  {
    "country": "PH",
    "name": "Panikian",
    "lat": "7.0107",
    "lng": "126.02418"
  },
  {
    "country": "PH",
    "name": "Pangyan",
    "lat": "5.70083",
    "lng": "125.28111"
  },
  {
    "country": "PH",
    "name": "Simbahan",
    "lat": "6.3032",
    "lng": "120.5836"
  },
  {
    "country": "PH",
    "name": "Pangulayan",
    "lat": "13.0398",
    "lng": "121.44792"
  },
  {
    "country": "PH",
    "name": "Panguiranan",
    "lat": "12.06986",
    "lng": "123.31851"
  },
  {
    "country": "PH",
    "name": "Pangpang",
    "lat": "15.93875",
    "lng": "120.30939"
  },
  {
    "country": "PH",
    "name": "Pangpang",
    "lat": "12.5692",
    "lng": "125.074"
  },
  {
    "country": "PH",
    "name": "Pañgobilian",
    "lat": "8.80111",
    "lng": "117.85944"
  },
  {
    "country": "PH",
    "name": "Panglao",
    "lat": "9.57806",
    "lng": "123.74583"
  },
  {
    "country": "PH",
    "name": "Pangil",
    "lat": "14.4033",
    "lng": "121.46506"
  },
  {
    "country": "PH",
    "name": "Pangil",
    "lat": "14.20102",
    "lng": "120.90778"
  },
  {
    "country": "PH",
    "name": "Pangian",
    "lat": "6.46278",
    "lng": "125.54528"
  },
  {
    "country": "PH",
    "name": "Pangdan",
    "lat": "11.74444",
    "lng": "124.91667"
  },
  {
    "country": "PH",
    "name": "Pangdan",
    "lat": "10.23078",
    "lng": "123.7379"
  },
  {
    "country": "PH",
    "name": "Pangascasan",
    "lat": "16.11691",
    "lng": "120.08664"
  },
  {
    "country": "PH",
    "name": "Pangapisan",
    "lat": "16.216",
    "lng": "119.957"
  },
  {
    "country": "PH",
    "name": "Pangao",
    "lat": "13.91722",
    "lng": "121.12556"
  },
  {
    "country": "PH",
    "name": "Pangantocan",
    "lat": "7.84722",
    "lng": "124.8125"
  },
  {
    "country": "PH",
    "name": "Panganiban",
    "lat": "16.0075",
    "lng": "120.7752"
  },
  {
    "country": "PH",
    "name": "Panganiban",
    "lat": "13.90033",
    "lng": "124.29816"
  },
  {
    "country": "PH",
    "name": "Pangal Sur",
    "lat": "16.60036",
    "lng": "121.66979"
  },
  {
    "country": "PH",
    "name": "Pangabuan",
    "lat": "8.05694",
    "lng": "123.69583"
  },
  {
    "country": "PH",
    "name": "Pang",
    "lat": "5.94837",
    "lng": "121.2883"
  },
  {
    "country": "PH",
    "name": "Pando",
    "lat": "15.39395",
    "lng": "120.68473"
  },
  {
    "country": "PH",
    "name": "Pandi",
    "lat": "14.865",
    "lng": "120.95722"
  },
  {
    "country": "PH",
    "name": "New Pandanon",
    "lat": "10.55696",
    "lng": "123.1475"
  },
  {
    "country": "PH",
    "name": "Pandan Niog",
    "lat": "6.2282",
    "lng": "120.5631"
  },
  {
    "country": "PH",
    "name": "Pandan",
    "lat": "14.0453",
    "lng": "124.1694"
  },
  {
    "country": "PH",
    "name": "Pandan",
    "lat": "13.7421",
    "lng": "123.0815"
  },
  {
    "country": "PH",
    "name": "Pandan",
    "lat": "11.7195",
    "lng": "122.0949"
  },
  {
    "country": "PH",
    "name": "Pandan",
    "lat": "9.2388",
    "lng": "124.7278"
  },
  {
    "country": "PH",
    "name": "Pandacaqui",
    "lat": "15.1719",
    "lng": "120.65457"
  },
  {
    "country": "PH",
    "name": "Pancol",
    "lat": "10.8715",
    "lng": "119.4157"
  },
  {
    "country": "PH",
    "name": "Pance",
    "lat": "15.6885",
    "lng": "120.6201"
  },
  {
    "country": "PH",
    "name": "Panaytayon",
    "lat": "9.95",
    "lng": "123.98333"
  },
  {
    "country": "PH",
    "name": "Panayacan",
    "lat": "11.7603",
    "lng": "122.2236"
  },
  {
    "country": "PH",
    "name": "Panay",
    "lat": "11.55778",
    "lng": "122.79417"
  },
  {
    "country": "PH",
    "name": "Pan-an",
    "lat": "8.21917",
    "lng": "123.84028"
  },
  {
    "country": "PH",
    "name": "Panay",
    "lat": "6.49704",
    "lng": "124.63808"
  },
  {
    "country": "PH",
    "name": "Pananaw",
    "lat": "5.98111",
    "lng": "121.21472"
  },
  {
    "country": "PH",
    "name": "Panan",
    "lat": "15.2134",
    "lng": "120.0272"
  },
  {
    "country": "PH",
    "name": "Panalo-on",
    "lat": "7.91667",
    "lng": "123.75"
  },
  {
    "country": "PH",
    "name": "Panalipan",
    "lat": "10.64833",
    "lng": "124.02167"
  },
  {
    "country": "PH",
    "name": "Panalingaan",
    "lat": "8.78417",
    "lng": "117.42306"
  },
  {
    "country": "PH",
    "name": "Panalanoy",
    "lat": "11.25111",
    "lng": "125.00639"
  },
  {
    "country": "PH",
    "name": "Panacan",
    "lat": "9.24627",
    "lng": "118.4082"
  },
  {
    "country": "PH",
    "name": "Panabuan",
    "lat": "5.9616",
    "lng": "120.9627"
  },
  {
    "country": "PH",
    "name": "Panabo",
    "lat": "7.30806",
    "lng": "125.68417"
  },
  {
    "country": "PH",
    "name": "Panabingan",
    "lat": "15.37732",
    "lng": "120.76492"
  },
  {
    "country": "PH",
    "name": "Pamplona",
    "lat": "18.46639",
    "lng": "121.34111"
  },
  {
    "country": "PH",
    "name": "Pamplona",
    "lat": "13.5916",
    "lng": "123.0816"
  },
  {
    "country": "PH",
    "name": "Pamplona",
    "lat": "9.4724",
    "lng": "123.1192"
  },
  {
    "country": "PH",
    "name": "Pambujan",
    "lat": "12.5642",
    "lng": "124.9276"
  },
  {
    "country": "PH",
    "name": "Pambuhan",
    "lat": "13.9736",
    "lng": "123.0837"
  },
  {
    "country": "PH",
    "name": "Pambisan",
    "lat": "13.0137",
    "lng": "121.41282"
  },
  {
    "country": "PH",
    "name": "Pamatawan",
    "lat": "14.92779",
    "lng": "120.21363"
  },
  {
    "country": "PH",
    "name": "Pamantingan",
    "lat": "6.71413",
    "lng": "124.38095"
  },
  {
    "country": "PH",
    "name": "Palusapis",
    "lat": "15.68324",
    "lng": "120.86267"
  },
  {
    "country": "PH",
    "name": "Paluan",
    "lat": "13.416",
    "lng": "120.4623"
  },
  {
    "country": "PH",
    "name": "Palsong",
    "lat": "13.4248",
    "lng": "123.2963"
  },
  {
    "country": "PH",
    "name": "Palompon",
    "lat": "11.0508",
    "lng": "124.3843"
  },
  {
    "country": "PH",
    "name": "Palomoc",
    "lat": "7.9153",
    "lng": "122.5829"
  },
  {
    "country": "PH",
    "name": "Palo",
    "lat": "11.1575",
    "lng": "124.99083"
  },
  {
    "country": "PH",
    "name": "Palma Gil",
    "lat": "7.64222",
    "lng": "125.62917"
  },
  {
    "country": "PH",
    "name": "Palkan",
    "lat": "6.29639",
    "lng": "125.03167"
  },
  {
    "country": "PH",
    "name": "Palimbang",
    "lat": "6.21002",
    "lng": "124.18887"
  },
  {
    "country": "PH",
    "name": "Palian",
    "lat": "6.37427",
    "lng": "124.91062"
  },
  {
    "country": "PH",
    "name": "Palhi",
    "lat": "10.6498",
    "lng": "124.8062"
  },
  {
    "country": "PH",
    "name": "Palguyod",
    "lat": "16.1227",
    "lng": "120.52"
  },
  {
    "country": "PH",
    "name": "Palestina",
    "lat": "13.6117",
    "lng": "123.249"
  },
  {
    "country": "PH",
    "name": "Paldit",
    "lat": "16.16667",
    "lng": "120.53333"
  },
  {
    "country": "PH",
    "name": "Palayan City",
    "lat": "15.5415",
    "lng": "121.0848"
  },
  {
    "country": "PH",
    "name": "Palauig",
    "lat": "15.435",
    "lng": "119.9045"
  },
  {
    "country": "PH",
    "name": "Palaroo",
    "lat": "11.4056",
    "lng": "124.483"
  },
  {
    "country": "PH",
    "name": "Palapag",
    "lat": "12.5458",
    "lng": "125.1147"
  },
  {
    "country": "PH",
    "name": "Palanit",
    "lat": "12.32134",
    "lng": "124.34341"
  },
  {
    "country": "PH",
    "name": "Palangue",
    "lat": "14.28417",
    "lng": "120.81139"
  },
  {
    "country": "PH",
    "name": "Palanas",
    "lat": "12.1458",
    "lng": "123.9216"
  },
  {
    "country": "PH",
    "name": "Palampas",
    "lat": "10.52506",
    "lng": "123.4208"
  },
  {
    "country": "PH",
    "name": "Palali",
    "lat": "14.30622",
    "lng": "122.48571"
  },
  {
    "country": "PH",
    "name": "Palahanan Uno",
    "lat": "13.83113",
    "lng": "121.35639"
  },
  {
    "country": "PH",
    "name": "Palagao Norte",
    "lat": "18.04406",
    "lng": "121.71871"
  },
  {
    "country": "PH",
    "name": "Palacpalac",
    "lat": "16.1312",
    "lng": "120.5305"
  },
  {
    "country": "PH",
    "name": "Pakil",
    "lat": "14.3835",
    "lng": "121.4786"
  },
  {
    "country": "PH",
    "name": "Pakiad",
    "lat": "10.71278",
    "lng": "122.52417"
  },
  {
    "country": "PH",
    "name": "Pajo",
    "lat": "11.24121",
    "lng": "124.01067"
  },
  {
    "country": "PH",
    "name": "Paitan Este",
    "lat": "16.08532",
    "lng": "120.03164"
  },
  {
    "country": "PH",
    "name": "Paitan Norte",
    "lat": "15.83333",
    "lng": "120.74086"
  },
  {
    "country": "PH",
    "name": "Paitan",
    "lat": "6.66005",
    "lng": "124.87183"
  },
  {
    "country": "PH",
    "name": "Paiisa",
    "lat": "13.92629",
    "lng": "121.35415"
  },
  {
    "country": "PH",
    "name": "Pagudpud",
    "lat": "18.5616",
    "lng": "120.7868"
  },
  {
    "country": "PH",
    "name": "Pagsanjan",
    "lat": "14.2732",
    "lng": "121.4552"
  },
  {
    "country": "PH",
    "name": "Pagsanghan",
    "lat": "11.9657",
    "lng": "124.7212"
  },
  {
    "country": "PH",
    "name": "Pagsañgahan",
    "lat": "13.21583",
    "lng": "122.54306"
  },
  {
    "country": "PH",
    "name": "Pagsanahan Norte",
    "lat": "17.9193",
    "lng": "120.4458"
  },
  {
    "country": "PH",
    "name": "Pagsabangan",
    "lat": "7.48111",
    "lng": "125.74944"
  },
  {
    "country": "PH",
    "name": "Pagbilao",
    "lat": "13.96689",
    "lng": "121.69835"
  },
  {
    "country": "PH",
    "name": "Pagatin",
    "lat": "6.97306",
    "lng": "124.47528"
  },
  {
    "country": "PH",
    "name": "Pag-asa",
    "lat": "7.57556",
    "lng": "125.68389"
  },
  {
    "country": "PH",
    "name": "Pagangan",
    "lat": "7.11444",
    "lng": "124.59528"
  },
  {
    "country": "PH",
    "name": "Pagaluñgan",
    "lat": "7.14167",
    "lng": "124.38056"
  },
  {
    "country": "PH",
    "name": "Pagalungan",
    "lat": "7.05667",
    "lng": "124.70083"
  },
  {
    "country": "PH",
    "name": "Pagadian",
    "lat": "7.8257",
    "lng": "123.437"
  },
  {
    "country": "PH",
    "name": "Paete",
    "lat": "14.3647",
    "lng": "121.4829"
  },
  {
    "country": "PH",
    "name": "Padre Zamora",
    "lat": "10.06667",
    "lng": "123.25"
  },
  {
    "country": "PH",
    "name": "Padre Garcia",
    "lat": "13.8791",
    "lng": "121.2139"
  },
  {
    "country": "PH",
    "name": "Padre Burgos",
    "lat": "13.9226",
    "lng": "121.81163"
  },
  {
    "country": "PH",
    "name": "Padre Burgos",
    "lat": "10.03694",
    "lng": "125.01917"
  },
  {
    "country": "PH",
    "name": "Padong",
    "lat": "18.05435",
    "lng": "120.75427"
  },
  {
    "country": "PH",
    "name": "Paddaya",
    "lat": "18.31279",
    "lng": "121.7677"
  },
  {
    "country": "PH",
    "name": "Padapada",
    "lat": "15.5517",
    "lng": "120.5163"
  },
  {
    "country": "PH",
    "name": "Padang",
    "lat": "13.2196",
    "lng": "123.7655"
  },
  {
    "country": "PH",
    "name": "Padada",
    "lat": "6.64111",
    "lng": "125.345"
  },
  {
    "country": "PH",
    "name": "Paco Roman",
    "lat": "15.6597",
    "lng": "121.0877"
  },
  {
    "country": "PH",
    "name": "Pacol",
    "lat": "10.45",
    "lng": "122.81667"
  },
  {
    "country": "PH",
    "name": "Paclolo",
    "lat": "12.37675",
    "lng": "121.17351"
  },
  {
    "country": "PH",
    "name": "Paatan",
    "lat": "7.11972",
    "lng": "124.92389"
  },
  {
    "country": "PH",
    "name": "Paagahan",
    "lat": "14.4447",
    "lng": "121.401"
  },
  {
    "country": "PH",
    "name": "Ozamiz City",
    "lat": "8.1481",
    "lng": "123.8405"
  },
  {
    "country": "PH",
    "name": "Owak",
    "lat": "10.55",
    "lng": "123.7"
  },
  {
    "country": "PH",
    "name": "Oton",
    "lat": "10.69306",
    "lng": "122.47361"
  },
  {
    "country": "PH",
    "name": "Utabi",
    "lat": "12.6417",
    "lng": "123.9092"
  },
  {
    "country": "PH",
    "name": "Osmeña",
    "lat": "12.7315",
    "lng": "123.3318"
  },
  {
    "country": "PH",
    "name": "Osmeña",
    "lat": "10.52083",
    "lng": "119.92583"
  },
  {
    "country": "PH",
    "name": "Oslob",
    "lat": "9.5211",
    "lng": "123.4315"
  },
  {
    "country": "PH",
    "name": "Osias",
    "lat": "7.6",
    "lng": "124.81667"
  },
  {
    "country": "PH",
    "name": "Osiao",
    "lat": "13.0914",
    "lng": "123.9811"
  },
  {
    "country": "PH",
    "name": "Oroquieta",
    "lat": "8.4859",
    "lng": "123.8048"
  },
  {
    "country": "PH",
    "name": "Orong",
    "lat": "9.9373",
    "lng": "122.829"
  },
  {
    "country": "PH",
    "name": "Ormoc",
    "lat": "11.00639",
    "lng": "124.6075"
  },
  {
    "country": "PH",
    "name": "Orion",
    "lat": "14.62056",
    "lng": "120.58167"
  },
  {
    "country": "PH",
    "name": "Oras",
    "lat": "12.1406",
    "lng": "125.4397"
  },
  {
    "country": "PH",
    "name": "Orani",
    "lat": "14.8006",
    "lng": "120.5371"
  },
  {
    "country": "PH",
    "name": "Oracon",
    "lat": "10.4782",
    "lng": "122.5839"
  },
  {
    "country": "PH",
    "name": "Opol",
    "lat": "8.52139",
    "lng": "124.57111"
  },
  {
    "country": "PH",
    "name": "Ondoy",
    "lat": "11.81917",
    "lng": "122.12611"
  },
  {
    "country": "PH",
    "name": "Olutanga",
    "lat": "7.31056",
    "lng": "122.84639"
  },
  {
    "country": "PH",
    "name": "Olongapo",
    "lat": "14.82917",
    "lng": "120.28278"
  },
  {
    "country": "PH",
    "name": "Olingan",
    "lat": "8.5381",
    "lng": "123.3216"
  },
  {
    "country": "PH",
    "name": "Olea",
    "lat": "15.86237",
    "lng": "120.49366"
  },
  {
    "country": "PH",
    "name": "Okiot",
    "lat": "9.56667",
    "lng": "123.16667"
  },
  {
    "country": "PH",
    "name": "Ogtongon",
    "lat": "10.77334",
    "lng": "123.52"
  },
  {
    "country": "PH",
    "name": "Ogod",
    "lat": "12.9009",
    "lng": "123.617"
  },
  {
    "country": "PH",
    "name": "Odiongan",
    "lat": "12.40167",
    "lng": "121.99194"
  },
  {
    "country": "PH",
    "name": "Odiongan",
    "lat": "8.84583",
    "lng": "125.16639"
  },
  {
    "country": "PH",
    "name": "Odiong",
    "lat": "12.5931",
    "lng": "121.5032"
  },
  {
    "country": "PH",
    "name": "Odiong",
    "lat": "11.5356",
    "lng": "122.4666"
  },
  {
    "country": "PH",
    "name": "Odiong",
    "lat": "10.2858",
    "lng": "123.0526"
  },
  {
    "country": "PH",
    "name": "Odicon",
    "lat": "13.53",
    "lng": "123.0588"
  },
  {
    "country": "PH",
    "name": "Ocoy",
    "lat": "11.1716",
    "lng": "123.7948"
  },
  {
    "country": "PH",
    "name": "Ochanado",
    "lat": "11.6139",
    "lng": "122.4833"
  },
  {
    "country": "PH",
    "name": "Ocaña",
    "lat": "10.0656",
    "lng": "123.6244"
  },
  {
    "country": "PH",
    "name": "Ocampo",
    "lat": "13.5594",
    "lng": "123.3761"
  },
  {
    "country": "PH",
    "name": "Obong",
    "lat": "9.741",
    "lng": "123.5098"
  },
  {
    "country": "PH",
    "name": "Obando",
    "lat": "14.7098",
    "lng": "120.9362"
  },
  {
    "country": "PH",
    "name": "Oaqui",
    "lat": "16.8583",
    "lng": "120.4124"
  },
  {
    "country": "PH",
    "name": "Numancia",
    "lat": "11.7059",
    "lng": "122.3284"
  },
  {
    "country": "PH",
    "name": "Noling",
    "lat": "6.65984",
    "lng": "124.09981"
  },
  {
    "country": "PH",
    "name": "Nugas",
    "lat": "9.6968",
    "lng": "123.4415"
  },
  {
    "country": "PH",
    "name": "Nueva Vida Sur",
    "lat": "9.7846",
    "lng": "124.1745"
  },
  {
    "country": "PH",
    "name": "Nueva Valencia",
    "lat": "10.51077",
    "lng": "122.5315"
  },
  {
    "country": "PH",
    "name": "Nueva Fuerza",
    "lat": "9.8464",
    "lng": "124.167"
  },
  {
    "country": "PH",
    "name": "Nueva Era",
    "lat": "17.9163",
    "lng": "120.6641"
  },
  {
    "country": "PH",
    "name": "Noveleta",
    "lat": "14.42922",
    "lng": "120.87989"
  },
  {
    "country": "PH",
    "name": "Novallas",
    "lat": "9.5117",
    "lng": "123.1225"
  },
  {
    "country": "PH",
    "name": "Norzagaray",
    "lat": "14.9109",
    "lng": "121.0493"
  },
  {
    "country": "PH",
    "name": "Norala",
    "lat": "6.5225",
    "lng": "124.65917"
  },
  {
    "country": "PH",
    "name": "Nuing",
    "lat": "5.63278",
    "lng": "125.43528"
  },
  {
    "country": "PH",
    "name": "Niugan",
    "lat": "14.94607",
    "lng": "120.9672"
  },
  {
    "country": "PH",
    "name": "Niugan",
    "lat": "14.66444",
    "lng": "120.95528"
  },
  {
    "country": "PH",
    "name": "Ninoy",
    "lat": "15.8596",
    "lng": "120.2478"
  },
  {
    "country": "PH",
    "name": "Nilombot",
    "lat": "16.0306",
    "lng": "120.43685"
  },
  {
    "country": "PH",
    "name": "Nieves",
    "lat": "15.32842",
    "lng": "120.94892"
  },
  {
    "country": "PH",
    "name": "Nibaliw Central",
    "lat": "16.1275",
    "lng": "120.4027"
  },
  {
    "country": "PH",
    "name": "New Washington",
    "lat": "11.6508",
    "lng": "122.4322"
  },
  {
    "country": "PH",
    "name": "New Visayas",
    "lat": "7.52333",
    "lng": "125.62333"
  },
  {
    "country": "PH",
    "name": "New Sibonga",
    "lat": "7.5609",
    "lng": "125.9298"
  },
  {
    "country": "PH",
    "name": "New Panay",
    "lat": "6.74237",
    "lng": "124.55956"
  },
  {
    "country": "PH",
    "name": "New Panamao",
    "lat": "5.95",
    "lng": "121.2"
  },
  {
    "country": "PH",
    "name": "Lucena",
    "lat": "10.8794",
    "lng": "122.5967"
  },
  {
    "country": "PH",
    "name": "New Leyte",
    "lat": "7.5",
    "lng": "125.75"
  },
  {
    "country": "PH",
    "name": "New Lagao",
    "lat": "6.70235",
    "lng": "124.64141"
  },
  {
    "country": "PH",
    "name": "New Iloilo",
    "lat": "6.54776",
    "lng": "124.78951"
  },
  {
    "country": "PH",
    "name": "New Corella",
    "lat": "7.5866",
    "lng": "125.8237"
  },
  {
    "country": "PH",
    "name": "New Cebu",
    "lat": "7.09528",
    "lng": "125.03361"
  },
  {
    "country": "PH",
    "name": "New Bohol",
    "lat": "7.5233",
    "lng": "125.8363"
  },
  {
    "country": "PH",
    "name": "New Batu Batu",
    "lat": "5.06667",
    "lng": "119.88333"
  },
  {
    "country": "PH",
    "name": "Bantacan",
    "lat": "7.604",
    "lng": "126.1298"
  },
  {
    "country": "PH",
    "name": "New Agutaya",
    "lat": "10.56139",
    "lng": "119.30778"
  },
  {
    "country": "PH",
    "name": "Nenita",
    "lat": "12.49167",
    "lng": "124.80444"
  },
  {
    "country": "PH",
    "name": "Nena",
    "lat": "11.76583",
    "lng": "125.41778"
  },
  {
    "country": "PH",
    "name": "Navotas",
    "lat": "14.66667",
    "lng": "120.95"
  },
  {
    "country": "PH",
    "name": "Navotas",
    "lat": "14.4167",
    "lng": "121.2268"
  },
  {
    "country": "PH",
    "name": "Navatat",
    "lat": "15.84971",
    "lng": "120.39054"
  },
  {
    "country": "PH",
    "name": "Naval",
    "lat": "11.56056",
    "lng": "124.3975"
  },
  {
    "country": "PH",
    "name": "Naujan",
    "lat": "13.32328",
    "lng": "121.30282"
  },
  {
    "country": "PH",
    "name": "Natalungan",
    "lat": "7.53167",
    "lng": "125.02361"
  },
  {
    "country": "PH",
    "name": "Natubleng",
    "lat": "16.69647",
    "lng": "120.78054"
  },
  {
    "country": "PH",
    "name": "Natonin",
    "lat": "17.10925",
    "lng": "121.27614"
  },
  {
    "country": "PH",
    "name": "Nato",
    "lat": "13.6105",
    "lng": "123.5356"
  },
  {
    "country": "PH",
    "name": "Nato",
    "lat": "10.1492",
    "lng": "122.8619"
  },
  {
    "country": "PH",
    "name": "Natividad",
    "lat": "16.0443",
    "lng": "120.7987"
  },
  {
    "country": "PH",
    "name": "Nattapian",
    "lat": "17.67536",
    "lng": "121.70296"
  },
  {
    "country": "PH",
    "name": "Nasugbu",
    "lat": "14.06694",
    "lng": "120.63181"
  },
  {
    "country": "PH",
    "name": "Masonogan",
    "lat": "11.3686",
    "lng": "122.6753"
  },
  {
    "country": "PH",
    "name": "Nasipit",
    "lat": "8.96917",
    "lng": "125.29472"
  },
  {
    "country": "PH",
    "name": "Narvacan",
    "lat": "17.4175",
    "lng": "120.4753"
  },
  {
    "country": "PH",
    "name": "Narra",
    "lat": "9.26877",
    "lng": "118.4043"
  },
  {
    "country": "PH",
    "name": "Naro",
    "lat": "11.89697",
    "lng": "123.67392"
  },
  {
    "country": "PH",
    "name": "Marawis",
    "lat": "10.2453",
    "lng": "122.8869"
  },
  {
    "country": "PH",
    "name": "Napuro",
    "lat": "12.0273",
    "lng": "124.7082"
  },
  {
    "country": "PH",
    "name": "Napoles",
    "lat": "10.504",
    "lng": "122.8979"
  },
  {
    "country": "PH",
    "name": "Napnapan",
    "lat": "10.70845",
    "lng": "122.393"
  },
  {
    "country": "PH",
    "name": "Napalitan",
    "lat": "8.77528",
    "lng": "124.80222"
  },
  {
    "country": "PH",
    "name": "Nanyo",
    "lat": "7.33306",
    "lng": "125.63778"
  },
  {
    "country": "PH",
    "name": "Nangka",
    "lat": "10.85564",
    "lng": "123.0359"
  },
  {
    "country": "PH",
    "name": "Nangka",
    "lat": "10.55",
    "lng": "123.96667"
  },
  {
    "country": "PH",
    "name": "Nangka",
    "lat": "10.5324",
    "lng": "123.7195"
  },
  {
    "country": "PH",
    "name": "Nañgka",
    "lat": "8.16667",
    "lng": "124.18333"
  },
  {
    "country": "PH",
    "name": "Nangka",
    "lat": "9.4023",
    "lng": "122.8244"
  },
  {
    "country": "PH",
    "name": "Nangan",
    "lat": "6.47264",
    "lng": "126.12438"
  },
  {
    "country": "PH",
    "name": "Nangalisan",
    "lat": "16.4344",
    "lng": "120.4778"
  },
  {
    "country": "PH",
    "name": "Nancamarinan",
    "lat": "15.6752",
    "lng": "120.5364"
  },
  {
    "country": "PH",
    "name": "Nancalobasaan",
    "lat": "15.9342",
    "lng": "120.8426"
  },
  {
    "country": "PH",
    "name": "Namuac",
    "lat": "18.6109",
    "lng": "121.1657"
  },
  {
    "country": "PH",
    "name": "Nampicuan",
    "lat": "15.7314",
    "lng": "120.625"
  },
  {
    "country": "PH",
    "name": "Namboongan",
    "lat": "16.3033",
    "lng": "120.3758"
  },
  {
    "country": "PH",
    "name": "Nambalan",
    "lat": "15.59911",
    "lng": "120.46031"
  },
  {
    "country": "PH",
    "name": "Nama",
    "lat": "16.1412",
    "lng": "120.5426"
  },
  {
    "country": "PH",
    "name": "Nalus",
    "lat": "6.01222",
    "lng": "124.58528"
  },
  {
    "country": "PH",
    "name": "Nalundan",
    "lat": "9.75",
    "lng": "123.06667"
  },
  {
    "country": "PH",
    "name": "Nalsian Norte",
    "lat": "15.84476",
    "lng": "120.45084"
  },
  {
    "country": "PH",
    "name": "Brgy. Nalook, kalibo",
    "lat": "11.68586",
    "lng": "122.36916"
  },
  {
    "country": "PH",
    "name": "Naisud",
    "lat": "11.8058",
    "lng": "122.1939"
  },
  {
    "country": "PH",
    "name": "Nailong",
    "lat": "11.0537",
    "lng": "124.0385"
  },
  {
    "country": "PH",
    "name": "Naili",
    "lat": "11.7666",
    "lng": "122.1765"
  },
  {
    "country": "PH",
    "name": "Naic",
    "lat": "14.31812",
    "lng": "120.76609"
  },
  {
    "country": "PH",
    "name": "Nahawan",
    "lat": "9.9711",
    "lng": "124.0484"
  },
  {
    "country": "PH",
    "name": "Naguilian",
    "lat": "17.02315",
    "lng": "121.83704"
  },
  {
    "country": "PH",
    "name": "Naguilian",
    "lat": "16.53389",
    "lng": "120.39667"
  },
  {
    "country": "PH",
    "name": "Naguilayan",
    "lat": "16.00304",
    "lng": "120.29108"
  },
  {
    "country": "PH",
    "name": "Naguelguel",
    "lat": "16.00585",
    "lng": "120.26351"
  },
  {
    "country": "PH",
    "name": "Nagtipunan",
    "lat": "16.21667",
    "lng": "121.6"
  },
  {
    "country": "PH",
    "name": "Nagsaing",
    "lat": "15.98069",
    "lng": "120.33787"
  },
  {
    "country": "PH",
    "name": "Nagrumbuan",
    "lat": "16.89955",
    "lng": "121.70974"
  },
  {
    "country": "PH",
    "name": "Nagpandayan",
    "lat": "15.60138",
    "lng": "120.76893"
  },
  {
    "country": "PH",
    "name": "Nagiba",
    "lat": "13.33018",
    "lng": "121.27432"
  },
  {
    "country": "PH",
    "name": "Naghalin",
    "lat": "11.1456",
    "lng": "124.5671"
  },
  {
    "country": "PH",
    "name": "Nagcarlan",
    "lat": "14.1364",
    "lng": "121.4165"
  },
  {
    "country": "PH",
    "name": "Nagbukel",
    "lat": "17.4471",
    "lng": "120.5247"
  },
  {
    "country": "PH",
    "name": "Nagbalaye",
    "lat": "9.2492",
    "lng": "122.8759"
  },
  {
    "country": "PH",
    "name": "Nagbacalan",
    "lat": "18.1159",
    "lng": "120.5235"
  },
  {
    "country": "PH",
    "name": "Naagas",
    "lat": "13.4357",
    "lng": "123.6781"
  },
  {
    "country": "PH",
    "name": "Naga",
    "lat": "13.61917",
    "lng": "123.18139"
  },
  {
    "country": "PH",
    "name": "Naga",
    "lat": "10.20898",
    "lng": "123.758"
  },
  {
    "country": "PH",
    "name": "Naga",
    "lat": "7.77028",
    "lng": "122.75083"
  },
  {
    "country": "PH",
    "name": "Nabunturan",
    "lat": "7.60778",
    "lng": "125.96639"
  },
  {
    "country": "PH",
    "name": "Nabulao",
    "lat": "9.6616",
    "lng": "122.4577"
  },
  {
    "country": "PH",
    "name": "Nabannagan West",
    "lat": "18.07156",
    "lng": "121.5363"
  },
  {
    "country": "PH",
    "name": "Nabua",
    "lat": "13.4075",
    "lng": "123.3724"
  },
  {
    "country": "PH",
    "name": "Nabas",
    "lat": "11.831",
    "lng": "122.087"
  },
  {
    "country": "PH",
    "name": "Nabangig",
    "lat": "12.0989",
    "lng": "123.9503"
  },
  {
    "country": "PH",
    "name": "Naawan",
    "lat": "8.43444",
    "lng": "124.28889"
  },
  {
    "country": "PH",
    "name": "Muti",
    "lat": "7.27583",
    "lng": "122.28"
  },
  {
    "country": "PH",
    "name": "Muricay",
    "lat": "7.8275",
    "lng": "123.4782"
  },
  {
    "country": "PH",
    "name": "Murcia",
    "lat": "15.40425",
    "lng": "120.60903"
  },
  {
    "country": "PH",
    "name": "Murcia",
    "lat": "10.60516",
    "lng": "123.0417"
  },
  {
    "country": "PH",
    "name": "Muntinlupa",
    "lat": "14.39028",
    "lng": "121.0475"
  },
  {
    "country": "PH",
    "name": "Muñoz East",
    "lat": "17.15754",
    "lng": "121.61354"
  },
  {
    "country": "PH",
    "name": "Muñoz",
    "lat": "15.71611",
    "lng": "120.90306"
  },
  {
    "country": "PH",
    "name": "Mungo",
    "lat": "17.72412",
    "lng": "121.47096"
  },
  {
    "country": "PH",
    "name": "Munai",
    "lat": "7.97583",
    "lng": "124.06361"
  },
  {
    "country": "PH",
    "name": "Mulauin",
    "lat": "13.86667",
    "lng": "121.01667"
  },
  {
    "country": "PH",
    "name": "Mulanay",
    "lat": "13.52222",
    "lng": "122.40417"
  },
  {
    "country": "PH",
    "name": "Muladbucad",
    "lat": "13.2389",
    "lng": "123.6057"
  },
  {
    "country": "PH",
    "name": "Mozzozzin Sur",
    "lat": "17.45685",
    "lng": "121.74607"
  },
  {
    "country": "PH",
    "name": "Mozon",
    "lat": "13.8526",
    "lng": "120.98935"
  },
  {
    "country": "PH",
    "name": "Motiong",
    "lat": "11.78",
    "lng": "124.99972"
  },
  {
    "country": "PH",
    "name": "Morong",
    "lat": "14.67889",
    "lng": "120.26611"
  },
  {
    "country": "PH",
    "name": "Morong",
    "lat": "14.51849",
    "lng": "121.23778"
  },
  {
    "country": "PH",
    "name": "Morobuan",
    "lat": "10.62566",
    "lng": "122.5547"
  },
  {
    "country": "PH",
    "name": "Moriones",
    "lat": "15.46116",
    "lng": "120.46579"
  },
  {
    "country": "PH",
    "name": "Morales",
    "lat": "11.5456",
    "lng": "122.3764"
  },
  {
    "country": "PH",
    "name": "Moog",
    "lat": "8.60111",
    "lng": "124.46583"
  },
  {
    "country": "PH",
    "name": "Montilla",
    "lat": "10.2027",
    "lng": "122.9261"
  },
  {
    "country": "PH",
    "name": "Montevista",
    "lat": "7.69333",
    "lng": "125.98889"
  },
  {
    "country": "PH",
    "name": "Montecillo",
    "lat": "13.89067",
    "lng": "121.47575"
  },
  {
    "country": "PH",
    "name": "Montaneza",
    "lat": "9.6846",
    "lng": "123.3289"
  },
  {
    "country": "PH",
    "name": "Rodriguez",
    "lat": "14.76011",
    "lng": "121.19993"
  },
  {
    "country": "PH",
    "name": "Monreal",
    "lat": "12.644",
    "lng": "123.6648"
  },
  {
    "country": "PH",
    "name": "Monpon",
    "lat": "10.91194",
    "lng": "122.63778"
  },
  {
    "country": "PH",
    "name": "Monkayo",
    "lat": "7.81528",
    "lng": "126.05444"
  },
  {
    "country": "PH",
    "name": "Mondragon",
    "lat": "12.5157",
    "lng": "124.7523"
  },
  {
    "country": "PH",
    "name": "Moncada",
    "lat": "15.7354",
    "lng": "120.574"
  },
  {
    "country": "PH",
    "name": "Monbon",
    "lat": "12.7307",
    "lng": "124.0189"
  },
  {
    "country": "PH",
    "name": "Monamon",
    "lat": "16.8833",
    "lng": "120.8833"
  },
  {
    "country": "PH",
    "name": "Molugan",
    "lat": "8.5375",
    "lng": "124.56222"
  },
  {
    "country": "PH",
    "name": "Molave",
    "lat": "8.0844",
    "lng": "123.491"
  },
  {
    "country": "PH",
    "name": "Moises Padilla",
    "lat": "10.27028",
    "lng": "123.07806"
  },
  {
    "country": "PH",
    "name": "Mogpog",
    "lat": "13.47444",
    "lng": "121.86139"
  },
  {
    "country": "PH",
    "name": "Mobo",
    "lat": "12.3363",
    "lng": "123.6574"
  },
  {
    "country": "PH",
    "name": "Moalboal",
    "lat": "9.94333",
    "lng": "123.39917"
  },
  {
    "country": "PH",
    "name": "Miranda",
    "lat": "10.3047",
    "lng": "122.8778"
  },
  {
    "country": "PH",
    "name": "Minuyan",
    "lat": "10.51366",
    "lng": "123.1049"
  },
  {
    "country": "PH",
    "name": "Minuri",
    "lat": "16.53233",
    "lng": "121.85532"
  },
  {
    "country": "PH",
    "name": "Minolos",
    "lat": "10.1019",
    "lng": "123.4727"
  },
  {
    "country": "PH",
    "name": "Minlagas",
    "lat": "8.87833",
    "lng": "125.03889"
  },
  {
    "country": "PH",
    "name": "Minien East",
    "lat": "15.97723",
    "lng": "120.48127"
  },
  {
    "country": "PH",
    "name": "Minglanilla",
    "lat": "10.24498",
    "lng": "123.7964"
  },
  {
    "country": "PH",
    "name": "Mindupok",
    "lat": "6.09056",
    "lng": "124.42333"
  },
  {
    "country": "PH",
    "name": "Minapasoc",
    "lat": "10.69885",
    "lng": "123.349"
  },
  {
    "country": "PH",
    "name": "Minapan",
    "lat": "6.815",
    "lng": "124.85861"
  },
  {
    "country": "PH",
    "name": "Minante Segundo",
    "lat": "16.9022",
    "lng": "121.76191"
  },
  {
    "country": "PH",
    "name": "Minanga Norte",
    "lat": "17.45233",
    "lng": "121.78533"
  },
  {
    "country": "PH",
    "name": "Minanga Norte",
    "lat": "17.7604",
    "lng": "121.72944"
  },
  {
    "country": "PH",
    "name": "Minallo",
    "lat": "16.98685",
    "lng": "121.85394"
  },
  {
    "country": "PH",
    "name": "Minalin",
    "lat": "14.9676",
    "lng": "120.6828"
  },
  {
    "country": "PH",
    "name": "Minalabac",
    "lat": "13.5687",
    "lng": "123.1838"
  },
  {
    "country": "PH",
    "name": "Mina",
    "lat": "10.9313",
    "lng": "122.5745"
  },
  {
    "country": "PH",
    "name": "Mileb",
    "lat": "6.89861",
    "lng": "124.58389"
  },
  {
    "country": "PH",
    "name": "Milaor",
    "lat": "13.5961",
    "lng": "123.1772"
  },
  {
    "country": "PH",
    "name": "Milagros",
    "lat": "12.21814",
    "lng": "123.50951"
  },
  {
    "country": "PH",
    "name": "Midsayap",
    "lat": "7.19083",
    "lng": "124.53028"
  },
  {
    "country": "PH",
    "name": "Midsalip",
    "lat": "8",
    "lng": "123.26667"
  },
  {
    "country": "PH",
    "name": "Miaray",
    "lat": "7.57472",
    "lng": "125.04444"
  },
  {
    "country": "PH",
    "name": "Mianay",
    "lat": "11.4716",
    "lng": "122.7011"
  },
  {
    "country": "PH",
    "name": "Miagao",
    "lat": "10.6442",
    "lng": "122.2352"
  },
  {
    "country": "PH",
    "name": "Miaga",
    "lat": "12.2376",
    "lng": "123.8167"
  },
  {
    "country": "PH",
    "name": "Meycauayan",
    "lat": "14.73694",
    "lng": "120.96083"
  },
  {
    "country": "PH",
    "name": "Mexico",
    "lat": "15.0646",
    "lng": "120.7198"
  },
  {
    "country": "PH",
    "name": "Merida",
    "lat": "10.9098",
    "lng": "124.5376"
  },
  {
    "country": "PH",
    "name": "Mercedes",
    "lat": "14.1093",
    "lng": "123.0109"
  },
  {
    "country": "PH",
    "name": "Mercedes",
    "lat": "10.6686",
    "lng": "124.4021"
  },
  {
    "country": "PH",
    "name": "Mercedes",
    "lat": "6.95861",
    "lng": "122.14833"
  },
  {
    "country": "PH",
    "name": "Mendez-Nuñez",
    "lat": "14.12861",
    "lng": "120.90583"
  },
  {
    "country": "PH",
    "name": "Medina",
    "lat": "8.91222",
    "lng": "125.02444"
  },
  {
    "country": "PH",
    "name": "Medellin",
    "lat": "11.1286",
    "lng": "123.9622"
  },
  {
    "country": "PH",
    "name": "McKinley",
    "lat": "10.0844",
    "lng": "123.2592"
  },
  {
    "country": "PH",
    "name": "Maypangdan",
    "lat": "11.65194",
    "lng": "125.45028"
  },
  {
    "country": "PH",
    "name": "Mayorga",
    "lat": "10.9",
    "lng": "125"
  },
  {
    "country": "PH",
    "name": "Mayo",
    "lat": "7.00211",
    "lng": "126.33198"
  },
  {
    "country": "PH",
    "name": "Mayngaran",
    "lat": "12.3492",
    "lng": "123.5996"
  },
  {
    "country": "PH",
    "name": "Maygatasan",
    "lat": "8.70944",
    "lng": "125.71833"
  },
  {
    "country": "PH",
    "name": "Maydolong",
    "lat": "11.50021",
    "lng": "125.49811"
  },
  {
    "country": "PH",
    "name": "Mayapusi",
    "lat": "9.6241",
    "lng": "123.0188"
  },
  {
    "country": "PH",
    "name": "Mayantoc",
    "lat": "15.6199",
    "lng": "120.377"
  },
  {
    "country": "PH",
    "name": "Mayana",
    "lat": "9.75611",
    "lng": "124.35222"
  },
  {
    "country": "PH",
    "name": "Mayabon",
    "lat": "9.0961",
    "lng": "123.1738"
  },
  {
    "country": "PH",
    "name": "Maya",
    "lat": "11.27442",
    "lng": "124.05526"
  },
  {
    "country": "PH",
    "name": "Maxingal",
    "lat": "18.21488",
    "lng": "121.66815"
  },
  {
    "country": "PH",
    "name": "Mawab",
    "lat": "7.56667",
    "lng": "125.98333"
  },
  {
    "country": "PH",
    "name": "Mauraro",
    "lat": "13.1494",
    "lng": "123.5953"
  },
  {
    "country": "PH",
    "name": "Maulawin",
    "lat": "14.26667",
    "lng": "121.43333"
  },
  {
    "country": "PH",
    "name": "Mauhao",
    "lat": "12.29015",
    "lng": "121.30071"
  },
  {
    "country": "PH",
    "name": "Maugat West",
    "lat": "13.8613",
    "lng": "121.28276"
  },
  {
    "country": "PH",
    "name": "Mauban",
    "lat": "14.191",
    "lng": "121.7309"
  },
  {
    "country": "PH",
    "name": "Maturanoc",
    "lat": "15.6571",
    "lng": "120.7921"
  },
  {
    "country": "PH",
    "name": "Matungao",
    "lat": "8.13611",
    "lng": "124.16417"
  },
  {
    "country": "PH",
    "name": "Matti",
    "lat": "6.77056",
    "lng": "125.30861"
  },
  {
    "country": "PH",
    "name": "Matnog",
    "lat": "14.06667",
    "lng": "122.93333"
  },
  {
    "country": "PH",
    "name": "Matnog",
    "lat": "12.5878",
    "lng": "124.0875"
  },
  {
    "country": "PH",
    "name": "Matlang",
    "lat": "10.8902",
    "lng": "124.4554"
  },
  {
    "country": "PH",
    "name": "Matiompong",
    "lat": "6.69611",
    "lng": "124.56611"
  },
  {
    "country": "PH",
    "name": "Matingain",
    "lat": "13.9129",
    "lng": "120.88006"
  },
  {
    "country": "PH",
    "name": "Malinao",
    "lat": "7.56029",
    "lng": "124.70839"
  },
  {
    "country": "PH",
    "name": "Maticmatic",
    "lat": "15.9863",
    "lng": "120.45192"
  },
  {
    "country": "PH",
    "name": "Matiao",
    "lat": "7.0828",
    "lng": "125.9362"
  },
  {
    "country": "PH",
    "name": "Mati",
    "lat": "9.7358",
    "lng": "125.468"
  },
  {
    "country": "PH",
    "name": "Mat-i",
    "lat": "8.40194",
    "lng": "124.34528"
  },
  {
    "country": "PH",
    "name": "Mati",
    "lat": "6.95508",
    "lng": "126.21655"
  },
  {
    "country": "PH",
    "name": "Mataywanac",
    "lat": "14.0311",
    "lng": "120.7296"
  },
  {
    "country": "PH",
    "name": "Matayumtayum",
    "lat": "15.5166",
    "lng": "120.7098"
  },
  {
    "country": "PH",
    "name": "Matanog",
    "lat": "7.51611",
    "lng": "124.25639"
  },
  {
    "country": "PH",
    "name": "Matangad",
    "lat": "8.57694",
    "lng": "124.37"
  },
  {
    "country": "PH",
    "name": "Matanao",
    "lat": "6.67917",
    "lng": "125.255"
  },
  {
    "country": "PH",
    "name": "Matalom",
    "lat": "10.28306",
    "lng": "124.78778"
  },
  {
    "country": "PH",
    "name": "Matalam",
    "lat": "7.08639",
    "lng": "124.90056"
  },
  {
    "country": "PH",
    "name": "Matala",
    "lat": "13.8287",
    "lng": "121.1549"
  },
  {
    "country": "PH",
    "name": "Matagbak",
    "lat": "14.13056",
    "lng": "120.83472"
  },
  {
    "country": "PH",
    "name": "Matacon",
    "lat": "13.3284",
    "lng": "123.4356"
  },
  {
    "country": "PH",
    "name": "Matabao",
    "lat": "8.95722",
    "lng": "125.39944"
  },
  {
    "country": "PH",
    "name": "Mataas Na Kahoy",
    "lat": "13.9589",
    "lng": "121.1138"
  },
  {
    "country": "PH",
    "name": "Masoli",
    "lat": "13.3593",
    "lng": "123.3898"
  },
  {
    "country": "PH",
    "name": "Maslog",
    "lat": "13.1046",
    "lng": "123.7713"
  },
  {
    "country": "PH",
    "name": "Maslog",
    "lat": "12.15",
    "lng": "125.23333"
  },
  {
    "country": "PH",
    "name": "Masiu",
    "lat": "7.81167",
    "lng": "124.3175"
  },
  {
    "country": "PH",
    "name": "Masipi West",
    "lat": "17.37933",
    "lng": "121.83861"
  },
  {
    "country": "PH",
    "name": "Masinloc",
    "lat": "15.5363",
    "lng": "119.9502"
  },
  {
    "country": "PH",
    "name": "Masiga",
    "lat": "13.3607",
    "lng": "121.8278"
  },
  {
    "country": "PH",
    "name": "Masbate",
    "lat": "12.37169",
    "lng": "123.62494"
  },
  {
    "country": "PH",
    "name": "Masaya Sur",
    "lat": "16.50017",
    "lng": "121.74743"
  },
  {
    "country": "PH",
    "name": "Masaya",
    "lat": "14.15189",
    "lng": "121.2819"
  },
  {
    "country": "PH",
    "name": "Masarayao",
    "lat": "11.08972",
    "lng": "124.6175"
  },
  {
    "country": "PH",
    "name": "Masaraway",
    "lat": "13.2268",
    "lng": "123.6148"
  },
  {
    "country": "PH",
    "name": "Masapang",
    "lat": "14.1971",
    "lng": "121.3423"
  },
  {
    "country": "PH",
    "name": "Masantol",
    "lat": "14.896",
    "lng": "120.7092"
  },
  {
    "country": "PH",
    "name": "Masalukot Uno",
    "lat": "13.95533",
    "lng": "121.41887"
  },
  {
    "country": "PH",
    "name": "Masalipit",
    "lat": "15.1481",
    "lng": "121.0373"
  },
  {
    "country": "PH",
    "name": "Masaling",
    "lat": "9.9818",
    "lng": "122.5369"
  },
  {
    "country": "PH",
    "name": "Masaguisi",
    "lat": "12.75452",
    "lng": "121.44841"
  },
  {
    "country": "PH",
    "name": "Masaba",
    "lat": "10.53333",
    "lng": "123.96667"
  },
  {
    "country": "PH",
    "name": "Marupit",
    "lat": "13.6269",
    "lng": "123.1663"
  },
  {
    "country": "PH",
    "name": "Marogong",
    "lat": "7.66667",
    "lng": "124.15"
  },
  {
    "country": "PH",
    "name": "Mariveles",
    "lat": "14.43385",
    "lng": "120.48569"
  },
  {
    "country": "PH",
    "name": "Miliroc",
    "lat": "13.3449",
    "lng": "123.702"
  },
  {
    "country": "PH",
    "name": "Maripipi",
    "lat": "11.77917",
    "lng": "124.34917"
  },
  {
    "country": "PH",
    "name": "Marintoc",
    "lat": "12.28554",
    "lng": "123.72281"
  },
  {
    "country": "PH",
    "name": "Marilao",
    "lat": "14.75778",
    "lng": "120.94833"
  },
  {
    "country": "PH",
    "name": "Marihatag",
    "lat": "8.8059",
    "lng": "126.2966"
  },
  {
    "country": "PH",
    "name": "Maricalom",
    "lat": "9.7049",
    "lng": "122.4188"
  },
  {
    "country": "PH",
    "name": "Maricaban",
    "lat": "11.1516",
    "lng": "123.7679"
  },
  {
    "country": "PH",
    "name": "Maribong",
    "lat": "11.1",
    "lng": "122.53333"
  },
  {
    "country": "PH",
    "name": "Maribojoc",
    "lat": "9.7417",
    "lng": "123.8446"
  },
  {
    "country": "PH",
    "name": "Mariano Marcos",
    "lat": "6.73333",
    "lng": "124.66667"
  },
  {
    "country": "PH",
    "name": "Mariano",
    "lat": "8.83333",
    "lng": "125.11667"
  },
  {
    "country": "PH",
    "name": "Maria Cristina",
    "lat": "8.16604",
    "lng": "124.20396"
  },
  {
    "country": "PH",
    "name": "Maria Aurora",
    "lat": "15.7967",
    "lng": "121.4737"
  },
  {
    "country": "PH",
    "name": "Maria",
    "lat": "9.1983",
    "lng": "123.6544"
  },
  {
    "country": "PH",
    "name": "Margosatubig",
    "lat": "7.5777",
    "lng": "123.1658"
  },
  {
    "country": "PH",
    "name": "Margen",
    "lat": "11.01722",
    "lng": "124.52833"
  },
  {
    "country": "PH",
    "name": "Marcos",
    "lat": "18.052",
    "lng": "120.6898"
  },
  {
    "country": "PH",
    "name": "Marbel",
    "lat": "7.11583",
    "lng": "124.9125"
  },
  {
    "country": "PH",
    "name": "Marawi City",
    "lat": "8.0034",
    "lng": "124.28395"
  },
  {
    "country": "PH",
    "name": "Marawa",
    "lat": "15.41727",
    "lng": "120.83819"
  },
  {
    "country": "PH",
    "name": "Maravilla",
    "lat": "10.9011",
    "lng": "123.8918"
  },
  {
    "country": "PH",
    "name": "Marao",
    "lat": "13.91434",
    "lng": "121.82409"
  },
  {
    "country": "PH",
    "name": "Marantao",
    "lat": "7.95",
    "lng": "124.23333"
  },
  {
    "country": "PH",
    "name": "Maramag",
    "lat": "7.76333",
    "lng": "125.00528"
  },
  {
    "country": "PH",
    "name": "Maragondon",
    "lat": "14.2733",
    "lng": "120.7377"
  },
  {
    "country": "PH",
    "name": "Makiwalo",
    "lat": "12.5101",
    "lng": "124.706"
  },
  {
    "country": "PH",
    "name": "Maquiling",
    "lat": "10.78094",
    "lng": "123.3938"
  },
  {
    "country": "PH",
    "name": "Maquiapo",
    "lat": "14.98561",
    "lng": "120.55855"
  },
  {
    "country": "PH",
    "name": "Maputi",
    "lat": "8.44972",
    "lng": "124.29056"
  },
  {
    "country": "PH",
    "name": "Mapulot",
    "lat": "14.033",
    "lng": "122.5399"
  },
  {
    "country": "PH",
    "name": "Mapulo",
    "lat": "13.7317",
    "lng": "121.1842"
  },
  {
    "country": "PH",
    "name": "Mapolopolo",
    "lat": "15.88087",
    "lng": "120.37422"
  },
  {
    "country": "PH",
    "name": "Mapili",
    "lat": "11.1081",
    "lng": "122.7393"
  },
  {
    "country": "PH",
    "name": "Mapaniqui",
    "lat": "15.10696",
    "lng": "120.92287"
  },
  {
    "country": "PH",
    "name": "Mapandan",
    "lat": "16.0248",
    "lng": "120.4547"
  },
  {
    "country": "PH",
    "name": "Mapanas",
    "lat": "12.47502",
    "lng": "125.25621"
  },
  {
    "country": "PH",
    "name": "Mapalad",
    "lat": "15.45133",
    "lng": "121.08384"
  },
  {
    "country": "PH",
    "name": "Mapalacsiao",
    "lat": "15.42831",
    "lng": "120.65252"
  },
  {
    "country": "PH",
    "name": "Maonon",
    "lat": "13.03643",
    "lng": "123.37074"
  },
  {
    "country": "PH",
    "name": "Manup",
    "lat": "11.5315",
    "lng": "122.498"
  },
  {
    "country": "PH",
    "name": "Manuk Mangkaw",
    "lat": "4.8",
    "lng": "119.85"
  },
  {
    "country": "PH",
    "name": "Manukan",
    "lat": "8.53333",
    "lng": "123.1"
  },
  {
    "country": "PH",
    "name": "Manuel Roxas",
    "lat": "6.44173",
    "lng": "124.66605"
  },
  {
    "country": "PH",
    "name": "Manubul",
    "lat": "5.4732",
    "lng": "120.7986"
  },
  {
    "country": "PH",
    "name": "Manuangan",
    "lat": "7.27694",
    "lng": "124.40444"
  },
  {
    "country": "PH",
    "name": "Mantiquil",
    "lat": "9.16667",
    "lng": "123.05"
  },
  {
    "country": "PH",
    "name": "Manticao",
    "lat": "8.40417",
    "lng": "124.28667"
  },
  {
    "country": "PH",
    "name": "Mantang",
    "lat": "11.87",
    "lng": "125.42833"
  },
  {
    "country": "PH",
    "name": "Mantampay",
    "lat": "8.16667",
    "lng": "124.21667"
  },
  {
    "country": "PH",
    "name": "Mantalongon",
    "lat": "10.126",
    "lng": "123.5808"
  },
  {
    "country": "PH",
    "name": "Mantalongon",
    "lat": "9.8106",
    "lng": "123.4617"
  },
  {
    "country": "PH",
    "name": "Mansilingan",
    "lat": "10.63111",
    "lng": "122.97889"
  },
  {
    "country": "PH",
    "name": "Mansalay",
    "lat": "12.52044",
    "lng": "121.43851"
  },
  {
    "country": "PH",
    "name": "Manolo Fortich",
    "lat": "8.36972",
    "lng": "124.86444"
  },
  {
    "country": "PH",
    "name": "Manoc-Manoc",
    "lat": "11.94157",
    "lng": "121.94281"
  },
  {
    "country": "PH",
    "name": "Maño",
    "lat": "11.04167",
    "lng": "123.94472"
  },
  {
    "country": "PH",
    "name": "Manlucahoc",
    "lat": "9.7399",
    "lng": "122.498"
  },
  {
    "country": "PH",
    "name": "Malilinao",
    "lat": "11.10694",
    "lng": "124.50111"
  },
  {
    "country": "PH",
    "name": "Manito",
    "lat": "13.1235",
    "lng": "123.8693"
  },
  {
    "country": "PH",
    "name": "Maninihon",
    "lat": "9.3711",
    "lng": "122.8405"
  },
  {
    "country": "PH",
    "name": "Manila",
    "lat": "14.6042",
    "lng": "120.9822"
  },
  {
    "country": "PH",
    "name": "Manikling",
    "lat": "6.87907",
    "lng": "126.06063"
  },
  {
    "country": "PH",
    "name": "Manika",
    "lat": "11.38801",
    "lng": "122.27931"
  },
  {
    "country": "PH",
    "name": "Manicahan",
    "lat": "7.01944",
    "lng": "122.20111"
  },
  {
    "country": "PH",
    "name": "Manibaug Pasig",
    "lat": "15.09621",
    "lng": "120.56445"
  },
  {
    "country": "PH",
    "name": "Manjoy",
    "lat": "11.3534",
    "lng": "122.6663"
  },
  {
    "country": "PH",
    "name": "Manquiring",
    "lat": "13.7341",
    "lng": "123.269"
  },
  {
    "country": "PH",
    "name": "Mangoso",
    "lat": "11.4175",
    "lng": "122.6382"
  },
  {
    "country": "PH",
    "name": "Mangili",
    "lat": "6.00333",
    "lng": "125.68389"
  },
  {
    "country": "PH",
    "name": "Mangero",
    "lat": "13.2705",
    "lng": "122.6774"
  },
  {
    "country": "PH",
    "name": "Mangatarem",
    "lat": "15.7874",
    "lng": "120.2921"
  },
  {
    "country": "PH",
    "name": "Mangas",
    "lat": "14.11769",
    "lng": "120.86661"
  },
  {
    "country": "PH",
    "name": "Mangarine",
    "lat": "12.35115",
    "lng": "121.09801"
  },
  {
    "country": "PH",
    "name": "Mangaldan",
    "lat": "16.07",
    "lng": "120.4025"
  },
  {
    "country": "PH",
    "name": "Manaloal",
    "lat": "7.36611",
    "lng": "125.66028"
  },
  {
    "country": "PH",
    "name": "Manggahan",
    "lat": "14.29196",
    "lng": "120.90145"
  },
  {
    "country": "PH",
    "name": "Manga",
    "lat": "17.70123",
    "lng": "121.86048"
  },
  {
    "country": "PH",
    "name": "Mangga",
    "lat": "15.25041",
    "lng": "120.90876"
  },
  {
    "country": "PH",
    "name": "Manga",
    "lat": "13.2719",
    "lng": "123.4623"
  },
  {
    "country": "PH",
    "name": "Manga",
    "lat": "6.29083",
    "lng": "125.30833"
  },
  {
    "country": "PH",
    "name": "Mandili",
    "lat": "15.17912",
    "lng": "120.87726"
  },
  {
    "country": "PH",
    "name": "Mandih",
    "lat": "8.2087",
    "lng": "123.0141"
  },
  {
    "country": "PH",
    "name": "Mandaue City",
    "lat": "10.32361",
    "lng": "123.92222"
  },
  {
    "country": "PH",
    "name": "Mandaon",
    "lat": "12.22594",
    "lng": "123.28421"
  },
  {
    "country": "PH",
    "name": "Mandangoa",
    "lat": "8.77278",
    "lng": "124.79111"
  },
  {
    "country": "PH",
    "name": "Mandaluyong City",
    "lat": "14.5832",
    "lng": "121.0409"
  },
  {
    "country": "PH",
    "name": "Mancilang",
    "lat": "11.2835",
    "lng": "123.7462"
  },
  {
    "country": "PH",
    "name": "Mankayan",
    "lat": "16.8632",
    "lng": "120.7829"
  },
  {
    "country": "PH",
    "name": "Manay",
    "lat": "7.34167",
    "lng": "125.575"
  },
  {
    "country": "PH",
    "name": "Manay",
    "lat": "7.215",
    "lng": "126.53972"
  },
  {
    "country": "PH",
    "name": "Manaulanan",
    "lat": "7.04806",
    "lng": "124.61944"
  },
  {
    "country": "PH",
    "name": "Manaul",
    "lat": "12.453",
    "lng": "121.4107"
  },
  {
    "country": "PH",
    "name": "Manatal",
    "lat": "14.87688",
    "lng": "120.91639"
  },
  {
    "country": "PH",
    "name": "Manat",
    "lat": "7.5637",
    "lng": "126.0184"
  },
  {
    "country": "PH",
    "name": "Manat",
    "lat": "7.5327",
    "lng": "126.0173"
  },
  {
    "country": "PH",
    "name": "Manaring",
    "lat": "17.17294",
    "lng": "121.90254"
  },
  {
    "country": "PH",
    "name": "Manapla",
    "lat": "10.95803",
    "lng": "123.123"
  },
  {
    "country": "PH",
    "name": "Manapa",
    "lat": "8.97778",
    "lng": "125.43944"
  },
  {
    "country": "PH",
    "name": "Manaoag",
    "lat": "16.0438",
    "lng": "120.4861"
  },
  {
    "country": "PH",
    "name": "Mananum",
    "lat": "8.83333",
    "lng": "124.95"
  },
  {
    "country": "PH",
    "name": "Manamrag",
    "lat": "13.7351",
    "lng": "124.1064"
  },
  {
    "country": "PH",
    "name": "Manalongon",
    "lat": "9.2209",
    "lng": "122.886"
  },
  {
    "country": "PH",
    "name": "Manalad",
    "lat": "10.0056",
    "lng": "122.7769"
  },
  {
    "country": "PH",
    "name": "Manogpi",
    "lat": "13.3108",
    "lng": "121.204"
  },
  {
    "country": "PH",
    "name": "Managok",
    "lat": "8.02889",
    "lng": "125.18861"
  },
  {
    "country": "PH",
    "name": "Managa",
    "lat": "6.74611",
    "lng": "125.26806"
  },
  {
    "country": "PH",
    "name": "Manacsac",
    "lat": "15.5952",
    "lng": "120.7911"
  },
  {
    "country": "PH",
    "name": "Manabo",
    "lat": "17.4332",
    "lng": "120.7053"
  },
  {
    "country": "PH",
    "name": "Mamonit",
    "lat": "15.58719",
    "lng": "120.39644"
  },
  {
    "country": "PH",
    "name": "Mampurog",
    "lat": "14.0458",
    "lng": "122.8836"
  },
  {
    "country": "PH",
    "name": "Mambusao",
    "lat": "11.43355",
    "lng": "122.5982"
  },
  {
    "country": "PH",
    "name": "Mamburao",
    "lat": "13.2233",
    "lng": "120.596"
  },
  {
    "country": "PH",
    "name": "Mambulo",
    "lat": "13.71667",
    "lng": "123.05"
  },
  {
    "country": "PH",
    "name": "Mambog",
    "lat": "15.3137",
    "lng": "120.0304"
  },
  {
    "country": "PH",
    "name": "Mambayaan",
    "lat": "8.78278",
    "lng": "124.78417"
  },
  {
    "country": "PH",
    "name": "Mambatangan",
    "lat": "8.43333",
    "lng": "124.83333"
  },
  {
    "country": "PH",
    "name": "Mambajao",
    "lat": "9.2504",
    "lng": "124.7156"
  },
  {
    "country": "PH",
    "name": "Mabahin",
    "lat": "9.18556",
    "lng": "126.17056"
  },
  {
    "country": "PH",
    "name": "Mambago",
    "lat": "7.10556",
    "lng": "125.69444"
  },
  {
    "country": "PH",
    "name": "Mambagatan",
    "lat": "10.1093",
    "lng": "122.8882"
  },
  {
    "country": "PH",
    "name": "Mamatid",
    "lat": "14.2349",
    "lng": "121.15902"
  },
  {
    "country": "PH",
    "name": "Mamali",
    "lat": "6.7736",
    "lng": "124.6477"
  },
  {
    "country": "PH",
    "name": "Mamala",
    "lat": "14.01667",
    "lng": "121.51667"
  },
  {
    "country": "PH",
    "name": "Malvar",
    "lat": "14.04472",
    "lng": "121.15861"
  },
  {
    "country": "PH",
    "name": "Maluso",
    "lat": "6.543",
    "lng": "121.8753"
  },
  {
    "country": "PH",
    "name": "Malusac",
    "lat": "14.85842",
    "lng": "120.6212"
  },
  {
    "country": "PH",
    "name": "Maluno Sur",
    "lat": "16.99885",
    "lng": "121.96434"
  },
  {
    "country": "PH",
    "name": "Maluñgun",
    "lat": "6.27917",
    "lng": "125.28167"
  },
  {
    "country": "PH",
    "name": "Maluko",
    "lat": "8.375",
    "lng": "124.95389"
  },
  {
    "country": "PH",
    "name": "Maluid",
    "lat": "15.5493",
    "lng": "120.6528"
  },
  {
    "country": "PH",
    "name": "Malway",
    "lat": "9.1319",
    "lng": "123.2203"
  },
  {
    "country": "PH",
    "name": "Maluanluan",
    "lat": "13.0967",
    "lng": "121.42352"
  },
  {
    "country": "PH",
    "name": "Maltana",
    "lat": "6.4229",
    "lng": "124.93688"
  },
  {
    "country": "PH",
    "name": "Maloma",
    "lat": "15.1135",
    "lng": "120.0639"
  },
  {
    "country": "PH",
    "name": "Malolos",
    "lat": "14.8443",
    "lng": "120.81039"
  },
  {
    "country": "PH",
    "name": "Maloh",
    "lat": "9.056",
    "lng": "122.9851"
  },
  {
    "country": "PH",
    "name": "Maloco",
    "lat": "11.7832",
    "lng": "122.152"
  },
  {
    "country": "PH",
    "name": "Malocloc",
    "lat": "11.50583",
    "lng": "122.67833"
  },
  {
    "country": "PH",
    "name": "Mallig",
    "lat": "17.21284",
    "lng": "121.61074"
  },
  {
    "country": "PH",
    "name": "Malitubog",
    "lat": "7.31556",
    "lng": "124.63806"
  },
  {
    "country": "PH",
    "name": "Malitbog",
    "lat": "12.75212",
    "lng": "121.46591"
  },
  {
    "country": "PH",
    "name": "Malitbog",
    "lat": "10.16",
    "lng": "124.99917"
  },
  {
    "country": "PH",
    "name": "Malitbog",
    "lat": "8.53389",
    "lng": "124.88306"
  },
  {
    "country": "PH",
    "name": "Malita",
    "lat": "6.415",
    "lng": "125.61167"
  },
  {
    "country": "PH",
    "name": "Malisbeng",
    "lat": "6.12",
    "lng": "124.35472"
  },
  {
    "country": "PH",
    "name": "Malinta",
    "lat": "12.30144",
    "lng": "123.55811"
  },
  {
    "country": "PH",
    "name": "Malingin",
    "lat": "11.05",
    "lng": "123.98333"
  },
  {
    "country": "PH",
    "name": "Malinaw",
    "lat": "8.825",
    "lng": "125.19306"
  },
  {
    "country": "PH",
    "name": "Malinao Ilaya",
    "lat": "13.99611",
    "lng": "121.83577"
  },
  {
    "country": "PH",
    "name": "Malinao",
    "lat": "13.3992",
    "lng": "123.7069"
  },
  {
    "country": "PH",
    "name": "Malinao",
    "lat": "11.6439",
    "lng": "122.3083"
  },
  {
    "country": "PH",
    "name": "Malinao",
    "lat": "6.65917",
    "lng": "125.28667"
  },
  {
    "country": "PH",
    "name": "Malimono",
    "lat": "9.61806",
    "lng": "125.40222"
  },
  {
    "country": "PH",
    "name": "Malilipot",
    "lat": "13.3188",
    "lng": "123.7385"
  },
  {
    "country": "PH",
    "name": "Maliig",
    "lat": "13.84556",
    "lng": "120.15032"
  },
  {
    "country": "PH",
    "name": "Maligaya",
    "lat": "15.6747",
    "lng": "120.8887"
  },
  {
    "country": "PH",
    "name": "Malidong",
    "lat": "13.01333",
    "lng": "123.45962"
  },
  {
    "country": "PH",
    "name": "Malicboy",
    "lat": "13.98155",
    "lng": "121.78888"
  },
  {
    "country": "PH",
    "name": "Malibong East",
    "lat": "15.8466",
    "lng": "120.3269"
  },
  {
    "country": "PH",
    "name": "Malibago",
    "lat": "13.2783",
    "lng": "122.0228"
  },
  {
    "country": "PH",
    "name": "Malhiao",
    "lat": "9.88487",
    "lng": "123.40641"
  },
  {
    "country": "PH",
    "name": "Malbug",
    "lat": "12.0563",
    "lng": "123.6461"
  },
  {
    "country": "PH",
    "name": "Malbug",
    "lat": "9.7327",
    "lng": "123.3402"
  },
  {
    "country": "PH",
    "name": "Malbang",
    "lat": "5.85556",
    "lng": "125.04528"
  },
  {
    "country": "PH",
    "name": "Malaybalay",
    "lat": "8.1575",
    "lng": "125.12778"
  },
  {
    "country": "PH",
    "name": "Malayal",
    "lat": "7.20801",
    "lng": "121.94204"
  },
  {
    "country": "PH",
    "name": "Malaya",
    "lat": "14.3971",
    "lng": "121.3385"
  },
  {
    "country": "PH",
    "name": "Malay",
    "lat": "11.90027",
    "lng": "121.90911"
  },
  {
    "country": "PH",
    "name": "Malawag",
    "lat": "13.38333",
    "lng": "123.28333"
  },
  {
    "country": "PH",
    "name": "Malawa",
    "lat": "15.95804",
    "lng": "120.27782"
  },
  {
    "country": "PH",
    "name": "Malatap",
    "lat": "14.1871",
    "lng": "122.5119"
  },
  {
    "country": "PH",
    "name": "Malasugui",
    "lat": "14.1439",
    "lng": "122.8471"
  },
  {
    "country": "PH",
    "name": "Malasiqui",
    "lat": "15.9201",
    "lng": "120.414"
  },
  {
    "country": "PH",
    "name": "Malasin",
    "lat": "16.80444",
    "lng": "121.78428"
  },
  {
    "country": "PH",
    "name": "Malasin",
    "lat": "16.3045",
    "lng": "121.1062"
  },
  {
    "country": "PH",
    "name": "Malasila",
    "lat": "6.94389",
    "lng": "125.12944"
  },
  {
    "country": "PH",
    "name": "Malaruhatan",
    "lat": "14.0306",
    "lng": "120.6804"
  },
  {
    "country": "PH",
    "name": "Malapatan",
    "lat": "5.96917",
    "lng": "125.28944"
  },
  {
    "country": "PH",
    "name": "Malapag",
    "lat": "7.13333",
    "lng": "124.81667"
  },
  {
    "country": "PH",
    "name": "Malangas",
    "lat": "7.63028",
    "lng": "123.03167"
  },
  {
    "country": "PH",
    "name": "Malangabang",
    "lat": "11.2367",
    "lng": "123.2062"
  },
  {
    "country": "PH",
    "name": "Malanday",
    "lat": "14.7069",
    "lng": "121.1306"
  },
  {
    "country": "PH",
    "name": "Malanay",
    "lat": "16.00865",
    "lng": "120.4094"
  },
  {
    "country": "PH",
    "name": "Malamote",
    "lat": "7.07389",
    "lng": "124.94"
  },
  {
    "country": "PH",
    "name": "Malamig",
    "lat": "12.95",
    "lng": "121.36667"
  },
  {
    "country": "PH",
    "name": "Malalag",
    "lat": "6.59583",
    "lng": "125.39917"
  },
  {
    "country": "PH",
    "name": "Malainen Luma",
    "lat": "14.2703",
    "lng": "120.7884"
  },
  {
    "country": "PH",
    "name": "Malaiba",
    "lat": "10.33333",
    "lng": "123.31667"
  },
  {
    "country": "PH",
    "name": "Malajog",
    "lat": "12.1102",
    "lng": "124.4793"
  },
  {
    "country": "PH",
    "name": "Malayo-an",
    "lat": "11.0979",
    "lng": "123.0091"
  },
  {
    "country": "PH",
    "name": "Malagos",
    "lat": "7.185",
    "lng": "125.42222"
  },
  {
    "country": "PH",
    "name": "Malaga",
    "lat": "12.23686",
    "lng": "124.37529"
  },
  {
    "country": "PH",
    "name": "Malacampa",
    "lat": "15.64335",
    "lng": "120.41109"
  },
  {
    "country": "PH",
    "name": "Malabuyoc",
    "lat": "9.6525",
    "lng": "123.3252"
  },
  {
    "country": "PH",
    "name": "Malabugas",
    "lat": "9.3692",
    "lng": "122.7702"
  },
  {
    "country": "PH",
    "name": "Malabor",
    "lat": "11.27292",
    "lng": "122.04661"
  },
  {
    "country": "PH",
    "name": "Malabonot",
    "lat": "11.96817",
    "lng": "121.92021"
  },
  {
    "country": "PH",
    "name": "Malabon",
    "lat": "15.6361",
    "lng": "119.9379"
  },
  {
    "country": "PH",
    "name": "Malabon",
    "lat": "14.67333",
    "lng": "120.93972"
  },
  {
    "country": "PH",
    "name": "Malabog",
    "lat": "13.1738",
    "lng": "123.6865"
  },
  {
    "country": "PH",
    "name": "Malabang",
    "lat": "7.59028",
    "lng": "124.07028"
  },
  {
    "country": "PH",
    "name": "Malabanban Norte",
    "lat": "13.94521",
    "lng": "121.43065"
  },
  {
    "country": "PH",
    "name": "Malabanan",
    "lat": "14",
    "lng": "121.13333"
  },
  {
    "country": "PH",
    "name": "Malabago",
    "lat": "15.98154",
    "lng": "120.35913"
  },
  {
    "country": "PH",
    "name": "Malabag",
    "lat": "14.1552",
    "lng": "120.96547"
  },
  {
    "country": "PH",
    "name": "Makilala",
    "lat": "6.95167",
    "lng": "125.09694"
  },
  {
    "country": "PH",
    "name": "Makati City",
    "lat": "14.55027",
    "lng": "121.03269"
  },
  {
    "country": "PH",
    "name": "Majayjay",
    "lat": "14.1463",
    "lng": "121.4729"
  },
  {
    "country": "PH",
    "name": "Maitum",
    "lat": "6.03917",
    "lng": "124.49861"
  },
  {
    "country": "PH",
    "name": "Mainit Norte",
    "lat": "14.16546",
    "lng": "121.98496"
  },
  {
    "country": "PH",
    "name": "Mainit",
    "lat": "9.535",
    "lng": "125.52306"
  },
  {
    "country": "PH",
    "name": "Mainit",
    "lat": "9.4335",
    "lng": "123.3595"
  },
  {
    "country": "PH",
    "name": "Mainit",
    "lat": "8.8436",
    "lng": "117.8183"
  },
  {
    "country": "PH",
    "name": "Maindang",
    "lat": "6.58978",
    "lng": "124.84732"
  },
  {
    "country": "PH",
    "name": "Maimbung",
    "lat": "5.93329",
    "lng": "121.02494"
  },
  {
    "country": "PH",
    "name": "Mailag",
    "lat": "7.97028",
    "lng": "125.1375"
  },
  {
    "country": "PH",
    "name": "Maigo",
    "lat": "8.1613",
    "lng": "123.9583"
  },
  {
    "country": "PH",
    "name": "Maibu",
    "lat": "6.57",
    "lng": "124.79361"
  },
  {
    "country": "PH",
    "name": "Mahinog",
    "lat": "9.15778",
    "lng": "124.7875"
  },
  {
    "country": "PH",
    "name": "Mahayag",
    "lat": "9.9349",
    "lng": "124.3164"
  },
  {
    "country": "PH",
    "name": "Mahayag",
    "lat": "8.1183",
    "lng": "123.4455"
  },
  {
    "country": "PH",
    "name": "Mahayag",
    "lat": "7.21667",
    "lng": "125.61944"
  },
  {
    "country": "PH",
    "name": "Mahatao",
    "lat": "20.41585",
    "lng": "121.94707"
  },
  {
    "country": "PH",
    "name": "Mahaplag",
    "lat": "10.6045",
    "lng": "124.9646"
  },
  {
    "country": "PH",
    "name": "Mahanob",
    "lat": "7.57326",
    "lng": "126.50684"
  },
  {
    "country": "PH",
    "name": "Mahala",
    "lat": "5.91667",
    "lng": "121.13333"
  },
  {
    "country": "PH",
    "name": "Mahabang Parang",
    "lat": "13.98333",
    "lng": "121.08333"
  },
  {
    "country": "PH",
    "name": "Mahaba",
    "lat": "13.2676",
    "lng": "123.5514"
  },
  {
    "country": "PH",
    "name": "Maguyam",
    "lat": "14.26277",
    "lng": "121.005"
  },
  {
    "country": "PH",
    "name": "Maguling",
    "lat": "6.095",
    "lng": "124.40333"
  },
  {
    "country": "PH",
    "name": "Maguinao",
    "lat": "15.02231",
    "lng": "120.93409"
  },
  {
    "country": "PH",
    "name": "Maguilling",
    "lat": "17.76982",
    "lng": "121.49778"
  },
  {
    "country": "PH",
    "name": "Magtangol",
    "lat": "15.758",
    "lng": "120.9156"
  },
  {
    "country": "PH",
    "name": "Magtaking",
    "lat": "15.9854",
    "lng": "120.1832"
  },
  {
    "country": "PH",
    "name": "Magsingal",
    "lat": "17.685",
    "lng": "120.42444"
  },
  {
    "country": "PH",
    "name": "Magsaysay",
    "lat": "17.30813",
    "lng": "121.77755"
  },
  {
    "country": "PH",
    "name": "Magsaysay",
    "lat": "12.33333",
    "lng": "121.15"
  },
  {
    "country": "PH",
    "name": "Magsaysay",
    "lat": "10.87389",
    "lng": "121.05306"
  },
  {
    "country": "PH",
    "name": "Magsaysay",
    "lat": "9.02083",
    "lng": "125.1825"
  },
  {
    "country": "PH",
    "name": "Magsaysay",
    "lat": "7.39667",
    "lng": "125.635"
  },
  {
    "country": "PH",
    "name": "Magsaysay",
    "lat": "6.76667",
    "lng": "125.18333"
  },
  {
    "country": "PH",
    "name": "Magsalangi",
    "lat": "12.18275",
    "lng": "123.56661"
  },
  {
    "country": "PH",
    "name": "Magpet",
    "lat": "7.10017",
    "lng": "125.11548"
  },
  {
    "country": "PH",
    "name": "Magnaga",
    "lat": "7.1694",
    "lng": "125.8931"
  },
  {
    "country": "PH",
    "name": "Maglamin",
    "lat": "8.05194",
    "lng": "125.26167"
  },
  {
    "country": "PH",
    "name": "Magdug",
    "lat": "6.54764",
    "lng": "126.09508"
  },
  {
    "country": "PH",
    "name": "Magdiwang",
    "lat": "12.48372",
    "lng": "122.51472"
  },
  {
    "country": "PH",
    "name": "Magdalena",
    "lat": "16.95225",
    "lng": "121.66548"
  },
  {
    "country": "PH",
    "name": "Magdalena",
    "lat": "14.1999",
    "lng": "121.429"
  },
  {
    "country": "PH",
    "name": "Magdalena",
    "lat": "10.4236",
    "lng": "121.9751"
  },
  {
    "country": "PH",
    "name": "Magbay",
    "lat": "12.41014",
    "lng": "121.08991"
  },
  {
    "country": "PH",
    "name": "Magay",
    "lat": "10.4719",
    "lng": "124.0132"
  },
  {
    "country": "PH",
    "name": "Magatos",
    "lat": "7.55556",
    "lng": "125.72667"
  },
  {
    "country": "PH",
    "name": "Magarao",
    "lat": "13.6604",
    "lng": "123.1869"
  },
  {
    "country": "PH",
    "name": "Magapit",
    "lat": "18.13741",
    "lng": "121.66942"
  },
  {
    "country": "PH",
    "name": "Magapit, Aguiguican",
    "lat": "18.10788",
    "lng": "121.67705"
  },
  {
    "country": "PH",
    "name": "Maganoy",
    "lat": "6.86472",
    "lng": "124.44167"
  },
  {
    "country": "PH",
    "name": "Magallon Cadre",
    "lat": "10.2885",
    "lng": "123.0922"
  },
  {
    "country": "PH",
    "name": "Magallanes",
    "lat": "16.0196",
    "lng": "120.739"
  },
  {
    "country": "PH",
    "name": "Magallanes",
    "lat": "14.18833",
    "lng": "120.7575"
  },
  {
    "country": "PH",
    "name": "Magallanes",
    "lat": "12.82917",
    "lng": "123.83639"
  },
  {
    "country": "PH",
    "name": "Magallanes",
    "lat": "9.02",
    "lng": "125.51722"
  },
  {
    "country": "PH",
    "name": "Magalang",
    "lat": "15.2151",
    "lng": "120.6596"
  },
  {
    "country": "PH",
    "name": "Magalalag",
    "lat": "17.57732",
    "lng": "121.73497"
  },
  {
    "country": "PH",
    "name": "Madulao",
    "lat": "13.5684",
    "lng": "122.3413"
  },
  {
    "country": "PH",
    "name": "Madridejos",
    "lat": "11.298",
    "lng": "123.7339"
  },
  {
    "country": "PH",
    "name": "Madridejos",
    "lat": "9.79116",
    "lng": "123.3462"
  },
  {
    "country": "PH",
    "name": "Madrid",
    "lat": "9.26211",
    "lng": "125.96437"
  },
  {
    "country": "PH",
    "name": "Maddela",
    "lat": "16.3414",
    "lng": "121.6849"
  },
  {
    "country": "PH",
    "name": "Maddarulug Norte",
    "lat": "17.60732",
    "lng": "121.6767"
  },
  {
    "country": "PH",
    "name": "Madamba",
    "lat": "7.83889",
    "lng": "124.11029"
  },
  {
    "country": "PH",
    "name": "Madalum",
    "lat": "7.8542",
    "lng": "124.12048"
  },
  {
    "country": "PH",
    "name": "Madalag",
    "lat": "11.5272",
    "lng": "122.3073"
  },
  {
    "country": "PH",
    "name": "Madalag",
    "lat": "10.89944",
    "lng": "122.9828"
  },
  {
    "country": "PH",
    "name": "Macrohon",
    "lat": "10.07972",
    "lng": "124.94306"
  },
  {
    "country": "PH",
    "name": "Maco",
    "lat": "7.36194",
    "lng": "125.85528"
  },
  {
    "country": "PH",
    "name": "Macayug",
    "lat": "16.09376",
    "lng": "120.43201"
  },
  {
    "country": "PH",
    "name": "Makato",
    "lat": "11.712",
    "lng": "122.2922"
  },
  {
    "country": "PH",
    "name": "Macatbong",
    "lat": "15.5048",
    "lng": "121.0791"
  },
  {
    "country": "PH",
    "name": "MacArthur",
    "lat": "10.83472",
    "lng": "124.99528"
  },
  {
    "country": "PH",
    "name": "Macarse",
    "lat": "15.42495",
    "lng": "120.77476"
  },
  {
    "country": "PH",
    "name": "Macapsing",
    "lat": "15.6783",
    "lng": "121.1319"
  },
  {
    "country": "PH",
    "name": "Macalva Norte",
    "lat": "16.3485",
    "lng": "120.3866"
  },
  {
    "country": "PH",
    "name": "Macalong",
    "lat": "16.0137",
    "lng": "120.6586"
  },
  {
    "country": "PH",
    "name": "Macalelon",
    "lat": "13.74694",
    "lng": "122.13861"
  },
  {
    "country": "PH",
    "name": "Macalaya",
    "lat": "12.88944",
    "lng": "123.77111"
  },
  {
    "country": "PH",
    "name": "Macalamcam A",
    "lat": "13.8566",
    "lng": "121.32814"
  },
  {
    "country": "PH",
    "name": "Macabugos",
    "lat": "13.2362",
    "lng": "123.3053"
  },
  {
    "country": "PH",
    "name": "Macabuboni",
    "lat": "16.1909",
    "lng": "119.7802"
  },
  {
    "country": "PH",
    "name": "Macabebe",
    "lat": "14.9089",
    "lng": "120.7155"
  },
  {
    "country": "PH",
    "name": "Macaas",
    "lat": "10.69885",
    "lng": "124.01154"
  },
  {
    "country": "PH",
    "name": "Mabuttal East",
    "lat": "18.3762",
    "lng": "121.5147"
  },
  {
    "country": "PH",
    "name": "Mabusag",
    "lat": "17.9261",
    "lng": "120.4976"
  },
  {
    "country": "PH",
    "name": "Mabunga",
    "lat": "13.8634",
    "lng": "122.0677"
  },
  {
    "country": "PH",
    "name": "Mabuhay",
    "lat": "7.41778",
    "lng": "122.83667"
  },
  {
    "country": "PH",
    "name": "Mabuhay",
    "lat": "7.33306",
    "lng": "125.5475"
  },
  {
    "country": "PH",
    "name": "Mabua",
    "lat": "9.8039",
    "lng": "125.4409"
  },
  {
    "country": "PH",
    "name": "Mabiton",
    "lat": "12.8334",
    "lng": "123.2612"
  },
  {
    "country": "PH",
    "name": "Mabitac",
    "lat": "14.4259",
    "lng": "121.429"
  },
  {
    "country": "PH",
    "name": "Mabini",
    "lat": "17.09936",
    "lng": "121.73454"
  },
  {
    "country": "PH",
    "name": "Mabini",
    "lat": "16.0699",
    "lng": "119.9391"
  },
  {
    "country": "PH",
    "name": "Mabini",
    "lat": "15.6",
    "lng": "120.98333"
  },
  {
    "country": "PH",
    "name": "Mabini",
    "lat": "13.75324",
    "lng": "120.94049"
  },
  {
    "country": "PH",
    "name": "Mabini",
    "lat": "11.41667",
    "lng": "125.16667"
  },
  {
    "country": "PH",
    "name": "Mabini",
    "lat": "10.79594",
    "lng": "123.4846"
  },
  {
    "country": "PH",
    "name": "Mabini",
    "lat": "9.8649",
    "lng": "124.5215"
  },
  {
    "country": "PH",
    "name": "Mabini",
    "lat": "7.31139",
    "lng": "125.85278"
  },
  {
    "country": "PH",
    "name": "Mabini",
    "lat": "6.50556",
    "lng": "124.9081"
  },
  {
    "country": "PH",
    "name": "Mabinay",
    "lat": "9.72722",
    "lng": "122.90167"
  },
  {
    "country": "PH",
    "name": "Mabilog",
    "lat": "15.39485",
    "lng": "120.66573"
  },
  {
    "country": "PH",
    "name": "Brgy. Mabilo, New Washington",
    "lat": "11.67778",
    "lng": "122.4075"
  },
  {
    "country": "PH",
    "name": "Mabilbila Sur",
    "lat": "17.50709",
    "lng": "120.441"
  },
  {
    "country": "PH",
    "name": "Mabilao",
    "lat": "16.15351",
    "lng": "120.42494"
  },
  {
    "country": "PH",
    "name": "Mabilang",
    "lat": "15.67511",
    "lng": "120.48835"
  },
  {
    "country": "PH",
    "name": "Mabayo",
    "lat": "14.7318",
    "lng": "120.2781"
  },
  {
    "country": "PH",
    "name": "Mabay",
    "lat": "6.05772",
    "lng": "124.46661"
  },
  {
    "country": "PH",
    "name": "Mabasa",
    "lat": "16.321",
    "lng": "121.1262"
  },
  {
    "country": "PH",
    "name": "Mabalacat City",
    "lat": "15.22303",
    "lng": "120.57117"
  },
  {
    "country": "PH",
    "name": "Mababanaba",
    "lat": "15.49715",
    "lng": "120.46053"
  },
  {
    "country": "PH",
    "name": "Maayong Tubig",
    "lat": "9.1672",
    "lng": "123.2469"
  },
  {
    "country": "PH",
    "name": "Maayon",
    "lat": "11.3867",
    "lng": "122.7859"
  },
  {
    "country": "PH",
    "name": "Maasin",
    "lat": "10.8925",
    "lng": "122.43472"
  },
  {
    "country": "PH",
    "name": "Maasin",
    "lat": "10.13361",
    "lng": "124.84472"
  },
  {
    "country": "PH",
    "name": "Maasim",
    "lat": "14.99551",
    "lng": "121.03082"
  },
  {
    "country": "PH",
    "name": "Maasin",
    "lat": "5.8575",
    "lng": "125.00611"
  },
  {
    "country": "PH",
    "name": "Maao",
    "lat": "10.4896",
    "lng": "122.9907"
  },
  {
    "country": "PH",
    "name": "Maanas",
    "lat": "8.89389",
    "lng": "125.03083"
  },
  {
    "country": "PH",
    "name": "Maan",
    "lat": "5.93389",
    "lng": "124.73556"
  },
  {
    "country": "PH",
    "name": "Maagnas",
    "lat": "13.7192",
    "lng": "123.6675"
  },
  {
    "country": "PH",
    "name": "Lusong",
    "lat": "16.867",
    "lng": "120.442"
  },
  {
    "country": "PH",
    "name": "Luzon",
    "lat": "6.51904",
    "lng": "126.09408"
  },
  {
    "country": "PH",
    "name": "Luuk Datan",
    "lat": "4.81194",
    "lng": "119.84528"
  },
  {
    "country": "PH",
    "name": "Lu-uk",
    "lat": "5.9684",
    "lng": "121.3122"
  },
  {
    "country": "PH",
    "name": "Lut-od",
    "lat": "10.25722",
    "lng": "123.62944"
  },
  {
    "country": "PH",
    "name": "Lutayan",
    "lat": "6.6189",
    "lng": "124.88156"
  },
  {
    "country": "PH",
    "name": "Kabayan",
    "lat": "16.62388",
    "lng": "120.83994"
  },
  {
    "country": "PH",
    "name": "Lusacan",
    "lat": "13.95523",
    "lng": "121.34477"
  },
  {
    "country": "PH",
    "name": "Lurugan",
    "lat": "8.01667",
    "lng": "124.96667"
  },
  {
    "country": "PH",
    "name": "Lupon",
    "lat": "6.89814",
    "lng": "126.00961"
  },
  {
    "country": "PH",
    "name": "Lupi Viejo",
    "lat": "13.7897",
    "lng": "122.9098"
  },
  {
    "country": "PH",
    "name": "Lupi",
    "lat": "13.53333",
    "lng": "123.15"
  },
  {
    "country": "PH",
    "name": "Lapase",
    "lat": "8.1924",
    "lng": "123.8632"
  },
  {
    "country": "PH",
    "name": "Lupao",
    "lat": "15.8793",
    "lng": "120.8983"
  },
  {
    "country": "PH",
    "name": "Luntal",
    "lat": "14.0292",
    "lng": "120.7174"
  },
  {
    "country": "PH",
    "name": "Lun Pequeño",
    "lat": "6.03778",
    "lng": "125.28389"
  },
  {
    "country": "PH",
    "name": "Lungog",
    "lat": "17.4645",
    "lng": "120.4784"
  },
  {
    "country": "PH",
    "name": "Lungaog",
    "lat": "7.52944",
    "lng": "125.68778"
  },
  {
    "country": "PH",
    "name": "Lunen",
    "lat": "6.35911",
    "lng": "124.90477"
  },
  {
    "country": "PH",
    "name": "Lunec",
    "lat": "15.95395",
    "lng": "120.48949"
  },
  {
    "country": "PH",
    "name": "Lunas",
    "lat": "10.6402",
    "lng": "123.7525"
  },
  {
    "country": "PH",
    "name": "Lunao",
    "lat": "8.85028",
    "lng": "125.05639"
  },
  {
    "country": "PH",
    "name": "Luna",
    "lat": "18.32583",
    "lng": "121.35361"
  },
  {
    "country": "PH",
    "name": "Luna",
    "lat": "16.96975",
    "lng": "121.72924"
  },
  {
    "country": "PH",
    "name": "Luna",
    "lat": "16.8528",
    "lng": "120.3761"
  },
  {
    "country": "PH",
    "name": "Luna",
    "lat": "10.969",
    "lng": "123.2419"
  },
  {
    "country": "PH",
    "name": "Luna",
    "lat": "9.737",
    "lng": "125.4976"
  },
  {
    "country": "PH",
    "name": "Luna",
    "lat": "7.57639",
    "lng": "125.66722"
  },
  {
    "country": "PH",
    "name": "Lumuyon",
    "lat": "5.91583",
    "lng": "124.78694"
  },
  {
    "country": "PH",
    "name": "Lumil",
    "lat": "14.18144",
    "lng": "121.00989"
  },
  {
    "country": "PH",
    "name": "Lumbia",
    "lat": "8.39583",
    "lng": "124.59389"
  },
  {
    "country": "PH",
    "name": "Lumbayao",
    "lat": "8.01667",
    "lng": "125.16667"
  },
  {
    "country": "PH",
    "name": "Lumbayanague",
    "lat": "7.7825",
    "lng": "124.28"
  },
  {
    "country": "PH",
    "name": "Lumbayan",
    "lat": "6.94722",
    "lng": "122.14111"
  },
  {
    "country": "PH",
    "name": "Lumbatan",
    "lat": "7.785",
    "lng": "124.25639"
  },
  {
    "country": "PH",
    "name": "Lumbangan",
    "lat": "14.0524",
    "lng": "120.6667"
  },
  {
    "country": "PH",
    "name": "Lumbang",
    "lat": "14.2973",
    "lng": "121.4598"
  },
  {
    "country": "PH",
    "name": "Lumatil",
    "lat": "5.87472",
    "lng": "124.88833"
  },
  {
    "country": "PH",
    "name": "Lumazal",
    "lat": "5.88528",
    "lng": "124.84944"
  },
  {
    "country": "PH",
    "name": "Lumangbayan",
    "lat": "13.419",
    "lng": "121.0348"
  },
  {
    "country": "PH",
    "name": "Lumangbayan",
    "lat": "13.0483",
    "lng": "121.49872"
  },
  {
    "country": "PH",
    "name": "Luksuhin",
    "lat": "14.09667",
    "lng": "120.88083"
  },
  {
    "country": "PH",
    "name": "Luklukan",
    "lat": "14.3254",
    "lng": "122.7124"
  },
  {
    "country": "PH",
    "name": "Luisiana",
    "lat": "14.185",
    "lng": "121.5109"
  },
  {
    "country": "PH",
    "name": "Lugus",
    "lat": "5.70361",
    "lng": "120.82028"
  },
  {
    "country": "PH",
    "name": "Lugui",
    "lat": "14.1131",
    "lng": "122.7935"
  },
  {
    "country": "PH",
    "name": "Lugo",
    "lat": "10.81672",
    "lng": "123.98626"
  },
  {
    "country": "PH",
    "name": "Lugait",
    "lat": "8.34111",
    "lng": "124.25917"
  },
  {
    "country": "PH",
    "name": "Lucsuhin",
    "lat": "13.88186",
    "lng": "120.64131"
  },
  {
    "country": "PH",
    "name": "Locmayan",
    "lat": "10.4726",
    "lng": "122.519"
  },
  {
    "country": "PH",
    "name": "Lucero",
    "lat": "16.4051",
    "lng": "119.9124"
  },
  {
    "country": "PH",
    "name": "Lucero",
    "lat": "11.4542",
    "lng": "122.46431"
  },
  {
    "country": "PH",
    "name": "Lucena",
    "lat": "13.93139",
    "lng": "121.61722"
  },
  {
    "country": "PH",
    "name": "Lucban",
    "lat": "14.11356",
    "lng": "121.55574"
  },
  {
    "country": "PH",
    "name": "Lukatan",
    "lat": "7.0096",
    "lng": "126.42118"
  },
  {
    "country": "PH",
    "name": "Lucapon",
    "lat": "15.6998",
    "lng": "119.932"
  },
  {
    "country": "PH",
    "name": "Lucap",
    "lat": "16.19038",
    "lng": "120.00221"
  },
  {
    "country": "PH",
    "name": "Lubuagan",
    "lat": "17.3548",
    "lng": "121.1747"
  },
  {
    "country": "PH",
    "name": "Lubigan",
    "lat": "13.742",
    "lng": "122.9373"
  },
  {
    "country": "PH",
    "name": "Lucban",
    "lat": "18.33644",
    "lng": "121.43082"
  },
  {
    "country": "PH",
    "name": "Lubao",
    "lat": "14.9405",
    "lng": "120.6011"
  },
  {
    "country": "PH",
    "name": "Lubang",
    "lat": "13.85835",
    "lng": "120.12402"
  },
  {
    "country": "PH",
    "name": "Luba",
    "lat": "17.318",
    "lng": "120.6945"
  },
  {
    "country": "PH",
    "name": "Loyola",
    "lat": "8.33492",
    "lng": "126.33366"
  },
  {
    "country": "PH",
    "name": "Lourdes",
    "lat": "15.0193",
    "lng": "120.8511"
  },
  {
    "country": "PH",
    "name": "Lourdes",
    "lat": "14.96667",
    "lng": "120.68333"
  },
  {
    "country": "PH",
    "name": "Lourdes",
    "lat": "13.3899",
    "lng": "123.3735"
  },
  {
    "country": "PH",
    "name": "Lourdes",
    "lat": "8.525",
    "lng": "124.43222"
  },
  {
    "country": "PH",
    "name": "Los Baños",
    "lat": "14.17025",
    "lng": "121.24181"
  },
  {
    "country": "PH",
    "name": "Los Arcos",
    "lat": "8.63278",
    "lng": "125.98556"
  },
  {
    "country": "PH",
    "name": "Los Angeles",
    "lat": "9.0125",
    "lng": "125.60806"
  },
  {
    "country": "PH",
    "name": "Loreto",
    "lat": "10.36361",
    "lng": "125.57306"
  },
  {
    "country": "PH",
    "name": "Loreto",
    "lat": "8.18694",
    "lng": "125.85306"
  },
  {
    "country": "PH",
    "name": "Lupo",
    "lat": "11.5076",
    "lng": "122.4791"
  },
  {
    "country": "PH",
    "name": "Lopez Jaena",
    "lat": "10.8478",
    "lng": "123.4141"
  },
  {
    "country": "PH",
    "name": "Lopez Jaena",
    "lat": "8.5528",
    "lng": "123.7615"
  },
  {
    "country": "PH",
    "name": "Lopez",
    "lat": "13.884",
    "lng": "122.2604"
  },
  {
    "country": "PH",
    "name": "Lope de Vega",
    "lat": "12.2983",
    "lng": "124.6238"
  },
  {
    "country": "PH",
    "name": "Loon",
    "lat": "9.7998",
    "lng": "123.7929"
  },
  {
    "country": "PH",
    "name": "Lookan",
    "lat": "5.037",
    "lng": "120.1027"
  },
  {
    "country": "PH",
    "name": "Looc",
    "lat": "8.84333",
    "lng": "124.79167"
  },
  {
    "country": "PH",
    "name": "Looc",
    "lat": "14.1648",
    "lng": "120.6293"
  },
  {
    "country": "PH",
    "name": "Looc",
    "lat": "13.72036",
    "lng": "120.24982"
  },
  {
    "country": "PH",
    "name": "Looc",
    "lat": "12.2605",
    "lng": "121.9926"
  },
  {
    "country": "PH",
    "name": "Looc",
    "lat": "11.4788",
    "lng": "124.5542"
  },
  {
    "country": "PH",
    "name": "Lono",
    "lat": "11.51361",
    "lng": "122.72972"
  },
  {
    "country": "PH",
    "name": "Lonoy",
    "lat": "11.51222",
    "lng": "122.55333"
  },
  {
    "country": "PH",
    "name": "Longos",
    "lat": "16.10734",
    "lng": "120.39658"
  },
  {
    "country": "PH",
    "name": "Lomboy",
    "lat": "15.49255",
    "lng": "120.71723"
  },
  {
    "country": "PH",
    "name": "Lombog",
    "lat": "9.7788",
    "lng": "124.4174"
  },
  {
    "country": "PH",
    "name": "Lombocan",
    "lat": "9.00767",
    "lng": "125.50558"
  },
  {
    "country": "PH",
    "name": "Loma de Gato",
    "lat": "14.78869",
    "lng": "120.99889"
  },
  {
    "country": "PH",
    "name": "Loqueb Este",
    "lat": "15.94481",
    "lng": "120.44607"
  },
  {
    "country": "PH",
    "name": "Logon",
    "lat": "11.3303",
    "lng": "124.1146"
  },
  {
    "country": "PH",
    "name": "Lobong",
    "lat": "16.0815",
    "lng": "120.4704"
  },
  {
    "country": "PH",
    "name": "Loboc",
    "lat": "9.63833",
    "lng": "124.03482"
  },
  {
    "country": "PH",
    "name": "Lobo",
    "lat": "13.6481",
    "lng": "121.2112"
  },
  {
    "country": "PH",
    "name": "Loay",
    "lat": "9.6006",
    "lng": "124.0142"
  },
  {
    "country": "PH",
    "name": "Loacan",
    "lat": "16.55",
    "lng": "120.66667"
  },
  {
    "country": "PH",
    "name": "Llorente",
    "lat": "11.41194",
    "lng": "125.54583"
  },
  {
    "country": "PH",
    "name": "Llanera",
    "lat": "15.6635",
    "lng": "121.0182"
  },
  {
    "country": "PH",
    "name": "Little Baguio",
    "lat": "7.89389",
    "lng": "125.27639"
  },
  {
    "country": "PH",
    "name": "Litayan",
    "lat": "7.33583",
    "lng": "124.03472"
  },
  {
    "country": "PH",
    "name": "Lipayran",
    "lat": "11.0593",
    "lng": "123.6342"
  },
  {
    "country": "PH",
    "name": "Lipay",
    "lat": "15.4561",
    "lng": "119.9208"
  },
  {
    "country": "PH",
    "name": "Lipahan",
    "lat": "13.83687",
    "lng": "121.40167"
  },
  {
    "country": "PH",
    "name": "Lipa City",
    "lat": "13.9411",
    "lng": "121.1631"
  },
  {
    "country": "PH",
    "name": "Liozon",
    "lat": "15.3993",
    "lng": "119.933"
  },
  {
    "country": "PH",
    "name": "Lintangan",
    "lat": "7.21554",
    "lng": "121.952"
  },
  {
    "country": "PH",
    "name": "Linoan",
    "lat": "7.626",
    "lng": "125.9741"
  },
  {
    "country": "PH",
    "name": "Linmansangan",
    "lat": "15.8298",
    "lng": "120.29593"
  },
  {
    "country": "PH",
    "name": "Lingion",
    "lat": "8.18806",
    "lng": "124.60972"
  },
  {
    "country": "PH",
    "name": "Lingig",
    "lat": "8.03889",
    "lng": "126.4125"
  },
  {
    "country": "PH",
    "name": "Lingayen",
    "lat": "16.02182",
    "lng": "120.23194"
  },
  {
    "country": "PH",
    "name": "Lingating",
    "lat": "8.33167",
    "lng": "124.62889"
  },
  {
    "country": "PH",
    "name": "Lingasan",
    "lat": "8.4966",
    "lng": "123.3997"
  },
  {
    "country": "PH",
    "name": "Linay",
    "lat": "8.51667",
    "lng": "123.13333"
  },
  {
    "country": "PH",
    "name": "San Miguel",
    "lat": "11.4924",
    "lng": "119.8703"
  },
  {
    "country": "PH",
    "name": "Linaon",
    "lat": "9.9499",
    "lng": "122.4483"
  },
  {
    "country": "PH",
    "name": "Linao",
    "lat": "7.16778",
    "lng": "124.9675"
  },
  {
    "country": "PH",
    "name": "Linao",
    "lat": "7.0172",
    "lng": "125.992"
  },
  {
    "country": "PH",
    "name": "Linan",
    "lat": "6.43218",
    "lng": "124.97617"
  },
  {
    "country": "PH",
    "name": "Linamon",
    "lat": "8.18603",
    "lng": "124.16276"
  },
  {
    "country": "PH",
    "name": "Linabuan Sur",
    "lat": "11.65111",
    "lng": "122.345"
  },
  {
    "country": "PH",
    "name": "Linabuan",
    "lat": "11.651",
    "lng": "122.3575"
  },
  {
    "country": "PH",
    "name": "Linabo",
    "lat": "8.05417",
    "lng": "125.155"
  },
  {
    "country": "PH",
    "name": "Limulan",
    "lat": "6.58528",
    "lng": "124.06189"
  },
  {
    "country": "PH",
    "name": "Limpapa",
    "lat": "7.11972",
    "lng": "121.91056"
  },
  {
    "country": "PH",
    "name": "Limot",
    "lat": "7.0405",
    "lng": "126.27268"
  },
  {
    "country": "PH",
    "name": "Limon",
    "lat": "12.3",
    "lng": "122.01667"
  },
  {
    "country": "PH",
    "name": "Limon",
    "lat": "11.2889",
    "lng": "124.5671"
  },
  {
    "country": "PH",
    "name": "Limanancong",
    "lat": "10.9893",
    "lng": "119.3593"
  },
  {
    "country": "PH",
    "name": "Limbo",
    "lat": "7.25167",
    "lng": "124.24389"
  },
  {
    "country": "PH",
    "name": "Limbalod",
    "lat": "7.13278",
    "lng": "124.79889"
  },
  {
    "country": "PH",
    "name": "Limbaan",
    "lat": "7.6396",
    "lng": "125.8209"
  },
  {
    "country": "PH",
    "name": "Limay",
    "lat": "14.56194",
    "lng": "120.59833"
  },
  {
    "country": "PH",
    "name": "Limaong",
    "lat": "7.36056",
    "lng": "122.36639"
  },
  {
    "country": "PH",
    "name": "Limao",
    "lat": "7.07917",
    "lng": "125.67361"
  },
  {
    "country": "PH",
    "name": "Liloy",
    "lat": "8.11444",
    "lng": "122.65944"
  },
  {
    "country": "PH",
    "name": "Liloan",
    "lat": "11.04417",
    "lng": "124.55056"
  },
  {
    "country": "PH",
    "name": "Liloan",
    "lat": "10.3991",
    "lng": "123.9992"
  },
  {
    "country": "PH",
    "name": "Liloan",
    "lat": "10.15811",
    "lng": "125.11806"
  },
  {
    "country": "PH",
    "name": "Lilio",
    "lat": "14.1313",
    "lng": "121.4362"
  },
  {
    "country": "PH",
    "name": "Liliongan",
    "lat": "7.36278",
    "lng": "124.79278"
  },
  {
    "country": "PH",
    "name": "Lila",
    "lat": "9.5918",
    "lng": "124.0958"
  },
  {
    "country": "PH",
    "name": "Ligayan",
    "lat": "4.65442",
    "lng": "119.47062"
  },
  {
    "country": "PH",
    "name": "Ligaya",
    "lat": "15.5091",
    "lng": "121.2872"
  },
  {
    "country": "PH",
    "name": "Ligaya",
    "lat": "12.65993",
    "lng": "120.89231"
  },
  {
    "country": "PH",
    "name": "Ligao",
    "lat": "13.21697",
    "lng": "123.51924"
  },
  {
    "country": "PH",
    "name": "Lidlidda",
    "lat": "17.2693",
    "lng": "120.5213"
  },
  {
    "country": "PH",
    "name": "Licuan",
    "lat": "17.6089",
    "lng": "120.9059"
  },
  {
    "country": "PH",
    "name": "Liciada",
    "lat": "14.91484",
    "lng": "120.93182"
  },
  {
    "country": "PH",
    "name": "Licab",
    "lat": "15.5439",
    "lng": "120.7634"
  },
  {
    "country": "PH",
    "name": "Libungan",
    "lat": "7.24083",
    "lng": "124.52"
  },
  {
    "country": "PH",
    "name": "Libuganon",
    "lat": "7.3488",
    "lng": "125.7782"
  },
  {
    "country": "PH",
    "name": "Liboro",
    "lat": "13.8245",
    "lng": "122.7295"
  },
  {
    "country": "PH",
    "name": "Liboran",
    "lat": "8.35472",
    "lng": "124.64889"
  },
  {
    "country": "PH",
    "name": "Libona",
    "lat": "8.33889",
    "lng": "124.73528"
  },
  {
    "country": "PH",
    "name": "Libon",
    "lat": "13.2997",
    "lng": "123.4386"
  },
  {
    "country": "PH",
    "name": "Libog",
    "lat": "13.2349",
    "lng": "123.7778"
  },
  {
    "country": "PH",
    "name": "Libmanan",
    "lat": "13.6928",
    "lng": "123.0596"
  },
  {
    "country": "PH",
    "name": "Libjo",
    "lat": "10.19778",
    "lng": "125.53528"
  },
  {
    "country": "PH",
    "name": "Liberty",
    "lat": "10.87417",
    "lng": "125.0025"
  },
  {
    "country": "PH",
    "name": "Liberty",
    "lat": "6.51989",
    "lng": "124.63194"
  },
  {
    "country": "PH",
    "name": "Liberty",
    "lat": "6.45521",
    "lng": "124.98217"
  },
  {
    "country": "PH",
    "name": "Libertad",
    "lat": "12.45412",
    "lng": "122.00828"
  },
  {
    "country": "PH",
    "name": "Libertad",
    "lat": "11.7694",
    "lng": "121.919"
  },
  {
    "country": "PH",
    "name": "Libertad",
    "lat": "11.03639",
    "lng": "124.56833"
  },
  {
    "country": "PH",
    "name": "Libertad",
    "lat": "11.03528",
    "lng": "122.76944"
  },
  {
    "country": "PH",
    "name": "Libertad",
    "lat": "11.0304",
    "lng": "124.0215"
  },
  {
    "country": "PH",
    "name": "Libertad",
    "lat": "10.91667",
    "lng": "124.45"
  },
  {
    "country": "PH",
    "name": "Libertad",
    "lat": "10.83333",
    "lng": "123.56667"
  },
  {
    "country": "PH",
    "name": "Libertad",
    "lat": "8.94417",
    "lng": "125.50194"
  },
  {
    "country": "PH",
    "name": "Libertad",
    "lat": "8.56111",
    "lng": "124.35139"
  },
  {
    "country": "PH",
    "name": "Libertad",
    "lat": "8.2755",
    "lng": "123.8382"
  },
  {
    "country": "PH",
    "name": "Libertad",
    "lat": "8.25",
    "lng": "124.23333"
  },
  {
    "country": "PH",
    "name": "Libertad",
    "lat": "8.1075",
    "lng": "126.02639"
  },
  {
    "country": "PH",
    "name": "Libato",
    "lat": "13.81514",
    "lng": "121.33463"
  },
  {
    "country": "PH",
    "name": "Libas",
    "lat": "15.87789",
    "lng": "120.31633"
  },
  {
    "country": "PH",
    "name": "Libas",
    "lat": "13.24167",
    "lng": "121.95555"
  },
  {
    "country": "PH",
    "name": "Libas",
    "lat": "10.9388",
    "lng": "124.545"
  },
  {
    "country": "PH",
    "name": "Libas",
    "lat": "9.88333",
    "lng": "125.98333"
  },
  {
    "country": "PH",
    "name": "Libas",
    "lat": "6.52014",
    "lng": "124.78234"
  },
  {
    "country": "PH",
    "name": "Libagon",
    "lat": "10.30083",
    "lng": "125.05583"
  },
  {
    "country": "PH",
    "name": "Libacao",
    "lat": "11.4802",
    "lng": "122.30421"
  },
  {
    "country": "PH",
    "name": "Libacao",
    "lat": "10.18",
    "lng": "122.9137"
  },
  {
    "country": "PH",
    "name": "Lianga",
    "lat": "8.63361",
    "lng": "126.09472"
  },
  {
    "country": "PH",
    "name": "Lian",
    "lat": "14.03364",
    "lng": "120.64928"
  },
  {
    "country": "PH",
    "name": "Leyte",
    "lat": "11.36687",
    "lng": "124.48239"
  },
  {
    "country": "PH",
    "name": "Leuteboro",
    "lat": "13.061",
    "lng": "121.37472"
  },
  {
    "country": "PH",
    "name": "Lepanto",
    "lat": "9.6845",
    "lng": "123.4026"
  },
  {
    "country": "PH",
    "name": "Lepa",
    "lat": "15.88438",
    "lng": "120.45089"
  },
  {
    "country": "PH",
    "name": "Leones East",
    "lat": "16.3633",
    "lng": "120.3919"
  },
  {
    "country": "PH",
    "name": "Leon",
    "lat": "10.78085",
    "lng": "122.3894"
  },
  {
    "country": "PH",
    "name": "Lennec",
    "lat": "15.6835",
    "lng": "120.7338"
  },
  {
    "country": "PH",
    "name": "Lemery",
    "lat": "13.8809",
    "lng": "120.91389"
  },
  {
    "country": "PH",
    "name": "Lemery",
    "lat": "11.2258",
    "lng": "122.9275"
  },
  {
    "country": "PH",
    "name": "Legaspi",
    "lat": "13.14125",
    "lng": "123.74073"
  },
  {
    "country": "PH",
    "name": "Legrada",
    "lat": "7.6333",
    "lng": "123.3045"
  },
  {
    "country": "PH",
    "name": "Leganes",
    "lat": "10.78722",
    "lng": "122.58917"
  },
  {
    "country": "PH",
    "name": "Lebak",
    "lat": "6.64389",
    "lng": "124.06583"
  },
  {
    "country": "PH",
    "name": "Lazi",
    "lat": "9.1287",
    "lng": "123.6356"
  },
  {
    "country": "PH",
    "name": "Layog",
    "lat": "7.07667",
    "lng": "124.73056"
  },
  {
    "country": "PH",
    "name": "Laylay",
    "lat": "13.4391",
    "lng": "121.8202"
  },
  {
    "country": "PH",
    "name": "Laya",
    "lat": "17.4726",
    "lng": "121.4678"
  },
  {
    "country": "PH",
    "name": "Lawang Kupang",
    "lat": "15.34807",
    "lng": "120.85752"
  },
  {
    "country": "PH",
    "name": "Lawa-an",
    "lat": "11.14028",
    "lng": "125.30139"
  },
  {
    "country": "PH",
    "name": "Lawa-an",
    "lat": "11.15",
    "lng": "122.03333"
  },
  {
    "country": "PH",
    "name": "Lavezares",
    "lat": "12.5336",
    "lng": "124.3305"
  },
  {
    "country": "PH",
    "name": "Laurel",
    "lat": "14.05542",
    "lng": "120.91932"
  },
  {
    "country": "PH",
    "name": "Laur",
    "lat": "15.5865",
    "lng": "121.1834"
  },
  {
    "country": "PH",
    "name": "La Union",
    "lat": "9.08556",
    "lng": "125.53583"
  },
  {
    "country": "PH",
    "name": "La Union",
    "lat": "6.70413",
    "lng": "126.08798"
  },
  {
    "country": "PH",
    "name": "Lauigan",
    "lat": "10.487",
    "lng": "122.0354"
  },
  {
    "country": "PH",
    "name": "Latung",
    "lat": "5.5",
    "lng": "120.88333"
  },
  {
    "country": "PH",
    "name": "La Trinidad",
    "lat": "16.455",
    "lng": "120.5875"
  },
  {
    "country": "PH",
    "name": "Las Piñas",
    "lat": "14.45056",
    "lng": "120.98278"
  },
  {
    "country": "PH",
    "name": "Las Navas",
    "lat": "12.3392",
    "lng": "125.0313"
  },
  {
    "country": "PH",
    "name": "Lasang",
    "lat": "7.26694",
    "lng": "125.665"
  },
  {
    "country": "PH",
    "name": "Lasam",
    "lat": "18.06519",
    "lng": "121.60065"
  },
  {
    "country": "PH",
    "name": "La Roxas",
    "lat": "7.86417",
    "lng": "124.88694"
  },
  {
    "country": "PH",
    "name": "Larion Alto",
    "lat": "17.63082",
    "lng": "121.76062"
  },
  {
    "country": "PH",
    "name": "Larena",
    "lat": "9.24528",
    "lng": "123.59389"
  },
  {
    "country": "PH",
    "name": "Larap",
    "lat": "14.299",
    "lng": "122.6504"
  },
  {
    "country": "PH",
    "name": "Larap",
    "lat": "4.76154",
    "lng": "119.40511"
  },
  {
    "country": "PH",
    "name": "Lapuz",
    "lat": "6.49416",
    "lng": "124.63054"
  },
  {
    "country": "PH",
    "name": "Lapuyan",
    "lat": "7.6379",
    "lng": "123.1944"
  },
  {
    "country": "PH",
    "name": "Lapu-Lapu City",
    "lat": "10.31028",
    "lng": "123.94944"
  },
  {
    "country": "PH",
    "name": "Lapuan",
    "lat": "6.14444",
    "lng": "125.70083"
  },
  {
    "country": "PH",
    "name": "Lapolapo",
    "lat": "13.8341",
    "lng": "121.1379"
  },
  {
    "country": "PH",
    "name": "Lapinigan",
    "lat": "8.42056",
    "lng": "125.9825"
  },
  {
    "country": "PH",
    "name": "Lapinig",
    "lat": "12.3151",
    "lng": "125.3032"
  },
  {
    "country": "PH",
    "name": "Lapi",
    "lat": "17.716",
    "lng": "121.89775"
  },
  {
    "country": "PH",
    "name": "La Paz",
    "lat": "17.6746",
    "lng": "120.6864"
  },
  {
    "country": "PH",
    "name": "La Paz",
    "lat": "16.91075",
    "lng": "121.66824"
  },
  {
    "country": "PH",
    "name": "La Paz",
    "lat": "15.44125",
    "lng": "120.72863"
  },
  {
    "country": "PH",
    "name": "De la Paz",
    "lat": "11.06444",
    "lng": "122.77917"
  },
  {
    "country": "PH",
    "name": "Lapaz",
    "lat": "10.9887",
    "lng": "123.9797"
  },
  {
    "country": "PH",
    "name": "La Paz",
    "lat": "10.8925",
    "lng": "124.95583"
  },
  {
    "country": "PH",
    "name": "La Paz",
    "lat": "10.4131",
    "lng": "122.5162"
  },
  {
    "country": "PH",
    "name": "La Paz",
    "lat": "8.98471",
    "lng": "126.26299"
  },
  {
    "country": "PH",
    "name": "La Paz",
    "lat": "8.27083",
    "lng": "125.79972"
  },
  {
    "country": "PH",
    "name": "La Paz",
    "lat": "7.31583",
    "lng": "125.73333"
  },
  {
    "country": "PH",
    "name": "Laoang",
    "lat": "12.5698",
    "lng": "125.0141"
  },
  {
    "country": "PH",
    "name": "Laoag",
    "lat": "18.1978",
    "lng": "120.5957"
  },
  {
    "country": "PH",
    "name": "Lao",
    "lat": "11.01806",
    "lng": "124.55972"
  },
  {
    "country": "PH",
    "name": "Lanuza",
    "lat": "9.23417",
    "lng": "126.06444"
  },
  {
    "country": "PH",
    "name": "Tairan Camp",
    "lat": "6.6402",
    "lng": "121.8395"
  },
  {
    "country": "PH",
    "name": "Lantapan",
    "lat": "7.99778",
    "lng": "125.02778"
  },
  {
    "country": "PH",
    "name": "Lantangan",
    "lat": "12.19815",
    "lng": "123.27101"
  },
  {
    "country": "PH",
    "name": "Lantangan",
    "lat": "11.5882",
    "lng": "123.3256"
  },
  {
    "country": "PH",
    "name": "Lantangan",
    "lat": "11.386",
    "lng": "122.8887"
  },
  {
    "country": "PH",
    "name": "Lanot",
    "lat": "11.51917",
    "lng": "122.75722"
  },
  {
    "country": "PH",
    "name": "Lanna",
    "lat": "17.696",
    "lng": "121.70014"
  },
  {
    "country": "PH",
    "name": "Lanigay",
    "lat": "13.31667",
    "lng": "123.5"
  },
  {
    "country": "PH",
    "name": "Languyan",
    "lat": "5.2618",
    "lng": "120.0807"
  },
  {
    "country": "PH",
    "name": "Lañgub",
    "lat": "10.79754",
    "lng": "123.5338"
  },
  {
    "country": "PH",
    "name": "Langob",
    "lat": "10.5774",
    "lng": "123.7309"
  },
  {
    "country": "PH",
    "name": "Langtad",
    "lat": "10.18568",
    "lng": "123.7344"
  },
  {
    "country": "PH",
    "name": "Langtad",
    "lat": "9.89094",
    "lng": "123.6043"
  },
  {
    "country": "PH",
    "name": "Langpas",
    "lat": "5.975",
    "lng": "120.949"
  },
  {
    "country": "PH",
    "name": "Langiden",
    "lat": "17.5771",
    "lng": "120.564"
  },
  {
    "country": "PH",
    "name": "Langcangan",
    "lat": "8.47944",
    "lng": "123.75583"
  },
  {
    "country": "PH",
    "name": "Langatian",
    "lat": "8.5208",
    "lng": "123.2324"
  },
  {
    "country": "PH",
    "name": "Lanat",
    "lat": "15.79189",
    "lng": "120.60461"
  },
  {
    "country": "PH",
    "name": "Lanas",
    "lat": "12.04946",
    "lng": "121.91851"
  },
  {
    "country": "PH",
    "name": "Lanas",
    "lat": "10.26667",
    "lng": "123.73333"
  },
  {
    "country": "PH",
    "name": "Lanao",
    "lat": "11.25636",
    "lng": "124.02423"
  },
  {
    "country": "PH",
    "name": "Lamut",
    "lat": "16.64907",
    "lng": "121.22474"
  },
  {
    "country": "PH",
    "name": "Lampitak",
    "lat": "6.43222",
    "lng": "125.0525"
  },
  {
    "country": "PH",
    "name": "Lampari",
    "lat": "6.31264",
    "lng": "124.88028"
  },
  {
    "country": "PH",
    "name": "Lamitan City",
    "lat": "6.6502",
    "lng": "122.12952"
  },
  {
    "country": "PH",
    "name": "Lamitan",
    "lat": "6.08722",
    "lng": "125.70222"
  },
  {
    "country": "PH",
    "name": "Laminusa",
    "lat": "5.5549",
    "lng": "120.9136"
  },
  {
    "country": "PH",
    "name": "Lamian",
    "lat": "6.30917",
    "lng": "124.84639"
  },
  {
    "country": "PH",
    "name": "Lambunao",
    "lat": "11.05563",
    "lng": "122.4759"
  },
  {
    "country": "PH",
    "name": "Lambayong",
    "lat": "6.51944",
    "lng": "125.04444"
  },
  {
    "country": "PH",
    "name": "Lambakin",
    "lat": "15.37171",
    "lng": "120.8607"
  },
  {
    "country": "PH",
    "name": "Lambakin",
    "lat": "14.75",
    "lng": "120.86667"
  },
  {
    "country": "PH",
    "name": "Lamba",
    "lat": "6.35025",
    "lng": "124.81974"
  },
  {
    "country": "PH",
    "name": "Lamak",
    "lat": "10.39972",
    "lng": "124.73889"
  },
  {
    "country": "PH",
    "name": "Lallayug",
    "lat": "17.70684",
    "lng": "121.44175"
  },
  {
    "country": "PH",
    "name": "Lalig",
    "lat": "13.98255",
    "lng": "121.32647"
  },
  {
    "country": "PH",
    "name": "La Libertad",
    "lat": "10.0266",
    "lng": "123.2335"
  },
  {
    "country": "PH",
    "name": "La Libertad",
    "lat": "7.48028",
    "lng": "125.64722"
  },
  {
    "country": "PH",
    "name": "Lalauigan",
    "lat": "11.58917",
    "lng": "125.46972"
  },
  {
    "country": "PH",
    "name": "Lalagsan",
    "lat": "10.2824",
    "lng": "123.013"
  },
  {
    "country": "PH",
    "name": "Lalab",
    "lat": "11.5749",
    "lng": "122.4284"
  },
  {
    "country": "PH",
    "name": "Lala",
    "lat": "7.97306",
    "lng": "123.74722"
  },
  {
    "country": "PH",
    "name": "Rancheria Payau",
    "lat": "7.8541",
    "lng": "123.1598"
  },
  {
    "country": "PH",
    "name": "Lajong",
    "lat": "12.83333",
    "lng": "123.96667"
  },
  {
    "country": "PH",
    "name": "Laiya",
    "lat": "13.68031",
    "lng": "121.40081"
  },
  {
    "country": "PH",
    "name": "Lais",
    "lat": "6.33278",
    "lng": "125.64639"
  },
  {
    "country": "PH",
    "name": "La Hacienda",
    "lat": "9.8815",
    "lng": "124.3923"
  },
  {
    "country": "PH",
    "name": "Laguitas",
    "lat": "8.08917",
    "lng": "125.13056"
  },
  {
    "country": "PH",
    "name": "Laguit Centro",
    "lat": "15.9472",
    "lng": "120.1904"
  },
  {
    "country": "PH",
    "name": "Lagindingan",
    "lat": "8.57472",
    "lng": "124.44222"
  },
  {
    "country": "PH",
    "name": "Laguilayan",
    "lat": "6.67213",
    "lng": "124.52491"
  },
  {
    "country": "PH",
    "name": "La Granja",
    "lat": "10.4082",
    "lng": "122.9898"
  },
  {
    "country": "PH",
    "name": "Lagonoy",
    "lat": "13.7342",
    "lng": "123.5207"
  },
  {
    "country": "PH",
    "name": "Lagonglong",
    "lat": "8.80722",
    "lng": "124.79028"
  },
  {
    "country": "PH",
    "name": "Lagayan",
    "lat": "17.7208",
    "lng": "120.7067"
  },
  {
    "country": "PH",
    "name": "Lagawe",
    "lat": "16.79997",
    "lng": "121.11924"
  },
  {
    "country": "PH",
    "name": "Lagasit",
    "lat": "15.9934",
    "lng": "120.794"
  },
  {
    "country": "PH",
    "name": "Lagangilang",
    "lat": "17.6125",
    "lng": "120.7358"
  },
  {
    "country": "PH",
    "name": "La Fortuna",
    "lat": "8.27972",
    "lng": "125.00139"
  },
  {
    "country": "PH",
    "name": "La Curva",
    "lat": "12.40484",
    "lng": "121.04591"
  },
  {
    "country": "PH",
    "name": "Lacson",
    "lat": "7.21194",
    "lng": "125.44222"
  },
  {
    "country": "PH",
    "name": "Lacdayan",
    "lat": "13.6",
    "lng": "122.53333"
  },
  {
    "country": "PH",
    "name": "La Castellana",
    "lat": "10.3239",
    "lng": "123.0215"
  },
  {
    "country": "PH",
    "name": "Lacaron",
    "lat": "11.422",
    "lng": "122.7422"
  },
  {
    "country": "PH",
    "name": "Lacaron",
    "lat": "6.44889",
    "lng": "125.57917"
  },
  {
    "country": "PH",
    "name": "La Carlota",
    "lat": "10.4242",
    "lng": "122.9212"
  },
  {
    "country": "PH",
    "name": "Lacag",
    "lat": "13.1553",
    "lng": "123.6812"
  },
  {
    "country": "PH",
    "name": "Labu-o",
    "lat": "7.11417",
    "lng": "125.04528"
  },
  {
    "country": "PH",
    "name": "Labuñgan",
    "lat": "7.10306",
    "lng": "124.235"
  },
  {
    "country": "PH",
    "name": "Labuan",
    "lat": "7.09972",
    "lng": "121.90417"
  },
  {
    "country": "PH",
    "name": "Labrador",
    "lat": "16.02812",
    "lng": "120.14424"
  },
  {
    "country": "PH",
    "name": "Labog",
    "lat": "9.0558",
    "lng": "118.0495"
  },
  {
    "country": "PH",
    "name": "Labo",
    "lat": "14.1532",
    "lng": "122.8303"
  },
  {
    "country": "PH",
    "name": "Labnig",
    "lat": "13.3769",
    "lng": "123.6788"
  },
  {
    "country": "PH",
    "name": "Labney",
    "lat": "16.1028",
    "lng": "120.4655"
  },
  {
    "country": "PH",
    "name": "Labayug",
    "lat": "16.1528",
    "lng": "120.5661"
  },
  {
    "country": "PH",
    "name": "Labason",
    "lat": "8.06917",
    "lng": "122.52167"
  },
  {
    "country": "PH",
    "name": "Labasan",
    "lat": "12.77732",
    "lng": "121.46922"
  },
  {
    "country": "PH",
    "name": "Labangan",
    "lat": "7.8654",
    "lng": "123.5123"
  },
  {
    "country": "PH",
    "name": "Kumalisquis",
    "lat": "10.50726",
    "lng": "123.203"
  },
  {
    "country": "PH",
    "name": "Kumalarang",
    "lat": "7.7478",
    "lng": "123.1445"
  },
  {
    "country": "PH",
    "name": "Cumadcad",
    "lat": "12.98056",
    "lng": "123.78917"
  },
  {
    "country": "PH",
    "name": "Kulempang",
    "lat": "7.51944",
    "lng": "124.38972"
  },
  {
    "country": "PH",
    "name": "Culit",
    "lat": "8.94722",
    "lng": "125.35694"
  },
  {
    "country": "PH",
    "name": "Kulay-Kulay",
    "lat": "5.94528",
    "lng": "121.2325"
  },
  {
    "country": "PH",
    "name": "Kolumbug",
    "lat": "6.52389",
    "lng": "124.60833"
  },
  {
    "country": "PH",
    "name": "Kulaman",
    "lat": "6.46001",
    "lng": "124.08767"
  },
  {
    "country": "PH",
    "name": "Kudanding",
    "lat": "6.58803",
    "lng": "124.63274"
  },
  {
    "country": "PH",
    "name": "Kuanos",
    "lat": "10.28298",
    "lng": "123.78"
  },
  {
    "country": "PH",
    "name": "Koronadal",
    "lat": "6.50306",
    "lng": "124.84694"
  },
  {
    "country": "PH",
    "name": "Koronadal",
    "lat": "6.24501",
    "lng": "124.98743"
  },
  {
    "country": "PH",
    "name": "Comagascas",
    "lat": "9.13972",
    "lng": "125.55972"
  },
  {
    "country": "PH",
    "name": "Kolape",
    "lat": "5.07028",
    "lng": "119.89694"
  },
  {
    "country": "PH",
    "name": "Kolambugan",
    "lat": "8.1144",
    "lng": "123.8971"
  },
  {
    "country": "PH",
    "name": "Cogon",
    "lat": "10.0372",
    "lng": "123.4539"
  },
  {
    "country": "PH",
    "name": "Klinan",
    "lat": "6.18683",
    "lng": "125.13684"
  },
  {
    "country": "PH",
    "name": "Kiupo",
    "lat": "5.84167",
    "lng": "125.31917"
  },
  {
    "country": "PH",
    "name": "Kitobo",
    "lat": "7.57444",
    "lng": "125.105"
  },
  {
    "country": "PH",
    "name": "Kitcharao",
    "lat": "9.455",
    "lng": "125.57306"
  },
  {
    "country": "PH",
    "name": "Kitapak",
    "lat": "6.95333",
    "lng": "124.42556"
  },
  {
    "country": "PH",
    "name": "Kitaotao",
    "lat": "7.63972",
    "lng": "125.00889"
  },
  {
    "country": "PH",
    "name": "Kitango",
    "lat": "6.94833",
    "lng": "124.44111"
  },
  {
    "country": "PH",
    "name": "Kisolon",
    "lat": "8.33",
    "lng": "124.97694"
  },
  {
    "country": "PH",
    "name": "Kisante",
    "lat": "6.92306",
    "lng": "125.155"
  },
  {
    "country": "PH",
    "name": "Quipot",
    "lat": "13.77911",
    "lng": "121.39722"
  },
  {
    "country": "PH",
    "name": "Kipit",
    "lat": "8.04611",
    "lng": "122.53222"
  },
  {
    "country": "PH",
    "name": "Kipalbig",
    "lat": "6.41056",
    "lng": "124.9264"
  },
  {
    "country": "PH",
    "name": "Kinogitan",
    "lat": "8.98556",
    "lng": "124.79278"
  },
  {
    "country": "PH",
    "name": "Kinangan",
    "lat": "6.30139",
    "lng": "125.585"
  },
  {
    "country": "PH",
    "name": "Kinamayan",
    "lat": "7.49944",
    "lng": "125.67361"
  },
  {
    "country": "PH",
    "name": "Kinalansan",
    "lat": "13.7036",
    "lng": "123.5531"
  },
  {
    "country": "PH",
    "name": "Kinalaglagan",
    "lat": "14.00149",
    "lng": "121.09772"
  },
  {
    "country": "PH",
    "name": "Kinablangan",
    "lat": "7.6928",
    "lng": "126.54912"
  },
  {
    "country": "PH",
    "name": "Kinabhangan",
    "lat": "8.96917",
    "lng": "125.3575"
  },
  {
    "country": "PH",
    "name": "Kimaya",
    "lat": "8.56472",
    "lng": "124.83972"
  },
  {
    "country": "PH",
    "name": "Kimanuit",
    "lat": "7.76039",
    "lng": "124.72497"
  },
  {
    "country": "PH",
    "name": "Kiloloran",
    "lat": "14.63571",
    "lng": "121.60617"
  },
  {
    "country": "PH",
    "name": "Kilim",
    "lat": "10.7118",
    "lng": "124.7968"
  },
  {
    "country": "PH",
    "name": "Kidapawan",
    "lat": "7.00833",
    "lng": "125.08944"
  },
  {
    "country": "PH",
    "name": "Kibureau",
    "lat": "7.6975",
    "lng": "125.2325"
  },
  {
    "country": "PH",
    "name": "Kibungan",
    "lat": "16.695",
    "lng": "120.6553"
  },
  {
    "country": "PH",
    "name": "Kibonsod",
    "lat": "9.00694",
    "lng": "125.20944"
  },
  {
    "country": "PH",
    "name": "Kiblawan",
    "lat": "6.61417",
    "lng": "125.23667"
  },
  {
    "country": "PH",
    "name": "Kibawe",
    "lat": "7.56861",
    "lng": "124.98778"
  },
  {
    "country": "PH",
    "name": "Kibangay",
    "lat": "8.04972",
    "lng": "124.89306"
  },
  {
    "country": "PH",
    "name": "Kiangan",
    "lat": "16.77607",
    "lng": "121.08584"
  },
  {
    "country": "PH",
    "name": "Kiamba",
    "lat": "5.98944",
    "lng": "124.62417"
  },
  {
    "country": "PH",
    "name": "Kaytitinga",
    "lat": "14.10722",
    "lng": "120.82917"
  },
  {
    "country": "PH",
    "name": "Kayapa",
    "lat": "16.3592",
    "lng": "120.8867"
  },
  {
    "country": "PH",
    "name": "Kawit",
    "lat": "14.44426",
    "lng": "120.90164"
  },
  {
    "country": "PH",
    "name": "Kawit",
    "lat": "8.1875",
    "lng": "124.06667"
  },
  {
    "country": "PH",
    "name": "Kawayan",
    "lat": "11.67944",
    "lng": "124.35667"
  },
  {
    "country": "PH",
    "name": "Cawayan",
    "lat": "9.80391",
    "lng": "123.53236"
  },
  {
    "country": "PH",
    "name": "Kawayan",
    "lat": "7.53833",
    "lng": "122.8725"
  },
  {
    "country": "PH",
    "name": "Kauswagan",
    "lat": "8.78972",
    "lng": "124.77556"
  },
  {
    "country": "PH",
    "name": "Kauswagan",
    "lat": "8.51667",
    "lng": "125.75"
  },
  {
    "country": "PH",
    "name": "Kauswagan",
    "lat": "8.19167",
    "lng": "124.08472"
  },
  {
    "country": "PH",
    "name": "Kauran",
    "lat": "6.79454",
    "lng": "124.47034"
  },
  {
    "country": "PH",
    "name": "Katuli",
    "lat": "7.43333",
    "lng": "124.21667"
  },
  {
    "country": "PH",
    "name": "Katipunan",
    "lat": "8.514",
    "lng": "123.2829"
  },
  {
    "country": "PH",
    "name": "Katidtuan",
    "lat": "7.18861",
    "lng": "124.31528"
  },
  {
    "country": "PH",
    "name": "Katubao",
    "lat": "5.88917",
    "lng": "124.82944"
  },
  {
    "country": "PH",
    "name": "Katangawan",
    "lat": "6.17222",
    "lng": "125.22139"
  },
  {
    "country": "PH",
    "name": "Kasibu",
    "lat": "16.3167",
    "lng": "121.2965"
  },
  {
    "country": "PH",
    "name": "Casay",
    "lat": "9.8204",
    "lng": "123.5496"
  },
  {
    "country": "PH",
    "name": "Karungdong",
    "lat": "5.8844",
    "lng": "121.263"
  },
  {
    "country": "PH",
    "name": "Caromatan",
    "lat": "7.7959",
    "lng": "123.7145"
  },
  {
    "country": "PH",
    "name": "Kaputian",
    "lat": "6.96583",
    "lng": "125.72611"
  },
  {
    "country": "PH",
    "name": "Kapingkong",
    "lat": "6.67503",
    "lng": "124.62632"
  },
  {
    "country": "PH",
    "name": "Kapatan",
    "lat": "5.90056",
    "lng": "125.2375"
  },
  {
    "country": "PH",
    "name": "Kapatalan",
    "lat": "14.4741",
    "lng": "121.4903"
  },
  {
    "country": "PH",
    "name": "Kapatagan",
    "lat": "7.9003",
    "lng": "123.7692"
  },
  {
    "country": "PH",
    "name": "Kapangan",
    "lat": "16.5746",
    "lng": "120.5971"
  },
  {
    "country": "PH",
    "name": "Kaongkod",
    "lat": "11.25028",
    "lng": "123.75556"
  },
  {
    "country": "PH",
    "name": "Kansipati",
    "lat": "6.00111",
    "lng": "121.23444"
  },
  {
    "country": "PH",
    "name": "Kanluran",
    "lat": "14.41667",
    "lng": "120.85"
  },
  {
    "country": "PH",
    "name": "Kanlagay",
    "lat": "5.87568",
    "lng": "121.29146"
  },
  {
    "country": "PH",
    "name": "Kananya",
    "lat": "11.1867",
    "lng": "124.5601"
  },
  {
    "country": "PH",
    "name": "Kampokpok",
    "lat": "11.2962",
    "lng": "124.405"
  },
  {
    "country": "PH",
    "name": "Kambing",
    "lat": "5.94646",
    "lng": "121.30757"
  },
  {
    "country": "PH",
    "name": "Kamanga",
    "lat": "5.85778",
    "lng": "125.05611"
  },
  {
    "country": "PH",
    "name": "Kalugmanan",
    "lat": "8.27778",
    "lng": "124.85972"
  },
  {
    "country": "PH",
    "name": "Calumboyan",
    "lat": "10.79129",
    "lng": "124.02749"
  },
  {
    "country": "PH",
    "name": "Kaliling",
    "lat": "9.9804",
    "lng": "122.4814"
  },
  {
    "country": "PH",
    "name": "Kalilangan",
    "lat": "7.74514",
    "lng": "124.74777"
  },
  {
    "country": "PH",
    "name": "Kalibo (poblacion)",
    "lat": "11.70611",
    "lng": "122.36444"
  },
  {
    "country": "PH",
    "name": "Kalian",
    "lat": "6.12306",
    "lng": "125.70028"
  },
  {
    "country": "PH",
    "name": "Kalbugan",
    "lat": "6.95972",
    "lng": "124.65917"
  },
  {
    "country": "PH",
    "name": "Kalbay",
    "lat": "5.72333",
    "lng": "125.49861"
  },
  {
    "country": "PH",
    "name": "Kalayaan",
    "lat": "14.35",
    "lng": "121.56667"
  },
  {
    "country": "PH",
    "name": "Kalawit",
    "lat": "8.06667",
    "lng": "122.51667"
  },
  {
    "country": "PH",
    "name": "Kalaisan",
    "lat": "7.01028",
    "lng": "125.045"
  },
  {
    "country": "PH",
    "name": "Kalanganan",
    "lat": "8.08333",
    "lng": "124.24667"
  },
  {
    "country": "PH",
    "name": "Kalandagan",
    "lat": "6.67826",
    "lng": "124.72477"
  },
  {
    "country": "PH",
    "name": "Kalamansig",
    "lat": "6.55187",
    "lng": "124.05111"
  },
  {
    "country": "PH",
    "name": "Kalamangog",
    "lat": "6.72556",
    "lng": "124.06889"
  },
  {
    "country": "PH",
    "name": "Kagay",
    "lat": "6.0088",
    "lng": "120.9074"
  },
  {
    "country": "PH",
    "name": "Kadingilan",
    "lat": "7.60111",
    "lng": "124.90861"
  },
  {
    "country": "PH",
    "name": "Kabuynan",
    "lat": "11.08056",
    "lng": "125.02472"
  },
  {
    "country": "PH",
    "name": "Kabungahan",
    "lat": "10.51667",
    "lng": "123.98333"
  },
  {
    "country": "PH",
    "name": "Kabulusan",
    "lat": "14.3615",
    "lng": "121.4004"
  },
  {
    "country": "PH",
    "name": "Kabulohan",
    "lat": "8.04333",
    "lng": "125.27667"
  },
  {
    "country": "PH",
    "name": "Kabugao",
    "lat": "18.01698",
    "lng": "121.18173"
  },
  {
    "country": "PH",
    "name": "Kabasalan",
    "lat": "7.79722",
    "lng": "122.765"
  },
  {
    "country": "PH",
    "name": "Kabasalan",
    "lat": "7.06667",
    "lng": "124.65"
  },
  {
    "country": "PH",
    "name": "Kabankalan",
    "lat": "9.9839",
    "lng": "122.81423"
  },
  {
    "country": "PH",
    "name": "Kabalen",
    "lat": "6.31944",
    "lng": "125.01056"
  },
  {
    "country": "PH",
    "name": "Kabalantian",
    "lat": "8.37083",
    "lng": "124.3275"
  },
  {
    "country": "PH",
    "name": "Kabacan",
    "lat": "7.10667",
    "lng": "124.82917"
  },
  {
    "country": "PH",
    "name": "Casuguran",
    "lat": "14.7167",
    "lng": "122.37422"
  },
  {
    "country": "PH",
    "name": "Julita",
    "lat": "10.97472",
    "lng": "124.96167"
  },
  {
    "country": "PH",
    "name": "Jugno",
    "lat": "9.4683",
    "lng": "123.2038"
  },
  {
    "country": "PH",
    "name": "Tugas",
    "lat": "11.613",
    "lng": "122.3822"
  },
  {
    "country": "PH",
    "name": "Jubasan",
    "lat": "12.4844",
    "lng": "124.2872"
  },
  {
    "country": "PH",
    "name": "Juban",
    "lat": "12.84778",
    "lng": "123.98778"
  },
  {
    "country": "PH",
    "name": "Jovellar",
    "lat": "13.0695",
    "lng": "123.5999"
  },
  {
    "country": "PH",
    "name": "Jovellar",
    "lat": "7.0635",
    "lng": "126.45558"
  },
  {
    "country": "PH",
    "name": "Jose Pañganiban",
    "lat": "14.2906",
    "lng": "122.6917"
  },
  {
    "country": "PH",
    "name": "Josefina",
    "lat": "8.2",
    "lng": "123.53333"
  },
  {
    "country": "PH",
    "name": "Joroan",
    "lat": "13.4885",
    "lng": "123.6189"
  },
  {
    "country": "PH",
    "name": "Jordan",
    "lat": "10.65836",
    "lng": "122.5963"
  },
  {
    "country": "PH",
    "name": "Jones",
    "lat": "16.5571",
    "lng": "121.7029"
  },
  {
    "country": "PH",
    "name": "Jolo",
    "lat": "6.05222",
    "lng": "121.00222"
  },
  {
    "country": "PH",
    "name": "Hipadpad",
    "lat": "12.2855",
    "lng": "125.2361"
  },
  {
    "country": "PH",
    "name": "Jimenez",
    "lat": "8.3365",
    "lng": "123.8383"
  },
  {
    "country": "PH",
    "name": "Jimalalud",
    "lat": "9.9797",
    "lng": "123.1999"
  },
  {
    "country": "PH",
    "name": "Jibao-an",
    "lat": "10.78333",
    "lng": "122.5"
  },
  {
    "country": "PH",
    "name": "Jiabong",
    "lat": "11.7625",
    "lng": "124.95194"
  },
  {
    "country": "PH",
    "name": "Jetafe",
    "lat": "10.14722",
    "lng": "124.15389"
  },
  {
    "country": "PH",
    "name": "Jayubó",
    "lat": "11.05",
    "lng": "122.38333"
  },
  {
    "country": "PH",
    "name": "Bugho",
    "lat": "10.7921",
    "lng": "124.9364"
  },
  {
    "country": "PH",
    "name": "Javier",
    "lat": "8.48889",
    "lng": "126.085"
  },
  {
    "country": "PH",
    "name": "Javalera",
    "lat": "14.25813",
    "lng": "120.91558"
  },
  {
    "country": "PH",
    "name": "Jasaan",
    "lat": "8.65417",
    "lng": "124.75556"
  },
  {
    "country": "PH",
    "name": "Jaro",
    "lat": "11.18375",
    "lng": "124.78267"
  },
  {
    "country": "PH",
    "name": "Japitan",
    "lat": "10.76524",
    "lng": "123.5444"
  },
  {
    "country": "PH",
    "name": "Japitan",
    "lat": "10.1279",
    "lng": "123.5035"
  },
  {
    "country": "PH",
    "name": "Jantianon",
    "lat": "9.4442",
    "lng": "123.1657"
  },
  {
    "country": "PH",
    "name": "Janopol",
    "lat": "14.08586",
    "lng": "121.09489"
  },
  {
    "country": "PH",
    "name": "Janiuay",
    "lat": "10.9493",
    "lng": "122.5061"
  },
  {
    "country": "PH",
    "name": "Jandayan Norte",
    "lat": "10.16852",
    "lng": "124.18148"
  },
  {
    "country": "PH",
    "name": "Janagdong",
    "lat": "13.9034",
    "lng": "121.5134"
  },
  {
    "country": "PH",
    "name": "Jampang",
    "lat": "9.90761",
    "lng": "123.60015"
  },
  {
    "country": "PH",
    "name": "Hamoraon",
    "lat": "12.22564",
    "lng": "123.55151"
  },
  {
    "country": "PH",
    "name": "Jamindan",
    "lat": "11.40023",
    "lng": "122.49833"
  },
  {
    "country": "PH",
    "name": "Jamabalod",
    "lat": "10.8788",
    "lng": "122.6212"
  },
  {
    "country": "PH",
    "name": "Jalaud",
    "lat": "10.89333",
    "lng": "122.7475"
  },
  {
    "country": "PH",
    "name": "Jalaud",
    "lat": "10.8436",
    "lng": "122.6404"
  },
  {
    "country": "PH",
    "name": "Jalajala",
    "lat": "14.353",
    "lng": "121.3225"
  },
  {
    "country": "PH",
    "name": "Jagupit",
    "lat": "9.24222",
    "lng": "125.55806"
  },
  {
    "country": "PH",
    "name": "Jaguimitan",
    "lat": "11.14",
    "lng": "122.7236"
  },
  {
    "country": "PH",
    "name": "Jagna",
    "lat": "9.6531",
    "lng": "124.3697"
  },
  {
    "country": "PH",
    "name": "Jaena",
    "lat": "11.41667",
    "lng": "122.4"
  },
  {
    "country": "PH",
    "name": "Jaen",
    "lat": "15.3275",
    "lng": "120.9192"
  },
  {
    "country": "PH",
    "name": "Jaclupan",
    "lat": "10.30138",
    "lng": "123.8165"
  },
  {
    "country": "PH",
    "name": "Jabonga",
    "lat": "9.34306",
    "lng": "125.51556"
  },
  {
    "country": "PH",
    "name": "Ivisan",
    "lat": "11.52167",
    "lng": "122.69083"
  },
  {
    "country": "PH",
    "name": "Ivana",
    "lat": "20.37005",
    "lng": "121.91457"
  },
  {
    "country": "PH",
    "name": "Itogon",
    "lat": "16.36389",
    "lng": "120.67694"
  },
  {
    "country": "PH",
    "name": "Itbayat",
    "lat": "20.78733",
    "lng": "121.84177"
  },
  {
    "country": "PH",
    "name": "Isulan",
    "lat": "6.62944",
    "lng": "124.605"
  },
  {
    "country": "PH",
    "name": "Isugod",
    "lat": "9.34077",
    "lng": "118.1196"
  },
  {
    "country": "PH",
    "name": "Isla",
    "lat": "15.89507",
    "lng": "120.30137"
  },
  {
    "country": "PH",
    "name": "Isabela",
    "lat": "10.2048",
    "lng": "122.9888"
  },
  {
    "country": "PH",
    "name": "City of Isabela",
    "lat": "6.70407",
    "lng": "121.97117"
  },
  {
    "country": "PH",
    "name": "Isabel",
    "lat": "10.9267",
    "lng": "124.434"
  },
  {
    "country": "PH",
    "name": "Isabang",
    "lat": "13.95694",
    "lng": "121.57083"
  },
  {
    "country": "PH",
    "name": "Irosin",
    "lat": "12.70013",
    "lng": "124.03221"
  },
  {
    "country": "PH",
    "name": "Irirum",
    "lat": "12.61603",
    "lng": "120.93061"
  },
  {
    "country": "PH",
    "name": "Iriga City",
    "lat": "13.4324",
    "lng": "123.4115"
  },
  {
    "country": "PH",
    "name": "Iraya",
    "lat": "13.25",
    "lng": "123.51667"
  },
  {
    "country": "PH",
    "name": "Irasan",
    "lat": "8.526",
    "lng": "123.206"
  },
  {
    "country": "PH",
    "name": "Iraray",
    "lat": "8.99361",
    "lng": "118.05111"
  },
  {
    "country": "PH",
    "name": "Irahuan",
    "lat": "9.80798",
    "lng": "118.69191"
  },
  {
    "country": "PH",
    "name": "Iraga",
    "lat": "17.7015",
    "lng": "121.6546"
  },
  {
    "country": "PH",
    "name": "Ipilan",
    "lat": "8.84306",
    "lng": "117.90333"
  },
  {
    "country": "PH",
    "name": "Ipil",
    "lat": "13.5132",
    "lng": "121.9841"
  },
  {
    "country": "PH",
    "name": "Ipil",
    "lat": "10.97472",
    "lng": "124.63639"
  },
  {
    "country": "PH",
    "name": "Ipil",
    "lat": "9.7907",
    "lng": "125.4386"
  },
  {
    "country": "PH",
    "name": "Ipil",
    "lat": "7.78444",
    "lng": "122.58611"
  },
  {
    "country": "PH",
    "name": "Inobulan",
    "lat": "8.88639",
    "lng": "124.79472"
  },
  {
    "country": "PH",
    "name": "Intampilan",
    "lat": "11.4813",
    "lng": "122.7434"
  },
  {
    "country": "PH",
    "name": "Initao",
    "lat": "8.49972",
    "lng": "124.30389"
  },
  {
    "country": "PH",
    "name": "Inicbulan",
    "lat": "13.82043",
    "lng": "120.98345"
  },
  {
    "country": "PH",
    "name": "Infanta",
    "lat": "15.8264",
    "lng": "119.9077"
  },
  {
    "country": "PH",
    "name": "Infanta",
    "lat": "14.74495",
    "lng": "121.64953"
  },
  {
    "country": "PH",
    "name": "Ineangan",
    "lat": "16.3181",
    "lng": "121.093"
  },
  {
    "country": "PH",
    "name": "Indulang",
    "lat": "8.09028",
    "lng": "124.58444"
  },
  {
    "country": "PH",
    "name": "Indang",
    "lat": "14.19528",
    "lng": "120.87694"
  },
  {
    "country": "PH",
    "name": "Inayauan",
    "lat": "9.9005",
    "lng": "122.434"
  },
  {
    "country": "PH",
    "name": "Inayagan",
    "lat": "10.23478",
    "lng": "123.769"
  },
  {
    "country": "PH",
    "name": "Inawayan",
    "lat": "6.96083",
    "lng": "125.47333"
  },
  {
    "country": "PH",
    "name": "Inapatan",
    "lat": "13.3964",
    "lng": "123.3227"
  },
  {
    "country": "PH",
    "name": "Inangatan",
    "lat": "11.25",
    "lng": "124.4"
  },
  {
    "country": "PH",
    "name": "Inabanga",
    "lat": "10.0307",
    "lng": "124.0671"
  },
  {
    "country": "PH",
    "name": "Inabaan Sur",
    "lat": "16.263",
    "lng": "120.4781"
  },
  {
    "country": "PH",
    "name": "Imus",
    "lat": "14.42972",
    "lng": "120.93667"
  },
  {
    "country": "PH",
    "name": "Impalutao",
    "lat": "8.25778",
    "lng": "125.0275"
  },
  {
    "country": "PH",
    "name": "Imelda",
    "lat": "14.03333",
    "lng": "122.88333"
  },
  {
    "country": "PH",
    "name": "Imelda",
    "lat": "7.64703",
    "lng": "122.95349"
  },
  {
    "country": "PH",
    "name": "Imbatug",
    "lat": "8.05444",
    "lng": "125.28389"
  },
  {
    "country": "PH",
    "name": "Imbang",
    "lat": "10.7967",
    "lng": "123.0213"
  },
  {
    "country": "PH",
    "name": "Iloilo",
    "lat": "10.69694",
    "lng": "122.56444"
  },
  {
    "country": "PH",
    "name": "Ilog",
    "lat": "10.0266",
    "lng": "122.7684"
  },
  {
    "country": "PH",
    "name": "Ilioilio",
    "lat": "15.9616",
    "lng": "119.7658"
  },
  {
    "country": "PH",
    "name": "Ilihan",
    "lat": "13.631",
    "lng": "121.0709"
  },
  {
    "country": "PH",
    "name": "Ilihan",
    "lat": "10.9054",
    "lng": "123.9704"
  },
  {
    "country": "PH",
    "name": "Iligan City",
    "lat": "8.25",
    "lng": "124.4"
  },
  {
    "country": "PH",
    "name": "Iligan",
    "lat": "8.2289",
    "lng": "124.24344"
  },
  {
    "country": "PH",
    "name": "Ilaya",
    "lat": "8.5459",
    "lng": "123.4308"
  },
  {
    "country": "PH",
    "name": "Ilangay",
    "lat": "6.91284",
    "lng": "126.05008"
  },
  {
    "country": "PH",
    "name": "Ilagan",
    "lat": "17.14854",
    "lng": "121.88924"
  },
  {
    "country": "PH",
    "name": "Iguig",
    "lat": "17.7506",
    "lng": "121.73645"
  },
  {
    "country": "PH",
    "name": "Igpit",
    "lat": "8.51083",
    "lng": "124.58667"
  },
  {
    "country": "PH",
    "name": "Ignit",
    "lat": "6.70083",
    "lng": "125.29194"
  },
  {
    "country": "PH",
    "name": "Igmaya-an",
    "lat": "10.54986",
    "lng": "123.2206"
  },
  {
    "country": "PH",
    "name": "Igcocolo",
    "lat": "10.68966",
    "lng": "122.3193"
  },
  {
    "country": "PH",
    "name": "Igbon",
    "lat": "11.2142",
    "lng": "123.1655"
  },
  {
    "country": "PH",
    "name": "Igbaras",
    "lat": "10.71565",
    "lng": "122.2657"
  },
  {
    "country": "PH",
    "name": "Igang",
    "lat": "10.916",
    "lng": "122.6388"
  },
  {
    "country": "PH",
    "name": "Idtig",
    "lat": "6.79889",
    "lng": "124.77278"
  },
  {
    "country": "PH",
    "name": "Idio",
    "lat": "11.6238",
    "lng": "122.0979"
  },
  {
    "country": "PH",
    "name": "Ichon",
    "lat": "10.09495",
    "lng": "124.90168"
  },
  {
    "country": "PH",
    "name": "Ibarra",
    "lat": "10.12472",
    "lng": "124.88417"
  },
  {
    "country": "PH",
    "name": "Ibajay",
    "lat": "11.8199",
    "lng": "122.162"
  },
  {
    "country": "PH",
    "name": "Yuni",
    "lat": "13.4124",
    "lng": "122.4846"
  },
  {
    "country": "PH",
    "name": "Ibabang Tayuman",
    "lat": "13.4042",
    "lng": "122.5165"
  },
  {
    "country": "PH",
    "name": "Ibaan",
    "lat": "13.8176",
    "lng": "121.133"
  },
  {
    "country": "PH",
    "name": "Iba",
    "lat": "15.45392",
    "lng": "120.41048"
  },
  {
    "country": "PH",
    "name": "Iba",
    "lat": "15.3276",
    "lng": "119.978"
  },
  {
    "country": "PH",
    "name": "Hukay",
    "lat": "13.84519",
    "lng": "120.70287"
  },
  {
    "country": "PH",
    "name": "Hondagua",
    "lat": "13.9455",
    "lng": "122.2417"
  },
  {
    "country": "PH",
    "name": "Hobo",
    "lat": "13.5101",
    "lng": "123.1792"
  },
  {
    "country": "PH",
    "name": "Hipasngo",
    "lat": "10.6624",
    "lng": "124.8085"
  },
  {
    "country": "PH",
    "name": "Hipona",
    "lat": "11.4174",
    "lng": "122.8825"
  },
  {
    "country": "PH",
    "name": "Hinundayan",
    "lat": "10.3523",
    "lng": "125.2506"
  },
  {
    "country": "PH",
    "name": "Hinunangan",
    "lat": "10.39408",
    "lng": "125.19768"
  },
  {
    "country": "PH",
    "name": "Hinlayagan Ilaud",
    "lat": "10.03061",
    "lng": "124.33457"
  },
  {
    "country": "PH",
    "name": "Hinigaran",
    "lat": "10.2706",
    "lng": "122.8507"
  },
  {
    "country": "PH",
    "name": "Hingatungan",
    "lat": "10.584",
    "lng": "125.1852"
  },
  {
    "country": "PH",
    "name": "Hindang",
    "lat": "10.43417",
    "lng": "124.72917"
  },
  {
    "country": "PH",
    "name": "Hinatuan",
    "lat": "8.37222",
    "lng": "126.33417"
  },
  {
    "country": "PH",
    "name": "Hinapalanan",
    "lat": "8.64028",
    "lng": "124.87306"
  },
  {
    "country": "PH",
    "name": "Himensulan",
    "lat": "10.5967",
    "lng": "124.2821"
  },
  {
    "country": "PH",
    "name": "Himaya",
    "lat": "10.4516",
    "lng": "122.8325"
  },
  {
    "country": "PH",
    "name": "Gimampang",
    "lat": "8.47139",
    "lng": "124.29667"
  },
  {
    "country": "PH",
    "name": "Himamaylan",
    "lat": "10.09889",
    "lng": "122.87056"
  },
  {
    "country": "PH",
    "name": "Himaao",
    "lat": "13.5448",
    "lng": "123.3005"
  },
  {
    "country": "PH",
    "name": "Hilotongan",
    "lat": "11.144",
    "lng": "123.6426"
  },
  {
    "country": "PH",
    "name": "Hilongos",
    "lat": "10.37444",
    "lng": "124.74972"
  },
  {
    "country": "PH",
    "name": "Hiju, Maco",
    "lat": "7.38541",
    "lng": "125.82822"
  },
  {
    "country": "PH",
    "name": "Hibaiyo",
    "lat": "10.2726",
    "lng": "123.321"
  },
  {
    "country": "PH",
    "name": "Herrera",
    "lat": "13.2693",
    "lng": "123.5769"
  },
  {
    "country": "PH",
    "name": "Hernani",
    "lat": "11.32583",
    "lng": "125.61944"
  },
  {
    "country": "PH",
    "name": "Hermosa",
    "lat": "14.8314",
    "lng": "120.5081"
  },
  {
    "country": "PH",
    "name": "Harrison",
    "lat": "13.45",
    "lng": "120.43333"
  },
  {
    "country": "PH",
    "name": "Jarigue",
    "lat": "11.86538",
    "lng": "121.44041"
  },
  {
    "country": "PH",
    "name": "Hapao",
    "lat": "16.87966",
    "lng": "121.01604"
  },
  {
    "country": "PH",
    "name": "Hamtic",
    "lat": "10.7023",
    "lng": "121.9824"
  },
  {
    "country": "PH",
    "name": "Halog West",
    "lat": "16.3668",
    "lng": "120.4147"
  },
  {
    "country": "PH",
    "name": "Haligue",
    "lat": "13.66667",
    "lng": "121.11667"
  },
  {
    "country": "PH",
    "name": "Halayhayin",
    "lat": "14.1891",
    "lng": "121.4075"
  },
  {
    "country": "PH",
    "name": "Halayhay",
    "lat": "14.37389",
    "lng": "120.81333"
  },
  {
    "country": "PH",
    "name": "Halapitan",
    "lat": "7.9175",
    "lng": "125.33"
  },
  {
    "country": "PH",
    "name": "Haguimit",
    "lat": "10.3999",
    "lng": "123.0178"
  },
  {
    "country": "PH",
    "name": "Hagonoy",
    "lat": "14.83413",
    "lng": "120.73271"
  },
  {
    "country": "PH",
    "name": "Hagonoy",
    "lat": "6.68333",
    "lng": "125.32556"
  },
  {
    "country": "PH",
    "name": "Hagnaya",
    "lat": "11.0924",
    "lng": "123.9435"
  },
  {
    "country": "PH",
    "name": "Hagdan",
    "lat": "11.33333",
    "lng": "123.9"
  },
  {
    "country": "PH",
    "name": "Dolores",
    "lat": "15.09498",
    "lng": "120.52889"
  },
  {
    "country": "PH",
    "name": "Hacienda",
    "lat": "15.936",
    "lng": "120.1786"
  },
  {
    "country": "PH",
    "name": "Guyong",
    "lat": "14.8361",
    "lng": "120.97844"
  },
  {
    "country": "PH",
    "name": "Guyam Malaki",
    "lat": "14.1525",
    "lng": "120.86111"
  },
  {
    "country": "PH",
    "name": "Gutalac",
    "lat": "7.9825",
    "lng": "122.40472"
  },
  {
    "country": "PH",
    "name": "Gutad",
    "lat": "14.9274",
    "lng": "120.4894"
  },
  {
    "country": "PH",
    "name": "Guruyan",
    "lat": "12.73889",
    "lng": "123.93917"
  },
  {
    "country": "PH",
    "name": "Gupitan",
    "lat": "7.77583",
    "lng": "125.64056"
  },
  {
    "country": "PH",
    "name": "Gumian",
    "lat": "14.71006",
    "lng": "121.61867"
  },
  {
    "country": "PH",
    "name": "Gumaus",
    "lat": "14.3103",
    "lng": "122.7229"
  },
  {
    "country": "PH",
    "name": "Gumalang",
    "lat": "7.20833",
    "lng": "125.40361"
  },
  {
    "country": "PH",
    "name": "Gumaca",
    "lat": "13.921",
    "lng": "122.1002"
  },
  {
    "country": "PH",
    "name": "Gulod",
    "lat": "13.87514",
    "lng": "120.63359"
  },
  {
    "country": "PH",
    "name": "Guiwanon",
    "lat": "11.1975",
    "lng": "123.708"
  },
  {
    "country": "PH",
    "name": "Guiuan",
    "lat": "11.03088",
    "lng": "125.72342"
  },
  {
    "country": "PH",
    "name": "Guisijan",
    "lat": "11.0932",
    "lng": "122.0461"
  },
  {
    "country": "PH",
    "name": "Guisguis",
    "lat": "15.7928",
    "lng": "119.9766"
  },
  {
    "country": "PH",
    "name": "Guisguis",
    "lat": "13.8738",
    "lng": "121.5189"
  },
  {
    "country": "PH",
    "name": "Guiset East",
    "lat": "16.06667",
    "lng": "120.68333"
  },
  {
    "country": "PH",
    "name": "Guirang",
    "lat": "11.35",
    "lng": "125.11667"
  },
  {
    "country": "PH",
    "name": "Guipos",
    "lat": "7.7161",
    "lng": "123.3219"
  },
  {
    "country": "PH",
    "name": "Guiong",
    "lat": "6.41861",
    "lng": "122.02583"
  },
  {
    "country": "PH",
    "name": "Giawang",
    "lat": "9.7922",
    "lng": "124.509"
  },
  {
    "country": "PH",
    "name": "Guintubhan",
    "lat": "10.2074",
    "lng": "122.9627"
  },
  {
    "country": "PH",
    "name": "Guinticgan",
    "lat": "11.5641",
    "lng": "123.1236"
  },
  {
    "country": "PH",
    "name": "Guinisiliban",
    "lat": "9.09639",
    "lng": "124.78278"
  },
  {
    "country": "PH",
    "name": "Guinsang-an",
    "lat": "6.46499",
    "lng": "124.68491"
  },
  {
    "country": "PH",
    "name": "Guinsadan",
    "lat": "16.9642",
    "lng": "120.868"
  },
  {
    "country": "PH",
    "name": "Guinobatan",
    "lat": "13.1913",
    "lng": "123.5987"
  },
  {
    "country": "PH",
    "name": "Guinlo",
    "lat": "10.8009",
    "lng": "119.4383"
  },
  {
    "country": "PH",
    "name": "Guindulman",
    "lat": "9.7629",
    "lng": "124.4878"
  },
  {
    "country": "PH",
    "name": "Guindarohan",
    "lat": "10.26111",
    "lng": "123.76556"
  },
  {
    "country": "PH",
    "name": "Guindapunan",
    "lat": "11.30278",
    "lng": "124.70583"
  },
  {
    "country": "PH",
    "name": "Guinoaliuan",
    "lat": "11.6576",
    "lng": "122.3851"
  },
  {
    "country": "PH",
    "name": "Guinayangan, Fourth District of Quezon",
    "lat": "13.9002",
    "lng": "122.44808"
  },
  {
    "country": "PH",
    "name": "Guinabsan",
    "lat": "8.8975",
    "lng": "125.41611"
  },
  {
    "country": "PH",
    "name": "Guinacotan",
    "lat": "14.1569",
    "lng": "122.868"
  },
  {
    "country": "PH",
    "name": "Guimbal",
    "lat": "10.6633",
    "lng": "122.3228"
  },
  {
    "country": "PH",
    "name": "Guimba",
    "lat": "15.6605",
    "lng": "120.7683"
  },
  {
    "country": "PH",
    "name": "Guiljungan",
    "lat": "9.9805",
    "lng": "122.6742"
  },
  {
    "country": "PH",
    "name": "Guiling",
    "lat": "15.84295",
    "lng": "120.61513"
  },
  {
    "country": "PH",
    "name": "Guijalo",
    "lat": "13.7373",
    "lng": "123.868"
  },
  {
    "country": "PH",
    "name": "Guihulñgan",
    "lat": "10.1214",
    "lng": "123.2742"
  },
  {
    "country": "PH",
    "name": "Guihing Proper",
    "lat": "6.68444",
    "lng": "125.3525"
  },
  {
    "country": "PH",
    "name": "Guiguinto",
    "lat": "14.83333",
    "lng": "120.88333"
  },
  {
    "country": "PH",
    "name": "Guiddam",
    "lat": "18.33493",
    "lng": "121.46617"
  },
  {
    "country": "PH",
    "name": "Guibodangan",
    "lat": "10.1157",
    "lng": "123.4944"
  },
  {
    "country": "PH",
    "name": "Gueset",
    "lat": "15.95",
    "lng": "120.63333"
  },
  {
    "country": "PH",
    "name": "Gubat",
    "lat": "12.92056",
    "lng": "124.12306"
  },
  {
    "country": "PH",
    "name": "Guba",
    "lat": "10.3131",
    "lng": "123.2667"
  },
  {
    "country": "PH",
    "name": "Guagua",
    "lat": "14.9653",
    "lng": "120.6325"
  },
  {
    "country": "PH",
    "name": "Guadalupe",
    "lat": "11.00444",
    "lng": "124.01389"
  },
  {
    "country": "PH",
    "name": "Guadalupe",
    "lat": "10.45447",
    "lng": "123.3732"
  },
  {
    "country": "PH",
    "name": "Guadalupe",
    "lat": "10.1165",
    "lng": "123.6072"
  },
  {
    "country": "PH",
    "name": "Guadalupe",
    "lat": "9.7236",
    "lng": "123.4018"
  },
  {
    "country": "PH",
    "name": "Guadalupe",
    "lat": "8.58278",
    "lng": "125.70806"
  },
  {
    "country": "PH",
    "name": "Gregorio del Pilar",
    "lat": "17.13028",
    "lng": "120.61194"
  },
  {
    "country": "PH",
    "name": "Granada",
    "lat": "11.63333",
    "lng": "123.35"
  },
  {
    "country": "PH",
    "name": "Sigaboy",
    "lat": "6.65413",
    "lng": "126.07268"
  },
  {
    "country": "PH",
    "name": "Gonzaga",
    "lat": "18.25937",
    "lng": "121.99495"
  },
  {
    "country": "PH",
    "name": "Goma",
    "lat": "6.79194",
    "lng": "125.32083"
  },
  {
    "country": "PH",
    "name": "Gocoton",
    "lat": "7.15611",
    "lng": "124.69111"
  },
  {
    "country": "PH",
    "name": "Goa",
    "lat": "13.6978",
    "lng": "123.4892"
  },
  {
    "country": "PH",
    "name": "Gloria",
    "lat": "12.98333",
    "lng": "121.46667"
  },
  {
    "country": "PH",
    "name": "Glan Peidu",
    "lat": "5.855",
    "lng": "125.21861"
  },
  {
    "country": "PH",
    "name": "Glan",
    "lat": "5.82417",
    "lng": "125.20333"
  },
  {
    "country": "PH",
    "name": "Glamang",
    "lat": "6.16255",
    "lng": "125.08392"
  },
  {
    "country": "PH",
    "name": "Glad",
    "lat": "7.14833",
    "lng": "124.51806"
  },
  {
    "country": "PH",
    "name": "Gitagum",
    "lat": "8.59667",
    "lng": "124.40639"
  },
  {
    "country": "PH",
    "name": "Giporlos",
    "lat": "11.12",
    "lng": "125.44944"
  },
  {
    "country": "PH",
    "name": "Gines-Patay",
    "lat": "10.9357",
    "lng": "122.4932"
  },
  {
    "country": "PH",
    "name": "Ginatilan",
    "lat": "9.5694",
    "lng": "123.3128"
  },
  {
    "country": "PH",
    "name": "Ginabuyan",
    "lat": "11.2383",
    "lng": "124.4047"
  },
  {
    "country": "PH",
    "name": "Hilantagaan",
    "lat": "11.1943",
    "lng": "123.8131"
  },
  {
    "country": "PH",
    "name": "Gigmoto",
    "lat": "13.7796",
    "lng": "124.39"
  },
  {
    "country": "PH",
    "name": "Gigaquit",
    "lat": "9.59444",
    "lng": "125.6975"
  },
  {
    "country": "PH",
    "name": "Gibong",
    "lat": "11.86338",
    "lng": "122.03941"
  },
  {
    "country": "PH",
    "name": "Gibgos",
    "lat": "13.859",
    "lng": "123.7675"
  },
  {
    "country": "PH",
    "name": "Gibato",
    "lat": "11.2251",
    "lng": "122.8143"
  },
  {
    "country": "PH",
    "name": "Getulio",
    "lat": "10.747",
    "lng": "122.666"
  },
  {
    "country": "PH",
    "name": "Gerona",
    "lat": "15.6065",
    "lng": "120.5978"
  },
  {
    "country": "PH",
    "name": "General Trias",
    "lat": "14.38694",
    "lng": "120.88167"
  },
  {
    "country": "PH",
    "name": "General Tinio",
    "lat": "15.35075",
    "lng": "121.04773"
  },
  {
    "country": "PH",
    "name": "General Santos",
    "lat": "6.11278",
    "lng": "125.17167"
  },
  {
    "country": "PH",
    "name": "General Nakar",
    "lat": "14.76365",
    "lng": "121.63559"
  },
  {
    "country": "PH",
    "name": "General Mamerto Natividad",
    "lat": "15.6025",
    "lng": "121.0515"
  },
  {
    "country": "PH",
    "name": "General MacArthur",
    "lat": "11.24639",
    "lng": "125.53944"
  },
  {
    "country": "PH",
    "name": "General Luna",
    "lat": "15.7306",
    "lng": "121.1791"
  },
  {
    "country": "PH",
    "name": "General Luna",
    "lat": "13.6866",
    "lng": "122.1709"
  },
  {
    "country": "PH",
    "name": "General Luna",
    "lat": "9.78417",
    "lng": "126.15889"
  },
  {
    "country": "PH",
    "name": "General Emilio Aguinaldo",
    "lat": "14.18417",
    "lng": "120.79583"
  },
  {
    "country": "PH",
    "name": "Gayaman",
    "lat": "16.01402",
    "lng": "120.30757"
  },
  {
    "country": "PH",
    "name": "Gattaran",
    "lat": "18.06157",
    "lng": "121.6441"
  },
  {
    "country": "PH",
    "name": "Gatbo",
    "lat": "13.58333",
    "lng": "123.38333"
  },
  {
    "country": "PH",
    "name": "Gasan",
    "lat": "13.32372",
    "lng": "121.84675"
  },
  {
    "country": "PH",
    "name": "Garcia Hernandez",
    "lat": "9.6144",
    "lng": "124.2946"
  },
  {
    "country": "PH",
    "name": "Garchitorena",
    "lat": "13.8804",
    "lng": "123.6946"
  },
  {
    "country": "PH",
    "name": "Gappal",
    "lat": "16.83646",
    "lng": "121.82184"
  },
  {
    "country": "PH",
    "name": "Gapan",
    "lat": "15.3072",
    "lng": "120.9464"
  },
  {
    "country": "PH",
    "name": "Ganyangan",
    "lat": "7.67889",
    "lng": "122.90944"
  },
  {
    "country": "PH",
    "name": "Gansing",
    "lat": "6.71851",
    "lng": "124.65338"
  },
  {
    "country": "PH",
    "name": "Gang",
    "lat": "7.24583",
    "lng": "124.26639"
  },
  {
    "country": "PH",
    "name": "Gandara",
    "lat": "12.013",
    "lng": "124.8118"
  },
  {
    "country": "PH",
    "name": "Ganassi",
    "lat": "7.82694",
    "lng": "124.10344"
  },
  {
    "country": "PH",
    "name": "Gamut",
    "lat": "9.00444",
    "lng": "126.16972"
  },
  {
    "country": "PH",
    "name": "Gamut",
    "lat": "8.53153",
    "lng": "126.24117"
  },
  {
    "country": "PH",
    "name": "Gamu",
    "lat": "17.04975",
    "lng": "121.83604"
  },
  {
    "country": "PH",
    "name": "Gammad",
    "lat": "17.7104",
    "lng": "121.7437"
  },
  {
    "country": "PH",
    "name": "Gambang",
    "lat": "16.75",
    "lng": "120.7833"
  },
  {
    "country": "PH",
    "name": "Gamay",
    "lat": "12.38542",
    "lng": "125.29791"
  },
  {
    "country": "PH",
    "name": "Galimuyod",
    "lat": "17.18444",
    "lng": "120.47194"
  },
  {
    "country": "PH",
    "name": "Gainza",
    "lat": "13.6165",
    "lng": "123.1419"
  },
  {
    "country": "PH",
    "name": "Gadung",
    "lat": "6.8025",
    "lng": "124.02"
  },
  {
    "country": "PH",
    "name": "Gadu",
    "lat": "17.6292",
    "lng": "121.6105"
  },
  {
    "country": "PH",
    "name": "Gabuyan",
    "lat": "7.60806",
    "lng": "125.66889"
  },
  {
    "country": "PH",
    "name": "Gabi",
    "lat": "10.26306",
    "lng": "123.96139"
  },
  {
    "country": "PH",
    "name": "Gabi",
    "lat": "11.5956",
    "lng": "123.3376"
  },
  {
    "country": "PH",
    "name": "Gabi",
    "lat": "7.6215",
    "lng": "126.092"
  },
  {
    "country": "PH",
    "name": "Gabawan",
    "lat": "12.42714",
    "lng": "122.01332"
  },
  {
    "country": "PH",
    "name": "Gabas",
    "lat": "10.7297",
    "lng": "124.7961"
  },
  {
    "country": "PH",
    "name": "Gabao",
    "lat": "12.9924",
    "lng": "124.0169"
  },
  {
    "country": "PH",
    "name": "Gabao",
    "lat": "12.72709",
    "lng": "123.97835"
  },
  {
    "country": "PH",
    "name": "Gabaldon",
    "lat": "15.4522",
    "lng": "121.3387"
  },
  {
    "country": "PH",
    "name": "Furao",
    "lat": "17.03466",
    "lng": "121.79689"
  },
  {
    "country": "PH",
    "name": "Fuerte",
    "lat": "17.53418",
    "lng": "120.3695"
  },
  {
    "country": "PH",
    "name": "Floridablanca",
    "lat": "14.9775",
    "lng": "120.5285"
  },
  {
    "country": "PH",
    "name": "Flora",
    "lat": "18.2163",
    "lng": "121.4185"
  },
  {
    "country": "PH",
    "name": "Ferrol",
    "lat": "12.33833",
    "lng": "121.94139"
  },
  {
    "country": "PH",
    "name": "Feliciano",
    "lat": "11.5787",
    "lng": "122.3583"
  },
  {
    "country": "PH",
    "name": "Famy",
    "lat": "14.4376",
    "lng": "121.4482"
  },
  {
    "country": "PH",
    "name": "Fabrica",
    "lat": "13.49",
    "lng": "123.294"
  },
  {
    "country": "PH",
    "name": "Evangelista",
    "lat": "13.3335",
    "lng": "121.0972"
  },
  {
    "country": "PH",
    "name": "Eustaquio Lopez",
    "lat": "10.8195",
    "lng": "123.0412"
  },
  {
    "country": "PH",
    "name": "Estrella",
    "lat": "15.75",
    "lng": "121.03333"
  },
  {
    "country": "PH",
    "name": "Estrella",
    "lat": "13.32898",
    "lng": "121.31092"
  },
  {
    "country": "PH",
    "name": "Estipona",
    "lat": "15.5902",
    "lng": "120.6377"
  },
  {
    "country": "PH",
    "name": "Estefania",
    "lat": "17.79952",
    "lng": "121.7231"
  },
  {
    "country": "PH",
    "name": "Estancia",
    "lat": "13.3589",
    "lng": "123.6796"
  },
  {
    "country": "PH",
    "name": "Estancia",
    "lat": "11.4551",
    "lng": "123.152"
  },
  {
    "country": "PH",
    "name": "Estacion",
    "lat": "15.69944",
    "lng": "120.60833"
  },
  {
    "country": "PH",
    "name": "Estaca",
    "lat": "9.6933",
    "lng": "124.2722"
  },
  {
    "country": "PH",
    "name": "Espiritu",
    "lat": "17.9809",
    "lng": "120.6569"
  },
  {
    "country": "PH",
    "name": "Esperanza East",
    "lat": "17.02327",
    "lng": "121.68402"
  },
  {
    "country": "PH",
    "name": "Esperanza",
    "lat": "11.7365",
    "lng": "124.042"
  },
  {
    "country": "PH",
    "name": "Esperanza",
    "lat": "10.7027",
    "lng": "124.4143"
  },
  {
    "country": "PH",
    "name": "Esperanza",
    "lat": "10.6995",
    "lng": "124.3143"
  },
  {
    "country": "PH",
    "name": "Esperanza",
    "lat": "8.67694",
    "lng": "125.64694"
  },
  {
    "country": "PH",
    "name": "Esperanza",
    "lat": "8.18083",
    "lng": "124.00722"
  },
  {
    "country": "PH",
    "name": "Esperanza",
    "lat": "7.49167",
    "lng": "125.72806"
  },
  {
    "country": "PH",
    "name": "Esperanza",
    "lat": "6.72306",
    "lng": "124.51972"
  },
  {
    "country": "PH",
    "name": "España",
    "lat": "12.38414",
    "lng": "122.49901"
  },
  {
    "country": "PH",
    "name": "Esmeralda",
    "lat": "15.86722",
    "lng": "120.715"
  },
  {
    "country": "PH",
    "name": "Escalante",
    "lat": "10.84028",
    "lng": "123.49917"
  },
  {
    "country": "PH",
    "name": "Ermita",
    "lat": "10.9",
    "lng": "122.71667"
  },
  {
    "country": "PH",
    "name": "Erenas",
    "lat": "12.4245",
    "lng": "124.3238"
  },
  {
    "country": "PH",
    "name": "Eraan",
    "lat": "9.06289",
    "lng": "117.7016"
  },
  {
    "country": "PH",
    "name": "Entablado",
    "lat": "15.28661",
    "lng": "120.86302"
  },
  {
    "country": "PH",
    "name": "Enrique Villanueva",
    "lat": "9.2761",
    "lng": "123.6468"
  },
  {
    "country": "PH",
    "name": "Saravia",
    "lat": "10.87754",
    "lng": "122.9677"
  },
  {
    "country": "PH",
    "name": "Enrile",
    "lat": "17.5596",
    "lng": "121.6974"
  },
  {
    "country": "PH",
    "name": "El Salvador",
    "lat": "8.56306",
    "lng": "124.5225"
  },
  {
    "country": "PH",
    "name": "El Pardo",
    "lat": "9.66",
    "lng": "123.4944"
  },
  {
    "country": "PH",
    "name": "El Nido",
    "lat": "11.18583",
    "lng": "119.39556"
  },
  {
    "country": "PH",
    "name": "Eguia",
    "lat": "15.9065",
    "lng": "119.8858"
  },
  {
    "country": "PH",
    "name": "Egaña",
    "lat": "10.7472",
    "lng": "122.00984"
  },
  {
    "country": "PH",
    "name": "Eden",
    "lat": "17.03809",
    "lng": "121.59799"
  },
  {
    "country": "PH",
    "name": "Ebcor Town",
    "lat": "7.44056",
    "lng": "124.39722"
  },
  {
    "country": "PH",
    "name": "Echague",
    "lat": "16.70509",
    "lng": "121.67633"
  },
  {
    "country": "PH",
    "name": "Duran",
    "lat": "11.2618",
    "lng": "122.5917"
  },
  {
    "country": "PH",
    "name": "Dunguan",
    "lat": "6.94972",
    "lng": "124.86083"
  },
  {
    "country": "PH",
    "name": "Dumpay",
    "lat": "15.88295",
    "lng": "120.38899"
  },
  {
    "country": "PH",
    "name": "Dumlan",
    "lat": "7.4275",
    "lng": "125.8819"
  },
  {
    "country": "PH",
    "name": "Dumingag",
    "lat": "8.16917",
    "lng": "123.35056"
  },
  {
    "country": "PH",
    "name": "Dumarao",
    "lat": "11.2654",
    "lng": "122.6889"
  },
  {
    "country": "PH",
    "name": "Dumaran",
    "lat": "10.525",
    "lng": "119.7671"
  },
  {
    "country": "PH",
    "name": "Dumarais",
    "lat": "15.43455",
    "lng": "120.69213"
  },
  {
    "country": "PH",
    "name": "Dumanjog",
    "lat": "10.057",
    "lng": "123.4361"
  },
  {
    "country": "PH",
    "name": "Dumangas",
    "lat": "10.825",
    "lng": "122.713"
  },
  {
    "country": "PH",
    "name": "Dumalneg",
    "lat": "18.5254",
    "lng": "120.8094"
  },
  {
    "country": "PH",
    "name": "Dumalinao",
    "lat": "7.8191",
    "lng": "123.3694"
  },
  {
    "country": "PH",
    "name": "Dumalaguing",
    "lat": "8.34694",
    "lng": "125.055"
  },
  {
    "country": "PH",
    "name": "Dumalag",
    "lat": "11.308",
    "lng": "122.6236"
  },
  {
    "country": "PH",
    "name": "Dumaguil",
    "lat": "6.62",
    "lng": "124.65333"
  },
  {
    "country": "PH",
    "name": "Dumaguete",
    "lat": "9.30722",
    "lng": "123.30261"
  },
  {
    "country": "PH",
    "name": "Dumabato",
    "lat": "16.31667",
    "lng": "121.7"
  },
  {
    "country": "PH",
    "name": "Doljo",
    "lat": "9.58745",
    "lng": "123.73033"
  },
  {
    "country": "PH",
    "name": "Dulig",
    "lat": "16.00212",
    "lng": "120.16864"
  },
  {
    "country": "PH",
    "name": "Dulao",
    "lat": "10.54176",
    "lng": "122.9383"
  },
  {
    "country": "PH",
    "name": "Dulangan",
    "lat": "13.4685",
    "lng": "120.9803"
  },
  {
    "country": "PH",
    "name": "Dulangan",
    "lat": "13.3051",
    "lng": "121.1129"
  },
  {
    "country": "PH",
    "name": "Dulangan",
    "lat": "11.4561",
    "lng": "122.9557"
  },
  {
    "country": "PH",
    "name": "Dulag",
    "lat": "10.9525",
    "lng": "125.03167"
  },
  {
    "country": "PH",
    "name": "Dukay",
    "lat": "6.66688",
    "lng": "124.55697"
  },
  {
    "country": "PH",
    "name": "Dugongan",
    "lat": "14.1025",
    "lng": "122.9066"
  },
  {
    "country": "PH",
    "name": "Dugcal",
    "lat": "13.6241",
    "lng": "123.1612"
  },
  {
    "country": "PH",
    "name": "Duero",
    "lat": "9.709",
    "lng": "124.4055"
  },
  {
    "country": "PH",
    "name": "Dueñas",
    "lat": "11.06698",
    "lng": "122.61545"
  },
  {
    "country": "PH",
    "name": "Dualing",
    "lat": "7.15167",
    "lng": "124.56833"
  },
  {
    "country": "PH",
    "name": "Doyong",
    "lat": "15.97224",
    "lng": "120.35386"
  },
  {
    "country": "PH",
    "name": "Dos Hermanas",
    "lat": "10.7421",
    "lng": "123.0377"
  },
  {
    "country": "PH",
    "name": "Dorongan Punta",
    "lat": "15.81476",
    "lng": "120.32266"
  },
  {
    "country": "PH",
    "name": "Doos",
    "lat": "10.46528",
    "lng": "124.72944"
  },
  {
    "country": "PH",
    "name": "Doong",
    "lat": "11.0786",
    "lng": "123.6395"
  },
  {
    "country": "PH",
    "name": "Donsol",
    "lat": "12.9055",
    "lng": "123.5949"
  },
  {
    "country": "PH",
    "name": "Don Pedro",
    "lat": "15.88518",
    "lng": "120.43036"
  },
  {
    "country": "PH",
    "name": "Talagutong",
    "lat": "6.26444",
    "lng": "125.66778"
  },
  {
    "country": "PH",
    "name": "Dungon",
    "lat": "11.7196",
    "lng": "122.316"
  },
  {
    "country": "PH",
    "name": "Don Carlos",
    "lat": "7.68",
    "lng": "125.005"
  },
  {
    "country": "PH",
    "name": "Doña Remedios Trinidad",
    "lat": "15",
    "lng": "121.08333"
  },
  {
    "country": "PH",
    "name": "Domampot",
    "lat": "16",
    "lng": "120.65"
  },
  {
    "country": "PH",
    "name": "Domalanoan",
    "lat": "16.00292",
    "lng": "120.21154"
  },
  {
    "country": "PH",
    "name": "Dolores",
    "lat": "17.6477",
    "lng": "120.7091"
  },
  {
    "country": "PH",
    "name": "Dolores",
    "lat": "14.02265",
    "lng": "121.41008"
  },
  {
    "country": "PH",
    "name": "Dolores",
    "lat": "12.0371",
    "lng": "125.4825"
  },
  {
    "country": "PH",
    "name": "Dolores",
    "lat": "11.06139",
    "lng": "124.61333"
  },
  {
    "country": "PH",
    "name": "Dologon",
    "lat": "7.84083",
    "lng": "125.04444"
  },
  {
    "country": "PH",
    "name": "Dolo",
    "lat": "6.81028",
    "lng": "125.19167"
  },
  {
    "country": "PH",
    "name": "Dodan",
    "lat": "17.64107",
    "lng": "121.79449"
  },
  {
    "country": "PH",
    "name": "Dobdoban",
    "lat": "12.5747",
    "lng": "122.1138"
  },
  {
    "country": "PH",
    "name": "Divisoria",
    "lat": "17.52268",
    "lng": "121.77421"
  },
  {
    "country": "PH",
    "name": "Ditsaan",
    "lat": "7.97889",
    "lng": "124.35111"
  },
  {
    "country": "PH",
    "name": "Disod",
    "lat": "8.2611",
    "lng": "123.0169"
  },
  {
    "country": "PH",
    "name": "Dipolog",
    "lat": "8.56697",
    "lng": "123.33471"
  },
  {
    "country": "PH",
    "name": "Diplahan",
    "lat": "7.71667",
    "lng": "123.01667"
  },
  {
    "country": "PH",
    "name": "Dipolo",
    "lat": "7.7828",
    "lng": "123.1158"
  },
  {
    "country": "PH",
    "name": "Dingras",
    "lat": "18.1032",
    "lng": "120.6967"
  },
  {
    "country": "PH",
    "name": "Dingle",
    "lat": "10.9995",
    "lng": "122.6711"
  },
  {
    "country": "PH",
    "name": "Dinganen",
    "lat": "7.32833",
    "lng": "124.37833"
  },
  {
    "country": "PH",
    "name": "Dingalan",
    "lat": "15.3897",
    "lng": "121.3929"
  },
  {
    "country": "PH",
    "name": "Dinalupihan",
    "lat": "14.87827",
    "lng": "120.45221"
  },
  {
    "country": "PH",
    "name": "Dinalongan",
    "lat": "16.1404",
    "lng": "121.9573"
  },
  {
    "country": "PH",
    "name": "Dinaig",
    "lat": "7.02556",
    "lng": "124.315"
  },
  {
    "country": "PH",
    "name": "Dinahican",
    "lat": "14.71667",
    "lng": "121.71667"
  },
  {
    "country": "PH",
    "name": "Dinagat",
    "lat": "9.95611",
    "lng": "125.59333"
  },
  {
    "country": "PH",
    "name": "Dimiao",
    "lat": "9.6064",
    "lng": "124.1633"
  },
  {
    "country": "PH",
    "name": "Dimayon",
    "lat": "8.06667",
    "lng": "124.15"
  },
  {
    "country": "PH",
    "name": "Dimataling",
    "lat": "7.5344",
    "lng": "123.3738"
  },
  {
    "country": "PH",
    "name": "Dimasalang",
    "lat": "12.1923",
    "lng": "123.8592"
  },
  {
    "country": "PH",
    "name": "Dimaluna",
    "lat": "8.1218",
    "lng": "123.7995"
  },
  {
    "country": "PH",
    "name": "Diliman Primero",
    "lat": "15.0247",
    "lng": "120.95208"
  },
  {
    "country": "PH",
    "name": "Dilan",
    "lat": "16.0879",
    "lng": "120.5207"
  },
  {
    "country": "PH",
    "name": "Bonifacio",
    "lat": "8.0525",
    "lng": "123.6142"
  },
  {
    "country": "PH",
    "name": "Digos",
    "lat": "6.74972",
    "lng": "125.35722"
  },
  {
    "country": "PH",
    "name": "Digkilaan",
    "lat": "8.25111",
    "lng": "124.31722"
  },
  {
    "country": "PH",
    "name": "Digdig",
    "lat": "15.949",
    "lng": "120.9778"
  },
  {
    "country": "PH",
    "name": "Digal",
    "lat": "6.75306",
    "lng": "124.79639"
  },
  {
    "country": "PH",
    "name": "Diffun",
    "lat": "16.59",
    "lng": "121.5057"
  },
  {
    "country": "PH",
    "name": "Dicayong",
    "lat": "8.2206",
    "lng": "123.0338"
  },
  {
    "country": "PH",
    "name": "Dicamay",
    "lat": "16.75606",
    "lng": "122.00374"
  },
  {
    "country": "PH",
    "name": "Dicabisagan",
    "lat": "17.08184",
    "lng": "122.41574"
  },
  {
    "country": "PH",
    "name": "Dibuluan",
    "lat": "16.51907",
    "lng": "121.76472"
  },
  {
    "country": "PH",
    "name": "Diaz",
    "lat": "15.8463",
    "lng": "120.8347"
  },
  {
    "country": "PH",
    "name": "Dian-ay",
    "lat": "10.83333",
    "lng": "123.55"
  },
  {
    "country": "PH",
    "name": "Diamantina",
    "lat": "16.91795",
    "lng": "121.62674"
  },
  {
    "country": "PH",
    "name": "Diadi",
    "lat": "16.7262",
    "lng": "121.3589"
  },
  {
    "country": "PH",
    "name": "Del Rosario",
    "lat": "13.3057",
    "lng": "123.3133"
  },
  {
    "country": "PH",
    "name": "Del Pilar",
    "lat": "15.03601",
    "lng": "120.69935"
  },
  {
    "country": "PH",
    "name": "Del Pilar",
    "lat": "9.15194",
    "lng": "125.58472"
  },
  {
    "country": "PH",
    "name": "Daliciasao",
    "lat": "9.9859",
    "lng": "122.7618"
  },
  {
    "country": "PH",
    "name": "Del Gallego",
    "lat": "13.9223",
    "lng": "122.5954"
  },
  {
    "country": "PH",
    "name": "Del Carmen",
    "lat": "15.00544",
    "lng": "120.53412"
  },
  {
    "country": "PH",
    "name": "Del Carmen, Surigao del Norte",
    "lat": "9.86944",
    "lng": "125.96972"
  },
  {
    "country": "PH",
    "name": "De la Paz",
    "lat": "9.70004",
    "lng": "123.86433"
  },
  {
    "country": "PH",
    "name": "Daykitin",
    "lat": "13.27073",
    "lng": "121.91086"
  },
  {
    "country": "PH",
    "name": "Dayapan",
    "lat": "13.93723",
    "lng": "120.9162"
  },
  {
    "country": "PH",
    "name": "Dayap",
    "lat": "14.18014",
    "lng": "121.33335"
  },
  {
    "country": "PH",
    "name": "Dawa-Dawa",
    "lat": "7.46833",
    "lng": "122.83694"
  },
  {
    "country": "PH",
    "name": "Davila",
    "lat": "18.4726",
    "lng": "120.5763"
  },
  {
    "country": "PH",
    "name": "Davao",
    "lat": "7.07306",
    "lng": "125.61278"
  },
  {
    "country": "PH",
    "name": "Dauis",
    "lat": "9.62528",
    "lng": "123.86583"
  },
  {
    "country": "PH",
    "name": "Dauin",
    "lat": "9.1914",
    "lng": "123.2654"
  },
  {
    "country": "PH",
    "name": "Davan",
    "lat": "6.91487",
    "lng": "126.15323"
  },
  {
    "country": "PH",
    "name": "Datu Piang",
    "lat": "7.02833",
    "lng": "124.5025"
  },
  {
    "country": "PH",
    "name": "Datu Paglas",
    "lat": "6.76667",
    "lng": "124.85"
  },
  {
    "country": "PH",
    "name": "Datagon",
    "lat": "9.4461",
    "lng": "123.0891"
  },
  {
    "country": "PH",
    "name": "Dassun",
    "lat": "17.74517",
    "lng": "121.71137"
  },
  {
    "country": "PH",
    "name": "Dasol",
    "lat": "15.9902",
    "lng": "119.8828"
  },
  {
    "country": "PH",
    "name": "Dasmariñas",
    "lat": "14.32944",
    "lng": "120.93667"
  },
  {
    "country": "PH",
    "name": "Darapidap",
    "lat": "17.20007",
    "lng": "120.41802"
  },
  {
    "country": "PH",
    "name": "Daram",
    "lat": "11.6341",
    "lng": "124.7947"
  },
  {
    "country": "PH",
    "name": "Daraitan",
    "lat": "14.6028",
    "lng": "121.4319"
  },
  {
    "country": "PH",
    "name": "Daragutan",
    "lat": "17",
    "lng": "122.03333"
  },
  {
    "country": "PH",
    "name": "Daraga",
    "lat": "13.1483",
    "lng": "123.7124"
  },
  {
    "country": "PH",
    "name": "Dapitan",
    "lat": "10.26244",
    "lng": "123.9497"
  },
  {
    "country": "PH",
    "name": "Dapitan",
    "lat": "8.6561",
    "lng": "123.4227"
  },
  {
    "country": "PH",
    "name": "Dapdapan",
    "lat": "11.4943",
    "lng": "122.6314"
  },
  {
    "country": "PH",
    "name": "Dapdap",
    "lat": "12.2155",
    "lng": "123.7662"
  },
  {
    "country": "PH",
    "name": "Dapdap",
    "lat": "12.062",
    "lng": "125.4881"
  },
  {
    "country": "PH",
    "name": "Dapawan",
    "lat": "12.40694",
    "lng": "122.02778"
  },
  {
    "country": "PH",
    "name": "Dapa",
    "lat": "9.75944",
    "lng": "126.05306"
  },
  {
    "country": "PH",
    "name": "Dao",
    "lat": "12.0998",
    "lng": "125.4372"
  },
  {
    "country": "PH",
    "name": "Dao",
    "lat": "11.3937",
    "lng": "122.6856"
  },
  {
    "country": "PH",
    "name": "Tobias Fornier",
    "lat": "10.515",
    "lng": "121.9461"
  },
  {
    "country": "PH",
    "name": "Dansuli",
    "lat": "6.64075",
    "lng": "124.58258"
  },
  {
    "country": "PH",
    "name": "Dorsalanam",
    "lat": "8.30667",
    "lng": "124.58556"
  },
  {
    "country": "PH",
    "name": "Danglas",
    "lat": "17.7009",
    "lng": "120.6556"
  },
  {
    "country": "PH",
    "name": "Dangcalan",
    "lat": "12.9168",
    "lng": "123.5838"
  },
  {
    "country": "PH",
    "name": "Dancagan",
    "lat": "7.60917",
    "lng": "125.00417"
  },
  {
    "country": "PH",
    "name": "Dancalan",
    "lat": "9.9821",
    "lng": "122.7386"
  },
  {
    "country": "PH",
    "name": "Danao",
    "lat": "10.52083",
    "lng": "124.02722"
  },
  {
    "country": "PH",
    "name": "Danao",
    "lat": "9.945",
    "lng": "124.2233"
  },
  {
    "country": "PH",
    "name": "Danao",
    "lat": "9.63333",
    "lng": "124.2"
  },
  {
    "country": "PH",
    "name": "Danao",
    "lat": "9.55421",
    "lng": "123.75648"
  },
  {
    "country": "PH",
    "name": "Damulog",
    "lat": "7.48361",
    "lng": "124.94306"
  },
  {
    "country": "PH",
    "name": "Dampol",
    "lat": "14.90128",
    "lng": "120.82187"
  },
  {
    "country": "PH",
    "name": "Damortis",
    "lat": "16.24051",
    "lng": "120.40565"
  },
  {
    "country": "PH",
    "name": "Damolog",
    "lat": "10.77271",
    "lng": "124.00639"
  },
  {
    "country": "PH",
    "name": "Damilag",
    "lat": "8.35472",
    "lng": "124.81222"
  },
  {
    "country": "PH",
    "name": "Damayan",
    "lat": "11.4936",
    "lng": "122.5531"
  },
  {
    "country": "PH",
    "name": "Damawato",
    "lat": "6.7",
    "lng": "124.78333"
  },
  {
    "country": "PH",
    "name": "Damatulan",
    "lat": "7.03889",
    "lng": "124.48278"
  },
  {
    "country": "PH",
    "name": "Dalwangan",
    "lat": "8.20056",
    "lng": "125.04056"
  },
  {
    "country": "PH",
    "name": "Dalupirip",
    "lat": "16.32603",
    "lng": "120.72414"
  },
  {
    "country": "PH",
    "name": "Dalupaon",
    "lat": "13.5517",
    "lng": "122.9457"
  },
  {
    "country": "PH",
    "name": "Dalumangcob",
    "lat": "7.21667",
    "lng": "124.3"
  },
  {
    "country": "PH",
    "name": "Dalorong",
    "lat": "7.58583",
    "lng": "125.13278"
  },
  {
    "country": "PH",
    "name": "Dalirig",
    "lat": "8.37722",
    "lng": "124.90139"
  },
  {
    "country": "PH",
    "name": "Dalipuga",
    "lat": "8.31583",
    "lng": "124.25472"
  },
  {
    "country": "PH",
    "name": "Dalipey",
    "lat": "16.8",
    "lng": "120.71667"
  },
  {
    "country": "PH",
    "name": "Dalican",
    "lat": "6.96667",
    "lng": "124.4"
  },
  {
    "country": "PH",
    "name": "Daliao",
    "lat": "5.86111",
    "lng": "124.95333"
  },
  {
    "country": "PH",
    "name": "Dalaoig",
    "lat": "17.94917",
    "lng": "121.7148"
  },
  {
    "country": "PH",
    "name": "Dalaguete",
    "lat": "9.7612",
    "lng": "123.5349"
  },
  {
    "country": "PH",
    "name": "Dahay",
    "lat": "6.39067",
    "lng": "124.71464"
  },
  {
    "country": "PH",
    "name": "Dagupan",
    "lat": "17.70039",
    "lng": "121.50448"
  },
  {
    "country": "PH",
    "name": "Dagupan",
    "lat": "16.04313",
    "lng": "120.33325"
  },
  {
    "country": "PH",
    "name": "Dagup",
    "lat": "16.63722",
    "lng": "120.44556"
  },
  {
    "country": "PH",
    "name": "Daguit",
    "lat": "14.1895",
    "lng": "122.7266"
  },
  {
    "country": "PH",
    "name": "Daguioman",
    "lat": "17.45093",
    "lng": "120.91505"
  },
  {
    "country": "PH",
    "name": "Dagumba-an",
    "lat": "8.15306",
    "lng": "124.59083"
  },
  {
    "country": "PH",
    "name": "Dagohoy",
    "lat": "9.90016",
    "lng": "124.28322"
  },
  {
    "country": "PH",
    "name": "Dagatan",
    "lat": "14.0017",
    "lng": "121.3767"
  },
  {
    "country": "PH",
    "name": "Dagatan",
    "lat": "13.7389",
    "lng": "121.199"
  },
  {
    "country": "PH",
    "name": "Dagami",
    "lat": "11.06083",
    "lng": "124.90278"
  },
  {
    "country": "PH",
    "name": "Daet",
    "lat": "14.1122",
    "lng": "122.9553"
  },
  {
    "country": "PH",
    "name": "Dadus",
    "lat": "7.0575",
    "lng": "124.32167"
  },
  {
    "country": "PH",
    "name": "Dacudao",
    "lat": "7.21528",
    "lng": "125.47139"
  },
  {
    "country": "PH",
    "name": "Da-an Sur",
    "lat": "11.2612",
    "lng": "122.4202"
  },
  {
    "country": "PH",
    "name": "Viejo Daan Banua",
    "lat": "10.90354",
    "lng": "123.0597"
  },
  {
    "country": "PH",
    "name": "Daanbantayan",
    "lat": "11.24681",
    "lng": "124.01462"
  },
  {
    "country": "PH",
    "name": "Cuyo",
    "lat": "10.8525",
    "lng": "121.00861"
  },
  {
    "country": "PH",
    "name": "Cuyapo",
    "lat": "15.78194",
    "lng": "120.66472"
  },
  {
    "country": "PH",
    "name": "Cut-cut Primero",
    "lat": "15.48277",
    "lng": "120.58604"
  },
  {
    "country": "PH",
    "name": "Curuan",
    "lat": "7.20528",
    "lng": "122.23306"
  },
  {
    "country": "PH",
    "name": "Curry",
    "lat": "13.6",
    "lng": "123.3"
  },
  {
    "country": "PH",
    "name": "Currimao",
    "lat": "18.0182",
    "lng": "120.4876"
  },
  {
    "country": "PH",
    "name": "Culubasa",
    "lat": "15.14431",
    "lng": "120.65223"
  },
  {
    "country": "PH",
    "name": "Cullalabo del Sur",
    "lat": "17.10267",
    "lng": "121.70394"
  },
  {
    "country": "PH",
    "name": "Culianin",
    "lat": "14.91511",
    "lng": "120.89847"
  },
  {
    "country": "PH",
    "name": "Culianan",
    "lat": "6.98028",
    "lng": "122.14667"
  },
  {
    "country": "PH",
    "name": "Culasi",
    "lat": "11.42721",
    "lng": "122.05601"
  },
  {
    "country": "PH",
    "name": "Culasi",
    "lat": "11.07917",
    "lng": "122.98194"
  },
  {
    "country": "PH",
    "name": "Culaman",
    "lat": "5.96028",
    "lng": "125.65861"
  },
  {
    "country": "PH",
    "name": "Culaba",
    "lat": "11.65778",
    "lng": "124.5425"
  },
  {
    "country": "PH",
    "name": "Cuevas",
    "lat": "8.01917",
    "lng": "126.09417"
  },
  {
    "country": "PH",
    "name": "Cuenca",
    "lat": "13.902",
    "lng": "121.0521"
  },
  {
    "country": "PH",
    "name": "Cuartero",
    "lat": "11.3407",
    "lng": "122.6694"
  },
  {
    "country": "PH",
    "name": "Cuambog",
    "lat": "7.30861",
    "lng": "125.84806"
  },
  {
    "country": "PH",
    "name": "Cotmon",
    "lat": "13.1175",
    "lng": "123.6637"
  },
  {
    "country": "PH",
    "name": "Kotkot",
    "lat": "10.425",
    "lng": "124.0005"
  },
  {
    "country": "PH",
    "name": "Cotabato",
    "lat": "7.22361",
    "lng": "124.24639"
  },
  {
    "country": "PH",
    "name": "Cosina",
    "lat": "8.10611",
    "lng": "124.61972"
  },
  {
    "country": "PH",
    "name": "Cortez",
    "lat": "11.5301",
    "lng": "122.3975"
  },
  {
    "country": "PH",
    "name": "Cortes",
    "lat": "9.722",
    "lng": "123.88"
  },
  {
    "country": "PH",
    "name": "Cortes",
    "lat": "9.27972",
    "lng": "126.19111"
  },
  {
    "country": "PH",
    "name": "Corrooy",
    "lat": "16.7962",
    "lng": "120.4453"
  },
  {
    "country": "PH",
    "name": "Coronon",
    "lat": "6.87917",
    "lng": "125.44889"
  },
  {
    "country": "PH",
    "name": "Coron",
    "lat": "11.9986",
    "lng": "120.2043"
  },
  {
    "country": "PH",
    "name": "Corella",
    "lat": "9.6875",
    "lng": "123.9218"
  },
  {
    "country": "PH",
    "name": "Cordova",
    "lat": "10.73028",
    "lng": "122.40139"
  },
  {
    "country": "PH",
    "name": "Cordon",
    "lat": "16.6744",
    "lng": "121.4658"
  },
  {
    "country": "PH",
    "name": "Cordova",
    "lat": "10.24394",
    "lng": "123.94222"
  },
  {
    "country": "PH",
    "name": "Corcuera",
    "lat": "12.78331",
    "lng": "122.04851"
  },
  {
    "country": "PH",
    "name": "Conversion",
    "lat": "15.8984",
    "lng": "121.1277"
  },
  {
    "country": "PH",
    "name": "Consuelo",
    "lat": "10.6348",
    "lng": "124.301"
  },
  {
    "country": "PH",
    "name": "Consuelo",
    "lat": "9.9996",
    "lng": "122.758"
  },
  {
    "country": "PH",
    "name": "Consuelo",
    "lat": "8.90167",
    "lng": "125.1875"
  },
  {
    "country": "PH",
    "name": "Consuegra",
    "lat": "11.2976",
    "lng": "124.5124"
  },
  {
    "country": "PH",
    "name": "Constancia",
    "lat": "10.59596",
    "lng": "122.6415"
  },
  {
    "country": "PH",
    "name": "Consolacion",
    "lat": "11.3284",
    "lng": "122.6332"
  },
  {
    "country": "PH",
    "name": "Consolacion",
    "lat": "10.3766",
    "lng": "123.9573"
  },
  {
    "country": "PH",
    "name": "Conner",
    "lat": "17.79639",
    "lng": "121.3275"
  },
  {
    "country": "PH",
    "name": "Conel",
    "lat": "6.20222",
    "lng": "125.18722"
  },
  {
    "country": "PH",
    "name": "Conduaga",
    "lat": "8.862",
    "lng": "117.4893"
  },
  {
    "country": "PH",
    "name": "Concordia",
    "lat": "10.50767",
    "lng": "122.5496"
  },
  {
    "country": "PH",
    "name": "Concepcion",
    "lat": "15.44447",
    "lng": "120.8007"
  },
  {
    "country": "PH",
    "name": "Concepcion",
    "lat": "15.32546",
    "lng": "120.65723"
  },
  {
    "country": "PH",
    "name": "Concepcion",
    "lat": "15.22089",
    "lng": "120.83114"
  },
  {
    "country": "PH",
    "name": "Concepcion Ibaba",
    "lat": "13.92309",
    "lng": "121.46099"
  },
  {
    "country": "PH",
    "name": "Concepcion",
    "lat": "12.3975",
    "lng": "122.09361"
  },
  {
    "country": "PH",
    "name": "Concepcion",
    "lat": "11.2161",
    "lng": "123.1073"
  },
  {
    "country": "PH",
    "name": "Concepcion",
    "lat": "10.692",
    "lng": "123.0608"
  },
  {
    "country": "PH",
    "name": "Concepcion",
    "lat": "10.40528",
    "lng": "124.78306"
  },
  {
    "country": "PH",
    "name": "Compostela",
    "lat": "10.455",
    "lng": "124.0106"
  },
  {
    "country": "PH",
    "name": "Compostela",
    "lat": "7.67306",
    "lng": "126.08889"
  },
  {
    "country": "PH",
    "name": "Communal",
    "lat": "13.2548",
    "lng": "121.1366"
  },
  {
    "country": "PH",
    "name": "Comillas Norte",
    "lat": "16.959",
    "lng": "120.7469"
  },
  {
    "country": "PH",
    "name": "Comillas",
    "lat": "15.39833",
    "lng": "120.70045"
  },
  {
    "country": "PH",
    "name": "Columbio",
    "lat": "6.69639",
    "lng": "124.93722"
  },
  {
    "country": "PH",
    "name": "Colonia",
    "lat": "10.6553",
    "lng": "123.7911"
  },
  {
    "country": "PH",
    "name": "Colonia",
    "lat": "6.64361",
    "lng": "122.1575"
  },
  {
    "country": "PH",
    "name": "Colongulo",
    "lat": "6.33861",
    "lng": "124.72167"
  },
  {
    "country": "PH",
    "name": "Culasian",
    "lat": "11.30694",
    "lng": "124.61056"
  },
  {
    "country": "PH",
    "name": "Culacling",
    "lat": "13.7815",
    "lng": "122.8767"
  },
  {
    "country": "PH",
    "name": "Cogtong",
    "lat": "9.8374",
    "lng": "124.5291"
  },
  {
    "country": "PH",
    "name": "Cogon",
    "lat": "7.15083",
    "lng": "125.71722"
  },
  {
    "country": "PH",
    "name": "Cogon Cruz",
    "lat": "10.50944",
    "lng": "123.96972"
  },
  {
    "country": "PH",
    "name": "Cogon",
    "lat": "11.4641",
    "lng": "122.803"
  },
  {
    "country": "PH",
    "name": "Cogon",
    "lat": "10.7133",
    "lng": "123.8284"
  },
  {
    "country": "PH",
    "name": "Cogon",
    "lat": "10.26778",
    "lng": "123.75861"
  },
  {
    "country": "PH",
    "name": "Codcod",
    "lat": "10.46337",
    "lng": "123.2495"
  },
  {
    "country": "PH",
    "name": "Claveria",
    "lat": "18.60742",
    "lng": "121.08322"
  },
  {
    "country": "PH",
    "name": "Claveria",
    "lat": "12.9035",
    "lng": "123.2457"
  },
  {
    "country": "PH",
    "name": "Claveria",
    "lat": "8.61",
    "lng": "124.89472"
  },
  {
    "country": "PH",
    "name": "Claver",
    "lat": "9.5725",
    "lng": "125.73306"
  },
  {
    "country": "PH",
    "name": "Clarin",
    "lat": "9.9616",
    "lng": "124.0252"
  },
  {
    "country": "PH",
    "name": "Clarin",
    "lat": "8.2023",
    "lng": "123.8582"
  },
  {
    "country": "PH",
    "name": "Chambrey",
    "lat": "10.9768",
    "lng": "123.1682"
  },
  {
    "country": "PH",
    "name": "Cervantes",
    "lat": "16.9909",
    "lng": "120.7359"
  },
  {
    "country": "PH",
    "name": "Cervantes",
    "lat": "12.36861",
    "lng": "124.65972"
  },
  {
    "country": "PH",
    "name": "Cervantes",
    "lat": "10.8726",
    "lng": "123.5209"
  },
  {
    "country": "PH",
    "name": "Cebuano",
    "lat": "6.38794",
    "lng": "124.96841"
  },
  {
    "country": "PH",
    "name": "Cebu City",
    "lat": "10.31672",
    "lng": "123.89071"
  },
  {
    "country": "PH",
    "name": "Cayungnan",
    "lat": "16.1332",
    "lng": "119.8375"
  },
  {
    "country": "PH",
    "name": "Cayhagan",
    "lat": "9.6783",
    "lng": "122.4335"
  },
  {
    "country": "PH",
    "name": "Cayanguan",
    "lat": "11.689",
    "lng": "122.2909"
  },
  {
    "country": "PH",
    "name": "Cayanga",
    "lat": "16.11508",
    "lng": "120.39875"
  },
  {
    "country": "PH",
    "name": "Cayang",
    "lat": "11.06667",
    "lng": "123.98333"
  },
  {
    "country": "PH",
    "name": "Kauit",
    "lat": "11.186",
    "lng": "123.9459"
  },
  {
    "country": "PH",
    "name": "Cawayan Bugtong",
    "lat": "15.63362",
    "lng": "120.77695"
  },
  {
    "country": "PH",
    "name": "Cawayan",
    "lat": "13.3672",
    "lng": "122.5094"
  },
  {
    "country": "PH",
    "name": "Cawayan",
    "lat": "12.6557",
    "lng": "121.5456"
  },
  {
    "country": "PH",
    "name": "Cawayan",
    "lat": "11.6237",
    "lng": "122.4649"
  },
  {
    "country": "PH",
    "name": "Cavite",
    "lat": "15.67785",
    "lng": "120.76978"
  },
  {
    "country": "PH",
    "name": "Cavite City",
    "lat": "14.48369",
    "lng": "120.89878"
  },
  {
    "country": "PH",
    "name": "Cavinti",
    "lat": "14.24482",
    "lng": "121.50797"
  },
  {
    "country": "PH",
    "name": "Causwagan",
    "lat": "8.4475",
    "lng": "125.84028"
  },
  {
    "country": "PH",
    "name": "Causip",
    "lat": "13.5159",
    "lng": "123.2834"
  },
  {
    "country": "PH",
    "name": "Cauayan",
    "lat": "16.93472",
    "lng": "121.7725"
  },
  {
    "country": "PH",
    "name": "Cauayan",
    "lat": "15.15149",
    "lng": "120.67166"
  },
  {
    "country": "PH",
    "name": "Cawayan",
    "lat": "9.9718",
    "lng": "122.6249"
  },
  {
    "country": "PH",
    "name": "Catungawan Sur",
    "lat": "9.7817",
    "lng": "124.4693"
  },
  {
    "country": "PH",
    "name": "Catungan",
    "lat": "10.7706",
    "lng": "122.0149"
  },
  {
    "country": "PH",
    "name": "Catuday",
    "lat": "16.2923",
    "lng": "119.8062"
  },
  {
    "country": "PH",
    "name": "Catubig",
    "lat": "12.4098",
    "lng": "125.0548"
  },
  {
    "country": "PH",
    "name": "Cato",
    "lat": "15.8362",
    "lng": "119.9151"
  },
  {
    "country": "PH",
    "name": "Catmondaan",
    "lat": "10.68692",
    "lng": "124.01494"
  },
  {
    "country": "PH",
    "name": "Catmon",
    "lat": "11.53516",
    "lng": "124.43115"
  },
  {
    "country": "PH",
    "name": "Catmon",
    "lat": "10.71667",
    "lng": "124"
  },
  {
    "country": "PH",
    "name": "Caticugan",
    "lat": "9.1",
    "lng": "123"
  },
  {
    "country": "PH",
    "name": "Katico",
    "lat": "6.76015",
    "lng": "124.73214"
  },
  {
    "country": "PH",
    "name": "Caticlan",
    "lat": "11.93337",
    "lng": "121.95981"
  },
  {
    "country": "PH",
    "name": "Caterman",
    "lat": "17.21738",
    "lng": "120.42442"
  },
  {
    "country": "PH",
    "name": "Cateel",
    "lat": "7.79139",
    "lng": "126.45333"
  },
  {
    "country": "PH",
    "name": "Catbalogan",
    "lat": "11.77528",
    "lng": "124.88611"
  },
  {
    "country": "PH",
    "name": "Catayauan",
    "lat": "18.16072",
    "lng": "121.65271"
  },
  {
    "country": "PH",
    "name": "Catarman",
    "lat": "12.4989",
    "lng": "124.6377"
  },
  {
    "country": "PH",
    "name": "Catarman",
    "lat": "9.60169",
    "lng": "123.86111"
  },
  {
    "country": "PH",
    "name": "Catarman",
    "lat": "9.12556",
    "lng": "124.67556"
  },
  {
    "country": "PH",
    "name": "Catanauan",
    "lat": "13.5926",
    "lng": "122.3215"
  },
  {
    "country": "PH",
    "name": "Cataingan",
    "lat": "12.003",
    "lng": "123.992"
  },
  {
    "country": "PH",
    "name": "Catablan",
    "lat": "15.9757",
    "lng": "120.4953"
  },
  {
    "country": "PH",
    "name": "Catabangan",
    "lat": "13.8777",
    "lng": "122.6615"
  },
  {
    "country": "PH",
    "name": "Castillo",
    "lat": "13.7313",
    "lng": "123.1166"
  },
  {
    "country": "PH",
    "name": "Castillejos",
    "lat": "14.93363",
    "lng": "120.19785"
  },
  {
    "country": "PH",
    "name": "Castilla",
    "lat": "12.94861",
    "lng": "123.88222"
  },
  {
    "country": "PH",
    "name": "Castañas",
    "lat": "13.8744",
    "lng": "121.5533"
  },
  {
    "country": "PH",
    "name": "Casisang",
    "lat": "8.13806",
    "lng": "125.125"
  },
  {
    "country": "PH",
    "name": "Casiguran",
    "lat": "12.87361",
    "lng": "124.00972"
  },
  {
    "country": "PH",
    "name": "Casian",
    "lat": "11.035",
    "lng": "119.7136"
  },
  {
    "country": "PH",
    "name": "Casay",
    "lat": "13.2632",
    "lng": "122.5217"
  },
  {
    "country": "PH",
    "name": "Cassanayan",
    "lat": "11.5169",
    "lng": "123.0512"
  },
  {
    "country": "PH",
    "name": "Casambalangan",
    "lat": "18.37646",
    "lng": "122.12745"
  },
  {
    "country": "PH",
    "name": "Casala-an",
    "lat": "9.11667",
    "lng": "123.05"
  },
  {
    "country": "PH",
    "name": "Caruray",
    "lat": "10.3094",
    "lng": "119.0128"
  },
  {
    "country": "PH",
    "name": "Caronoan West",
    "lat": "16.2633",
    "lng": "120.4463"
  },
  {
    "country": "PH",
    "name": "Cartagena",
    "lat": "9.8203",
    "lng": "122.4004"
  },
  {
    "country": "PH",
    "name": "Carriedo",
    "lat": "16.031",
    "lng": "120.7549"
  },
  {
    "country": "PH",
    "name": "Carriedo",
    "lat": "12.9344",
    "lng": "124.105"
  },
  {
    "country": "PH",
    "name": "Carrascal",
    "lat": "9.37028",
    "lng": "125.94917"
  },
  {
    "country": "PH",
    "name": "Carranglan",
    "lat": "15.9613",
    "lng": "121.0641"
  },
  {
    "country": "PH",
    "name": "Carpenter Hill",
    "lat": "6.44413",
    "lng": "124.88138"
  },
  {
    "country": "PH",
    "name": "Carot",
    "lat": "16.34468",
    "lng": "119.98005"
  },
  {
    "country": "PH",
    "name": "Carusucan",
    "lat": "15.96589",
    "lng": "120.63598"
  },
  {
    "country": "PH",
    "name": "Carmona",
    "lat": "14.3132",
    "lng": "121.0576"
  },
  {
    "country": "PH",
    "name": "Carmen",
    "lat": "15.88642",
    "lng": "120.59984"
  },
  {
    "country": "PH",
    "name": "Carmen",
    "lat": "15.44702",
    "lng": "120.82676"
  },
  {
    "country": "PH",
    "name": "Carmen",
    "lat": "12.6171",
    "lng": "122.1211"
  },
  {
    "country": "PH",
    "name": "Cogan",
    "lat": "10.59306",
    "lng": "124.01778"
  },
  {
    "country": "PH",
    "name": "Carmen Grande",
    "lat": "10.3787",
    "lng": "122.9156"
  },
  {
    "country": "PH",
    "name": "Carmen",
    "lat": "9.8223",
    "lng": "124.1964"
  },
  {
    "country": "PH",
    "name": "Carmen",
    "lat": "9.22639",
    "lng": "126.01722"
  },
  {
    "country": "PH",
    "name": "Carmen",
    "lat": "8.98861",
    "lng": "125.2925"
  },
  {
    "country": "PH",
    "name": "Carmen",
    "lat": "7.36056",
    "lng": "125.70639"
  },
  {
    "country": "PH",
    "name": "Carmen",
    "lat": "7.20444",
    "lng": "124.79167"
  },
  {
    "country": "PH",
    "name": "Carmelo",
    "lat": "11.01667",
    "lng": "122.81667"
  },
  {
    "country": "PH",
    "name": "Carmelo",
    "lat": "10.7051",
    "lng": "123.7935"
  },
  {
    "country": "PH",
    "name": "Carles",
    "lat": "11.5726",
    "lng": "123.1342"
  },
  {
    "country": "PH",
    "name": "Karligan",
    "lat": "14.97561",
    "lng": "122.04272"
  },
  {
    "country": "PH",
    "name": "Carigara",
    "lat": "11.29811",
    "lng": "124.67895"
  },
  {
    "country": "PH",
    "name": "Carig",
    "lat": "17.65929",
    "lng": "121.74357"
  },
  {
    "country": "PH",
    "name": "Caridad",
    "lat": "10.8315",
    "lng": "124.7518"
  },
  {
    "country": "PH",
    "name": "Caridad",
    "lat": "10.4967",
    "lng": "122.8974"
  },
  {
    "country": "PH",
    "name": "Cardona",
    "lat": "15.5722",
    "lng": "120.5897"
  },
  {
    "country": "PH",
    "name": "Cardona",
    "lat": "14.48646",
    "lng": "121.22752"
  },
  {
    "country": "PH",
    "name": "Carcar",
    "lat": "10.1061",
    "lng": "123.6402"
  },
  {
    "country": "PH",
    "name": "Caraycayon",
    "lat": "13.61667",
    "lng": "123.48333"
  },
  {
    "country": "PH",
    "name": "Caraycaray",
    "lat": "11.5551",
    "lng": "124.415"
  },
  {
    "country": "PH",
    "name": "Carasi",
    "lat": "18.19889",
    "lng": "120.86833"
  },
  {
    "country": "PH",
    "name": "Caranan",
    "lat": "13.5167",
    "lng": "123.0156"
  },
  {
    "country": "PH",
    "name": "Caramutan",
    "lat": "15.92074",
    "lng": "120.61012"
  },
  {
    "country": "PH",
    "name": "Caramoran",
    "lat": "13.9849",
    "lng": "124.1347"
  },
  {
    "country": "PH",
    "name": "Caramoan",
    "lat": "13.7707",
    "lng": "123.8631"
  },
  {
    "country": "PH",
    "name": "Caramay",
    "lat": "10.1815",
    "lng": "119.236"
  },
  {
    "country": "PH",
    "name": "Caraga",
    "lat": "7.32972",
    "lng": "126.5675"
  },
  {
    "country": "PH",
    "name": "Caracal",
    "lat": "8.12722",
    "lng": "122.845"
  },
  {
    "country": "PH",
    "name": "Carabalan",
    "lat": "10.0964",
    "lng": "122.946"
  },
  {
    "country": "PH",
    "name": "Capuy",
    "lat": "12.98333",
    "lng": "123.93333"
  },
  {
    "country": "PH",
    "name": "Capuluan",
    "lat": "13.8162",
    "lng": "122.5158"
  },
  {
    "country": "PH",
    "name": "Capulaan",
    "lat": "15.90497",
    "lng": "120.53719"
  },
  {
    "country": "PH",
    "name": "Capul",
    "lat": "12.4237",
    "lng": "124.1811"
  },
  {
    "country": "PH",
    "name": "Capucnasan",
    "lat": "13.6",
    "lng": "123.21667"
  },
  {
    "country": "PH",
    "name": "Capoocan",
    "lat": "11.29333",
    "lng": "124.64194"
  },
  {
    "country": "PH",
    "name": "Capissayan Sur",
    "lat": "18.0509",
    "lng": "121.8177"
  },
  {
    "country": "PH",
    "name": "Capas",
    "lat": "15.33117",
    "lng": "120.5898"
  },
  {
    "country": "PH",
    "name": "Capandanan",
    "lat": "15.95943",
    "lng": "120.69519"
  },
  {
    "country": "PH",
    "name": "Capalonga",
    "lat": "14.3306",
    "lng": "122.4937"
  },
  {
    "country": "PH",
    "name": "Capalayan",
    "lat": "9.74056",
    "lng": "125.54444"
  },
  {
    "country": "PH",
    "name": "Capaga",
    "lat": "11.4379",
    "lng": "122.7479"
  },
  {
    "country": "PH",
    "name": "Caoayan",
    "lat": "17.56194",
    "lng": "120.3975"
  },
  {
    "country": "PH",
    "name": "Canubing No 2",
    "lat": "13.35",
    "lng": "121.13333"
  },
  {
    "country": "PH",
    "name": "Canturay",
    "lat": "9.7937",
    "lng": "122.4543"
  },
  {
    "country": "PH",
    "name": "Cantoria",
    "lat": "16.8441",
    "lng": "120.4045"
  },
  {
    "country": "PH",
    "name": "Cantilan",
    "lat": "9.33361",
    "lng": "125.9775"
  },
  {
    "country": "PH",
    "name": "Cantel",
    "lat": "12.6176",
    "lng": "121.5136"
  },
  {
    "country": "PH",
    "name": "Cantapoy",
    "lat": "9.49056",
    "lng": "125.43639"
  },
  {
    "country": "PH",
    "name": "Cantao-an",
    "lat": "10.24258",
    "lng": "123.7496"
  },
  {
    "country": "PH",
    "name": "Cansolungon",
    "lat": "10.151",
    "lng": "122.9978"
  },
  {
    "country": "PH",
    "name": "Cansuje",
    "lat": "9.92314",
    "lng": "123.49629"
  },
  {
    "country": "PH",
    "name": "Canroma",
    "lat": "10.3606",
    "lng": "122.879"
  },
  {
    "country": "PH",
    "name": "Canomoy",
    "lat": "12.15735",
    "lng": "123.27011"
  },
  {
    "country": "PH",
    "name": "Corocotan",
    "lat": "7.3998",
    "lng": "125.7727"
  },
  {
    "country": "PH",
    "name": "Canmaya Diot",
    "lat": "9.9384",
    "lng": "124.0942"
  },
  {
    "country": "PH",
    "name": "Canlaon",
    "lat": "10.38697",
    "lng": "123.2227"
  },
  {
    "country": "PH",
    "name": "Canjulao",
    "lat": "9.6605",
    "lng": "124.3532"
  },
  {
    "country": "PH",
    "name": "Caningay",
    "lat": "9.8297",
    "lng": "122.6442"
  },
  {
    "country": "PH",
    "name": "Canhaway",
    "lat": "9.7501",
    "lng": "124.4722"
  },
  {
    "country": "PH",
    "name": "Canhandugan",
    "lat": "11.135",
    "lng": "124.77972"
  },
  {
    "country": "PH",
    "name": "Candoni",
    "lat": "9.817",
    "lng": "122.6043"
  },
  {
    "country": "PH",
    "name": "Candon",
    "lat": "17.19472",
    "lng": "120.45167"
  },
  {
    "country": "PH",
    "name": "Candijay",
    "lat": "9.8182",
    "lng": "124.4977"
  },
  {
    "country": "PH",
    "name": "Candiis",
    "lat": "8.97028",
    "lng": "125.18417"
  },
  {
    "country": "PH",
    "name": "Candelaria",
    "lat": "13.93111",
    "lng": "121.42333"
  },
  {
    "country": "PH",
    "name": "Candelaria",
    "lat": "11.2893",
    "lng": "122.5228"
  },
  {
    "country": "PH",
    "name": "Candating",
    "lat": "15.15056",
    "lng": "120.81847"
  },
  {
    "country": "PH",
    "name": "Candabong",
    "lat": "9.7343",
    "lng": "124.5383"
  },
  {
    "country": "PH",
    "name": "Kandabong",
    "lat": "9.6859",
    "lng": "123.0728"
  },
  {
    "country": "PH",
    "name": "Candaba",
    "lat": "15.0956",
    "lng": "120.8267"
  },
  {
    "country": "PH",
    "name": "Cansilayan",
    "lat": "10.55976",
    "lng": "123.0184"
  },
  {
    "country": "PH",
    "name": "Canayan",
    "lat": "8.19556",
    "lng": "125.14472"
  },
  {
    "country": "PH",
    "name": "Canauay",
    "lat": "9.0651",
    "lng": "123.0524"
  },
  {
    "country": "PH",
    "name": "Can-Avid",
    "lat": "11.99528",
    "lng": "125.44722"
  },
  {
    "country": "PH",
    "name": "Can-asujan",
    "lat": "10.1299",
    "lng": "123.6574"
  },
  {
    "country": "PH",
    "name": "Ganapi",
    "lat": "17.20174",
    "lng": "121.86524"
  },
  {
    "country": "PH",
    "name": "Canaoalan",
    "lat": "16.02902",
    "lng": "120.29641"
  },
  {
    "country": "PH",
    "name": "Canan Norte",
    "lat": "15.90986",
    "lng": "120.47763"
  },
  {
    "country": "PH",
    "name": "Canaman",
    "lat": "13.648",
    "lng": "123.1699"
  },
  {
    "country": "PH",
    "name": "Camohaguin",
    "lat": "13.9089",
    "lng": "122.1666"
  },
  {
    "country": "PH",
    "name": "Campoyo",
    "lat": "9.6564",
    "lng": "123.1479"
  },
  {
    "country": "PH",
    "name": "Campusong",
    "lat": "10.81583",
    "lng": "124.03222"
  },
  {
    "country": "PH",
    "name": "Camingawan",
    "lat": "9.8958",
    "lng": "122.8625"
  },
  {
    "country": "PH",
    "name": "Camindangan",
    "lat": "9.9184",
    "lng": "122.6296"
  },
  {
    "country": "PH",
    "name": "Caminauit",
    "lat": "12.33135",
    "lng": "121.08251"
  },
  {
    "country": "PH",
    "name": "Camiling",
    "lat": "15.6866",
    "lng": "120.4128"
  },
  {
    "country": "PH",
    "name": "Camias",
    "lat": "15.16679",
    "lng": "120.97416"
  },
  {
    "country": "PH",
    "name": "Camp Flora",
    "lat": "13.3508",
    "lng": "122.6641"
  },
  {
    "country": "PH",
    "name": "Cambuga",
    "lat": "13.61667",
    "lng": "122.45"
  },
  {
    "country": "PH",
    "name": "Cambanay",
    "lat": "10.54361",
    "lng": "123.98611"
  },
  {
    "country": "PH",
    "name": "Gambalidio",
    "lat": "13.6205",
    "lng": "122.8913"
  },
  {
    "country": "PH",
    "name": "Camangcamang",
    "lat": "10.1791",
    "lng": "122.9865"
  },
  {
    "country": "PH",
    "name": "Camandag",
    "lat": "10.33333",
    "lng": "123.06667"
  },
  {
    "country": "PH",
    "name": "Camambugan",
    "lat": "10.05844",
    "lng": "124.43811"
  },
  {
    "country": "PH",
    "name": "Camalobalo",
    "lat": "10.2731",
    "lng": "122.9505"
  },
  {
    "country": "PH",
    "name": "Camaligan",
    "lat": "13.6224",
    "lng": "123.1667"
  },
  {
    "country": "PH",
    "name": "Camalig",
    "lat": "13.1821",
    "lng": "123.6543"
  },
  {
    "country": "PH",
    "name": "Camaley",
    "lat": "15.99724",
    "lng": "120.30107"
  },
  {
    "country": "PH",
    "name": "Camalaniugan",
    "lat": "18.274",
    "lng": "121.6748"
  },
  {
    "country": "PH",
    "name": "Cama Juan",
    "lat": "15.39223",
    "lng": "120.76848"
  },
  {
    "country": "PH",
    "name": "Camachile",
    "lat": "14.64361",
    "lng": "120.58083"
  },
  {
    "country": "PH",
    "name": "Caluya",
    "lat": "11.931",
    "lng": "121.5477"
  },
  {
    "country": "PH",
    "name": "Calumpit",
    "lat": "14.91639",
    "lng": "120.76583"
  },
  {
    "country": "PH",
    "name": "Calumpang",
    "lat": "15.174",
    "lng": "121.0249"
  },
  {
    "country": "PH",
    "name": "Calumpang",
    "lat": "14.6228",
    "lng": "121.0897"
  },
  {
    "country": "PH",
    "name": "Calumpang",
    "lat": "14.1966",
    "lng": "121.402"
  },
  {
    "country": "PH",
    "name": "Calumpang",
    "lat": "13.9897",
    "lng": "121.5494"
  },
  {
    "country": "PH",
    "name": "Calumpang",
    "lat": "13.84239",
    "lng": "120.97555"
  },
  {
    "country": "PH",
    "name": "Calomboyan",
    "lat": "15.94652",
    "lng": "120.30348"
  },
  {
    "country": "PH",
    "name": "San Isidro",
    "lat": "15.4425",
    "lng": "120.72565"
  },
  {
    "country": "PH",
    "name": "Calubian",
    "lat": "11.4472",
    "lng": "124.4281"
  },
  {
    "country": "PH",
    "name": "Calubcub Dos",
    "lat": "13.7393",
    "lng": "121.42193"
  },
  {
    "country": "PH",
    "name": "Calsib",
    "lat": "15.84711",
    "lng": "120.26412"
  },
  {
    "country": "PH",
    "name": "Caloocan City",
    "lat": "14.64953",
    "lng": "120.96788"
  },
  {
    "country": "PH",
    "name": "Calongbuyan",
    "lat": "17.16478",
    "lng": "120.42716"
  },
  {
    "country": "PH",
    "name": "Calolbon",
    "lat": "13.596",
    "lng": "124.0991"
  },
  {
    "country": "PH",
    "name": "Calog Norte",
    "lat": "18.36359",
    "lng": "121.38533"
  },
  {
    "country": "PH",
    "name": "Caloc-an",
    "lat": "9.04694",
    "lng": "125.53056"
  },
  {
    "country": "PH",
    "name": "Callaguip",
    "lat": "18.07139",
    "lng": "120.48667"
  },
  {
    "country": "PH",
    "name": "Calizo",
    "lat": "11.5819",
    "lng": "122.3857"
  },
  {
    "country": "PH",
    "name": "Calituban",
    "lat": "10.23995",
    "lng": "124.2919"
  },
  {
    "country": "PH",
    "name": "Colipapa",
    "lat": "9.4726",
    "lng": "122.5616"
  },
  {
    "country": "PH",
    "name": "Calintaan",
    "lat": "12.56667",
    "lng": "120.93333"
  },
  {
    "country": "PH",
    "name": "Calinog",
    "lat": "11.11667",
    "lng": "122.56667"
  },
  {
    "country": "PH",
    "name": "Calingcuan",
    "lat": "15.33333",
    "lng": "120.58333"
  },
  {
    "country": "PH",
    "name": "Calinaoan Malasin",
    "lat": "17.35189",
    "lng": "121.74074"
  },
  {
    "country": "PH",
    "name": "Calilayan",
    "lat": "13.8503",
    "lng": "121.93"
  },
  {
    "country": "PH",
    "name": "Calidñgan",
    "lat": "10.1",
    "lng": "123.63333"
  },
  {
    "country": "PH",
    "name": "Calibutbut",
    "lat": "15.11494",
    "lng": "120.59815"
  },
  {
    "country": "PH",
    "name": "Calibungan",
    "lat": "15.5982",
    "lng": "120.724"
  },
  {
    "country": "PH",
    "name": "Calero",
    "lat": "10.37331",
    "lng": "123.99786"
  },
  {
    "country": "PH",
    "name": "Calepaan",
    "lat": "16.0195",
    "lng": "120.619"
  },
  {
    "country": "PH",
    "name": "Calbiga",
    "lat": "11.62472",
    "lng": "125.01639"
  },
  {
    "country": "PH",
    "name": "Calbayog City",
    "lat": "12.0668",
    "lng": "124.5962"
  },
  {
    "country": "PH",
    "name": "Calayaan",
    "lat": "15.56739",
    "lng": "120.51434"
  },
  {
    "country": "PH",
    "name": "Calaya",
    "lat": "10.4916",
    "lng": "122.6255"
  },
  {
    "country": "PH",
    "name": "Calauan",
    "lat": "14.14989",
    "lng": "121.3152"
  },
  {
    "country": "PH",
    "name": "Calauag",
    "lat": "13.9575",
    "lng": "122.288"
  },
  {
    "country": "PH",
    "name": "Calauag",
    "lat": "10.66817",
    "lng": "119.5705"
  },
  {
    "country": "PH",
    "name": "Calatugas",
    "lat": "9.16898",
    "lng": "118.2235"
  },
  {
    "country": "PH",
    "name": "Calatrava",
    "lat": "12.6198",
    "lng": "122.0714"
  },
  {
    "country": "PH",
    "name": "Calatrava",
    "lat": "10.59496",
    "lng": "123.4838"
  },
  {
    "country": "PH",
    "name": "Calatagan",
    "lat": "13.83224",
    "lng": "120.63219"
  },
  {
    "country": "PH",
    "name": "Calatagan",
    "lat": "13.5885",
    "lng": "124.2065"
  },
  {
    "country": "PH",
    "name": "Calasiao",
    "lat": "16.0111",
    "lng": "120.36"
  },
  {
    "country": "PH",
    "name": "Calasgasan",
    "lat": "14.08333",
    "lng": "122.93333"
  },
  {
    "country": "PH",
    "name": "Calape",
    "lat": "10.2736",
    "lng": "122.9743"
  },
  {
    "country": "PH",
    "name": "Calape",
    "lat": "11.9425",
    "lng": "125.02139"
  },
  {
    "country": "PH",
    "name": "Calape",
    "lat": "11.1756",
    "lng": "124.0335"
  },
  {
    "country": "PH",
    "name": "Calape",
    "lat": "9.8922",
    "lng": "123.8748"
  },
  {
    "country": "PH",
    "name": "Calapan",
    "lat": "13.4117",
    "lng": "121.1803"
  },
  {
    "country": "PH",
    "name": "Calaoagan",
    "lat": "18.04279",
    "lng": "121.72325"
  },
  {
    "country": "PH",
    "name": "Calantas",
    "lat": "15.01933",
    "lng": "120.51793"
  },
  {
    "country": "PH",
    "name": "Calantas",
    "lat": "13.97202",
    "lng": "120.77456"
  },
  {
    "country": "PH",
    "name": "Calantac",
    "lat": "17.90904",
    "lng": "121.7228"
  },
  {
    "country": "PH",
    "name": "Calanogas",
    "lat": "7.75",
    "lng": "124.1"
  },
  {
    "country": "PH",
    "name": "Calangain",
    "lat": "14.89815",
    "lng": "120.55877"
  },
  {
    "country": "PH",
    "name": "Calancuasan Norte",
    "lat": "15.80137",
    "lng": "120.64102"
  },
  {
    "country": "PH",
    "name": "Calanasan",
    "lat": "18.255",
    "lng": "121.03444"
  },
  {
    "country": "PH",
    "name": "Calampisauan",
    "lat": "10.60985",
    "lng": "123.4765"
  },
  {
    "country": "PH",
    "name": "Calamba",
    "lat": "14.21167",
    "lng": "121.16528"
  },
  {
    "country": "PH",
    "name": "Calamba",
    "lat": "10.1755",
    "lng": "123.2826"
  },
  {
    "country": "PH",
    "name": "Calamba",
    "lat": "9.10361",
    "lng": "125.59417"
  },
  {
    "country": "PH",
    "name": "Calamba",
    "lat": "8.5587",
    "lng": "123.6425"
  },
  {
    "country": "PH",
    "name": "Calamagui East",
    "lat": "17.48815",
    "lng": "121.76845"
  },
  {
    "country": "PH",
    "name": "Calachuchi",
    "lat": "12.21775",
    "lng": "123.53061"
  },
  {
    "country": "PH",
    "name": "Calaca",
    "lat": "13.93244",
    "lng": "120.81327"
  },
  {
    "country": "PH",
    "name": "Calabugao",
    "lat": "8.45639",
    "lng": "125.15889"
  },
  {
    "country": "PH",
    "name": "Calabasa",
    "lat": "7.24639",
    "lng": "122.23417"
  },
  {
    "country": "PH",
    "name": "Calabanga",
    "lat": "13.7068",
    "lng": "123.2087"
  },
  {
    "country": "PH",
    "name": "Calabaca",
    "lat": "14.3001",
    "lng": "122.43364"
  },
  {
    "country": "PH",
    "name": "Calaba",
    "lat": "17.6178",
    "lng": "120.6162"
  },
  {
    "country": "PH",
    "name": "Calaba",
    "lat": "15.3005",
    "lng": "120.87423"
  },
  {
    "country": "PH",
    "name": "Cajimos",
    "lat": "12.59463",
    "lng": "122.27531"
  },
  {
    "country": "PH",
    "name": "Cajidiocan",
    "lat": "12.36696",
    "lng": "122.68141"
  },
  {
    "country": "PH",
    "name": "Cainta",
    "lat": "14.5786",
    "lng": "121.1222"
  },
  {
    "country": "PH",
    "name": "Caigangan",
    "lat": "13.25811",
    "lng": "121.93363"
  },
  {
    "country": "PH",
    "name": "Caibiran",
    "lat": "11.57167",
    "lng": "124.58222"
  },
  {
    "country": "PH",
    "name": "Cagwait",
    "lat": "8.91861",
    "lng": "126.30111"
  },
  {
    "country": "PH",
    "name": "Cagsiay",
    "lat": "14.21667",
    "lng": "121.75"
  },
  {
    "country": "PH",
    "name": "Cagmanaba",
    "lat": "13.05501",
    "lng": "123.29706"
  },
  {
    "country": "PH",
    "name": "Kaliliog",
    "lat": "13.9039",
    "lng": "123.2925"
  },
  {
    "country": "PH",
    "name": "Cagdianao",
    "lat": "9.92111",
    "lng": "125.66917"
  },
  {
    "country": "PH",
    "name": "Cagbang",
    "lat": "10.7",
    "lng": "122.49889"
  },
  {
    "country": "PH",
    "name": "Cagayan",
    "lat": "6.9747",
    "lng": "118.5144"
  },
  {
    "country": "PH",
    "name": "Cagayan de Oro",
    "lat": "8.48222",
    "lng": "124.64722"
  },
  {
    "country": "PH",
    "name": "Cagayancillo",
    "lat": "9.57694",
    "lng": "121.20722"
  },
  {
    "country": "PH",
    "name": "Cagamotan",
    "lat": "12.35583",
    "lng": "125.28391"
  },
  {
    "country": "PH",
    "name": "Cafe",
    "lat": "15.33686",
    "lng": "120.70623"
  },
  {
    "country": "PH",
    "name": "Cadlan",
    "lat": "13.5971",
    "lng": "123.257"
  },
  {
    "country": "PH",
    "name": "Cadiz",
    "lat": "10.9465",
    "lng": "123.288"
  },
  {
    "country": "PH",
    "name": "Caditaan",
    "lat": "12.80528",
    "lng": "123.84917"
  },
  {
    "country": "PH",
    "name": "Cadagmayan Norte",
    "lat": "10.81667",
    "lng": "122.5"
  },
  {
    "country": "PH",
    "name": "Cabuyao",
    "lat": "14.2726",
    "lng": "121.1262"
  },
  {
    "country": "PH",
    "name": "Cabusao",
    "lat": "13.7227",
    "lng": "123.1169"
  },
  {
    "country": "PH",
    "name": "Caburan",
    "lat": "5.91806",
    "lng": "125.64111"
  },
  {
    "country": "PH",
    "name": "Cabungan",
    "lat": "16.33999",
    "lng": "119.9949"
  },
  {
    "country": "PH",
    "name": "Cabulay",
    "lat": "16.74556",
    "lng": "121.4975"
  },
  {
    "country": "PH",
    "name": "Cabul-an",
    "lat": "10.15684",
    "lng": "124.04397"
  },
  {
    "country": "PH",
    "name": "Cabugao",
    "lat": "17.7931",
    "lng": "120.4578"
  },
  {
    "country": "PH",
    "name": "Cabugao",
    "lat": "13.5962",
    "lng": "124.2804"
  },
  {
    "country": "PH",
    "name": "Cabugao",
    "lat": "10.81028",
    "lng": "122.54472"
  },
  {
    "country": "PH",
    "name": "Cabucgayan",
    "lat": "11.47194",
    "lng": "124.575"
  },
  {
    "country": "PH",
    "name": "Cabra",
    "lat": "13.88833",
    "lng": "120.04944"
  },
  {
    "country": "PH",
    "name": "Cabog",
    "lat": "15.3153",
    "lng": "121.3703"
  },
  {
    "country": "PH",
    "name": "Kablalan",
    "lat": "5.77972",
    "lng": "125.19778"
  },
  {
    "country": "PH",
    "name": "Cabittaogan",
    "lat": "17.57788",
    "lng": "120.35914"
  },
  {
    "country": "PH",
    "name": "Cabitan",
    "lat": "12.29434",
    "lng": "123.34121"
  },
  {
    "country": "PH",
    "name": "Cabiraoan",
    "lat": "18.32377",
    "lng": "122.08595"
  },
  {
    "country": "PH",
    "name": "Cabinuangan",
    "lat": "7.68333",
    "lng": "126.03333"
  },
  {
    "country": "PH",
    "name": "Cabilauan",
    "lat": "10.89222",
    "lng": "122.65917"
  },
  {
    "country": "PH",
    "name": "Kabilauan",
    "lat": "10.861",
    "lng": "122.5734"
  },
  {
    "country": "PH",
    "name": "Cabilao",
    "lat": "11.5396",
    "lng": "123.1436"
  },
  {
    "country": "PH",
    "name": "Cabiguan",
    "lat": "12.90583",
    "lng": "123.73139"
  },
  {
    "country": "PH",
    "name": "Cabadiangan",
    "lat": "10.1459",
    "lng": "122.9431"
  },
  {
    "country": "PH",
    "name": "Cabiao",
    "lat": "15.2488",
    "lng": "120.8548"
  },
  {
    "country": "PH",
    "name": "Cabcaben",
    "lat": "14.454",
    "lng": "120.5914"
  },
  {
    "country": "PH",
    "name": "Cabcab",
    "lat": "13.6268",
    "lng": "124.0515"
  },
  {
    "country": "PH",
    "name": "Cabayaoasan",
    "lat": "15.66323",
    "lng": "120.55135"
  },
  {
    "country": "PH",
    "name": "Cabayangan",
    "lat": "7.40722",
    "lng": "125.73306"
  },
  {
    "country": "PH",
    "name": "Cabay",
    "lat": "13.8708",
    "lng": "121.37992"
  },
  {
    "country": "PH",
    "name": "Cabay",
    "lat": "11.44556",
    "lng": "125.49333"
  },
  {
    "country": "PH",
    "name": "Cabatuan",
    "lat": "16.95655",
    "lng": "121.66854"
  },
  {
    "country": "PH",
    "name": "Cabatuan",
    "lat": "12.5228",
    "lng": "125.2202"
  },
  {
    "country": "PH",
    "name": "Cabatuan",
    "lat": "10.8794",
    "lng": "122.486"
  },
  {
    "country": "PH",
    "name": "Cabatang",
    "lat": "13.9669",
    "lng": "121.3668"
  },
  {
    "country": "PH",
    "name": "Cabarroguis",
    "lat": "16.51105",
    "lng": "121.52118"
  },
  {
    "country": "PH",
    "name": "Cabaritan East",
    "lat": "18.41781",
    "lng": "121.48872"
  },
  {
    "country": "PH",
    "name": "Cabano",
    "lat": "10.5869",
    "lng": "122.7002"
  },
  {
    "country": "PH",
    "name": "Cabannungan Second",
    "lat": "17.1249",
    "lng": "121.8506"
  },
  {
    "country": "PH",
    "name": "Cabanglasan",
    "lat": "8.12139",
    "lng": "125.3275"
  },
  {
    "country": "PH",
    "name": "Cabangan",
    "lat": "15.158",
    "lng": "120.0569"
  },
  {
    "country": "PH",
    "name": "Cabangahan",
    "lat": "9.0781",
    "lng": "122.9469"
  },
  {
    "country": "PH",
    "name": "Cabangahan",
    "lat": "8.02278",
    "lng": "125.1375"
  },
  {
    "country": "PH",
    "name": "Cabanbanan",
    "lat": "14.2404",
    "lng": "121.4341"
  },
  {
    "country": "PH",
    "name": "Cabanbanan",
    "lat": "10.0852",
    "lng": "122.9579"
  },
  {
    "country": "PH",
    "name": "Cabanatuan City",
    "lat": "15.48586",
    "lng": "120.96648"
  },
  {
    "country": "PH",
    "name": "Cabaluay",
    "lat": "7.00139",
    "lng": "122.18028"
  },
  {
    "country": "PH",
    "name": "Cabalitian",
    "lat": "16.0883",
    "lng": "120.7922"
  },
  {
    "country": "PH",
    "name": "Cabalawan",
    "lat": "10.74139",
    "lng": "123.9525"
  },
  {
    "country": "PH",
    "name": "Cabalaoangan",
    "lat": "15.98333",
    "lng": "120.78333"
  },
  {
    "country": "PH",
    "name": "Kabac",
    "lat": "11.2353",
    "lng": "123.6979"
  },
  {
    "country": "PH",
    "name": "Cabognon",
    "lat": "13.1829",
    "lng": "123.6777"
  },
  {
    "country": "PH",
    "name": "Cabagan",
    "lat": "17.42782",
    "lng": "121.76955"
  },
  {
    "country": "PH",
    "name": "Cabodiongan",
    "lat": "12.6643",
    "lng": "125.0456"
  },
  {
    "country": "PH",
    "name": "Cabadiangan",
    "lat": "9.7534",
    "lng": "122.4739"
  },
  {
    "country": "PH",
    "name": "Cabadbaran",
    "lat": "9.12261",
    "lng": "125.53549"
  },
  {
    "country": "PH",
    "name": "Cabacuñgan",
    "lat": "10.93333",
    "lng": "124.98167"
  },
  {
    "country": "PH",
    "name": "Cabacungan",
    "lat": "10.3237",
    "lng": "123.1331"
  },
  {
    "country": "PH",
    "name": "Cabacao",
    "lat": "13.3356",
    "lng": "120.6588"
  },
  {
    "country": "PH",
    "name": "Caba",
    "lat": "16.4316",
    "lng": "120.3446"
  },
  {
    "country": "PH",
    "name": "Caabiangan",
    "lat": "16.0874",
    "lng": "119.9245"
  },
  {
    "country": "PH",
    "name": "Buyuan",
    "lat": "10.67086",
    "lng": "122.3574"
  },
  {
    "country": "PH",
    "name": "Buyo",
    "lat": "13.6813",
    "lng": "123.4733"
  },
  {
    "country": "PH",
    "name": "Buyo",
    "lat": "13.1144",
    "lng": "123.8666"
  },
  {
    "country": "PH",
    "name": "Buyabod",
    "lat": "13.4666",
    "lng": "122.0526"
  },
  {
    "country": "PH",
    "name": "Buug",
    "lat": "7.7294",
    "lng": "123.0598"
  },
  {
    "country": "PH",
    "name": "Butulan",
    "lat": "5.61444",
    "lng": "125.43167"
  },
  {
    "country": "PH",
    "name": "Butubut Norte",
    "lat": "16.8034",
    "lng": "120.4344"
  },
  {
    "country": "PH",
    "name": "Butuan",
    "lat": "8.94917",
    "lng": "125.54361"
  },
  {
    "country": "PH",
    "name": "Butigui",
    "lat": "17.11534",
    "lng": "121.43304"
  },
  {
    "country": "PH",
    "name": "Butig",
    "lat": "7.72444",
    "lng": "124.30083"
  },
  {
    "country": "PH",
    "name": "Butazon",
    "lat": "11.3072",
    "lng": "124.462"
  },
  {
    "country": "PH",
    "name": "Butag",
    "lat": "12.6292",
    "lng": "123.9335"
  },
  {
    "country": "PH",
    "name": "Busuanga",
    "lat": "12.15847",
    "lng": "119.91781"
  },
  {
    "country": "PH",
    "name": "Brgy. New Buswang, Kalibo",
    "lat": "11.71222",
    "lng": "122.38472"
  },
  {
    "country": "PH",
    "name": "Bustos",
    "lat": "14.95806",
    "lng": "120.91778"
  },
  {
    "country": "PH",
    "name": "Busing",
    "lat": "13.15139",
    "lng": "122.97139"
  },
  {
    "country": "PH",
    "name": "Busilak",
    "lat": "16.4775",
    "lng": "121.1241"
  },
  {
    "country": "PH",
    "name": "Busdi",
    "lat": "8.27611",
    "lng": "125.25139"
  },
  {
    "country": "PH",
    "name": "Busay",
    "lat": "10.5378",
    "lng": "122.886"
  },
  {
    "country": "PH",
    "name": "Boroon",
    "lat": "8.18278",
    "lng": "124.17701"
  },
  {
    "country": "PH",
    "name": "Barurao",
    "lat": "6.89806",
    "lng": "124.5975"
  },
  {
    "country": "PH",
    "name": "Buruanga",
    "lat": "11.84428",
    "lng": "121.88841"
  },
  {
    "country": "PH",
    "name": "Burirao",
    "lat": "9.2",
    "lng": "118.1"
  },
  {
    "country": "PH",
    "name": "Burias",
    "lat": "11.4463",
    "lng": "122.5497"
  },
  {
    "country": "PH",
    "name": "Burias",
    "lat": "5.71778",
    "lng": "125.25361"
  },
  {
    "country": "PH",
    "name": "Burgos",
    "lat": "18.51658",
    "lng": "120.64492"
  },
  {
    "country": "PH",
    "name": "Burgos",
    "lat": "17.3324",
    "lng": "120.4954"
  },
  {
    "country": "PH",
    "name": "Burgos",
    "lat": "17.08914",
    "lng": "121.70254"
  },
  {
    "country": "PH",
    "name": "Burgos",
    "lat": "16.8246",
    "lng": "121.73313"
  },
  {
    "country": "PH",
    "name": "Burgos",
    "lat": "16.51861",
    "lng": "120.46278"
  },
  {
    "country": "PH",
    "name": "Burgos",
    "lat": "16.07181",
    "lng": "121.04954"
  },
  {
    "country": "PH",
    "name": "Burgos",
    "lat": "16.0583",
    "lng": "119.865"
  },
  {
    "country": "PH",
    "name": "Burgos",
    "lat": "15.72892",
    "lng": "120.57224"
  },
  {
    "country": "PH",
    "name": "Burgos",
    "lat": "15.49465",
    "lng": "120.40453"
  },
  {
    "country": "PH",
    "name": "Burgos",
    "lat": "9.26639",
    "lng": "126.18833"
  },
  {
    "country": "PH",
    "name": "Burdeos",
    "lat": "14.84302",
    "lng": "121.96906"
  },
  {
    "country": "PH",
    "name": "Buray",
    "lat": "10.715",
    "lng": "122.45944"
  },
  {
    "country": "PH",
    "name": "Burauen",
    "lat": "10.97556",
    "lng": "124.89278"
  },
  {
    "country": "PH",
    "name": "Buracan",
    "lat": "13.6",
    "lng": "123.5"
  },
  {
    "country": "PH",
    "name": "Burabod",
    "lat": "13.2686",
    "lng": "123.4162"
  },
  {
    "country": "PH",
    "name": "Bukid",
    "lat": "5.57167",
    "lng": "125.40556"
  },
  {
    "country": "PH",
    "name": "Bunol",
    "lat": "15.6671",
    "lng": "120.8344"
  },
  {
    "country": "PH",
    "name": "Bunog",
    "lat": "9.14028",
    "lng": "117.78167"
  },
  {
    "country": "PH",
    "name": "Bungoy",
    "lat": "13.99779",
    "lng": "121.36564"
  },
  {
    "country": "PH",
    "name": "Bunguiao",
    "lat": "7.10444",
    "lng": "122.19639"
  },
  {
    "country": "PH",
    "name": "Bungahan",
    "lat": "13.94286",
    "lng": "120.66178"
  },
  {
    "country": "PH",
    "name": "Bunga",
    "lat": "11.4838",
    "lng": "124.5918"
  },
  {
    "country": "PH",
    "name": "Bunga",
    "lat": "10.7731",
    "lng": "124.7847"
  },
  {
    "country": "PH",
    "name": "Bundoc",
    "lat": "15.48575",
    "lng": "120.71743"
  },
  {
    "country": "PH",
    "name": "Buawan",
    "lat": "8.31667",
    "lng": "124.30306"
  },
  {
    "country": "PH",
    "name": "Bunawan",
    "lat": "8.16722",
    "lng": "125.99083"
  },
  {
    "country": "PH",
    "name": "Bumbaran",
    "lat": "7.8",
    "lng": "124.65"
  },
  {
    "country": "PH",
    "name": "Brgy. Bulwang, Numancia",
    "lat": "11.72194",
    "lng": "122.36111"
  },
  {
    "country": "PH",
    "name": "Bulusan",
    "lat": "12.74936",
    "lng": "124.12087"
  },
  {
    "country": "PH",
    "name": "Buluangan",
    "lat": "10.38707",
    "lng": "123.3381"
  },
  {
    "country": "PH",
    "name": "Buluang",
    "lat": "13.3068",
    "lng": "123.3425"
  },
  {
    "country": "PH",
    "name": "Buluang",
    "lat": "12.23336",
    "lng": "119.87581"
  },
  {
    "country": "PH",
    "name": "Buluan",
    "lat": "6.72028",
    "lng": "124.80194"
  },
  {
    "country": "PH",
    "name": "Bulualto",
    "lat": "15.22127",
    "lng": "120.95326"
  },
  {
    "country": "PH",
    "name": "Bulu",
    "lat": "17.33333",
    "lng": "121.76667"
  },
  {
    "country": "PH",
    "name": "Bulog",
    "lat": "15.9602",
    "lng": "120.4017"
  },
  {
    "country": "PH",
    "name": "Bulod",
    "lat": "9.68333",
    "lng": "123.15"
  },
  {
    "country": "PH",
    "name": "Buliwao",
    "lat": "16.48333",
    "lng": "121.23333"
  },
  {
    "country": "PH",
    "name": "Bulit",
    "lat": "7.11528",
    "lng": "124.78944"
  },
  {
    "country": "PH",
    "name": "Buliran Segundo",
    "lat": "15.26667",
    "lng": "120.86667"
  },
  {
    "country": "PH",
    "name": "Buliran",
    "lat": "15.54602",
    "lng": "120.95959"
  },
  {
    "country": "PH",
    "name": "Buliok",
    "lat": "7.01667",
    "lng": "124.7"
  },
  {
    "country": "PH",
    "name": "Bulihan",
    "lat": "14.87581",
    "lng": "120.89563"
  },
  {
    "country": "PH",
    "name": "Bulihan",
    "lat": "14.156",
    "lng": "120.6441"
  },
  {
    "country": "PH",
    "name": "Bulihan",
    "lat": "13.8091",
    "lng": "121.2485"
  },
  {
    "country": "PH",
    "name": "Buldon",
    "lat": "7.50972",
    "lng": "124.37139"
  },
  {
    "country": "PH",
    "name": "Bulaon",
    "lat": "15.08262",
    "lng": "120.66288"
  },
  {
    "country": "PH",
    "name": "Bulatukan",
    "lat": "6.9025",
    "lng": "125.16083"
  },
  {
    "country": "PH",
    "name": "Bulata",
    "lat": "9.8599",
    "lng": "122.4016"
  },
  {
    "country": "PH",
    "name": "Bulasa",
    "lat": "9.93206",
    "lng": "123.61802"
  },
  {
    "country": "PH",
    "name": "Bularit",
    "lat": "15.56824",
    "lng": "120.62167"
  },
  {
    "country": "PH",
    "name": "Bolanon",
    "lat": "10.9171",
    "lng": "123.4734"
  },
  {
    "country": "PH",
    "name": "Bulan",
    "lat": "12.67139",
    "lng": "123.875"
  },
  {
    "country": "PH",
    "name": "Bulalacao",
    "lat": "12.32535",
    "lng": "121.34351"
  },
  {
    "country": "PH",
    "name": "Bulalacao",
    "lat": "16.8358",
    "lng": "120.8085"
  },
  {
    "country": "PH",
    "name": "Bulalacao",
    "lat": "11.7435",
    "lng": "120.1715"
  },
  {
    "country": "PH",
    "name": "Bulad",
    "lat": "10.2548",
    "lng": "122.9983"
  },
  {
    "country": "PH",
    "name": "Bulacnin",
    "lat": "13.9903",
    "lng": "121.139"
  },
  {
    "country": "PH",
    "name": "Bulacan",
    "lat": "14.79278",
    "lng": "120.87889"
  },
  {
    "country": "PH",
    "name": "Bulacan",
    "lat": "6.5675",
    "lng": "125.42111"
  },
  {
    "country": "PH",
    "name": "Bula",
    "lat": "13.4701",
    "lng": "123.278"
  },
  {
    "country": "PH",
    "name": "Bula",
    "lat": "11.448",
    "lng": "122.5685"
  },
  {
    "country": "PH",
    "name": "Bukal Sur",
    "lat": "13.93806",
    "lng": "121.38556"
  },
  {
    "country": "PH",
    "name": "Bukal",
    "lat": "13.9132",
    "lng": "121.5264"
  },
  {
    "country": "PH",
    "name": "Bukal",
    "lat": "13.8364",
    "lng": "121.0939"
  },
  {
    "country": "PH",
    "name": "Buhi",
    "lat": "13.4322",
    "lng": "123.517"
  },
  {
    "country": "PH",
    "name": "Buhatan",
    "lat": "12.9755",
    "lng": "124.0478"
  },
  {
    "country": "PH",
    "name": "Buhangin",
    "lat": "6.49111",
    "lng": "125.5475"
  },
  {
    "country": "PH",
    "name": "Buguias",
    "lat": "16.72267",
    "lng": "120.82834"
  },
  {
    "country": "PH",
    "name": "Buguey",
    "lat": "18.28823",
    "lng": "121.8331"
  },
  {
    "country": "PH",
    "name": "Bugsoc",
    "lat": "9.7834",
    "lng": "124.2712"
  },
  {
    "country": "PH",
    "name": "Bugo",
    "lat": "8.50833",
    "lng": "124.75944"
  },
  {
    "country": "PH",
    "name": "Bugko",
    "lat": "12.5356",
    "lng": "124.7923"
  },
  {
    "country": "PH",
    "name": "Bugcaon",
    "lat": "8.04583",
    "lng": "125.11278"
  },
  {
    "country": "PH",
    "name": "Bugasong",
    "lat": "11.04464",
    "lng": "122.06463"
  },
  {
    "country": "PH",
    "name": "Bugasan",
    "lat": "7.44083",
    "lng": "124.25917"
  },
  {
    "country": "PH",
    "name": "Bugas",
    "lat": "9.89804",
    "lng": "123.40492"
  },
  {
    "country": "PH",
    "name": "Bugang",
    "lat": "10.74185",
    "lng": "123.3933"
  },
  {
    "country": "PH",
    "name": "Bugallon",
    "lat": "15.9528",
    "lng": "120.2155"
  },
  {
    "country": "PH",
    "name": "Bugaan",
    "lat": "14.03987",
    "lng": "120.93609"
  },
  {
    "country": "PH",
    "name": "Buga",
    "lat": "13.2966",
    "lng": "123.3596"
  },
  {
    "country": "PH",
    "name": "Buga",
    "lat": "10.71667",
    "lng": "122.26667"
  },
  {
    "country": "PH",
    "name": "Buensuseso",
    "lat": "15.19333",
    "lng": "120.67314"
  },
  {
    "country": "PH",
    "name": "Buenlag",
    "lat": "15.82976",
    "lng": "120.51139"
  },
  {
    "country": "PH",
    "name": "Buenlag",
    "lat": "15.62743",
    "lng": "120.58199"
  },
  {
    "country": "PH",
    "name": "Buenavista",
    "lat": "10.08333",
    "lng": "124.11611"
  },
  {
    "country": "PH",
    "name": "Buenavista",
    "lat": "13.867",
    "lng": "123.302"
  },
  {
    "country": "PH",
    "name": "Buenavista",
    "lat": "13.25511",
    "lng": "121.94149"
  },
  {
    "country": "PH",
    "name": "Buenavista",
    "lat": "12.17639",
    "lng": "123.79056"
  },
  {
    "country": "PH",
    "name": "Buenavista",
    "lat": "10.79874",
    "lng": "123.5544"
  },
  {
    "country": "PH",
    "name": "Buenavista",
    "lat": "10.70111",
    "lng": "122.6275"
  },
  {
    "country": "PH",
    "name": "Buenavista",
    "lat": "10.61466",
    "lng": "123.0994"
  },
  {
    "country": "PH",
    "name": "Buenavista",
    "lat": "10.54406",
    "lng": "123.4478"
  },
  {
    "country": "PH",
    "name": "Buenavista",
    "lat": "10.1776",
    "lng": "123.6013"
  },
  {
    "country": "PH",
    "name": "Buenavista",
    "lat": "10.1379",
    "lng": "123.2439"
  },
  {
    "country": "PH",
    "name": "Buenavista",
    "lat": "9.84056",
    "lng": "124.2225"
  },
  {
    "country": "PH",
    "name": "Buenavista",
    "lat": "9.115",
    "lng": "126.16083"
  },
  {
    "country": "PH",
    "name": "Buenavista",
    "lat": "8.97694",
    "lng": "125.40889"
  },
  {
    "country": "PH",
    "name": "Buenavista",
    "lat": "7.23611",
    "lng": "122.25528"
  },
  {
    "country": "PH",
    "name": "Bued",
    "lat": "16.16086",
    "lng": "119.9988"
  },
  {
    "country": "PH",
    "name": "Bued",
    "lat": "15.83657",
    "lng": "120.65006"
  },
  {
    "country": "PH",
    "name": "Budta",
    "lat": "7.20417",
    "lng": "124.43972"
  },
  {
    "country": "PH",
    "name": "Bucloc",
    "lat": "17.44113",
    "lng": "120.85885"
  },
  {
    "country": "PH",
    "name": "Buclad",
    "lat": "7.52778",
    "lng": "125.75056"
  },
  {
    "country": "PH",
    "name": "Bukay Pait",
    "lat": "6.56161",
    "lng": "124.76706"
  },
  {
    "country": "PH",
    "name": "Bucay",
    "lat": "17.5404",
    "lng": "120.7188"
  },
  {
    "country": "PH",
    "name": "Babug",
    "lat": "12.37325",
    "lng": "121.04171"
  },
  {
    "country": "PH",
    "name": "Buayan",
    "lat": "6.11639",
    "lng": "125.23472"
  },
  {
    "country": "PH",
    "name": "Buanoy",
    "lat": "10.46746",
    "lng": "123.6999"
  },
  {
    "country": "PH",
    "name": "Buang",
    "lat": "13.3115",
    "lng": "123.6421"
  },
  {
    "country": "PH",
    "name": "Bualan",
    "lat": "7.75",
    "lng": "124.26667"
  },
  {
    "country": "PH",
    "name": "Bual",
    "lat": "7.1825",
    "lng": "124.50583"
  },
  {
    "country": "PH",
    "name": "Bual",
    "lat": "6.79583",
    "lng": "124.91083"
  },
  {
    "country": "PH",
    "name": "Buagsong",
    "lat": "10.25302",
    "lng": "123.93909"
  },
  {
    "country": "PH",
    "name": "Buadiposo-Buntong",
    "lat": "7.96667",
    "lng": "124.38333"
  },
  {
    "country": "PH",
    "name": "Boton",
    "lat": "12.9287",
    "lng": "124.0479"
  },
  {
    "country": "PH",
    "name": "Botolan",
    "lat": "15.2896",
    "lng": "120.0245"
  },
  {
    "country": "PH",
    "name": "Botigues",
    "lat": "11.0995",
    "lng": "123.6675"
  },
  {
    "country": "PH",
    "name": "Botao",
    "lat": "15.91667",
    "lng": "120.41667"
  },
  {
    "country": "PH",
    "name": "Boston",
    "lat": "7.87111",
    "lng": "126.36417"
  },
  {
    "country": "PH",
    "name": "Bosdak",
    "lat": "13.4",
    "lng": "122.5"
  },
  {
    "country": "PH",
    "name": "Borongan",
    "lat": "11.60806",
    "lng": "125.43194"
  },
  {
    "country": "PH",
    "name": "Yapak",
    "lat": "11.95",
    "lng": "121.93333"
  },
  {
    "country": "PH",
    "name": "Borbon",
    "lat": "10.838",
    "lng": "124.0297"
  },
  {
    "country": "PH",
    "name": "Borbon",
    "lat": "8.48417",
    "lng": "125.89306"
  },
  {
    "country": "PH",
    "name": "Boot",
    "lat": "14.04556",
    "lng": "121.07722"
  },
  {
    "country": "PH",
    "name": "Bood",
    "lat": "9.74508",
    "lng": "123.82783"
  },
  {
    "country": "PH",
    "name": "Bontoc",
    "lat": "17.08731",
    "lng": "120.97685"
  },
  {
    "country": "PH",
    "name": "Bontoc",
    "lat": "10.3556",
    "lng": "124.9697"
  },
  {
    "country": "PH",
    "name": "Bongued",
    "lat": "7.11667",
    "lng": "124.4"
  },
  {
    "country": "PH",
    "name": "Bungsuan",
    "lat": "11.2404",
    "lng": "122.6976"
  },
  {
    "country": "PH",
    "name": "Bongao",
    "lat": "5.02917",
    "lng": "119.77306"
  },
  {
    "country": "PH",
    "name": "Boñgalon",
    "lat": "16.00022",
    "lng": "120.15904"
  },
  {
    "country": "PH",
    "name": "Bungabon",
    "lat": "7.2221",
    "lng": "125.8731"
  },
  {
    "country": "PH",
    "name": "Bongabon",
    "lat": "15.6321",
    "lng": "121.1448"
  },
  {
    "country": "PH",
    "name": "Bonga",
    "lat": "13.2799",
    "lng": "123.7587"
  },
  {
    "country": "PH",
    "name": "Bonga",
    "lat": "13.21667",
    "lng": "123.55"
  },
  {
    "country": "PH",
    "name": "Bone South",
    "lat": "16.2446",
    "lng": "120.9958"
  },
  {
    "country": "PH",
    "name": "Bonbon",
    "lat": "10.2245",
    "lng": "123.5573"
  },
  {
    "country": "PH",
    "name": "Bonawon",
    "lat": "9.134",
    "lng": "122.9193"
  },
  {
    "country": "PH",
    "name": "Bombon",
    "lat": "13.6887",
    "lng": "123.2077"
  },
  {
    "country": "PH",
    "name": "Bolong",
    "lat": "10.81667",
    "lng": "122.51667"
  },
  {
    "country": "PH",
    "name": "Bolong",
    "lat": "7.09833",
    "lng": "122.23917"
  },
  {
    "country": "PH",
    "name": "Bolo Bolo",
    "lat": "8.55833",
    "lng": "124.53"
  },
  {
    "country": "PH",
    "name": "Bolo",
    "lat": "15.9948",
    "lng": "120.1647"
  },
  {
    "country": "PH",
    "name": "Bolo",
    "lat": "13.78991",
    "lng": "120.98173"
  },
  {
    "country": "PH",
    "name": "Bolo",
    "lat": "13.753",
    "lng": "122.9658"
  },
  {
    "country": "PH",
    "name": "Bulo",
    "lat": "12.4109",
    "lng": "123.5672"
  },
  {
    "country": "PH",
    "name": "Bolo",
    "lat": "11.54028",
    "lng": "122.75722"
  },
  {
    "country": "PH",
    "name": "Boljoon",
    "lat": "9.6281",
    "lng": "123.4785"
  },
  {
    "country": "PH",
    "name": "Bolitoc",
    "lat": "15.7395",
    "lng": "119.8769"
  },
  {
    "country": "PH",
    "name": "Bolisong",
    "lat": "9.69111",
    "lng": "123.15167"
  },
  {
    "country": "PH",
    "name": "Bolingit",
    "lat": "15.95873",
    "lng": "120.3496"
  },
  {
    "country": "PH",
    "name": "Boliney",
    "lat": "17.40773",
    "lng": "120.78115"
  },
  {
    "country": "PH",
    "name": "Bolinao",
    "lat": "16.3883",
    "lng": "119.8923"
  },
  {
    "country": "PH",
    "name": "Bolilao",
    "lat": "10.88333",
    "lng": "122.73333"
  },
  {
    "country": "PH",
    "name": "Bolila",
    "lat": "6.37167",
    "lng": "125.57139"
  },
  {
    "country": "PH",
    "name": "Bolboc",
    "lat": "14.02074",
    "lng": "120.75595"
  },
  {
    "country": "PH",
    "name": "Bulawin",
    "lat": "15.4173",
    "lng": "119.9564"
  },
  {
    "country": "PH",
    "name": "Bolaoit",
    "lat": "15.93218",
    "lng": "120.43073"
  },
  {
    "country": "PH",
    "name": "Bokod",
    "lat": "16.4895",
    "lng": "120.8313"
  },
  {
    "country": "PH",
    "name": "Bogtong",
    "lat": "15.75536",
    "lng": "120.32899"
  },
  {
    "country": "PH",
    "name": "Bogo",
    "lat": "11.0517",
    "lng": "124.0055"
  },
  {
    "country": "PH",
    "name": "Bogo",
    "lat": "9.85686",
    "lng": "123.56417"
  },
  {
    "country": "PH",
    "name": "Bodega",
    "lat": "14.9229",
    "lng": "120.47982"
  },
  {
    "country": "PH",
    "name": "Bocos",
    "lat": "16.92646",
    "lng": "121.05734"
  },
  {
    "country": "PH",
    "name": "Bocaue",
    "lat": "14.79833",
    "lng": "120.92611"
  },
  {
    "country": "PH",
    "name": "Bocana",
    "lat": "10.0116",
    "lng": "122.7217"
  },
  {
    "country": "PH",
    "name": "Bobon Second",
    "lat": "15.65653",
    "lng": "120.38119"
  },
  {
    "country": "PH",
    "name": "Bobonan",
    "lat": "16.1348",
    "lng": "120.5271"
  },
  {
    "country": "PH",
    "name": "Bobon",
    "lat": "12.5246",
    "lng": "124.5636"
  },
  {
    "country": "PH",
    "name": "Bobon",
    "lat": "6.86782",
    "lng": "126.32838"
  },
  {
    "country": "PH",
    "name": "Buayan",
    "lat": "7.26111",
    "lng": "124.52944"
  },
  {
    "country": "PH",
    "name": "Buan",
    "lat": "5.1608",
    "lng": "120.0426"
  },
  {
    "country": "PH",
    "name": "Boac",
    "lat": "13.4463",
    "lng": "121.84"
  },
  {
    "country": "PH",
    "name": "Blinsung",
    "lat": "7.01806",
    "lng": "124.18056"
  },
  {
    "country": "PH",
    "name": "Blingkong",
    "lat": "6.58808",
    "lng": "124.88951"
  },
  {
    "country": "PH",
    "name": "Biwang",
    "lat": "6.60592",
    "lng": "124.54358"
  },
  {
    "country": "PH",
    "name": "Bituñgol",
    "lat": "14.88333",
    "lng": "121.03333"
  },
  {
    "country": "PH",
    "name": "Biton",
    "lat": "11.23279",
    "lng": "123.9993"
  },
  {
    "country": "PH",
    "name": "Bitoon",
    "lat": "10.0804",
    "lng": "123.4587"
  },
  {
    "country": "PH",
    "name": "Bitin",
    "lat": "14.11647",
    "lng": "121.22194"
  },
  {
    "country": "PH",
    "name": "Bitaogan",
    "lat": "6.76842",
    "lng": "126.07738"
  },
  {
    "country": "PH",
    "name": "Bitanjuan",
    "lat": "10.5955",
    "lng": "124.7663"
  },
  {
    "country": "PH",
    "name": "Bitangan",
    "lat": "14.25389",
    "lng": "120.87833"
  },
  {
    "country": "PH",
    "name": "Bitag Grande",
    "lat": "17.90244",
    "lng": "121.85013"
  },
  {
    "country": "PH",
    "name": "Bitadtun",
    "lat": "11.4969",
    "lng": "122.08511"
  },
  {
    "country": "PH",
    "name": "Bislig",
    "lat": "11.0725",
    "lng": "125.03361"
  },
  {
    "country": "PH",
    "name": "Bislig",
    "lat": "8.21528",
    "lng": "126.31639"
  },
  {
    "country": "PH",
    "name": "Biri",
    "lat": "12.68333",
    "lng": "124.36361"
  },
  {
    "country": "PH",
    "name": "Binantocan",
    "lat": "11.4073",
    "lng": "122.8602"
  },
  {
    "country": "PH",
    "name": "Binulasan",
    "lat": "14.73159",
    "lng": "121.69781"
  },
  {
    "country": "PH",
    "name": "Binucayan",
    "lat": "8.25",
    "lng": "125.71667"
  },
  {
    "country": "PH",
    "name": "Binubusan",
    "lat": "13.96947",
    "lng": "120.63572"
  },
  {
    "country": "PH",
    "name": "Binuangan",
    "lat": "8.91528",
    "lng": "124.78833"
  },
  {
    "country": "PH",
    "name": "Bintawan",
    "lat": "16.57588",
    "lng": "121.18764"
  },
  {
    "country": "PH",
    "name": "Bintacay",
    "lat": "13.4986",
    "lng": "121.8768"
  },
  {
    "country": "PH",
    "name": "Binonga",
    "lat": "10.7719",
    "lng": "122.9817"
  },
  {
    "country": "PH",
    "name": "Binon-an",
    "lat": "11.3947",
    "lng": "123.1426"
  },
  {
    "country": "PH",
    "name": "Binodegahan",
    "lat": "13.0614",
    "lng": "123.4579"
  },
  {
    "country": "PH",
    "name": "Binmaley",
    "lat": "16.03232",
    "lng": "120.26904"
  },
  {
    "country": "PH",
    "name": "Binlod",
    "lat": "9.91845",
    "lng": "123.60743"
  },
  {
    "country": "PH",
    "name": "Binitinan",
    "lat": "8.71",
    "lng": "124.77556"
  },
  {
    "country": "PH",
    "name": "Binitayan",
    "lat": "13.2945",
    "lng": "123.7579"
  },
  {
    "country": "PH",
    "name": "Binidayan",
    "lat": "7.80668",
    "lng": "124.16846"
  },
  {
    "country": "PH",
    "name": "Binguang",
    "lat": "17.45893",
    "lng": "121.79519"
  },
  {
    "country": "PH",
    "name": "Bingawan",
    "lat": "11.233",
    "lng": "122.5672"
  },
  {
    "country": "PH",
    "name": "Payabon",
    "lat": "9.759",
    "lng": "123.1412"
  },
  {
    "country": "PH",
    "name": "Binday",
    "lat": "16.12812",
    "lng": "120.45238"
  },
  {
    "country": "PH",
    "name": "Bincoñgan",
    "lat": "7.36667",
    "lng": "125.75"
  },
  {
    "country": "PH",
    "name": "Binay",
    "lat": "13.5019",
    "lng": "122.5983"
  },
  {
    "country": "PH",
    "name": "Binanwanaan",
    "lat": "13.7",
    "lng": "123.3"
  },
  {
    "country": "PH",
    "name": "Binangonan",
    "lat": "14.4646",
    "lng": "121.1929"
  },
  {
    "country": "PH",
    "name": "Biñan",
    "lat": "14.34267",
    "lng": "121.08071"
  },
  {
    "country": "PH",
    "name": "Binalonan",
    "lat": "16.0503",
    "lng": "120.5926"
  },
  {
    "country": "PH",
    "name": "Binalbagan",
    "lat": "10.1948",
    "lng": "122.8581"
  },
  {
    "country": "PH",
    "name": "Binalan",
    "lat": "18.3275",
    "lng": "121.5451"
  },
  {
    "country": "PH",
    "name": "Binahaan",
    "lat": "13.9917",
    "lng": "121.75391"
  },
  {
    "country": "PH",
    "name": "Binabalian",
    "lat": "16.4202",
    "lng": "119.9279"
  },
  {
    "country": "PH",
    "name": "Binabaan",
    "lat": "11.0191",
    "lng": "122.5221"
  },
  {
    "country": "PH",
    "name": "Bilwang",
    "lat": "10.8834",
    "lng": "124.4667"
  },
  {
    "country": "PH",
    "name": "Bilog-Bilog",
    "lat": "14.11361",
    "lng": "121.08861"
  },
  {
    "country": "PH",
    "name": "Bil-Loca",
    "lat": "18.0875",
    "lng": "120.5687"
  },
  {
    "country": "PH",
    "name": "Biliran",
    "lat": "11.46694",
    "lng": "124.47396"
  },
  {
    "country": "PH",
    "name": "Bilaran",
    "lat": "14.03528",
    "lng": "120.71028"
  },
  {
    "country": "PH",
    "name": "Bilar",
    "lat": "9.70825",
    "lng": "124.10717"
  },
  {
    "country": "PH",
    "name": "Bilao",
    "lat": "11.488",
    "lng": "122.5599"
  },
  {
    "country": "PH",
    "name": "Bilad",
    "lat": "15.73676",
    "lng": "120.43321"
  },
  {
    "country": "PH",
    "name": "Biking",
    "lat": "9.59382",
    "lng": "123.84303"
  },
  {
    "country": "PH",
    "name": "Bignay Uno",
    "lat": "13.86445",
    "lng": "121.48792"
  },
  {
    "country": "PH",
    "name": "Bigaan",
    "lat": "8.31722",
    "lng": "126.28111"
  },
  {
    "country": "PH",
    "name": "Bigaa",
    "lat": "13.1993",
    "lng": "123.7566"
  },
  {
    "country": "PH",
    "name": "Biga",
    "lat": "14.25759",
    "lng": "120.97195"
  },
  {
    "country": "PH",
    "name": "Biga",
    "lat": "13.3106",
    "lng": "121.161"
  },
  {
    "country": "PH",
    "name": "Biga",
    "lat": "8.35778",
    "lng": "124.25972"
  },
  {
    "country": "PH",
    "name": "Bien Unido",
    "lat": "10.13729",
    "lng": "124.37761"
  },
  {
    "country": "PH",
    "name": "Bicos",
    "lat": "15.6602",
    "lng": "121.0414"
  },
  {
    "country": "PH",
    "name": "Bibiclat",
    "lat": "15.52186",
    "lng": "120.86235"
  },
  {
    "country": "PH",
    "name": "Bical Norte",
    "lat": "15.81471",
    "lng": "120.43509"
  },
  {
    "country": "PH",
    "name": "Biasong",
    "lat": "10.5229",
    "lng": "123.736"
  },
  {
    "country": "PH",
    "name": "Biao",
    "lat": "10.1088",
    "lng": "122.9772"
  },
  {
    "country": "PH",
    "name": "Biao",
    "lat": "7.16333",
    "lng": "125.52111"
  },
  {
    "country": "PH",
    "name": "Bialong",
    "lat": "6.98056",
    "lng": "124.88889"
  },
  {
    "country": "PH",
    "name": "Biabas",
    "lat": "9.8",
    "lng": "124.46667"
  },
  {
    "country": "PH",
    "name": "Betwagan",
    "lat": "17.08333",
    "lng": "120.96667"
  },
  {
    "country": "PH",
    "name": "Besao",
    "lat": "17.095",
    "lng": "120.8579"
  },
  {
    "country": "PH",
    "name": "Benito Soliven",
    "lat": "16.98155",
    "lng": "121.95994"
  },
  {
    "country": "PH",
    "name": "Belison",
    "lat": "10.8384",
    "lng": "121.9605"
  },
  {
    "country": "PH",
    "name": "Belance",
    "lat": "16.18333",
    "lng": "121.25"
  },
  {
    "country": "PH",
    "name": "Begang",
    "lat": "6.6909",
    "lng": "122.0168"
  },
  {
    "country": "PH",
    "name": "Beddeng",
    "lat": "14.97728",
    "lng": "120.08493"
  },
  {
    "country": "PH",
    "name": "Becerril",
    "lat": "9.6531",
    "lng": "123.4344"
  },
  {
    "country": "PH",
    "name": "Beberon",
    "lat": "13.5444",
    "lng": "123.1405"
  },
  {
    "country": "PH",
    "name": "Bayuin",
    "lat": "13.0411",
    "lng": "121.38852"
  },
  {
    "country": "PH",
    "name": "Bayugan",
    "lat": "8.75611",
    "lng": "125.7675"
  },
  {
    "country": "PH",
    "name": "Bayombong",
    "lat": "16.4812",
    "lng": "121.1497"
  },
  {
    "country": "PH",
    "name": "Bayog",
    "lat": "7.86667",
    "lng": "123.06667"
  },
  {
    "country": "PH",
    "name": "Baylo",
    "lat": "7.85514",
    "lng": "126.05563"
  },
  {
    "country": "PH",
    "name": "Baybayin",
    "lat": "13.82083",
    "lng": "121.26992"
  },
  {
    "country": "PH",
    "name": "Baybay",
    "lat": "13.4083",
    "lng": "123.7135"
  },
  {
    "country": "PH",
    "name": "Baybay",
    "lat": "10.6785",
    "lng": "124.8006"
  },
  {
    "country": "PH",
    "name": "Bayawan",
    "lat": "9.3649",
    "lng": "122.804"
  },
  {
    "country": "PH",
    "name": "Bayasong",
    "lat": "6.64889",
    "lng": "124.87306"
  },
  {
    "country": "PH",
    "name": "Bayas",
    "lat": "11.4336",
    "lng": "123.1816"
  },
  {
    "country": "PH",
    "name": "Bayaoas",
    "lat": "15.83404",
    "lng": "120.26478"
  },
  {
    "country": "PH",
    "name": "Bay-ang",
    "lat": "11.03472",
    "lng": "122.94167"
  },
  {
    "country": "PH",
    "name": "Bayang",
    "lat": "7.79278",
    "lng": "124.19167"
  },
  {
    "country": "PH",
    "name": "Bayanan",
    "lat": "13.3592",
    "lng": "121.1699"
  },
  {
    "country": "PH",
    "name": "Bayambang",
    "lat": "15.8127",
    "lng": "120.4557"
  },
  {
    "country": "PH",
    "name": "Bayabas",
    "lat": "16.45",
    "lng": "120.51667"
  },
  {
    "country": "PH",
    "name": "Bayabas",
    "lat": "8.96972",
    "lng": "126.28611"
  },
  {
    "country": "PH",
    "name": "Bay",
    "lat": "14.18368",
    "lng": "121.28554"
  },
  {
    "country": "PH",
    "name": "Bawison",
    "lat": "5.9375",
    "lng": "120.8745"
  },
  {
    "country": "PH",
    "name": "Bautista",
    "lat": "15.78362",
    "lng": "120.49848"
  },
  {
    "country": "PH",
    "name": "Bautista",
    "lat": "13.99444",
    "lng": "121.27778"
  },
  {
    "country": "PH",
    "name": "Baunu-Timbangan",
    "lat": "6.00547",
    "lng": "120.99406"
  },
  {
    "country": "PH",
    "name": "Bauko",
    "lat": "16.9898",
    "lng": "120.8671"
  },
  {
    "country": "PH",
    "name": "Baugo",
    "lat": "10.31745",
    "lng": "123.919"
  },
  {
    "country": "PH",
    "name": "Bauang",
    "lat": "16.53083",
    "lng": "120.33306"
  },
  {
    "country": "PH",
    "name": "Bauan",
    "lat": "17.72256",
    "lng": "121.68028"
  },
  {
    "country": "PH",
    "name": "Bauan",
    "lat": "13.7917",
    "lng": "121.0085"
  },
  {
    "country": "PH",
    "name": "Bau",
    "lat": "7.40528",
    "lng": "124.64972"
  },
  {
    "country": "PH",
    "name": "Batutitik",
    "lat": "6.22333",
    "lng": "125.25194"
  },
  {
    "country": "PH",
    "name": "Batuan",
    "lat": "12.3976",
    "lng": "123.76279"
  },
  {
    "country": "PH",
    "name": "Batuan",
    "lat": "9.7808",
    "lng": "124.1484"
  },
  {
    "country": "PH",
    "name": "Battung",
    "lat": "17.72261",
    "lng": "121.45914"
  },
  {
    "country": "PH",
    "name": "Batobalane",
    "lat": "14.23333",
    "lng": "122.75"
  },
  {
    "country": "PH",
    "name": "Bato",
    "lat": "13.6068",
    "lng": "124.2986"
  },
  {
    "country": "PH",
    "name": "Bato",
    "lat": "13.3528",
    "lng": "123.3677"
  },
  {
    "country": "PH",
    "name": "Bato",
    "lat": "10.80854",
    "lng": "123.3733"
  },
  {
    "country": "PH",
    "name": "Bato",
    "lat": "10.825",
    "lng": "119.471"
  },
  {
    "country": "PH",
    "name": "Bato",
    "lat": "10.32778",
    "lng": "124.79111"
  },
  {
    "country": "PH",
    "name": "Bato",
    "lat": "8.6027",
    "lng": "123.6449"
  },
  {
    "country": "PH",
    "name": "Bato",
    "lat": "7.04306",
    "lng": "125.47306"
  },
  {
    "country": "PH",
    "name": "Batitang",
    "lat": "15.4004",
    "lng": "120.80276"
  },
  {
    "country": "PH",
    "name": "Batiano",
    "lat": "7.5534",
    "lng": "126.4907"
  },
  {
    "country": "PH",
    "name": "Bateria",
    "lat": "11.1416",
    "lng": "124.0267"
  },
  {
    "country": "PH",
    "name": "Batasan Bata",
    "lat": "15.14442",
    "lng": "120.94077"
  },
  {
    "country": "PH",
    "name": "Batasan",
    "lat": "12.76667",
    "lng": "120.78333"
  },
  {
    "country": "PH",
    "name": "Batasan",
    "lat": "7.03333",
    "lng": "125.05"
  },
  {
    "country": "PH",
    "name": "Batas",
    "lat": "14.2",
    "lng": "120.81667"
  },
  {
    "country": "PH",
    "name": "Batarasa",
    "lat": "8.67335",
    "lng": "117.62795"
  },
  {
    "country": "PH",
    "name": "Batangas",
    "lat": "13.7567",
    "lng": "121.0584"
  },
  {
    "country": "PH",
    "name": "Batana",
    "lat": "13.2498",
    "lng": "123.5641"
  },
  {
    "country": "PH",
    "name": "Batan",
    "lat": "11.5857",
    "lng": "122.4971"
  },
  {
    "country": "PH",
    "name": "Batal",
    "lat": "16.6875",
    "lng": "121.60083"
  },
  {
    "country": "PH",
    "name": "Bataquil",
    "lat": "16.15528",
    "lng": "120.5275"
  },
  {
    "country": "PH",
    "name": "Batad",
    "lat": "11.418",
    "lng": "123.108"
  },
  {
    "country": "PH",
    "name": "Batac City",
    "lat": "18.0554",
    "lng": "120.56489"
  },
  {
    "country": "PH",
    "name": "Basud",
    "lat": "14.065",
    "lng": "122.9642"
  },
  {
    "country": "PH",
    "name": "Basud",
    "lat": "12.98889",
    "lng": "123.95"
  },
  {
    "country": "PH",
    "name": "Basud",
    "lat": "11.3663",
    "lng": "124.3631"
  },
  {
    "country": "PH",
    "name": "Basista",
    "lat": "15.8524",
    "lng": "120.3976"
  },
  {
    "country": "PH",
    "name": "Basing",
    "lat": "15.98505",
    "lng": "120.26831"
  },
  {
    "country": "PH",
    "name": "Basilisa",
    "lat": "10",
    "lng": "125.5"
  },
  {
    "country": "PH",
    "name": "Basicao Coastal",
    "lat": "13.04589",
    "lng": "123.40423"
  },
  {
    "country": "PH",
    "name": "Basiao",
    "lat": "11.54861",
    "lng": "122.6375"
  },
  {
    "country": "PH",
    "name": "Basiad",
    "lat": "14.15617",
    "lng": "122.33749"
  },
  {
    "country": "PH",
    "name": "Basey",
    "lat": "11.28205",
    "lng": "125.06986"
  },
  {
    "country": "PH",
    "name": "Basdiot",
    "lat": "9.94718",
    "lng": "123.37515"
  },
  {
    "country": "PH",
    "name": "Basco",
    "lat": "20.44865",
    "lng": "121.97017"
  },
  {
    "country": "PH",
    "name": "Bascaron",
    "lat": "13.1029",
    "lng": "123.6999"
  },
  {
    "country": "PH",
    "name": "Basay",
    "lat": "9.4087",
    "lng": "122.64"
  },
  {
    "country": "PH",
    "name": "Basak",
    "lat": "8.04111",
    "lng": "124.86278"
  },
  {
    "country": "PH",
    "name": "Basak",
    "lat": "6.72736",
    "lng": "124.15117"
  },
  {
    "country": "PH",
    "name": "Basag",
    "lat": "8.92548",
    "lng": "125.62167"
  },
  {
    "country": "PH",
    "name": "Basak",
    "lat": "10.2264",
    "lng": "123.3064"
  },
  {
    "country": "PH",
    "name": "Basa",
    "lat": "8.07222",
    "lng": "126.06417"
  },
  {
    "country": "PH",
    "name": "Barugo",
    "lat": "11.32417",
    "lng": "124.73833"
  },
  {
    "country": "PH",
    "name": "Barucboc Norte",
    "lat": "17.25857",
    "lng": "121.60561"
  },
  {
    "country": "PH",
    "name": "Barra",
    "lat": "12.0717",
    "lng": "123.6395"
  },
  {
    "country": "PH",
    "name": "Barra",
    "lat": "8.51028",
    "lng": "124.60444"
  },
  {
    "country": "PH",
    "name": "Baroy",
    "lat": "8.0269",
    "lng": "123.7784"
  },
  {
    "country": "PH",
    "name": "Barotac Viejo",
    "lat": "11.04194",
    "lng": "122.85222"
  },
  {
    "country": "PH",
    "name": "Barotac Nuevo",
    "lat": "10.89417",
    "lng": "122.70444"
  },
  {
    "country": "PH",
    "name": "Barongis",
    "lat": "7.26111",
    "lng": "124.56417"
  },
  {
    "country": "PH",
    "name": "Barong Barong",
    "lat": "8.8535",
    "lng": "117.8939"
  },
  {
    "country": "PH",
    "name": "Barong",
    "lat": "18.0576",
    "lng": "120.734"
  },
  {
    "country": "PH",
    "name": "Barobo",
    "lat": "8.53528",
    "lng": "126.12139"
  },
  {
    "country": "PH",
    "name": "Baro",
    "lat": "15.99895",
    "lng": "120.6735"
  },
  {
    "country": "PH",
    "name": "Barlig",
    "lat": "17.03725",
    "lng": "121.10384"
  },
  {
    "country": "PH",
    "name": "Bariw",
    "lat": "13.13333",
    "lng": "123.73333"
  },
  {
    "country": "PH",
    "name": "Barira",
    "lat": "7.48722",
    "lng": "124.29917"
  },
  {
    "country": "PH",
    "name": "Barili",
    "lat": "10.115",
    "lng": "123.5103"
  },
  {
    "country": "PH",
    "name": "Barcelona",
    "lat": "13.7715",
    "lng": "123.0485"
  },
  {
    "country": "PH",
    "name": "Barcelona",
    "lat": "12.8683",
    "lng": "124.1419"
  },
  {
    "country": "PH",
    "name": "Barcelona",
    "lat": "8.5275",
    "lng": "123.4587"
  },
  {
    "country": "PH",
    "name": "Barcelona",
    "lat": "8.15917",
    "lng": "126.43417"
  },
  {
    "country": "PH",
    "name": "Barbaza",
    "lat": "11.19572",
    "lng": "122.03861"
  },
  {
    "country": "PH",
    "name": "Barayong",
    "lat": "13.1",
    "lng": "123.71667"
  },
  {
    "country": "PH",
    "name": "Baras",
    "lat": "14.51691",
    "lng": "121.2658"
  },
  {
    "country": "PH",
    "name": "Baras",
    "lat": "13.6588",
    "lng": "124.37"
  },
  {
    "country": "PH",
    "name": "Baras",
    "lat": "11.18333",
    "lng": "125.01667"
  },
  {
    "country": "PH",
    "name": "Barangobong",
    "lat": "15.87778",
    "lng": "120.54833"
  },
  {
    "country": "PH",
    "name": "Barahan",
    "lat": "13.0121",
    "lng": "120.762"
  },
  {
    "country": "PH",
    "name": "Baracatan",
    "lat": "6.9675",
    "lng": "125.41583"
  },
  {
    "country": "PH",
    "name": "Baquero Norte",
    "lat": "15.7162",
    "lng": "120.5543"
  },
  {
    "country": "PH",
    "name": "Baon",
    "lat": "6.79562",
    "lng": "126.08778"
  },
  {
    "country": "PH",
    "name": "Baud",
    "lat": "11.2111",
    "lng": "123.7031"
  },
  {
    "country": "PH",
    "name": "Bantuanon",
    "lat": "8.01528",
    "lng": "125.07083"
  },
  {
    "country": "PH",
    "name": "Bantogon",
    "lat": "6.53333",
    "lng": "124.03333"
  },
  {
    "country": "PH",
    "name": "Bantog",
    "lat": "16.0091",
    "lng": "120.6929"
  },
  {
    "country": "PH",
    "name": "Bantilan",
    "lat": "14.75814",
    "lng": "121.66902"
  },
  {
    "country": "PH",
    "name": "Bantiqui",
    "lat": "10.9245",
    "lng": "124.4154"
  },
  {
    "country": "PH",
    "name": "Bantayan",
    "lat": "12.5237",
    "lng": "124.8283"
  },
  {
    "country": "PH",
    "name": "Bantayan",
    "lat": "11.1683",
    "lng": "123.7223"
  },
  {
    "country": "PH",
    "name": "Bantay",
    "lat": "17.58472",
    "lng": "120.38917"
  },
  {
    "country": "PH",
    "name": "Bantay",
    "lat": "17.43793",
    "lng": "120.75775"
  },
  {
    "country": "PH",
    "name": "Bansud",
    "lat": "12.865",
    "lng": "121.45639"
  },
  {
    "country": "PH",
    "name": "Bansalan",
    "lat": "6.78611",
    "lng": "125.21333"
  },
  {
    "country": "PH",
    "name": "Bangkirohan",
    "lat": "13.0553",
    "lng": "123.7468"
  },
  {
    "country": "PH",
    "name": "Banquero",
    "lat": "17.02305",
    "lng": "121.77834"
  },
  {
    "country": "PH",
    "name": "Banos",
    "lat": "12.64553",
    "lng": "120.90972"
  },
  {
    "country": "PH",
    "name": "Banog Sur",
    "lat": "16.16542",
    "lng": "119.89802"
  },
  {
    "country": "PH",
    "name": "Banugao",
    "lat": "14.74825",
    "lng": "121.6184"
  },
  {
    "country": "PH",
    "name": "Banocboc",
    "lat": "14.3",
    "lng": "122.58333"
  },
  {
    "country": "PH",
    "name": "Bankaw",
    "lat": "5.0192",
    "lng": "120.0091"
  },
  {
    "country": "PH",
    "name": "Banisilan",
    "lat": "7.49083",
    "lng": "124.72417"
  },
  {
    "country": "PH",
    "name": "Banilad",
    "lat": "14.0667",
    "lng": "120.7347"
  },
  {
    "country": "PH",
    "name": "Banilad",
    "lat": "9.2786",
    "lng": "123.2936"
  },
  {
    "country": "PH",
    "name": "Bani",
    "lat": "16.185",
    "lng": "119.8613"
  },
  {
    "country": "PH",
    "name": "Bani",
    "lat": "15.5823",
    "lng": "119.9335"
  },
  {
    "country": "PH",
    "name": "Banhigan",
    "lat": "9.85903",
    "lng": "123.38926"
  },
  {
    "country": "PH",
    "name": "Bangui",
    "lat": "18.5376",
    "lng": "120.7671"
  },
  {
    "country": "PH",
    "name": "Bangued",
    "lat": "17.60833",
    "lng": "120.63806"
  },
  {
    "country": "PH",
    "name": "Bangonay",
    "lat": "9.31444",
    "lng": "125.55389"
  },
  {
    "country": "PH",
    "name": "Bangkal",
    "lat": "6.06667",
    "lng": "121.06667"
  },
  {
    "country": "PH",
    "name": "Bangar",
    "lat": "16.8936",
    "lng": "120.4243"
  },
  {
    "country": "PH",
    "name": "Bangao",
    "lat": "16.8211",
    "lng": "120.8404"
  },
  {
    "country": "PH",
    "name": "Bangan-Oda",
    "lat": "16.1087",
    "lng": "119.8307"
  },
  {
    "country": "PH",
    "name": "Banganan",
    "lat": "16.3144",
    "lng": "121.0544"
  },
  {
    "country": "PH",
    "name": "Bangahan",
    "lat": "7.79634",
    "lng": "124.73361"
  },
  {
    "country": "PH",
    "name": "Bangad",
    "lat": "17.49543",
    "lng": "121.77714"
  },
  {
    "country": "PH",
    "name": "Bangad",
    "lat": "15.5019",
    "lng": "121.0275"
  },
  {
    "country": "PH",
    "name": "Bangad",
    "lat": "12.16125",
    "lng": "123.40131"
  },
  {
    "country": "PH",
    "name": "Bañga",
    "lat": "11.6387",
    "lng": "122.3341"
  },
  {
    "country": "PH",
    "name": "Banga",
    "lat": "10.5018",
    "lng": "122.8289"
  },
  {
    "country": "PH",
    "name": "Bañga",
    "lat": "6.42389",
    "lng": "124.77833"
  },
  {
    "country": "PH",
    "name": "Bancasi",
    "lat": "8.96667",
    "lng": "125.46667"
  },
  {
    "country": "PH",
    "name": "Bancal",
    "lat": "11.5591",
    "lng": "123.1551"
  },
  {
    "country": "PH",
    "name": "Banayoyo",
    "lat": "17.23333",
    "lng": "120.48333"
  },
  {
    "country": "PH",
    "name": "Banaybanay",
    "lat": "13.9331",
    "lng": "121.1151"
  },
  {
    "country": "PH",
    "name": "Banaybanay",
    "lat": "13.85",
    "lng": "121.2"
  },
  {
    "country": "PH",
    "name": "Banaybanay",
    "lat": "6.96233",
    "lng": "126.01717"
  },
  {
    "country": "PH",
    "name": "Banaue",
    "lat": "16.91356",
    "lng": "121.06184"
  },
  {
    "country": "PH",
    "name": "Banawang",
    "lat": "14.6121",
    "lng": "120.39"
  },
  {
    "country": "PH",
    "name": "Banawa",
    "lat": "7.15361",
    "lng": "124.86667"
  },
  {
    "country": "PH",
    "name": "Banate",
    "lat": "11.00222",
    "lng": "122.8175"
  },
  {
    "country": "PH",
    "name": "Banalo",
    "lat": "13.6464",
    "lng": "121.1817"
  },
  {
    "country": "PH",
    "name": "Banag",
    "lat": "13.37889",
    "lng": "123.70333"
  },
  {
    "country": "PH",
    "name": "Banaba",
    "lat": "14.21667",
    "lng": "120.85"
  },
  {
    "country": "PH",
    "name": "Banaba",
    "lat": "13.8966",
    "lng": "121.21"
  },
  {
    "country": "PH",
    "name": "Bambang",
    "lat": "16.3865",
    "lng": "121.1066"
  },
  {
    "country": "PH",
    "name": "Bamban",
    "lat": "15.6747",
    "lng": "120.3315"
  },
  {
    "country": "PH",
    "name": "Baluyot",
    "lat": "15.79586",
    "lng": "120.46088"
  },
  {
    "country": "PH",
    "name": "Balutu",
    "lat": "15.29875",
    "lng": "120.69226"
  },
  {
    "country": "PH",
    "name": "Balutakay",
    "lat": "6.72111",
    "lng": "125.35167"
  },
  {
    "country": "PH",
    "name": "Balut",
    "lat": "14.68333",
    "lng": "120.55"
  },
  {
    "country": "PH",
    "name": "Balungao",
    "lat": "15.89806",
    "lng": "120.68833"
  },
  {
    "country": "PH",
    "name": "Balugo",
    "lat": "12.57923",
    "lng": "121.43931"
  },
  {
    "country": "PH",
    "name": "Balud",
    "lat": "12.03686",
    "lng": "123.19351"
  },
  {
    "country": "PH",
    "name": "Balud",
    "lat": "11.61667",
    "lng": "125.43333"
  },
  {
    "country": "PH",
    "name": "Balud",
    "lat": "10.1476",
    "lng": "123.6953"
  },
  {
    "country": "PH",
    "name": "Balucuc",
    "lat": "14.95282",
    "lng": "120.81452"
  },
  {
    "country": "PH",
    "name": "Balsic",
    "lat": "14.85906",
    "lng": "120.4824"
  },
  {
    "country": "PH",
    "name": "Baloy",
    "lat": "15.8053",
    "lng": "120.7742"
  },
  {
    "country": "PH",
    "name": "Bal-os",
    "lat": "9.4416",
    "lng": "122.6257"
  },
  {
    "country": "PH",
    "name": "Mamungan",
    "lat": "8.11722",
    "lng": "124.21861"
  },
  {
    "country": "PH",
    "name": "Balogo",
    "lat": "15.99032",
    "lng": "120.28302"
  },
  {
    "country": "PH",
    "name": "Balogo",
    "lat": "13.5016",
    "lng": "123.0638"
  },
  {
    "country": "PH",
    "name": "Balogo",
    "lat": "13.2871",
    "lng": "123.5496"
  },
  {
    "country": "PH",
    "name": "Balogo",
    "lat": "10.8868",
    "lng": "124.7105"
  },
  {
    "country": "PH",
    "name": "Balogo",
    "lat": "10.1148",
    "lng": "123.1706"
  },
  {
    "country": "PH",
    "name": "Balogo",
    "lat": "7.2823",
    "lng": "124.46388"
  },
  {
    "country": "PH",
    "name": "Balocawehay",
    "lat": "10.7221",
    "lng": "124.9678"
  },
  {
    "country": "PH",
    "name": "Balucawi",
    "lat": "12.2013",
    "lng": "123.8426"
  },
  {
    "country": "PH",
    "name": "Baloc",
    "lat": "15.6435",
    "lng": "120.8852"
  },
  {
    "country": "PH",
    "name": "Ballesteros",
    "lat": "18.4126",
    "lng": "121.5152"
  },
  {
    "country": "PH",
    "name": "Baliwagan",
    "lat": "8.71861",
    "lng": "124.79056"
  },
  {
    "country": "PH",
    "name": "Baliuag Nuevo",
    "lat": "13.5214",
    "lng": "123.2016"
  },
  {
    "country": "PH",
    "name": "Baliwagan",
    "lat": "10.3971",
    "lng": "122.8911"
  },
  {
    "country": "PH",
    "name": "Baliuag",
    "lat": "14.95472",
    "lng": "120.89694"
  },
  {
    "country": "PH",
    "name": "Baliton",
    "lat": "5.74361",
    "lng": "125.23639"
  },
  {
    "country": "PH",
    "name": "Balitoc",
    "lat": "13.86269",
    "lng": "120.63554"
  },
  {
    "country": "PH",
    "name": "Balite Segundo",
    "lat": "14.1832",
    "lng": "120.97433"
  },
  {
    "country": "PH",
    "name": "Balite",
    "lat": "14.89524",
    "lng": "120.78721"
  },
  {
    "country": "PH",
    "name": "Balinsacayao",
    "lat": "10.681",
    "lng": "124.9595"
  },
  {
    "country": "PH",
    "name": "Balingueo",
    "lat": "15.9583",
    "lng": "120.40973"
  },
  {
    "country": "PH",
    "name": "Balingoan",
    "lat": "9.00389",
    "lng": "124.85194"
  },
  {
    "country": "PH",
    "name": "Balingcanaway",
    "lat": "15.48215",
    "lng": "120.68543"
  },
  {
    "country": "PH",
    "name": "Balingasay",
    "lat": "16.3573",
    "lng": "119.8564"
  },
  {
    "country": "PH",
    "name": "Balingasag",
    "lat": "8.74417",
    "lng": "124.77694"
  },
  {
    "country": "PH",
    "name": "Balindong",
    "lat": "7.91667",
    "lng": "124.20028"
  },
  {
    "country": "PH",
    "name": "Balinad",
    "lat": "13.2926",
    "lng": "123.5454"
  },
  {
    "country": "PH",
    "name": "Balimbing",
    "lat": "5.0825",
    "lng": "119.96583"
  },
  {
    "country": "PH",
    "name": "Balilihan",
    "lat": "9.7561",
    "lng": "123.973"
  },
  {
    "country": "PH",
    "name": "Balili",
    "lat": "7.895",
    "lng": "123.7337"
  },
  {
    "country": "PH",
    "name": "Balila",
    "lat": "8.00278",
    "lng": "125.01306"
  },
  {
    "country": "PH",
    "name": "Baligang",
    "lat": "13.1537",
    "lng": "123.6432"
  },
  {
    "country": "PH",
    "name": "Balibago",
    "lat": "15.1624",
    "lng": "120.5954"
  },
  {
    "country": "PH",
    "name": "Balibago",
    "lat": "13.92572",
    "lng": "120.62556"
  },
  {
    "country": "PH",
    "name": "Balibago",
    "lat": "13.6093",
    "lng": "121.2971"
  },
  {
    "country": "PH",
    "name": "Balibagan Oeste",
    "lat": "10.8",
    "lng": "122.51667"
  },
  {
    "country": "PH",
    "name": "Balite",
    "lat": "15.64451",
    "lng": "120.64196"
  },
  {
    "country": "PH",
    "name": "Balete",
    "lat": "14.01983",
    "lng": "121.09506"
  },
  {
    "country": "PH",
    "name": "Balete",
    "lat": "13.01917",
    "lng": "124.03194"
  },
  {
    "country": "PH",
    "name": "Calamundingan",
    "lat": "12.93101",
    "lng": "121.47062"
  },
  {
    "country": "PH",
    "name": "Balete",
    "lat": "11.5556",
    "lng": "122.3803"
  },
  {
    "country": "PH",
    "name": "Baler",
    "lat": "15.7589",
    "lng": "121.5607"
  },
  {
    "country": "PH",
    "name": "Baleno",
    "lat": "12.4739",
    "lng": "123.4982"
  },
  {
    "country": "PH",
    "name": "Balele",
    "lat": "14.06532",
    "lng": "121.09363"
  },
  {
    "country": "PH",
    "name": "Balbalan",
    "lat": "17.44139",
    "lng": "121.20194"
  },
  {
    "country": "PH",
    "name": "Balayong",
    "lat": "9.4744",
    "lng": "123.0623"
  },
  {
    "country": "PH",
    "name": "Balayang",
    "lat": "15.5495",
    "lng": "120.6943"
  },
  {
    "country": "PH",
    "name": "Balayan",
    "lat": "13.93714",
    "lng": "120.73224"
  },
  {
    "country": "PH",
    "name": "Balatero",
    "lat": "13.5021",
    "lng": "120.9244"
  },
  {
    "country": "PH",
    "name": "Balatan",
    "lat": "13.32111",
    "lng": "123.23333"
  },
  {
    "country": "PH",
    "name": "Balasing",
    "lat": "14.8545",
    "lng": "121.0127"
  },
  {
    "country": "PH",
    "name": "Balasan",
    "lat": "11.4728",
    "lng": "123.0878"
  },
  {
    "country": "PH",
    "name": "Balas",
    "lat": "6.6875",
    "lng": "122.13806"
  },
  {
    "country": "PH",
    "name": "Balaogan",
    "lat": "13.4328",
    "lng": "123.2818"
  },
  {
    "country": "PH",
    "name": "Balaoang",
    "lat": "15.6633",
    "lng": "120.5147"
  },
  {
    "country": "PH",
    "name": "Balaoan",
    "lat": "16.8219",
    "lng": "120.4045"
  },
  {
    "country": "PH",
    "name": "Balangonan",
    "lat": "5.57333",
    "lng": "125.35389"
  },
  {
    "country": "PH",
    "name": "Balangkayan",
    "lat": "11.47139",
    "lng": "125.51056"
  },
  {
    "country": "PH",
    "name": "Balangiga",
    "lat": "11.10972",
    "lng": "125.3875"
  },
  {
    "country": "PH",
    "name": "Balangbalang",
    "lat": "9.05694",
    "lng": "125.62278"
  },
  {
    "country": "PH",
    "name": "Balanga",
    "lat": "14.67611",
    "lng": "120.53611"
  },
  {
    "country": "PH",
    "name": "Balanacan",
    "lat": "13.5289",
    "lng": "121.8677"
  },
  {
    "country": "PH",
    "name": "Balamban",
    "lat": "10.5039",
    "lng": "123.7156"
  },
  {
    "country": "PH",
    "name": "Balagunan",
    "lat": "7.49222",
    "lng": "125.52111"
  },
  {
    "country": "PH",
    "name": "Balagui",
    "lat": "11.4752",
    "lng": "124.5324"
  },
  {
    "country": "PH",
    "name": "Balagtas",
    "lat": "11.1333",
    "lng": "124.5192"
  },
  {
    "country": "PH",
    "name": "Balagtasin",
    "lat": "13.9018",
    "lng": "121.0889"
  },
  {
    "country": "PH",
    "name": "Balagtas",
    "lat": "14.81667",
    "lng": "120.86667"
  },
  {
    "country": "PH",
    "name": "Balagon",
    "lat": "8.0063",
    "lng": "123.2396"
  },
  {
    "country": "PH",
    "name": "Balading",
    "lat": "13.3906",
    "lng": "123.7121"
  },
  {
    "country": "PH",
    "name": "Balabagan",
    "lat": "7.52639",
    "lng": "124.11417"
  },
  {
    "country": "PH",
    "name": "Balabag",
    "lat": "11.97",
    "lng": "121.91917"
  },
  {
    "country": "PH",
    "name": "Balabag",
    "lat": "10.76333",
    "lng": "122.49306"
  },
  {
    "country": "PH",
    "name": "Balabac",
    "lat": "7.98363",
    "lng": "117.04868"
  },
  {
    "country": "PH",
    "name": "Bakung",
    "lat": "4.89111",
    "lng": "119.79417"
  },
  {
    "country": "PH",
    "name": "Bakun",
    "lat": "16.7895",
    "lng": "120.6631"
  },
  {
    "country": "PH",
    "name": "Bachauan",
    "lat": "11.2067",
    "lng": "123.9634"
  },
  {
    "country": "PH",
    "name": "Brgy. Bachaw Norte, Kalibo",
    "lat": "11.71806",
    "lng": "122.37806"
  },
  {
    "country": "PH",
    "name": "Baka",
    "lat": "7.27611",
    "lng": "124.26417"
  },
  {
    "country": "PH",
    "name": "Bais",
    "lat": "9.59111",
    "lng": "123.12278"
  },
  {
    "country": "PH",
    "name": "Bairan",
    "lat": "10.19718",
    "lng": "123.7271"
  },
  {
    "country": "PH",
    "name": "Bailan",
    "lat": "11.4584",
    "lng": "122.8301"
  },
  {
    "country": "PH",
    "name": "Bail",
    "lat": "16.2867",
    "lng": "120.4004"
  },
  {
    "country": "PH",
    "name": "Baikingon",
    "lat": "8.47222",
    "lng": "124.55361"
  },
  {
    "country": "PH",
    "name": "Baheli",
    "lat": "10.01369",
    "lng": "118.77294"
  },
  {
    "country": "PH",
    "name": "Bah-Bah",
    "lat": "8.60722",
    "lng": "125.91444"
  },
  {
    "country": "PH",
    "name": "Bahay Pare",
    "lat": "15.03238",
    "lng": "120.88083"
  },
  {
    "country": "PH",
    "name": "Bahay",
    "lat": "13.5437",
    "lng": "123.0407"
  },
  {
    "country": "PH",
    "name": "Bao",
    "lat": "13.6414",
    "lng": "122.8314"
  },
  {
    "country": "PH",
    "name": "Bagupaye",
    "lat": "13.565",
    "lng": "122.3902"
  },
  {
    "country": "PH",
    "name": "Bagombong",
    "lat": "14.3413",
    "lng": "121.3775"
  },
  {
    "country": "PH",
    "name": "Bagumbayan",
    "lat": "18.1939",
    "lng": "121.66302"
  },
  {
    "country": "PH",
    "name": "Bagumbayan",
    "lat": "17.72271",
    "lng": "121.44695"
  },
  {
    "country": "PH",
    "name": "Bagumbayan",
    "lat": "13.45",
    "lng": "123.66667"
  },
  {
    "country": "PH",
    "name": "Bagumbayan",
    "lat": "13.4653",
    "lng": "123.3899"
  },
  {
    "country": "PH",
    "name": "Bagumbayan",
    "lat": "10.446",
    "lng": "122.8348"
  },
  {
    "country": "PH",
    "name": "Bagulin",
    "lat": "16.60833",
    "lng": "120.43944"
  },
  {
    "country": "PH",
    "name": "Baguio",
    "lat": "16.41639",
    "lng": "120.59306"
  },
  {
    "country": "PH",
    "name": "Baguinge",
    "lat": "16.77767",
    "lng": "121.10624"
  },
  {
    "country": "PH",
    "name": "Baguer",
    "lat": "7.25611",
    "lng": "124.50417"
  },
  {
    "country": "PH",
    "name": "Bagu",
    "lat": "18.42441",
    "lng": "121.35573"
  },
  {
    "country": "PH",
    "name": "Bagtic",
    "lat": "9.6864",
    "lng": "123.0122"
  },
  {
    "country": "PH",
    "name": "Bagroy",
    "lat": "10.2031",
    "lng": "122.9362"
  },
  {
    "country": "PH",
    "name": "Bagontapay",
    "lat": "6.85889",
    "lng": "124.90889"
  },
  {
    "country": "PH",
    "name": "Bagong Tanza",
    "lat": "16.98269",
    "lng": "121.61109"
  },
  {
    "country": "PH",
    "name": "Bagong-Sikat",
    "lat": "15.4801",
    "lng": "121.3073"
  },
  {
    "country": "PH",
    "name": "Bagong Sikat",
    "lat": "12.36745",
    "lng": "121.06171"
  },
  {
    "country": "PH",
    "name": "Bagong Barrio",
    "lat": "14.88993",
    "lng": "120.94095"
  },
  {
    "country": "PH",
    "name": "Bago City",
    "lat": "10.53333",
    "lng": "122.83333"
  },
  {
    "country": "PH",
    "name": "Bagay",
    "lat": "11.1964",
    "lng": "124.035"
  },
  {
    "country": "PH",
    "name": "Baganga",
    "lat": "7.57389",
    "lng": "126.56"
  },
  {
    "country": "PH",
    "name": "Bayanga",
    "lat": "7.52139",
    "lng": "124.25222"
  },
  {
    "country": "PH",
    "name": "Bagan",
    "lat": "6.92556",
    "lng": "124.42028"
  },
  {
    "country": "PH",
    "name": "Bagamanoc",
    "lat": "13.9404",
    "lng": "124.28962"
  },
  {
    "country": "PH",
    "name": "Bagalangit",
    "lat": "13.71041",
    "lng": "120.88467"
  },
  {
    "country": "PH",
    "name": "Bagakay",
    "lat": "8.1454",
    "lng": "123.8157"
  },
  {
    "country": "PH",
    "name": "Bagahanlad",
    "lat": "12.5797",
    "lng": "123.6688"
  },
  {
    "country": "PH",
    "name": "Bagacay",
    "lat": "13.777",
    "lng": "123.3032"
  },
  {
    "country": "PH",
    "name": "Bagacay",
    "lat": "12.9821",
    "lng": "124.1415"
  },
  {
    "country": "PH",
    "name": "Bagacay",
    "lat": "10.15209",
    "lng": "124.25857"
  },
  {
    "country": "PH",
    "name": "Bagacay",
    "lat": "9.8664",
    "lng": "123.918"
  },
  {
    "country": "PH",
    "name": "Bagac",
    "lat": "14.5962",
    "lng": "120.3928"
  },
  {
    "country": "PH",
    "name": "Bagabag",
    "lat": "16.6068",
    "lng": "121.2542"
  },
  {
    "country": "PH",
    "name": "Baggabag B",
    "lat": "16.50588",
    "lng": "121.19014"
  },
  {
    "country": "PH",
    "name": "Buadtasan",
    "lat": "6.00496",
    "lng": "124.61266"
  },
  {
    "country": "PH",
    "name": "Badoc",
    "lat": "17.9265",
    "lng": "120.4764"
  },
  {
    "country": "PH",
    "name": "Badlan",
    "lat": "11.1414",
    "lng": "122.52"
  },
  {
    "country": "PH",
    "name": "Badiangan",
    "lat": "11.00573",
    "lng": "122.50051"
  },
  {
    "country": "PH",
    "name": "Badian",
    "lat": "13.03167",
    "lng": "123.30778"
  },
  {
    "country": "PH",
    "name": "Badian",
    "lat": "9.86472",
    "lng": "123.39639"
  },
  {
    "country": "PH",
    "name": "Bacuyangan",
    "lat": "9.637",
    "lng": "122.4721"
  },
  {
    "country": "PH",
    "name": "Bacungan",
    "lat": "9.91056",
    "lng": "118.70222"
  },
  {
    "country": "PH",
    "name": "Bacundao Weste",
    "lat": "15.91536",
    "lng": "120.47668"
  },
  {
    "country": "PH",
    "name": "Baculongan",
    "lat": "16.8",
    "lng": "120.8333"
  },
  {
    "country": "PH",
    "name": "Bakulong",
    "lat": "15.5379",
    "lng": "120.6385"
  },
  {
    "country": "PH",
    "name": "Baculin",
    "lat": "7.4525",
    "lng": "126.58417"
  },
  {
    "country": "PH",
    "name": "Bacuag",
    "lat": "9.60806",
    "lng": "125.63889"
  },
  {
    "country": "PH",
    "name": "Bactad Proper",
    "lat": "15.97842",
    "lng": "120.61026"
  },
  {
    "country": "PH",
    "name": "Bacsay",
    "lat": "15.62063",
    "lng": "120.34341"
  },
  {
    "country": "PH",
    "name": "Bacoor",
    "lat": "14.45903",
    "lng": "120.92903"
  },
  {
    "country": "PH",
    "name": "Leon Postigo",
    "lat": "8.1551",
    "lng": "122.9311"
  },
  {
    "country": "PH",
    "name": "Bacong",
    "lat": "9.7393",
    "lng": "124.5656"
  },
  {
    "country": "PH",
    "name": "Bacong",
    "lat": "9.2464",
    "lng": "123.2956"
  },
  {
    "country": "PH",
    "name": "Bacon",
    "lat": "13.03778",
    "lng": "124.04111"
  },
  {
    "country": "PH",
    "name": "Bacolor",
    "lat": "15.0003",
    "lng": "120.652"
  },
  {
    "country": "PH",
    "name": "Bacolod City",
    "lat": "10.66667",
    "lng": "122.95"
  },
  {
    "country": "PH",
    "name": "Bacolod",
    "lat": "12.22854",
    "lng": "123.50851"
  },
  {
    "country": "PH",
    "name": "Bacolod",
    "lat": "8.93167",
    "lng": "126.28944"
  },
  {
    "country": "PH",
    "name": "Bacolod",
    "lat": "8.11667",
    "lng": "123.91667"
  },
  {
    "country": "PH",
    "name": "Baco",
    "lat": "13.3573",
    "lng": "121.0983"
  },
  {
    "country": "PH",
    "name": "Bacnotan",
    "lat": "16.72222",
    "lng": "120.3525"
  },
  {
    "country": "PH",
    "name": "Bacnor East",
    "lat": "17.03449",
    "lng": "121.70375"
  },
  {
    "country": "PH",
    "name": "Bacnar",
    "lat": "15.88641",
    "lng": "120.34419"
  },
  {
    "country": "PH",
    "name": "Baclayon",
    "lat": "9.62639",
    "lng": "123.89417"
  },
  {
    "country": "PH",
    "name": "New Baclayon",
    "lat": "6.58417",
    "lng": "125.36944"
  },
  {
    "country": "PH",
    "name": "Bacayawan",
    "lat": "7.76667",
    "lng": "124.23333"
  },
  {
    "country": "PH",
    "name": "Bacarra",
    "lat": "18.2529",
    "lng": "120.6125"
  },
  {
    "country": "PH",
    "name": "Bacalan",
    "lat": "11.5464",
    "lng": "122.0849"
  },
  {
    "country": "PH",
    "name": "Bacag",
    "lat": "15.93",
    "lng": "120.58222"
  },
  {
    "country": "PH",
    "name": "Bacacay",
    "lat": "13.2934",
    "lng": "123.7919"
  },
  {
    "country": "PH",
    "name": "Bacabac",
    "lat": "15.72477",
    "lng": "120.42816"
  },
  {
    "country": "PH",
    "name": "Babo-Pangulo",
    "lat": "15.08333",
    "lng": "120.51667"
  },
  {
    "country": "PH",
    "name": "Babatngon",
    "lat": "11.4238",
    "lng": "124.8449"
  },
  {
    "country": "PH",
    "name": "Babak",
    "lat": "7.13639",
    "lng": "125.6875"
  },
  {
    "country": "PH",
    "name": "Babag",
    "lat": "7.73309",
    "lng": "126.0713"
  },
  {
    "country": "PH",
    "name": "Baay",
    "lat": "18.1188",
    "lng": "120.5753"
  },
  {
    "country": "PH",
    "name": "Baao",
    "lat": "13.4549",
    "lng": "123.3653"
  },
  {
    "country": "PH",
    "name": "Azagra",
    "lat": "9.4779",
    "lng": "123.1367"
  },
  {
    "country": "PH",
    "name": "Ayusan Uno",
    "lat": "13.95609",
    "lng": "121.30765"
  },
  {
    "country": "PH",
    "name": "Ayungon",
    "lat": "9.8589",
    "lng": "123.1444"
  },
  {
    "country": "PH",
    "name": "Ayugan",
    "lat": "13.5469",
    "lng": "123.3217"
  },
  {
    "country": "PH",
    "name": "Aya",
    "lat": "13.8945",
    "lng": "121.1139"
  },
  {
    "country": "PH",
    "name": "Awang",
    "lat": "7.15306",
    "lng": "124.22111"
  },
  {
    "country": "PH",
    "name": "Awallan",
    "lat": "17.92439",
    "lng": "121.91305"
  },
  {
    "country": "PH",
    "name": "Avila",
    "lat": "10.692",
    "lng": "122.709"
  },
  {
    "country": "PH",
    "name": "Aurora",
    "lat": "16.99065",
    "lng": "121.63664"
  },
  {
    "country": "PH",
    "name": "Aurora",
    "lat": "13.2322",
    "lng": "121.1203"
  },
  {
    "country": "PH",
    "name": "Aurora",
    "lat": "8.59306",
    "lng": "125.8375"
  },
  {
    "country": "PH",
    "name": "Aurora",
    "lat": "7.9506",
    "lng": "123.5826"
  },
  {
    "country": "PH",
    "name": "Aurelliana",
    "lat": "10.8849",
    "lng": "121.9769"
  },
  {
    "country": "PH",
    "name": "Aumbay",
    "lat": "7.1026",
    "lng": "125.7837"
  },
  {
    "country": "PH",
    "name": "Atulayan",
    "lat": "17.6648",
    "lng": "121.6937"
  },
  {
    "country": "PH",
    "name": "Atop-atop",
    "lat": "11.2322",
    "lng": "123.7602"
  },
  {
    "country": "PH",
    "name": "Atok",
    "lat": "16.58355",
    "lng": "120.69949"
  },
  {
    "country": "PH",
    "name": "Atipuluhan",
    "lat": "10.51336",
    "lng": "122.9621"
  },
  {
    "country": "PH",
    "name": "Atimonan",
    "lat": "14.0027",
    "lng": "121.92078"
  },
  {
    "country": "PH",
    "name": "Atabayan",
    "lat": "10.68333",
    "lng": "122.41667"
  },
  {
    "country": "PH",
    "name": "Cambanugoy",
    "lat": "7.5413",
    "lng": "125.7553"
  },
  {
    "country": "PH",
    "name": "Asturias",
    "lat": "10.5669",
    "lng": "123.7161"
  },
  {
    "country": "PH",
    "name": "Asturga",
    "lat": "11.25449",
    "lng": "122.8018"
  },
  {
    "country": "PH",
    "name": "Astorga",
    "lat": "6.90722",
    "lng": "125.45583"
  },
  {
    "country": "PH",
    "name": "Asingan",
    "lat": "16.0051",
    "lng": "120.6695"
  },
  {
    "country": "PH",
    "name": "Asia",
    "lat": "9.5506",
    "lng": "122.5164"
  },
  {
    "country": "PH",
    "name": "Arteche",
    "lat": "12.2645",
    "lng": "125.4048"
  },
  {
    "country": "PH",
    "name": "Aroroy",
    "lat": "12.5111",
    "lng": "123.3977"
  },
  {
    "country": "PH",
    "name": "Arminia",
    "lat": "15.43563",
    "lng": "120.56379"
  },
  {
    "country": "PH",
    "name": "Armenia",
    "lat": "12.25324",
    "lng": "123.74361"
  },
  {
    "country": "PH",
    "name": "Aritao",
    "lat": "16.2979",
    "lng": "121.0345"
  },
  {
    "country": "PH",
    "name": "Aringay",
    "lat": "16.394",
    "lng": "120.3545"
  },
  {
    "country": "PH",
    "name": "Argao",
    "lat": "9.87944",
    "lng": "123.59556"
  },
  {
    "country": "PH",
    "name": "Arenas",
    "lat": "15.17042",
    "lng": "120.68571"
  },
  {
    "country": "PH",
    "name": "Arcangel",
    "lat": "11.5395",
    "lng": "122.3455"
  },
  {
    "country": "PH",
    "name": "Arayat",
    "lat": "15.1505",
    "lng": "120.7697"
  },
  {
    "country": "PH",
    "name": "Aras-asan",
    "lat": "8.88781",
    "lng": "126.3112"
  },
  {
    "country": "PH",
    "name": "Aranda",
    "lat": "10.2365",
    "lng": "122.9467"
  },
  {
    "country": "PH",
    "name": "Aranas Sur",
    "lat": "11.5635",
    "lng": "122.3901"
  },
  {
    "country": "PH",
    "name": "Aramawayan",
    "lat": "9.34247",
    "lng": "118.1623"
  },
  {
    "country": "PH",
    "name": "Aramayuan",
    "lat": "9.17008",
    "lng": "118.1872"
  },
  {
    "country": "PH",
    "name": "Araceli",
    "lat": "10.5529",
    "lng": "119.9913"
  },
  {
    "country": "PH",
    "name": "Araal",
    "lat": "10.4195",
    "lng": "123.0437"
  },
  {
    "country": "PH",
    "name": "Aquino",
    "lat": "11.8221",
    "lng": "122.1088"
  },
  {
    "country": "PH",
    "name": "Apurawan",
    "lat": "9.5994",
    "lng": "118.3489"
  },
  {
    "country": "PH",
    "name": "Apud",
    "lat": "13.13928",
    "lng": "123.29164"
  },
  {
    "country": "PH",
    "name": "Apoya",
    "lat": "9.2207",
    "lng": "122.9053"
  },
  {
    "country": "PH",
    "name": "Aplaya",
    "lat": "14.32106",
    "lng": "121.11369"
  },
  {
    "country": "PH",
    "name": "Santa Rita Aplaya",
    "lat": "13.77173",
    "lng": "121.03492"
  },
  {
    "country": "PH",
    "name": "Aplaya",
    "lat": "8.60861",
    "lng": "124.76806"
  },
  {
    "country": "PH",
    "name": "Apitong",
    "lat": "13.2391",
    "lng": "121.2075"
  },
  {
    "country": "PH",
    "name": "Aparri",
    "lat": "18.3566",
    "lng": "121.6406"
  },
  {
    "country": "PH",
    "name": "Apalit",
    "lat": "14.95333",
    "lng": "120.77"
  },
  {
    "country": "PH",
    "name": "Apad",
    "lat": "13.815",
    "lng": "122.7664"
  },
  {
    "country": "PH",
    "name": "Anuling",
    "lat": "14.12388",
    "lng": "120.8922"
  },
  {
    "country": "PH",
    "name": "Anuling",
    "lat": "6.03556",
    "lng": "121.00667"
  },
  {
    "country": "PH",
    "name": "Anulid",
    "lat": "15.82563",
    "lng": "120.48834"
  },
  {
    "country": "PH",
    "name": "Luna",
    "lat": "12.5492",
    "lng": "123.7336"
  },
  {
    "country": "PH",
    "name": "Antipolo",
    "lat": "15.6181",
    "lng": "121.19"
  },
  {
    "country": "PH",
    "name": "Antipolo",
    "lat": "14.62578",
    "lng": "121.12251"
  },
  {
    "country": "PH",
    "name": "Antipolo",
    "lat": "13.5286",
    "lng": "123.1622"
  },
  {
    "country": "PH",
    "name": "Antipolo",
    "lat": "13.3927",
    "lng": "123.5231"
  },
  {
    "country": "PH",
    "name": "Antipolo",
    "lat": "11.16667",
    "lng": "123.95"
  },
  {
    "country": "PH",
    "name": "Antipolo",
    "lat": "10.3565",
    "lng": "122.9646"
  },
  {
    "country": "PH",
    "name": "Anticala",
    "lat": "9.00444",
    "lng": "125.64528"
  },
  {
    "country": "PH",
    "name": "Antequera",
    "lat": "9.7809",
    "lng": "123.8988"
  },
  {
    "country": "PH",
    "name": "Antagan Segunda",
    "lat": "17.28268",
    "lng": "121.87153"
  },
  {
    "country": "PH",
    "name": "Anoring",
    "lat": "11.25",
    "lng": "123.03333"
  },
  {
    "country": "PH",
    "name": "Anopog",
    "lat": "10.25",
    "lng": "123.25"
  },
  {
    "country": "PH",
    "name": "Anonang",
    "lat": "11",
    "lng": "124.03333"
  },
  {
    "country": "PH",
    "name": "Anuling",
    "lat": "13.2093",
    "lng": "123.6761"
  },
  {
    "country": "PH",
    "name": "Anito",
    "lat": "12.44972",
    "lng": "125.28861"
  },
  {
    "country": "PH",
    "name": "Aanislag",
    "lat": "13.0748",
    "lng": "123.703"
  },
  {
    "country": "PH",
    "name": "Anini-y",
    "lat": "10.4312",
    "lng": "121.927"
  },
  {
    "country": "PH",
    "name": "Anilao",
    "lat": "12.71402",
    "lng": "121.51242"
  },
  {
    "country": "PH",
    "name": "Anilao",
    "lat": "10.97778",
    "lng": "122.75222"
  },
  {
    "country": "PH",
    "name": "Ani-e",
    "lat": "8.61361",
    "lng": "124.87056"
  },
  {
    "country": "PH",
    "name": "Anibongan",
    "lat": "7.39333",
    "lng": "125.71889"
  },
  {
    "country": "PH",
    "name": "Angono",
    "lat": "14.5266",
    "lng": "121.1536"
  },
  {
    "country": "PH",
    "name": "Angeles City",
    "lat": "15.15",
    "lng": "120.58333"
  },
  {
    "country": "PH",
    "name": "Angatel",
    "lat": "15.80589",
    "lng": "120.34326"
  },
  {
    "country": "PH",
    "name": "Angat",
    "lat": "14.9285",
    "lng": "121.03"
  },
  {
    "country": "PH",
    "name": "Angadanan",
    "lat": "16.75526",
    "lng": "121.74834"
  },
  {
    "country": "PH",
    "name": "Angad",
    "lat": "17.5849",
    "lng": "120.6257"
  },
  {
    "country": "PH",
    "name": "Andres Bonifacio",
    "lat": "10.91667",
    "lng": "123.25"
  },
  {
    "country": "PH",
    "name": "Andili",
    "lat": "7.462",
    "lng": "125.9701"
  },
  {
    "country": "PH",
    "name": "Anda",
    "lat": "16.2892",
    "lng": "119.95"
  },
  {
    "country": "PH",
    "name": "Anda",
    "lat": "9.746",
    "lng": "124.5767"
  },
  {
    "country": "PH",
    "name": "Anao",
    "lat": "15.7291",
    "lng": "120.6253"
  },
  {
    "country": "PH",
    "name": "Anao",
    "lat": "15.1415",
    "lng": "120.69136"
  },
  {
    "country": "PH",
    "name": "Anambongan",
    "lat": "15.86634",
    "lng": "120.38858"
  },
  {
    "country": "PH",
    "name": "Anakan",
    "lat": "8.84778",
    "lng": "125.15139"
  },
  {
    "country": "PH",
    "name": "Anahawan",
    "lat": "10.3429",
    "lng": "124.8782"
  },
  {
    "country": "PH",
    "name": "Anahawan",
    "lat": "10.27722",
    "lng": "125.2625"
  },
  {
    "country": "PH",
    "name": "Amuñgan",
    "lat": "15.3652",
    "lng": "119.9582"
  },
  {
    "country": "PH",
    "name": "Amulung",
    "lat": "17.8357",
    "lng": "121.72375"
  },
  {
    "country": "PH",
    "name": "Amucao",
    "lat": "15.46405",
    "lng": "120.68643"
  },
  {
    "country": "PH",
    "name": "Ampusungan",
    "lat": "16.7804",
    "lng": "120.7247"
  },
  {
    "country": "PH",
    "name": "Ampatuan",
    "lat": "6.86667",
    "lng": "124.46667"
  },
  {
    "country": "PH",
    "name": "Amlimay",
    "lat": "16.69377",
    "lng": "120.83704"
  },
  {
    "country": "PH",
    "name": "Amio",
    "lat": "9.3571",
    "lng": "122.9413"
  },
  {
    "country": "PH",
    "name": "Amdos",
    "lat": "9.8821",
    "lng": "123.0972"
  },
  {
    "country": "PH",
    "name": "Ambulong",
    "lat": "14.08804",
    "lng": "121.06127"
  },
  {
    "country": "PH",
    "name": "Ambuclao",
    "lat": "16.48333",
    "lng": "120.75"
  },
  {
    "country": "PH",
    "name": "Ambulong",
    "lat": "11.5793",
    "lng": "122.4987"
  },
  {
    "country": "PH",
    "name": "Amas",
    "lat": "7.05694",
    "lng": "124.98389"
  },
  {
    "country": "PH",
    "name": "Amagbagan",
    "lat": "16.0914",
    "lng": "120.5232"
  },
  {
    "country": "PH",
    "name": "Amaga",
    "lat": "8.53083",
    "lng": "126.07028"
  },
  {
    "country": "PH",
    "name": "Amadeo",
    "lat": "14.17056",
    "lng": "120.92361"
  },
  {
    "country": "PH",
    "name": "Amacalan",
    "lat": "15.5815",
    "lng": "120.6112"
  },
  {
    "country": "PH",
    "name": "Alupay",
    "lat": "13.84696",
    "lng": "121.30719"
  },
  {
    "country": "PH",
    "name": "Alugan",
    "lat": "12.2188",
    "lng": "125.4808"
  },
  {
    "country": "PH",
    "name": "Alubijid",
    "lat": "8.57333",
    "lng": "124.47361"
  },
  {
    "country": "PH",
    "name": "Alubijid",
    "lat": "8.96278",
    "lng": "125.42583"
  },
  {
    "country": "PH",
    "name": "Alua",
    "lat": "15.31154",
    "lng": "120.89433"
  },
  {
    "country": "PH",
    "name": "Altavas",
    "lat": "11.538",
    "lng": "122.487"
  },
  {
    "country": "PH",
    "name": "Aloleng",
    "lat": "16.1307",
    "lng": "119.7824"
  },
  {
    "country": "PH",
    "name": "Aloguinsan",
    "lat": "10.2219",
    "lng": "123.5483"
  },
  {
    "country": "PH",
    "name": "Almeria",
    "lat": "11.62028",
    "lng": "124.38167"
  },
  {
    "country": "PH",
    "name": "Almendras",
    "lat": "15.27576",
    "lng": "120.69873"
  },
  {
    "country": "PH",
    "name": "Almaguer North",
    "lat": "16.3497",
    "lng": "121.0926"
  },
  {
    "country": "PH",
    "name": "Almagro",
    "lat": "11.9109",
    "lng": "124.2858"
  },
  {
    "country": "PH",
    "name": "Allen",
    "lat": "12.5006",
    "lng": "124.2849"
  },
  {
    "country": "PH",
    "name": "Allangigan Primero",
    "lat": "17.17393",
    "lng": "120.49195"
  },
  {
    "country": "PH",
    "name": "Allacapan",
    "lat": "18.22598",
    "lng": "121.55615"
  },
  {
    "country": "PH",
    "name": "Alitagtag",
    "lat": "13.8645",
    "lng": "121.0041"
  },
  {
    "country": "PH",
    "name": "Alimono",
    "lat": "11.1855",
    "lng": "122.7129"
  },
  {
    "country": "PH",
    "name": "Alimodian",
    "lat": "10.82139",
    "lng": "122.43111"
  },
  {
    "country": "PH",
    "name": "Alemanguan",
    "lat": "10.61177",
    "lng": "119.3268"
  },
  {
    "country": "PH",
    "name": "Alim",
    "lat": "9.5649",
    "lng": "122.4876"
  },
  {
    "country": "PH",
    "name": "Alilem",
    "lat": "16.8861",
    "lng": "120.5304"
  },
  {
    "country": "PH",
    "name": "Alijis",
    "lat": "10.4583",
    "lng": "122.8348"
  },
  {
    "country": "PH",
    "name": "Alicia",
    "lat": "16.77936",
    "lng": "121.69734"
  },
  {
    "country": "PH",
    "name": "Alicia",
    "lat": "9.8949",
    "lng": "124.4422"
  },
  {
    "country": "PH",
    "name": "Alicia",
    "lat": "7.51389",
    "lng": "122.93"
  },
  {
    "country": "PH",
    "name": "Alicante",
    "lat": "10.89704",
    "lng": "123.0185"
  },
  {
    "country": "PH",
    "name": "Alibunan",
    "lat": "11.14652",
    "lng": "122.45911"
  },
  {
    "country": "PH",
    "name": "Alibug",
    "lat": "12.22906",
    "lng": "121.22811"
  },
  {
    "country": "PH",
    "name": "Alibago",
    "lat": "17.11667",
    "lng": "121.86667"
  },
  {
    "country": "PH",
    "name": "Aliang",
    "lat": "14.28333",
    "lng": "120.88333"
  },
  {
    "country": "PH",
    "name": "Aliaga",
    "lat": "15.5",
    "lng": "120.843"
  },
  {
    "country": "PH",
    "name": "Algeciras",
    "lat": "11.4154",
    "lng": "120.8168"
  },
  {
    "country": "PH",
    "name": "Alfonso",
    "lat": "14.14083",
    "lng": "120.85389"
  },
  {
    "country": "PH",
    "name": "Alpaco",
    "lat": "10.24378",
    "lng": "123.6825"
  },
  {
    "country": "PH",
    "name": "Alejal",
    "lat": "7.38417",
    "lng": "125.66"
  },
  {
    "country": "PH",
    "name": "Alegria",
    "lat": "12.3984",
    "lng": "124.3261"
  },
  {
    "country": "PH",
    "name": "Alegria",
    "lat": "10.64345",
    "lng": "123.0836"
  },
  {
    "country": "PH",
    "name": "Alegria",
    "lat": "9.7289",
    "lng": "123.3398"
  },
  {
    "country": "PH",
    "name": "Alegria",
    "lat": "9.46694",
    "lng": "125.57722"
  },
  {
    "country": "PH",
    "name": "Alegria",
    "lat": "8.50667",
    "lng": "126.01194"
  },
  {
    "country": "PH",
    "name": "Alcoy",
    "lat": "9.7102",
    "lng": "123.5067"
  },
  {
    "country": "PH",
    "name": "Alcantara",
    "lat": "12.2589",
    "lng": "122.0544"
  },
  {
    "country": "PH",
    "name": "Alcantara",
    "lat": "9.97556",
    "lng": "123.40611"
  },
  {
    "country": "PH",
    "name": "Alcala",
    "lat": "17.9021",
    "lng": "121.65595"
  },
  {
    "country": "PH",
    "name": "Alcala",
    "lat": "15.84722",
    "lng": "120.52417"
  },
  {
    "country": "PH",
    "name": "Alburquerque",
    "lat": "9.60806",
    "lng": "123.95806"
  },
  {
    "country": "PH",
    "name": "Albuera",
    "lat": "10.9158",
    "lng": "124.6945"
  },
  {
    "country": "PH",
    "name": "Alayao",
    "lat": "14.2818",
    "lng": "122.5524"
  },
  {
    "country": "PH",
    "name": "Alannay",
    "lat": "18.06114",
    "lng": "121.58616"
  },
  {
    "country": "PH",
    "name": "Alanib",
    "lat": "8.02778",
    "lng": "124.98611"
  },
  {
    "country": "PH",
    "name": "Alangilanan",
    "lat": "9.642",
    "lng": "123.1059"
  },
  {
    "country": "PH",
    "name": "Alangilan",
    "lat": "9.2793",
    "lng": "122.8789"
  },
  {
    "country": "PH",
    "name": "Alangalang",
    "lat": "11.20611",
    "lng": "124.84667"
  },
  {
    "country": "PH",
    "name": "Alaminos",
    "lat": "16.15611",
    "lng": "119.98111"
  },
  {
    "country": "PH",
    "name": "Alaminos",
    "lat": "14.06391",
    "lng": "121.24649"
  },
  {
    "country": "PH",
    "name": "Alamada",
    "lat": "7.33333",
    "lng": "124.56667"
  },
  {
    "country": "PH",
    "name": "Alae",
    "lat": "8.42444",
    "lng": "124.81278"
  },
  {
    "country": "PH",
    "name": "Alad",
    "lat": "12.61682",
    "lng": "122.24751"
  },
  {
    "country": "PH",
    "name": "Alacaygan",
    "lat": "10.84014",
    "lng": "123.0583"
  },
  {
    "country": "PH",
    "name": "Alac",
    "lat": "15.9877",
    "lng": "120.8065"
  },
  {
    "country": "PH",
    "name": "Alabug",
    "lat": "17.73261",
    "lng": "121.46773"
  },
  {
    "country": "PH",
    "name": "Alabel",
    "lat": "6.10179",
    "lng": "125.29048"
  },
  {
    "country": "PH",
    "name": "Alabat",
    "lat": "14.101",
    "lng": "122.0125"
  },
  {
    "country": "PH",
    "name": "Akle",
    "lat": "15.0482",
    "lng": "121.0733"
  },
  {
    "country": "PH",
    "name": "Ajuy",
    "lat": "11.1724",
    "lng": "123.0197"
  },
  {
    "country": "PH",
    "name": "Agutaya",
    "lat": "11.148",
    "lng": "120.9417"
  },
  {
    "country": "PH",
    "name": "Agusan",
    "lat": "8.49056",
    "lng": "124.73722"
  },
  {
    "country": "PH",
    "name": "Agupit",
    "lat": "13.4225",
    "lng": "123.32472"
  },
  {
    "country": "PH",
    "name": "Aguisan",
    "lat": "10.1603",
    "lng": "122.8615"
  },
  {
    "country": "PH",
    "name": "Aguining",
    "lat": "10.0861",
    "lng": "124.5944"
  },
  {
    "country": "PH",
    "name": "Aguilar",
    "lat": "15.8884",
    "lng": "120.2378"
  },
  {
    "country": "PH",
    "name": "Aguada",
    "lat": "12.81667",
    "lng": "123.83333"
  },
  {
    "country": "PH",
    "name": "Agsungot",
    "lat": "10.43444",
    "lng": "123.90611"
  },
  {
    "country": "PH",
    "name": "Agpangi",
    "lat": "10.57716",
    "lng": "123.4232"
  },
  {
    "country": "PH",
    "name": "Agos",
    "lat": "13.3434",
    "lng": "123.3983"
  },
  {
    "country": "PH",
    "name": "Agoo",
    "lat": "16.3228",
    "lng": "120.3666"
  },
  {
    "country": "PH",
    "name": "Agoo",
    "lat": "16.08333",
    "lng": "120.1"
  },
  {
    "country": "PH",
    "name": "Agoncillo",
    "lat": "13.93556",
    "lng": "120.93261"
  },
  {
    "country": "PH",
    "name": "Agno",
    "lat": "16.1161",
    "lng": "119.7993"
  },
  {
    "country": "PH",
    "name": "Aglipay",
    "lat": "16.4889",
    "lng": "121.645"
  },
  {
    "country": "PH",
    "name": "Aglayan",
    "lat": "8.055",
    "lng": "125.13417"
  },
  {
    "country": "PH",
    "name": "Aglalana",
    "lat": "11.1803",
    "lng": "122.6574"
  },
  {
    "country": "PH",
    "name": "Aggugaddah",
    "lat": "17.70016",
    "lng": "121.8025"
  },
  {
    "country": "PH",
    "name": "Agdangan",
    "lat": "13.8771",
    "lng": "121.91305"
  },
  {
    "country": "PH",
    "name": "Agbannawag",
    "lat": "17.37641",
    "lng": "121.5478"
  },
  {
    "country": "PH",
    "name": "Agbannawag",
    "lat": "15.6792",
    "lng": "121.0833"
  },
  {
    "country": "PH",
    "name": "Agay",
    "lat": "9.05361",
    "lng": "125.58667"
  },
  {
    "country": "PH",
    "name": "Aganan",
    "lat": "10.78333",
    "lng": "122.53333"
  },
  {
    "country": "PH",
    "name": "Ag-ambulong",
    "lat": "11.3684",
    "lng": "122.5094"
  },
  {
    "country": "PH",
    "name": "Aga",
    "lat": "14.0965",
    "lng": "120.80217"
  },
  {
    "country": "PH",
    "name": "Afusing Centro",
    "lat": "17.8526",
    "lng": "121.6269"
  },
  {
    "country": "PH",
    "name": "Adtugan",
    "lat": "7.81194",
    "lng": "124.85444"
  },
  {
    "country": "PH",
    "name": "Adlay",
    "lat": "9.40972",
    "lng": "125.8975"
  },
  {
    "country": "PH",
    "name": "Adlaon",
    "lat": "10.3",
    "lng": "123.9"
  },
  {
    "country": "PH",
    "name": "Adela",
    "lat": "12.44164",
    "lng": "120.97291"
  },
  {
    "country": "PH",
    "name": "Adams",
    "lat": "18.46667",
    "lng": "120.9"
  },
  {
    "country": "PH",
    "name": "Acli",
    "lat": "15.12279",
    "lng": "120.6447"
  },
  {
    "country": "PH",
    "name": "Accusilian",
    "lat": "17.74791",
    "lng": "121.46254"
  },
  {
    "country": "PH",
    "name": "Acao",
    "lat": "16.52556",
    "lng": "120.37639"
  },
  {
    "country": "PH",
    "name": "Abuyon",
    "lat": "13.6226",
    "lng": "122.5191"
  },
  {
    "country": "PH",
    "name": "Abuyog",
    "lat": "12.9461",
    "lng": "124.0519"
  },
  {
    "country": "PH",
    "name": "Abuyog",
    "lat": "10.747",
    "lng": "125.0107"
  },
  {
    "country": "PH",
    "name": "Abut",
    "lat": "17.35423",
    "lng": "121.60138"
  },
  {
    "country": "PH",
    "name": "Abulug",
    "lat": "18.44528",
    "lng": "121.45333"
  },
  {
    "country": "PH",
    "name": "Abucayan",
    "lat": "9.929",
    "lng": "123.9146"
  },
  {
    "country": "PH",
    "name": "Abucay",
    "lat": "14.73347",
    "lng": "120.53358"
  },
  {
    "country": "PH",
    "name": "Abucay",
    "lat": "12.982",
    "lng": "123.6492"
  },
  {
    "country": "PH",
    "name": "Abra de Ilog",
    "lat": "13.4437",
    "lng": "120.7291"
  },
  {
    "country": "PH",
    "name": "Aborlan",
    "lat": "9.43361",
    "lng": "118.54879"
  },
  {
    "country": "PH",
    "name": "Abis",
    "lat": "9.7173",
    "lng": "122.9438"
  },
  {
    "country": "PH",
    "name": "Abilay",
    "lat": "10.73333",
    "lng": "122.5"
  },
  {
    "country": "PH",
    "name": "Abiera",
    "lat": "11.5749",
    "lng": "122.09"
  },
  {
    "country": "PH",
    "name": "Abangay",
    "lat": "10.96667",
    "lng": "122.65"
  },
  {
    "country": "PH",
    "name": "Abaca",
    "lat": "11.1342",
    "lng": "122.7156"
  },
  {
    "country": "PH",
    "name": "Abaca",
    "lat": "9.9204",
    "lng": "124.5051"
  },
  {
    "country": "PH",
    "name": "Tolosa",
    "lat": "7.03222",
    "lng": "122.16139"
  },
  {
    "country": "PH",
    "name": "Sangali",
    "lat": "7.06944",
    "lng": "122.20139"
  },
  {
    "country": "PH",
    "name": "Lamisahan",
    "lat": "7.07083",
    "lng": "122.15833"
  },
  {
    "country": "PH",
    "name": "Dulian",
    "lat": "7.12139",
    "lng": "122.17889"
  },
  {
    "country": "PH",
    "name": "Landang Laum",
    "lat": "6.96889",
    "lng": "122.24917"
  },
  {
    "country": "PH",
    "name": "Talabaan",
    "lat": "6.94111",
    "lng": "122.17222"
  },
  {
    "country": "PH",
    "name": "Tablas",
    "lat": "6.62917",
    "lng": "122.17472"
  },
  {
    "country": "PH",
    "name": "Mangusu",
    "lat": "7.32556",
    "lng": "122.2775"
  },
  {
    "country": "PH",
    "name": "Sibulao",
    "lat": "7.32417",
    "lng": "122.23944"
  },
  {
    "country": "PH",
    "name": "Batu",
    "lat": "7.75333",
    "lng": "122.82944"
  },
  {
    "country": "PH",
    "name": "Laparay",
    "lat": "7.40361",
    "lng": "122.81722"
  },
  {
    "country": "PH",
    "name": "Monching",
    "lat": "7.71583",
    "lng": "122.86639"
  },
  {
    "country": "PH",
    "name": "Dalangin",
    "lat": "7.85056",
    "lng": "122.57833"
  },
  {
    "country": "PH",
    "name": "Tigpalay",
    "lat": "7.49479",
    "lng": "122.34496"
  },
  {
    "country": "PH",
    "name": "Tunggol",
    "lat": "5.84458",
    "lng": "121.15436"
  },
  {
    "country": "PH",
    "name": "Marsada",
    "lat": "5.93139",
    "lng": "121.10694"
  },
  {
    "country": "PH",
    "name": "Talipaw",
    "lat": "5.91",
    "lng": "121.09444"
  },
  {
    "country": "PH",
    "name": "Katipunan",
    "lat": "7.5825",
    "lng": "122.83056"
  },
  {
    "country": "PH",
    "name": "Sanga-Sanga",
    "lat": "5.0725",
    "lng": "119.78528"
  },
  {
    "country": "PH",
    "name": "Ungus-Ungus",
    "lat": "5.05083",
    "lng": "119.83972"
  },
  {
    "country": "PH",
    "name": "Binuang",
    "lat": "5.95694",
    "lng": "121.06"
  },
  {
    "country": "PH",
    "name": "Pandakan",
    "lat": "5.98889",
    "lng": "121.16583"
  },
  {
    "country": "PH",
    "name": "Mauboh",
    "lat": "5.99",
    "lng": "121.09361"
  },
  {
    "country": "PH",
    "name": "Kulase",
    "lat": "5.9052",
    "lng": "120.9569"
  },
  {
    "country": "PH",
    "name": "Kalang",
    "lat": "5.91972",
    "lng": "121.36306"
  },
  {
    "country": "PH",
    "name": "Andalan",
    "lat": "5.95944",
    "lng": "121.39028"
  },
  {
    "country": "PH",
    "name": "Buansa",
    "lat": "6.0258",
    "lng": "120.9614"
  },
  {
    "country": "PH",
    "name": "Kajatian",
    "lat": "6.03111",
    "lng": "120.99194"
  },
  {
    "country": "PH",
    "name": "Bato Bato",
    "lat": "6.0344",
    "lng": "120.9463"
  },
  {
    "country": "PH",
    "name": "Sionogan",
    "lat": "6.00528",
    "lng": "120.94861"
  },
  {
    "country": "PH",
    "name": "Payuhan",
    "lat": "5.94167",
    "lng": "120.90111"
  },
  {
    "country": "PH",
    "name": "Buan",
    "lat": "5.5508",
    "lng": "120.8815"
  },
  {
    "country": "PH",
    "name": "Kungtad",
    "lat": "5.5572",
    "lng": "120.8472"
  },
  {
    "country": "PH",
    "name": "La Dicha",
    "lat": "7.676",
    "lng": "123.0023"
  },
  {
    "country": "PH",
    "name": "Del Monte",
    "lat": "7.72583",
    "lng": "123.00806"
  },
  {
    "country": "PH",
    "name": "Kalian",
    "lat": "7.5916",
    "lng": "123.2319"
  },
  {
    "country": "PH",
    "name": "Lumbog",
    "lat": "7.5581",
    "lng": "123.2014"
  },
  {
    "country": "PH",
    "name": "Tiguha",
    "lat": "7.70444",
    "lng": "123.21139"
  },
  {
    "country": "PH",
    "name": "Sagacad",
    "lat": "7.68611",
    "lng": "123.34056"
  },
  {
    "country": "PH",
    "name": "East Migpulao",
    "lat": "7.6325",
    "lng": "123.35917"
  },
  {
    "country": "PH",
    "name": "Binuatan",
    "lat": "7.61222",
    "lng": "123.34417"
  },
  {
    "country": "PH",
    "name": "Guiniculalay",
    "lat": "7.65611",
    "lng": "123.39139"
  },
  {
    "country": "PH",
    "name": "Danlugan",
    "lat": "7.89139",
    "lng": "123.37278"
  },
  {
    "country": "PH",
    "name": "Kagawasan",
    "lat": "7.86611",
    "lng": "123.395"
  },
  {
    "country": "PH",
    "name": "Lapining",
    "lat": "7.9227",
    "lng": "123.6883"
  },
  {
    "country": "PH",
    "name": "Margos",
    "lat": "7.932",
    "lng": "123.659"
  },
  {
    "country": "PH",
    "name": "Taguitic",
    "lat": "7.9387",
    "lng": "123.6312"
  },
  {
    "country": "PH",
    "name": "Sumalig",
    "lat": "7.9986",
    "lng": "123.6627"
  },
  {
    "country": "PH",
    "name": "Gubaan",
    "lat": "7.9748",
    "lng": "123.564"
  },
  {
    "country": "PH",
    "name": "Lanipao",
    "lat": "7.95528",
    "lng": "123.77667"
  },
  {
    "country": "PH",
    "name": "Maranding",
    "lat": "7.9248",
    "lng": "123.7715"
  },
  {
    "country": "PH",
    "name": "Rebe",
    "lat": "7.9076",
    "lng": "123.8155"
  },
  {
    "country": "PH",
    "name": "Panubigan",
    "lat": "7.4281",
    "lng": "123.3466"
  },
  {
    "country": "PH",
    "name": "Malim",
    "lat": "7.452",
    "lng": "123.4312"
  },
  {
    "country": "PH",
    "name": "Kapalong",
    "lat": "7.77056",
    "lng": "125.55861"
  },
  {
    "country": "PH",
    "name": "Andop",
    "lat": "7.86111",
    "lng": "125.75389"
  },
  {
    "country": "PH",
    "name": "Concepcion",
    "lat": "7.75056",
    "lng": "125.71194"
  },
  {
    "country": "PH",
    "name": "Kaligutan",
    "lat": "7.70306",
    "lng": "125.81306"
  },
  {
    "country": "PH",
    "name": "Del Pilar",
    "lat": "7.56306",
    "lng": "125.82667"
  },
  {
    "country": "PH",
    "name": "Tagnanan",
    "lat": "7.28361",
    "lng": "125.84222"
  },
  {
    "country": "PH",
    "name": "Camudmud",
    "lat": "7.17611",
    "lng": "125.69333"
  },
  {
    "country": "PH",
    "name": "Maduao",
    "lat": "7.29417",
    "lng": "125.62583"
  },
  {
    "country": "PH",
    "name": "Katipunan",
    "lat": "7.32028",
    "lng": "125.62028"
  },
  {
    "country": "PH",
    "name": "San Remigio",
    "lat": "6.92306",
    "lng": "125.77583"
  },
  {
    "country": "PH",
    "name": "Bonbon",
    "lat": "9.10528",
    "lng": "124.73389"
  },
  {
    "country": "PH",
    "name": "Balas",
    "lat": "15.04998",
    "lng": "120.58611"
  },
  {
    "country": "PH",
    "name": "Magliman",
    "lat": "15.03545",
    "lng": "120.66421"
  },
  {
    "country": "PH",
    "name": "Motrico",
    "lat": "15.41355",
    "lng": "120.67653"
  },
  {
    "country": "PH",
    "name": "San Pascual",
    "lat": "15.50152",
    "lng": "120.66718"
  },
  {
    "country": "PH",
    "name": "Santo Niño",
    "lat": "15.23664",
    "lng": "120.71204"
  },
  {
    "country": "PH",
    "name": "Capitan Ramon",
    "lat": "10.7602",
    "lng": "123.1148"
  },
  {
    "country": "PH",
    "name": "Malusay",
    "lat": "10.1439",
    "lng": "123.2717"
  },
  {
    "country": "PH",
    "name": "Del Pilar",
    "lat": "15.6956",
    "lng": "121.0863"
  },
  {
    "country": "PH",
    "name": "Bulihan",
    "lat": "14.2782",
    "lng": "120.99503"
  },
  {
    "country": "PH",
    "name": "Magsaysay",
    "lat": "14.3388",
    "lng": "121.0341"
  },
  {
    "country": "PH",
    "name": "Gulod",
    "lat": "14.3449",
    "lng": "121.2177"
  },
  {
    "country": "PH",
    "name": "Badak",
    "lat": "6.84722",
    "lng": "124.72056"
  },
  {
    "country": "PH",
    "name": "Bagong Pagasa",
    "lat": "14.6627",
    "lng": "121.0328"
  },
  {
    "country": "PH",
    "name": "Lim-oo",
    "lat": "11.15083",
    "lng": "124.63083"
  },
  {
    "country": "PH",
    "name": "Ibung",
    "lat": "16.60938",
    "lng": "121.18614"
  },
  {
    "country": "PH",
    "name": "Damabalas",
    "lat": "7.01556",
    "lng": "124.51417"
  },
  {
    "country": "PH",
    "name": "Esperanza",
    "lat": "6.49804",
    "lng": "124.66741"
  },
  {
    "country": "PH",
    "name": "Makir",
    "lat": "7.03083",
    "lng": "124.30417"
  },
  {
    "country": "PH",
    "name": "Nunguan",
    "lat": "7.12825",
    "lng": "124.68912"
  },
  {
    "country": "PH",
    "name": "Basiawan",
    "lat": "6.53417",
    "lng": "125.48694"
  },
  {
    "country": "PH",
    "name": "Lumbac",
    "lat": "7.73417",
    "lng": "124.25278"
  },
  {
    "country": "PH",
    "name": "Pagalungan",
    "lat": "6.26556",
    "lng": "125.01333"
  },
  {
    "country": "PH",
    "name": "Malandag",
    "lat": "6.3103",
    "lng": "125.24756"
  },
  {
    "country": "PH",
    "name": "Malingao",
    "lat": "7.16083",
    "lng": "124.475"
  },
  {
    "country": "PH",
    "name": "Dado",
    "lat": "7.05",
    "lng": "124.45972"
  },
  {
    "country": "PH",
    "name": "Molundo",
    "lat": "7.93861",
    "lng": "124.37028"
  },
  {
    "country": "PH",
    "name": "Simuay",
    "lat": "7.27722",
    "lng": "124.30722"
  },
  {
    "country": "PH",
    "name": "Bualan",
    "lat": "7.44778",
    "lng": "124.2675"
  },
  {
    "country": "PH",
    "name": "Mataya",
    "lat": "7.47111",
    "lng": "124.37194"
  },
  {
    "country": "PH",
    "name": "Nuyo",
    "lat": "7.41806",
    "lng": "124.41083"
  },
  {
    "country": "PH",
    "name": "Tuka",
    "lat": "6.51862",
    "lng": "124.58736"
  },
  {
    "country": "PH",
    "name": "Busok",
    "lat": "6.5082",
    "lng": "124.60009"
  },
  {
    "country": "PH",
    "name": "Lopez Jaena",
    "lat": "6.47591",
    "lng": "124.69828"
  },
  {
    "country": "PH",
    "name": "Lambontong",
    "lat": "6.30833",
    "lng": "124.81056"
  },
  {
    "country": "PH",
    "name": "Daguma",
    "lat": "6.60345",
    "lng": "124.5702"
  },
  {
    "country": "PH",
    "name": "Kapaya",
    "lat": "6.54258",
    "lng": "124.56314"
  },
  {
    "country": "PH",
    "name": "Simod",
    "lat": "7.47583",
    "lng": "125.34083"
  },
  {
    "country": "PH",
    "name": "Pasig City",
    "lat": "14.58691",
    "lng": "121.0614"
  },
  {
    "country": "PH",
    "name": "Tubo",
    "lat": "17.2667",
    "lng": "120.7355"
  },
  {
    "country": "PH",
    "name": "Sambayanihan People's Village",
    "lat": "14.45558",
    "lng": "120.99816"
  },
  {
    "country": "PH",
    "name": "Tabuk",
    "lat": "17.4084",
    "lng": "121.2785"
  },
  {
    "country": "PH",
    "name": "Pandan",
    "lat": "11.74479",
    "lng": "122.10027"
  },
  {
    "country": "PH",
    "name": "Subic Bay Freeport Zone",
    "lat": "14.78899",
    "lng": "120.27987"
  },
  {
    "country": "PH",
    "name": "Cambarus",
    "lat": "10.21342",
    "lng": "122.52117"
  },
  {
    "country": "PH",
    "name": "Hanggan",
    "lat": "14.18871",
    "lng": "121.30009"
  },
  {
    "country": "PH",
    "name": "City of Ligao",
    "lat": "13.21684",
    "lng": "123.51418"
  },
  {
    "country": "PH",
    "name": "Paranas",
    "lat": "11.85022",
    "lng": "125.11531"
  },
  {
    "country": "PH",
    "name": "Apas",
    "lat": "10.34076",
    "lng": "123.90261"
  },
  {
    "country": "PH",
    "name": "Roseller Lim",
    "lat": "7.65605",
    "lng": "122.46714"
  },
  {
    "country": "PK",
    "name": "Chuhar Jamali",
    "lat": "24.3944",
    "lng": "67.99298"
  },
  {
    "country": "PK",
    "name": "Timargara",
    "lat": "34.82659",
    "lng": "71.84423"
  },
  {
    "country": "PK",
    "name": "Rawala Kot",
    "lat": "33.85782",
    "lng": "73.76043"
  },
  {
    "country": "PK",
    "name": "Pir Jo Goth",
    "lat": "27.59178",
    "lng": "68.61848"
  },
  {
    "country": "PK",
    "name": "Khairpur Mir’s",
    "lat": "27.52948",
    "lng": "68.75915"
  },
  {
    "country": "PK",
    "name": "Adilpur",
    "lat": "27.93677",
    "lng": "69.31941"
  },
  {
    "country": "PK",
    "name": "Ziarat",
    "lat": "30.38244",
    "lng": "67.72562"
  },
  {
    "country": "PK",
    "name": "Zhob",
    "lat": "31.34082",
    "lng": "69.4493"
  },
  {
    "country": "PK",
    "name": "Zaida",
    "lat": "34.0595",
    "lng": "72.4669"
  },
  {
    "country": "PK",
    "name": "Zahir Pir",
    "lat": "28.81284",
    "lng": "70.52341"
  },
  {
    "country": "PK",
    "name": "Zafarwal",
    "lat": "32.34464",
    "lng": "74.8999"
  },
  {
    "country": "PK",
    "name": "Yazman",
    "lat": "29.12122",
    "lng": "71.74459"
  },
  {
    "country": "PK",
    "name": "Wazirabad",
    "lat": "32.44324",
    "lng": "74.12"
  },
  {
    "country": "PK",
    "name": "Chak Five Hundred Seventy-five",
    "lat": "31.54514",
    "lng": "73.82891"
  },
  {
    "country": "PK",
    "name": "Warah",
    "lat": "27.44805",
    "lng": "67.79654"
  },
  {
    "country": "PK",
    "name": "Wana",
    "lat": "32.29889",
    "lng": "69.5725"
  },
  {
    "country": "PK",
    "name": "Vihari",
    "lat": "30.0445",
    "lng": "72.3556"
  },
  {
    "country": "PK",
    "name": "Utmanzai",
    "lat": "34.18775",
    "lng": "71.76274"
  },
  {
    "country": "PK",
    "name": "Uthal",
    "lat": "25.80722",
    "lng": "66.62194"
  },
  {
    "country": "PK",
    "name": "Usta Muhammad",
    "lat": "28.17723",
    "lng": "68.04367"
  },
  {
    "country": "PK",
    "name": "Umarkot",
    "lat": "25.36329",
    "lng": "69.74184"
  },
  {
    "country": "PK",
    "name": "Ubauro",
    "lat": "28.16429",
    "lng": "69.73114"
  },
  {
    "country": "PK",
    "name": "Turbat",
    "lat": "26.00122",
    "lng": "63.04849"
  },
  {
    "country": "PK",
    "name": "Topi",
    "lat": "34.07034",
    "lng": "72.62147"
  },
  {
    "country": "PK",
    "name": "Toba Tek Singh",
    "lat": "30.97127",
    "lng": "72.48275"
  },
  {
    "country": "PK",
    "name": "Thul",
    "lat": "28.2403",
    "lng": "68.7755"
  },
  {
    "country": "PK",
    "name": "Thatta",
    "lat": "24.74745",
    "lng": "67.92353"
  },
  {
    "country": "PK",
    "name": "Tharu Shah",
    "lat": "26.9423",
    "lng": "68.11759"
  },
  {
    "country": "PK",
    "name": "Taunsa",
    "lat": "30.70358",
    "lng": "70.65054"
  },
  {
    "country": "PK",
    "name": "Tank",
    "lat": "32.21707",
    "lng": "70.38315"
  },
  {
    "country": "PK",
    "name": "Tangwani",
    "lat": "28.27886",
    "lng": "68.9976"
  },
  {
    "country": "PK",
    "name": "Tangi",
    "lat": "34.3009",
    "lng": "71.65238"
  },
  {
    "country": "PK",
    "name": "Tando Muhammad Khan",
    "lat": "25.12384",
    "lng": "68.53677"
  },
  {
    "country": "PK",
    "name": "Tando Mitha Khan",
    "lat": "25.99625",
    "lng": "69.20251"
  },
  {
    "country": "PK",
    "name": "Tando Jam",
    "lat": "25.42813",
    "lng": "68.52923"
  },
  {
    "country": "PK",
    "name": "Tando Bago",
    "lat": "24.78914",
    "lng": "68.96535"
  },
  {
    "country": "PK",
    "name": "Tando Allahyar",
    "lat": "25.4605",
    "lng": "68.71745"
  },
  {
    "country": "PK",
    "name": "Tando Adam",
    "lat": "25.76818",
    "lng": "68.66196"
  },
  {
    "country": "PK",
    "name": "Tandlianwala",
    "lat": "31.03359",
    "lng": "73.13268"
  },
  {
    "country": "PK",
    "name": "Talhar",
    "lat": "24.88454",
    "lng": "68.81437"
  },
  {
    "country": "PK",
    "name": "Talamba",
    "lat": "30.52693",
    "lng": "72.24079"
  },
  {
    "country": "PK",
    "name": "Talagang",
    "lat": "32.92766",
    "lng": "72.41594"
  },
  {
    "country": "PK",
    "name": "Thal",
    "lat": "35.47836",
    "lng": "72.24383"
  },
  {
    "country": "PK",
    "name": "Swabi",
    "lat": "34.12018",
    "lng": "72.46982"
  },
  {
    "country": "PK",
    "name": "Surkhpur",
    "lat": "32.71816",
    "lng": "74.44773"
  },
  {
    "country": "PK",
    "name": "Surab",
    "lat": "28.49276",
    "lng": "66.25999"
  },
  {
    "country": "PK",
    "name": "Sukkur",
    "lat": "27.70323",
    "lng": "68.85889"
  },
  {
    "country": "PK",
    "name": "Sukheke Mandi",
    "lat": "31.86541",
    "lng": "73.50875"
  },
  {
    "country": "PK",
    "name": "Sohbatpur",
    "lat": "28.52038",
    "lng": "68.54298"
  },
  {
    "country": "PK",
    "name": "Sodhri",
    "lat": "32.46211",
    "lng": "74.18207"
  },
  {
    "country": "PK",
    "name": "Sobhodero",
    "lat": "27.30475",
    "lng": "68.39715"
  },
  {
    "country": "PK",
    "name": "Skardu",
    "lat": "35.29787",
    "lng": "75.63372"
  },
  {
    "country": "PK",
    "name": "Sīta Road",
    "lat": "27.03333",
    "lng": "67.85"
  },
  {
    "country": "PK",
    "name": "Sinjhoro",
    "lat": "26.03008",
    "lng": "68.80867"
  },
  {
    "country": "PK",
    "name": "Sillanwali",
    "lat": "31.82539",
    "lng": "72.54064"
  },
  {
    "country": "PK",
    "name": "Sibi",
    "lat": "29.54299",
    "lng": "67.87726"
  },
  {
    "country": "PK",
    "name": "Sialkot",
    "lat": "32.49268",
    "lng": "74.53134"
  },
  {
    "country": "PK",
    "name": "Shujaabad",
    "lat": "29.88092",
    "lng": "71.29344"
  },
  {
    "country": "PK",
    "name": "Shorkot",
    "lat": "31.91023",
    "lng": "70.87757"
  },
  {
    "country": "PK",
    "name": "Shinpokh",
    "lat": "34.32959",
    "lng": "71.17852"
  },
  {
    "country": "PK",
    "name": "Shikarpur",
    "lat": "27.95558",
    "lng": "68.63823"
  },
  {
    "country": "PK",
    "name": "Shekhupura",
    "lat": "31.71287",
    "lng": "73.98556"
  },
  {
    "country": "PK",
    "name": "Sharqpur Sharif",
    "lat": "31.46116",
    "lng": "74.10091"
  },
  {
    "country": "PK",
    "name": "Shakargarh",
    "lat": "32.26361",
    "lng": "75.16008"
  },
  {
    "country": "PK",
    "name": "Shahr Sultan",
    "lat": "29.57517",
    "lng": "71.02209"
  },
  {
    "country": "PK",
    "name": "Shahpur Chakar",
    "lat": "26.15411",
    "lng": "68.65013"
  },
  {
    "country": "PK",
    "name": "Shahpur",
    "lat": "32.2682",
    "lng": "72.46884"
  },
  {
    "country": "PK",
    "name": "Shahkot",
    "lat": "31.5709",
    "lng": "73.48531"
  },
  {
    "country": "PK",
    "name": "Shahdadpur",
    "lat": "25.92539",
    "lng": "68.6228"
  },
  {
    "country": "PK",
    "name": "Shahdad Kot",
    "lat": "27.84726",
    "lng": "67.90679"
  },
  {
    "country": "PK",
    "name": "Shabqadar",
    "lat": "34.21599",
    "lng": "71.5548"
  },
  {
    "country": "PK",
    "name": "Sehwan",
    "lat": "26.42495",
    "lng": "67.86126"
  },
  {
    "country": "PK",
    "name": "Sargodha",
    "lat": "32.08586",
    "lng": "72.67418"
  },
  {
    "country": "PK",
    "name": "Sarai Sidhu",
    "lat": "30.59476",
    "lng": "71.9699"
  },
  {
    "country": "PK",
    "name": "Sarai Naurang",
    "lat": "32.82581",
    "lng": "70.78107"
  },
  {
    "country": "PK",
    "name": "Sarai Alamgir",
    "lat": "32.90495",
    "lng": "73.75518"
  },
  {
    "country": "PK",
    "name": "Sann",
    "lat": "26.0403",
    "lng": "68.13763"
  },
  {
    "country": "PK",
    "name": "Sanjwal",
    "lat": "33.76105",
    "lng": "72.43315"
  },
  {
    "country": "PK",
    "name": "Sangla Hill",
    "lat": "31.71667",
    "lng": "73.38333"
  },
  {
    "country": "PK",
    "name": "Sanghar",
    "lat": "26.04694",
    "lng": "68.94917"
  },
  {
    "country": "PK",
    "name": "Sambrial",
    "lat": "32.47835",
    "lng": "74.35338"
  },
  {
    "country": "PK",
    "name": "Samaro",
    "lat": "25.28143",
    "lng": "69.39623"
  },
  {
    "country": "PK",
    "name": "Sakrand",
    "lat": "26.13845",
    "lng": "68.27444"
  },
  {
    "country": "PK",
    "name": "Saidu Sharif",
    "lat": "34.74655",
    "lng": "72.35568"
  },
  {
    "country": "PK",
    "name": "Sahiwal",
    "lat": "31.97386",
    "lng": "72.33109"
  },
  {
    "country": "PK",
    "name": "Sahiwal",
    "lat": "30.66595",
    "lng": "73.10186"
  },
  {
    "country": "PK",
    "name": "Saddiqabad",
    "lat": "28.3091",
    "lng": "70.12652"
  },
  {
    "country": "PK",
    "name": "Rustam",
    "lat": "27.96705",
    "lng": "68.80386"
  },
  {
    "country": "PK",
    "name": "Rojhan",
    "lat": "28.68735",
    "lng": "69.9535"
  },
  {
    "country": "PK",
    "name": "Rohri",
    "lat": "27.69203",
    "lng": "68.89503"
  },
  {
    "country": "PK",
    "name": "Renala Khurd",
    "lat": "30.87878",
    "lng": "73.59857"
  },
  {
    "country": "PK",
    "name": "Rawalpindi",
    "lat": "33.59733",
    "lng": "73.0479"
  },
  {
    "country": "PK",
    "name": "Ratodero",
    "lat": "27.80227",
    "lng": "68.28902"
  },
  {
    "country": "PK",
    "name": "Rasulnagar",
    "lat": "32.32794",
    "lng": "73.7804"
  },
  {
    "country": "PK",
    "name": "Ranipur",
    "lat": "27.2872",
    "lng": "68.50623"
  },
  {
    "country": "PK",
    "name": "Rajo Khanani",
    "lat": "24.98391",
    "lng": "68.8537"
  },
  {
    "country": "PK",
    "name": "Rajanpur",
    "lat": "29.10408",
    "lng": "70.32969"
  },
  {
    "country": "PK",
    "name": "Raja Jang",
    "lat": "31.22078",
    "lng": "74.25483"
  },
  {
    "country": "PK",
    "name": "Raiwind",
    "lat": "31.24895",
    "lng": "74.21534"
  },
  {
    "country": "PK",
    "name": "Rahim Yar Khan",
    "lat": "28.41987",
    "lng": "70.30345"
  },
  {
    "country": "PK",
    "name": "Goth Radhan",
    "lat": "27.19846",
    "lng": "67.95348"
  },
  {
    "country": "PK",
    "name": "Chenab Nagar",
    "lat": "31.75511",
    "lng": "72.91403"
  },
  {
    "country": "PK",
    "name": "Quetta",
    "lat": "30.18414",
    "lng": "67.00141"
  },
  {
    "country": "PK",
    "name": "Qila Saifullah",
    "lat": "30.70077",
    "lng": "68.35984"
  },
  {
    "country": "PK",
    "name": "Qila Abdullah",
    "lat": "30.72803",
    "lng": "66.66117"
  },
  {
    "country": "PK",
    "name": "Kambar",
    "lat": "27.58753",
    "lng": "68.00066"
  },
  {
    "country": "PK",
    "name": "Qadirpur Ran",
    "lat": "30.29184",
    "lng": "71.67164"
  },
  {
    "country": "PK",
    "name": "Pithoro",
    "lat": "25.51122",
    "lng": "69.37803"
  },
  {
    "country": "PK",
    "name": "Pishin",
    "lat": "30.58176",
    "lng": "66.99406"
  },
  {
    "country": "PK",
    "name": "Pir Mahal",
    "lat": "30.76663",
    "lng": "72.43455"
  },
  {
    "country": "PK",
    "name": "Pindi Gheb",
    "lat": "33.24095",
    "lng": "72.2648"
  },
  {
    "country": "PK",
    "name": "Pindi Bhattian",
    "lat": "31.89844",
    "lng": "73.27339"
  },
  {
    "country": "PK",
    "name": "Pind Dadan Khan",
    "lat": "32.58662",
    "lng": "73.04456"
  },
  {
    "country": "PK",
    "name": "Goth Phulji",
    "lat": "26.88099",
    "lng": "67.68239"
  },
  {
    "country": "PK",
    "name": "Phalia",
    "lat": "32.43104",
    "lng": "73.579"
  },
  {
    "country": "PK",
    "name": "Peshawar",
    "lat": "34.008",
    "lng": "71.57849"
  },
  {
    "country": "PK",
    "name": "Pattoki",
    "lat": "31.02021",
    "lng": "73.85333"
  },
  {
    "country": "PK",
    "name": "Pasrur",
    "lat": "32.26286",
    "lng": "74.66327"
  },
  {
    "country": "PK",
    "name": "Pasni",
    "lat": "25.26302",
    "lng": "63.46921"
  },
  {
    "country": "PK",
    "name": "Parachinar",
    "lat": "33.89968",
    "lng": "70.10012"
  },
  {
    "country": "PK",
    "name": "Pano Aqil",
    "lat": "27.85619",
    "lng": "69.11111"
  },
  {
    "country": "PK",
    "name": "Panjgur",
    "lat": "26.97186",
    "lng": "64.09459"
  },
  {
    "country": "PK",
    "name": "Pakpattan",
    "lat": "30.34314",
    "lng": "73.38944"
  },
  {
    "country": "PK",
    "name": "Paharpur",
    "lat": "32.10502",
    "lng": "70.97055"
  },
  {
    "country": "PK",
    "name": "Pad Idan",
    "lat": "26.77455",
    "lng": "68.30094"
  },
  {
    "country": "PK",
    "name": "Pabbi",
    "lat": "34.00968",
    "lng": "71.79445"
  },
  {
    "country": "PK",
    "name": "Ormara",
    "lat": "25.2088",
    "lng": "64.6357"
  },
  {
    "country": "PK",
    "name": "Okara",
    "lat": "30.81029",
    "lng": "73.45155"
  },
  {
    "country": "PK",
    "name": "Nushki",
    "lat": "29.55218",
    "lng": "66.02288"
  },
  {
    "country": "PK",
    "name": "Nowshera",
    "lat": "34.01583",
    "lng": "71.98123"
  },
  {
    "country": "PK",
    "name": "New Mirpur",
    "lat": "33.14782",
    "lng": "73.75187"
  },
  {
    "country": "PK",
    "name": "Nawabshah",
    "lat": "26.23939",
    "lng": "68.40369"
  },
  {
    "country": "PK",
    "name": "Naushahro Firoz",
    "lat": "26.8401",
    "lng": "68.12265"
  },
  {
    "country": "PK",
    "name": "Naushahra Virkan",
    "lat": "31.96258",
    "lng": "73.97117"
  },
  {
    "country": "PK",
    "name": "Naudero",
    "lat": "27.66684",
    "lng": "68.3609"
  },
  {
    "country": "PK",
    "name": "Nasirabad",
    "lat": "27.38137",
    "lng": "67.91644"
  },
  {
    "country": "PK",
    "name": "Narowal",
    "lat": "32.10197",
    "lng": "74.87303"
  },
  {
    "country": "PK",
    "name": "Narang Mandi",
    "lat": "31.90376",
    "lng": "74.51587"
  },
  {
    "country": "PK",
    "name": "Naukot",
    "lat": "24.85822",
    "lng": "69.40153"
  },
  {
    "country": "PK",
    "name": "Nankana Sahib",
    "lat": "31.4501",
    "lng": "73.70653"
  },
  {
    "country": "PK",
    "name": "Nabisar",
    "lat": "25.06717",
    "lng": "69.6434"
  },
  {
    "country": "PK",
    "name": "Muzaffargarh",
    "lat": "30.07258",
    "lng": "71.19379"
  },
  {
    "country": "PK",
    "name": "Muzaffarābād",
    "lat": "34.37002",
    "lng": "73.47082"
  },
  {
    "country": "PK",
    "name": "Mustafābād",
    "lat": "30.89222",
    "lng": "73.49889"
  },
  {
    "country": "PK",
    "name": "Musa Khel Bazar",
    "lat": "30.85944",
    "lng": "69.82208"
  },
  {
    "country": "PK",
    "name": "Murree",
    "lat": "33.90836",
    "lng": "73.3903"
  },
  {
    "country": "PK",
    "name": "Muridke",
    "lat": "31.80258",
    "lng": "74.25772"
  },
  {
    "country": "PK",
    "name": "Multan",
    "lat": "30.19679",
    "lng": "71.47824"
  },
  {
    "country": "PK",
    "name": "Moro",
    "lat": "26.66317",
    "lng": "68.00016"
  },
  {
    "country": "PK",
    "name": "Mithi",
    "lat": "24.73701",
    "lng": "69.79707"
  },
  {
    "country": "PK",
    "name": "Mitha Tiwana",
    "lat": "32.2454",
    "lng": "72.10615"
  },
  {
    "country": "PK",
    "name": "Mirwah Gorchani",
    "lat": "25.30981",
    "lng": "69.05019"
  },
  {
    "country": "PK",
    "name": "Mirpur Sakro",
    "lat": "24.54692",
    "lng": "67.62797"
  },
  {
    "country": "PK",
    "name": "Mirpur Mathelo",
    "lat": "28.02136",
    "lng": "69.54914"
  },
  {
    "country": "PK",
    "name": "Mirpur Khas",
    "lat": "25.5276",
    "lng": "69.01255"
  },
  {
    "country": "PK",
    "name": "Mirpur Bhtoro",
    "lat": "24.72852",
    "lng": "68.2601"
  },
  {
    "country": "PK",
    "name": "Miro Khan",
    "lat": "27.75985",
    "lng": "68.09195"
  },
  {
    "country": "PK",
    "name": "Miran Shah",
    "lat": "33.00059",
    "lng": "70.07117"
  },
  {
    "country": "PK",
    "name": "Mingora",
    "lat": "34.7795",
    "lng": "72.36265"
  },
  {
    "country": "PK",
    "name": "Minchianabad",
    "lat": "30.16356",
    "lng": "73.56858"
  },
  {
    "country": "PK",
    "name": "Mianwali",
    "lat": "32.57756",
    "lng": "71.52847"
  },
  {
    "country": "PK",
    "name": "Mian Channun",
    "lat": "30.44067",
    "lng": "72.35679"
  },
  {
    "country": "PK",
    "name": "Mehrabpur",
    "lat": "28.10773",
    "lng": "68.02554"
  },
  {
    "country": "PK",
    "name": "Mehar",
    "lat": "27.18027",
    "lng": "67.82051"
  },
  {
    "country": "PK",
    "name": "Matli",
    "lat": "25.0429",
    "lng": "68.65591"
  },
  {
    "country": "PK",
    "name": "Matiari",
    "lat": "25.59709",
    "lng": "68.4467"
  },
  {
    "country": "PK",
    "name": "Mastung",
    "lat": "29.79966",
    "lng": "66.84553"
  },
  {
    "country": "PK",
    "name": "Mardan",
    "lat": "34.19794",
    "lng": "72.04965"
  },
  {
    "country": "PK",
    "name": "Mansehra",
    "lat": "34.33023",
    "lng": "73.19679"
  },
  {
    "country": "PK",
    "name": "Mankera",
    "lat": "31.38771",
    "lng": "71.44047"
  },
  {
    "country": "PK",
    "name": "Mangla",
    "lat": "31.89306",
    "lng": "72.38167"
  },
  {
    "country": "PK",
    "name": "Mandi Bahauddin",
    "lat": "32.58704",
    "lng": "73.49123"
  },
  {
    "country": "PK",
    "name": "Mananwala",
    "lat": "31.58803",
    "lng": "73.68927"
  },
  {
    "country": "PK",
    "name": "Mamu Kanjan",
    "lat": "30.83044",
    "lng": "72.79943"
  },
  {
    "country": "PK",
    "name": "Malir Cantonment",
    "lat": "24.94343",
    "lng": "67.20591"
  },
  {
    "country": "PK",
    "name": "Malakwal",
    "lat": "32.55449",
    "lng": "73.21274"
  },
  {
    "country": "PK",
    "name": "Malakand",
    "lat": "34.56561",
    "lng": "71.93043"
  },
  {
    "country": "PK",
    "name": "Mailsi",
    "lat": "29.80123",
    "lng": "72.17398"
  },
  {
    "country": "PK",
    "name": "Madeji",
    "lat": "27.75314",
    "lng": "68.45166"
  },
  {
    "country": "PK",
    "name": "Mach",
    "lat": "29.86371",
    "lng": "67.33018"
  },
  {
    "country": "PK",
    "name": "Loralai",
    "lat": "30.37051",
    "lng": "68.59795"
  },
  {
    "country": "PK",
    "name": "Lodhran",
    "lat": "29.5339",
    "lng": "71.63244"
  },
  {
    "country": "PK",
    "name": "Liliani",
    "lat": "32.20393",
    "lng": "72.9512"
  },
  {
    "country": "PK",
    "name": "Layyah",
    "lat": "30.96128",
    "lng": "70.93904"
  },
  {
    "country": "PK",
    "name": "Larkana",
    "lat": "27.55898",
    "lng": "68.21204"
  },
  {
    "country": "PK",
    "name": "Landi Kotal",
    "lat": "34.0988",
    "lng": "71.14108"
  },
  {
    "country": "PK",
    "name": "Lalian",
    "lat": "31.82462",
    "lng": "72.80116"
  },
  {
    "country": "PK",
    "name": "Lala Musa",
    "lat": "32.70138",
    "lng": "73.95746"
  },
  {
    "country": "PK",
    "name": "Lakki",
    "lat": "32.60724",
    "lng": "70.91234"
  },
  {
    "country": "PK",
    "name": "Lakhi",
    "lat": "27.84884",
    "lng": "68.69972"
  },
  {
    "country": "PK",
    "name": "Lahore",
    "lat": "31.558",
    "lng": "74.35071"
  },
  {
    "country": "PK",
    "name": "Ladhewala Waraich",
    "lat": "32.15692",
    "lng": "74.11564"
  },
  {
    "country": "PK",
    "name": "Lachi",
    "lat": "33.38291",
    "lng": "71.33733"
  },
  {
    "country": "PK",
    "name": "Kunri",
    "lat": "25.17874",
    "lng": "69.56572"
  },
  {
    "country": "PK",
    "name": "Kunjah",
    "lat": "32.52982",
    "lng": "73.97486"
  },
  {
    "country": "PK",
    "name": "Kundian",
    "lat": "32.45775",
    "lng": "71.47892"
  },
  {
    "country": "PK",
    "name": "Kulachi",
    "lat": "31.93058",
    "lng": "70.45959"
  },
  {
    "country": "PK",
    "name": "Kot Sultan",
    "lat": "30.7737",
    "lng": "70.93125"
  },
  {
    "country": "PK",
    "name": "Kot Samaba",
    "lat": "28.55207",
    "lng": "70.46837"
  },
  {
    "country": "PK",
    "name": "Kotri",
    "lat": "25.36566",
    "lng": "68.30831"
  },
  {
    "country": "PK",
    "name": "Kot Rajkour",
    "lat": "32.41208",
    "lng": "74.62855"
  },
  {
    "country": "PK",
    "name": "Kot Radha Kishan",
    "lat": "31.17068",
    "lng": "74.10126"
  },
  {
    "country": "PK",
    "name": "Kot Mumin",
    "lat": "32.18843",
    "lng": "73.02987"
  },
  {
    "country": "PK",
    "name": "Kot Malik Barkhurdar",
    "lat": "30.20379",
    "lng": "66.98723"
  },
  {
    "country": "PK",
    "name": "Kotli Loharan",
    "lat": "32.58893",
    "lng": "74.49466"
  },
  {
    "country": "PK",
    "name": "Kotli",
    "lat": "33.51836",
    "lng": "73.9022"
  },
  {
    "country": "PK",
    "name": "Kot Ghulam Muhammad",
    "lat": "32.33311",
    "lng": "74.54694"
  },
  {
    "country": "PK",
    "name": "Kot Diji",
    "lat": "27.34156",
    "lng": "68.70821"
  },
  {
    "country": "PK",
    "name": "Kot Addu",
    "lat": "30.46907",
    "lng": "70.96699"
  },
  {
    "country": "PK",
    "name": "Kohlu",
    "lat": "29.89651",
    "lng": "69.25324"
  },
  {
    "country": "PK",
    "name": "Kohat",
    "lat": "33.58196",
    "lng": "71.44929"
  },
  {
    "country": "PK",
    "name": "Khuzdar",
    "lat": "27.81193",
    "lng": "66.61096"
  },
  {
    "country": "PK",
    "name": "Khushāb",
    "lat": "32.29667",
    "lng": "72.3525"
  },
  {
    "country": "PK",
    "name": "Khurrianwala",
    "lat": "31.49936",
    "lng": "73.26763"
  },
  {
    "country": "PK",
    "name": "Khewra",
    "lat": "32.6491",
    "lng": "73.01059"
  },
  {
    "country": "PK",
    "name": "Kharian",
    "lat": "32.81612",
    "lng": "73.88697"
  },
  {
    "country": "PK",
    "name": "Kharan",
    "lat": "28.58459",
    "lng": "65.41501"
  },
  {
    "country": "PK",
    "name": "Karak",
    "lat": "33.11633",
    "lng": "71.09354"
  },
  {
    "country": "PK",
    "name": "Khanpur",
    "lat": "28.64739",
    "lng": "70.65694"
  },
  {
    "country": "PK",
    "name": "Khanpur Mahar",
    "lat": "27.84088",
    "lng": "69.41302"
  },
  {
    "country": "PK",
    "name": "Khangarh",
    "lat": "29.91446",
    "lng": "71.16067"
  },
  {
    "country": "PK",
    "name": "Khangah Dogran",
    "lat": "31.83294",
    "lng": "73.62213"
  },
  {
    "country": "PK",
    "name": "Khanewal",
    "lat": "30.30173",
    "lng": "71.93212"
  },
  {
    "country": "PK",
    "name": "Khandowa",
    "lat": "32.74255",
    "lng": "72.73478"
  },
  {
    "country": "PK",
    "name": "Khalabat",
    "lat": "34.05997",
    "lng": "72.88963"
  },
  {
    "country": "PK",
    "name": "Khairpur Nathan Shah",
    "lat": "27.09064",
    "lng": "67.73489"
  },
  {
    "country": "PK",
    "name": "Khairpur Tamewah",
    "lat": "29.58139",
    "lng": "72.23804"
  },
  {
    "country": "PK",
    "name": "Khairpur",
    "lat": "28.06437",
    "lng": "69.70363"
  },
  {
    "country": "PK",
    "name": "Khadro",
    "lat": "26.14713",
    "lng": "68.71777"
  },
  {
    "country": "PK",
    "name": "Keti Bandar",
    "lat": "24.14422",
    "lng": "67.45094"
  },
  {
    "country": "PK",
    "name": "Keshupur",
    "lat": "32.26",
    "lng": "72.5"
  },
  {
    "country": "PK",
    "name": "Kasur",
    "lat": "31.11866",
    "lng": "74.45025"
  },
  {
    "country": "PK",
    "name": "Kashmor",
    "lat": "28.4326",
    "lng": "69.58364"
  },
  {
    "country": "PK",
    "name": "Karor",
    "lat": "31.2246",
    "lng": "70.95153"
  },
  {
    "country": "PK",
    "name": "Kario Ghanwar",
    "lat": "24.80817",
    "lng": "68.60483"
  },
  {
    "country": "PK",
    "name": "Karaundi",
    "lat": "26.89709",
    "lng": "68.40643"
  },
  {
    "country": "PK",
    "name": "Karachi",
    "lat": "24.8608",
    "lng": "67.0104"
  },
  {
    "country": "PK",
    "name": "Kanganpur",
    "lat": "30.76468",
    "lng": "74.12286"
  },
  {
    "country": "PK",
    "name": "Kandiaro",
    "lat": "27.05918",
    "lng": "68.21022"
  },
  {
    "country": "PK",
    "name": "Kandiari",
    "lat": "26.9155",
    "lng": "68.52193"
  },
  {
    "country": "PK",
    "name": "Kandhkot",
    "lat": "28.24574",
    "lng": "69.17974"
  },
  {
    "country": "PK",
    "name": "Kamra",
    "lat": "33.74698",
    "lng": "73.51229"
  },
  {
    "country": "PK",
    "name": "Kamoke",
    "lat": "31.97526",
    "lng": "74.22304"
  },
  {
    "country": "PK",
    "name": "Chak One Hundred Twenty Nine Left",
    "lat": "30.42919",
    "lng": "73.04522"
  },
  {
    "country": "PK",
    "name": "Kamar Mushani",
    "lat": "32.84318",
    "lng": "71.36192"
  },
  {
    "country": "PK",
    "name": "Kamalia",
    "lat": "30.72708",
    "lng": "72.64607"
  },
  {
    "country": "PK",
    "name": "Kalur Kot",
    "lat": "32.15512",
    "lng": "71.26631"
  },
  {
    "country": "PK",
    "name": "Kallar Kahar",
    "lat": "32.77998",
    "lng": "72.69793"
  },
  {
    "country": "PK",
    "name": "Kaleke Mandi",
    "lat": "31.97597",
    "lng": "73.59999"
  },
  {
    "country": "PK",
    "name": "Kalat",
    "lat": "29.02663",
    "lng": "66.59361"
  },
  {
    "country": "PK",
    "name": "Kalaswala",
    "lat": "32.20081",
    "lng": "74.64858"
  },
  {
    "country": "PK",
    "name": "Kalabagh",
    "lat": "32.96164",
    "lng": "71.54638"
  },
  {
    "country": "PK",
    "name": "Kahuta",
    "lat": "33.59183",
    "lng": "73.38736"
  },
  {
    "country": "PK",
    "name": "Kahror Pakka",
    "lat": "29.6243",
    "lng": "71.91437"
  },
  {
    "country": "PK",
    "name": "Kahna Nau",
    "lat": "31.36709",
    "lng": "74.36899"
  },
  {
    "country": "PK",
    "name": "Kadhan",
    "lat": "24.48041",
    "lng": "68.98551"
  },
  {
    "country": "PK",
    "name": "Kabirwala",
    "lat": "30.40472",
    "lng": "71.86269"
  },
  {
    "country": "PK",
    "name": "Johi",
    "lat": "26.69225",
    "lng": "67.61431"
  },
  {
    "country": "PK",
    "name": "Jiwani",
    "lat": "25.04852",
    "lng": "61.74573"
  },
  {
    "country": "PK",
    "name": "Chak Jhumra",
    "lat": "31.56808",
    "lng": "73.18317"
  },
  {
    "country": "PK",
    "name": "Jhol",
    "lat": "25.95533",
    "lng": "68.88871"
  },
  {
    "country": "PK",
    "name": "Jhelum",
    "lat": "32.93448",
    "lng": "73.73102"
  },
  {
    "country": "PK",
    "name": "Jhawarian",
    "lat": "32.36192",
    "lng": "72.62275"
  },
  {
    "country": "PK",
    "name": "Dera Allahyar",
    "lat": "28.37353",
    "lng": "68.35078"
  },
  {
    "country": "PK",
    "name": "Jhang Sadr",
    "lat": "31.26981",
    "lng": "72.31687"
  },
  {
    "country": "PK",
    "name": "Jauharabad",
    "lat": "32.29016",
    "lng": "72.28182"
  },
  {
    "country": "PK",
    "name": "Jatoi Shimali",
    "lat": "29.51827",
    "lng": "70.84474"
  },
  {
    "country": "PK",
    "name": "Jati",
    "lat": "24.35492",
    "lng": "68.26732"
  },
  {
    "country": "PK",
    "name": "Jaranwala",
    "lat": "31.3332",
    "lng": "73.41868"
  },
  {
    "country": "PK",
    "name": "Jandiala Sher Khan",
    "lat": "31.82098",
    "lng": "73.91815"
  },
  {
    "country": "PK",
    "name": "Jand",
    "lat": "33.43304",
    "lng": "72.01877"
  },
  {
    "country": "PK",
    "name": "Jamshoro",
    "lat": "25.43608",
    "lng": "68.28017"
  },
  {
    "country": "PK",
    "name": "Jampur",
    "lat": "29.64235",
    "lng": "70.59518"
  },
  {
    "country": "PK",
    "name": "Jalalpur Pirwala",
    "lat": "29.5051",
    "lng": "71.22202"
  },
  {
    "country": "PK",
    "name": "Jalalpur Jattan",
    "lat": "32.64118",
    "lng": "74.20561"
  },
  {
    "country": "PK",
    "name": "Jahanian Shah",
    "lat": "31.80541",
    "lng": "72.2774"
  },
  {
    "country": "PK",
    "name": "Jacobabad",
    "lat": "28.28187",
    "lng": "68.43761"
  },
  {
    "country": "PK",
    "name": "Islamkot",
    "lat": "24.69904",
    "lng": "70.17982"
  },
  {
    "country": "PK",
    "name": "Islamabad",
    "lat": "33.72148",
    "lng": "73.04329"
  },
  {
    "country": "PK",
    "name": "Hyderabad",
    "lat": "25.39242",
    "lng": "68.37366"
  },
  {
    "country": "PK",
    "name": "Hujra Shah Muqim",
    "lat": "30.74168",
    "lng": "73.82327"
  },
  {
    "country": "PK",
    "name": "Hingorja",
    "lat": "27.21088",
    "lng": "68.41598"
  },
  {
    "country": "PK",
    "name": "Hazro City",
    "lat": "33.9099",
    "lng": "72.49179"
  },
  {
    "country": "PK",
    "name": "Havelian",
    "lat": "34.05348",
    "lng": "73.15993"
  },
  {
    "country": "PK",
    "name": "Haveli Lakha",
    "lat": "30.45097",
    "lng": "73.69371"
  },
  {
    "country": "PK",
    "name": "Hasilpur",
    "lat": "29.69221",
    "lng": "72.54566"
  },
  {
    "country": "PK",
    "name": "Chak Thirty-one -Eleven Left",
    "lat": "30.42388",
    "lng": "72.69737"
  },
  {
    "country": "PK",
    "name": "Harunabad",
    "lat": "29.61206",
    "lng": "73.13802"
  },
  {
    "country": "PK",
    "name": "Harnoli",
    "lat": "32.27871",
    "lng": "71.55429"
  },
  {
    "country": "PK",
    "name": "Harnai",
    "lat": "30.10077",
    "lng": "67.93824"
  },
  {
    "country": "PK",
    "name": "Haripur",
    "lat": "33.99783",
    "lng": "72.93493"
  },
  {
    "country": "PK",
    "name": "Hangu",
    "lat": "33.53198",
    "lng": "71.0595"
  },
  {
    "country": "PK",
    "name": "Hala",
    "lat": "25.81459",
    "lng": "68.42198"
  },
  {
    "country": "PK",
    "name": "Hafizabad",
    "lat": "32.07095",
    "lng": "73.68802"
  },
  {
    "country": "PK",
    "name": "Hadali",
    "lat": "32.64043",
    "lng": "74.56898"
  },
  {
    "country": "PK",
    "name": "Gwadar",
    "lat": "25.12163",
    "lng": "62.32541"
  },
  {
    "country": "PK",
    "name": "Gujrat",
    "lat": "32.5742",
    "lng": "74.07542"
  },
  {
    "country": "PK",
    "name": "Gujranwala",
    "lat": "32.15567",
    "lng": "74.18705"
  },
  {
    "country": "PK",
    "name": "Gujar Khan",
    "lat": "33.25411",
    "lng": "73.30433"
  },
  {
    "country": "PK",
    "name": "Gojra",
    "lat": "31.14926",
    "lng": "72.68323"
  },
  {
    "country": "PK",
    "name": "Gilgit",
    "lat": "35.91869",
    "lng": "74.31245"
  },
  {
    "country": "PK",
    "name": "Ghotki",
    "lat": "28.00437",
    "lng": "69.31569"
  },
  {
    "country": "PK",
    "name": "Ghauspur",
    "lat": "28.13882",
    "lng": "69.08245"
  },
  {
    "country": "PK",
    "name": "Gharo",
    "lat": "24.74182",
    "lng": "67.58534"
  },
  {
    "country": "PK",
    "name": "Garh Maharaja",
    "lat": "30.83383",
    "lng": "71.90491"
  },
  {
    "country": "PK",
    "name": "Garhiyasin",
    "lat": "27.90631",
    "lng": "68.5121"
  },
  {
    "country": "PK",
    "name": "Garhi Khairo",
    "lat": "28.06029",
    "lng": "67.98033"
  },
  {
    "country": "PK",
    "name": "Goth Garelo",
    "lat": "27.43521",
    "lng": "68.07572"
  },
  {
    "country": "PK",
    "name": "Gandava",
    "lat": "28.61321",
    "lng": "67.48564"
  },
  {
    "country": "PK",
    "name": "Gambat",
    "lat": "27.3517",
    "lng": "68.5215"
  },
  {
    "country": "PK",
    "name": "Gakuch",
    "lat": "36.17683",
    "lng": "73.76383"
  },
  {
    "country": "PK",
    "name": "Gadani",
    "lat": "25.11853",
    "lng": "66.72985"
  },
  {
    "country": "PK",
    "name": "Fort Abbas",
    "lat": "29.19344",
    "lng": "72.85525"
  },
  {
    "country": "PK",
    "name": "Fazilpur",
    "lat": "32.17629",
    "lng": "75.06583"
  },
  {
    "country": "PK",
    "name": "Chak Two Hundred Forty-nine Thal Development Authority",
    "lat": "31.17772",
    "lng": "71.2048"
  },
  {
    "country": "PK",
    "name": "Faruka",
    "lat": "31.88642",
    "lng": "72.41362"
  },
  {
    "country": "PK",
    "name": "Faqirwali",
    "lat": "29.46799",
    "lng": "73.03489"
  },
  {
    "country": "PK",
    "name": "Faisalabad",
    "lat": "31.41554",
    "lng": "73.08969"
  },
  {
    "country": "PK",
    "name": "Eminabad",
    "lat": "32.04237",
    "lng": "74.25996"
  },
  {
    "country": "PK",
    "name": "Dunyapur",
    "lat": "29.80275",
    "lng": "71.74344"
  },
  {
    "country": "PK",
    "name": "Dunga Bunga",
    "lat": "29.74975",
    "lng": "73.24294"
  },
  {
    "country": "PK",
    "name": "Dullewala",
    "lat": "31.83439",
    "lng": "71.43639"
  },
  {
    "country": "PK",
    "name": "Duki",
    "lat": "30.15307",
    "lng": "68.57323"
  },
  {
    "country": "PK",
    "name": "Dokri",
    "lat": "27.37421",
    "lng": "68.09715"
  },
  {
    "country": "PK",
    "name": "Doaba",
    "lat": "33.4245",
    "lng": "70.73676"
  },
  {
    "country": "PK",
    "name": "Upper Dir",
    "lat": "35.2074",
    "lng": "71.8768"
  },
  {
    "country": "PK",
    "name": "Diplo",
    "lat": "24.46688",
    "lng": "69.58114"
  },
  {
    "country": "PK",
    "name": "Dipalpur",
    "lat": "30.66984",
    "lng": "73.65306"
  },
  {
    "country": "PK",
    "name": "Dinan Bashnoian Wala",
    "lat": "29.76584",
    "lng": "73.26557"
  },
  {
    "country": "PK",
    "name": "Dinga",
    "lat": "32.64101",
    "lng": "73.72039"
  },
  {
    "country": "PK",
    "name": "Dijkot",
    "lat": "31.21735",
    "lng": "72.99621"
  },
  {
    "country": "PK",
    "name": "Digri",
    "lat": "25.15657",
    "lng": "69.11098"
  },
  {
    "country": "PK",
    "name": "Dhoro Naro",
    "lat": "25.50484",
    "lng": "69.5709"
  },
  {
    "country": "PK",
    "name": "Dhaunkal",
    "lat": "32.40613",
    "lng": "74.13706"
  },
  {
    "country": "PK",
    "name": "Dhanot",
    "lat": "29.57991",
    "lng": "71.75213"
  },
  {
    "country": "PK",
    "name": "Dera Ismail Khan",
    "lat": "31.83129",
    "lng": "70.9017"
  },
  {
    "country": "PK",
    "name": "Dera Ghazi Khan",
    "lat": "30.04587",
    "lng": "70.64029"
  },
  {
    "country": "PK",
    "name": "Dera Bugti",
    "lat": "29.03619",
    "lng": "69.15849"
  },
  {
    "country": "PK",
    "name": "Daur",
    "lat": "26.45528",
    "lng": "68.31835"
  },
  {
    "country": "PK",
    "name": "Daultala",
    "lat": "33.19282",
    "lng": "73.14099"
  },
  {
    "country": "PK",
    "name": "Daulatpur",
    "lat": "26.50158",
    "lng": "67.97079"
  },
  {
    "country": "PK",
    "name": "Daud Khel",
    "lat": "32.87533",
    "lng": "71.57118"
  },
  {
    "country": "PK",
    "name": "Daska Kalan",
    "lat": "32.32422",
    "lng": "74.35039"
  },
  {
    "country": "PK",
    "name": "Darya Khan Marri",
    "lat": "26.67765",
    "lng": "68.28666"
  },
  {
    "country": "PK",
    "name": "Darya Khan",
    "lat": "31.78447",
    "lng": "71.10197"
  },
  {
    "country": "PK",
    "name": "Daromehar",
    "lat": "24.79382",
    "lng": "68.17978"
  },
  {
    "country": "PK",
    "name": "Dalbandin",
    "lat": "28.88846",
    "lng": "64.40616"
  },
  {
    "country": "PK",
    "name": "Dajal",
    "lat": "29.55769",
    "lng": "70.37614"
  },
  {
    "country": "PK",
    "name": "Daira Din Panah",
    "lat": "30.57053",
    "lng": "70.93722"
  },
  {
    "country": "PK",
    "name": "Daggar",
    "lat": "34.51106",
    "lng": "72.48438"
  },
  {
    "country": "PK",
    "name": "Dadu",
    "lat": "26.73033",
    "lng": "67.7769"
  },
  {
    "country": "PK",
    "name": "Dadhar",
    "lat": "29.47489",
    "lng": "67.65167"
  },
  {
    "country": "PK",
    "name": "Chunian",
    "lat": "30.96621",
    "lng": "73.97908"
  },
  {
    "country": "PK",
    "name": "Chuchar-kana Mandi",
    "lat": "31.75",
    "lng": "73.8"
  },
  {
    "country": "PK",
    "name": "Chhor",
    "lat": "25.5126",
    "lng": "69.78437"
  },
  {
    "country": "PK",
    "name": "Choa Saidan Shah",
    "lat": "32.71962",
    "lng": "72.98625"
  },
  {
    "country": "PK",
    "name": "Chitral",
    "lat": "35.8518",
    "lng": "71.78636"
  },
  {
    "country": "PK",
    "name": "Chishtian",
    "lat": "29.79713",
    "lng": "72.85772"
  },
  {
    "country": "PK",
    "name": "Chiniot",
    "lat": "31.72091",
    "lng": "72.97836"
  },
  {
    "country": "PK",
    "name": "Chilas",
    "lat": "35.41287",
    "lng": "74.10407"
  },
  {
    "country": "PK",
    "name": "Chichawatni",
    "lat": "30.5301",
    "lng": "72.69155"
  },
  {
    "country": "PK",
    "name": "Cherat Cantonement",
    "lat": "33.82342",
    "lng": "71.89292"
  },
  {
    "country": "PK",
    "name": "Chawinda",
    "lat": "32.34434",
    "lng": "74.70507"
  },
  {
    "country": "PK",
    "name": "Charsadda",
    "lat": "34.14822",
    "lng": "71.7406"
  },
  {
    "country": "PK",
    "name": "Chamber",
    "lat": "25.29362",
    "lng": "68.81176"
  },
  {
    "country": "PK",
    "name": "Chaman",
    "lat": "30.91769",
    "lng": "66.45259"
  },
  {
    "country": "PK",
    "name": "Chakwal",
    "lat": "32.93286",
    "lng": "72.85394"
  },
  {
    "country": "PK",
    "name": "Chak Azam Sahu",
    "lat": "30.75202",
    "lng": "73.02834"
  },
  {
    "country": "PK",
    "name": "Chak",
    "lat": "27.85838",
    "lng": "68.83378"
  },
  {
    "country": "PK",
    "name": "Būrewāla",
    "lat": "30.16667",
    "lng": "72.65"
  },
  {
    "country": "PK",
    "name": "Bulri",
    "lat": "24.86667",
    "lng": "68.33333"
  },
  {
    "country": "PK",
    "name": "Bozdar Wada",
    "lat": "27.183",
    "lng": "68.6358"
  },
  {
    "country": "PK",
    "name": "Bhopalwala",
    "lat": "32.42968",
    "lng": "74.3635"
  },
  {
    "country": "PK",
    "name": "Bhit Shah",
    "lat": "25.80565",
    "lng": "68.49143"
  },
  {
    "country": "PK",
    "name": "Bhiria",
    "lat": "26.91041",
    "lng": "68.19466"
  },
  {
    "country": "PK",
    "name": "Bhimbar",
    "lat": "32.97465",
    "lng": "74.07846"
  },
  {
    "country": "PK",
    "name": "Bhera",
    "lat": "32.48206",
    "lng": "72.90865"
  },
  {
    "country": "PK",
    "name": "Bhawana",
    "lat": "31.56884",
    "lng": "72.64917"
  },
  {
    "country": "PK",
    "name": "Bhan",
    "lat": "26.55831",
    "lng": "67.72139"
  },
  {
    "country": "PK",
    "name": "Bhalwal",
    "lat": "32.26576",
    "lng": "72.89809"
  },
  {
    "country": "PK",
    "name": "Bhakkar",
    "lat": "31.62685",
    "lng": "71.06471"
  },
  {
    "country": "PK",
    "name": "Mianke Mor",
    "lat": "31.2024",
    "lng": "73.94857"
  },
  {
    "country": "PK",
    "name": "Bhag",
    "lat": "29.04174",
    "lng": "67.82394"
  },
  {
    "country": "PK",
    "name": "Berani",
    "lat": "25.78497",
    "lng": "68.80754"
  },
  {
    "country": "PK",
    "name": "Bela",
    "lat": "26.22718",
    "lng": "66.31178"
  },
  {
    "country": "PK",
    "name": "Begowala",
    "lat": "32.43816",
    "lng": "74.26794"
  },
  {
    "country": "PK",
    "name": "Bat Khela",
    "lat": "34.6178",
    "lng": "71.97247"
  },
  {
    "country": "PK",
    "name": "Battagram",
    "lat": "34.67719",
    "lng": "73.02329"
  },
  {
    "country": "PK",
    "name": "Basirpur",
    "lat": "30.57759",
    "lng": "73.83912"
  },
  {
    "country": "PK",
    "name": "Barkhan",
    "lat": "29.89773",
    "lng": "69.52558"
  },
  {
    "country": "PK",
    "name": "Bannu",
    "lat": "32.98527",
    "lng": "70.60403"
  },
  {
    "country": "PK",
    "name": "Bandhi",
    "lat": "26.58761",
    "lng": "68.30215"
  },
  {
    "country": "PK",
    "name": "Bakhri Ahmad Khan",
    "lat": "30.73586",
    "lng": "70.83796"
  },
  {
    "country": "PK",
    "name": "Bahawalpur",
    "lat": "29.39779",
    "lng": "71.6752"
  },
  {
    "country": "PK",
    "name": "Bahawalnagar",
    "lat": "29.99835",
    "lng": "73.25272"
  },
  {
    "country": "PK",
    "name": "Bagh",
    "lat": "33.98111",
    "lng": "73.77608"
  },
  {
    "country": "PK",
    "name": "Bagarji",
    "lat": "27.75431",
    "lng": "68.75866"
  },
  {
    "country": "PK",
    "name": "Baffa",
    "lat": "34.4377",
    "lng": "73.22368"
  },
  {
    "country": "PK",
    "name": "Badin",
    "lat": "24.656",
    "lng": "68.837"
  },
  {
    "country": "PK",
    "name": "Baddomalhi",
    "lat": "31.99042",
    "lng": "74.6641"
  },
  {
    "country": "PK",
    "name": "Awaran",
    "lat": "26.45677",
    "lng": "65.23144"
  },
  {
    "country": "PK",
    "name": "Attock City",
    "lat": "33.76671",
    "lng": "72.35977"
  },
  {
    "country": "PK",
    "name": "Arifwala",
    "lat": "30.29058",
    "lng": "73.06574"
  },
  {
    "country": "PK",
    "name": "Aman Garh",
    "lat": "34.00584",
    "lng": "71.92971"
  },
  {
    "country": "PK",
    "name": "Alizai",
    "lat": "33.53613",
    "lng": "70.34607"
  },
  {
    "country": "PK",
    "name": "Alipur",
    "lat": "29.38242",
    "lng": "70.91106"
  },
  {
    "country": "PK",
    "name": "Aliabad",
    "lat": "36.30703",
    "lng": "74.61545"
  },
  {
    "country": "PK",
    "name": "Akora",
    "lat": "34.00337",
    "lng": "72.12561"
  },
  {
    "country": "PK",
    "name": "Ahmadpur East",
    "lat": "29.14269",
    "lng": "71.25771"
  },
  {
    "country": "PK",
    "name": "Abbottabad",
    "lat": "34.1463",
    "lng": "73.21168"
  },
  {
    "country": "PK",
    "name": "Jhang City",
    "lat": "31.30568",
    "lng": "72.32594"
  },
  {
    "country": "PK",
    "name": "Bahawalnagar",
    "lat": "30.55083",
    "lng": "73.39083"
  },
  {
    "country": "PK",
    "name": "Gulishah Kach",
    "lat": "32.67087",
    "lng": "70.33917"
  },
  {
    "country": "PK",
    "name": "Nowshera Cantonment",
    "lat": "33.99829",
    "lng": "71.99834"
  },
  {
    "country": "PK",
    "name": "Alik Ghund",
    "lat": "30.48976",
    "lng": "67.52177"
  },
  {
    "country": "PK",
    "name": "Khadan Khak",
    "lat": "30.75236",
    "lng": "67.71133"
  },
  {
    "country": "PK",
    "name": "Ahmadpur Sial",
    "lat": "30.67791",
    "lng": "71.74344"
  },
  {
    "country": "PK",
    "name": "New Bādāh",
    "lat": "27.34167",
    "lng": "68.03194"
  },
  {
    "country": "PK",
    "name": "Dandot RS",
    "lat": "32.64167",
    "lng": "72.975"
  },
  {
    "country": "PK",
    "name": "Dera Murad Jamali",
    "lat": "28.54657",
    "lng": "68.22308"
  },
  {
    "country": "PK",
    "name": "Jām Sāhib",
    "lat": "26.29583",
    "lng": "68.62917"
  },
  {
    "country": "PK",
    "name": "Chowki Jamali",
    "lat": "28.01944",
    "lng": "67.92083"
  },
  {
    "country": "PK",
    "name": "Setharja Old",
    "lat": "27.2127",
    "lng": "68.46883"
  },
  {
    "country": "PK",
    "name": "Risalpur Cantonment",
    "lat": "34.06048",
    "lng": "71.99276"
  },
  {
    "country": "PK",
    "name": "Noorabad",
    "lat": "34.25195",
    "lng": "71.96656"
  },
  {
    "country": "PK",
    "name": "Alpurai",
    "lat": "34.92039",
    "lng": "72.63265"
  },
  {
    "country": "PK",
    "name": "Shingli Bala",
    "lat": "34.67872",
    "lng": "72.98491"
  },
  {
    "country": "PK",
    "name": "Malakwal City",
    "lat": "32.55492",
    "lng": "73.2122"
  },
  {
    "country": "PK",
    "name": "Mehmand Chak",
    "lat": "32.78518",
    "lng": "73.82306"
  },
  {
    "country": "PK",
    "name": "Basti Dosa",
    "lat": "30.78769",
    "lng": "70.86853"
  },
  {
    "country": "PK",
    "name": "Moza Shahwala",
    "lat": "30.80563",
    "lng": "70.84911"
  },
  {
    "country": "PK",
    "name": "Eidgah",
    "lat": "35.34712",
    "lng": "74.85632"
  },
  {
    "country": "PK",
    "name": "Dasu",
    "lat": "35.29169",
    "lng": "73.2906"
  },
  {
    "country": "PK",
    "name": "Barishal",
    "lat": "36.32162",
    "lng": "74.69502"
  },
  {
    "country": "PK",
    "name": "Athmuqam",
    "lat": "34.57173",
    "lng": "73.89724"
  },
  {
    "country": "PK",
    "name": "Nazir Town",
    "lat": "33.30614",
    "lng": "73.4833"
  },
  {
    "country": "PK",
    "name": "Amirabad",
    "lat": "34.18729",
    "lng": "73.09078"
  },
  {
    "country": "PK",
    "name": "Kakad Wari Dir Upper",
    "lat": "34.99798",
    "lng": "72.07295"
  },
  {
    "country": "PK",
    "name": "Hattian Bala",
    "lat": "34.1691",
    "lng": "73.7432"
  },
  {
    "country": "PK",
    "name": "Ashanagro Koto",
    "lat": "34.10773",
    "lng": "72.24517"
  },
  {
    "country": "PL",
    "name": "Żyrzyn",
    "lat": "51.49918",
    "lng": "22.0917"
  },
  {
    "country": "PL",
    "name": "Żyrardów",
    "lat": "52.0488",
    "lng": "20.44599"
  },
  {
    "country": "PL",
    "name": "Żyraków",
    "lat": "50.08545",
    "lng": "21.39622"
  },
  {
    "country": "PL",
    "name": "Zwoleń",
    "lat": "51.35542",
    "lng": "21.58768"
  },
  {
    "country": "PL",
    "name": "Zwierzyniec",
    "lat": "50.614",
    "lng": "22.97512"
  },
  {
    "country": "PL",
    "name": "Żurowa",
    "lat": "49.82636",
    "lng": "21.16894"
  },
  {
    "country": "PL",
    "name": "Żurawiczki",
    "lat": "50.0137",
    "lng": "22.49949"
  },
  {
    "country": "PL",
    "name": "Żurawica",
    "lat": "49.82348",
    "lng": "22.78925"
  },
  {
    "country": "PL",
    "name": "Żołynia",
    "lat": "50.162",
    "lng": "22.30825"
  },
  {
    "country": "PL",
    "name": "Żółkiewka",
    "lat": "50.90991",
    "lng": "22.83465"
  },
  {
    "country": "PL",
    "name": "Żoliborz",
    "lat": "52.26896",
    "lng": "20.98644"
  },
  {
    "country": "PL",
    "name": "Zmiennica",
    "lat": "49.67652",
    "lng": "21.96596"
  },
  {
    "country": "PL",
    "name": "Złota",
    "lat": "50.3816",
    "lng": "20.59361"
  },
  {
    "country": "PL",
    "name": "Złota",
    "lat": "49.88059",
    "lng": "20.69326"
  },
  {
    "country": "PL",
    "name": "Zielonka",
    "lat": "52.30376",
    "lng": "21.16018"
  },
  {
    "country": "PL",
    "name": "Zgłobień",
    "lat": "50.0127",
    "lng": "21.8549"
  },
  {
    "country": "PL",
    "name": "Żelechów",
    "lat": "51.81051",
    "lng": "21.89721"
  },
  {
    "country": "PL",
    "name": "Żelechlinek",
    "lat": "51.71214",
    "lng": "20.0346"
  },
  {
    "country": "PL",
    "name": "Żegocina",
    "lat": "49.81395",
    "lng": "20.41964"
  },
  {
    "country": "PL",
    "name": "Zbuczyn",
    "lat": "52.08974",
    "lng": "22.43829"
  },
  {
    "country": "PL",
    "name": "Zbójna",
    "lat": "53.24293",
    "lng": "21.78812"
  },
  {
    "country": "PL",
    "name": "Zawichost",
    "lat": "50.80743",
    "lng": "21.85408"
  },
  {
    "country": "PL",
    "name": "Zatory",
    "lat": "52.59929",
    "lng": "21.18258"
  },
  {
    "country": "PL",
    "name": "Zarzecze",
    "lat": "50.52767",
    "lng": "22.19522"
  },
  {
    "country": "PL",
    "name": "Zarzecze",
    "lat": "49.98633",
    "lng": "22.53716"
  },
  {
    "country": "PL",
    "name": "Zarszyn",
    "lat": "49.58178",
    "lng": "22.01283"
  },
  {
    "country": "PL",
    "name": "Żarnów",
    "lat": "51.24607",
    "lng": "20.17476"
  },
  {
    "country": "PL",
    "name": "Zamość",
    "lat": "50.72314",
    "lng": "23.25196"
  },
  {
    "country": "PL",
    "name": "Zamch",
    "lat": "50.31713",
    "lng": "23.02786"
  },
  {
    "country": "PL",
    "name": "Zambrów",
    "lat": "52.9855",
    "lng": "22.24319"
  },
  {
    "country": "PL",
    "name": "Załuski",
    "lat": "52.51152",
    "lng": "20.52864"
  },
  {
    "country": "PL",
    "name": "Zaleszany",
    "lat": "50.64799",
    "lng": "21.89069"
  },
  {
    "country": "PL",
    "name": "Zalesie Górne",
    "lat": "52.02768",
    "lng": "21.03659"
  },
  {
    "country": "PL",
    "name": "Zalesie",
    "lat": "52.03743",
    "lng": "23.3636"
  },
  {
    "country": "PL",
    "name": "Zakrzówek",
    "lat": "50.95124",
    "lng": "22.38138"
  },
  {
    "country": "PL",
    "name": "Zakrzew",
    "lat": "51.44095",
    "lng": "21.00105"
  },
  {
    "country": "PL",
    "name": "Zakrzew",
    "lat": "50.89004",
    "lng": "22.59115"
  },
  {
    "country": "PL",
    "name": "Zakroczym",
    "lat": "52.43351",
    "lng": "20.61207"
  },
  {
    "country": "PL",
    "name": "Zaklików",
    "lat": "50.75769",
    "lng": "22.10226"
  },
  {
    "country": "PL",
    "name": "Zakliczyn",
    "lat": "49.85589",
    "lng": "20.80935"
  },
  {
    "country": "PL",
    "name": "Zagórzyce",
    "lat": "50.0169",
    "lng": "21.67517"
  },
  {
    "country": "PL",
    "name": "Zagórz",
    "lat": "49.51457",
    "lng": "22.26706"
  },
  {
    "country": "PL",
    "name": "Zagnańsk",
    "lat": "50.98037",
    "lng": "20.66314"
  },
  {
    "country": "PL",
    "name": "Żabno",
    "lat": "50.13334",
    "lng": "20.88615"
  },
  {
    "country": "PL",
    "name": "Zabłudów",
    "lat": "53.01442",
    "lng": "23.33831"
  },
  {
    "country": "PL",
    "name": "Ząbki",
    "lat": "52.29271",
    "lng": "21.10539"
  },
  {
    "country": "PL",
    "name": "Zabierzów Bocheński",
    "lat": "50.06821",
    "lng": "20.31896"
  },
  {
    "country": "PL",
    "name": "Żabieniec",
    "lat": "52.05856",
    "lng": "21.04817"
  },
  {
    "country": "PL",
    "name": "Żabia Wola",
    "lat": "52.03169",
    "lng": "20.69112"
  },
  {
    "country": "PL",
    "name": "Wyszogród",
    "lat": "52.38988",
    "lng": "20.19081"
  },
  {
    "country": "PL",
    "name": "Wyszków",
    "lat": "52.59278",
    "lng": "21.4584"
  },
  {
    "country": "PL",
    "name": "Wyszki",
    "lat": "52.84129",
    "lng": "22.98119"
  },
  {
    "country": "PL",
    "name": "Wysokie Mazowieckie",
    "lat": "52.91661",
    "lng": "22.51712"
  },
  {
    "country": "PL",
    "name": "Wysokie",
    "lat": "50.91093",
    "lng": "22.666"
  },
  {
    "country": "PL",
    "name": "Wysoka Strzyżowska",
    "lat": "49.83056",
    "lng": "21.74074"
  },
  {
    "country": "PL",
    "name": "Wysoka Głogowska",
    "lat": "50.16019",
    "lng": "22.02124"
  },
  {
    "country": "PL",
    "name": "Wysoka",
    "lat": "50.04474",
    "lng": "22.26002"
  },
  {
    "country": "PL",
    "name": "Wyśmierzyce",
    "lat": "51.62494",
    "lng": "20.81394"
  },
  {
    "country": "PL",
    "name": "Wydminy",
    "lat": "53.98194",
    "lng": "22.03239"
  },
  {
    "country": "PL",
    "name": "Wołomin",
    "lat": "52.34006",
    "lng": "21.24207"
  },
  {
    "country": "PL",
    "name": "Wólka Tanewska",
    "lat": "50.50005",
    "lng": "22.26113"
  },
  {
    "country": "PL",
    "name": "Wólka Podleśna",
    "lat": "50.11785",
    "lng": "22.11213"
  },
  {
    "country": "PL",
    "name": "Wólka Pełkińska",
    "lat": "50.09553",
    "lng": "22.62342"
  },
  {
    "country": "PL",
    "name": "Wólka Niedźwiedzka",
    "lat": "50.24226",
    "lng": "22.18826"
  },
  {
    "country": "PL",
    "name": "Wola Żarczycka",
    "lat": "50.2912",
    "lng": "22.25023"
  },
  {
    "country": "PL",
    "name": "Wola Zabierzowska",
    "lat": "50.07257",
    "lng": "20.33217"
  },
  {
    "country": "PL",
    "name": "Wola Uhruska",
    "lat": "51.32139",
    "lng": "23.62627"
  },
  {
    "country": "PL",
    "name": "Wola Sernicka",
    "lat": "51.44978",
    "lng": "22.68351"
  },
  {
    "country": "PL",
    "name": "Wola Rębkowska",
    "lat": "51.90181",
    "lng": "21.55818"
  },
  {
    "country": "PL",
    "name": "Wolanów",
    "lat": "51.3803",
    "lng": "20.97702"
  },
  {
    "country": "PL",
    "name": "Wola Jachowa",
    "lat": "50.84524",
    "lng": "20.85814"
  },
  {
    "country": "PL",
    "name": "Wola Dębińska",
    "lat": "49.98214",
    "lng": "20.68777"
  },
  {
    "country": "PL",
    "name": "Wola Batorska",
    "lat": "50.05262",
    "lng": "20.26617"
  },
  {
    "country": "PL",
    "name": "Wola",
    "lat": "52.2401",
    "lng": "20.98869"
  },
  {
    "country": "PL",
    "name": "Wojsławice",
    "lat": "50.91916",
    "lng": "23.54602"
  },
  {
    "country": "PL",
    "name": "Wojnicz",
    "lat": "49.958",
    "lng": "20.83785"
  },
  {
    "country": "PL",
    "name": "Wojcieszków",
    "lat": "51.76922",
    "lng": "22.31589"
  },
  {
    "country": "PL",
    "name": "Wojciechowice",
    "lat": "50.84226",
    "lng": "21.58942"
  },
  {
    "country": "PL",
    "name": "Wojciechów",
    "lat": "51.23543",
    "lng": "22.24551"
  },
  {
    "country": "PL",
    "name": "Wojaszówka",
    "lat": "49.77777",
    "lng": "21.67079"
  },
  {
    "country": "PL",
    "name": "Wohyń",
    "lat": "51.75642",
    "lng": "22.78582"
  },
  {
    "country": "PL",
    "name": "Wodzisław",
    "lat": "50.52047",
    "lng": "20.1915"
  },
  {
    "country": "PL",
    "name": "Wodynie",
    "lat": "52.0404",
    "lng": "21.95575"
  },
  {
    "country": "PL",
    "name": "Włodawa",
    "lat": "51.55",
    "lng": "23.55"
  },
  {
    "country": "PL",
    "name": "Włochy",
    "lat": "52.17941",
    "lng": "20.94612"
  },
  {
    "country": "PL",
    "name": "Wizna",
    "lat": "53.19518",
    "lng": "22.38241"
  },
  {
    "country": "PL",
    "name": "Wisznice",
    "lat": "51.78924",
    "lng": "23.20836"
  },
  {
    "country": "PL",
    "name": "Wiśniowa",
    "lat": "49.86897",
    "lng": "21.65508"
  },
  {
    "country": "PL",
    "name": "Wiśniowa",
    "lat": "49.7878",
    "lng": "20.11502"
  },
  {
    "country": "PL",
    "name": "Wiśniew",
    "lat": "52.07265",
    "lng": "22.29392"
  },
  {
    "country": "PL",
    "name": "Wiślica",
    "lat": "50.34891",
    "lng": "20.67438"
  },
  {
    "country": "PL",
    "name": "Wiskitki",
    "lat": "52.08831",
    "lng": "20.38708"
  },
  {
    "country": "PL",
    "name": "Winnica",
    "lat": "52.64306",
    "lng": "20.94114"
  },
  {
    "country": "PL",
    "name": "Wilków",
    "lat": "51.26224",
    "lng": "21.87756"
  },
  {
    "country": "PL",
    "name": "Wilkołaz",
    "lat": "51.01473",
    "lng": "22.35014"
  },
  {
    "country": "PL",
    "name": "Wilga",
    "lat": "51.85211",
    "lng": "21.37751"
  },
  {
    "country": "PL",
    "name": "Wilczyce",
    "lat": "50.74694",
    "lng": "21.65783"
  },
  {
    "country": "PL",
    "name": "Wilanów",
    "lat": "52.16311",
    "lng": "21.08748"
  },
  {
    "country": "PL",
    "name": "Wietrzychowice",
    "lat": "50.19097",
    "lng": "20.76502"
  },
  {
    "country": "PL",
    "name": "Wierzchosławice",
    "lat": "50.02478",
    "lng": "20.85677"
  },
  {
    "country": "PL",
    "name": "Wierzbno",
    "lat": "52.31008",
    "lng": "21.85902"
  },
  {
    "country": "PL",
    "name": "Wierzbna",
    "lat": "50.03311",
    "lng": "22.60128"
  },
  {
    "country": "PL",
    "name": "Wierzbica",
    "lat": "51.2494",
    "lng": "21.08259"
  },
  {
    "country": "PL",
    "name": "Wierzawice",
    "lat": "50.23623",
    "lng": "22.4509"
  },
  {
    "country": "PL",
    "name": "Wieniawa",
    "lat": "51.36171",
    "lng": "20.79489"
  },
  {
    "country": "PL",
    "name": "Wielopole Skrzyńskie",
    "lat": "49.94564",
    "lng": "21.61491"
  },
  {
    "country": "PL",
    "name": "Wielkie Oczy",
    "lat": "50.02357",
    "lng": "23.16407"
  },
  {
    "country": "PL",
    "name": "Wielka Wieś",
    "lat": "51.07107",
    "lng": "20.96655"
  },
  {
    "country": "PL",
    "name": "Wielka Wieś",
    "lat": "49.93631",
    "lng": "20.82304"
  },
  {
    "country": "PL",
    "name": "Wieliszew",
    "lat": "52.4513",
    "lng": "20.96827"
  },
  {
    "country": "PL",
    "name": "Wieliczka",
    "lat": "49.98738",
    "lng": "20.06473"
  },
  {
    "country": "PL",
    "name": "Wielbark",
    "lat": "53.39858",
    "lng": "20.94629"
  },
  {
    "country": "PL",
    "name": "Wieczfnia Kościelna",
    "lat": "53.19534",
    "lng": "20.47637"
  },
  {
    "country": "PL",
    "name": "Wiązownica",
    "lat": "50.08066",
    "lng": "22.70668"
  },
  {
    "country": "PL",
    "name": "Wesoła",
    "lat": "52.25451",
    "lng": "21.22407"
  },
  {
    "country": "PL",
    "name": "Wesoła",
    "lat": "49.79977",
    "lng": "22.10029"
  },
  {
    "country": "PL",
    "name": "Werbkowice",
    "lat": "50.75373",
    "lng": "23.76411"
  },
  {
    "country": "PL",
    "name": "Węgrzce Wielkie",
    "lat": "50.01491",
    "lng": "20.11082"
  },
  {
    "country": "PL",
    "name": "Węgrów",
    "lat": "52.39954",
    "lng": "22.01634"
  },
  {
    "country": "PL",
    "name": "Węgorzewo",
    "lat": "54.21567",
    "lng": "21.7372"
  },
  {
    "country": "PL",
    "name": "Węglówka",
    "lat": "49.73424",
    "lng": "20.08575"
  },
  {
    "country": "PL",
    "name": "Wawrzeńczyce",
    "lat": "50.11012",
    "lng": "20.31612"
  },
  {
    "country": "PL",
    "name": "Wąwolnica",
    "lat": "51.29467",
    "lng": "22.14681"
  },
  {
    "country": "PL",
    "name": "Wawer",
    "lat": "52.19656",
    "lng": "21.17752"
  },
  {
    "country": "PL",
    "name": "Wąsosz",
    "lat": "53.52209",
    "lng": "22.31915"
  },
  {
    "country": "PL",
    "name": "Waśniów",
    "lat": "50.89914",
    "lng": "21.22301"
  },
  {
    "country": "PL",
    "name": "Wasilków",
    "lat": "53.19909",
    "lng": "23.20776"
  },
  {
    "country": "PL",
    "name": "Warsaw",
    "lat": "52.22977",
    "lng": "21.01178"
  },
  {
    "country": "PL",
    "name": "Warka",
    "lat": "51.7843",
    "lng": "21.19091"
  },
  {
    "country": "PL",
    "name": "Jodłówka-Wałki",
    "lat": "50.04992",
    "lng": "21.13332"
  },
  {
    "country": "PL",
    "name": "Waksmund",
    "lat": "49.48207",
    "lng": "20.07563"
  },
  {
    "country": "PL",
    "name": "Wadowice Górne",
    "lat": "50.26312",
    "lng": "21.30215"
  },
  {
    "country": "PL",
    "name": "Wąchock",
    "lat": "51.07391",
    "lng": "21.01243"
  },
  {
    "country": "PL",
    "name": "Ustrzyki Dolne",
    "lat": "49.4304",
    "lng": "22.59381"
  },
  {
    "country": "PL",
    "name": "Uścimów Stary",
    "lat": "51.46962",
    "lng": "22.95516"
  },
  {
    "country": "PL",
    "name": "Uście Gorlickie",
    "lat": "49.52192",
    "lng": "21.13821"
  },
  {
    "country": "PL",
    "name": "Urzejowice",
    "lat": "50.01182",
    "lng": "22.46189"
  },
  {
    "country": "PL",
    "name": "Urzędów",
    "lat": "50.99323",
    "lng": "22.1426"
  },
  {
    "country": "PL",
    "name": "Urszulin",
    "lat": "51.3939",
    "lng": "23.1948"
  },
  {
    "country": "PL",
    "name": "Ursus",
    "lat": "52.19517",
    "lng": "20.88419"
  },
  {
    "country": "PL",
    "name": "Ulhówek",
    "lat": "50.44969",
    "lng": "23.79956"
  },
  {
    "country": "PL",
    "name": "Ułęż",
    "lat": "51.59195",
    "lng": "22.10741"
  },
  {
    "country": "PL",
    "name": "Ulanów",
    "lat": "50.49031",
    "lng": "22.26362"
  },
  {
    "country": "PL",
    "name": "Uherce Mineralne",
    "lat": "49.46455",
    "lng": "22.39829"
  },
  {
    "country": "PL",
    "name": "Tyszowce",
    "lat": "50.61699",
    "lng": "23.69927"
  },
  {
    "country": "PL",
    "name": "Tyrawa Wołoska",
    "lat": "49.57744",
    "lng": "22.36988"
  },
  {
    "country": "PL",
    "name": "Tymbark",
    "lat": "49.72859",
    "lng": "20.32539"
  },
  {
    "country": "PL",
    "name": "Tylicz",
    "lat": "49.39598",
    "lng": "21.02368"
  },
  {
    "country": "PL",
    "name": "Tykocin",
    "lat": "53.20567",
    "lng": "22.77457"
  },
  {
    "country": "PL",
    "name": "Tyczyn",
    "lat": "49.96384",
    "lng": "22.03398"
  },
  {
    "country": "PL",
    "name": "Turze Pole",
    "lat": "49.66329",
    "lng": "22.00476"
  },
  {
    "country": "PL",
    "name": "Turośń Kościelna",
    "lat": "53.01463",
    "lng": "23.05532"
  },
  {
    "country": "PL",
    "name": "Turobin",
    "lat": "50.82367",
    "lng": "22.74273"
  },
  {
    "country": "PL",
    "name": "Tuczna",
    "lat": "51.88029",
    "lng": "23.4252"
  },
  {
    "country": "PL",
    "name": "Tuczępy",
    "lat": "50.51676",
    "lng": "20.99187"
  },
  {
    "country": "PL",
    "name": "Tuchów",
    "lat": "49.89485",
    "lng": "21.05407"
  },
  {
    "country": "PL",
    "name": "Trzydnik Duży",
    "lat": "50.84887",
    "lng": "22.13359"
  },
  {
    "country": "PL",
    "name": "Trzemeśnia",
    "lat": "49.82752",
    "lng": "20.02207"
  },
  {
    "country": "PL",
    "name": "Trzebownisko",
    "lat": "50.07829",
    "lng": "22.03712"
  },
  {
    "country": "PL",
    "name": "Trzebieszów",
    "lat": "51.99006",
    "lng": "22.55502"
  },
  {
    "country": "PL",
    "name": "Trzcinica",
    "lat": "49.74301",
    "lng": "21.4175"
  },
  {
    "country": "PL",
    "name": "Trzciana",
    "lat": "50.30771",
    "lng": "21.33725"
  },
  {
    "country": "PL",
    "name": "Trzciana",
    "lat": "50.0719",
    "lng": "21.8385"
  },
  {
    "country": "PL",
    "name": "Trzciana",
    "lat": "49.84485",
    "lng": "20.37415"
  },
  {
    "country": "PL",
    "name": "Tryńcza",
    "lat": "50.16087",
    "lng": "22.55008"
  },
  {
    "country": "PL",
    "name": "Truskaw",
    "lat": "52.30124",
    "lng": "20.78244"
  },
  {
    "country": "PL",
    "name": "Troszyn",
    "lat": "53.03115",
    "lng": "21.73083"
  },
  {
    "country": "PL",
    "name": "Trojanów",
    "lat": "51.69225",
    "lng": "21.81112"
  },
  {
    "country": "PL",
    "name": "Trawniki",
    "lat": "51.13633",
    "lng": "22.99816"
  },
  {
    "country": "PL",
    "name": "Trablice",
    "lat": "51.35249",
    "lng": "21.12877"
  },
  {
    "country": "PL",
    "name": "Trąbki",
    "lat": "51.94792",
    "lng": "21.59929"
  },
  {
    "country": "PL",
    "name": "Trąbki",
    "lat": "49.96226",
    "lng": "20.1424"
  },
  {
    "country": "PL",
    "name": "Tomaszów Mazowiecki",
    "lat": "51.53131",
    "lng": "20.00855"
  },
  {
    "country": "PL",
    "name": "Tomaszów Lubelski",
    "lat": "50.44767",
    "lng": "23.41616"
  },
  {
    "country": "PL",
    "name": "Tłuszcz",
    "lat": "52.43058",
    "lng": "21.43561"
  },
  {
    "country": "PL",
    "name": "Tereszpol",
    "lat": "50.58373",
    "lng": "22.8798"
  },
  {
    "country": "PL",
    "name": "Terespol",
    "lat": "52.0755",
    "lng": "23.61614"
  },
  {
    "country": "PL",
    "name": "Teresin",
    "lat": "52.19887",
    "lng": "20.41672"
  },
  {
    "country": "PL",
    "name": "Telatyn",
    "lat": "50.52712",
    "lng": "23.83956"
  },
  {
    "country": "PL",
    "name": "Tczów",
    "lat": "51.326",
    "lng": "21.44677"
  },
  {
    "country": "PL",
    "name": "Tarnowiec",
    "lat": "49.98164",
    "lng": "20.98655"
  },
  {
    "country": "PL",
    "name": "Tarnowiec",
    "lat": "49.73108",
    "lng": "21.57663"
  },
  {
    "country": "PL",
    "name": "Tarnów",
    "lat": "50.01381",
    "lng": "20.98698"
  },
  {
    "country": "PL",
    "name": "Tarnogród",
    "lat": "50.3609",
    "lng": "22.74174"
  },
  {
    "country": "PL",
    "name": "Tarnobrzeg",
    "lat": "50.57304",
    "lng": "21.67937"
  },
  {
    "country": "PL",
    "name": "Tarnawatka",
    "lat": "50.53154",
    "lng": "23.3959"
  },
  {
    "country": "PL",
    "name": "Tarłów",
    "lat": "51.0016",
    "lng": "21.71474"
  },
  {
    "country": "PL",
    "name": "Targowisko",
    "lat": "49.98473",
    "lng": "20.29346"
  },
  {
    "country": "PL",
    "name": "Targówek",
    "lat": "52.29185",
    "lng": "21.04845"
  },
  {
    "country": "PL",
    "name": "Tarczyn",
    "lat": "51.98197",
    "lng": "20.83394"
  },
  {
    "country": "PL",
    "name": "Szynwałd",
    "lat": "49.96767",
    "lng": "21.12293"
  },
  {
    "country": "PL",
    "name": "Szydłowo",
    "lat": "53.08062",
    "lng": "20.45071"
  },
  {
    "country": "PL",
    "name": "Szydłowiec",
    "lat": "51.22823",
    "lng": "20.86106"
  },
  {
    "country": "PL",
    "name": "Szydłów",
    "lat": "50.59114",
    "lng": "21.0068"
  },
  {
    "country": "PL",
    "name": "Szumowo",
    "lat": "52.91884",
    "lng": "22.08449"
  },
  {
    "country": "PL",
    "name": "Szreńsk",
    "lat": "53.01277",
    "lng": "20.12009"
  },
  {
    "country": "PL",
    "name": "Szerzyny",
    "lat": "49.80919",
    "lng": "21.2467"
  },
  {
    "country": "PL",
    "name": "Szepietowo",
    "lat": "52.87032",
    "lng": "22.54392"
  },
  {
    "country": "PL",
    "name": "Szelków",
    "lat": "52.83487",
    "lng": "21.21769"
  },
  {
    "country": "PL",
    "name": "Szczytno",
    "lat": "53.56259",
    "lng": "20.98747"
  },
  {
    "country": "PL",
    "name": "Szczurowa",
    "lat": "50.11915",
    "lng": "20.6361"
  },
  {
    "country": "PL",
    "name": "Szczuczyn",
    "lat": "53.5633",
    "lng": "22.28534"
  },
  {
    "country": "PL",
    "name": "Szczucin",
    "lat": "50.30957",
    "lng": "21.07444"
  },
  {
    "country": "PL",
    "name": "Szczebrzeszyn",
    "lat": "50.69499",
    "lng": "22.97954"
  },
  {
    "country": "PL",
    "name": "Szczawnica",
    "lat": "49.42437",
    "lng": "20.48487"
  },
  {
    "country": "PL",
    "name": "Szastarka",
    "lat": "50.85527",
    "lng": "22.31971"
  },
  {
    "country": "PL",
    "name": "Szarów",
    "lat": "49.99505",
    "lng": "20.2696"
  },
  {
    "country": "PL",
    "name": "Szaflary",
    "lat": "49.42655",
    "lng": "20.02713"
  },
  {
    "country": "PL",
    "name": "Sypniewo",
    "lat": "53.0058",
    "lng": "21.3073"
  },
  {
    "country": "PL",
    "name": "Świlcza",
    "lat": "50.07179",
    "lng": "21.89798"
  },
  {
    "country": "PL",
    "name": "Swiętajno",
    "lat": "54.00151",
    "lng": "22.3183"
  },
  {
    "country": "PL",
    "name": "Świętajno",
    "lat": "53.56692",
    "lng": "21.21546"
  },
  {
    "country": "PL",
    "name": "Świdnik",
    "lat": "51.21898",
    "lng": "22.69621"
  },
  {
    "country": "PL",
    "name": "Suwałki",
    "lat": "54.11175",
    "lng": "22.93087"
  },
  {
    "country": "PL",
    "name": "Susiec",
    "lat": "50.41973",
    "lng": "23.19626"
  },
  {
    "country": "PL",
    "name": "Suraż",
    "lat": "52.94908",
    "lng": "22.95653"
  },
  {
    "country": "PL",
    "name": "Supraśl",
    "lat": "53.20526",
    "lng": "23.33934"
  },
  {
    "country": "PL",
    "name": "Sułów",
    "lat": "50.90661",
    "lng": "22.36061"
  },
  {
    "country": "PL",
    "name": "Sułów",
    "lat": "50.77099",
    "lng": "22.95593"
  },
  {
    "country": "PL",
    "name": "Sułkowice",
    "lat": "51.9231",
    "lng": "21.08929"
  },
  {
    "country": "PL",
    "name": "Sulejówek",
    "lat": "52.25221",
    "lng": "21.26902"
  },
  {
    "country": "PL",
    "name": "Suchożebry",
    "lat": "52.25948",
    "lng": "22.25289"
  },
  {
    "country": "PL",
    "name": "Suchowola",
    "lat": "53.57753",
    "lng": "23.10596"
  },
  {
    "country": "PL",
    "name": "Suchedniów",
    "lat": "51.04776",
    "lng": "20.82922"
  },
  {
    "country": "PL",
    "name": "Sucha",
    "lat": "51.61999",
    "lng": "20.94887"
  },
  {
    "country": "PL",
    "name": "Stupsk",
    "lat": "53.02258",
    "lng": "20.4368"
  },
  {
    "country": "PL",
    "name": "Stubno",
    "lat": "49.89806",
    "lng": "22.95602"
  },
  {
    "country": "PL",
    "name": "Strzyżowice",
    "lat": "51.0483",
    "lng": "22.44018"
  },
  {
    "country": "PL",
    "name": "Strzyżów",
    "lat": "49.87074",
    "lng": "21.79413"
  },
  {
    "country": "PL",
    "name": "Strzegowo",
    "lat": "52.89394",
    "lng": "20.28548"
  },
  {
    "country": "PL",
    "name": "Stromiec",
    "lat": "51.647",
    "lng": "21.09229"
  },
  {
    "country": "PL",
    "name": "Strawczyn",
    "lat": "50.94177",
    "lng": "20.42135"
  },
  {
    "country": "PL",
    "name": "Straszydle",
    "lat": "49.90038",
    "lng": "21.98124"
  },
  {
    "country": "PL",
    "name": "Strachówka",
    "lat": "52.42692",
    "lng": "21.635"
  },
  {
    "country": "PL",
    "name": "Strachocina",
    "lat": "49.60815",
    "lng": "22.08836"
  },
  {
    "country": "PL",
    "name": "Stopnica",
    "lat": "50.44018",
    "lng": "20.9378"
  },
  {
    "country": "PL",
    "name": "Stoczek Łukowski",
    "lat": "51.96135",
    "lng": "21.97137"
  },
  {
    "country": "PL",
    "name": "Stoczek",
    "lat": "52.54332",
    "lng": "21.90013"
  },
  {
    "country": "PL",
    "name": "Stężyca",
    "lat": "51.58187",
    "lng": "21.77087"
  },
  {
    "country": "PL",
    "name": "Sterdyń",
    "lat": "52.58026",
    "lng": "22.29358"
  },
  {
    "country": "PL",
    "name": "Stawiski",
    "lat": "53.37987",
    "lng": "22.15462"
  },
  {
    "country": "PL",
    "name": "Stawiguda",
    "lat": "53.6572",
    "lng": "20.40041"
  },
  {
    "country": "PL",
    "name": "Staszów",
    "lat": "50.56307",
    "lng": "21.16593"
  },
  {
    "country": "PL",
    "name": "Stary Zamość",
    "lat": "50.82004",
    "lng": "23.17154"
  },
  {
    "country": "PL",
    "name": "Stary Wiśnicz",
    "lat": "49.92548",
    "lng": "20.48641"
  },
  {
    "country": "PL",
    "name": "Stary Sącz",
    "lat": "49.56364",
    "lng": "20.63496"
  },
  {
    "country": "PL",
    "name": "Stare Miasto",
    "lat": "50.28879",
    "lng": "22.42928"
  },
  {
    "country": "PL",
    "name": "Stare Juchy",
    "lat": "53.92198",
    "lng": "22.17367"
  },
  {
    "country": "PL",
    "name": "Stare Babice",
    "lat": "52.26028",
    "lng": "20.83403"
  },
  {
    "country": "PL",
    "name": "Stara Wieś",
    "lat": "49.71505",
    "lng": "22.00441"
  },
  {
    "country": "PL",
    "name": "Starachowice",
    "lat": "51.0374",
    "lng": "21.07126"
  },
  {
    "country": "PL",
    "name": "Stąporków",
    "lat": "51.13762",
    "lng": "20.57173"
  },
  {
    "country": "PL",
    "name": "Stanisławów Pierwszy",
    "lat": "52.37485",
    "lng": "21.05184"
  },
  {
    "country": "PL",
    "name": "Stanisławów",
    "lat": "52.28937",
    "lng": "21.54848"
  },
  {
    "country": "PL",
    "name": "Stanisławice",
    "lat": "49.9855",
    "lng": "20.35123"
  },
  {
    "country": "PL",
    "name": "Stalowa Wola",
    "lat": "50.58286",
    "lng": "22.05334"
  },
  {
    "country": "PL",
    "name": "Srokowo",
    "lat": "54.21416",
    "lng": "21.52282"
  },
  {
    "country": "PL",
    "name": "Śródmieście",
    "lat": "52.22904",
    "lng": "21.01644"
  },
  {
    "country": "PL",
    "name": "Spiczyn",
    "lat": "51.34128",
    "lng": "22.75354"
  },
  {
    "country": "PL",
    "name": "Sosnówka",
    "lat": "51.75084",
    "lng": "23.33814"
  },
  {
    "country": "PL",
    "name": "Sosnowica",
    "lat": "51.52065",
    "lng": "23.09215"
  },
  {
    "country": "PL",
    "name": "Sośnica",
    "lat": "49.90083",
    "lng": "22.87469"
  },
  {
    "country": "PL",
    "name": "Sońsk",
    "lat": "52.78164",
    "lng": "20.69901"
  },
  {
    "country": "PL",
    "name": "Sonina",
    "lat": "50.06089",
    "lng": "22.26551"
  },
  {
    "country": "PL",
    "name": "Solec-Zdrój",
    "lat": "50.36594",
    "lng": "20.88956"
  },
  {
    "country": "PL",
    "name": "Solec Nad Wisłą",
    "lat": "51.13633",
    "lng": "21.76563"
  },
  {
    "country": "PL",
    "name": "Sokoły",
    "lat": "52.99314",
    "lng": "22.7005"
  },
  {
    "country": "PL",
    "name": "Sokołów Podlaski",
    "lat": "52.40677",
    "lng": "22.25307"
  },
  {
    "country": "PL",
    "name": "Sokołów Małopolski",
    "lat": "50.22909",
    "lng": "22.11968"
  },
  {
    "country": "PL",
    "name": "Sokolniki",
    "lat": "50.63803",
    "lng": "21.80649"
  },
  {
    "country": "PL",
    "name": "Sokółka",
    "lat": "53.40715",
    "lng": "23.50228"
  },
  {
    "country": "PL",
    "name": "Sochocin",
    "lat": "52.68715",
    "lng": "20.47259"
  },
  {
    "country": "PL",
    "name": "Sochaczew",
    "lat": "52.22944",
    "lng": "20.23838"
  },
  {
    "country": "PL",
    "name": "Sobolew",
    "lat": "51.7366",
    "lng": "21.66349"
  },
  {
    "country": "PL",
    "name": "Sobków",
    "lat": "50.69999",
    "lng": "20.45062"
  },
  {
    "country": "PL",
    "name": "Sobienie Jeziory",
    "lat": "51.93273",
    "lng": "21.30335"
  },
  {
    "country": "PL",
    "name": "Śniadowo",
    "lat": "53.03874",
    "lng": "21.99077"
  },
  {
    "country": "PL",
    "name": "Smyków",
    "lat": "51.04442",
    "lng": "20.40032"
  },
  {
    "country": "PL",
    "name": "Smęgorzów",
    "lat": "50.22843",
    "lng": "21.00414"
  },
  {
    "country": "PL",
    "name": "Słupno",
    "lat": "52.38409",
    "lng": "21.15572"
  },
  {
    "country": "PL",
    "name": "Słupiec",
    "lat": "50.32787",
    "lng": "21.19374"
  },
  {
    "country": "PL",
    "name": "Słupia",
    "lat": "51.0137",
    "lng": "20.1406"
  },
  {
    "country": "PL",
    "name": "Słotowa",
    "lat": "49.94603",
    "lng": "21.29425"
  },
  {
    "country": "PL",
    "name": "Słopnice",
    "lat": "49.68496",
    "lng": "20.34325"
  },
  {
    "country": "PL",
    "name": "Słomniki",
    "lat": "50.24012",
    "lng": "20.08224"
  },
  {
    "country": "PL",
    "name": "Sławno",
    "lat": "51.39273",
    "lng": "20.14043"
  },
  {
    "country": "PL",
    "name": "Sławatycze",
    "lat": "51.76338",
    "lng": "23.5546"
  },
  {
    "country": "PL",
    "name": "Skrzyszów",
    "lat": "49.99373",
    "lng": "21.06139"
  },
  {
    "country": "PL",
    "name": "Skrzydlna",
    "lat": "49.75343",
    "lng": "20.18618"
  },
  {
    "country": "PL",
    "name": "Skórzec",
    "lat": "52.10727",
    "lng": "22.13052"
  },
  {
    "country": "PL",
    "name": "Skołyszyn",
    "lat": "49.74955",
    "lng": "21.33665"
  },
  {
    "country": "PL",
    "name": "Skierniewice",
    "lat": "51.95485",
    "lng": "20.15837"
  },
  {
    "country": "PL",
    "name": "Skierbieszów",
    "lat": "50.85158",
    "lng": "23.35917"
  },
  {
    "country": "PL",
    "name": "Skarżysko Kościelne",
    "lat": "51.13822",
    "lng": "20.91196"
  },
  {
    "country": "PL",
    "name": "Skarżysko-Kamienna",
    "lat": "51.11311",
    "lng": "20.87162"
  },
  {
    "country": "PL",
    "name": "Skaryszew",
    "lat": "51.31075",
    "lng": "21.25233"
  },
  {
    "country": "PL",
    "name": "Skalbmierz",
    "lat": "50.31993",
    "lng": "20.39929"
  },
  {
    "country": "PL",
    "name": "Sitno",
    "lat": "50.74944",
    "lng": "23.3626"
  },
  {
    "country": "PL",
    "name": "Osiedle-Nowiny",
    "lat": "50.8177",
    "lng": "20.54117"
  },
  {
    "country": "PL",
    "name": "Sietesz",
    "lat": "49.98622",
    "lng": "22.34671"
  },
  {
    "country": "PL",
    "name": "Sieradza",
    "lat": "50.13499",
    "lng": "20.92947"
  },
  {
    "country": "PL",
    "name": "Sienno",
    "lat": "51.08773",
    "lng": "21.48325"
  },
  {
    "country": "PL",
    "name": "Siennica",
    "lat": "52.09164",
    "lng": "21.61921"
  },
  {
    "country": "PL",
    "name": "Sieniawa",
    "lat": "50.1779",
    "lng": "22.60954"
  },
  {
    "country": "PL",
    "name": "Sieniawa",
    "lat": "49.56508",
    "lng": "21.92785"
  },
  {
    "country": "PL",
    "name": "Siemień",
    "lat": "51.62883",
    "lng": "22.77243"
  },
  {
    "country": "PL",
    "name": "Siemiechów",
    "lat": "49.85359",
    "lng": "20.90595"
  },
  {
    "country": "PL",
    "name": "Siemiatycze",
    "lat": "52.42719",
    "lng": "22.86231"
  },
  {
    "country": "PL",
    "name": "Siemiątkowo",
    "lat": "52.8811",
    "lng": "20.02893"
  },
  {
    "country": "PL",
    "name": "Siedliska",
    "lat": "49.95409",
    "lng": "21.94742"
  },
  {
    "country": "PL",
    "name": "Siedliska",
    "lat": "49.87163",
    "lng": "20.99625"
  },
  {
    "country": "PL",
    "name": "Siedleczka",
    "lat": "49.96061",
    "lng": "22.37949"
  },
  {
    "country": "PL",
    "name": "Siedlce",
    "lat": "52.16772",
    "lng": "22.29006"
  },
  {
    "country": "PL",
    "name": "Serokomla",
    "lat": "51.7007",
    "lng": "22.33237"
  },
  {
    "country": "PL",
    "name": "Serock",
    "lat": "52.51036",
    "lng": "21.0691"
  },
  {
    "country": "PL",
    "name": "Serniki",
    "lat": "51.43716",
    "lng": "22.65853"
  },
  {
    "country": "PL",
    "name": "Sępopol",
    "lat": "54.26903",
    "lng": "21.01453"
  },
  {
    "country": "PL",
    "name": "Sękowa",
    "lat": "49.62217",
    "lng": "21.19769"
  },
  {
    "country": "PL",
    "name": "Sejny",
    "lat": "54.10802",
    "lng": "23.34698"
  },
  {
    "country": "PL",
    "name": "Sędziszów Małopolski",
    "lat": "50.07069",
    "lng": "21.70062"
  },
  {
    "country": "PL",
    "name": "Sędziszów",
    "lat": "50.5659",
    "lng": "20.05563"
  },
  {
    "country": "PL",
    "name": "Sawin",
    "lat": "51.27443",
    "lng": "23.43375"
  },
  {
    "country": "PL",
    "name": "Sarnaki",
    "lat": "52.31504",
    "lng": "22.89044"
  },
  {
    "country": "PL",
    "name": "Sanok",
    "lat": "49.55573",
    "lng": "22.2056"
  },
  {
    "country": "PL",
    "name": "Sandomierz",
    "lat": "50.68265",
    "lng": "21.74898"
  },
  {
    "country": "PL",
    "name": "Samborzec",
    "lat": "50.64663",
    "lng": "21.64822"
  },
  {
    "country": "PL",
    "name": "Sadowne",
    "lat": "52.64124",
    "lng": "21.84563"
  },
  {
    "country": "PL",
    "name": "Sadowie",
    "lat": "50.85261",
    "lng": "21.36884"
  },
  {
    "country": "PL",
    "name": "Sadkowice",
    "lat": "51.72517",
    "lng": "20.51465"
  },
  {
    "country": "PL",
    "name": "Sabnie",
    "lat": "52.50097",
    "lng": "22.30697"
  },
  {
    "country": "PL",
    "name": "Rzezawa",
    "lat": "49.98997",
    "lng": "20.51508"
  },
  {
    "country": "PL",
    "name": "Rzewnie",
    "lat": "52.83508",
    "lng": "21.33682"
  },
  {
    "country": "PL",
    "name": "Rzeszów",
    "lat": "50.04132",
    "lng": "21.99901"
  },
  {
    "country": "PL",
    "name": "Rzepiennik Strzyżewski",
    "lat": "49.80542",
    "lng": "21.03599"
  },
  {
    "country": "PL",
    "name": "Rzepedź",
    "lat": "49.36997",
    "lng": "22.11174"
  },
  {
    "country": "PL",
    "name": "Rzekuń",
    "lat": "53.04756",
    "lng": "21.62069"
  },
  {
    "country": "PL",
    "name": "Rzeczyca",
    "lat": "51.96225",
    "lng": "22.74942"
  },
  {
    "country": "PL",
    "name": "Rzeczyca",
    "lat": "51.59824",
    "lng": "20.29484"
  },
  {
    "country": "PL",
    "name": "Rzeczniów",
    "lat": "51.12804",
    "lng": "21.44008"
  },
  {
    "country": "PL",
    "name": "Rząśnik",
    "lat": "52.71332",
    "lng": "21.36772"
  },
  {
    "country": "PL",
    "name": "Rytwiany",
    "lat": "50.5292",
    "lng": "21.20636"
  },
  {
    "country": "PL",
    "name": "Rytro",
    "lat": "49.48904",
    "lng": "20.66631"
  },
  {
    "country": "PL",
    "name": "Ryn",
    "lat": "53.9377",
    "lng": "21.54642"
  },
  {
    "country": "PL",
    "name": "Rymanów",
    "lat": "49.57649",
    "lng": "21.86811"
  },
  {
    "country": "PL",
    "name": "Ryki",
    "lat": "51.62574",
    "lng": "21.93274"
  },
  {
    "country": "PL",
    "name": "Ryglice",
    "lat": "49.87887",
    "lng": "21.13748"
  },
  {
    "country": "PL",
    "name": "Ryczywół",
    "lat": "51.69118",
    "lng": "21.42197"
  },
  {
    "country": "PL",
    "name": "Rybno",
    "lat": "52.24278",
    "lng": "20.10301"
  },
  {
    "country": "PL",
    "name": "Rybie",
    "lat": "52.15229",
    "lng": "20.93655"
  },
  {
    "country": "PL",
    "name": "Rybczewice",
    "lat": "51.02876",
    "lng": "22.85053"
  },
  {
    "country": "PL",
    "name": "Rutki",
    "lat": "53.1",
    "lng": "22.43333"
  },
  {
    "country": "PL",
    "name": "Rusinów",
    "lat": "51.43678",
    "lng": "20.58701"
  },
  {
    "country": "PL",
    "name": "Rudnik",
    "lat": "50.88035",
    "lng": "22.97293"
  },
  {
    "country": "PL",
    "name": "Rudnik nad Sanem",
    "lat": "50.44152",
    "lng": "22.24856"
  },
  {
    "country": "PL",
    "name": "Rudna Wielka",
    "lat": "50.08799",
    "lng": "21.94759"
  },
  {
    "country": "PL",
    "name": "Rudna Mała",
    "lat": "50.09889",
    "lng": "21.96021"
  },
  {
    "country": "PL",
    "name": "Rudka",
    "lat": "52.72439",
    "lng": "22.72676"
  },
  {
    "country": "PL",
    "name": "Ruda Maleniecka",
    "lat": "51.14592",
    "lng": "20.22377"
  },
  {
    "country": "PL",
    "name": "Ruciane-Nida",
    "lat": "53.64161",
    "lng": "21.53964"
  },
  {
    "country": "PL",
    "name": "Rozogi",
    "lat": "53.48549",
    "lng": "21.36223"
  },
  {
    "country": "PL",
    "name": "Rozbórz",
    "lat": "50.05615",
    "lng": "22.54686"
  },
  {
    "country": "PL",
    "name": "Siennica Różana",
    "lat": "51.00123",
    "lng": "23.3226"
  },
  {
    "country": "PL",
    "name": "Różan",
    "lat": "52.88757",
    "lng": "21.39105"
  },
  {
    "country": "PL",
    "name": "Rossosz",
    "lat": "51.85836",
    "lng": "23.1374"
  },
  {
    "country": "PL",
    "name": "Ropczyce",
    "lat": "50.05229",
    "lng": "21.60891"
  },
  {
    "country": "PL",
    "name": "Ropa",
    "lat": "49.59146",
    "lng": "21.04431"
  },
  {
    "country": "PL",
    "name": "Rokitno",
    "lat": "52.12142",
    "lng": "23.29514"
  },
  {
    "country": "PL",
    "name": "Rokietnica",
    "lat": "49.89983",
    "lng": "22.64171"
  },
  {
    "country": "PL",
    "name": "Rogóźno",
    "lat": "50.46417",
    "lng": "23.39041"
  },
  {
    "country": "PL",
    "name": "Rogóźno",
    "lat": "50.07367",
    "lng": "22.37486"
  },
  {
    "country": "PL",
    "name": "Rogów",
    "lat": "51.20414",
    "lng": "20.43483"
  },
  {
    "country": "PL",
    "name": "Reszel",
    "lat": "54.05042",
    "lng": "21.14585"
  },
  {
    "country": "PL",
    "name": "Repki",
    "lat": "52.38555",
    "lng": "22.39117"
  },
  {
    "country": "PL",
    "name": "Rembertów",
    "lat": "52.26059",
    "lng": "21.16355"
  },
  {
    "country": "PL",
    "name": "Rejowiec Fabryczny",
    "lat": "51.11414",
    "lng": "23.24724"
  },
  {
    "country": "PL",
    "name": "Rejowiec",
    "lat": "51.09134",
    "lng": "23.28192"
  },
  {
    "country": "PL",
    "name": "Regnów",
    "lat": "51.7485",
    "lng": "20.38711"
  },
  {
    "country": "PL",
    "name": "Regimin",
    "lat": "52.94166",
    "lng": "20.55319"
  },
  {
    "country": "PL",
    "name": "Rawa Mazowiecka",
    "lat": "51.76437",
    "lng": "20.25493"
  },
  {
    "country": "PL",
    "name": "Raszyn",
    "lat": "52.15603",
    "lng": "20.9226"
  },
  {
    "country": "PL",
    "name": "Raniżów",
    "lat": "50.25873",
    "lng": "21.97137"
  },
  {
    "country": "PL",
    "name": "Rakszawa",
    "lat": "50.16051",
    "lng": "22.23907"
  },
  {
    "country": "PL",
    "name": "Raków",
    "lat": "50.67427",
    "lng": "21.04517"
  },
  {
    "country": "PL",
    "name": "Rajgród",
    "lat": "53.73102",
    "lng": "22.70515"
  },
  {
    "country": "PL",
    "name": "Radzyń Podlaski",
    "lat": "51.78333",
    "lng": "22.61667"
  },
  {
    "country": "PL",
    "name": "Radzymin",
    "lat": "52.41592",
    "lng": "21.18415"
  },
  {
    "country": "PL",
    "name": "Radziłów",
    "lat": "53.40994",
    "lng": "22.40988"
  },
  {
    "country": "PL",
    "name": "Radziejowice",
    "lat": "52.00834",
    "lng": "20.5477"
  },
  {
    "country": "PL",
    "name": "Radzanów",
    "lat": "52.94238",
    "lng": "20.09219"
  },
  {
    "country": "PL",
    "name": "Radzanów",
    "lat": "51.55786",
    "lng": "20.86398"
  },
  {
    "country": "PL",
    "name": "Radymno",
    "lat": "49.9472",
    "lng": "22.82375"
  },
  {
    "country": "PL",
    "name": "Radoszyce",
    "lat": "51.07392",
    "lng": "20.25836"
  },
  {
    "country": "PL",
    "name": "Radomyśl Wielki",
    "lat": "50.19693",
    "lng": "21.27693"
  },
  {
    "country": "PL",
    "name": "Radomyśl",
    "lat": "50.68101",
    "lng": "21.94365"
  },
  {
    "country": "PL",
    "name": "Radom",
    "lat": "51.40253",
    "lng": "21.14714"
  },
  {
    "country": "PL",
    "name": "Radłów",
    "lat": "50.08419",
    "lng": "20.84967"
  },
  {
    "country": "PL",
    "name": "Radgoszcz",
    "lat": "50.2058",
    "lng": "21.11315"
  },
  {
    "country": "PL",
    "name": "Radecznica",
    "lat": "50.75155",
    "lng": "22.82976"
  },
  {
    "country": "PL",
    "name": "Raczki",
    "lat": "53.98749",
    "lng": "22.78487"
  },
  {
    "country": "PL",
    "name": "Racławice",
    "lat": "50.5137",
    "lng": "22.16552"
  },
  {
    "country": "PL",
    "name": "Raciąż",
    "lat": "52.78152",
    "lng": "20.1177"
  },
  {
    "country": "PL",
    "name": "Rachanie",
    "lat": "50.53842",
    "lng": "23.54688"
  },
  {
    "country": "PL",
    "name": "Pysznica",
    "lat": "50.56999",
    "lng": "22.12913"
  },
  {
    "country": "PL",
    "name": "Puszcza Mariańska",
    "lat": "51.97901",
    "lng": "20.35037"
  },
  {
    "country": "PL",
    "name": "Purda",
    "lat": "53.70844",
    "lng": "20.70683"
  },
  {
    "country": "PL",
    "name": "Puńsk",
    "lat": "54.25114",
    "lng": "23.18124"
  },
  {
    "country": "PL",
    "name": "Pułtusk",
    "lat": "52.7025",
    "lng": "21.08276"
  },
  {
    "country": "PL",
    "name": "Puławy",
    "lat": "51.41655",
    "lng": "21.96939"
  },
  {
    "country": "PL",
    "name": "Puchaczów",
    "lat": "51.3105",
    "lng": "22.9737"
  },
  {
    "country": "PL",
    "name": "Przytyk",
    "lat": "51.46567",
    "lng": "20.90587"
  },
  {
    "country": "PL",
    "name": "Przytoczno",
    "lat": "51.61951",
    "lng": "22.27135"
  },
  {
    "country": "PL",
    "name": "Przysucha",
    "lat": "51.35858",
    "lng": "20.62889"
  },
  {
    "country": "PL",
    "name": "Przyłęk",
    "lat": "51.30856",
    "lng": "21.74744"
  },
  {
    "country": "PL",
    "name": "Przybyszówka",
    "lat": "50.04788",
    "lng": "21.92579"
  },
  {
    "country": "PL",
    "name": "Przyborów",
    "lat": "50.03035",
    "lng": "20.66279"
  },
  {
    "country": "PL",
    "name": "Przeworsk",
    "lat": "50.05912",
    "lng": "22.49408"
  },
  {
    "country": "PL",
    "name": "Przesmyki",
    "lat": "52.26816",
    "lng": "22.58394"
  },
  {
    "country": "PL",
    "name": "Przemyśl",
    "lat": "49.78498",
    "lng": "22.76728"
  },
  {
    "country": "PL",
    "name": "Przędzel",
    "lat": "50.49465",
    "lng": "22.21925"
  },
  {
    "country": "PL",
    "name": "Przedmieście Dubieckie",
    "lat": "49.8371",
    "lng": "22.37177"
  },
  {
    "country": "PL",
    "name": "Przecław",
    "lat": "50.19339",
    "lng": "21.48007"
  },
  {
    "country": "PL",
    "name": "Przasnysz",
    "lat": "53.01907",
    "lng": "20.88029"
  },
  {
    "country": "PL",
    "name": "Pruszków",
    "lat": "52.17072",
    "lng": "20.81214"
  },
  {
    "country": "PL",
    "name": "Pruchnik",
    "lat": "49.9062",
    "lng": "22.51554"
  },
  {
    "country": "PL",
    "name": "Proszowice",
    "lat": "50.19275",
    "lng": "20.28909"
  },
  {
    "country": "PL",
    "name": "Prostki",
    "lat": "53.69901",
    "lng": "22.43183"
  },
  {
    "country": "PL",
    "name": "Promna",
    "lat": "51.68006",
    "lng": "20.95917"
  },
  {
    "country": "PL",
    "name": "Prażmów",
    "lat": "51.9404",
    "lng": "20.95479"
  },
  {
    "country": "PL",
    "name": "Pozezdrze",
    "lat": "54.14147",
    "lng": "21.8597"
  },
  {
    "country": "PL",
    "name": "Potworów",
    "lat": "51.50874",
    "lng": "20.72176"
  },
  {
    "country": "PL",
    "name": "Potok Wielki",
    "lat": "50.7915",
    "lng": "22.21642"
  },
  {
    "country": "PL",
    "name": "Potok Górny",
    "lat": "50.38477",
    "lng": "22.56188"
  },
  {
    "country": "PL",
    "name": "Poświętne",
    "lat": "52.32967",
    "lng": "21.42137"
  },
  {
    "country": "PL",
    "name": "Poświętne",
    "lat": "51.53203",
    "lng": "20.36453"
  },
  {
    "country": "PL",
    "name": "Poronin",
    "lat": "49.33781",
    "lng": "20.00291"
  },
  {
    "country": "PL",
    "name": "Poręba Spytkowska",
    "lat": "49.93995",
    "lng": "20.55405"
  },
  {
    "country": "PL",
    "name": "Poręba",
    "lat": "49.79645",
    "lng": "20.01718"
  },
  {
    "country": "PL",
    "name": "Poraż",
    "lat": "49.48597",
    "lng": "22.225"
  },
  {
    "country": "PL",
    "name": "Porąbka Uszewska",
    "lat": "49.9426",
    "lng": "20.69052"
  },
  {
    "country": "PL",
    "name": "Poniatowa",
    "lat": "51.17983",
    "lng": "22.13093"
  },
  {
    "country": "PL",
    "name": "Pomiechówek",
    "lat": "52.47138",
    "lng": "20.72923"
  },
  {
    "country": "PL",
    "name": "Połomia",
    "lat": "49.90475",
    "lng": "21.89198"
  },
  {
    "country": "PL",
    "name": "Policzna",
    "lat": "51.45545",
    "lng": "21.62684"
  },
  {
    "country": "PL",
    "name": "Połaniec",
    "lat": "50.43324",
    "lng": "21.2812"
  },
  {
    "country": "PL",
    "name": "Polańczyk",
    "lat": "49.36969",
    "lng": "22.42112"
  },
  {
    "country": "PL",
    "name": "Pokrzywnica",
    "lat": "52.62072",
    "lng": "21.01925"
  },
  {
    "country": "PL",
    "name": "Pokrówka",
    "lat": "51.09479",
    "lng": "23.46345"
  },
  {
    "country": "PL",
    "name": "Pogórska Wola",
    "lat": "50.01855",
    "lng": "21.15795"
  },
  {
    "country": "PL",
    "name": "Podłęże",
    "lat": "50.01458",
    "lng": "20.16781"
  },
  {
    "country": "PL",
    "name": "Podkowa Leśna",
    "lat": "52.12237",
    "lng": "20.72665"
  },
  {
    "country": "PL",
    "name": "Podegrodzie",
    "lat": "49.57688",
    "lng": "20.58855"
  },
  {
    "country": "PL",
    "name": "Podedwórze",
    "lat": "51.68815",
    "lng": "23.19961"
  },
  {
    "country": "PL",
    "name": "Pniewy",
    "lat": "51.91468",
    "lng": "20.74578"
  },
  {
    "country": "PL",
    "name": "Płońsk",
    "lat": "52.62348",
    "lng": "20.37552"
  },
  {
    "country": "PL",
    "name": "Płoniawy-Bramura",
    "lat": "52.9778",
    "lng": "21.07178"
  },
  {
    "country": "PL",
    "name": "Pleśna",
    "lat": "49.92642",
    "lng": "20.94526"
  },
  {
    "country": "PL",
    "name": "Piwniczna-Zdrój",
    "lat": "49.44056",
    "lng": "20.71423"
  },
  {
    "country": "PL",
    "name": "Piszczac",
    "lat": "51.98118",
    "lng": "23.37719"
  },
  {
    "country": "PL",
    "name": "Pisz",
    "lat": "53.62744",
    "lng": "21.81253"
  },
  {
    "country": "PL",
    "name": "Piskorowice",
    "lat": "50.23579",
    "lng": "22.52867"
  },
  {
    "country": "PL",
    "name": "Pionki",
    "lat": "51.47604",
    "lng": "21.44995"
  },
  {
    "country": "PL",
    "name": "Pińczów",
    "lat": "50.52052",
    "lng": "20.52649"
  },
  {
    "country": "PL",
    "name": "Pilzno",
    "lat": "49.97883",
    "lng": "21.29228"
  },
  {
    "country": "PL",
    "name": "Pilawa",
    "lat": "51.95945",
    "lng": "21.53089"
  },
  {
    "country": "PL",
    "name": "Pierzchnica",
    "lat": "50.69754",
    "lng": "20.75489"
  },
  {
    "country": "PL",
    "name": "Pieniężno",
    "lat": "54.23649",
    "lng": "20.12833"
  },
  {
    "country": "PL",
    "name": "Piekoszów",
    "lat": "50.88035",
    "lng": "20.46418"
  },
  {
    "country": "PL",
    "name": "Piecki",
    "lat": "53.75759",
    "lng": "21.33914"
  },
  {
    "country": "PL",
    "name": "Piątnica",
    "lat": "53.19657",
    "lng": "22.09591"
  },
  {
    "country": "PL",
    "name": "Piastów",
    "lat": "52.18435",
    "lng": "20.83952"
  },
  {
    "country": "PL",
    "name": "Piaski",
    "lat": "51.13892",
    "lng": "22.84856"
  },
  {
    "country": "PL",
    "name": "Piaseczno",
    "lat": "52.0814",
    "lng": "21.02397"
  },
  {
    "country": "PL",
    "name": "Perlejewo",
    "lat": "52.56676",
    "lng": "22.56457"
  },
  {
    "country": "PL",
    "name": "Pawłów",
    "lat": "50.96216",
    "lng": "21.12062"
  },
  {
    "country": "PL",
    "name": "Pawłosiów",
    "lat": "49.99533",
    "lng": "22.64763"
  },
  {
    "country": "PL",
    "name": "Pawlikowice",
    "lat": "49.9531",
    "lng": "20.05486"
  },
  {
    "country": "PL",
    "name": "Pasym",
    "lat": "53.65069",
    "lng": "20.79188"
  },
  {
    "country": "PL",
    "name": "Parysów",
    "lat": "51.97584",
    "lng": "21.68006"
  },
  {
    "country": "PL",
    "name": "Parczew",
    "lat": "51.64021",
    "lng": "22.90057"
  },
  {
    "country": "PL",
    "name": "Paradyż",
    "lat": "51.30604",
    "lng": "20.11374"
  },
  {
    "country": "PL",
    "name": "Paprotnia",
    "lat": "52.30071",
    "lng": "22.46756"
  },
  {
    "country": "PL",
    "name": "Paprotnia",
    "lat": "52.20513",
    "lng": "20.4232"
  },
  {
    "country": "PL",
    "name": "Pantalowice",
    "lat": "49.9521",
    "lng": "22.43563"
  },
  {
    "country": "PL",
    "name": "Padew Narodowa",
    "lat": "50.43947",
    "lng": "21.50059"
  },
  {
    "country": "PL",
    "name": "Pacanów",
    "lat": "50.40031",
    "lng": "21.04148"
  },
  {
    "country": "PL",
    "name": "Ożarów Mazowiecki",
    "lat": "52.21039",
    "lng": "20.79716"
  },
  {
    "country": "PL",
    "name": "Ożarów",
    "lat": "50.88798",
    "lng": "21.66658"
  },
  {
    "country": "PL",
    "name": "Owczarnia",
    "lat": "52.11114",
    "lng": "20.70468"
  },
  {
    "country": "PL",
    "name": "Otwock",
    "lat": "52.10577",
    "lng": "21.26129"
  },
  {
    "country": "PL",
    "name": "Otrębusy",
    "lat": "52.12843",
    "lng": "20.76073"
  },
  {
    "country": "PL",
    "name": "Ostrowsko",
    "lat": "49.47616",
    "lng": "20.10052"
  },
  {
    "country": "PL",
    "name": "Ostrów Mazowiecka",
    "lat": "52.80245",
    "lng": "21.89507"
  },
  {
    "country": "PL",
    "name": "Ostrów Lubelski",
    "lat": "51.49416",
    "lng": "22.85287"
  },
  {
    "country": "PL",
    "name": "Ostrowiec Świętokrzyski",
    "lat": "50.92936",
    "lng": "21.38525"
  },
  {
    "country": "PL",
    "name": "Ostrówek",
    "lat": "52.5535",
    "lng": "21.76014"
  },
  {
    "country": "PL",
    "name": "Ostrówek",
    "lat": "51.5815",
    "lng": "22.61227"
  },
  {
    "country": "PL",
    "name": "Ostrów",
    "lat": "50.09779",
    "lng": "21.5932"
  },
  {
    "country": "PL",
    "name": "Ostrów",
    "lat": "49.96812",
    "lng": "22.7871"
  },
  {
    "country": "PL",
    "name": "Ostrołęka",
    "lat": "53.08621",
    "lng": "21.57566"
  },
  {
    "country": "PL",
    "name": "Osiek Jasielski",
    "lat": "49.63784",
    "lng": "21.4884"
  },
  {
    "country": "PL",
    "name": "Osiek",
    "lat": "50.51996",
    "lng": "21.44192"
  },
  {
    "country": "PL",
    "name": "Osieczany",
    "lat": "49.84252",
    "lng": "19.98207"
  },
  {
    "country": "PL",
    "name": "Osieck",
    "lat": "51.96653",
    "lng": "21.41913"
  },
  {
    "country": "PL",
    "name": "Orzysz",
    "lat": "53.80967",
    "lng": "21.94811"
  },
  {
    "country": "PL",
    "name": "Orzechówka",
    "lat": "49.7308",
    "lng": "21.94519"
  },
  {
    "country": "PL",
    "name": "Orońsko",
    "lat": "51.31339",
    "lng": "20.99067"
  },
  {
    "country": "PL",
    "name": "Orneta",
    "lat": "54.11483",
    "lng": "20.13328"
  },
  {
    "country": "PL",
    "name": "Orły",
    "lat": "49.87107",
    "lng": "22.80298"
  },
  {
    "country": "PL",
    "name": "Orla",
    "lat": "52.70546",
    "lng": "23.33213"
  },
  {
    "country": "PL",
    "name": "Opole Lubelskie",
    "lat": "51.14775",
    "lng": "21.96897"
  },
  {
    "country": "PL",
    "name": "Opoczno",
    "lat": "51.37569",
    "lng": "20.27827"
  },
  {
    "country": "PL",
    "name": "Opinogóra Górna",
    "lat": "52.90554",
    "lng": "20.71781"
  },
  {
    "country": "PL",
    "name": "Opatowiec",
    "lat": "50.24314",
    "lng": "20.72348"
  },
  {
    "country": "PL",
    "name": "Opatów",
    "lat": "50.80058",
    "lng": "21.42538"
  },
  {
    "country": "PL",
    "name": "Olsztynek",
    "lat": "53.58374",
    "lng": "20.28471"
  },
  {
    "country": "PL",
    "name": "Olsztyn",
    "lat": "53.77995",
    "lng": "20.49416"
  },
  {
    "country": "PL",
    "name": "Olszówka",
    "lat": "49.61455",
    "lng": "20.02885"
  },
  {
    "country": "PL",
    "name": "Olszanica",
    "lat": "49.47741",
    "lng": "22.44382"
  },
  {
    "country": "PL",
    "name": "Olszana",
    "lat": "49.56748",
    "lng": "20.52126"
  },
  {
    "country": "PL",
    "name": "Ołpiny",
    "lat": "49.80686",
    "lng": "21.20464"
  },
  {
    "country": "PL",
    "name": "Oleszyce",
    "lat": "50.1675",
    "lng": "23.03481"
  },
  {
    "country": "PL",
    "name": "Olesno",
    "lat": "50.20152",
    "lng": "20.92578"
  },
  {
    "country": "PL",
    "name": "Oleśnica",
    "lat": "50.45357",
    "lng": "21.06457"
  },
  {
    "country": "PL",
    "name": "Olecko",
    "lat": "54.03374",
    "lng": "22.50704"
  },
  {
    "country": "PL",
    "name": "Oksa",
    "lat": "50.72874",
    "lng": "20.10086"
  },
  {
    "country": "PL",
    "name": "Okocim",
    "lat": "49.9489",
    "lng": "20.6016"
  },
  {
    "country": "PL",
    "name": "Ojrzeń",
    "lat": "52.7657",
    "lng": "20.54315"
  },
  {
    "country": "PL",
    "name": "Odrzywół",
    "lat": "51.51953",
    "lng": "20.55559"
  },
  {
    "country": "PL",
    "name": "Odrzykoń",
    "lat": "49.74057",
    "lng": "21.74074"
  },
  {
    "country": "PL",
    "name": "Ochotnica Dolna",
    "lat": "49.52682",
    "lng": "20.34265"
  },
  {
    "country": "PL",
    "name": "Ochota",
    "lat": "52.22096",
    "lng": "20.98526"
  },
  {
    "country": "PL",
    "name": "Obsza",
    "lat": "50.3152",
    "lng": "22.95688"
  },
  {
    "country": "PL",
    "name": "Obryte",
    "lat": "52.71633",
    "lng": "21.24945"
  },
  {
    "country": "PL",
    "name": "Obrazów",
    "lat": "50.69276",
    "lng": "21.65045"
  },
  {
    "country": "PL",
    "name": "Nurzec-Stacja",
    "lat": "52.46249",
    "lng": "23.08571"
  },
  {
    "country": "PL",
    "name": "Nur",
    "lat": "52.66826",
    "lng": "22.32207"
  },
  {
    "country": "PL",
    "name": "Nozdrzec",
    "lat": "49.77323",
    "lng": "22.19865"
  },
  {
    "country": "PL",
    "name": "Nowy Żmigród",
    "lat": "49.60353",
    "lng": "21.52376"
  },
  {
    "country": "PL",
    "name": "Nowy Wiśnicz",
    "lat": "49.91465",
    "lng": "20.46109"
  },
  {
    "country": "PL",
    "name": "Nowy Targ",
    "lat": "49.47783",
    "lng": "20.03228"
  },
  {
    "country": "PL",
    "name": "Nowy Sącz",
    "lat": "49.62177",
    "lng": "20.69705"
  },
  {
    "country": "PL",
    "name": "Nowy Korczyn",
    "lat": "50.30124",
    "lng": "20.80759"
  },
  {
    "country": "PL",
    "name": "Nowy Dwór Mazowiecki",
    "lat": "52.43022",
    "lng": "20.71652"
  },
  {
    "country": "PL",
    "name": "Nowosielce-Gniewosz",
    "lat": "49.56842",
    "lng": "22.06947"
  },
  {
    "country": "PL",
    "name": "Nowosielce",
    "lat": "50.05747",
    "lng": "22.41056"
  },
  {
    "country": "PL",
    "name": "Nowogród",
    "lat": "53.22698",
    "lng": "21.8821"
  },
  {
    "country": "PL",
    "name": "Nowodwór",
    "lat": "51.63901",
    "lng": "22.10183"
  },
  {
    "country": "PL",
    "name": "Nowe Sioło",
    "lat": "50.23194",
    "lng": "23.15884"
  },
  {
    "country": "PL",
    "name": "Nowe Miasto nad Pilicą",
    "lat": "51.61812",
    "lng": "20.57619"
  },
  {
    "country": "PL",
    "name": "Nowe Miasto",
    "lat": "52.65691",
    "lng": "20.62838"
  },
  {
    "country": "PL",
    "name": "Nowe Brzesko",
    "lat": "50.13222",
    "lng": "20.37663"
  },
  {
    "country": "PL",
    "name": "Nowa Słupia",
    "lat": "50.86432",
    "lng": "21.09049"
  },
  {
    "country": "PL",
    "name": "Nowa Sarzyna",
    "lat": "50.32086",
    "lng": "22.34456"
  },
  {
    "country": "PL",
    "name": "Nowa Dęba",
    "lat": "50.42974",
    "lng": "21.75078"
  },
  {
    "country": "PL",
    "name": "Niwiska",
    "lat": "50.22492",
    "lng": "21.63036"
  },
  {
    "country": "PL",
    "name": "Nisko",
    "lat": "50.51987",
    "lng": "22.13968"
  },
  {
    "country": "PL",
    "name": "Nieporęt",
    "lat": "52.43152",
    "lng": "21.03212"
  },
  {
    "country": "PL",
    "name": "Niepołomice",
    "lat": "50.04066",
    "lng": "20.22257"
  },
  {
    "country": "PL",
    "name": "Nienadowa",
    "lat": "49.82901",
    "lng": "22.42704"
  },
  {
    "country": "PL",
    "name": "Niemce",
    "lat": "51.36155",
    "lng": "22.63939"
  },
  {
    "country": "PL",
    "name": "Nielisz",
    "lat": "50.80067",
    "lng": "23.04451"
  },
  {
    "country": "PL",
    "name": "Niedźwiedź",
    "lat": "49.621",
    "lng": "20.07794"
  },
  {
    "country": "PL",
    "name": "Niedźwiada",
    "lat": "51.54409",
    "lng": "22.6914"
  },
  {
    "country": "PL",
    "name": "Niedźwiada",
    "lat": "49.98937",
    "lng": "21.52162"
  },
  {
    "country": "PL",
    "name": "Niedzica",
    "lat": "49.41008",
    "lng": "20.30273"
  },
  {
    "country": "PL",
    "name": "Niedrzwica Duża",
    "lat": "51.11462",
    "lng": "22.38911"
  },
  {
    "country": "PL",
    "name": "Niedomice",
    "lat": "50.10737",
    "lng": "20.89548"
  },
  {
    "country": "PL",
    "name": "Niechobrz",
    "lat": "49.99472",
    "lng": "21.87824"
  },
  {
    "country": "PL",
    "name": "Niebylec",
    "lat": "49.85669",
    "lng": "21.90348"
  },
  {
    "country": "PL",
    "name": "Nieborów",
    "lat": "52.07771",
    "lng": "20.06902"
  },
  {
    "country": "PL",
    "name": "Niebocko",
    "lat": "49.67774",
    "lng": "22.10484"
  },
  {
    "country": "PL",
    "name": "Niebieszczany",
    "lat": "49.50348",
    "lng": "22.15651"
  },
  {
    "country": "PL",
    "name": "Nidzica",
    "lat": "53.36052",
    "lng": "20.42749"
  },
  {
    "country": "PL",
    "name": "Nawojowa",
    "lat": "49.56686",
    "lng": "20.73927"
  },
  {
    "country": "PL",
    "name": "Nasielsk",
    "lat": "52.58887",
    "lng": "20.80553"
  },
  {
    "country": "PL",
    "name": "Naruszewo",
    "lat": "52.52687",
    "lng": "20.35157"
  },
  {
    "country": "PL",
    "name": "Narol",
    "lat": "50.34925",
    "lng": "23.32679"
  },
  {
    "country": "PL",
    "name": "Narew",
    "lat": "52.91418",
    "lng": "23.51984"
  },
  {
    "country": "PL",
    "name": "Nałęczów",
    "lat": "51.28581",
    "lng": "22.21539"
  },
  {
    "country": "PL",
    "name": "Nagłowice",
    "lat": "50.67835",
    "lng": "20.10661"
  },
  {
    "country": "PL",
    "name": "Nadarzyn",
    "lat": "52.09438",
    "lng": "20.80776"
  },
  {
    "country": "PL",
    "name": "Myszyniec",
    "lat": "53.38055",
    "lng": "21.34961"
  },
  {
    "country": "PL",
    "name": "Mysiadło",
    "lat": "52.10216",
    "lng": "21.01856"
  },
  {
    "country": "PL",
    "name": "Muszyna",
    "lat": "49.35661",
    "lng": "20.89718"
  },
  {
    "country": "PL",
    "name": "Mszczonów",
    "lat": "51.97415",
    "lng": "20.52083"
  },
  {
    "country": "PL",
    "name": "Mszana Górna",
    "lat": "49.66202",
    "lng": "20.09734"
  },
  {
    "country": "PL",
    "name": "Mszana Dolna",
    "lat": "49.67432",
    "lng": "20.07992"
  },
  {
    "country": "PL",
    "name": "Mrozy",
    "lat": "52.16609",
    "lng": "21.80263"
  },
  {
    "country": "PL",
    "name": "Mrozy",
    "lat": "52.01975",
    "lng": "20.36702"
  },
  {
    "country": "PL",
    "name": "Mrągowo",
    "lat": "53.86437",
    "lng": "21.30507"
  },
  {
    "country": "PL",
    "name": "Moszczenica",
    "lat": "49.73668",
    "lng": "21.09238"
  },
  {
    "country": "PL",
    "name": "Mordy",
    "lat": "52.2116",
    "lng": "22.51725"
  },
  {
    "country": "PL",
    "name": "Morawica",
    "lat": "50.74678",
    "lng": "20.61756"
  },
  {
    "country": "PL",
    "name": "Mońki",
    "lat": "53.40496",
    "lng": "22.79791"
  },
  {
    "country": "PL",
    "name": "Mokotów",
    "lat": "52.1934",
    "lng": "21.03487"
  },
  {
    "country": "PL",
    "name": "Mokobody",
    "lat": "52.26523",
    "lng": "22.11182"
  },
  {
    "country": "PL",
    "name": "Mogielnica",
    "lat": "51.69432",
    "lng": "20.72227"
  },
  {
    "country": "PL",
    "name": "Modliborzyce",
    "lat": "50.75416",
    "lng": "22.32945"
  },
  {
    "country": "PL",
    "name": "Mniszków",
    "lat": "51.37017",
    "lng": "20.03915"
  },
  {
    "country": "PL",
    "name": "Mniów",
    "lat": "51.01224",
    "lng": "20.48427"
  },
  {
    "country": "PL",
    "name": "Młynarze",
    "lat": "52.95417",
    "lng": "21.41141"
  },
  {
    "country": "PL",
    "name": "Młodzieszyn",
    "lat": "52.29945",
    "lng": "20.20017"
  },
  {
    "country": "PL",
    "name": "Mława",
    "lat": "53.11278",
    "lng": "20.3841"
  },
  {
    "country": "PL",
    "name": "Mirzec",
    "lat": "51.13466",
    "lng": "21.0571"
  },
  {
    "country": "PL",
    "name": "Mirów",
    "lat": "51.1972",
    "lng": "21.0329"
  },
  {
    "country": "PL",
    "name": "Mirocin",
    "lat": "50.04237",
    "lng": "22.55596"
  },
  {
    "country": "PL",
    "name": "Mircze",
    "lat": "50.65164",
    "lng": "23.89604"
  },
  {
    "country": "PL",
    "name": "Mińsk Mazowiecki",
    "lat": "52.17935",
    "lng": "21.57251"
  },
  {
    "country": "PL",
    "name": "Milejów",
    "lat": "51.23226",
    "lng": "22.92443"
  },
  {
    "country": "PL",
    "name": "Milejczyce",
    "lat": "52.51967",
    "lng": "23.13206"
  },
  {
    "country": "PL",
    "name": "Milanówek",
    "lat": "52.11879",
    "lng": "20.67155"
  },
  {
    "country": "PL",
    "name": "Milanów",
    "lat": "51.70374",
    "lng": "22.8883"
  },
  {
    "country": "PL",
    "name": "Miłakowo",
    "lat": "54.00923",
    "lng": "20.07125"
  },
  {
    "country": "PL",
    "name": "Mikołajki",
    "lat": "53.80288",
    "lng": "21.57011"
  },
  {
    "country": "PL",
    "name": "Miętne",
    "lat": "51.92135",
    "lng": "21.57457"
  },
  {
    "country": "PL",
    "name": "Mielec",
    "lat": "50.28709",
    "lng": "21.4239"
  },
  {
    "country": "PL",
    "name": "Miejsce Piastowe",
    "lat": "49.6344",
    "lng": "21.78735"
  },
  {
    "country": "PL",
    "name": "Międzyrzec Podlaski",
    "lat": "51.9864",
    "lng": "22.78248"
  },
  {
    "country": "PL",
    "name": "Miedzna",
    "lat": "52.46778",
    "lng": "22.08947"
  },
  {
    "country": "PL",
    "name": "Miedziana Góra",
    "lat": "50.9368",
    "lng": "20.55096"
  },
  {
    "country": "PL",
    "name": "Miechów",
    "lat": "50.35648",
    "lng": "20.02788"
  },
  {
    "country": "PL",
    "name": "Michów",
    "lat": "51.52573",
    "lng": "22.31435"
  },
  {
    "country": "PL",
    "name": "Michałowo",
    "lat": "53.03492",
    "lng": "23.60996"
  },
  {
    "country": "PL",
    "name": "Michałowice",
    "lat": "52.17435",
    "lng": "20.88089"
  },
  {
    "country": "PL",
    "name": "Michałów-Reginów",
    "lat": "52.41711",
    "lng": "20.96595"
  },
  {
    "country": "PL",
    "name": "Michałów",
    "lat": "50.73727",
    "lng": "23.02297"
  },
  {
    "country": "PL",
    "name": "Michałów",
    "lat": "50.54709",
    "lng": "23.60361"
  },
  {
    "country": "PL",
    "name": "Michałów",
    "lat": "50.49541",
    "lng": "20.46178"
  },
  {
    "country": "PL",
    "name": "Miastków Kościelny",
    "lat": "51.88407",
    "lng": "21.82528"
  },
  {
    "country": "PL",
    "name": "Miączyn",
    "lat": "50.73825",
    "lng": "23.5013"
  },
  {
    "country": "PL",
    "name": "Mełgiew",
    "lat": "51.22519",
    "lng": "22.78414"
  },
  {
    "country": "PL",
    "name": "Medyka",
    "lat": "49.80526",
    "lng": "22.92229"
  },
  {
    "country": "PL",
    "name": "Mędrzechów",
    "lat": "50.28221",
    "lng": "20.94749"
  },
  {
    "country": "PL",
    "name": "Maszkienice",
    "lat": "49.9892",
    "lng": "20.68657"
  },
  {
    "country": "PL",
    "name": "Masłów",
    "lat": "50.90065",
    "lng": "20.72322"
  },
  {
    "country": "PL",
    "name": "Markuszów",
    "lat": "51.37457",
    "lng": "22.25804"
  },
  {
    "country": "PL",
    "name": "Markowa",
    "lat": "50.02633",
    "lng": "22.3316"
  },
  {
    "country": "PL",
    "name": "Marki",
    "lat": "52.32065",
    "lng": "21.10474"
  },
  {
    "country": "PL",
    "name": "Maniowy",
    "lat": "49.45976",
    "lng": "20.26454"
  },
  {
    "country": "PL",
    "name": "Manasterz",
    "lat": "49.9352",
    "lng": "22.34602"
  },
  {
    "country": "PL",
    "name": "Mały Płock",
    "lat": "53.30385",
    "lng": "22.02836"
  },
  {
    "country": "PL",
    "name": "Małogoszcz",
    "lat": "50.81214",
    "lng": "20.26407"
  },
  {
    "country": "PL",
    "name": "Małkinia Górna",
    "lat": "52.6922",
    "lng": "22.02836"
  },
  {
    "country": "PL",
    "name": "Maków Mazowiecki",
    "lat": "52.86493",
    "lng": "21.10053"
  },
  {
    "country": "PL",
    "name": "Maków",
    "lat": "51.94696",
    "lng": "20.05211"
  },
  {
    "country": "PL",
    "name": "Majdan Królewski",
    "lat": "50.37935",
    "lng": "21.74615"
  },
  {
    "country": "PL",
    "name": "Maciejowice",
    "lat": "51.69222",
    "lng": "21.55342"
  },
  {
    "country": "PL",
    "name": "Jeziorzany",
    "lat": "51.60245",
    "lng": "22.27667"
  },
  {
    "country": "PL",
    "name": "Łyse",
    "lat": "53.36443",
    "lng": "21.56487"
  },
  {
    "country": "PL",
    "name": "Łużna",
    "lat": "49.71288",
    "lng": "21.04637"
  },
  {
    "country": "PL",
    "name": "Lutowiska",
    "lat": "49.25318",
    "lng": "22.69252"
  },
  {
    "country": "PL",
    "name": "Lutoryż",
    "lat": "49.96712",
    "lng": "21.9124"
  },
  {
    "country": "PL",
    "name": "Łukowica",
    "lat": "49.6111",
    "lng": "20.48289"
  },
  {
    "country": "PL",
    "name": "Łukowa",
    "lat": "50.37426",
    "lng": "22.94349"
  },
  {
    "country": "PL",
    "name": "Łukowa",
    "lat": "50.093",
    "lng": "20.97548"
  },
  {
    "country": "PL",
    "name": "Łuków",
    "lat": "51.929",
    "lng": "22.37956"
  },
  {
    "country": "PL",
    "name": "Ludwin",
    "lat": "51.34605",
    "lng": "22.90581"
  },
  {
    "country": "PL",
    "name": "Lubycza Królewska",
    "lat": "50.34102",
    "lng": "23.51941"
  },
  {
    "country": "PL",
    "name": "Lubomino",
    "lat": "54.06684",
    "lng": "20.23956"
  },
  {
    "country": "PL",
    "name": "Lubomierz",
    "lat": "49.60854",
    "lng": "20.20214"
  },
  {
    "country": "PL",
    "name": "Lubochnia",
    "lat": "51.60794",
    "lng": "20.05391"
  },
  {
    "country": "PL",
    "name": "Łubnice",
    "lat": "50.41164",
    "lng": "21.15014"
  },
  {
    "country": "PL",
    "name": "Lublin",
    "lat": "51.25",
    "lng": "22.56667"
  },
  {
    "country": "PL",
    "name": "Lubenia",
    "lat": "49.93078",
    "lng": "21.92665"
  },
  {
    "country": "PL",
    "name": "Lubartów",
    "lat": "51.46026",
    "lng": "22.60952"
  },
  {
    "country": "PL",
    "name": "Lubaczów",
    "lat": "50.157",
    "lng": "23.12339"
  },
  {
    "country": "PL",
    "name": "Łososina Dolna",
    "lat": "49.74977",
    "lng": "20.63129"
  },
  {
    "country": "PL",
    "name": "Łosice",
    "lat": "52.21129",
    "lng": "22.71801"
  },
  {
    "country": "PL",
    "name": "Łopuszno",
    "lat": "50.94864",
    "lng": "20.25081"
  },
  {
    "country": "PL",
    "name": "Łopuszna",
    "lat": "49.47281",
    "lng": "20.13021"
  },
  {
    "country": "PL",
    "name": "Łopuszka Wielka",
    "lat": "49.93454",
    "lng": "22.39305"
  },
  {
    "country": "PL",
    "name": "Łopiennik Górny",
    "lat": "51.0408",
    "lng": "23.01833"
  },
  {
    "country": "PL",
    "name": "Łoniów",
    "lat": "50.56443",
    "lng": "21.52599"
  },
  {
    "country": "PL",
    "name": "Łomża",
    "lat": "53.17806",
    "lng": "22.05935"
  },
  {
    "country": "PL",
    "name": "Łomianki",
    "lat": "52.33413",
    "lng": "20.88602"
  },
  {
    "country": "PL",
    "name": "Łomazy",
    "lat": "51.90435",
    "lng": "23.17656"
  },
  {
    "country": "PL",
    "name": "Łochów",
    "lat": "52.53076",
    "lng": "21.68158"
  },
  {
    "country": "PL",
    "name": "Liw",
    "lat": "52.37515",
    "lng": "21.96768"
  },
  {
    "country": "PL",
    "name": "Lisia Góra",
    "lat": "50.08039",
    "lng": "21.04397"
  },
  {
    "country": "PL",
    "name": "Lipsko",
    "lat": "51.15954",
    "lng": "21.64933"
  },
  {
    "country": "PL",
    "name": "Lipsk",
    "lat": "53.73312",
    "lng": "23.40225"
  },
  {
    "country": "PL",
    "name": "Lipowiec Kościelny",
    "lat": "53.10459",
    "lng": "20.17639"
  },
  {
    "country": "PL",
    "name": "Lipinki",
    "lat": "49.67296",
    "lng": "21.29288"
  },
  {
    "country": "PL",
    "name": "Lipnik",
    "lat": "50.72977",
    "lng": "21.49389"
  },
  {
    "country": "PL",
    "name": "Lipnik",
    "lat": "49.78902",
    "lng": "20.08455"
  },
  {
    "country": "PL",
    "name": "Lipnica Wielka",
    "lat": "49.70489",
    "lng": "20.86844"
  },
  {
    "country": "PL",
    "name": "Lipnica",
    "lat": "50.28939",
    "lng": "21.88811"
  },
  {
    "country": "PL",
    "name": "Nowe Lipiny",
    "lat": "52.35789",
    "lng": "21.27125"
  },
  {
    "country": "PL",
    "name": "Limanowa",
    "lat": "49.70594",
    "lng": "20.42204"
  },
  {
    "country": "PL",
    "name": "Lidzbark Warmiński",
    "lat": "54.12588",
    "lng": "20.57954"
  },
  {
    "country": "PL",
    "name": "Leżajsk",
    "lat": "50.26257",
    "lng": "22.41932"
  },
  {
    "country": "PL",
    "name": "Łętownia",
    "lat": "50.32481",
    "lng": "22.23401"
  },
  {
    "country": "PL",
    "name": "Lesznowola",
    "lat": "52.09095",
    "lng": "20.93479"
  },
  {
    "country": "PL",
    "name": "Leszno",
    "lat": "52.25799",
    "lng": "20.59121"
  },
  {
    "country": "PL",
    "name": "Leśnica",
    "lat": "49.40092",
    "lng": "20.06001"
  },
  {
    "country": "PL",
    "name": "Leśna Podlaska",
    "lat": "52.13317",
    "lng": "23.02786"
  },
  {
    "country": "PL",
    "name": "Lesko",
    "lat": "49.4701",
    "lng": "22.33042"
  },
  {
    "country": "PL",
    "name": "Lelkowo",
    "lat": "54.32458",
    "lng": "20.2248"
  },
  {
    "country": "PL",
    "name": "Łęki Górne",
    "lat": "49.97386",
    "lng": "21.17426"
  },
  {
    "country": "PL",
    "name": "Łęki Dolne",
    "lat": "49.97386",
    "lng": "21.24739"
  },
  {
    "country": "PL",
    "name": "Łęki",
    "lat": "49.80996",
    "lng": "21.66023"
  },
  {
    "country": "PL",
    "name": "Legionowo",
    "lat": "52.40149",
    "lng": "20.92664"
  },
  {
    "country": "PL",
    "name": "Łęczna",
    "lat": "51.30121",
    "lng": "22.88135"
  },
  {
    "country": "PL",
    "name": "Lecka",
    "lat": "49.8786",
    "lng": "22.01368"
  },
  {
    "country": "PL",
    "name": "Łaziska",
    "lat": "51.14226",
    "lng": "21.87919"
  },
  {
    "country": "PL",
    "name": "Latowicz",
    "lat": "52.02636",
    "lng": "21.80829"
  },
  {
    "country": "PL",
    "name": "Laszki",
    "lat": "50.0202",
    "lng": "22.89997"
  },
  {
    "country": "PL",
    "name": "Łaszczów",
    "lat": "50.53332",
    "lng": "23.72562"
  },
  {
    "country": "PL",
    "name": "Laskowa",
    "lat": "49.76147",
    "lng": "20.45045"
  },
  {
    "country": "PL",
    "name": "Łaskarzew",
    "lat": "51.78993",
    "lng": "21.59122"
  },
  {
    "country": "PL",
    "name": "Łapy",
    "lat": "52.9911",
    "lng": "22.88422"
  },
  {
    "country": "PL",
    "name": "Łapsze Niżne",
    "lat": "49.39807",
    "lng": "20.24343"
  },
  {
    "country": "PL",
    "name": "Łapczyca",
    "lat": "49.95994",
    "lng": "20.38445"
  },
  {
    "country": "PL",
    "name": "Łapanów",
    "lat": "49.86538",
    "lng": "20.29149"
  },
  {
    "country": "PL",
    "name": "Łańcut",
    "lat": "50.06871",
    "lng": "22.22912"
  },
  {
    "country": "PL",
    "name": "Łajski",
    "lat": "52.42873",
    "lng": "20.94946"
  },
  {
    "country": "PL",
    "name": "Łagów",
    "lat": "50.77517",
    "lng": "21.08431"
  },
  {
    "country": "PL",
    "name": "Łączna",
    "lat": "51.00231",
    "lng": "20.79712"
  },
  {
    "country": "PL",
    "name": "Łącko",
    "lat": "49.55757",
    "lng": "20.43586"
  },
  {
    "country": "PL",
    "name": "Łabunie",
    "lat": "50.65517",
    "lng": "23.3662"
  },
  {
    "country": "PL",
    "name": "Łabowa",
    "lat": "49.52766",
    "lng": "20.85497"
  },
  {
    "country": "PL",
    "name": "Kuźnica",
    "lat": "53.51094",
    "lng": "23.64953"
  },
  {
    "country": "PL",
    "name": "Kuryłówka",
    "lat": "50.29976",
    "lng": "22.46601"
  },
  {
    "country": "PL",
    "name": "Kurów",
    "lat": "51.38941",
    "lng": "22.18637"
  },
  {
    "country": "PL",
    "name": "Kunów",
    "lat": "50.96156",
    "lng": "21.28058"
  },
  {
    "country": "PL",
    "name": "Kuczbork-Osada",
    "lat": "53.08619",
    "lng": "20.04782"
  },
  {
    "country": "PL",
    "name": "Księżpol",
    "lat": "50.42323",
    "lng": "22.73526"
  },
  {
    "country": "PL",
    "name": "Księżomierz",
    "lat": "50.90855",
    "lng": "21.98965"
  },
  {
    "country": "PL",
    "name": "Krzywda",
    "lat": "51.79519",
    "lng": "22.19994"
  },
  {
    "country": "PL",
    "name": "Krzywcza",
    "lat": "49.79894",
    "lng": "22.54549"
  },
  {
    "country": "PL",
    "name": "Krzynowłoga Mała",
    "lat": "53.15773",
    "lng": "20.78579"
  },
  {
    "country": "PL",
    "name": "Krzeszów",
    "lat": "50.40381",
    "lng": "22.34241"
  },
  {
    "country": "PL",
    "name": "Krzemienica",
    "lat": "50.0621",
    "lng": "22.18054"
  },
  {
    "country": "PL",
    "name": "Krzeczowice",
    "lat": "49.9892",
    "lng": "22.46378"
  },
  {
    "country": "PL",
    "name": "Krzeczów",
    "lat": "49.98876",
    "lng": "20.48779"
  },
  {
    "country": "PL",
    "name": "Krynki",
    "lat": "53.26444",
    "lng": "23.77304"
  },
  {
    "country": "PL",
    "name": "Krynice",
    "lat": "50.5876",
    "lng": "23.38157"
  },
  {
    "country": "PL",
    "name": "Krynica-Zdrój",
    "lat": "49.42225",
    "lng": "20.95942"
  },
  {
    "country": "PL",
    "name": "Kruklanki",
    "lat": "54.08855",
    "lng": "21.92227"
  },
  {
    "country": "PL",
    "name": "Krosno",
    "lat": "49.68866",
    "lng": "21.77058"
  },
  {
    "country": "PL",
    "name": "Krośnica",
    "lat": "49.44787",
    "lng": "20.33956"
  },
  {
    "country": "PL",
    "name": "Krościenko Wyżne",
    "lat": "49.67946",
    "lng": "21.82898"
  },
  {
    "country": "PL",
    "name": "Krempna",
    "lat": "49.51128",
    "lng": "21.50042"
  },
  {
    "country": "PL",
    "name": "Krasocin",
    "lat": "50.88874",
    "lng": "20.11863"
  },
  {
    "country": "PL",
    "name": "Krasnystaw",
    "lat": "50.98464",
    "lng": "23.1742"
  },
  {
    "country": "PL",
    "name": "Krasnosielc",
    "lat": "53.03378",
    "lng": "21.15735"
  },
  {
    "country": "PL",
    "name": "Krasnopol",
    "lat": "54.11613",
    "lng": "23.20476"
  },
  {
    "country": "PL",
    "name": "Krasnobród",
    "lat": "50.54551",
    "lng": "23.21308"
  },
  {
    "country": "PL",
    "name": "Kraśnik",
    "lat": "50.9236",
    "lng": "22.22706"
  },
  {
    "country": "PL",
    "name": "Kraśniczyn",
    "lat": "50.93171",
    "lng": "23.34929"
  },
  {
    "country": "PL",
    "name": "Krasne",
    "lat": "52.92401",
    "lng": "20.96732"
  },
  {
    "country": "PL",
    "name": "Krasne",
    "lat": "50.05626",
    "lng": "22.08638"
  },
  {
    "country": "PL",
    "name": "Krasiczyn",
    "lat": "49.77644",
    "lng": "22.65252"
  },
  {
    "country": "PL",
    "name": "Kramarzówka",
    "lat": "49.86034",
    "lng": "22.50137"
  },
  {
    "country": "PL",
    "name": "Kraczkowa",
    "lat": "50.03796",
    "lng": "22.16801"
  },
  {
    "country": "PL",
    "name": "Kozubszczyzna",
    "lat": "51.22323",
    "lng": "22.42747"
  },
  {
    "country": "PL",
    "name": "Kozłowo",
    "lat": "53.30652",
    "lng": "20.29098"
  },
  {
    "country": "PL",
    "name": "Kozłów",
    "lat": "50.48394",
    "lng": "20.02456"
  },
  {
    "country": "PL",
    "name": "Kozienice",
    "lat": "51.58294",
    "lng": "21.54779"
  },
  {
    "country": "PL",
    "name": "Kowiesy",
    "lat": "51.88942",
    "lng": "20.41929"
  },
  {
    "country": "PL",
    "name": "Kowale Oleckie",
    "lat": "54.16354",
    "lng": "22.41666"
  },
  {
    "country": "PL",
    "name": "Kowala",
    "lat": "51.32503",
    "lng": "21.06972"
  },
  {
    "country": "PL",
    "name": "Kotuń",
    "lat": "52.17643",
    "lng": "22.06819"
  },
  {
    "country": "PL",
    "name": "Koszyce",
    "lat": "49.97226",
    "lng": "20.94166"
  },
  {
    "country": "PL",
    "name": "Kostomłoty Pierwsze",
    "lat": "50.92322",
    "lng": "20.5949"
  },
  {
    "country": "PL",
    "name": "Kostomłoty Drugie",
    "lat": "50.92684",
    "lng": "20.56529"
  },
  {
    "country": "PL",
    "name": "Kosów Lacki",
    "lat": "52.59541",
    "lng": "22.14707"
  },
  {
    "country": "PL",
    "name": "Kosina",
    "lat": "50.07213",
    "lng": "22.32903"
  },
  {
    "country": "PL",
    "name": "Korzenna",
    "lat": "49.68635",
    "lng": "20.84355"
  },
  {
    "country": "PL",
    "name": "Korytnica",
    "lat": "52.41441",
    "lng": "21.84949"
  },
  {
    "country": "PL",
    "name": "Kortowo",
    "lat": "53.75731",
    "lng": "20.4562"
  },
  {
    "country": "PL",
    "name": "Korsze",
    "lat": "54.17002",
    "lng": "21.13915"
  },
  {
    "country": "PL",
    "name": "Stara Kornica",
    "lat": "52.18183",
    "lng": "22.93752"
  },
  {
    "country": "PL",
    "name": "Korczyna",
    "lat": "49.71555",
    "lng": "21.80941"
  },
  {
    "country": "PL",
    "name": "Korczew",
    "lat": "52.35327",
    "lng": "22.61338"
  },
  {
    "country": "PL",
    "name": "Koprzywnica",
    "lat": "50.5934",
    "lng": "21.5838"
  },
  {
    "country": "PL",
    "name": "Konstantynów",
    "lat": "52.20746",
    "lng": "23.0853"
  },
  {
    "country": "PL",
    "name": "Konstancin-Jeziorna",
    "lat": "52.0938",
    "lng": "21.11761"
  },
  {
    "country": "PL",
    "name": "Końskowola",
    "lat": "51.40922",
    "lng": "22.05175"
  },
  {
    "country": "PL",
    "name": "Końskie",
    "lat": "51.19166",
    "lng": "20.40607"
  },
  {
    "country": "PL",
    "name": "Konieczkowa",
    "lat": "49.84208",
    "lng": "21.9282"
  },
  {
    "country": "PL",
    "name": "Kończyce",
    "lat": "50.42575",
    "lng": "22.15376"
  },
  {
    "country": "PL",
    "name": "Komorów",
    "lat": "52.1456",
    "lng": "20.81566"
  },
  {
    "country": "PL",
    "name": "Komarówka Podlaska",
    "lat": "51.80315",
    "lng": "22.94392"
  },
  {
    "country": "PL",
    "name": "Komarów-Osada",
    "lat": "50.62888",
    "lng": "23.4774"
  },
  {
    "country": "PL",
    "name": "Komańcza",
    "lat": "49.33922",
    "lng": "22.06166"
  },
  {
    "country": "PL",
    "name": "Kolno",
    "lat": "53.41148",
    "lng": "21.92905"
  },
  {
    "country": "PL",
    "name": "Kolbuszowa",
    "lat": "50.2441",
    "lng": "21.7761"
  },
  {
    "country": "PL",
    "name": "Kołbiel",
    "lat": "52.06431",
    "lng": "21.48153"
  },
  {
    "country": "PL",
    "name": "Kołaczyce",
    "lat": "49.80743",
    "lng": "21.43407"
  },
  {
    "country": "PL",
    "name": "Kokotów",
    "lat": "50.01254",
    "lng": "20.07829"
  },
  {
    "country": "PL",
    "name": "Kodeń",
    "lat": "51.91171",
    "lng": "23.60301"
  },
  {
    "country": "PL",
    "name": "Kock",
    "lat": "51.63997",
    "lng": "22.44391"
  },
  {
    "country": "PL",
    "name": "Kobyłka",
    "lat": "52.33953",
    "lng": "21.19589"
  },
  {
    "country": "PL",
    "name": "Kobylanka",
    "lat": "49.66891",
    "lng": "21.22293"
  },
  {
    "country": "PL",
    "name": "Knyszyn",
    "lat": "53.31406",
    "lng": "22.91963"
  },
  {
    "country": "PL",
    "name": "Klwów",
    "lat": "51.53448",
    "lng": "20.63644"
  },
  {
    "country": "PL",
    "name": "Kluszkowce",
    "lat": "49.451",
    "lng": "20.30179"
  },
  {
    "country": "PL",
    "name": "Kłoczew",
    "lat": "51.72134",
    "lng": "21.96493"
  },
  {
    "country": "PL",
    "name": "Klimontów",
    "lat": "50.65588",
    "lng": "21.45587"
  },
  {
    "country": "PL",
    "name": "Klimontów",
    "lat": "50.22843",
    "lng": "20.3199"
  },
  {
    "country": "PL",
    "name": "Kleszczele",
    "lat": "52.57314",
    "lng": "23.32539"
  },
  {
    "country": "PL",
    "name": "Klembów",
    "lat": "52.4065",
    "lng": "21.33176"
  },
  {
    "country": "PL",
    "name": "Kłaj",
    "lat": "49.99246",
    "lng": "20.29904"
  },
  {
    "country": "PL",
    "name": "Kije",
    "lat": "50.60721",
    "lng": "20.57121"
  },
  {
    "country": "PL",
    "name": "Kiełpin",
    "lat": "52.35796",
    "lng": "20.86214"
  },
  {
    "country": "PL",
    "name": "Kielce",
    "lat": "50.87033",
    "lng": "20.62752"
  },
  {
    "country": "PL",
    "name": "Kielanówka",
    "lat": "50.02616",
    "lng": "21.92905"
  },
  {
    "country": "PL",
    "name": "Kętrzyn",
    "lat": "54.07676",
    "lng": "21.37527"
  },
  {
    "country": "PL",
    "name": "Kępie Żaleszańskie",
    "lat": "50.63983",
    "lng": "21.88133"
  },
  {
    "country": "PL",
    "name": "Kazimierz Dolny",
    "lat": "51.31911",
    "lng": "21.95502"
  },
  {
    "country": "PL",
    "name": "Kazimierza Wielka",
    "lat": "50.26564",
    "lng": "20.49358"
  },
  {
    "country": "PL",
    "name": "Kazanów",
    "lat": "51.27593",
    "lng": "21.46737"
  },
  {
    "country": "PL",
    "name": "Kawęczyn Nowy",
    "lat": "51.88597",
    "lng": "20.24703"
  },
  {
    "country": "PL",
    "name": "Kasina Wielka",
    "lat": "49.72969",
    "lng": "20.13554"
  },
  {
    "country": "PL",
    "name": "Karniewo",
    "lat": "52.837",
    "lng": "20.98886"
  },
  {
    "country": "PL",
    "name": "Karczmiska",
    "lat": "51.22952",
    "lng": "21.98158"
  },
  {
    "country": "PL",
    "name": "Karczew",
    "lat": "52.07655",
    "lng": "21.24962"
  },
  {
    "country": "PL",
    "name": "Kaniów",
    "lat": "50.98577",
    "lng": "20.66391"
  },
  {
    "country": "PL",
    "name": "Kańczuga",
    "lat": "49.98346",
    "lng": "22.41168"
  },
  {
    "country": "PL",
    "name": "Kampinos",
    "lat": "52.26837",
    "lng": "20.46307"
  },
  {
    "country": "PL",
    "name": "Kamionka Wielka",
    "lat": "49.56848",
    "lng": "20.82364"
  },
  {
    "country": "PL",
    "name": "Kamionka",
    "lat": "51.47165",
    "lng": "22.46275"
  },
  {
    "country": "PL",
    "name": "Kamienica",
    "lat": "49.57533",
    "lng": "20.34505"
  },
  {
    "country": "PL",
    "name": "Kamień",
    "lat": "50.34064",
    "lng": "22.13539"
  },
  {
    "country": "PL",
    "name": "Kałuszyn",
    "lat": "52.20669",
    "lng": "21.80838"
  },
  {
    "country": "PL",
    "name": "Kadzidło",
    "lat": "53.23435",
    "lng": "21.46454"
  },
  {
    "country": "PL",
    "name": "Kabaty",
    "lat": "52.13012",
    "lng": "21.08148"
  },
  {
    "country": "PL",
    "name": "Józefów",
    "lat": "52.19446",
    "lng": "20.69592"
  },
  {
    "country": "PL",
    "name": "Józefów",
    "lat": "52.13707",
    "lng": "21.23589"
  },
  {
    "country": "PL",
    "name": "Józefów nad Wisłą",
    "lat": "51.04183",
    "lng": "21.83018"
  },
  {
    "country": "PL",
    "name": "Józefów",
    "lat": "50.48119",
    "lng": "23.05404"
  },
  {
    "country": "PL",
    "name": "Józefosław",
    "lat": "52.1005",
    "lng": "21.04629"
  },
  {
    "country": "PL",
    "name": "Jonkowo",
    "lat": "53.82817",
    "lng": "20.31054"
  },
  {
    "country": "PL",
    "name": "Joniec",
    "lat": "52.60128",
    "lng": "20.58177"
  },
  {
    "country": "PL",
    "name": "Jodłówka",
    "lat": "49.99295",
    "lng": "20.54821"
  },
  {
    "country": "PL",
    "name": "Jodłówka",
    "lat": "49.8943",
    "lng": "22.46653"
  },
  {
    "country": "PL",
    "name": "Jodłowa",
    "lat": "49.87229",
    "lng": "21.27897"
  },
  {
    "country": "PL",
    "name": "Jeżowe",
    "lat": "50.37486",
    "lng": "22.12749"
  },
  {
    "country": "PL",
    "name": "Jeziorany",
    "lat": "53.97578",
    "lng": "20.74639"
  },
  {
    "country": "PL",
    "name": "Jedwabno",
    "lat": "53.5299",
    "lng": "20.72657"
  },
  {
    "country": "PL",
    "name": "Jedwabne",
    "lat": "53.28554",
    "lng": "22.30353"
  },
  {
    "country": "PL",
    "name": "Jędrzejów",
    "lat": "50.63945",
    "lng": "20.30454"
  },
  {
    "country": "PL",
    "name": "Jednorożec",
    "lat": "53.14116",
    "lng": "21.05161"
  },
  {
    "country": "PL",
    "name": "Jedlnia-Letnisko",
    "lat": "51.43074",
    "lng": "21.33536"
  },
  {
    "country": "PL",
    "name": "Jedlińsk",
    "lat": "51.514",
    "lng": "21.11577"
  },
  {
    "country": "PL",
    "name": "Jedlicze",
    "lat": "49.71749",
    "lng": "21.64886"
  },
  {
    "country": "PL",
    "name": "Jawornik Polski",
    "lat": "49.89082",
    "lng": "22.28868"
  },
  {
    "country": "PL",
    "name": "Jawornik",
    "lat": "49.8464",
    "lng": "21.89404"
  },
  {
    "country": "PL",
    "name": "Jastrzębia",
    "lat": "51.49742",
    "lng": "21.23709"
  },
  {
    "country": "PL",
    "name": "Jastrzębia",
    "lat": "49.79733",
    "lng": "20.88089"
  },
  {
    "country": "PL",
    "name": "Jastrząb",
    "lat": "51.24725",
    "lng": "20.94758"
  },
  {
    "country": "PL",
    "name": "Jastków",
    "lat": "51.30411",
    "lng": "22.43546"
  },
  {
    "country": "PL",
    "name": "Jasło",
    "lat": "49.74506",
    "lng": "21.47252"
  },
  {
    "country": "PL",
    "name": "Jaśliska",
    "lat": "49.44229",
    "lng": "21.80795"
  },
  {
    "country": "PL",
    "name": "Jasionów",
    "lat": "49.65841",
    "lng": "21.97678"
  },
  {
    "country": "PL",
    "name": "Jasieniec",
    "lat": "51.82104",
    "lng": "20.94099"
  },
  {
    "country": "PL",
    "name": "Jasienica Rosielna",
    "lat": "49.75144",
    "lng": "21.94176"
  },
  {
    "country": "PL",
    "name": "Jasienica",
    "lat": "52.41415",
    "lng": "21.4115"
  },
  {
    "country": "PL",
    "name": "Jasień",
    "lat": "49.96988",
    "lng": "20.5719"
  },
  {
    "country": "PL",
    "name": "Jarosław",
    "lat": "50.01623",
    "lng": "22.67776"
  },
  {
    "country": "PL",
    "name": "Jarocin",
    "lat": "50.56459",
    "lng": "22.32121"
  },
  {
    "country": "PL",
    "name": "Jarczów",
    "lat": "50.42438",
    "lng": "23.58576"
  },
  {
    "country": "PL",
    "name": "Janów Podlaski",
    "lat": "52.19398",
    "lng": "23.21218"
  },
  {
    "country": "PL",
    "name": "Janów Lubelski",
    "lat": "50.70695",
    "lng": "22.41039"
  },
  {
    "country": "PL",
    "name": "Janowiec",
    "lat": "51.32359",
    "lng": "21.8894"
  },
  {
    "country": "PL",
    "name": "Janowice",
    "lat": "49.89154",
    "lng": "20.86081"
  },
  {
    "country": "PL",
    "name": "Janów",
    "lat": "53.46747",
    "lng": "23.23052"
  },
  {
    "country": "PL",
    "name": "Jakubowice Murowane",
    "lat": "51.26992",
    "lng": "22.63415"
  },
  {
    "country": "PL",
    "name": "Jakubów",
    "lat": "52.21965",
    "lng": "21.68032"
  },
  {
    "country": "PL",
    "name": "Jagiełła",
    "lat": "50.0946",
    "lng": "22.57261"
  },
  {
    "country": "PL",
    "name": "Jadowniki Mokre",
    "lat": "50.16546",
    "lng": "20.72845"
  },
  {
    "country": "PL",
    "name": "Jadowniki",
    "lat": "49.95884",
    "lng": "20.64434"
  },
  {
    "country": "PL",
    "name": "Jadów",
    "lat": "52.47849",
    "lng": "21.63199"
  },
  {
    "country": "PL",
    "name": "Jabłonna Lacka",
    "lat": "52.47664",
    "lng": "22.44228"
  },
  {
    "country": "PL",
    "name": "Jabłonna",
    "lat": "52.37885",
    "lng": "20.91745"
  },
  {
    "country": "PL",
    "name": "Jabłonna",
    "lat": "51.08875",
    "lng": "22.59364"
  },
  {
    "country": "PL",
    "name": "Jabłonka",
    "lat": "49.69417",
    "lng": "22.11565"
  },
  {
    "country": "PL",
    "name": "Jabłonica Polska",
    "lat": "49.69784",
    "lng": "21.89961"
  },
  {
    "country": "PL",
    "name": "Jabłoń",
    "lat": "51.72501",
    "lng": "23.08743"
  },
  {
    "country": "PL",
    "name": "Izbica",
    "lat": "50.88728",
    "lng": "23.15248"
  },
  {
    "country": "PL",
    "name": "Iwonicz-Zdrój",
    "lat": "49.56319",
    "lng": "21.78992"
  },
  {
    "country": "PL",
    "name": "Iwkowa",
    "lat": "49.81716",
    "lng": "20.59018"
  },
  {
    "country": "PL",
    "name": "Iwierzyce",
    "lat": "50.02958",
    "lng": "21.75396"
  },
  {
    "country": "PL",
    "name": "Iwaniska",
    "lat": "50.73146",
    "lng": "21.2806"
  },
  {
    "country": "PL",
    "name": "Inowłódz",
    "lat": "51.52717",
    "lng": "20.223"
  },
  {
    "country": "PL",
    "name": "Imielno",
    "lat": "50.58569",
    "lng": "20.44813"
  },
  {
    "country": "PL",
    "name": "Iłża",
    "lat": "51.16313",
    "lng": "21.23979"
  },
  {
    "country": "PL",
    "name": "Iłów",
    "lat": "52.33953",
    "lng": "20.0273"
  },
  {
    "country": "PL",
    "name": "Hyżne",
    "lat": "49.91769",
    "lng": "22.18131"
  },
  {
    "country": "PL",
    "name": "Husów",
    "lat": "49.97971",
    "lng": "22.28645"
  },
  {
    "country": "PL",
    "name": "Humniska",
    "lat": "49.67507",
    "lng": "22.05368"
  },
  {
    "country": "PL",
    "name": "Hrubieszów",
    "lat": "50.80502",
    "lng": "23.89251"
  },
  {
    "country": "PL",
    "name": "Horyniec-Zdrój",
    "lat": "50.19152",
    "lng": "23.36277"
  },
  {
    "country": "PL",
    "name": "Horodło",
    "lat": "50.89459",
    "lng": "24.03723"
  },
  {
    "country": "PL",
    "name": "Hornówek",
    "lat": "52.28638",
    "lng": "20.80793"
  },
  {
    "country": "PL",
    "name": "Harasiuki",
    "lat": "50.47515",
    "lng": "22.47288"
  },
  {
    "country": "PL",
    "name": "Hańsk",
    "lat": "51.41286",
    "lng": "23.39942"
  },
  {
    "country": "PL",
    "name": "Handzlówka",
    "lat": "49.99527",
    "lng": "22.22311"
  },
  {
    "country": "PL",
    "name": "Halinów",
    "lat": "52.2288",
    "lng": "21.3551"
  },
  {
    "country": "PL",
    "name": "Hajnówka",
    "lat": "52.74328",
    "lng": "23.58122"
  },
  {
    "country": "PL",
    "name": "Haczów",
    "lat": "49.66152",
    "lng": "21.8979"
  },
  {
    "country": "PL",
    "name": "Gzy",
    "lat": "52.74045",
    "lng": "20.94372"
  },
  {
    "country": "PL",
    "name": "Gwoźnica Górna",
    "lat": "49.82791",
    "lng": "21.99772"
  },
  {
    "country": "PL",
    "name": "Guzów",
    "lat": "52.11626",
    "lng": "20.33672"
  },
  {
    "country": "PL",
    "name": "Grzybowa Góra",
    "lat": "51.13326",
    "lng": "20.96174"
  },
  {
    "country": "PL",
    "name": "Grzęska",
    "lat": "50.08303",
    "lng": "22.45399"
  },
  {
    "country": "PL",
    "name": "Grybów",
    "lat": "49.62439",
    "lng": "20.94797"
  },
  {
    "country": "PL",
    "name": "Gruszów Wielki",
    "lat": "50.19163",
    "lng": "21.03144"
  },
  {
    "country": "PL",
    "name": "Grudusk",
    "lat": "53.05845",
    "lng": "20.62494"
  },
  {
    "country": "PL",
    "name": "Grudki",
    "lat": "53.09488",
    "lng": "23.66848"
  },
  {
    "country": "PL",
    "name": "Gromnik",
    "lat": "49.83843",
    "lng": "20.96123"
  },
  {
    "country": "PL",
    "name": "Grójec",
    "lat": "51.86252",
    "lng": "20.86757"
  },
  {
    "country": "PL",
    "name": "Grodzisko Górne",
    "lat": "50.1869",
    "lng": "22.43786"
  },
  {
    "country": "PL",
    "name": "Grodzisko Dolne",
    "lat": "50.16238",
    "lng": "22.46292"
  },
  {
    "country": "PL",
    "name": "Grodzisk Mazowiecki",
    "lat": "52.10387",
    "lng": "20.6337"
  },
  {
    "country": "PL",
    "name": "Grębów",
    "lat": "50.56536",
    "lng": "21.87404"
  },
  {
    "country": "PL",
    "name": "Gręboszów",
    "lat": "50.24501",
    "lng": "20.77669"
  },
  {
    "country": "PL",
    "name": "Grębków",
    "lat": "52.26931",
    "lng": "21.90974"
  },
  {
    "country": "PL",
    "name": "Granica",
    "lat": "52.13359",
    "lng": "20.80313"
  },
  {
    "country": "PL",
    "name": "Grajewo",
    "lat": "53.64728",
    "lng": "22.45537"
  },
  {
    "country": "PL",
    "name": "Grabownica Starzeńska",
    "lat": "49.65896",
    "lng": "22.07754"
  },
  {
    "country": "PL",
    "name": "Grabowiec",
    "lat": "50.8209",
    "lng": "23.55057"
  },
  {
    "country": "PL",
    "name": "Gózd",
    "lat": "51.37832",
    "lng": "21.37914"
  },
  {
    "country": "PL",
    "name": "Goworowo",
    "lat": "52.90083",
    "lng": "21.55578"
  },
  {
    "country": "PL",
    "name": "Gowarczów",
    "lat": "51.27845",
    "lng": "20.43835"
  },
  {
    "country": "PL",
    "name": "Goszczyn",
    "lat": "51.73187",
    "lng": "20.85154"
  },
  {
    "country": "PL",
    "name": "Gościeradów",
    "lat": "50.86859",
    "lng": "22.00536"
  },
  {
    "country": "PL",
    "name": "Gorzyce",
    "lat": "50.6672",
    "lng": "21.84013"
  },
  {
    "country": "PL",
    "name": "Gorzyce",
    "lat": "50.12841",
    "lng": "22.57926"
  },
  {
    "country": "PL",
    "name": "Górzno",
    "lat": "51.84681",
    "lng": "21.70933"
  },
  {
    "country": "PL",
    "name": "Gorzków",
    "lat": "50.94778",
    "lng": "23.01267"
  },
  {
    "country": "PL",
    "name": "Górowo Iławeckie",
    "lat": "54.28559",
    "lng": "20.48886"
  },
  {
    "country": "PL",
    "name": "Górno",
    "lat": "50.84774",
    "lng": "20.82501"
  },
  {
    "country": "PL",
    "name": "Górno",
    "lat": "50.28243",
    "lng": "22.145"
  },
  {
    "country": "PL",
    "name": "Gorliczyna",
    "lat": "50.09217",
    "lng": "22.48764"
  },
  {
    "country": "PL",
    "name": "Gorlice",
    "lat": "49.65563",
    "lng": "21.16035"
  },
  {
    "country": "PL",
    "name": "Górki",
    "lat": "49.64385",
    "lng": "22.04304"
  },
  {
    "country": "PL",
    "name": "Góra Kalwaria",
    "lat": "51.97653",
    "lng": "21.21537"
  },
  {
    "country": "PL",
    "name": "Goraj",
    "lat": "50.72184",
    "lng": "22.66651"
  },
  {
    "country": "PL",
    "name": "Goniadz",
    "lat": "53.48953",
    "lng": "22.73578"
  },
  {
    "country": "PL",
    "name": "Gołymin-Ośrodek",
    "lat": "52.808",
    "lng": "20.87325"
  },
  {
    "country": "PL",
    "name": "Gołdap",
    "lat": "54.30631",
    "lng": "22.30362"
  },
  {
    "country": "PL",
    "name": "Golcowa",
    "lat": "49.77162",
    "lng": "22.02501"
  },
  {
    "country": "PL",
    "name": "Godziszów",
    "lat": "50.74889",
    "lng": "22.49794"
  },
  {
    "country": "PL",
    "name": "Godzianów",
    "lat": "51.89694",
    "lng": "20.03589"
  },
  {
    "country": "PL",
    "name": "Gnojno",
    "lat": "50.60263",
    "lng": "20.84913"
  },
  {
    "country": "PL",
    "name": "Gnojnik",
    "lat": "49.89397",
    "lng": "20.60863"
  },
  {
    "country": "PL",
    "name": "Głuchów",
    "lat": "51.77947",
    "lng": "20.07666"
  },
  {
    "country": "PL",
    "name": "Głuchów",
    "lat": "50.08171",
    "lng": "22.27135"
  },
  {
    "country": "PL",
    "name": "Głogów Małopolski",
    "lat": "50.15122",
    "lng": "21.96287"
  },
  {
    "country": "PL",
    "name": "Glinojeck",
    "lat": "52.81983",
    "lng": "20.29198"
  },
  {
    "country": "PL",
    "name": "Giżycko",
    "lat": "54.03811",
    "lng": "21.76441"
  },
  {
    "country": "PL",
    "name": "Gietrzwałd",
    "lat": "53.74617",
    "lng": "20.23742"
  },
  {
    "country": "PL",
    "name": "Gierzwałd",
    "lat": "53.54128",
    "lng": "20.08867"
  },
  {
    "country": "PL",
    "name": "Gierłoż",
    "lat": "54.08134",
    "lng": "21.49551"
  },
  {
    "country": "PL",
    "name": "Gielniów",
    "lat": "51.40076",
    "lng": "20.48126"
  },
  {
    "country": "PL",
    "name": "Giedlarowa",
    "lat": "50.22689",
    "lng": "22.40593"
  },
  {
    "country": "PL",
    "name": "Gdów",
    "lat": "49.90818",
    "lng": "20.19879"
  },
  {
    "country": "PL",
    "name": "Gąsocin",
    "lat": "52.73754",
    "lng": "20.7118"
  },
  {
    "country": "PL",
    "name": "Garwolin",
    "lat": "51.89747",
    "lng": "21.61466"
  },
  {
    "country": "PL",
    "name": "Garbów",
    "lat": "51.35517",
    "lng": "22.32937"
  },
  {
    "country": "PL",
    "name": "Garbatka-Letnisko",
    "lat": "51.4832",
    "lng": "21.61079"
  },
  {
    "country": "PL",
    "name": "Gać",
    "lat": "50.02693",
    "lng": "22.35898"
  },
  {
    "country": "PL",
    "name": "Frysztak",
    "lat": "49.84164",
    "lng": "21.60942"
  },
  {
    "country": "PL",
    "name": "Frydman",
    "lat": "49.44927",
    "lng": "20.22961"
  },
  {
    "country": "PL",
    "name": "Fredropol",
    "lat": "49.69578",
    "lng": "22.74625"
  },
  {
    "country": "PL",
    "name": "Frampol",
    "lat": "50.67159",
    "lng": "22.67061"
  },
  {
    "country": "PL",
    "name": "Firlej",
    "lat": "51.55882",
    "lng": "22.50841"
  },
  {
    "country": "PL",
    "name": "Filipów",
    "lat": "54.18037",
    "lng": "22.62076"
  },
  {
    "country": "PL",
    "name": "Fałków",
    "lat": "51.13606",
    "lng": "20.1061"
  },
  {
    "country": "PL",
    "name": "Fajsławice",
    "lat": "51.09592",
    "lng": "22.96323"
  },
  {
    "country": "PL",
    "name": "Ełk",
    "lat": "53.82824",
    "lng": "22.36469"
  },
  {
    "country": "PL",
    "name": "Dzwola",
    "lat": "50.69657",
    "lng": "22.56729"
  },
  {
    "country": "PL",
    "name": "Dźwierzuty",
    "lat": "53.70494",
    "lng": "20.96037"
  },
  {
    "country": "PL",
    "name": "Dzików Stary",
    "lat": "50.24699",
    "lng": "22.92984"
  },
  {
    "country": "PL",
    "name": "Dzikowiec",
    "lat": "50.27288",
    "lng": "21.84365"
  },
  {
    "country": "PL",
    "name": "Dziewin",
    "lat": "50.07554",
    "lng": "20.45491"
  },
  {
    "country": "PL",
    "name": "Dzierzkowice",
    "lat": "50.96019",
    "lng": "22.06639"
  },
  {
    "country": "PL",
    "name": "Dzierzgowo",
    "lat": "53.15279",
    "lng": "20.66322"
  },
  {
    "country": "PL",
    "name": "Dzierzążnia",
    "lat": "52.62811",
    "lng": "20.23364"
  },
  {
    "country": "PL",
    "name": "Dziekanów Leśny",
    "lat": "52.35243",
    "lng": "20.85124"
  },
  {
    "country": "PL",
    "name": "Działoszyce",
    "lat": "50.36534",
    "lng": "20.35226"
  },
  {
    "country": "PL",
    "name": "Działdowo",
    "lat": "53.23958",
    "lng": "20.17004"
  },
  {
    "country": "PL",
    "name": "Dziadkowice",
    "lat": "52.5638",
    "lng": "22.91689"
  },
  {
    "country": "PL",
    "name": "Dywity",
    "lat": "53.83759",
    "lng": "20.47817"
  },
  {
    "country": "PL",
    "name": "Dynów",
    "lat": "49.81506",
    "lng": "22.23388"
  },
  {
    "country": "PL",
    "name": "Dydnia",
    "lat": "49.6864",
    "lng": "22.17196"
  },
  {
    "country": "PL",
    "name": "Dwikozy",
    "lat": "50.73613",
    "lng": "21.78864"
  },
  {
    "country": "PL",
    "name": "Dukla",
    "lat": "49.55554",
    "lng": "21.68317"
  },
  {
    "country": "PL",
    "name": "Duczki",
    "lat": "52.36271",
    "lng": "21.29047"
  },
  {
    "country": "PL",
    "name": "Dubienka",
    "lat": "51.04862",
    "lng": "23.89252"
  },
  {
    "country": "PL",
    "name": "Dubiecko",
    "lat": "49.82608",
    "lng": "22.39117"
  },
  {
    "country": "PL",
    "name": "Drzewica",
    "lat": "51.45085",
    "lng": "20.47701"
  },
  {
    "country": "PL",
    "name": "Drohiczyn",
    "lat": "52.40011",
    "lng": "22.65853"
  },
  {
    "country": "PL",
    "name": "Drelów",
    "lat": "51.91219",
    "lng": "22.87165"
  },
  {
    "country": "PL",
    "name": "Dorohusk",
    "lat": "51.15475",
    "lng": "23.80325"
  },
  {
    "country": "PL",
    "name": "Domaszowice",
    "lat": "50.87488",
    "lng": "20.68288"
  },
  {
    "country": "PL",
    "name": "Domaradz",
    "lat": "49.78675",
    "lng": "21.94571"
  },
  {
    "country": "PL",
    "name": "Domanice",
    "lat": "52.03739",
    "lng": "22.17642"
  },
  {
    "country": "PL",
    "name": "Dołhobyczów",
    "lat": "50.58591",
    "lng": "24.03594"
  },
  {
    "country": "PL",
    "name": "Dobrzyniewo Duże",
    "lat": "53.20022",
    "lng": "23.01129"
  },
  {
    "country": "PL",
    "name": "Dobre Miasto",
    "lat": "53.98668",
    "lng": "20.39749"
  },
  {
    "country": "PL",
    "name": "Dobre",
    "lat": "52.32097",
    "lng": "21.67881"
  },
  {
    "country": "PL",
    "name": "Dobra",
    "lat": "49.71793",
    "lng": "20.25347"
  },
  {
    "country": "PL",
    "name": "Dobczyce",
    "lat": "49.88109",
    "lng": "20.08936"
  },
  {
    "country": "PL",
    "name": "Długosiodło",
    "lat": "52.75998",
    "lng": "21.59183"
  },
  {
    "country": "PL",
    "name": "Długie",
    "lat": "49.57866",
    "lng": "22.04338"
  },
  {
    "country": "PL",
    "name": "Dębowiec",
    "lat": "49.68374",
    "lng": "21.46068"
  },
  {
    "country": "PL",
    "name": "Dębowa Kłoda",
    "lat": "51.59446",
    "lng": "23.0064"
  },
  {
    "country": "PL",
    "name": "Dębów",
    "lat": "50.0449",
    "lng": "22.43614"
  },
  {
    "country": "PL",
    "name": "Dębno",
    "lat": "50.19811",
    "lng": "22.51837"
  },
  {
    "country": "PL",
    "name": "Dębno",
    "lat": "49.96701",
    "lng": "20.71979"
  },
  {
    "country": "PL",
    "name": "Dęblin",
    "lat": "51.55912",
    "lng": "21.84829"
  },
  {
    "country": "PL",
    "name": "Dębica",
    "lat": "50.05146",
    "lng": "21.41141"
  },
  {
    "country": "PL",
    "name": "Dębe Wielkie",
    "lat": "52.19961",
    "lng": "21.44334"
  },
  {
    "country": "PL",
    "name": "Daleszyce",
    "lat": "50.80229",
    "lng": "20.80791"
  },
  {
    "country": "PL",
    "name": "Dąbrówno",
    "lat": "53.43408",
    "lng": "20.03529"
  },
  {
    "country": "PL",
    "name": "Dąbrówka",
    "lat": "52.48388",
    "lng": "21.29794"
  },
  {
    "country": "PL",
    "name": "Dąbrowa Tarnowska",
    "lat": "50.17462",
    "lng": "20.98633"
  },
  {
    "country": "PL",
    "name": "Dąbrowa Białostocka",
    "lat": "53.65364",
    "lng": "23.34792"
  },
  {
    "country": "PL",
    "name": "Czyżew",
    "lat": "52.79768",
    "lng": "22.31237"
  },
  {
    "country": "PL",
    "name": "Czudec",
    "lat": "49.94487",
    "lng": "21.84134"
  },
  {
    "country": "PL",
    "name": "Czerwonka",
    "lat": "53.91627",
    "lng": "20.89685"
  },
  {
    "country": "PL",
    "name": "Czerwonka",
    "lat": "52.89254",
    "lng": "21.21494"
  },
  {
    "country": "PL",
    "name": "Czerwińsk Nad Wisłą",
    "lat": "52.39828",
    "lng": "20.3096"
  },
  {
    "country": "PL",
    "name": "Czerwin",
    "lat": "52.94905",
    "lng": "21.75842"
  },
  {
    "country": "PL",
    "name": "Czerniewice",
    "lat": "51.65419",
    "lng": "20.15553"
  },
  {
    "country": "PL",
    "name": "Czernice Borowe",
    "lat": "53.03197",
    "lng": "20.71944"
  },
  {
    "country": "PL",
    "name": "Czermin",
    "lat": "50.33911",
    "lng": "21.33356"
  },
  {
    "country": "PL",
    "name": "Czeremcha",
    "lat": "52.51667",
    "lng": "23.35"
  },
  {
    "country": "PL",
    "name": "Czemierniki",
    "lat": "51.67298",
    "lng": "22.63887"
  },
  {
    "country": "PL",
    "name": "Czchów",
    "lat": "49.83726",
    "lng": "20.68056"
  },
  {
    "country": "PL",
    "name": "Czaszyn",
    "lat": "49.44854",
    "lng": "22.2165"
  },
  {
    "country": "PL",
    "name": "Czarnocin",
    "lat": "50.3408",
    "lng": "20.5162"
  },
  {
    "country": "PL",
    "name": "Czarnochowice",
    "lat": "50.00471",
    "lng": "20.0679"
  },
  {
    "country": "PL",
    "name": "Czarnia",
    "lat": "53.35614",
    "lng": "21.1952"
  },
  {
    "country": "PL",
    "name": "Czarna Góra",
    "lat": "49.37662",
    "lng": "20.13047"
  },
  {
    "country": "PL",
    "name": "Czarna Białostocka",
    "lat": "53.30509",
    "lng": "23.28146"
  },
  {
    "country": "PL",
    "name": "Czarna",
    "lat": "50.10979",
    "lng": "22.18165"
  },
  {
    "country": "PL",
    "name": "Czarna",
    "lat": "50.06717",
    "lng": "21.25614"
  },
  {
    "country": "PL",
    "name": "Czarna",
    "lat": "49.33116",
    "lng": "22.65896"
  },
  {
    "country": "PL",
    "name": "Cyców",
    "lat": "51.29928",
    "lng": "23.14124"
  },
  {
    "country": "PL",
    "name": "Cmolas",
    "lat": "50.29526",
    "lng": "21.74417"
  },
  {
    "country": "PL",
    "name": "Ćmielów",
    "lat": "50.89028",
    "lng": "21.51426"
  },
  {
    "country": "PL",
    "name": "Cisna",
    "lat": "49.21328",
    "lng": "22.32795"
  },
  {
    "country": "PL",
    "name": "Ciężkowice",
    "lat": "49.78575",
    "lng": "20.97324"
  },
  {
    "country": "PL",
    "name": "Cieszanów",
    "lat": "50.24564",
    "lng": "23.13163"
  },
  {
    "country": "PL",
    "name": "Ciepielów",
    "lat": "51.24838",
    "lng": "21.57475"
  },
  {
    "country": "PL",
    "name": "Cielądz",
    "lat": "51.71576",
    "lng": "20.34428"
  },
  {
    "country": "PL",
    "name": "Ciechanowiec",
    "lat": "52.67828",
    "lng": "22.49815"
  },
  {
    "country": "PL",
    "name": "Ciechanów",
    "lat": "52.88141",
    "lng": "20.61996"
  },
  {
    "country": "PL",
    "name": "Chynów",
    "lat": "51.90425",
    "lng": "21.08208"
  },
  {
    "country": "PL",
    "name": "Chwałowice",
    "lat": "50.76665",
    "lng": "21.88683"
  },
  {
    "country": "PL",
    "name": "Chrzanów",
    "lat": "50.77256",
    "lng": "22.60351"
  },
  {
    "country": "PL",
    "name": "Chorzele",
    "lat": "53.26075",
    "lng": "20.89728"
  },
  {
    "country": "PL",
    "name": "Choroszcz",
    "lat": "53.14332",
    "lng": "22.98889"
  },
  {
    "country": "PL",
    "name": "Chorkówka",
    "lat": "49.64668",
    "lng": "21.67156"
  },
  {
    "country": "PL",
    "name": "Chodel",
    "lat": "51.11177",
    "lng": "22.13269"
  },
  {
    "country": "PL",
    "name": "Chmielnik",
    "lat": "50.6144",
    "lng": "20.75206"
  },
  {
    "country": "PL",
    "name": "Chmielnik",
    "lat": "49.97386",
    "lng": "22.14535"
  },
  {
    "country": "PL",
    "name": "Chlewiska",
    "lat": "51.24376",
    "lng": "20.76871"
  },
  {
    "country": "PL",
    "name": "Chełmiec",
    "lat": "49.63051",
    "lng": "20.66425"
  },
  {
    "country": "PL",
    "name": "Chełm",
    "lat": "51.14312",
    "lng": "23.4716"
  },
  {
    "country": "PL",
    "name": "Chęciny",
    "lat": "50.80021",
    "lng": "20.46229"
  },
  {
    "country": "PL",
    "name": "Ceranów",
    "lat": "52.63082",
    "lng": "22.22826"
  },
  {
    "country": "PL",
    "name": "Celestynów",
    "lat": "52.06093",
    "lng": "21.39107"
  },
  {
    "country": "PL",
    "name": "Cegłów",
    "lat": "52.14782",
    "lng": "21.73739"
  },
  {
    "country": "PL",
    "name": "Bystra",
    "lat": "49.66235",
    "lng": "21.08628"
  },
  {
    "country": "PL",
    "name": "Bychawa",
    "lat": "51.01608",
    "lng": "22.53296"
  },
  {
    "country": "PL",
    "name": "Busko-Zdrój",
    "lat": "50.47078",
    "lng": "20.71884"
  },
  {
    "country": "PL",
    "name": "Bulkowo",
    "lat": "52.54087",
    "lng": "20.11889"
  },
  {
    "country": "PL",
    "name": "Bukowsko",
    "lat": "49.48039",
    "lng": "22.06329"
  },
  {
    "country": "PL",
    "name": "Bukowina Tatrzańska",
    "lat": "49.34302",
    "lng": "20.10807"
  },
  {
    "country": "PL",
    "name": "Brzyska",
    "lat": "49.82226",
    "lng": "21.39004"
  },
  {
    "country": "PL",
    "name": "Brzozów",
    "lat": "49.69501",
    "lng": "22.01926"
  },
  {
    "country": "PL",
    "name": "Brzóza Stadnicka",
    "lat": "50.19965",
    "lng": "22.28233"
  },
  {
    "country": "PL",
    "name": "Brzóza Królewska",
    "lat": "50.23908",
    "lng": "22.32559"
  },
  {
    "country": "PL",
    "name": "Brzostek",
    "lat": "49.87954",
    "lng": "21.41102"
  },
  {
    "country": "PL",
    "name": "Brzeźnica",
    "lat": "50.10065",
    "lng": "21.48025"
  },
  {
    "country": "PL",
    "name": "Brzeźnica",
    "lat": "49.95763",
    "lng": "20.49139"
  },
  {
    "country": "PL",
    "name": "Brzeziny",
    "lat": "50.77273",
    "lng": "20.57319"
  },
  {
    "country": "PL",
    "name": "Brzesko",
    "lat": "49.96911",
    "lng": "20.60606"
  },
  {
    "country": "PL",
    "name": "Brzączowice",
    "lat": "49.87478",
    "lng": "20.03709"
  },
  {
    "country": "PL",
    "name": "Brwinów",
    "lat": "52.14269",
    "lng": "20.71697"
  },
  {
    "country": "PL",
    "name": "Brok",
    "lat": "52.69948",
    "lng": "21.85704"
  },
  {
    "country": "PL",
    "name": "Brody",
    "lat": "51.02466",
    "lng": "21.22147"
  },
  {
    "country": "PL",
    "name": "Brochów",
    "lat": "52.3195",
    "lng": "20.26257"
  },
  {
    "country": "PL",
    "name": "Brańszczyk",
    "lat": "52.62931",
    "lng": "21.58745"
  },
  {
    "country": "PL",
    "name": "Brańsk",
    "lat": "52.7444",
    "lng": "22.83774"
  },
  {
    "country": "PL",
    "name": "Borzęcin",
    "lat": "50.0654",
    "lng": "20.71103"
  },
  {
    "country": "PL",
    "name": "Borzechów",
    "lat": "51.09258",
    "lng": "22.28414"
  },
  {
    "country": "PL",
    "name": "Borowie",
    "lat": "51.94908",
    "lng": "21.7658"
  },
  {
    "country": "PL",
    "name": "Borowa",
    "lat": "50.38548",
    "lng": "21.3515"
  },
  {
    "country": "PL",
    "name": "Borkowice",
    "lat": "51.32025",
    "lng": "20.68339"
  },
  {
    "country": "PL",
    "name": "Borki",
    "lat": "51.72161",
    "lng": "22.52129"
  },
  {
    "country": "PL",
    "name": "Borek",
    "lat": "50.01778",
    "lng": "20.53087"
  },
  {
    "country": "PL",
    "name": "Bolimów",
    "lat": "52.07671",
    "lng": "20.16352"
  },
  {
    "country": "PL",
    "name": "Bojanów",
    "lat": "50.42531",
    "lng": "21.95111"
  },
  {
    "country": "PL",
    "name": "Boguty-Pianki",
    "lat": "52.7168",
    "lng": "22.41546"
  },
  {
    "country": "PL",
    "name": "Boguchwała",
    "lat": "49.98473",
    "lng": "21.94528"
  },
  {
    "country": "PL",
    "name": "Bogoria",
    "lat": "50.65175",
    "lng": "21.26"
  },
  {
    "country": "PL",
    "name": "Bodzentyn",
    "lat": "50.94115",
    "lng": "20.95719"
  },
  {
    "country": "PL",
    "name": "Bodzechów",
    "lat": "50.90715",
    "lng": "21.43715"
  },
  {
    "country": "PL",
    "name": "Bodzanów",
    "lat": "52.49992",
    "lng": "20.02945"
  },
  {
    "country": "PL",
    "name": "Boćki",
    "lat": "52.65155",
    "lng": "23.04485"
  },
  {
    "country": "PL",
    "name": "Bochnia",
    "lat": "49.96905",
    "lng": "20.43028"
  },
  {
    "country": "PL",
    "name": "Bobrowniki",
    "lat": "52.06442",
    "lng": "20.01949"
  },
  {
    "country": "PL",
    "name": "Bobowa",
    "lat": "49.70866",
    "lng": "20.94767"
  },
  {
    "country": "PL",
    "name": "Stara Błotnica",
    "lat": "51.54676",
    "lng": "20.97479"
  },
  {
    "country": "PL",
    "name": "Błonie",
    "lat": "52.19849",
    "lng": "20.61709"
  },
  {
    "country": "PL",
    "name": "Bliżyn",
    "lat": "51.10778",
    "lng": "20.75935"
  },
  {
    "country": "PL",
    "name": "Blizne",
    "lat": "49.75332",
    "lng": "21.97351"
  },
  {
    "country": "PL",
    "name": "Błędów",
    "lat": "51.77767",
    "lng": "20.69798"
  },
  {
    "country": "PL",
    "name": "Błażowa",
    "lat": "49.88521",
    "lng": "22.10037"
  },
  {
    "country": "PL",
    "name": "Bisztynek",
    "lat": "54.08633",
    "lng": "20.90192"
  },
  {
    "country": "PL",
    "name": "Biszcza",
    "lat": "50.40146",
    "lng": "22.65063"
  },
  {
    "country": "PL",
    "name": "Biskupiec",
    "lat": "53.86467",
    "lng": "20.95692"
  },
  {
    "country": "PL",
    "name": "Biskupice Radłowskie",
    "lat": "50.12069",
    "lng": "20.85943"
  },
  {
    "country": "PL",
    "name": "Bircza",
    "lat": "49.69173",
    "lng": "22.47854"
  },
  {
    "country": "PL",
    "name": "Binarowa",
    "lat": "49.75621",
    "lng": "21.22816"
  },
  {
    "country": "PL",
    "name": "Biłgoraj",
    "lat": "50.54114",
    "lng": "22.72204"
  },
  {
    "country": "PL",
    "name": "Bieniewice",
    "lat": "52.18268",
    "lng": "20.56306"
  },
  {
    "country": "PL",
    "name": "Bielsk Podlaski",
    "lat": "52.76512",
    "lng": "23.18647"
  },
  {
    "country": "PL",
    "name": "Bieliny",
    "lat": "50.84947",
    "lng": "20.94149"
  },
  {
    "country": "PL",
    "name": "Bieliny",
    "lat": "50.44237",
    "lng": "22.30482"
  },
  {
    "country": "PL",
    "name": "Bielany",
    "lat": "52.34174",
    "lng": "22.24929"
  },
  {
    "country": "PL",
    "name": "Bielany",
    "lat": "52.29242",
    "lng": "20.93531"
  },
  {
    "country": "PL",
    "name": "Biecz",
    "lat": "49.73596",
    "lng": "21.26301"
  },
  {
    "country": "PL",
    "name": "Białystok",
    "lat": "53.13333",
    "lng": "23.16433"
  },
  {
    "country": "PL",
    "name": "Biały Dunajec",
    "lat": "49.3738",
    "lng": "20.00898"
  },
  {
    "country": "PL",
    "name": "Białowieża",
    "lat": "52.7",
    "lng": "23.86667"
  },
  {
    "country": "PL",
    "name": "Białołeka",
    "lat": "52.32127",
    "lng": "20.97204"
  },
  {
    "country": "PL",
    "name": "Białobrzegi",
    "lat": "52.44199",
    "lng": "21.05255"
  },
  {
    "country": "PL",
    "name": "Białobrzegi",
    "lat": "51.64695",
    "lng": "20.95041"
  },
  {
    "country": "PL",
    "name": "Białobrzegi",
    "lat": "50.10252",
    "lng": "22.31907"
  },
  {
    "country": "PL",
    "name": "Białka Tatrzańska",
    "lat": "49.38975",
    "lng": "20.10507"
  },
  {
    "country": "PL",
    "name": "Biała Rawska",
    "lat": "51.80779",
    "lng": "20.47259"
  },
  {
    "country": "PL",
    "name": "Biała Podlaska",
    "lat": "52.03238",
    "lng": "23.11652"
  },
  {
    "country": "PL",
    "name": "Biała Piska",
    "lat": "53.61191",
    "lng": "22.06321"
  },
  {
    "country": "PL",
    "name": "Białaczów",
    "lat": "51.29815",
    "lng": "20.29724"
  },
  {
    "country": "PL",
    "name": "Besko",
    "lat": "49.58757",
    "lng": "21.95292"
  },
  {
    "country": "PL",
    "name": "Bemowo",
    "lat": "52.2546",
    "lng": "20.90844"
  },
  {
    "country": "PL",
    "name": "Bełżyce",
    "lat": "51.17415",
    "lng": "22.28027"
  },
  {
    "country": "PL",
    "name": "Belsk Duży",
    "lat": "51.82561",
    "lng": "20.80847"
  },
  {
    "country": "PL",
    "name": "Bejsce",
    "lat": "50.23903",
    "lng": "20.59834"
  },
  {
    "country": "PL",
    "name": "Batorz",
    "lat": "50.8505",
    "lng": "22.49313"
  },
  {
    "country": "PL",
    "name": "Bartoszyce",
    "lat": "54.25354",
    "lng": "20.80819"
  },
  {
    "country": "PL",
    "name": "Barczewo",
    "lat": "53.83055",
    "lng": "20.69112"
  },
  {
    "country": "PL",
    "name": "Barciany",
    "lat": "54.21993",
    "lng": "21.35347"
  },
  {
    "country": "PL",
    "name": "Baranów Sandomierski",
    "lat": "50.49912",
    "lng": "21.54204"
  },
  {
    "country": "PL",
    "name": "Baranowo",
    "lat": "53.17554",
    "lng": "21.29803"
  },
  {
    "country": "PL",
    "name": "Baranów",
    "lat": "51.55786",
    "lng": "22.13625"
  },
  {
    "country": "PL",
    "name": "Baniocha",
    "lat": "52.01653",
    "lng": "21.13984"
  },
  {
    "country": "PL",
    "name": "Banie Mazurskie",
    "lat": "54.24662",
    "lng": "22.03617"
  },
  {
    "country": "PL",
    "name": "Bałtów",
    "lat": "51.01845",
    "lng": "21.54385"
  },
  {
    "country": "PL",
    "name": "Baligród",
    "lat": "49.3309",
    "lng": "22.28566"
  },
  {
    "country": "PL",
    "name": "Baćkowice",
    "lat": "50.79194",
    "lng": "21.23211"
  },
  {
    "country": "PL",
    "name": "Baboszewo",
    "lat": "52.6807",
    "lng": "20.25527"
  },
  {
    "country": "PL",
    "name": "Babica",
    "lat": "49.93476",
    "lng": "21.87035"
  },
  {
    "country": "PL",
    "name": "Augustów",
    "lat": "53.84321",
    "lng": "22.97979"
  },
  {
    "country": "PL",
    "name": "Annopol",
    "lat": "50.88551",
    "lng": "21.85678"
  },
  {
    "country": "PL",
    "name": "Aleksandrów",
    "lat": "50.4663",
    "lng": "22.89225"
  },
  {
    "country": "PL",
    "name": "Albigowa",
    "lat": "50.01425",
    "lng": "22.22414"
  },
  {
    "country": "PL",
    "name": "Adamówka",
    "lat": "50.25857",
    "lng": "22.69595"
  },
  {
    "country": "PL",
    "name": "Adamów",
    "lat": "51.74335",
    "lng": "22.26414"
  },
  {
    "country": "PL",
    "name": "Abramów",
    "lat": "51.45647",
    "lng": "22.31521"
  },
  {
    "country": "PL",
    "name": "Żywiec",
    "lat": "49.68529",
    "lng": "19.19243"
  },
  {
    "country": "PL",
    "name": "Żychlin",
    "lat": "52.24404",
    "lng": "19.62613"
  },
  {
    "country": "PL",
    "name": "Zwierzyń",
    "lat": "52.83212",
    "lng": "15.56763"
  },
  {
    "country": "PL",
    "name": "Żuromin",
    "lat": "53.06611",
    "lng": "19.90894"
  },
  {
    "country": "PL",
    "name": "Żukowo",
    "lat": "54.3422",
    "lng": "18.36476"
  },
  {
    "country": "PL",
    "name": "Zubrzyca Górna",
    "lat": "49.56174",
    "lng": "19.64973"
  },
  {
    "country": "PL",
    "name": "Zubrzyca Dolna",
    "lat": "49.52688",
    "lng": "19.67342"
  },
  {
    "country": "PL",
    "name": "Żory",
    "lat": "50.04523",
    "lng": "18.70062"
  },
  {
    "country": "PL",
    "name": "Żórawina",
    "lat": "50.9808",
    "lng": "17.03671"
  },
  {
    "country": "PL",
    "name": "Żnin",
    "lat": "52.84958",
    "lng": "17.71992"
  },
  {
    "country": "PL",
    "name": "Żmigród",
    "lat": "51.46672",
    "lng": "16.90564"
  },
  {
    "country": "PL",
    "name": "Złoty Stok",
    "lat": "50.44472",
    "lng": "16.87586"
  },
  {
    "country": "PL",
    "name": "Złotów",
    "lat": "53.36346",
    "lng": "17.04082"
  },
  {
    "country": "PL",
    "name": "Złotoryja",
    "lat": "51.12637",
    "lng": "15.91979"
  },
  {
    "country": "PL",
    "name": "Złotniki Kujawskie",
    "lat": "52.89943",
    "lng": "18.14564"
  },
  {
    "country": "PL",
    "name": "Złotniki",
    "lat": "52.49407",
    "lng": "16.84496"
  },
  {
    "country": "PL",
    "name": "Złoczew",
    "lat": "51.41719",
    "lng": "18.60363"
  },
  {
    "country": "PL",
    "name": "Złocieniec",
    "lat": "53.53286",
    "lng": "16.01132"
  },
  {
    "country": "PL",
    "name": "Zławieś Wielka",
    "lat": "53.09562",
    "lng": "18.32897"
  },
  {
    "country": "PL",
    "name": "Zielonki",
    "lat": "50.12091",
    "lng": "19.92156"
  },
  {
    "country": "PL",
    "name": "Zielona Góra",
    "lat": "51.93548",
    "lng": "15.50643"
  },
  {
    "country": "PL",
    "name": "Ziębice",
    "lat": "50.60122",
    "lng": "17.04065"
  },
  {
    "country": "PL",
    "name": "Zgorzelec",
    "lat": "51.14942",
    "lng": "15.00835"
  },
  {
    "country": "PL",
    "name": "Zgierz",
    "lat": "51.85561",
    "lng": "19.40623"
  },
  {
    "country": "PL",
    "name": "Żerniki Wrocławskie",
    "lat": "51.03308",
    "lng": "17.05662"
  },
  {
    "country": "PL",
    "name": "Żernica",
    "lat": "50.2477",
    "lng": "18.61547"
  },
  {
    "country": "PL",
    "name": "Żerków",
    "lat": "52.06877",
    "lng": "17.56349"
  },
  {
    "country": "PL",
    "name": "Zembrzyce",
    "lat": "49.77517",
    "lng": "19.6012"
  },
  {
    "country": "PL",
    "name": "Zelów",
    "lat": "51.46452",
    "lng": "19.21972"
  },
  {
    "country": "PL",
    "name": "Żelistrzewo",
    "lat": "54.6777",
    "lng": "18.41738"
  },
  {
    "country": "PL",
    "name": "Żelazków",
    "lat": "51.85418",
    "lng": "18.1743"
  },
  {
    "country": "PL",
    "name": "Zebrzydowice",
    "lat": "50.1",
    "lng": "18.5"
  },
  {
    "country": "PL",
    "name": "Zebrzydowice",
    "lat": "49.89032",
    "lng": "19.67291"
  },
  {
    "country": "PL",
    "name": "Zebrzydowice",
    "lat": "49.87793",
    "lng": "18.61127"
  },
  {
    "country": "PL",
    "name": "Zębowice",
    "lat": "50.7629",
    "lng": "18.34434"
  },
  {
    "country": "PL",
    "name": "Zdzieszowice",
    "lat": "50.42482",
    "lng": "18.12349"
  },
  {
    "country": "PL",
    "name": "Zduny",
    "lat": "51.6458",
    "lng": "17.37694"
  },
  {
    "country": "PL",
    "name": "Zduńska Wola",
    "lat": "51.59915",
    "lng": "18.93974"
  },
  {
    "country": "PL",
    "name": "Zbytków",
    "lat": "49.92288",
    "lng": "18.72697"
  },
  {
    "country": "PL",
    "name": "Zbrosławice",
    "lat": "50.41612",
    "lng": "18.75443"
  },
  {
    "country": "PL",
    "name": "Zbójno",
    "lat": "53.00848",
    "lng": "19.1575"
  },
  {
    "country": "PL",
    "name": "Zblewo",
    "lat": "53.93366",
    "lng": "18.32262"
  },
  {
    "country": "PL",
    "name": "Zbąszynek",
    "lat": "52.24315",
    "lng": "15.81654"
  },
  {
    "country": "PL",
    "name": "Zbąszyń",
    "lat": "52.2509",
    "lng": "15.9252"
  },
  {
    "country": "PL",
    "name": "Zawoja",
    "lat": "49.64396",
    "lng": "19.54227"
  },
  {
    "country": "PL",
    "name": "Zawiercie",
    "lat": "50.48766",
    "lng": "19.41679"
  },
  {
    "country": "PL",
    "name": "Zawidz",
    "lat": "52.82745",
    "lng": "19.87367"
  },
  {
    "country": "PL",
    "name": "Zawidów",
    "lat": "51.02546",
    "lng": "15.06213"
  },
  {
    "country": "PL",
    "name": "Zawadzkie",
    "lat": "50.60503",
    "lng": "18.48467"
  },
  {
    "country": "PL",
    "name": "Zator",
    "lat": "49.99604",
    "lng": "19.43799"
  },
  {
    "country": "PL",
    "name": "Zarzecze",
    "lat": "50.36715",
    "lng": "19.69591"
  },
  {
    "country": "PL",
    "name": "Zarzecze",
    "lat": "49.71932",
    "lng": "19.17526"
  },
  {
    "country": "PL",
    "name": "Żary",
    "lat": "51.64205",
    "lng": "15.13727"
  },
  {
    "country": "PL",
    "name": "Żarów",
    "lat": "50.94116",
    "lng": "16.49466"
  },
  {
    "country": "PL",
    "name": "Żarki",
    "lat": "50.62518",
    "lng": "19.36357"
  },
  {
    "country": "PL",
    "name": "Żarki",
    "lat": "50.08259",
    "lng": "19.35199"
  },
  {
    "country": "PL",
    "name": "Zapolice",
    "lat": "51.54319",
    "lng": "18.88335"
  },
  {
    "country": "PL",
    "name": "Zaniemyśl",
    "lat": "52.15561",
    "lng": "17.16228"
  },
  {
    "country": "PL",
    "name": "Zamarski",
    "lat": "49.78254",
    "lng": "18.66972"
  },
  {
    "country": "PL",
    "name": "Zalewo",
    "lat": "53.84534",
    "lng": "19.60519"
  },
  {
    "country": "PL",
    "name": "Zalas",
    "lat": "50.08033",
    "lng": "19.62132"
  },
  {
    "country": "PL",
    "name": "Zakrzów",
    "lat": "49.82558",
    "lng": "19.64973"
  },
  {
    "country": "PL",
    "name": "Zakrzewo",
    "lat": "53.41186",
    "lng": "17.15472"
  },
  {
    "country": "PL",
    "name": "Zakopane",
    "lat": "49.29899",
    "lng": "19.94885"
  },
  {
    "country": "PL",
    "name": "Zagrodno",
    "lat": "51.19134",
    "lng": "15.86533"
  },
  {
    "country": "PL",
    "name": "Zagórze",
    "lat": "50.09449",
    "lng": "19.40357"
  },
  {
    "country": "PL",
    "name": "Zagórów",
    "lat": "52.16835",
    "lng": "17.89561"
  },
  {
    "country": "PL",
    "name": "Zagórnik",
    "lat": "49.8371",
    "lng": "19.37868"
  },
  {
    "country": "PL",
    "name": "Żagań",
    "lat": "51.61759",
    "lng": "15.31486"
  },
  {
    "country": "PL",
    "name": "Zadzim",
    "lat": "51.77666",
    "lng": "18.84928"
  },
  {
    "country": "PL",
    "name": "Zabrzeg",
    "lat": "49.91619",
    "lng": "18.94292"
  },
  {
    "country": "PL",
    "name": "Zabrze",
    "lat": "50.32492",
    "lng": "18.78576"
  },
  {
    "country": "PL",
    "name": "Zaborze",
    "lat": "50.02175",
    "lng": "19.24067"
  },
  {
    "country": "PL",
    "name": "Zaborze",
    "lat": "49.87279",
    "lng": "18.8037"
  },
  {
    "country": "PL",
    "name": "Zabór",
    "lat": "51.95194",
    "lng": "15.71676"
  },
  {
    "country": "PL",
    "name": "Żabnica",
    "lat": "49.58139",
    "lng": "19.15621"
  },
  {
    "country": "PL",
    "name": "Zabłocie",
    "lat": "49.90282",
    "lng": "18.78147"
  },
  {
    "country": "PL",
    "name": "Ząbkowice Śląskie",
    "lat": "50.58969",
    "lng": "16.81239"
  },
  {
    "country": "PL",
    "name": "Zabierzów",
    "lat": "50.11425",
    "lng": "19.79788"
  },
  {
    "country": "PL",
    "name": "Wysoka",
    "lat": "53.18091",
    "lng": "17.08353"
  },
  {
    "country": "PL",
    "name": "Wysoka",
    "lat": "50.42989",
    "lng": "19.35368"
  },
  {
    "country": "PL",
    "name": "Wysoka",
    "lat": "49.90713",
    "lng": "19.60356"
  },
  {
    "country": "PL",
    "name": "Wyrzysk",
    "lat": "53.153",
    "lng": "17.26802"
  },
  {
    "country": "PL",
    "name": "Wyry",
    "lat": "50.13296",
    "lng": "18.90052"
  },
  {
    "country": "PL",
    "name": "Wymiarki",
    "lat": "51.51109",
    "lng": "15.08208"
  },
  {
    "country": "PL",
    "name": "Wschowa",
    "lat": "51.80705",
    "lng": "16.31663"
  },
  {
    "country": "PL",
    "name": "Września",
    "lat": "52.32512",
    "lng": "17.56519"
  },
  {
    "country": "PL",
    "name": "Wrząsowice",
    "lat": "49.95862",
    "lng": "19.94654"
  },
  {
    "country": "PL",
    "name": "Wronki",
    "lat": "52.71051",
    "lng": "16.38044"
  },
  {
    "country": "PL",
    "name": "Wrocław",
    "lat": "51.1",
    "lng": "17.03333"
  },
  {
    "country": "PL",
    "name": "Wróblew",
    "lat": "51.61215",
    "lng": "18.61487"
  },
  {
    "country": "PL",
    "name": "Wręczyca Wielka",
    "lat": "50.84589",
    "lng": "18.92086"
  },
  {
    "country": "PL",
    "name": "Wożniki",
    "lat": "50.58934",
    "lng": "19.05991"
  },
  {
    "country": "PL",
    "name": "Woźniki",
    "lat": "49.93774",
    "lng": "19.49078"
  },
  {
    "country": "PL",
    "name": "Wolsztyn",
    "lat": "52.11552",
    "lng": "16.11712"
  },
  {
    "country": "PL",
    "name": "Wołowice",
    "lat": "49.98876",
    "lng": "19.7263"
  },
  {
    "country": "PL",
    "name": "Wołów",
    "lat": "51.33656",
    "lng": "16.64429"
  },
  {
    "country": "PL",
    "name": "Wolin",
    "lat": "53.84214",
    "lng": "14.61465"
  },
  {
    "country": "PL",
    "name": "Wołczyn",
    "lat": "51.01845",
    "lng": "18.04994"
  },
  {
    "country": "PL",
    "name": "Wolbrom",
    "lat": "50.37957",
    "lng": "19.75831"
  },
  {
    "country": "PL",
    "name": "Wolbórz",
    "lat": "51.50196",
    "lng": "19.83049"
  },
  {
    "country": "PL",
    "name": "Wola Radziszowska",
    "lat": "49.90558",
    "lng": "19.78827"
  },
  {
    "country": "PL",
    "name": "Wola Krzysztoporska",
    "lat": "51.34418",
    "lng": "19.5809"
  },
  {
    "country": "PL",
    "name": "Wola Filipowska",
    "lat": "50.13433",
    "lng": "19.58013"
  },
  {
    "country": "PL",
    "name": "Wola",
    "lat": "50.01745",
    "lng": "19.12333"
  },
  {
    "country": "PL",
    "name": "Wojkowice",
    "lat": "50.36509",
    "lng": "19.03652"
  },
  {
    "country": "PL",
    "name": "Wojcieszów",
    "lat": "50.95194",
    "lng": "15.92185"
  },
  {
    "country": "PL",
    "name": "Wodzisław Śląski",
    "lat": "50.00377",
    "lng": "18.47205"
  },
  {
    "country": "PL",
    "name": "Wodzierady",
    "lat": "51.71826",
    "lng": "19.15123"
  },
  {
    "country": "PL",
    "name": "Włoszczowa",
    "lat": "50.85256",
    "lng": "19.96593"
  },
  {
    "country": "PL",
    "name": "Włoszakowice",
    "lat": "51.92754",
    "lng": "16.36456"
  },
  {
    "country": "PL",
    "name": "Włosienica",
    "lat": "50.01822",
    "lng": "19.31671"
  },
  {
    "country": "PL",
    "name": "Włodowice",
    "lat": "50.5556",
    "lng": "19.45155"
  },
  {
    "country": "PL",
    "name": "Włocławek",
    "lat": "52.64817",
    "lng": "19.0678"
  },
  {
    "country": "PL",
    "name": "Wleń",
    "lat": "51.01635",
    "lng": "15.67474"
  },
  {
    "country": "PL",
    "name": "Władysławowo",
    "lat": "54.79086",
    "lng": "18.4009"
  },
  {
    "country": "PL",
    "name": "Władysławów",
    "lat": "52.10313",
    "lng": "18.47626"
  },
  {
    "country": "PL",
    "name": "Witonia",
    "lat": "52.14655",
    "lng": "19.30049"
  },
  {
    "country": "PL",
    "name": "Witnica",
    "lat": "52.67318",
    "lng": "14.89765"
  },
  {
    "country": "PL",
    "name": "Witkowo",
    "lat": "52.43964",
    "lng": "17.77264"
  },
  {
    "country": "PL",
    "name": "Witkowice",
    "lat": "49.90746",
    "lng": "19.27963"
  },
  {
    "country": "PL",
    "name": "Witaszyce",
    "lat": "51.94151",
    "lng": "17.56182"
  },
  {
    "country": "PL",
    "name": "Witanowice",
    "lat": "49.91796",
    "lng": "19.52579"
  },
  {
    "country": "PL",
    "name": "Wisła",
    "lat": "49.65629",
    "lng": "18.8591"
  },
  {
    "country": "PL",
    "name": "Wińsko",
    "lat": "51.47032",
    "lng": "16.6139"
  },
  {
    "country": "PL",
    "name": "Wilkowice",
    "lat": "51.88513",
    "lng": "16.53417"
  },
  {
    "country": "PL",
    "name": "Wilkowice",
    "lat": "49.76282",
    "lng": "19.08973"
  },
  {
    "country": "PL",
    "name": "Wilków",
    "lat": "51.10158",
    "lng": "17.66284"
  },
  {
    "country": "PL",
    "name": "Wilków",
    "lat": "51.09212",
    "lng": "15.92824"
  },
  {
    "country": "PL",
    "name": "Wilczyn",
    "lat": "52.48816",
    "lng": "18.16126"
  },
  {
    "country": "PL",
    "name": "Wilczogóra",
    "lat": "52.47348",
    "lng": "18.16744"
  },
  {
    "country": "PL",
    "name": "Wilcza",
    "lat": "50.18899",
    "lng": "18.59668"
  },
  {
    "country": "PL",
    "name": "Wilamowice",
    "lat": "49.91701",
    "lng": "19.15237"
  },
  {
    "country": "PL",
    "name": "Wijewo",
    "lat": "51.91627",
    "lng": "16.18552"
  },
  {
    "country": "PL",
    "name": "Wieszowa",
    "lat": "50.38444",
    "lng": "18.75924"
  },
  {
    "country": "PL",
    "name": "Wierzchucino",
    "lat": "54.78797",
    "lng": "18.00307"
  },
  {
    "country": "PL",
    "name": "Wierzchowo",
    "lat": "53.46013",
    "lng": "16.09961"
  },
  {
    "country": "PL",
    "name": "Wierzchosławice",
    "lat": "52.86923",
    "lng": "18.35609"
  },
  {
    "country": "PL",
    "name": "Wierzchlas",
    "lat": "51.20457",
    "lng": "18.66543"
  },
  {
    "country": "PL",
    "name": "Wierzbno",
    "lat": "50.93674",
    "lng": "17.17961"
  },
  {
    "country": "PL",
    "name": "Wierzbinek",
    "lat": "52.44026",
    "lng": "18.51085"
  },
  {
    "country": "PL",
    "name": "Wieruszów",
    "lat": "51.29488",
    "lng": "18.15547"
  },
  {
    "country": "PL",
    "name": "Wieprz",
    "lat": "49.89093",
    "lng": "19.35688"
  },
  {
    "country": "PL",
    "name": "Wieprz",
    "lat": "49.64746",
    "lng": "19.18007"
  },
  {
    "country": "PL",
    "name": "Wieluń",
    "lat": "51.22097",
    "lng": "18.56964"
  },
  {
    "country": "PL",
    "name": "Wielowieś",
    "lat": "50.50966",
    "lng": "18.61608"
  },
  {
    "country": "PL",
    "name": "Wielka Wieś",
    "lat": "50.15694",
    "lng": "19.84363"
  },
  {
    "country": "PL",
    "name": "Wielka Nieszawka",
    "lat": "52.99619",
    "lng": "18.50973"
  },
  {
    "country": "PL",
    "name": "Wielichowo",
    "lat": "52.11573",
    "lng": "16.3518"
  },
  {
    "country": "PL",
    "name": "Wielgie",
    "lat": "52.74076",
    "lng": "19.2635"
  },
  {
    "country": "PL",
    "name": "Wieleń",
    "lat": "52.89461",
    "lng": "16.17136"
  },
  {
    "country": "PL",
    "name": "Większyce",
    "lat": "50.33659",
    "lng": "18.10221"
  },
  {
    "country": "PL",
    "name": "Więcbork",
    "lat": "53.35384",
    "lng": "17.49064"
  },
  {
    "country": "PL",
    "name": "Widuchowa",
    "lat": "53.12693",
    "lng": "14.39074"
  },
  {
    "country": "PL",
    "name": "Widawa",
    "lat": "51.43855",
    "lng": "18.94421"
  },
  {
    "country": "PL",
    "name": "Wiązów",
    "lat": "50.81399",
    "lng": "17.20214"
  },
  {
    "country": "PL",
    "name": "Wejherowo",
    "lat": "54.60568",
    "lng": "18.23559"
  },
  {
    "country": "PL",
    "name": "Węgry",
    "lat": "50.74319",
    "lng": "18.01741"
  },
  {
    "country": "PL",
    "name": "Węgorzyno",
    "lat": "53.54101",
    "lng": "15.55964"
  },
  {
    "country": "PL",
    "name": "Węgliniec",
    "lat": "51.28753",
    "lng": "15.22894"
  },
  {
    "country": "PL",
    "name": "Węgierska Górka",
    "lat": "49.60776",
    "lng": "19.11638"
  },
  {
    "country": "PL",
    "name": "Wąsosz",
    "lat": "51.56224",
    "lng": "16.69059"
  },
  {
    "country": "PL",
    "name": "Wartkowice",
    "lat": "51.97626",
    "lng": "19.0018"
  },
  {
    "country": "PL",
    "name": "Warta",
    "lat": "51.71049",
    "lng": "18.62483"
  },
  {
    "country": "PL",
    "name": "Warnice",
    "lat": "53.25376",
    "lng": "14.99402"
  },
  {
    "country": "PL",
    "name": "Warlubie",
    "lat": "53.58751",
    "lng": "18.63444"
  },
  {
    "country": "PL",
    "name": "Wapno",
    "lat": "52.90804",
    "lng": "17.47504"
  },
  {
    "country": "PL",
    "name": "Wąpielsk",
    "lat": "53.13761",
    "lng": "19.27792"
  },
  {
    "country": "PL",
    "name": "Walim",
    "lat": "50.69749",
    "lng": "16.44482"
  },
  {
    "country": "PL",
    "name": "Walichnowy",
    "lat": "51.29579",
    "lng": "18.38073"
  },
  {
    "country": "PL",
    "name": "Wałcz",
    "lat": "53.27787",
    "lng": "16.47122"
  },
  {
    "country": "PL",
    "name": "Walce",
    "lat": "50.37322",
    "lng": "18.00427"
  },
  {
    "country": "PL",
    "name": "Wałbrzych",
    "lat": "50.77141",
    "lng": "16.28432"
  },
  {
    "country": "PL",
    "name": "Wągrowiec",
    "lat": "52.80842",
    "lng": "17.19961"
  },
  {
    "country": "PL",
    "name": "Waganiec",
    "lat": "52.8012",
    "lng": "18.87589"
  },
  {
    "country": "PL",
    "name": "Wadowice",
    "lat": "49.88335",
    "lng": "19.49292"
  },
  {
    "country": "PL",
    "name": "Wąbrzeźno",
    "lat": "53.27989",
    "lng": "18.94773"
  },
  {
    "country": "PL",
    "name": "Ustronie Morskie",
    "lat": "54.21517",
    "lng": "15.75568"
  },
  {
    "country": "PL",
    "name": "Ustroń",
    "lat": "49.72153",
    "lng": "18.80198"
  },
  {
    "country": "PL",
    "name": "Ustka",
    "lat": "54.58048",
    "lng": "16.86194"
  },
  {
    "country": "PL",
    "name": "Unisław",
    "lat": "53.21241",
    "lng": "18.38622"
  },
  {
    "country": "PL",
    "name": "Uniejów",
    "lat": "51.97428",
    "lng": "18.79308"
  },
  {
    "country": "PL",
    "name": "Ujsoły",
    "lat": "49.4829",
    "lng": "19.13801"
  },
  {
    "country": "PL",
    "name": "Ujście",
    "lat": "53.05339",
    "lng": "16.73201"
  },
  {
    "country": "PL",
    "name": "Ujazd",
    "lat": "51.59781",
    "lng": "19.92225"
  },
  {
    "country": "PL",
    "name": "Ujazd",
    "lat": "50.38938",
    "lng": "18.34929"
  },
  {
    "country": "PL",
    "name": "Udanin",
    "lat": "51.0374",
    "lng": "16.45469"
  },
  {
    "country": "PL",
    "name": "Uciechów",
    "lat": "50.75487",
    "lng": "16.68175"
  },
  {
    "country": "PL",
    "name": "Tyniec Mały",
    "lat": "51.01948",
    "lng": "16.91998"
  },
  {
    "country": "PL",
    "name": "Tychy",
    "lat": "50.13717",
    "lng": "18.96641"
  },
  {
    "country": "PL",
    "name": "Tychowo",
    "lat": "53.92774",
    "lng": "16.25771"
  },
  {
    "country": "PL",
    "name": "Tworóg",
    "lat": "50.531",
    "lng": "18.71572"
  },
  {
    "country": "PL",
    "name": "Tworków",
    "lat": "50.00559",
    "lng": "18.23576"
  },
  {
    "country": "PL",
    "name": "Twardogóra",
    "lat": "51.36487",
    "lng": "17.46878"
  },
  {
    "country": "PL",
    "name": "Twardawa",
    "lat": "50.34349",
    "lng": "17.99097"
  },
  {
    "country": "PL",
    "name": "Tuszyn",
    "lat": "51.60949",
    "lng": "19.53009"
  },
  {
    "country": "PL",
    "name": "Turza Śląska",
    "lat": "49.97231",
    "lng": "18.43781"
  },
  {
    "country": "PL",
    "name": "Turek",
    "lat": "52.01548",
    "lng": "18.50055"
  },
  {
    "country": "PL",
    "name": "Tuplice",
    "lat": "51.67639",
    "lng": "14.82914"
  },
  {
    "country": "PL",
    "name": "Tułowice",
    "lat": "50.59577",
    "lng": "17.65323"
  },
  {
    "country": "PL",
    "name": "Tuliszków",
    "lat": "52.07658",
    "lng": "18.29549"
  },
  {
    "country": "PL",
    "name": "Tuczno",
    "lat": "53.19374",
    "lng": "16.15368"
  },
  {
    "country": "PL",
    "name": "Tuchomie",
    "lat": "54.11522",
    "lng": "17.33634"
  },
  {
    "country": "PL",
    "name": "Tuchola",
    "lat": "53.58792",
    "lng": "17.85905"
  },
  {
    "country": "PL",
    "name": "Trzemeszno",
    "lat": "52.56139",
    "lng": "17.82311"
  },
  {
    "country": "PL",
    "name": "Trzebunia",
    "lat": "49.79146",
    "lng": "19.84715"
  },
  {
    "country": "PL",
    "name": "Trzebnica",
    "lat": "51.31076",
    "lng": "17.06331"
  },
  {
    "country": "PL",
    "name": "Trzebinia",
    "lat": "50.15931",
    "lng": "19.46966"
  },
  {
    "country": "PL",
    "name": "Trzebinia",
    "lat": "49.65024",
    "lng": "19.22264"
  },
  {
    "country": "PL",
    "name": "Trzebielino",
    "lat": "54.19996",
    "lng": "17.08726"
  },
  {
    "country": "PL",
    "name": "Trzebiel",
    "lat": "51.63496",
    "lng": "14.81609"
  },
  {
    "country": "PL",
    "name": "Trzebiechów",
    "lat": "52.02113",
    "lng": "15.7362"
  },
  {
    "country": "PL",
    "name": "Trzebiatów",
    "lat": "54.06147",
    "lng": "15.26475"
  },
  {
    "country": "PL",
    "name": "Trzcińsko Zdrój",
    "lat": "52.96487",
    "lng": "14.60667"
  },
  {
    "country": "PL",
    "name": "Trzcinica",
    "lat": "51.16707",
    "lng": "18.00453"
  },
  {
    "country": "PL",
    "name": "Trzciel",
    "lat": "52.36504",
    "lng": "15.87306"
  },
  {
    "country": "PL",
    "name": "Trzcianka",
    "lat": "53.04063",
    "lng": "16.45629"
  },
  {
    "country": "PL",
    "name": "Truskolasy",
    "lat": "50.86692",
    "lng": "18.82705"
  },
  {
    "country": "PL",
    "name": "Trąbki Wielkie",
    "lat": "54.17062",
    "lng": "18.54003"
  },
  {
    "country": "PL",
    "name": "Toszek",
    "lat": "50.45442",
    "lng": "18.52209"
  },
  {
    "country": "PL",
    "name": "Torzym",
    "lat": "52.31331",
    "lng": "15.08243"
  },
  {
    "country": "PL",
    "name": "Toruń",
    "lat": "53.01375",
    "lng": "18.59814"
  },
  {
    "country": "PL",
    "name": "Toporzysko",
    "lat": "49.62495",
    "lng": "19.80226"
  },
  {
    "country": "PL",
    "name": "Topólka",
    "lat": "52.50327",
    "lng": "18.71246"
  },
  {
    "country": "PL",
    "name": "Tomice",
    "lat": "49.89773",
    "lng": "19.48357"
  },
  {
    "country": "PL",
    "name": "Tolkmicko",
    "lat": "54.32038",
    "lng": "19.52695"
  },
  {
    "country": "PL",
    "name": "Tokarnia",
    "lat": "49.7272",
    "lng": "19.87161"
  },
  {
    "country": "PL",
    "name": "Tłuchowo",
    "lat": "52.74715",
    "lng": "19.46563"
  },
  {
    "country": "PL",
    "name": "Tenczynek",
    "lat": "50.11986",
    "lng": "19.61308"
  },
  {
    "country": "PL",
    "name": "Tczew",
    "lat": "54.09242",
    "lng": "18.77787"
  },
  {
    "country": "PL",
    "name": "Tarnowskie Góry",
    "lat": "50.44548",
    "lng": "18.86147"
  },
  {
    "country": "PL",
    "name": "Tarnów Opolski",
    "lat": "50.57631",
    "lng": "18.08367"
  },
  {
    "country": "PL",
    "name": "Tarnowo Podgórne",
    "lat": "52.46642",
    "lng": "16.66326"
  },
  {
    "country": "PL",
    "name": "Tarnówka",
    "lat": "53.34174",
    "lng": "16.85273"
  },
  {
    "country": "PL",
    "name": "Targanice",
    "lat": "49.80575",
    "lng": "19.32444"
  },
  {
    "country": "PL",
    "name": "Szydłowo",
    "lat": "53.16212",
    "lng": "16.61171"
  },
  {
    "country": "PL",
    "name": "Szubin",
    "lat": "53.00967",
    "lng": "17.74"
  },
  {
    "country": "PL",
    "name": "Sztum",
    "lat": "53.92077",
    "lng": "19.03072"
  },
  {
    "country": "PL",
    "name": "Szprotawa",
    "lat": "51.56563",
    "lng": "15.53664"
  },
  {
    "country": "PL",
    "name": "Szlichtyngowa",
    "lat": "51.71222",
    "lng": "16.24427"
  },
  {
    "country": "PL",
    "name": "Szlachta",
    "lat": "53.76827",
    "lng": "18.11367"
  },
  {
    "country": "PL",
    "name": "Szklarska Poręba",
    "lat": "50.82567",
    "lng": "15.52274"
  },
  {
    "country": "PL",
    "name": "Szemud",
    "lat": "54.48709",
    "lng": "18.2228"
  },
  {
    "country": "PL",
    "name": "Szczytna",
    "lat": "50.41343",
    "lng": "16.44743"
  },
  {
    "country": "PL",
    "name": "Szczyrk",
    "lat": "49.71724",
    "lng": "19.03183"
  },
  {
    "country": "PL",
    "name": "Szczutowo",
    "lat": "52.94047",
    "lng": "19.57438"
  },
  {
    "country": "PL",
    "name": "Szczerców",
    "lat": "51.33319",
    "lng": "19.10977"
  },
  {
    "country": "PL",
    "name": "Szczepanów",
    "lat": "51.19796",
    "lng": "16.61064"
  },
  {
    "country": "PL",
    "name": "Szczekociny",
    "lat": "50.62669",
    "lng": "19.825"
  },
  {
    "country": "PL",
    "name": "Szczecinek",
    "lat": "53.70791",
    "lng": "16.69937"
  },
  {
    "country": "PL",
    "name": "Szczecin",
    "lat": "53.42894",
    "lng": "14.55302"
  },
  {
    "country": "PL",
    "name": "Szczawno-Zdrój",
    "lat": "50.80352",
    "lng": "16.25655"
  },
  {
    "country": "PL",
    "name": "Szczaniec",
    "lat": "52.26874",
    "lng": "15.6817"
  },
  {
    "country": "PL",
    "name": "Szamotuły",
    "lat": "52.61201",
    "lng": "16.57794"
  },
  {
    "country": "PL",
    "name": "Szamocin",
    "lat": "53.02795",
    "lng": "17.12653"
  },
  {
    "country": "PL",
    "name": "Szadek",
    "lat": "51.69174",
    "lng": "18.97549"
  },
  {
    "country": "PL",
    "name": "Syrynia",
    "lat": "50.02004",
    "lng": "18.34597"
  },
  {
    "country": "PL",
    "name": "Sypniewo",
    "lat": "53.46823",
    "lng": "16.60583"
  },
  {
    "country": "PL",
    "name": "Sypniewo",
    "lat": "53.36981",
    "lng": "17.3269"
  },
  {
    "country": "PL",
    "name": "Syców",
    "lat": "51.30814",
    "lng": "17.71979"
  },
  {
    "country": "PL",
    "name": "Świnoujście",
    "lat": "53.91053",
    "lng": "14.24712"
  },
  {
    "country": "PL",
    "name": "Świnna",
    "lat": "49.65802",
    "lng": "19.25406"
  },
  {
    "country": "PL",
    "name": "Świnice Warckie",
    "lat": "52.04072",
    "lng": "18.91786"
  },
  {
    "country": "PL",
    "name": "Świętochłowice",
    "lat": "50.29636",
    "lng": "18.91726"
  },
  {
    "country": "PL",
    "name": "Święta Katarzyna",
    "lat": "51.02596",
    "lng": "17.11464"
  },
  {
    "country": "PL",
    "name": "Świerzno",
    "lat": "53.96497",
    "lng": "14.96544"
  },
  {
    "country": "PL",
    "name": "Świerzawa",
    "lat": "51.01375",
    "lng": "15.89516"
  },
  {
    "country": "PL",
    "name": "Świerklany Górne",
    "lat": "50.02765",
    "lng": "18.5905"
  },
  {
    "country": "PL",
    "name": "Świerklany Dolne",
    "lat": "50.01827",
    "lng": "18.57702"
  },
  {
    "country": "PL",
    "name": "Świerklaniec",
    "lat": "50.44237",
    "lng": "18.93734"
  },
  {
    "country": "PL",
    "name": "Świerczów",
    "lat": "50.96016",
    "lng": "17.7588"
  },
  {
    "country": "PL",
    "name": "Świeradów-Zdrój",
    "lat": "50.9092",
    "lng": "15.34309"
  },
  {
    "country": "PL",
    "name": "Świekatowo",
    "lat": "53.41864",
    "lng": "18.09731"
  },
  {
    "country": "PL",
    "name": "Świedziebnia",
    "lat": "53.15207",
    "lng": "19.55463"
  },
  {
    "country": "PL",
    "name": "Świebodzin",
    "lat": "52.24751",
    "lng": "15.53355"
  },
  {
    "country": "PL",
    "name": "Świecie nad Osą",
    "lat": "53.444",
    "lng": "19.10171"
  },
  {
    "country": "PL",
    "name": "Święciechowa",
    "lat": "51.85503",
    "lng": "16.49805"
  },
  {
    "country": "PL",
    "name": "Świecie",
    "lat": "53.40953",
    "lng": "18.44742"
  },
  {
    "country": "PL",
    "name": "Świebodzice",
    "lat": "50.85975",
    "lng": "16.3282"
  },
  {
    "country": "PL",
    "name": "Świdwin",
    "lat": "53.77464",
    "lng": "15.77671"
  },
  {
    "country": "PL",
    "name": "Świdnica",
    "lat": "51.88836",
    "lng": "15.39013"
  },
  {
    "country": "PL",
    "name": "Świdnica",
    "lat": "50.84378",
    "lng": "16.48859"
  },
  {
    "country": "PL",
    "name": "Świątniki Górne",
    "lat": "49.93429",
    "lng": "19.95364"
  },
  {
    "country": "PL",
    "name": "Swarzędz",
    "lat": "52.41289",
    "lng": "17.08503"
  },
  {
    "country": "PL",
    "name": "Suszec",
    "lat": "50.02958",
    "lng": "18.7916"
  },
  {
    "country": "PL",
    "name": "Susz",
    "lat": "53.71743",
    "lng": "19.33645"
  },
  {
    "country": "PL",
    "name": "Sułów",
    "lat": "51.49966",
    "lng": "17.16811"
  },
  {
    "country": "PL",
    "name": "Sułoszowa",
    "lat": "50.26789",
    "lng": "19.73282"
  },
  {
    "country": "PL",
    "name": "Sulmierzyce",
    "lat": "51.60594",
    "lng": "17.53053"
  },
  {
    "country": "PL",
    "name": "Sulmierzyce",
    "lat": "51.18456",
    "lng": "19.19595"
  },
  {
    "country": "PL",
    "name": "Sułkowice",
    "lat": "49.84053",
    "lng": "19.80097"
  },
  {
    "country": "PL",
    "name": "Sułkowice",
    "lat": "49.81932",
    "lng": "19.35988"
  },
  {
    "country": "PL",
    "name": "Borne Sulinowo",
    "lat": "53.57661",
    "lng": "16.53395"
  },
  {
    "country": "PL",
    "name": "Sulików",
    "lat": "51.07624",
    "lng": "15.06792"
  },
  {
    "country": "PL",
    "name": "Sulejów",
    "lat": "51.35436",
    "lng": "19.88538"
  },
  {
    "country": "PL",
    "name": "Sulęczyno",
    "lat": "54.23302",
    "lng": "17.7733"
  },
  {
    "country": "PL",
    "name": "Sulęcin",
    "lat": "52.44429",
    "lng": "15.11676"
  },
  {
    "country": "PL",
    "name": "Sulechów",
    "lat": "52.08362",
    "lng": "15.62513"
  },
  {
    "country": "PL",
    "name": "Suchy Las",
    "lat": "52.47308",
    "lng": "16.87745"
  },
  {
    "country": "PL",
    "name": "Suchy Dąb",
    "lat": "54.20809",
    "lng": "18.76731"
  },
  {
    "country": "PL",
    "name": "Suchań",
    "lat": "53.28003",
    "lng": "15.32541"
  },
  {
    "country": "PL",
    "name": "Sucha Beskidzka",
    "lat": "49.74188",
    "lng": "19.59429"
  },
  {
    "country": "PL",
    "name": "Subkowy",
    "lat": "54.00227",
    "lng": "18.76928"
  },
  {
    "country": "PL",
    "name": "Studzionka",
    "lat": "49.96232",
    "lng": "18.7728"
  },
  {
    "country": "PL",
    "name": "Studzienice",
    "lat": "54.09262",
    "lng": "17.57581"
  },
  {
    "country": "PL",
    "name": "Strzyżowice",
    "lat": "50.38725",
    "lng": "19.08038"
  },
  {
    "country": "PL",
    "name": "Strzelno",
    "lat": "54.78564",
    "lng": "18.32515"
  },
  {
    "country": "PL",
    "name": "Strzelno",
    "lat": "52.62789",
    "lng": "18.17246"
  },
  {
    "country": "PL",
    "name": "Strzelin",
    "lat": "50.78157",
    "lng": "17.06477"
  },
  {
    "country": "PL",
    "name": "Strzeleczki",
    "lat": "50.46215",
    "lng": "17.85665"
  },
  {
    "country": "PL",
    "name": "Strzelce Wielkie",
    "lat": "51.1394",
    "lng": "19.14539"
  },
  {
    "country": "PL",
    "name": "Strzelce Opolskie",
    "lat": "50.5107",
    "lng": "18.30056"
  },
  {
    "country": "PL",
    "name": "Strzelce Krajeńskie",
    "lat": "52.87726",
    "lng": "15.52978"
  },
  {
    "country": "PL",
    "name": "Strzelce",
    "lat": "52.31478",
    "lng": "19.40701"
  },
  {
    "country": "PL",
    "name": "Strzegom",
    "lat": "50.96264",
    "lng": "16.35006"
  },
  {
    "country": "PL",
    "name": "Strzebiń",
    "lat": "50.61647",
    "lng": "18.89794"
  },
  {
    "country": "PL",
    "name": "Strzałkowo",
    "lat": "52.30701",
    "lng": "17.81811"
  },
  {
    "country": "PL",
    "name": "Stryszów",
    "lat": "49.82569",
    "lng": "19.61763"
  },
  {
    "country": "PL",
    "name": "Stryszawa",
    "lat": "49.71327",
    "lng": "19.52185"
  },
  {
    "country": "PL",
    "name": "Stryków",
    "lat": "51.90224",
    "lng": "19.60536"
  },
  {
    "country": "PL",
    "name": "Strumień",
    "lat": "49.92103",
    "lng": "18.76637"
  },
  {
    "country": "PL",
    "name": "Stróża",
    "lat": "49.79628",
    "lng": "19.92379"
  },
  {
    "country": "PL",
    "name": "Stronie Śląskie",
    "lat": "50.29554",
    "lng": "16.87397"
  },
  {
    "country": "PL",
    "name": "Stronie",
    "lat": "49.83056",
    "lng": "19.67497"
  },
  {
    "country": "PL",
    "name": "Straszyn",
    "lat": "54.27214",
    "lng": "18.58114"
  },
  {
    "country": "PL",
    "name": "Stoszowice",
    "lat": "50.59986",
    "lng": "16.73896"
  },
  {
    "country": "PL",
    "name": "Stężyca",
    "lat": "54.20593",
    "lng": "17.95569"
  },
  {
    "country": "PL",
    "name": "Stęszew",
    "lat": "52.2837",
    "lng": "16.70085"
  },
  {
    "country": "PL",
    "name": "Stepnica",
    "lat": "53.65187",
    "lng": "14.62555"
  },
  {
    "country": "PL",
    "name": "Stegna",
    "lat": "54.32684",
    "lng": "19.11252"
  },
  {
    "country": "PL",
    "name": "Stawiszyn",
    "lat": "51.91786",
    "lng": "18.11171"
  },
  {
    "country": "PL",
    "name": "Stary Targ",
    "lat": "53.92335",
    "lng": "19.17003"
  },
  {
    "country": "PL",
    "name": "Staroźreby",
    "lat": "52.63265",
    "lng": "19.9855"
  },
  {
    "country": "PL",
    "name": "Starowa Góra",
    "lat": "51.69134",
    "lng": "19.48374"
  },
  {
    "country": "PL",
    "name": "Starokrzepice",
    "lat": "50.94859",
    "lng": "18.65341"
  },
  {
    "country": "PL",
    "name": "Starogard Gdański",
    "lat": "53.96396",
    "lng": "18.52638"
  },
  {
    "country": "PL",
    "name": "Stargard",
    "lat": "53.33672",
    "lng": "15.0499"
  },
  {
    "country": "PL",
    "name": "Stare Pole",
    "lat": "54.05667",
    "lng": "19.20874"
  },
  {
    "country": "PL",
    "name": "Stare Miasto",
    "lat": "52.17972",
    "lng": "18.21499"
  },
  {
    "country": "PL",
    "name": "Stare Kurowo",
    "lat": "52.85669",
    "lng": "15.67749"
  },
  {
    "country": "PL",
    "name": "Stare Czarnowo",
    "lat": "53.27861",
    "lng": "14.77906"
  },
  {
    "country": "PL",
    "name": "Stare Bogaczowice",
    "lat": "50.84752",
    "lng": "16.19308"
  },
  {
    "country": "PL",
    "name": "Starcza",
    "lat": "50.66421",
    "lng": "19.0418"
  },
  {
    "country": "PL",
    "name": "Stara Kiszewa",
    "lat": "53.99006",
    "lng": "18.16958"
  },
  {
    "country": "PL",
    "name": "Stara Kamienica",
    "lat": "50.91602",
    "lng": "15.57286"
  },
  {
    "country": "PL",
    "name": "Stara Dąbrowa",
    "lat": "53.42191",
    "lng": "15.14405"
  },
  {
    "country": "PL",
    "name": "Stanowice",
    "lat": "50.93106",
    "lng": "16.37426"
  },
  {
    "country": "PL",
    "name": "Stanowice",
    "lat": "50.13037",
    "lng": "18.67084"
  },
  {
    "country": "PL",
    "name": "Stanisław Górny",
    "lat": "49.91155",
    "lng": "19.62931"
  },
  {
    "country": "PL",
    "name": "Stanisław Dolny",
    "lat": "49.9047",
    "lng": "19.65334"
  },
  {
    "country": "PL",
    "name": "Środa Wielkopolska",
    "lat": "52.22843",
    "lng": "17.27617"
  },
  {
    "country": "PL",
    "name": "Środa Śląska",
    "lat": "51.16406",
    "lng": "16.59508"
  },
  {
    "country": "PL",
    "name": "Śrem",
    "lat": "52.08868",
    "lng": "17.01508"
  },
  {
    "country": "PL",
    "name": "Spytkowice",
    "lat": "49.99671",
    "lng": "19.51103"
  },
  {
    "country": "PL",
    "name": "Spytkowice",
    "lat": "49.57744",
    "lng": "19.83341"
  },
  {
    "country": "PL",
    "name": "Sosnówka",
    "lat": "50.8183",
    "lng": "15.72315"
  },
  {
    "country": "PL",
    "name": "Sosnowiec",
    "lat": "50.28682",
    "lng": "19.10385"
  },
  {
    "country": "PL",
    "name": "Sosnowice",
    "lat": "49.93995",
    "lng": "19.71514"
  },
  {
    "country": "PL",
    "name": "Sośno",
    "lat": "53.38922",
    "lng": "17.68713"
  },
  {
    "country": "PL",
    "name": "Sośnie",
    "lat": "51.47315",
    "lng": "17.63383"
  },
  {
    "country": "PL",
    "name": "Sośnicowice",
    "lat": "50.27214",
    "lng": "18.52982"
  },
  {
    "country": "PL",
    "name": "Sopotnia Wielka",
    "lat": "49.56853",
    "lng": "19.28289"
  },
  {
    "country": "PL",
    "name": "Sopot",
    "lat": "54.4418",
    "lng": "18.56003"
  },
  {
    "country": "PL",
    "name": "Sompolno",
    "lat": "52.38832",
    "lng": "18.50282"
  },
  {
    "country": "PL",
    "name": "Somonino",
    "lat": "54.27555",
    "lng": "18.19885"
  },
  {
    "country": "PL",
    "name": "Solec Kujawski",
    "lat": "53.08371",
    "lng": "18.22572"
  },
  {
    "country": "PL",
    "name": "Szczerbice",
    "lat": "50.09416",
    "lng": "18.44896"
  },
  {
    "country": "PL",
    "name": "Sól",
    "lat": "49.48764",
    "lng": "19.04171"
  },
  {
    "country": "PL",
    "name": "Sokolniki",
    "lat": "51.30738",
    "lng": "18.33275"
  },
  {
    "country": "PL",
    "name": "Sobótka",
    "lat": "50.89992",
    "lng": "16.74441"
  },
  {
    "country": "PL",
    "name": "Smolec",
    "lat": "51.07322",
    "lng": "16.88221"
  },
  {
    "country": "PL",
    "name": "Smołdzino",
    "lat": "54.66318",
    "lng": "17.21369"
  },
  {
    "country": "PL",
    "name": "Śmiłowo",
    "lat": "53.13647",
    "lng": "16.92075"
  },
  {
    "country": "PL",
    "name": "Śmigiel",
    "lat": "52.01339",
    "lng": "16.52704"
  },
  {
    "country": "PL",
    "name": "Smętowo Graniczne",
    "lat": "53.74638",
    "lng": "18.68586"
  },
  {
    "country": "PL",
    "name": "Słupsk",
    "lat": "54.46405",
    "lng": "17.02872"
  },
  {
    "country": "PL",
    "name": "Słupno",
    "lat": "52.50588",
    "lng": "19.83736"
  },
  {
    "country": "PL",
    "name": "Słupia",
    "lat": "51.85518",
    "lng": "19.96997"
  },
  {
    "country": "PL",
    "name": "Słupia pod Kępnem",
    "lat": "51.23924",
    "lng": "18.04255"
  },
  {
    "country": "PL",
    "name": "Słupia",
    "lat": "50.60073",
    "lng": "19.97435"
  },
  {
    "country": "PL",
    "name": "Słupca",
    "lat": "52.28733",
    "lng": "17.87192"
  },
  {
    "country": "PL",
    "name": "Słubice",
    "lat": "52.36942",
    "lng": "19.93881"
  },
  {
    "country": "PL",
    "name": "Słubice",
    "lat": "52.35088",
    "lng": "14.56065"
  },
  {
    "country": "PL",
    "name": "Słońsk",
    "lat": "52.56345",
    "lng": "14.80526"
  },
  {
    "country": "PL",
    "name": "Śliwice",
    "lat": "53.70875",
    "lng": "18.1737"
  },
  {
    "country": "PL",
    "name": "Ślesin",
    "lat": "53.16514",
    "lng": "17.70258"
  },
  {
    "country": "PL",
    "name": "Ślesin",
    "lat": "52.37039",
    "lng": "18.30644"
  },
  {
    "country": "PL",
    "name": "Ślemień",
    "lat": "49.71826",
    "lng": "19.36735"
  },
  {
    "country": "PL",
    "name": "Sławoborze",
    "lat": "53.88992",
    "lng": "15.70667"
  },
  {
    "country": "PL",
    "name": "Sławno",
    "lat": "54.36276",
    "lng": "16.67888"
  },
  {
    "country": "PL",
    "name": "Sławków",
    "lat": "50.29943",
    "lng": "19.38967"
  },
  {
    "country": "PL",
    "name": "Sławięcice",
    "lat": "50.37207",
    "lng": "18.32176"
  },
  {
    "country": "PL",
    "name": "Sława",
    "lat": "51.87623",
    "lng": "16.07205"
  },
  {
    "country": "PL",
    "name": "Skwierzyna",
    "lat": "52.59914",
    "lng": "15.50652"
  },
  {
    "country": "PL",
    "name": "Skulsk",
    "lat": "52.482",
    "lng": "18.33112"
  },
  {
    "country": "PL",
    "name": "Skrzyszów",
    "lat": "49.94873",
    "lng": "18.48879"
  },
  {
    "country": "PL",
    "name": "Skrwilno",
    "lat": "53.01607",
    "lng": "19.62364"
  },
  {
    "country": "PL",
    "name": "Skoroszyce",
    "lat": "50.59648",
    "lng": "17.38243"
  },
  {
    "country": "PL",
    "name": "Skorogoszcz",
    "lat": "50.75916",
    "lng": "17.68198"
  },
  {
    "country": "PL",
    "name": "Skórcz",
    "lat": "53.79436",
    "lng": "18.52561"
  },
  {
    "country": "PL",
    "name": "Skomlin",
    "lat": "51.17089",
    "lng": "18.38699"
  },
  {
    "country": "PL",
    "name": "Skomielna Czarna",
    "lat": "49.72709",
    "lng": "19.83633"
  },
  {
    "country": "PL",
    "name": "Skoki",
    "lat": "52.67222",
    "lng": "17.16107"
  },
  {
    "country": "PL",
    "name": "Skoczów",
    "lat": "49.80089",
    "lng": "18.7877"
  },
  {
    "country": "PL",
    "name": "Skępe",
    "lat": "52.86798",
    "lng": "19.35604"
  },
  {
    "country": "PL",
    "name": "Skawinki",
    "lat": "49.82281",
    "lng": "19.71256"
  },
  {
    "country": "PL",
    "name": "Skawina",
    "lat": "49.97524",
    "lng": "19.82869"
  },
  {
    "country": "PL",
    "name": "Skawica",
    "lat": "49.67718",
    "lng": "19.62321"
  },
  {
    "country": "PL",
    "name": "Skarszewy",
    "lat": "54.06911",
    "lng": "18.44416"
  },
  {
    "country": "PL",
    "name": "Skąpe",
    "lat": "52.15292",
    "lng": "15.45845"
  },
  {
    "country": "PL",
    "name": "Skalmierzyce",
    "lat": "51.70097",
    "lng": "17.96333"
  },
  {
    "country": "PL",
    "name": "Skała",
    "lat": "50.23052",
    "lng": "19.85363"
  },
  {
    "country": "PL",
    "name": "Siewierz",
    "lat": "50.46657",
    "lng": "19.23028"
  },
  {
    "country": "PL",
    "name": "Sierpc",
    "lat": "52.8568",
    "lng": "19.66913"
  },
  {
    "country": "PL",
    "name": "Sieroszewice",
    "lat": "51.63347",
    "lng": "17.972"
  },
  {
    "country": "PL",
    "name": "Sierakowice",
    "lat": "54.3461",
    "lng": "17.89252"
  },
  {
    "country": "PL",
    "name": "Sieraków",
    "lat": "52.65134",
    "lng": "16.08047"
  },
  {
    "country": "PL",
    "name": "Sieraków Śląski",
    "lat": "50.8029",
    "lng": "18.57548"
  },
  {
    "country": "PL",
    "name": "Sieradz",
    "lat": "51.59584",
    "lng": "18.73023"
  },
  {
    "country": "PL",
    "name": "Siepraw",
    "lat": "49.91437",
    "lng": "19.95864"
  },
  {
    "country": "PL",
    "name": "Sieniawa Żarska",
    "lat": "51.64007",
    "lng": "15.06045"
  },
  {
    "country": "PL",
    "name": "Sieniawa",
    "lat": "52.36344",
    "lng": "15.37768"
  },
  {
    "country": "PL",
    "name": "Sieniawa",
    "lat": "49.53947",
    "lng": "19.93014"
  },
  {
    "country": "PL",
    "name": "Siemkowice",
    "lat": "51.20194",
    "lng": "18.8988"
  },
  {
    "country": "PL",
    "name": "Siemianowice Śląskie",
    "lat": "50.32738",
    "lng": "19.02901"
  },
  {
    "country": "PL",
    "name": "Siekierczyn",
    "lat": "51.12217",
    "lng": "15.19375"
  },
  {
    "country": "PL",
    "name": "Siedlisko",
    "lat": "51.76864",
    "lng": "15.81396"
  },
  {
    "country": "PL",
    "name": "Siedlec",
    "lat": "52.13781",
    "lng": "16.00279"
  },
  {
    "country": "PL",
    "name": "Siechnice",
    "lat": "51.03384",
    "lng": "17.14743"
  },
  {
    "country": "PL",
    "name": "Sidzina",
    "lat": "50.57375",
    "lng": "17.44904"
  },
  {
    "country": "PL",
    "name": "Sidzina",
    "lat": "49.98732",
    "lng": "19.87495"
  },
  {
    "country": "PL",
    "name": "Sidzina",
    "lat": "49.59146",
    "lng": "19.71119"
  },
  {
    "country": "PL",
    "name": "Sicienko",
    "lat": "53.20387",
    "lng": "17.80051"
  },
  {
    "country": "PL",
    "name": "Sianów",
    "lat": "54.22646",
    "lng": "16.29127"
  },
  {
    "country": "PL",
    "name": "Sępólno Krajeńskie",
    "lat": "53.45198",
    "lng": "17.53169"
  },
  {
    "country": "PL",
    "name": "Sędziejowice",
    "lat": "51.50677",
    "lng": "19.02763"
  },
  {
    "country": "PL",
    "name": "Secemin",
    "lat": "50.76676",
    "lng": "19.83599"
  },
  {
    "country": "PL",
    "name": "Ścinawa",
    "lat": "51.41626",
    "lng": "16.4251"
  },
  {
    "country": "PL",
    "name": "Sarnów",
    "lat": "50.3738",
    "lng": "19.15061"
  },
  {
    "country": "PL",
    "name": "Sąspów",
    "lat": "50.22887",
    "lng": "19.77007"
  },
  {
    "country": "PL",
    "name": "Santok",
    "lat": "52.73785",
    "lng": "15.41021"
  },
  {
    "country": "PL",
    "name": "Sanniki",
    "lat": "52.33046",
    "lng": "19.86766"
  },
  {
    "country": "PL",
    "name": "Sanka",
    "lat": "50.06871",
    "lng": "19.64596"
  },
  {
    "country": "PL",
    "name": "Sadlinki",
    "lat": "53.66539",
    "lng": "18.86807"
  },
  {
    "country": "PL",
    "name": "Sadki",
    "lat": "53.16036",
    "lng": "17.44912"
  },
  {
    "country": "PL",
    "name": "Sączów",
    "lat": "50.4352",
    "lng": "19.03038"
  },
  {
    "country": "PL",
    "name": "Rzyki",
    "lat": "49.81129",
    "lng": "19.39619"
  },
  {
    "country": "PL",
    "name": "Rzozów",
    "lat": "49.95398",
    "lng": "19.79668"
  },
  {
    "country": "PL",
    "name": "Rzgów Pierwszy",
    "lat": "52.15134",
    "lng": "18.04976"
  },
  {
    "country": "PL",
    "name": "Rzeszotary",
    "lat": "49.94625",
    "lng": "19.9728"
  },
  {
    "country": "PL",
    "name": "Rzepin",
    "lat": "52.3464",
    "lng": "14.83227"
  },
  {
    "country": "PL",
    "name": "Rzeczenica",
    "lat": "53.7579",
    "lng": "17.10752"
  },
  {
    "country": "PL",
    "name": "Rząska",
    "lat": "50.09713",
    "lng": "19.84509"
  },
  {
    "country": "PL",
    "name": "Rypin",
    "lat": "53.06603",
    "lng": "19.40941"
  },
  {
    "country": "PL",
    "name": "Rymań",
    "lat": "53.94391",
    "lng": "15.52866"
  },
  {
    "country": "PL",
    "name": "Ryjewo",
    "lat": "53.84463",
    "lng": "18.96077"
  },
  {
    "country": "PL",
    "name": "Rydzyna",
    "lat": "51.78651",
    "lng": "16.66761"
  },
  {
    "country": "PL",
    "name": "Rydułtowy",
    "lat": "50.05857",
    "lng": "18.41703"
  },
  {
    "country": "PL",
    "name": "Ryczywół",
    "lat": "52.81324",
    "lng": "16.83114"
  },
  {
    "country": "PL",
    "name": "Ryczów",
    "lat": "49.98103",
    "lng": "19.55017"
  },
  {
    "country": "PL",
    "name": "Rychwał",
    "lat": "52.07149",
    "lng": "18.1651"
  },
  {
    "country": "PL",
    "name": "Rychtal",
    "lat": "51.14533",
    "lng": "17.85132"
  },
  {
    "country": "PL",
    "name": "Rycerka Górna",
    "lat": "49.44436",
    "lng": "19.01596"
  },
  {
    "country": "PL",
    "name": "Rycerka Dolna",
    "lat": "49.47805",
    "lng": "19.06162"
  },
  {
    "country": "PL",
    "name": "Rybno",
    "lat": "53.38348",
    "lng": "19.93229"
  },
  {
    "country": "PL",
    "name": "Rybnik",
    "lat": "50.09713",
    "lng": "18.54179"
  },
  {
    "country": "PL",
    "name": "Rybarzowice",
    "lat": "49.72956",
    "lng": "19.10162"
  },
  {
    "country": "PL",
    "name": "Rusocice",
    "lat": "49.99604",
    "lng": "19.60648"
  },
  {
    "country": "PL",
    "name": "Rusiec",
    "lat": "51.32444",
    "lng": "18.98506"
  },
  {
    "country": "PL",
    "name": "Rumia",
    "lat": "54.57092",
    "lng": "18.38802"
  },
  {
    "country": "PL",
    "name": "Rudziniec",
    "lat": "50.35324",
    "lng": "18.40914"
  },
  {
    "country": "PL",
    "name": "Rudziczka",
    "lat": "50.03608",
    "lng": "18.76225"
  },
  {
    "country": "PL",
    "name": "Rudy",
    "lat": "50.19003",
    "lng": "18.45334"
  },
  {
    "country": "PL",
    "name": "Rudniki",
    "lat": "50.87851",
    "lng": "19.24616"
  },
  {
    "country": "PL",
    "name": "Rudniki",
    "lat": "50.52134",
    "lng": "19.4313"
  },
  {
    "country": "PL",
    "name": "Rudnik",
    "lat": "50.12729",
    "lng": "18.18598"
  },
  {
    "country": "PL",
    "name": "Rudnik",
    "lat": "49.85243",
    "lng": "19.8474"
  },
  {
    "country": "PL",
    "name": "Rudna",
    "lat": "51.50981",
    "lng": "16.26363"
  },
  {
    "country": "PL",
    "name": "Rudawa",
    "lat": "50.12151",
    "lng": "19.71239"
  },
  {
    "country": "PL",
    "name": "Ruda Śląska",
    "lat": "50.2584",
    "lng": "18.85632"
  },
  {
    "country": "PL",
    "name": "Rozwadza",
    "lat": "50.43493",
    "lng": "18.0998"
  },
  {
    "country": "PL",
    "name": "Rozprza",
    "lat": "51.30266",
    "lng": "19.6457"
  },
  {
    "country": "PL",
    "name": "Rozdrażew",
    "lat": "51.78218",
    "lng": "17.50491"
  },
  {
    "country": "PL",
    "name": "Rościszewo",
    "lat": "52.90331",
    "lng": "19.77419"
  },
  {
    "country": "PL",
    "name": "Rokitno Szlacheckie",
    "lat": "50.43195",
    "lng": "19.43293"
  },
  {
    "country": "PL",
    "name": "Rokietnica",
    "lat": "52.51245",
    "lng": "16.7457"
  },
  {
    "country": "PL",
    "name": "Rokiciny",
    "lat": "51.65078",
    "lng": "19.80191"
  },
  {
    "country": "PL",
    "name": "Rokiciny",
    "lat": "49.57243",
    "lng": "19.92302"
  },
  {
    "country": "PL",
    "name": "Rogóźno",
    "lat": "53.53587",
    "lng": "18.92859"
  },
  {
    "country": "PL",
    "name": "Rogoźno",
    "lat": "52.75226",
    "lng": "16.99049"
  },
  {
    "country": "PL",
    "name": "Rogoźnik",
    "lat": "50.39106",
    "lng": "19.03776"
  },
  {
    "country": "PL",
    "name": "Rogowo",
    "lat": "52.97712",
    "lng": "19.38486"
  },
  {
    "country": "PL",
    "name": "Rogowo",
    "lat": "52.72449",
    "lng": "17.65117"
  },
  {
    "country": "PL",
    "name": "Rogów",
    "lat": "51.81758",
    "lng": "19.88654"
  },
  {
    "country": "PL",
    "name": "Rogów",
    "lat": "49.99097",
    "lng": "18.35077"
  },
  {
    "country": "PL",
    "name": "Rogalinek",
    "lat": "52.24945",
    "lng": "16.89989"
  },
  {
    "country": "PL",
    "name": "Roczyny",
    "lat": "49.8537",
    "lng": "19.31568"
  },
  {
    "country": "PL",
    "name": "Rewal",
    "lat": "54.0812",
    "lng": "15.01471"
  },
  {
    "country": "PL",
    "name": "Resko",
    "lat": "53.77307",
    "lng": "15.40607"
  },
  {
    "country": "PL",
    "name": "Reńska Wieś",
    "lat": "50.31587",
    "lng": "18.12607"
  },
  {
    "country": "PL",
    "name": "Rekowo Dolne",
    "lat": "54.63133",
    "lng": "18.36279"
  },
  {
    "country": "PL",
    "name": "Regulice",
    "lat": "50.08314",
    "lng": "19.52785"
  },
  {
    "country": "PL",
    "name": "Rędziny",
    "lat": "50.85922",
    "lng": "19.2162"
  },
  {
    "country": "PL",
    "name": "Reda",
    "lat": "54.60528",
    "lng": "18.34717"
  },
  {
    "country": "PL",
    "name": "Ręczno",
    "lat": "51.19026",
    "lng": "19.85375"
  },
  {
    "country": "PL",
    "name": "Recz",
    "lat": "53.25989",
    "lng": "15.54713"
  },
  {
    "country": "PL",
    "name": "Rawicz",
    "lat": "51.60946",
    "lng": "16.85852"
  },
  {
    "country": "PL",
    "name": "Ratowice",
    "lat": "51.03308",
    "lng": "17.27205"
  },
  {
    "country": "PL",
    "name": "Raszowa",
    "lat": "50.39779",
    "lng": "18.17722"
  },
  {
    "country": "PL",
    "name": "Raszków",
    "lat": "51.71828",
    "lng": "17.72571"
  },
  {
    "country": "PL",
    "name": "Raszczyce",
    "lat": "50.1219",
    "lng": "18.29962"
  },
  {
    "country": "PL",
    "name": "Rakoniewice",
    "lat": "52.13906",
    "lng": "16.27346"
  },
  {
    "country": "PL",
    "name": "Rajsko",
    "lat": "50.01193",
    "lng": "19.19294"
  },
  {
    "country": "PL",
    "name": "Rajcza",
    "lat": "49.50927",
    "lng": "19.11278"
  },
  {
    "country": "PL",
    "name": "Radzyń Chełmiński",
    "lat": "53.38509",
    "lng": "18.93725"
  },
  {
    "country": "PL",
    "name": "Radziszów",
    "lat": "49.93531",
    "lng": "19.81522"
  },
  {
    "country": "PL",
    "name": "Radzionków",
    "lat": "50.40026",
    "lng": "18.90232"
  },
  {
    "country": "PL",
    "name": "Radziejów",
    "lat": "52.62481",
    "lng": "18.52771"
  },
  {
    "country": "PL",
    "name": "Radziechowy",
    "lat": "49.64651",
    "lng": "19.13115"
  },
  {
    "country": "PL",
    "name": "Radzanowo",
    "lat": "52.57306",
    "lng": "19.89109"
  },
  {
    "country": "PL",
    "name": "Radowo Małe",
    "lat": "53.66575",
    "lng": "15.44789"
  },
  {
    "country": "PL",
    "name": "Radostowice",
    "lat": "50.00311",
    "lng": "18.88103"
  },
  {
    "country": "PL",
    "name": "Radomsko",
    "lat": "51.06713",
    "lng": "19.44477"
  },
  {
    "country": "PL",
    "name": "Radomin",
    "lat": "53.0867",
    "lng": "19.19415"
  },
  {
    "country": "PL",
    "name": "Radocza",
    "lat": "49.91774",
    "lng": "19.47498"
  },
  {
    "country": "PL",
    "name": "Radlin",
    "lat": "50.0502",
    "lng": "18.47626"
  },
  {
    "country": "PL",
    "name": "Radków",
    "lat": "50.50426",
    "lng": "16.40061"
  },
  {
    "country": "PL",
    "name": "Rączna",
    "lat": "50.00984",
    "lng": "19.76784"
  },
  {
    "country": "PL",
    "name": "Racławice Śląskie",
    "lat": "50.31204",
    "lng": "17.77528"
  },
  {
    "country": "PL",
    "name": "Racławice",
    "lat": "50.19344",
    "lng": "19.67686"
  },
  {
    "country": "PL",
    "name": "Racibórz",
    "lat": "50.09195",
    "lng": "18.21928"
  },
  {
    "country": "PL",
    "name": "Raciążek",
    "lat": "52.8565",
    "lng": "18.81334"
  },
  {
    "country": "PL",
    "name": "Rabka-Zdrój",
    "lat": "49.60889",
    "lng": "19.96654"
  },
  {
    "country": "PL",
    "name": "Rąbino",
    "lat": "53.8663",
    "lng": "15.94485"
  },
  {
    "country": "PL",
    "name": "Raba Wyżna",
    "lat": "49.56681",
    "lng": "19.87967"
  },
  {
    "country": "PL",
    "name": "Pyzdry",
    "lat": "52.17056",
    "lng": "17.69005"
  },
  {
    "country": "PL",
    "name": "Pyskowice",
    "lat": "50.4",
    "lng": "18.63333"
  },
  {
    "country": "PL",
    "name": "Pyrzyce",
    "lat": "53.1462",
    "lng": "14.89257"
  },
  {
    "country": "PL",
    "name": "Puszczykowo",
    "lat": "52.2857",
    "lng": "16.84925"
  },
  {
    "country": "PL",
    "name": "Puńców",
    "lat": "49.71842",
    "lng": "18.66157"
  },
  {
    "country": "PL",
    "name": "Puck",
    "lat": "54.7179",
    "lng": "18.40841"
  },
  {
    "country": "PL",
    "name": "Pszów",
    "lat": "50.03994",
    "lng": "18.39472"
  },
  {
    "country": "PL",
    "name": "Pszczyna",
    "lat": "49.98037",
    "lng": "18.95382"
  },
  {
    "country": "PL",
    "name": "Pszczółki",
    "lat": "54.17304",
    "lng": "18.69787"
  },
  {
    "country": "PL",
    "name": "Pszczew",
    "lat": "52.47724",
    "lng": "15.7816"
  },
  {
    "country": "PL",
    "name": "Psary",
    "lat": "51.18712",
    "lng": "17.03173"
  },
  {
    "country": "PL",
    "name": "Psary",
    "lat": "50.6147",
    "lng": "18.96991"
  },
  {
    "country": "PL",
    "name": "Psary",
    "lat": "50.37964",
    "lng": "19.11548"
  },
  {
    "country": "PL",
    "name": "Psary",
    "lat": "50.17242",
    "lng": "19.52953"
  },
  {
    "country": "PL",
    "name": "Przywidz",
    "lat": "54.19524",
    "lng": "18.32116"
  },
  {
    "country": "PL",
    "name": "Przytoczna",
    "lat": "52.57755",
    "lng": "15.67878"
  },
  {
    "country": "PL",
    "name": "Przytkowice",
    "lat": "49.91785",
    "lng": "19.6857"
  },
  {
    "country": "PL",
    "name": "Przyszowice",
    "lat": "50.24841",
    "lng": "18.74594"
  },
  {
    "country": "PL",
    "name": "Przystajń",
    "lat": "50.88495",
    "lng": "18.69169"
  },
  {
    "country": "PL",
    "name": "Przyrów",
    "lat": "50.80051",
    "lng": "19.52794"
  },
  {
    "country": "PL",
    "name": "Przykona",
    "lat": "51.98171",
    "lng": "18.61247"
  },
  {
    "country": "PL",
    "name": "Przygodzice",
    "lat": "51.59195",
    "lng": "17.82412"
  },
  {
    "country": "PL",
    "name": "Przyborów",
    "lat": "51.79991",
    "lng": "15.7689"
  },
  {
    "country": "PL",
    "name": "Przyborów",
    "lat": "49.6215",
    "lng": "19.38701"
  },
  {
    "country": "PL",
    "name": "Przybiernów",
    "lat": "53.7578",
    "lng": "14.78529"
  },
  {
    "country": "PL",
    "name": "Przodkowo",
    "lat": "54.37991",
    "lng": "18.2876"
  },
  {
    "country": "PL",
    "name": "Przewóz",
    "lat": "51.48053",
    "lng": "14.95188"
  },
  {
    "country": "PL",
    "name": "Przeworno",
    "lat": "50.68629",
    "lng": "17.16588"
  },
  {
    "country": "PL",
    "name": "Przemków",
    "lat": "51.5253",
    "lng": "15.79441"
  },
  {
    "country": "PL",
    "name": "Przemęt",
    "lat": "52.00808",
    "lng": "16.30114"
  },
  {
    "country": "PL",
    "name": "Przelewice",
    "lat": "53.10413",
    "lng": "15.07625"
  },
  {
    "country": "PL",
    "name": "Przeginia",
    "lat": "50.23831",
    "lng": "19.68853"
  },
  {
    "country": "PL",
    "name": "Przedecz",
    "lat": "52.3344",
    "lng": "18.89915"
  },
  {
    "country": "PL",
    "name": "Przedbórz",
    "lat": "51.08789",
    "lng": "19.87384"
  },
  {
    "country": "PL",
    "name": "Przecław",
    "lat": "53.37447",
    "lng": "14.47251"
  },
  {
    "country": "PL",
    "name": "Przeciszów",
    "lat": "50.00647",
    "lng": "19.37576"
  },
  {
    "country": "PL",
    "name": "Przecieszyn",
    "lat": "49.97838",
    "lng": "19.17046"
  },
  {
    "country": "PL",
    "name": "Przechlewo",
    "lat": "53.79847",
    "lng": "17.25205"
  },
  {
    "country": "PL",
    "name": "Pruszcz",
    "lat": "53.33021",
    "lng": "18.19894"
  },
  {
    "country": "PL",
    "name": "Pruszcz Gdański",
    "lat": "54.26217",
    "lng": "18.63625"
  },
  {
    "country": "PL",
    "name": "Prusice",
    "lat": "51.37116",
    "lng": "16.96025"
  },
  {
    "country": "PL",
    "name": "Prudnik",
    "lat": "50.32124",
    "lng": "17.57461"
  },
  {
    "country": "PL",
    "name": "Pruchna",
    "lat": "49.86527",
    "lng": "18.68191"
  },
  {
    "country": "PL",
    "name": "Prószków",
    "lat": "50.5767",
    "lng": "17.87143"
  },
  {
    "country": "PL",
    "name": "Prochowice",
    "lat": "51.27307",
    "lng": "16.36532"
  },
  {
    "country": "PL",
    "name": "Praszka",
    "lat": "51.05375",
    "lng": "18.45317"
  },
  {
    "country": "PL",
    "name": "Prabuty",
    "lat": "53.755",
    "lng": "19.20547"
  },
  {
    "country": "PL",
    "name": "Poznań",
    "lat": "52.40692",
    "lng": "16.92993"
  },
  {
    "country": "PL",
    "name": "Powidz",
    "lat": "52.41362",
    "lng": "17.91926"
  },
  {
    "country": "PL",
    "name": "Potok Złoty",
    "lat": "50.70676",
    "lng": "19.43091"
  },
  {
    "country": "PL",
    "name": "Potęgowo",
    "lat": "54.48285",
    "lng": "17.4862"
  },
  {
    "country": "PL",
    "name": "Poręba Wielka",
    "lat": "50.01116",
    "lng": "19.28375"
  },
  {
    "country": "PL",
    "name": "Cynków",
    "lat": "50.56203",
    "lng": "19.11956"
  },
  {
    "country": "PL",
    "name": "Poręba",
    "lat": "50.48831",
    "lng": "19.33903"
  },
  {
    "country": "PL",
    "name": "Poraj",
    "lat": "50.67797",
    "lng": "19.21509"
  },
  {
    "country": "PL",
    "name": "Porąbka",
    "lat": "49.81716",
    "lng": "19.21835"
  },
  {
    "country": "PL",
    "name": "Popów",
    "lat": "51.04029",
    "lng": "18.93117"
  },
  {
    "country": "PL",
    "name": "Popielów",
    "lat": "50.82632",
    "lng": "17.74378"
  },
  {
    "country": "PL",
    "name": "Ponikiew",
    "lat": "49.83311",
    "lng": "19.46571"
  },
  {
    "country": "PL",
    "name": "Poniec",
    "lat": "51.76343",
    "lng": "16.80867"
  },
  {
    "country": "PL",
    "name": "Polska Cerekiew",
    "lat": "50.22827",
    "lng": "18.12675"
  },
  {
    "country": "PL",
    "name": "Połomia",
    "lat": "49.99185",
    "lng": "18.55102"
  },
  {
    "country": "PL",
    "name": "Polkowice",
    "lat": "51.50391",
    "lng": "16.07261"
  },
  {
    "country": "PL",
    "name": "Police",
    "lat": "53.55214",
    "lng": "14.57182"
  },
  {
    "country": "PL",
    "name": "Połczyn-Zdrój",
    "lat": "53.76424",
    "lng": "16.09574"
  },
  {
    "country": "PL",
    "name": "Polanów",
    "lat": "54.1193",
    "lng": "16.68512"
  },
  {
    "country": "PL",
    "name": "Polanka Wielka",
    "lat": "49.98501",
    "lng": "19.32615"
  },
  {
    "country": "PL",
    "name": "Polanica-Zdrój",
    "lat": "50.40373",
    "lng": "16.51271"
  },
  {
    "country": "PL",
    "name": "Połajewo",
    "lat": "52.79923",
    "lng": "16.73347"
  },
  {
    "country": "PL",
    "name": "Pokój",
    "lat": "50.90265",
    "lng": "17.83751"
  },
  {
    "country": "PL",
    "name": "Pogwizdów",
    "lat": "49.80382",
    "lng": "18.60106"
  },
  {
    "country": "PL",
    "name": "Pogrzebień",
    "lat": "50.06722",
    "lng": "18.29876"
  },
  {
    "country": "PL",
    "name": "Pogorzyce",
    "lat": "50.10186",
    "lng": "19.42228"
  },
  {
    "country": "PL",
    "name": "Pogorzela",
    "lat": "51.8222",
    "lng": "17.23017"
  },
  {
    "country": "PL",
    "name": "Pogórze",
    "lat": "54.5644",
    "lng": "18.48209"
  },
  {
    "country": "PL",
    "name": "Podwilk",
    "lat": "49.5476",
    "lng": "19.73874"
  },
  {
    "country": "PL",
    "name": "Podgórzyn",
    "lat": "50.83261",
    "lng": "15.68161"
  },
  {
    "country": "PL",
    "name": "Poddębice",
    "lat": "51.89344",
    "lng": "18.9573"
  },
  {
    "country": "PL",
    "name": "Pobierowo",
    "lat": "54.061",
    "lng": "14.93282"
  },
  {
    "country": "PL",
    "name": "Pobiedziska",
    "lat": "52.47753",
    "lng": "17.28767"
  },
  {
    "country": "PL",
    "name": "Pniewy",
    "lat": "52.50943",
    "lng": "16.25668"
  },
  {
    "country": "PL",
    "name": "Płużnica",
    "lat": "53.29672",
    "lng": "18.77692"
  },
  {
    "country": "PL",
    "name": "Płoty",
    "lat": "53.80182",
    "lng": "15.2667"
  },
  {
    "country": "PL",
    "name": "Płock",
    "lat": "52.54682",
    "lng": "19.70638"
  },
  {
    "country": "PL",
    "name": "Plewiska",
    "lat": "52.36706",
    "lng": "16.80985"
  },
  {
    "country": "PL",
    "name": "Pleszew",
    "lat": "51.89636",
    "lng": "17.78549"
  },
  {
    "country": "PL",
    "name": "Płaza",
    "lat": "50.09988",
    "lng": "19.46451"
  },
  {
    "country": "PL",
    "name": "Pławno",
    "lat": "50.97772",
    "lng": "19.45524"
  },
  {
    "country": "PL",
    "name": "Pisarzowice",
    "lat": "51.14479",
    "lng": "15.23057"
  },
  {
    "country": "PL",
    "name": "Pisarzowice",
    "lat": "49.88363",
    "lng": "19.14565"
  },
  {
    "country": "PL",
    "name": "Piotrków Trybunalski",
    "lat": "51.40547",
    "lng": "19.70321"
  },
  {
    "country": "PL",
    "name": "Piotrków Kujawski",
    "lat": "52.55111",
    "lng": "18.49905"
  },
  {
    "country": "PL",
    "name": "Pilica",
    "lat": "50.46799",
    "lng": "19.65729"
  },
  {
    "country": "PL",
    "name": "Pilchowice",
    "lat": "50.21668",
    "lng": "18.56132"
  },
  {
    "country": "PL",
    "name": "Piława Górna",
    "lat": "50.68357",
    "lng": "16.74359"
  },
  {
    "country": "PL",
    "name": "Piła",
    "lat": "53.15145",
    "lng": "16.73782"
  },
  {
    "country": "PL",
    "name": "Pietrzykowice",
    "lat": "49.69634",
    "lng": "19.1599"
  },
  {
    "country": "PL",
    "name": "Pietrowice Wielkie",
    "lat": "50.08452",
    "lng": "18.09148"
  },
  {
    "country": "PL",
    "name": "Pieszyce",
    "lat": "50.71287",
    "lng": "16.58232"
  },
  {
    "country": "PL",
    "name": "Pierściec",
    "lat": "49.83339",
    "lng": "18.81409"
  },
  {
    "country": "PL",
    "name": "Pieńsk",
    "lat": "51.249",
    "lng": "15.04685"
  },
  {
    "country": "PL",
    "name": "Pielgrzymowice",
    "lat": "49.90547",
    "lng": "18.64886"
  },
  {
    "country": "PL",
    "name": "Piekielnik",
    "lat": "49.47688",
    "lng": "19.7681"
  },
  {
    "country": "PL",
    "name": "Piekary Śląskie",
    "lat": "50.38017",
    "lng": "18.92653"
  },
  {
    "country": "PL",
    "name": "Piekary",
    "lat": "50.02495",
    "lng": "19.79616"
  },
  {
    "country": "PL",
    "name": "Piechowice",
    "lat": "50.84963",
    "lng": "15.59887"
  },
  {
    "country": "PL",
    "name": "Piątek",
    "lat": "52.0689",
    "lng": "19.4797"
  },
  {
    "country": "PL",
    "name": "Piaski",
    "lat": "51.88497",
    "lng": "17.07293"
  },
  {
    "country": "PL",
    "name": "Piasek",
    "lat": "50.01055",
    "lng": "18.94807"
  },
  {
    "country": "PL",
    "name": "Pewel Wielka",
    "lat": "49.67457",
    "lng": "19.37482"
  },
  {
    "country": "PL",
    "name": "Pewel Ślemieńska",
    "lat": "49.68968",
    "lng": "19.33431"
  },
  {
    "country": "PL",
    "name": "Perzów",
    "lat": "51.27625",
    "lng": "17.8097"
  },
  {
    "country": "PL",
    "name": "Pępowo",
    "lat": "51.76569",
    "lng": "17.12661"
  },
  {
    "country": "PL",
    "name": "Pelplin",
    "lat": "53.92834",
    "lng": "18.6977"
  },
  {
    "country": "PL",
    "name": "Pełczyce",
    "lat": "53.04354",
    "lng": "15.30447"
  },
  {
    "country": "PL",
    "name": "Pęczniew",
    "lat": "51.80384",
    "lng": "18.72311"
  },
  {
    "country": "PL",
    "name": "Pecna",
    "lat": "52.18333",
    "lng": "16.8"
  },
  {
    "country": "PL",
    "name": "Pcim",
    "lat": "49.75166",
    "lng": "19.97108"
  },
  {
    "country": "PL",
    "name": "Pawonków",
    "lat": "50.69499",
    "lng": "18.58149"
  },
  {
    "country": "PL",
    "name": "Pawłowiczki",
    "lat": "50.2466",
    "lng": "18.04865"
  },
  {
    "country": "PL",
    "name": "Pawłowice",
    "lat": "49.96127",
    "lng": "18.71778"
  },
  {
    "country": "PL",
    "name": "Pątnów",
    "lat": "51.14403",
    "lng": "18.61659"
  },
  {
    "country": "PL",
    "name": "Paszowice",
    "lat": "51.01078",
    "lng": "16.15273"
  },
  {
    "country": "PL",
    "name": "Pasłęk",
    "lat": "54.0616",
    "lng": "19.65932"
  },
  {
    "country": "PL",
    "name": "Parzęczew",
    "lat": "51.94855",
    "lng": "19.20608"
  },
  {
    "country": "PL",
    "name": "Parchowo",
    "lat": "54.20658",
    "lng": "17.66816"
  },
  {
    "country": "PL",
    "name": "Panki",
    "lat": "50.88333",
    "lng": "18.7516"
  },
  {
    "country": "PL",
    "name": "Paniówki",
    "lat": "50.23139",
    "lng": "18.78104"
  },
  {
    "country": "PL",
    "name": "Pamiątkowo",
    "lat": "52.55334",
    "lng": "16.68094"
  },
  {
    "country": "PL",
    "name": "Palcza",
    "lat": "49.80454",
    "lng": "19.74389"
  },
  {
    "country": "PL",
    "name": "Pakosławice",
    "lat": "50.54474",
    "lng": "17.36578"
  },
  {
    "country": "PL",
    "name": "Pakosław",
    "lat": "51.61438",
    "lng": "17.05793"
  },
  {
    "country": "PL",
    "name": "Pakość",
    "lat": "52.80178",
    "lng": "18.0853"
  },
  {
    "country": "PL",
    "name": "Pajęczno",
    "lat": "51.14449",
    "lng": "18.99612"
  },
  {
    "country": "PL",
    "name": "Paczków",
    "lat": "50.46395",
    "lng": "17.00658"
  },
  {
    "country": "PL",
    "name": "Pacyna",
    "lat": "52.30281",
    "lng": "19.70982"
  },
  {
    "country": "PL",
    "name": "Pabianice",
    "lat": "51.66446",
    "lng": "19.35473"
  },
  {
    "country": "PL",
    "name": "Ozorków",
    "lat": "51.96336",
    "lng": "19.29139"
  },
  {
    "country": "PL",
    "name": "Ozimek",
    "lat": "50.67944",
    "lng": "18.2137"
  },
  {
    "country": "PL",
    "name": "Ożarowice",
    "lat": "50.46182",
    "lng": "19.04317"
  },
  {
    "country": "PL",
    "name": "Ożarów",
    "lat": "51.14489",
    "lng": "18.5111"
  },
  {
    "country": "PL",
    "name": "Otyń",
    "lat": "51.84766",
    "lng": "15.71105"
  },
  {
    "country": "PL",
    "name": "Otmuchów",
    "lat": "50.46627",
    "lng": "17.17348"
  },
  {
    "country": "PL",
    "name": "Oświęcim",
    "lat": "50.03437",
    "lng": "19.21037"
  },
  {
    "country": "PL",
    "name": "Ostrzeszów",
    "lat": "51.4264",
    "lng": "17.93355"
  },
  {
    "country": "PL",
    "name": "Ostrowy",
    "lat": "52.30444",
    "lng": "19.16565"
  },
  {
    "country": "PL",
    "name": "Ostrowy nad Okszą",
    "lat": "50.97799",
    "lng": "19.05355"
  },
  {
    "country": "PL",
    "name": "Ostrów Wielkopolski",
    "lat": "51.65501",
    "lng": "17.80686"
  },
  {
    "country": "PL",
    "name": "Ostrowite",
    "lat": "53.06917",
    "lng": "19.29337"
  },
  {
    "country": "PL",
    "name": "Ostrowite",
    "lat": "52.38199",
    "lng": "18.0447"
  },
  {
    "country": "PL",
    "name": "Ostroszowice",
    "lat": "50.64576",
    "lng": "16.63965"
  },
  {
    "country": "PL",
    "name": "Ostroróg",
    "lat": "52.6265",
    "lng": "16.44988"
  },
  {
    "country": "PL",
    "name": "Ostróda",
    "lat": "53.69671",
    "lng": "19.96486"
  },
  {
    "country": "PL",
    "name": "Ostrężnica",
    "lat": "50.19262",
    "lng": "19.57077"
  },
  {
    "country": "PL",
    "name": "Ostaszewo",
    "lat": "54.21256",
    "lng": "18.95142"
  },
  {
    "country": "PL",
    "name": "Ośno Lubuskie",
    "lat": "52.4536",
    "lng": "14.87549"
  },
  {
    "country": "PL",
    "name": "Osjaków",
    "lat": "51.28946",
    "lng": "18.79151"
  },
  {
    "country": "PL",
    "name": "Osina",
    "lat": "53.60473",
    "lng": "15.0123"
  },
  {
    "country": "PL",
    "name": "Osielsko",
    "lat": "53.18505",
    "lng": "18.08418"
  },
  {
    "country": "PL",
    "name": "Osielec",
    "lat": "49.68079",
    "lng": "19.78243"
  },
  {
    "country": "PL",
    "name": "Osiek nad Notecią",
    "lat": "53.1203",
    "lng": "17.29102"
  },
  {
    "country": "PL",
    "name": "Osiek Mały",
    "lat": "52.2763",
    "lng": "18.60234"
  },
  {
    "country": "PL",
    "name": "Osiek",
    "lat": "53.72226",
    "lng": "18.49051"
  },
  {
    "country": "PL",
    "name": "Osiek",
    "lat": "52.92629",
    "lng": "18.80765"
  },
  {
    "country": "PL",
    "name": "Osiek",
    "lat": "51.36717",
    "lng": "16.2338"
  },
  {
    "country": "PL",
    "name": "Osiek",
    "lat": "50.24353",
    "lng": "19.60047"
  },
  {
    "country": "PL",
    "name": "Osiek",
    "lat": "49.95067",
    "lng": "19.26444"
  },
  {
    "country": "PL",
    "name": "Osieczna",
    "lat": "51.9042",
    "lng": "16.67862"
  },
  {
    "country": "PL",
    "name": "Osięciny",
    "lat": "52.62926",
    "lng": "18.72208"
  },
  {
    "country": "PL",
    "name": "Osie",
    "lat": "53.59918",
    "lng": "18.34373"
  },
  {
    "country": "PL",
    "name": "Orzesze",
    "lat": "50.15595",
    "lng": "18.77923"
  },
  {
    "country": "PL",
    "name": "Orzech",
    "lat": "50.42744",
    "lng": "18.92275"
  },
  {
    "country": "PL",
    "name": "Ornontowice",
    "lat": "50.19377",
    "lng": "18.75435"
  },
  {
    "country": "PL",
    "name": "Orle",
    "lat": "54.64022",
    "lng": "18.17057"
  },
  {
    "country": "PL",
    "name": "Orchowo",
    "lat": "52.50938",
    "lng": "18.01578"
  },
  {
    "country": "PL",
    "name": "Oporów",
    "lat": "52.26448",
    "lng": "19.56416"
  },
  {
    "country": "PL",
    "name": "Opole",
    "lat": "50.67211",
    "lng": "17.92533"
  },
  {
    "country": "PL",
    "name": "Opatówek",
    "lat": "51.73989",
    "lng": "18.21653"
  },
  {
    "country": "PL",
    "name": "Opatów",
    "lat": "51.21463",
    "lng": "18.14615"
  },
  {
    "country": "PL",
    "name": "Opatów",
    "lat": "50.95567",
    "lng": "18.81941"
  },
  {
    "country": "PL",
    "name": "Opalenica",
    "lat": "52.30887",
    "lng": "16.41278"
  },
  {
    "country": "PL",
    "name": "Olza",
    "lat": "49.95393",
    "lng": "18.3391"
  },
  {
    "country": "PL",
    "name": "Olszyna",
    "lat": "51.0671",
    "lng": "15.37228"
  },
  {
    "country": "PL",
    "name": "Olsztyn",
    "lat": "50.75185",
    "lng": "19.26737"
  },
  {
    "country": "PL",
    "name": "Olszówka",
    "lat": "52.1903",
    "lng": "18.86258"
  },
  {
    "country": "PL",
    "name": "Olszanka",
    "lat": "50.79514",
    "lng": "17.4789"
  },
  {
    "country": "PL",
    "name": "Olszanica",
    "lat": "51.20672",
    "lng": "15.8004"
  },
  {
    "country": "PL",
    "name": "Olkusz",
    "lat": "50.2813",
    "lng": "19.56503"
  },
  {
    "country": "PL",
    "name": "Olesno",
    "lat": "50.87698",
    "lng": "18.42094"
  },
  {
    "country": "PL",
    "name": "Oleśnica",
    "lat": "51.21338",
    "lng": "17.38986"
  },
  {
    "country": "PL",
    "name": "Oława",
    "lat": "50.9466",
    "lng": "17.2926"
  },
  {
    "country": "PL",
    "name": "Kołaczkowo",
    "lat": "52.21739",
    "lng": "17.62413"
  },
  {
    "country": "PL",
    "name": "Okonek",
    "lat": "53.53618",
    "lng": "16.85158"
  },
  {
    "country": "PL",
    "name": "Ogrodzieniec",
    "lat": "50.45177",
    "lng": "19.51987"
  },
  {
    "country": "PL",
    "name": "Odolanów",
    "lat": "51.57419",
    "lng": "17.67434"
  },
  {
    "country": "PL",
    "name": "Ochojno",
    "lat": "49.95255",
    "lng": "19.97452"
  },
  {
    "country": "PL",
    "name": "Ochla",
    "lat": "51.87903",
    "lng": "15.47132"
  },
  {
    "country": "PL",
    "name": "Ochaby",
    "lat": "49.84252",
    "lng": "18.76894"
  },
  {
    "country": "PL",
    "name": "Obrzycko",
    "lat": "52.70338",
    "lng": "16.52807"
  },
  {
    "country": "PL",
    "name": "Obrowo",
    "lat": "52.97149",
    "lng": "18.87863"
  },
  {
    "country": "PL",
    "name": "Oborniki Śląskie",
    "lat": "51.30137",
    "lng": "16.91465"
  },
  {
    "country": "PL",
    "name": "Oborniki",
    "lat": "52.64739",
    "lng": "16.81406"
  },
  {
    "country": "PL",
    "name": "Nysa",
    "lat": "50.47379",
    "lng": "17.33437"
  },
  {
    "country": "PL",
    "name": "Nowy Tomyśl",
    "lat": "52.3195",
    "lng": "16.12844"
  },
  {
    "country": "PL",
    "name": "Nowy Staw",
    "lat": "54.13609",
    "lng": "19.00909"
  },
  {
    "country": "PL",
    "name": "Nowy Dwór Gdański",
    "lat": "54.21305",
    "lng": "19.11771"
  },
  {
    "country": "PL",
    "name": "Nowy Duninów",
    "lat": "52.58271",
    "lng": "19.47996"
  },
  {
    "country": "PL",
    "name": "Nowogrodziec",
    "lat": "51.19543",
    "lng": "15.39854"
  },
  {
    "country": "PL",
    "name": "Nowogródek Pomorski",
    "lat": "52.91149",
    "lng": "15.02947"
  },
  {
    "country": "PL",
    "name": "Nowogród Bobrzański",
    "lat": "51.79856",
    "lng": "15.2352"
  },
  {
    "country": "PL",
    "name": "Nowogard",
    "lat": "53.67437",
    "lng": "15.1163"
  },
  {
    "country": "PL",
    "name": "Nowe Warpno",
    "lat": "53.72256",
    "lng": "14.28961"
  },
  {
    "country": "PL",
    "name": "Nowe Skalmierzyce",
    "lat": "51.71038",
    "lng": "17.99337"
  },
  {
    "country": "PL",
    "name": "Nowe Miasto nad Wartą",
    "lat": "52.09007",
    "lng": "17.41114"
  },
  {
    "country": "PL",
    "name": "Nowe Miasto Lubawskie",
    "lat": "53.42079",
    "lng": "19.59515"
  },
  {
    "country": "PL",
    "name": "Nowe Miasteczko",
    "lat": "51.69097",
    "lng": "15.73174"
  },
  {
    "country": "PL",
    "name": "Nowe",
    "lat": "53.64906",
    "lng": "18.72716"
  },
  {
    "country": "PL",
    "name": "Nowa Wieś Wielka",
    "lat": "52.97159",
    "lng": "18.09036"
  },
  {
    "country": "PL",
    "name": "Nowa Wieś Lęborska",
    "lat": "54.55878",
    "lng": "17.72756"
  },
  {
    "country": "PL",
    "name": "Nowa Wieś",
    "lat": "49.90746",
    "lng": "19.21646"
  },
  {
    "country": "PL",
    "name": "Nowa Sól",
    "lat": "51.80333",
    "lng": "15.71702"
  },
  {
    "country": "PL",
    "name": "Nowa Ruda",
    "lat": "50.58008",
    "lng": "16.50164"
  },
  {
    "country": "PL",
    "name": "Nowa Góra",
    "lat": "50.17305",
    "lng": "19.5912"
  },
  {
    "country": "PL",
    "name": "Nieszawa",
    "lat": "52.83452",
    "lng": "18.89921"
  },
  {
    "country": "PL",
    "name": "Niemodlin",
    "lat": "50.642",
    "lng": "17.61932"
  },
  {
    "country": "PL",
    "name": "Niemcza",
    "lat": "50.72007",
    "lng": "16.83573"
  },
  {
    "country": "PL",
    "name": "Niegowonice",
    "lat": "50.38909",
    "lng": "19.42263"
  },
  {
    "country": "PL",
    "name": "Niedobczyce",
    "lat": "50.0654",
    "lng": "18.49531"
  },
  {
    "country": "PL",
    "name": "Niechanowo",
    "lat": "52.46527",
    "lng": "17.67812"
  },
  {
    "country": "PL",
    "name": "Nidek",
    "lat": "49.90492",
    "lng": "19.32461"
  },
  {
    "country": "PL",
    "name": "Nekla",
    "lat": "52.36496",
    "lng": "17.41329"
  },
  {
    "country": "PL",
    "name": "Nędza",
    "lat": "50.16112",
    "lng": "18.31103"
  },
  {
    "country": "PL",
    "name": "Naprawa",
    "lat": "49.64657",
    "lng": "19.87916"
  },
  {
    "country": "PL",
    "name": "Namysłów",
    "lat": "51.07592",
    "lng": "17.72284"
  },
  {
    "country": "PL",
    "name": "Nakło nad Notecią",
    "lat": "53.14214",
    "lng": "17.60181"
  },
  {
    "country": "PL",
    "name": "Nakło",
    "lat": "50.57975",
    "lng": "18.11817"
  },
  {
    "country": "PL",
    "name": "Nakło",
    "lat": "50.4369",
    "lng": "18.91056"
  },
  {
    "country": "PL",
    "name": "Myszków",
    "lat": "50.5752",
    "lng": "19.32461"
  },
  {
    "country": "PL",
    "name": "Mysłowice",
    "lat": "50.20745",
    "lng": "19.16668"
  },
  {
    "country": "PL",
    "name": "Myślibórz",
    "lat": "52.92382",
    "lng": "14.86785"
  },
  {
    "country": "PL",
    "name": "Myślenice",
    "lat": "49.83383",
    "lng": "19.9383"
  },
  {
    "country": "PL",
    "name": "Mysłakowice",
    "lat": "50.84123",
    "lng": "15.77894"
  },
  {
    "country": "PL",
    "name": "Myślachowice",
    "lat": "50.18514",
    "lng": "19.48116"
  },
  {
    "country": "PL",
    "name": "Mykanów",
    "lat": "50.9236",
    "lng": "19.2005"
  },
  {
    "country": "PL",
    "name": "Murowana Goślina",
    "lat": "52.57463",
    "lng": "17.00933"
  },
  {
    "country": "PL",
    "name": "Murów",
    "lat": "50.86307",
    "lng": "17.94557"
  },
  {
    "country": "PL",
    "name": "Murcki",
    "lat": "50.20036",
    "lng": "19.04351"
  },
  {
    "country": "PL",
    "name": "Mszana",
    "lat": "49.96939",
    "lng": "18.52793"
  },
  {
    "country": "PL",
    "name": "Mstów",
    "lat": "50.82969",
    "lng": "19.28547"
  },
  {
    "country": "PL",
    "name": "Mrzeżyno",
    "lat": "54.14384",
    "lng": "15.29142"
  },
  {
    "country": "PL",
    "name": "Mrzezino",
    "lat": "54.65378",
    "lng": "18.43025"
  },
  {
    "country": "PL",
    "name": "Mrozów",
    "lat": "51.18817",
    "lng": "16.78831"
  },
  {
    "country": "PL",
    "name": "Mrocza",
    "lat": "53.24313",
    "lng": "17.60405"
  },
  {
    "country": "PL",
    "name": "Moszczenica",
    "lat": "51.50297",
    "lng": "19.71986"
  },
  {
    "country": "PL",
    "name": "Moszczanka",
    "lat": "50.3002",
    "lng": "17.49109"
  },
  {
    "country": "PL",
    "name": "Mosty",
    "lat": "54.61195",
    "lng": "18.49634"
  },
  {
    "country": "PL",
    "name": "Mosty",
    "lat": "53.54796",
    "lng": "14.95634"
  },
  {
    "country": "PL",
    "name": "Mosina",
    "lat": "52.24543",
    "lng": "16.84709"
  },
  {
    "country": "PL",
    "name": "Moryń",
    "lat": "52.85769",
    "lng": "14.39297"
  },
  {
    "country": "PL",
    "name": "Morąg",
    "lat": "53.91711",
    "lng": "19.92602"
  },
  {
    "country": "PL",
    "name": "Mokrsko",
    "lat": "51.17897",
    "lng": "18.48879"
  },
  {
    "country": "PL",
    "name": "Mogilno",
    "lat": "52.65806",
    "lng": "17.95578"
  },
  {
    "country": "PL",
    "name": "Mogilany",
    "lat": "49.9389",
    "lng": "19.88972"
  },
  {
    "country": "PL",
    "name": "Modlniczka",
    "lat": "50.11739",
    "lng": "19.8553"
  },
  {
    "country": "PL",
    "name": "Modlnica",
    "lat": "50.12958",
    "lng": "19.86461"
  },
  {
    "country": "PL",
    "name": "Mochowo",
    "lat": "52.7657",
    "lng": "19.55592"
  },
  {
    "country": "PL",
    "name": "Mników",
    "lat": "50.06044",
    "lng": "19.72595"
  },
  {
    "country": "PL",
    "name": "Mnich",
    "lat": "49.88944",
    "lng": "18.80722"
  },
  {
    "country": "PL",
    "name": "Młynary",
    "lat": "54.1869",
    "lng": "19.72149"
  },
  {
    "country": "PL",
    "name": "Mirsk",
    "lat": "50.97054",
    "lng": "15.38567"
  },
  {
    "country": "PL",
    "name": "Mirosławiec",
    "lat": "53.34071",
    "lng": "16.08793"
  },
  {
    "country": "PL",
    "name": "Milówka",
    "lat": "49.5554",
    "lng": "19.09072"
  },
  {
    "country": "PL",
    "name": "Miłosław",
    "lat": "52.20318",
    "lng": "17.48955"
  },
  {
    "country": "PL",
    "name": "Miłoradz",
    "lat": "54.01392",
    "lng": "18.91846"
  },
  {
    "country": "PL",
    "name": "Miłomłyn",
    "lat": "53.76449",
    "lng": "19.838"
  },
  {
    "country": "PL",
    "name": "Miłkowice",
    "lat": "51.25601",
    "lng": "16.07231"
  },
  {
    "country": "PL",
    "name": "Milicz",
    "lat": "51.5277",
    "lng": "17.27137"
  },
  {
    "country": "PL",
    "name": "Mikstat",
    "lat": "51.53236",
    "lng": "17.97378"
  },
  {
    "country": "PL",
    "name": "Mikołów",
    "lat": "50.17103",
    "lng": "18.9041"
  },
  {
    "country": "PL",
    "name": "Mikołajki Pomorskie",
    "lat": "53.85131",
    "lng": "19.16574"
  },
  {
    "country": "PL",
    "name": "Mieszkowice",
    "lat": "52.7873",
    "lng": "14.49346"
  },
  {
    "country": "PL",
    "name": "Mieścisko",
    "lat": "52.74357",
    "lng": "17.33213"
  },
  {
    "country": "PL",
    "name": "Mierzęcice",
    "lat": "50.44504",
    "lng": "19.12934"
  },
  {
    "country": "PL",
    "name": "Mieroszów",
    "lat": "50.66589",
    "lng": "16.18883"
  },
  {
    "country": "PL",
    "name": "Mielno",
    "lat": "54.26086",
    "lng": "16.0621"
  },
  {
    "country": "PL",
    "name": "Mieleszyn",
    "lat": "52.66868",
    "lng": "17.49779"
  },
  {
    "country": "PL",
    "name": "Miękinia",
    "lat": "51.18844",
    "lng": "16.73595"
  },
  {
    "country": "PL",
    "name": "Miękinia",
    "lat": "50.15557",
    "lng": "19.60871"
  },
  {
    "country": "PL",
    "name": "Miejska Górka",
    "lat": "51.65573",
    "lng": "16.95826"
  },
  {
    "country": "PL",
    "name": "Międzyzdroje",
    "lat": "53.92921",
    "lng": "14.45097"
  },
  {
    "country": "PL",
    "name": "Międzyrzecz",
    "lat": "52.44461",
    "lng": "15.57801"
  },
  {
    "country": "PL",
    "name": "Międzylesie",
    "lat": "52.14487",
    "lng": "15.38283"
  },
  {
    "country": "PL",
    "name": "Międzylesie",
    "lat": "50.14778",
    "lng": "16.66712"
  },
  {
    "country": "PL",
    "name": "Międzychód",
    "lat": "52.59882",
    "lng": "15.89696"
  },
  {
    "country": "PL",
    "name": "Międzybrodzie Bialskie",
    "lat": "49.78747",
    "lng": "19.19741"
  },
  {
    "country": "PL",
    "name": "Międzybórz",
    "lat": "51.39626",
    "lng": "17.6661"
  },
  {
    "country": "PL",
    "name": "Miedzno",
    "lat": "50.96994",
    "lng": "18.98111"
  },
  {
    "country": "PL",
    "name": "Miedźna",
    "lat": "49.98225",
    "lng": "19.04883"
  },
  {
    "country": "PL",
    "name": "Miedzichowo",
    "lat": "52.37581",
    "lng": "15.95876"
  },
  {
    "country": "PL",
    "name": "Miechów Charsznica",
    "lat": "50.39599",
    "lng": "19.95031"
  },
  {
    "country": "PL",
    "name": "Michałowice",
    "lat": "50.15898",
    "lng": "19.98044"
  },
  {
    "country": "PL",
    "name": "Miastko",
    "lat": "54.00283",
    "lng": "16.98263"
  },
  {
    "country": "PL",
    "name": "Miasteczko Śląskie",
    "lat": "50.50262",
    "lng": "18.93949"
  },
  {
    "country": "PL",
    "name": "Miasteczko Krajeńskie",
    "lat": "53.09784",
    "lng": "17.00478"
  },
  {
    "country": "PL",
    "name": "Mętków",
    "lat": "50.05251",
    "lng": "19.37525"
  },
  {
    "country": "PL",
    "name": "Mazańcowice",
    "lat": "49.85802",
    "lng": "18.97708"
  },
  {
    "country": "PL",
    "name": "Maszewo Duże",
    "lat": "52.58026",
    "lng": "19.62905"
  },
  {
    "country": "PL",
    "name": "Maszewo",
    "lat": "53.49615",
    "lng": "15.06166"
  },
  {
    "country": "PL",
    "name": "Maszewo",
    "lat": "52.06896",
    "lng": "14.90553"
  },
  {
    "country": "PL",
    "name": "Markłowice",
    "lat": "50.01695",
    "lng": "18.52098"
  },
  {
    "country": "PL",
    "name": "Marianowo",
    "lat": "53.38287",
    "lng": "15.26645"
  },
  {
    "country": "PL",
    "name": "Margonin",
    "lat": "52.97335",
    "lng": "17.09464"
  },
  {
    "country": "PL",
    "name": "Marciszów",
    "lat": "50.8447",
    "lng": "16.02116"
  },
  {
    "country": "PL",
    "name": "Małomice",
    "lat": "51.55597",
    "lng": "15.45004"
  },
  {
    "country": "PL",
    "name": "Malec",
    "lat": "49.92106",
    "lng": "19.2453"
  },
  {
    "country": "PL",
    "name": "Małdyty",
    "lat": "53.91981",
    "lng": "19.74398"
  },
  {
    "country": "PL",
    "name": "Malczyce",
    "lat": "51.22038",
    "lng": "16.49365"
  },
  {
    "country": "PL",
    "name": "Malbork",
    "lat": "54.03591",
    "lng": "19.0266"
  },
  {
    "country": "PL",
    "name": "Malanów",
    "lat": "51.95358",
    "lng": "18.39128"
  },
  {
    "country": "PL",
    "name": "Maków Podhalański",
    "lat": "49.73008",
    "lng": "19.67711"
  },
  {
    "country": "PL",
    "name": "Łyszkowice",
    "lat": "51.98551",
    "lng": "19.90654"
  },
  {
    "country": "PL",
    "name": "Łysomice",
    "lat": "53.08629",
    "lng": "18.62002"
  },
  {
    "country": "PL",
    "name": "Lyski",
    "lat": "50.11992",
    "lng": "18.39146"
  },
  {
    "country": "PL",
    "name": "Lwówek Śląski",
    "lat": "51.11074",
    "lng": "15.58582"
  },
  {
    "country": "PL",
    "name": "Lwówek",
    "lat": "52.44798",
    "lng": "16.18106"
  },
  {
    "country": "PL",
    "name": "Luzino",
    "lat": "54.56604",
    "lng": "18.10907"
  },
  {
    "country": "PL",
    "name": "Lututów",
    "lat": "51.37033",
    "lng": "18.4348"
  },
  {
    "country": "PL",
    "name": "Lutomiersk",
    "lat": "51.75376",
    "lng": "19.21097"
  },
  {
    "country": "PL",
    "name": "Lutocin",
    "lat": "52.98152",
    "lng": "19.76655"
  },
  {
    "country": "PL",
    "name": "Luszowice",
    "lat": "50.17415",
    "lng": "19.40426"
  },
  {
    "country": "PL",
    "name": "Ludźmierz",
    "lat": "49.46656",
    "lng": "19.9825"
  },
  {
    "country": "PL",
    "name": "Ludwikowice Kłodzkie",
    "lat": "50.62464",
    "lng": "16.46052"
  },
  {
    "country": "PL",
    "name": "Lubsza",
    "lat": "50.91591",
    "lng": "17.52173"
  },
  {
    "country": "PL",
    "name": "Lubsko",
    "lat": "51.78467",
    "lng": "14.97196"
  },
  {
    "country": "PL",
    "name": "Lubrza",
    "lat": "52.30418",
    "lng": "15.44317"
  },
  {
    "country": "PL",
    "name": "Lubrza",
    "lat": "50.33631",
    "lng": "17.62636"
  },
  {
    "country": "PL",
    "name": "Lubraniec",
    "lat": "52.54178",
    "lng": "18.83254"
  },
  {
    "country": "PL",
    "name": "Łubowo",
    "lat": "53.58634",
    "lng": "16.39177"
  },
  {
    "country": "PL",
    "name": "Łubowo",
    "lat": "52.51168",
    "lng": "17.45333"
  },
  {
    "country": "PL",
    "name": "Lubowidz",
    "lat": "53.11865",
    "lng": "19.84594"
  },
  {
    "country": "PL",
    "name": "Luboń",
    "lat": "52.34705",
    "lng": "16.89267"
  },
  {
    "country": "PL",
    "name": "Lubomierz",
    "lat": "51.01278",
    "lng": "15.50969"
  },
  {
    "country": "PL",
    "name": "Lubomia",
    "lat": "50.03972",
    "lng": "18.3082"
  },
  {
    "country": "PL",
    "name": "Lubniewice",
    "lat": "52.51638",
    "lng": "15.25005"
  },
  {
    "country": "PL",
    "name": "Łubnice",
    "lat": "51.16406",
    "lng": "18.29069"
  },
  {
    "country": "PL",
    "name": "Łubniany",
    "lat": "50.78597",
    "lng": "18.0011"
  },
  {
    "country": "PL",
    "name": "Lubliniec",
    "lat": "50.66897",
    "lng": "18.6844"
  },
  {
    "country": "PL",
    "name": "Lublewo Gdańskie",
    "lat": "54.28457",
    "lng": "18.50389"
  },
  {
    "country": "PL",
    "name": "Lubiszyn",
    "lat": "52.78075",
    "lng": "14.94793"
  },
  {
    "country": "PL",
    "name": "Lubin",
    "lat": "51.40089",
    "lng": "16.20149"
  },
  {
    "country": "PL",
    "name": "Lubiewo",
    "lat": "53.46542",
    "lng": "18.02994"
  },
  {
    "country": "PL",
    "name": "Lubień Kujawski",
    "lat": "52.40574",
    "lng": "19.1644"
  },
  {
    "country": "PL",
    "name": "Lubień",
    "lat": "49.71921",
    "lng": "19.97847"
  },
  {
    "country": "PL",
    "name": "Lubichowo",
    "lat": "53.85136",
    "lng": "18.39901"
  },
  {
    "country": "PL",
    "name": "Łubianka",
    "lat": "53.13864",
    "lng": "18.48115"
  },
  {
    "country": "PL",
    "name": "Lubawka",
    "lat": "50.70456",
    "lng": "16.00026"
  },
  {
    "country": "PL",
    "name": "Lubawa",
    "lat": "53.50428",
    "lng": "19.74966"
  },
  {
    "country": "PL",
    "name": "Lubasz",
    "lat": "52.85213",
    "lng": "16.52344"
  },
  {
    "country": "PL",
    "name": "Lubanie",
    "lat": "52.74689",
    "lng": "18.9194"
  },
  {
    "country": "PL",
    "name": "Lubań",
    "lat": "51.12014",
    "lng": "15.28768"
  },
  {
    "country": "PL",
    "name": "Łowicz",
    "lat": "52.10714",
    "lng": "19.94525"
  },
  {
    "country": "PL",
    "name": "Łosiów",
    "lat": "50.79096",
    "lng": "17.56594"
  },
  {
    "country": "PL",
    "name": "Łódź",
    "lat": "51.77058",
    "lng": "19.47395"
  },
  {
    "country": "PL",
    "name": "Łodygowice",
    "lat": "49.72992",
    "lng": "19.13939"
  },
  {
    "country": "PL",
    "name": "Łobżenica",
    "lat": "53.26244",
    "lng": "17.25574"
  },
  {
    "country": "PL",
    "name": "Łobodno",
    "lat": "50.93079",
    "lng": "18.9909"
  },
  {
    "country": "PL",
    "name": "Łobez",
    "lat": "53.63918",
    "lng": "15.62129"
  },
  {
    "country": "PL",
    "name": "Lniano",
    "lat": "53.52801",
    "lng": "18.21267"
  },
  {
    "country": "PL",
    "name": "Liszki",
    "lat": "50.03884",
    "lng": "19.76835"
  },
  {
    "country": "PL",
    "name": "Lisków",
    "lat": "51.83313",
    "lng": "18.39789"
  },
  {
    "country": "PL",
    "name": "Lisewo Malborskie",
    "lat": "54.09665",
    "lng": "18.82928"
  },
  {
    "country": "PL",
    "name": "Lisewo",
    "lat": "53.2958",
    "lng": "18.68714"
  },
  {
    "country": "PL",
    "name": "Lipusz",
    "lat": "54.09806",
    "lng": "17.78455"
  },
  {
    "country": "PL",
    "name": "Lipowa",
    "lat": "49.67574",
    "lng": "19.09398"
  },
  {
    "country": "PL",
    "name": "Lipno",
    "lat": "52.84436",
    "lng": "19.17852"
  },
  {
    "country": "PL",
    "name": "Lipno",
    "lat": "51.91722",
    "lng": "16.56708"
  },
  {
    "country": "PL",
    "name": "Lipnica Wielka",
    "lat": "49.47404",
    "lng": "19.63883"
  },
  {
    "country": "PL",
    "name": "Lipnica Mała",
    "lat": "49.51507",
    "lng": "19.63497"
  },
  {
    "country": "PL",
    "name": "Lipnica",
    "lat": "53.99623",
    "lng": "17.40702"
  },
  {
    "country": "PL",
    "name": "Lipka",
    "lat": "53.49601",
    "lng": "17.25085"
  },
  {
    "country": "PL",
    "name": "Lipinki Łużyckie",
    "lat": "51.63954",
    "lng": "14.99874"
  },
  {
    "country": "PL",
    "name": "Lipie",
    "lat": "51.01257",
    "lng": "18.79658"
  },
  {
    "country": "PL",
    "name": "Lipiany",
    "lat": "53.00336",
    "lng": "14.96919"
  },
  {
    "country": "PL",
    "name": "Lipce Reymontowskie",
    "lat": "51.89863",
    "lng": "19.94173"
  },
  {
    "country": "PL",
    "name": "Liniewo",
    "lat": "54.07661",
    "lng": "18.22675"
  },
  {
    "country": "PL",
    "name": "Linia",
    "lat": "54.45143",
    "lng": "17.93454"
  },
  {
    "country": "PL",
    "name": "Ligota",
    "lat": "49.89856",
    "lng": "18.9509"
  },
  {
    "country": "PL",
    "name": "Lidzbark",
    "lat": "53.26283",
    "lng": "19.82663"
  },
  {
    "country": "PL",
    "name": "Licheń Stary",
    "lat": "52.31226",
    "lng": "18.35515"
  },
  {
    "country": "PL",
    "name": "Libiąż",
    "lat": "50.10396",
    "lng": "19.31568"
  },
  {
    "country": "PL",
    "name": "Libertów",
    "lat": "49.97242",
    "lng": "19.89461"
  },
  {
    "country": "PL",
    "name": "Lgota Wielka",
    "lat": "51.14904",
    "lng": "19.32735"
  },
  {
    "country": "PL",
    "name": "Łęczyce",
    "lat": "54.59405",
    "lng": "17.85931"
  },
  {
    "country": "PL",
    "name": "Lewin Kłodzki",
    "lat": "50.40559",
    "lng": "16.29101"
  },
  {
    "country": "PL",
    "name": "Lewin Brzeski",
    "lat": "50.7487",
    "lng": "17.61688"
  },
  {
    "country": "PL",
    "name": "Leszno",
    "lat": "51.84034",
    "lng": "16.57494"
  },
  {
    "country": "PL",
    "name": "Leśnica",
    "lat": "50.43083",
    "lng": "18.18684"
  },
  {
    "country": "PL",
    "name": "Leśna",
    "lat": "51.02431",
    "lng": "15.26413"
  },
  {
    "country": "PL",
    "name": "Leśna",
    "lat": "49.67041",
    "lng": "19.12763"
  },
  {
    "country": "PL",
    "name": "Leńcze",
    "lat": "49.89895",
    "lng": "19.73539"
  },
  {
    "country": "PL",
    "name": "Lelów",
    "lat": "50.68335",
    "lng": "19.62562"
  },
  {
    "country": "PL",
    "name": "Łęknica",
    "lat": "51.54148",
    "lng": "14.73584"
  },
  {
    "country": "PL",
    "name": "Łęki Szlacheckie",
    "lat": "51.18774",
    "lng": "19.79796"
  },
  {
    "country": "PL",
    "name": "Łękawica",
    "lat": "49.72209",
    "lng": "19.26496"
  },
  {
    "country": "PL",
    "name": "Łęka Opatowska",
    "lat": "51.21231",
    "lng": "18.1071"
  },
  {
    "country": "PL",
    "name": "Łęgowo",
    "lat": "54.22641",
    "lng": "18.64277"
  },
  {
    "country": "PL",
    "name": "Legnickie Pole",
    "lat": "51.14419",
    "lng": "16.24208"
  },
  {
    "country": "PL",
    "name": "Legnica",
    "lat": "51.21006",
    "lng": "16.1619"
  },
  {
    "country": "PL",
    "name": "Lędziny",
    "lat": "50.14264",
    "lng": "19.13149"
  },
  {
    "country": "PL",
    "name": "Łęczyca",
    "lat": "52.05959",
    "lng": "19.19972"
  },
  {
    "country": "PL",
    "name": "Lębork",
    "lat": "54.53921",
    "lng": "17.75012"
  },
  {
    "country": "PL",
    "name": "Łeba",
    "lat": "54.76099",
    "lng": "17.55547"
  },
  {
    "country": "PL",
    "name": "Łazy",
    "lat": "50.42769",
    "lng": "19.39465"
  },
  {
    "country": "PL",
    "name": "Łaziska Górne",
    "lat": "50.14952",
    "lng": "18.84215"
  },
  {
    "country": "PL",
    "name": "Łaziska",
    "lat": "49.9357",
    "lng": "18.44707"
  },
  {
    "country": "PL",
    "name": "Łask",
    "lat": "51.59056",
    "lng": "19.13278"
  },
  {
    "country": "PL",
    "name": "Łasin",
    "lat": "53.51794",
    "lng": "19.08832"
  },
  {
    "country": "PL",
    "name": "Lasek",
    "lat": "49.50883",
    "lng": "19.98078"
  },
  {
    "country": "PL",
    "name": "Łanięta",
    "lat": "52.36203",
    "lng": "19.28032"
  },
  {
    "country": "PL",
    "name": "Lanckorona",
    "lat": "49.84496",
    "lng": "19.71578"
  },
  {
    "country": "PL",
    "name": "Łambinowice",
    "lat": "50.53869",
    "lng": "17.56096"
  },
  {
    "country": "PL",
    "name": "Laliki",
    "lat": "49.53446",
    "lng": "19.00549"
  },
  {
    "country": "PL",
    "name": "Łąka Prudnicka",
    "lat": "50.31061",
    "lng": "17.52809"
  },
  {
    "country": "PL",
    "name": "Łagów",
    "lat": "52.33429",
    "lng": "15.29769"
  },
  {
    "country": "PL",
    "name": "Łagów",
    "lat": "51.15835",
    "lng": "15.04372"
  },
  {
    "country": "PL",
    "name": "Łagiewniki",
    "lat": "50.79088",
    "lng": "16.84457"
  },
  {
    "country": "PL",
    "name": "Lądek-Zdrój",
    "lat": "50.34371",
    "lng": "16.87946"
  },
  {
    "country": "PL",
    "name": "Lądek",
    "lat": "52.20929",
    "lng": "17.92994"
  },
  {
    "country": "PL",
    "name": "Łączany",
    "lat": "49.98407",
    "lng": "19.57867"
  },
  {
    "country": "PL",
    "name": "Łąck",
    "lat": "52.46621",
    "lng": "19.61137"
  },
  {
    "country": "PL",
    "name": "Lachowice",
    "lat": "49.71555",
    "lng": "19.47455"
  },
  {
    "country": "PL",
    "name": "Łabiszyn",
    "lat": "52.9521",
    "lng": "17.91971"
  },
  {
    "country": "PL",
    "name": "Kwilcz",
    "lat": "52.55506",
    "lng": "16.08562"
  },
  {
    "country": "PL",
    "name": "Kwidzyn",
    "lat": "53.72495",
    "lng": "18.93114"
  },
  {
    "country": "PL",
    "name": "Kwaczała",
    "lat": "50.06408",
    "lng": "19.49215"
  },
  {
    "country": "PL",
    "name": "Kuźnia Raciborska",
    "lat": "50.20058",
    "lng": "18.31146"
  },
  {
    "country": "PL",
    "name": "Kutno",
    "lat": "52.23064",
    "lng": "19.36409"
  },
  {
    "country": "PL",
    "name": "Kuślin",
    "lat": "52.36386",
    "lng": "16.31538"
  },
  {
    "country": "PL",
    "name": "Kurzętnik",
    "lat": "53.39858",
    "lng": "19.57858"
  },
  {
    "country": "PL",
    "name": "Kup",
    "lat": "50.80659",
    "lng": "17.88351"
  },
  {
    "country": "PL",
    "name": "Kunice Żarskie",
    "lat": "51.59944",
    "lng": "15.16495"
  },
  {
    "country": "PL",
    "name": "Kunice",
    "lat": "51.22231",
    "lng": "16.24809"
  },
  {
    "country": "PL",
    "name": "Kuków",
    "lat": "49.73252",
    "lng": "19.48485"
  },
  {
    "country": "PL",
    "name": "Kudowa-Zdrój",
    "lat": "50.44297",
    "lng": "16.24397"
  },
  {
    "country": "PL",
    "name": "Książ Wielkopolski",
    "lat": "52.06167",
    "lng": "17.23952"
  },
  {
    "country": "PL",
    "name": "Książki",
    "lat": "53.3298",
    "lng": "19.07029"
  },
  {
    "country": "PL",
    "name": "Książenice",
    "lat": "50.15524",
    "lng": "18.59925"
  },
  {
    "country": "PL",
    "name": "Ksawerów",
    "lat": "51.68288",
    "lng": "19.4028"
  },
  {
    "country": "PL",
    "name": "Krzyżowice",
    "lat": "49.98528",
    "lng": "18.67281"
  },
  {
    "country": "PL",
    "name": "Krzyżowa",
    "lat": "49.59235",
    "lng": "19.34469"
  },
  {
    "country": "PL",
    "name": "Krzyżanowice",
    "lat": "49.98247",
    "lng": "18.26846"
  },
  {
    "country": "PL",
    "name": "Krzyżanów",
    "lat": "52.18409",
    "lng": "19.45619"
  },
  {
    "country": "PL",
    "name": "Krzyż Wielkopolski",
    "lat": "52.88097",
    "lng": "16.01116"
  },
  {
    "country": "PL",
    "name": "Krzywiń",
    "lat": "51.96296",
    "lng": "16.81985"
  },
  {
    "country": "PL",
    "name": "Krzywaczka",
    "lat": "49.89353",
    "lng": "19.83221"
  },
  {
    "country": "PL",
    "name": "Krzyszkowice",
    "lat": "49.88346",
    "lng": "19.92285"
  },
  {
    "country": "PL",
    "name": "Krzymów",
    "lat": "52.1896",
    "lng": "18.4311"
  },
  {
    "country": "PL",
    "name": "Krzykosy",
    "lat": "52.11041",
    "lng": "17.37411"
  },
  {
    "country": "PL",
    "name": "Krzeszyce",
    "lat": "52.58329",
    "lng": "15.00707"
  },
  {
    "country": "PL",
    "name": "Krzeszowice",
    "lat": "50.14248",
    "lng": "19.63223"
  },
  {
    "country": "PL",
    "name": "Krzeszów",
    "lat": "50.73434",
    "lng": "16.06991"
  },
  {
    "country": "PL",
    "name": "Krzeszów",
    "lat": "49.75915",
    "lng": "19.48915"
  },
  {
    "country": "PL",
    "name": "Krzepice",
    "lat": "50.97059",
    "lng": "18.72886"
  },
  {
    "country": "PL",
    "name": "Krzemieniewo",
    "lat": "51.85905",
    "lng": "16.83354"
  },
  {
    "country": "PL",
    "name": "Krzęcin",
    "lat": "53.0816",
    "lng": "15.49008"
  },
  {
    "country": "PL",
    "name": "Krzęcin",
    "lat": "49.94316",
    "lng": "19.74157"
  },
  {
    "country": "PL",
    "name": "Krzczonów",
    "lat": "49.73813",
    "lng": "19.91821"
  },
  {
    "country": "PL",
    "name": "Krzanowice",
    "lat": "50.01822",
    "lng": "18.12251"
  },
  {
    "country": "PL",
    "name": "Kryspinów",
    "lat": "50.0438",
    "lng": "19.79822"
  },
  {
    "country": "PL",
    "name": "Kryry",
    "lat": "50.01667",
    "lng": "18.80568"
  },
  {
    "country": "PL",
    "name": "Krynica Morska",
    "lat": "54.38051",
    "lng": "19.44413"
  },
  {
    "country": "PL",
    "name": "Kruszwica",
    "lat": "52.67562",
    "lng": "18.33131"
  },
  {
    "country": "PL",
    "name": "Krupski Młyn",
    "lat": "50.57337",
    "lng": "18.62251"
  },
  {
    "country": "PL",
    "name": "Krotoszyn",
    "lat": "51.69868",
    "lng": "17.43738"
  },
  {
    "country": "PL",
    "name": "Krosno Odrzańskie",
    "lat": "52.05492",
    "lng": "15.09882"
  },
  {
    "country": "PL",
    "name": "Krosno",
    "lat": "52.22357",
    "lng": "16.83251"
  },
  {
    "country": "PL",
    "name": "Krośniewice",
    "lat": "52.25592",
    "lng": "19.17037"
  },
  {
    "country": "PL",
    "name": "Krośnice",
    "lat": "51.47641",
    "lng": "17.35917"
  },
  {
    "country": "PL",
    "name": "Krokowa",
    "lat": "54.77921",
    "lng": "18.1616"
  },
  {
    "country": "PL",
    "name": "Kroczyce",
    "lat": "50.56176",
    "lng": "19.57"
  },
  {
    "country": "PL",
    "name": "Krobia",
    "lat": "51.77405",
    "lng": "16.98237"
  },
  {
    "country": "PL",
    "name": "Kraszewice",
    "lat": "51.51868",
    "lng": "18.21997"
  },
  {
    "country": "PL",
    "name": "Krapkowice",
    "lat": "50.47515",
    "lng": "17.96539"
  },
  {
    "country": "PL",
    "name": "Kramsk",
    "lat": "52.26469",
    "lng": "18.42407"
  },
  {
    "country": "PL",
    "name": "Kraków",
    "lat": "50.06143",
    "lng": "19.93658"
  },
  {
    "country": "PL",
    "name": "Krajenka",
    "lat": "53.29759",
    "lng": "16.99079"
  },
  {
    "country": "PL",
    "name": "Kozy",
    "lat": "49.84756",
    "lng": "19.14891"
  },
  {
    "country": "PL",
    "name": "Kożuchów",
    "lat": "51.74558",
    "lng": "15.59492"
  },
  {
    "country": "PL",
    "name": "Koźminek",
    "lat": "51.79874",
    "lng": "18.33893"
  },
  {
    "country": "PL",
    "name": "Koźmin Wielkopolski",
    "lat": "51.82712",
    "lng": "17.45391"
  },
  {
    "country": "PL",
    "name": "Koźle",
    "lat": "50.3356",
    "lng": "18.14332"
  },
  {
    "country": "PL",
    "name": "Kozielice",
    "lat": "53.10679",
    "lng": "14.82237"
  },
  {
    "country": "PL",
    "name": "Koziegłowy",
    "lat": "50.60035",
    "lng": "19.16299"
  },
  {
    "country": "PL",
    "name": "Kowary",
    "lat": "50.79313",
    "lng": "15.83559"
  },
  {
    "country": "PL",
    "name": "Kowalewo Pomorskie",
    "lat": "53.15432",
    "lng": "18.89868"
  },
  {
    "country": "PL",
    "name": "Kowale",
    "lat": "54.30976",
    "lng": "18.56149"
  },
  {
    "country": "PL",
    "name": "Kowal",
    "lat": "52.53019",
    "lng": "19.14767"
  },
  {
    "country": "PL",
    "name": "Kotlin",
    "lat": "51.91913",
    "lng": "17.64825"
  },
  {
    "country": "PL",
    "name": "Kotla",
    "lat": "51.74542",
    "lng": "16.03575"
  },
  {
    "country": "PL",
    "name": "Koszarawa",
    "lat": "49.64462",
    "lng": "19.40083"
  },
  {
    "country": "PL",
    "name": "Koszalin",
    "lat": "54.19438",
    "lng": "16.17222"
  },
  {
    "country": "PL",
    "name": "Kostrzyn nad Odrą",
    "lat": "52.58713",
    "lng": "14.64953"
  },
  {
    "country": "PL",
    "name": "Kostrzyn",
    "lat": "52.39847",
    "lng": "17.22811"
  },
  {
    "country": "PL",
    "name": "Koszęcin",
    "lat": "50.63411",
    "lng": "18.8413"
  },
  {
    "country": "PL",
    "name": "Kościerzyna",
    "lat": "54.12226",
    "lng": "17.98119"
  },
  {
    "country": "PL",
    "name": "Kościelisko",
    "lat": "49.29073",
    "lng": "19.88929"
  },
  {
    "country": "PL",
    "name": "Kościelec",
    "lat": "52.17425",
    "lng": "18.57067"
  },
  {
    "country": "PL",
    "name": "Kościelec",
    "lat": "50.89713",
    "lng": "19.2156"
  },
  {
    "country": "PL",
    "name": "Kościan",
    "lat": "52.08829",
    "lng": "16.64866"
  },
  {
    "country": "PL",
    "name": "Kosakowo",
    "lat": "54.58927",
    "lng": "18.48484"
  },
  {
    "country": "PL",
    "name": "Koronowo",
    "lat": "53.3137",
    "lng": "17.93698"
  },
  {
    "country": "PL",
    "name": "Kornowac",
    "lat": "50.07179",
    "lng": "18.32846"
  },
  {
    "country": "PL",
    "name": "Kórnik",
    "lat": "52.24772",
    "lng": "17.08949"
  },
  {
    "country": "PL",
    "name": "Korfantów",
    "lat": "50.48894",
    "lng": "17.59898"
  },
  {
    "country": "PL",
    "name": "Korbielów",
    "lat": "49.5682",
    "lng": "19.35001"
  },
  {
    "country": "PL",
    "name": "Konstantynów Łódzki",
    "lat": "51.74776",
    "lng": "19.32564"
  },
  {
    "country": "PL",
    "name": "Konotop",
    "lat": "51.93157",
    "lng": "15.90391"
  },
  {
    "country": "PL",
    "name": "Konopiska",
    "lat": "50.72695",
    "lng": "19.00781"
  },
  {
    "country": "PL",
    "name": "Konin",
    "lat": "52.22338",
    "lng": "18.25121"
  },
  {
    "country": "PL",
    "name": "Koniecpol",
    "lat": "50.77468",
    "lng": "19.68896"
  },
  {
    "country": "PL",
    "name": "Koniaków",
    "lat": "49.55066",
    "lng": "18.9491"
  },
  {
    "country": "PL",
    "name": "Kończyce Wielkie",
    "lat": "49.8351",
    "lng": "18.64474"
  },
  {
    "country": "PL",
    "name": "Kończyce Małe",
    "lat": "49.85824",
    "lng": "18.62964"
  },
  {
    "country": "PL",
    "name": "Konary",
    "lat": "51.6569",
    "lng": "17.04185"
  },
  {
    "country": "PL",
    "name": "Komprachcice",
    "lat": "50.63678",
    "lng": "17.82635"
  },
  {
    "country": "PL",
    "name": "Komorniki",
    "lat": "52.3387",
    "lng": "16.81063"
  },
  {
    "country": "PL",
    "name": "Koluszki",
    "lat": "51.73872",
    "lng": "19.81994"
  },
  {
    "country": "PL",
    "name": "Kolsko",
    "lat": "51.96146",
    "lng": "15.95987"
  },
  {
    "country": "PL",
    "name": "Kolonowskie",
    "lat": "50.65338",
    "lng": "18.38493"
  },
  {
    "country": "PL",
    "name": "Kołobrzeg",
    "lat": "54.17565",
    "lng": "15.58342"
  },
  {
    "country": "PL",
    "name": "Koło",
    "lat": "52.20024",
    "lng": "18.63865"
  },
  {
    "country": "PL",
    "name": "Koleczkowo",
    "lat": "54.48629",
    "lng": "18.34373"
  },
  {
    "country": "PL",
    "name": "Kołczygłowy",
    "lat": "54.23895",
    "lng": "17.23154"
  },
  {
    "country": "PL",
    "name": "Kolbudy",
    "lat": "54.26989",
    "lng": "18.46639"
  },
  {
    "country": "PL",
    "name": "Kołbaskowo",
    "lat": "53.33641",
    "lng": "14.43835"
  },
  {
    "country": "PL",
    "name": "Koczała",
    "lat": "53.90449",
    "lng": "17.06529"
  },
  {
    "country": "PL",
    "name": "Kochanowice",
    "lat": "50.70548",
    "lng": "18.74911"
  },
  {
    "country": "PL",
    "name": "Kobylnica",
    "lat": "54.43975",
    "lng": "16.99782"
  },
  {
    "country": "PL",
    "name": "Kobylnica",
    "lat": "52.44597",
    "lng": "17.07644"
  },
  {
    "country": "PL",
    "name": "Kobylin",
    "lat": "51.71645",
    "lng": "17.22682"
  },
  {
    "country": "PL",
    "name": "Kobylanka",
    "lat": "53.34492",
    "lng": "14.87143"
  },
  {
    "country": "PL",
    "name": "Kobyla Góra",
    "lat": "51.37923",
    "lng": "17.83811"
  },
  {
    "country": "PL",
    "name": "Kobiór",
    "lat": "50.06089",
    "lng": "18.93468"
  },
  {
    "country": "PL",
    "name": "Kobierzyce",
    "lat": "50.97054",
    "lng": "16.93508"
  },
  {
    "country": "PL",
    "name": "Kobiernice",
    "lat": "49.85497",
    "lng": "19.21646"
  },
  {
    "country": "PL",
    "name": "Knurów",
    "lat": "50.21971",
    "lng": "18.65067"
  },
  {
    "country": "PL",
    "name": "Kluki",
    "lat": "51.34187",
    "lng": "19.23938"
  },
  {
    "country": "PL",
    "name": "Klucze",
    "lat": "50.33565",
    "lng": "19.56236"
  },
  {
    "country": "PL",
    "name": "Kluczbork",
    "lat": "50.97281",
    "lng": "18.21816"
  },
  {
    "country": "PL",
    "name": "Klonowa",
    "lat": "51.41928",
    "lng": "18.41815"
  },
  {
    "country": "PL",
    "name": "Kłomnice",
    "lat": "50.92165",
    "lng": "19.35679"
  },
  {
    "country": "PL",
    "name": "Kłodzko",
    "lat": "50.43488",
    "lng": "16.66145"
  },
  {
    "country": "PL",
    "name": "Kłodawa",
    "lat": "52.78595",
    "lng": "15.21452"
  },
  {
    "country": "PL",
    "name": "Kłodawa",
    "lat": "52.25447",
    "lng": "18.91352"
  },
  {
    "country": "PL",
    "name": "Kłobuck",
    "lat": "50.90081",
    "lng": "18.93674"
  },
  {
    "country": "PL",
    "name": "Klikuszowa",
    "lat": "49.5193",
    "lng": "19.9849"
  },
  {
    "country": "PL",
    "name": "Kleszczów",
    "lat": "51.22355",
    "lng": "19.30418"
  },
  {
    "country": "PL",
    "name": "Kleszczewo",
    "lat": "52.33377",
    "lng": "17.17163"
  },
  {
    "country": "PL",
    "name": "Klenica",
    "lat": "51.99217",
    "lng": "15.78392"
  },
  {
    "country": "PL",
    "name": "Kleczew",
    "lat": "52.37057",
    "lng": "18.17714"
  },
  {
    "country": "PL",
    "name": "Klecza Dolna",
    "lat": "49.88291",
    "lng": "19.53764"
  },
  {
    "country": "PL",
    "name": "Kłecko",
    "lat": "52.63181",
    "lng": "17.43075"
  },
  {
    "country": "PL",
    "name": "Kiszkowo",
    "lat": "52.58871",
    "lng": "17.2663"
  },
  {
    "country": "PL",
    "name": "Kisielice",
    "lat": "53.60855",
    "lng": "19.2635"
  },
  {
    "country": "PL",
    "name": "Kikół",
    "lat": "52.90994",
    "lng": "19.12016"
  },
  {
    "country": "PL",
    "name": "Kietrz",
    "lat": "50.08042",
    "lng": "18.00432"
  },
  {
    "country": "PL",
    "name": "Kiernozia",
    "lat": "52.26858",
    "lng": "19.87092"
  },
  {
    "country": "PL",
    "name": "Kiełczów",
    "lat": "51.13999",
    "lng": "17.17798"
  },
  {
    "country": "PL",
    "name": "Kęty",
    "lat": "49.88214",
    "lng": "19.22333"
  },
  {
    "country": "PL",
    "name": "Kęsowo",
    "lat": "53.55872",
    "lng": "17.7158"
  },
  {
    "country": "PL",
    "name": "Kępno",
    "lat": "51.2784",
    "lng": "17.98908"
  },
  {
    "country": "PL",
    "name": "Kępice",
    "lat": "54.24111",
    "lng": "16.88968"
  },
  {
    "country": "PL",
    "name": "Kędzierzyn-Koźle",
    "lat": "50.34984",
    "lng": "18.22606"
  },
  {
    "country": "PL",
    "name": "Kcynia",
    "lat": "52.99192",
    "lng": "17.4883"
  },
  {
    "country": "PL",
    "name": "Kaźmierz",
    "lat": "52.51309",
    "lng": "16.58403"
  },
  {
    "country": "PL",
    "name": "Kazimierz Biskupi",
    "lat": "52.311",
    "lng": "18.16581"
  },
  {
    "country": "PL",
    "name": "Kawęczyn",
    "lat": "51.90923",
    "lng": "18.53102"
  },
  {
    "country": "PL",
    "name": "Kąty Wrocławskie",
    "lat": "51.03098",
    "lng": "16.76767"
  },
  {
    "country": "PL",
    "name": "Katowice",
    "lat": "50.25841",
    "lng": "19.02754"
  },
  {
    "country": "PL",
    "name": "Kaszów",
    "lat": "50.03884",
    "lng": "19.71934"
  },
  {
    "country": "PL",
    "name": "Kartuzy",
    "lat": "54.33424",
    "lng": "18.19735"
  },
  {
    "country": "PL",
    "name": "Karsin",
    "lat": "53.90768",
    "lng": "17.92093"
  },
  {
    "country": "PL",
    "name": "Karpacz",
    "lat": "50.77669",
    "lng": "15.75594"
  },
  {
    "country": "PL",
    "name": "Karnice",
    "lat": "54.03001",
    "lng": "15.05496"
  },
  {
    "country": "PL",
    "name": "Karlino",
    "lat": "54.03515",
    "lng": "15.87739"
  },
  {
    "country": "PL",
    "name": "Kargowa",
    "lat": "52.0714",
    "lng": "15.86138"
  },
  {
    "country": "PL",
    "name": "Kaniów",
    "lat": "49.94316",
    "lng": "19.05098"
  },
  {
    "country": "PL",
    "name": "Kamyk",
    "lat": "50.90179",
    "lng": "19.02875"
  },
  {
    "country": "PL",
    "name": "Kamieńsk",
    "lat": "51.20242",
    "lng": "19.49661"
  },
  {
    "country": "PL",
    "name": "Kamień Pomorski",
    "lat": "53.96849",
    "lng": "14.77262"
  },
  {
    "country": "PL",
    "name": "Kamiennik",
    "lat": "50.57032",
    "lng": "17.14979"
  },
  {
    "country": "PL",
    "name": "Kamienna Góra",
    "lat": "50.78314",
    "lng": "16.03037"
  },
  {
    "country": "PL",
    "name": "Kamień Krajeński",
    "lat": "53.53352",
    "lng": "17.52019"
  },
  {
    "country": "PL",
    "name": "Kamieniec Ząbkowicki",
    "lat": "50.52541",
    "lng": "16.87921"
  },
  {
    "country": "PL",
    "name": "Kamieniec Wrocławski",
    "lat": "51.07182",
    "lng": "17.18193"
  },
  {
    "country": "PL",
    "name": "Kamieniec",
    "lat": "52.16614",
    "lng": "16.46164"
  },
  {
    "country": "PL",
    "name": "Kamienica Polska",
    "lat": "50.6709",
    "lng": "19.12265"
  },
  {
    "country": "PL",
    "name": "Kamienica",
    "lat": "50.45007",
    "lng": "16.95396"
  },
  {
    "country": "PL",
    "name": "Kamień",
    "lat": "50.01215",
    "lng": "19.58536"
  },
  {
    "country": "PL",
    "name": "Kamesznica",
    "lat": "49.56469",
    "lng": "19.0212"
  },
  {
    "country": "PL",
    "name": "Kalwaria Zebrzydowska",
    "lat": "49.86759",
    "lng": "19.6772"
  },
  {
    "country": "PL",
    "name": "Kalisz Pomorski",
    "lat": "53.29908",
    "lng": "15.90631"
  },
  {
    "country": "PL",
    "name": "Kalisz",
    "lat": "51.76109",
    "lng": "18.09102"
  },
  {
    "country": "PL",
    "name": "Kaliska",
    "lat": "53.90535",
    "lng": "18.21885"
  },
  {
    "country": "PL",
    "name": "Kalety",
    "lat": "50.5627",
    "lng": "18.8926"
  },
  {
    "country": "PL",
    "name": "Kalej",
    "lat": "50.83662",
    "lng": "18.98429"
  },
  {
    "country": "PL",
    "name": "Kaczyce",
    "lat": "49.82752",
    "lng": "18.59161"
  },
  {
    "country": "PL",
    "name": "Kaczory",
    "lat": "53.10348",
    "lng": "16.88169"
  },
  {
    "country": "PL",
    "name": "Wielki Kack",
    "lat": "54.46754",
    "lng": "18.4881"
  },
  {
    "country": "PL",
    "name": "Jutrosin",
    "lat": "51.65009",
    "lng": "17.16957"
  },
  {
    "country": "PL",
    "name": "Juszczyna",
    "lat": "49.62984",
    "lng": "19.22032"
  },
  {
    "country": "PL",
    "name": "Juszczyn",
    "lat": "49.6929",
    "lng": "19.69128"
  },
  {
    "country": "PL",
    "name": "Jugów",
    "lat": "50.62758",
    "lng": "16.51812"
  },
  {
    "country": "PL",
    "name": "Jordanów Śląski",
    "lat": "50.86421",
    "lng": "16.86873"
  },
  {
    "country": "PL",
    "name": "Jordanów",
    "lat": "49.64935",
    "lng": "19.82981"
  },
  {
    "country": "PL",
    "name": "Jeżów Sudecki",
    "lat": "50.93507",
    "lng": "15.74306"
  },
  {
    "country": "PL",
    "name": "Jeżów",
    "lat": "51.81376",
    "lng": "19.96877"
  },
  {
    "country": "PL",
    "name": "Jeziora Wielkie",
    "lat": "52.53043",
    "lng": "18.26803"
  },
  {
    "country": "PL",
    "name": "Jeżewo",
    "lat": "53.51061",
    "lng": "18.49437"
  },
  {
    "country": "PL",
    "name": "Jerzmanowice",
    "lat": "50.21267",
    "lng": "19.74672"
  },
  {
    "country": "PL",
    "name": "Jenin",
    "lat": "52.69647",
    "lng": "15.09796"
  },
  {
    "country": "PL",
    "name": "Jemielno",
    "lat": "51.52434",
    "lng": "16.54326"
  },
  {
    "country": "PL",
    "name": "Jemielnica",
    "lat": "50.54573",
    "lng": "18.37807"
  },
  {
    "country": "PL",
    "name": "Jeleśnia",
    "lat": "49.64246",
    "lng": "19.32701"
  },
  {
    "country": "PL",
    "name": "Jelenia Góra",
    "lat": "50.89973",
    "lng": "15.72899"
  },
  {
    "country": "PL",
    "name": "Jelcz",
    "lat": "51.02102",
    "lng": "17.32095"
  },
  {
    "country": "PL",
    "name": "Jejkowice",
    "lat": "50.10814",
    "lng": "18.46767"
  },
  {
    "country": "PL",
    "name": "Jedlina-Zdrój",
    "lat": "50.72005",
    "lng": "16.34645"
  },
  {
    "country": "PL",
    "name": "Jaworzynka",
    "lat": "49.54019",
    "lng": "18.86996"
  },
  {
    "country": "PL",
    "name": "Jaworzyna Śląska",
    "lat": "50.9134",
    "lng": "16.43241"
  },
  {
    "country": "PL",
    "name": "Jaworzno",
    "lat": "50.20528",
    "lng": "19.27498"
  },
  {
    "country": "PL",
    "name": "Jaworze",
    "lat": "49.79351",
    "lng": "18.9479"
  },
  {
    "country": "PL",
    "name": "Jawornik",
    "lat": "49.8558",
    "lng": "19.89315"
  },
  {
    "country": "PL",
    "name": "Jawor",
    "lat": "51.05132",
    "lng": "16.19347"
  },
  {
    "country": "PL",
    "name": "Jastrzębie Zdrój",
    "lat": "49.95542",
    "lng": "18.57479"
  },
  {
    "country": "PL",
    "name": "Jastrzębia Góra",
    "lat": "54.83135",
    "lng": "18.31301"
  },
  {
    "country": "PL",
    "name": "Jastrząb",
    "lat": "50.67019",
    "lng": "19.1817"
  },
  {
    "country": "PL",
    "name": "Jastrowie",
    "lat": "53.42048",
    "lng": "16.81756"
  },
  {
    "country": "PL",
    "name": "Jastarnia",
    "lat": "54.69606",
    "lng": "18.67873"
  },
  {
    "country": "PL",
    "name": "Jasienica",
    "lat": "49.82281",
    "lng": "19.84191"
  },
  {
    "country": "PL",
    "name": "Jasienica",
    "lat": "49.81312",
    "lng": "18.92155"
  },
  {
    "country": "PL",
    "name": "Jasień",
    "lat": "51.75142",
    "lng": "15.01419"
  },
  {
    "country": "PL",
    "name": "Jaroszowice",
    "lat": "49.86267",
    "lng": "19.51962"
  },
  {
    "country": "PL",
    "name": "Jarocin",
    "lat": "51.97266",
    "lng": "17.50256"
  },
  {
    "country": "PL",
    "name": "Jaraczewo",
    "lat": "51.96854",
    "lng": "17.29707"
  },
  {
    "country": "PL",
    "name": "Januszkowice",
    "lat": "50.39189",
    "lng": "18.1368"
  },
  {
    "country": "PL",
    "name": "Janowiec Wielkopolski",
    "lat": "52.75583",
    "lng": "17.48981"
  },
  {
    "country": "PL",
    "name": "Janowice Wielkie",
    "lat": "50.87569",
    "lng": "15.92322"
  },
  {
    "country": "PL",
    "name": "Janowice",
    "lat": "49.88496",
    "lng": "19.09376"
  },
  {
    "country": "PL",
    "name": "Janków Przygodzki",
    "lat": "51.59808",
    "lng": "17.78824"
  },
  {
    "country": "PL",
    "name": "Jankowice Rybnickie",
    "lat": "50.04479",
    "lng": "18.54707"
  },
  {
    "country": "PL",
    "name": "Jankowice",
    "lat": "50.0009",
    "lng": "18.98901"
  },
  {
    "country": "PL",
    "name": "Janikowo",
    "lat": "52.75328",
    "lng": "18.11328"
  },
  {
    "country": "PL",
    "name": "Jabłonowo Pomorskie",
    "lat": "53.39137",
    "lng": "19.15509"
  },
  {
    "country": "PL",
    "name": "Jabłonna",
    "lat": "52.20598",
    "lng": "16.20741"
  },
  {
    "country": "PL",
    "name": "Jabłonka",
    "lat": "49.47968",
    "lng": "19.6937"
  },
  {
    "country": "PL",
    "name": "Izdebnik",
    "lat": "49.87218",
    "lng": "19.76801"
  },
  {
    "country": "PL",
    "name": "Izbicko",
    "lat": "50.57163",
    "lng": "18.15585"
  },
  {
    "country": "PL",
    "name": "Izbica Kujawska",
    "lat": "52.42073",
    "lng": "18.7627"
  },
  {
    "country": "PL",
    "name": "Istebna",
    "lat": "49.56319",
    "lng": "18.90567"
  },
  {
    "country": "PL",
    "name": "Inwałd",
    "lat": "49.86355",
    "lng": "19.39276"
  },
  {
    "country": "PL",
    "name": "Ińsko",
    "lat": "53.43613",
    "lng": "15.5502"
  },
  {
    "country": "PL",
    "name": "Inowrocław",
    "lat": "52.79886",
    "lng": "18.26387"
  },
  {
    "country": "PL",
    "name": "Imielin",
    "lat": "50.14534",
    "lng": "19.18599"
  },
  {
    "country": "PL",
    "name": "Iłowa",
    "lat": "51.5006",
    "lng": "15.1998"
  },
  {
    "country": "PL",
    "name": "Iława",
    "lat": "53.59601",
    "lng": "19.56849"
  },
  {
    "country": "PL",
    "name": "Huta Stara B",
    "lat": "50.73792",
    "lng": "19.13295"
  },
  {
    "country": "PL",
    "name": "Herby",
    "lat": "50.75318",
    "lng": "18.88756"
  },
  {
    "country": "PL",
    "name": "Henryków",
    "lat": "50.65327",
    "lng": "17.01027"
  },
  {
    "country": "PL",
    "name": "Hel",
    "lat": "54.60814",
    "lng": "18.8013"
  },
  {
    "country": "PL",
    "name": "Hażlach",
    "lat": "49.80714",
    "lng": "18.65178"
  },
  {
    "country": "PL",
    "name": "Harbutowice",
    "lat": "49.81235",
    "lng": "19.78045"
  },
  {
    "country": "PL",
    "name": "Gubin",
    "lat": "51.94956",
    "lng": "14.72837"
  },
  {
    "country": "PL",
    "name": "Grzmiąca",
    "lat": "53.83734",
    "lng": "16.43512"
  },
  {
    "country": "PL",
    "name": "Grzegorzew",
    "lat": "52.20177",
    "lng": "18.73409"
  },
  {
    "country": "PL",
    "name": "Grzechynia",
    "lat": "49.7136",
    "lng": "19.64561"
  },
  {
    "country": "PL",
    "name": "Gryfów Śląski",
    "lat": "51.03081",
    "lng": "15.42017"
  },
  {
    "country": "PL",
    "name": "Gryfino",
    "lat": "53.25243",
    "lng": "14.48831"
  },
  {
    "country": "PL",
    "name": "Gryfice",
    "lat": "53.9165",
    "lng": "15.20027"
  },
  {
    "country": "PL",
    "name": "Gruta",
    "lat": "53.45315",
    "lng": "18.957"
  },
  {
    "country": "PL",
    "name": "Grudziądz",
    "lat": "53.48411",
    "lng": "18.75366"
  },
  {
    "country": "PL",
    "name": "Gronowo Górne",
    "lat": "54.13863",
    "lng": "19.45988"
  },
  {
    "country": "PL",
    "name": "Gronowo Elbląskie",
    "lat": "54.08588",
    "lng": "19.30598"
  },
  {
    "country": "PL",
    "name": "Gromadka",
    "lat": "51.36063",
    "lng": "15.76452"
  },
  {
    "country": "PL",
    "name": "Grojec",
    "lat": "50.08975",
    "lng": "19.55704"
  },
  {
    "country": "PL",
    "name": "Grojec",
    "lat": "49.98147",
    "lng": "19.23792"
  },
  {
    "country": "PL",
    "name": "Grodzisk Wielkopolski",
    "lat": "52.22762",
    "lng": "16.36534"
  },
  {
    "country": "PL",
    "name": "Grodziec",
    "lat": "52.03855",
    "lng": "18.05972"
  },
  {
    "country": "PL",
    "name": "Grodków",
    "lat": "50.69836",
    "lng": "17.38449"
  },
  {
    "country": "PL",
    "name": "Grębocice",
    "lat": "51.59909",
    "lng": "16.16741"
  },
  {
    "country": "PL",
    "name": "Granowo",
    "lat": "52.22244",
    "lng": "16.52859"
  },
  {
    "country": "PL",
    "name": "Grabowo Kościerskie",
    "lat": "54.16816",
    "lng": "18.14692"
  },
  {
    "country": "PL",
    "name": "Grabów nad Prosną",
    "lat": "51.50596",
    "lng": "18.11929"
  },
  {
    "country": "PL",
    "name": "Grabów",
    "lat": "52.12717",
    "lng": "19.00257"
  },
  {
    "country": "PL",
    "name": "Grabica",
    "lat": "51.47989",
    "lng": "19.53137"
  },
  {
    "country": "PL",
    "name": "Gozdowo",
    "lat": "52.72455",
    "lng": "19.68501"
  },
  {
    "country": "PL",
    "name": "Gozdnica",
    "lat": "51.4363",
    "lng": "15.09856"
  },
  {
    "country": "PL",
    "name": "Goszczanów",
    "lat": "51.79163",
    "lng": "18.5057"
  },
  {
    "country": "PL",
    "name": "Gostynin",
    "lat": "52.42938",
    "lng": "19.46194"
  },
  {
    "country": "PL",
    "name": "Gostyń",
    "lat": "51.88247",
    "lng": "17.01225"
  },
  {
    "country": "PL",
    "name": "Gostyń",
    "lat": "50.10528",
    "lng": "18.88241"
  },
  {
    "country": "PL",
    "name": "Gostycyn",
    "lat": "53.49014",
    "lng": "17.80978"
  },
  {
    "country": "PL",
    "name": "Gościno",
    "lat": "54.05123",
    "lng": "15.65256"
  },
  {
    "country": "PL",
    "name": "Gościcino",
    "lat": "54.60459",
    "lng": "18.15491"
  },
  {
    "country": "PL",
    "name": "Gorzyczki",
    "lat": "49.94912",
    "lng": "18.4033"
  },
  {
    "country": "PL",
    "name": "Gorzyce Wielkie",
    "lat": "51.63725",
    "lng": "17.72953"
  },
  {
    "country": "PL",
    "name": "Gorzyce",
    "lat": "49.95945",
    "lng": "18.39884"
  },
  {
    "country": "PL",
    "name": "Górzyca",
    "lat": "52.49447",
    "lng": "14.65503"
  },
  {
    "country": "PL",
    "name": "Gorzów Wielkopolski",
    "lat": "52.73679",
    "lng": "15.22878"
  },
  {
    "country": "PL",
    "name": "Gorzów Śląski",
    "lat": "51.02871",
    "lng": "18.42304"
  },
  {
    "country": "PL",
    "name": "Górzno",
    "lat": "53.19779",
    "lng": "19.64317"
  },
  {
    "country": "PL",
    "name": "Gorzkowice",
    "lat": "51.21533",
    "lng": "19.59626"
  },
  {
    "country": "PL",
    "name": "Górki Wielkie",
    "lat": "49.77971",
    "lng": "18.83117"
  },
  {
    "country": "PL",
    "name": "Gorenice",
    "lat": "50.208",
    "lng": "19.62038"
  },
  {
    "country": "PL",
    "name": "Górażdże",
    "lat": "50.52903",
    "lng": "18.01003"
  },
  {
    "country": "PL",
    "name": "Góra Świętej Małgorzaty",
    "lat": "52.05713",
    "lng": "19.31997"
  },
  {
    "country": "PL",
    "name": "Góra",
    "lat": "51.66638",
    "lng": "16.53494"
  },
  {
    "country": "PL",
    "name": "Góra",
    "lat": "49.97971",
    "lng": "19.10471"
  },
  {
    "country": "PL",
    "name": "Gomunice",
    "lat": "51.1689",
    "lng": "19.49335"
  },
  {
    "country": "PL",
    "name": "Gołuchów",
    "lat": "51.85036",
    "lng": "17.9314"
  },
  {
    "country": "PL",
    "name": "Golub-Dobrzyń",
    "lat": "53.11087",
    "lng": "19.05381"
  },
  {
    "country": "PL",
    "name": "Gołkowice",
    "lat": "49.91418",
    "lng": "18.51419"
  },
  {
    "country": "PL",
    "name": "Golina",
    "lat": "52.24315",
    "lng": "18.09268"
  },
  {
    "country": "PL",
    "name": "Golina",
    "lat": "51.91489",
    "lng": "17.48268"
  },
  {
    "country": "PL",
    "name": "Goleszów",
    "lat": "49.7358",
    "lng": "18.73675"
  },
  {
    "country": "PL",
    "name": "Goleniów",
    "lat": "53.56392",
    "lng": "14.82854"
  },
  {
    "country": "PL",
    "name": "Golczewo",
    "lat": "53.82426",
    "lng": "14.97847"
  },
  {
    "country": "PL",
    "name": "Gołańcz",
    "lat": "52.94326",
    "lng": "17.29995"
  },
  {
    "country": "PL",
    "name": "Gogolin",
    "lat": "50.49222",
    "lng": "18.01994"
  },
  {
    "country": "PL",
    "name": "Godziszka",
    "lat": "49.71288",
    "lng": "19.07587"
  },
  {
    "country": "PL",
    "name": "Godów",
    "lat": "49.92481",
    "lng": "18.4783"
  },
  {
    "country": "PL",
    "name": "Goczałkowice Zdrój",
    "lat": "49.94454",
    "lng": "18.96927"
  },
  {
    "country": "PL",
    "name": "Gniezno",
    "lat": "52.53481",
    "lng": "17.58259"
  },
  {
    "country": "PL",
    "name": "Gnieżdżewo",
    "lat": "54.74741",
    "lng": "18.37944"
  },
  {
    "country": "PL",
    "name": "Gniewkowo",
    "lat": "52.89461",
    "lng": "18.40785"
  },
  {
    "country": "PL",
    "name": "Gniewino",
    "lat": "54.71709",
    "lng": "18.01663"
  },
  {
    "country": "PL",
    "name": "Gniew",
    "lat": "53.83602",
    "lng": "18.8231"
  },
  {
    "country": "PL",
    "name": "Gniechowice",
    "lat": "50.98804",
    "lng": "16.83363"
  },
  {
    "country": "PL",
    "name": "Gniazdów",
    "lat": "50.59621",
    "lng": "19.11132"
  },
  {
    "country": "PL",
    "name": "Głuszyca Górna",
    "lat": "50.66606",
    "lng": "16.37585"
  },
  {
    "country": "PL",
    "name": "Głuszyca",
    "lat": "50.68743",
    "lng": "16.37173"
  },
  {
    "country": "PL",
    "name": "Głuchołazy",
    "lat": "50.31505",
    "lng": "17.38355"
  },
  {
    "country": "PL",
    "name": "Głubczyce",
    "lat": "50.20086",
    "lng": "17.82858"
  },
  {
    "country": "PL",
    "name": "Głowno",
    "lat": "51.96463",
    "lng": "19.71565"
  },
  {
    "country": "PL",
    "name": "Główczyce",
    "lat": "54.61935",
    "lng": "17.3723"
  },
  {
    "country": "PL",
    "name": "Głogówek",
    "lat": "50.35355",
    "lng": "17.86405"
  },
  {
    "country": "PL",
    "name": "Głogów",
    "lat": "51.66361",
    "lng": "16.0845"
  },
  {
    "country": "PL",
    "name": "Głogoczów",
    "lat": "49.89452",
    "lng": "19.8741"
  },
  {
    "country": "PL",
    "name": "Gliwice",
    "lat": "50.29761",
    "lng": "18.67658"
  },
  {
    "country": "PL",
    "name": "Gizałki",
    "lat": "52.04267",
    "lng": "17.76936"
  },
  {
    "country": "PL",
    "name": "Gilowice",
    "lat": "49.99505",
    "lng": "19.09613"
  },
  {
    "country": "PL",
    "name": "Gilowice",
    "lat": "49.71277",
    "lng": "19.31045"
  },
  {
    "country": "PL",
    "name": "Gierałtowice",
    "lat": "50.22486",
    "lng": "18.73384"
  },
  {
    "country": "PL",
    "name": "Gierałtowice",
    "lat": "49.94426",
    "lng": "19.3907"
  },
  {
    "country": "PL",
    "name": "Cielmice",
    "lat": "50.08826",
    "lng": "19.01896"
  },
  {
    "country": "PL",
    "name": "Giebułtów",
    "lat": "50.14556",
    "lng": "19.87856"
  },
  {
    "country": "PL",
    "name": "Gidle",
    "lat": "50.96199",
    "lng": "19.47181"
  },
  {
    "country": "PL",
    "name": "Gdynia",
    "lat": "54.51889",
    "lng": "18.53188"
  },
  {
    "country": "PL",
    "name": "Gdańsk",
    "lat": "54.35205",
    "lng": "18.64637"
  },
  {
    "country": "PL",
    "name": "Gaworzyce",
    "lat": "51.62773",
    "lng": "15.88198"
  },
  {
    "country": "PL",
    "name": "Gaszowice",
    "lat": "50.10858",
    "lng": "18.43042"
  },
  {
    "country": "PL",
    "name": "Gąsawa",
    "lat": "52.76757",
    "lng": "17.75579"
  },
  {
    "country": "PL",
    "name": "Gardeja",
    "lat": "53.61125",
    "lng": "18.94687"
  },
  {
    "country": "PL",
    "name": "Gardawice",
    "lat": "50.11667",
    "lng": "18.8"
  },
  {
    "country": "PL",
    "name": "Garcz",
    "lat": "54.3476",
    "lng": "18.10169"
  },
  {
    "country": "PL",
    "name": "Gałków Mały",
    "lat": "51.72554",
    "lng": "19.71359"
  },
  {
    "country": "PL",
    "name": "Galewice",
    "lat": "51.34471",
    "lng": "18.25756"
  },
  {
    "country": "PL",
    "name": "Gąbin",
    "lat": "52.39849",
    "lng": "19.73509"
  },
  {
    "country": "PL",
    "name": "Frydrychowice",
    "lat": "49.90481",
    "lng": "19.41936"
  },
  {
    "country": "PL",
    "name": "Frydek",
    "lat": "49.99626",
    "lng": "19.07278"
  },
  {
    "country": "PL",
    "name": "Frombork",
    "lat": "54.35766",
    "lng": "19.68029"
  },
  {
    "country": "PL",
    "name": "Fordon",
    "lat": "53.14821",
    "lng": "18.17036"
  },
  {
    "country": "PL",
    "name": "Filipowice",
    "lat": "50.15573",
    "lng": "19.56579"
  },
  {
    "country": "PL",
    "name": "Fabianki",
    "lat": "52.71929",
    "lng": "19.10943"
  },
  {
    "country": "PL",
    "name": "Elbląg",
    "lat": "54.1522",
    "lng": "19.40884"
  },
  {
    "country": "PL",
    "name": "Dziećmorowice",
    "lat": "50.76947",
    "lng": "16.35212"
  },
  {
    "country": "PL",
    "name": "Dziwnów",
    "lat": "54.02819",
    "lng": "14.76691"
  },
  {
    "country": "PL",
    "name": "Dzierżoniów",
    "lat": "50.7282",
    "lng": "16.65141"
  },
  {
    "country": "PL",
    "name": "Dzierzgoń",
    "lat": "53.92196",
    "lng": "19.34705"
  },
  {
    "country": "PL",
    "name": "Dziergowice",
    "lat": "50.24248",
    "lng": "18.28606"
  },
  {
    "country": "PL",
    "name": "Dziemiany",
    "lat": "54.00636",
    "lng": "17.76755"
  },
  {
    "country": "PL",
    "name": "Dzięgielów",
    "lat": "49.72259",
    "lng": "18.70491"
  },
  {
    "country": "PL",
    "name": "Działoszyn",
    "lat": "51.11699",
    "lng": "18.86524"
  },
  {
    "country": "PL",
    "name": "Dziadowa Kłoda",
    "lat": "51.23543",
    "lng": "17.70919"
  },
  {
    "country": "PL",
    "name": "Dygowo",
    "lat": "54.13031",
    "lng": "15.71993"
  },
  {
    "country": "PL",
    "name": "Duszniki-Zdrój",
    "lat": "50.40327",
    "lng": "16.39091"
  },
  {
    "country": "PL",
    "name": "Duszniki",
    "lat": "52.44691",
    "lng": "16.40602"
  },
  {
    "country": "PL",
    "name": "Drzycim",
    "lat": "53.5052",
    "lng": "18.3094"
  },
  {
    "country": "PL",
    "name": "Drużbice",
    "lat": "51.46369",
    "lng": "19.39404"
  },
  {
    "country": "PL",
    "name": "Drogomyśl",
    "lat": "49.86964",
    "lng": "18.75727"
  },
  {
    "country": "PL",
    "name": "Drobin",
    "lat": "52.73775",
    "lng": "19.98928"
  },
  {
    "country": "PL",
    "name": "Drezdenko",
    "lat": "52.83831",
    "lng": "15.83079"
  },
  {
    "country": "PL",
    "name": "Drawsko Pomorskie",
    "lat": "53.53056",
    "lng": "15.80967"
  },
  {
    "country": "PL",
    "name": "Drawsko",
    "lat": "52.85421",
    "lng": "16.03125"
  },
  {
    "country": "PL",
    "name": "Drawno",
    "lat": "53.21986",
    "lng": "15.75946"
  },
  {
    "country": "PL",
    "name": "Doruchów",
    "lat": "51.41719",
    "lng": "18.07697"
  },
  {
    "country": "PL",
    "name": "Dopiewo",
    "lat": "52.35726",
    "lng": "16.67562"
  },
  {
    "country": "PL",
    "name": "Dominowo",
    "lat": "52.29158",
    "lng": "17.35754"
  },
  {
    "country": "PL",
    "name": "Domaszowice",
    "lat": "51.0429",
    "lng": "17.88875"
  },
  {
    "country": "PL",
    "name": "Domaniewice",
    "lat": "52.00623",
    "lng": "19.80294"
  },
  {
    "country": "PL",
    "name": "Dolsk",
    "lat": "51.9818",
    "lng": "17.06273"
  },
  {
    "country": "PL",
    "name": "Dolice",
    "lat": "53.19081",
    "lng": "15.20267"
  },
  {
    "country": "PL",
    "name": "Dobrzyń nad Wisłą",
    "lat": "52.63814",
    "lng": "19.31875"
  },
  {
    "country": "PL",
    "name": "Dobrzyca",
    "lat": "51.86663",
    "lng": "17.60336"
  },
  {
    "country": "PL",
    "name": "Dobrzeń Wielki",
    "lat": "50.76844",
    "lng": "17.84652"
  },
  {
    "country": "PL",
    "name": "Dobrzany",
    "lat": "53.35914",
    "lng": "15.42886"
  },
  {
    "country": "PL",
    "name": "Dobroszyce",
    "lat": "51.26776",
    "lng": "17.34205"
  },
  {
    "country": "PL",
    "name": "Dobroń",
    "lat": "51.63885",
    "lng": "19.24539"
  },
  {
    "country": "PL",
    "name": "Dobrodzień",
    "lat": "50.72874",
    "lng": "18.44501"
  },
  {
    "country": "PL",
    "name": "Dobre",
    "lat": "52.68398",
    "lng": "18.57762"
  },
  {
    "country": "PL",
    "name": "Dobra",
    "lat": "53.58625",
    "lng": "15.30977"
  },
  {
    "country": "PL",
    "name": "Dobra",
    "lat": "53.48835",
    "lng": "14.38617"
  },
  {
    "country": "PL",
    "name": "Dobra",
    "lat": "51.91664",
    "lng": "18.61556"
  },
  {
    "country": "PL",
    "name": "Dobieszowice",
    "lat": "50.39697",
    "lng": "19.01304"
  },
  {
    "country": "PL",
    "name": "Dobiegniew",
    "lat": "52.96947",
    "lng": "15.75362"
  },
  {
    "country": "PL",
    "name": "Dmosin",
    "lat": "51.92437",
    "lng": "19.75934"
  },
  {
    "country": "PL",
    "name": "Dłutów",
    "lat": "51.55936",
    "lng": "19.39198"
  },
  {
    "country": "PL",
    "name": "Długołęka",
    "lat": "51.17902",
    "lng": "17.19137"
  },
  {
    "country": "PL",
    "name": "Długomiłowice",
    "lat": "50.28298",
    "lng": "18.14873"
  },
  {
    "country": "PL",
    "name": "Deszczno",
    "lat": "52.66988",
    "lng": "15.31975"
  },
  {
    "country": "PL",
    "name": "Debrzno",
    "lat": "53.53817",
    "lng": "17.23643"
  },
  {
    "country": "PL",
    "name": "Dębowiec",
    "lat": "49.81406",
    "lng": "18.72062"
  },
  {
    "country": "PL",
    "name": "Dębowa Łąka",
    "lat": "53.25541",
    "lng": "19.09595"
  },
  {
    "country": "PL",
    "name": "Dębno",
    "lat": "52.73901",
    "lng": "14.698"
  },
  {
    "country": "PL",
    "name": "Dębnica Kaszubska",
    "lat": "54.37831",
    "lng": "17.16116"
  },
  {
    "country": "PL",
    "name": "Daszyna",
    "lat": "52.15503",
    "lng": "19.18153"
  },
  {
    "country": "PL",
    "name": "Daszewice",
    "lat": "52.30002",
    "lng": "16.95723"
  },
  {
    "country": "PL",
    "name": "Darłowo",
    "lat": "54.42095",
    "lng": "16.4107"
  },
  {
    "country": "PL",
    "name": "Damnica",
    "lat": "54.50025",
    "lng": "17.27154"
  },
  {
    "country": "PL",
    "name": "Damasławek",
    "lat": "52.83979",
    "lng": "17.50062"
  },
  {
    "country": "PL",
    "name": "Dalików",
    "lat": "51.88476",
    "lng": "19.11904"
  },
  {
    "country": "PL",
    "name": "Dalachów",
    "lat": "51.07732",
    "lng": "18.5784"
  },
  {
    "country": "PL",
    "name": "Dąbrowice",
    "lat": "52.31142",
    "lng": "19.08437"
  },
  {
    "country": "PL",
    "name": "Dąbrowa Zielona",
    "lat": "50.84394",
    "lng": "19.55652"
  },
  {
    "country": "PL",
    "name": "Dąbrowa Górnicza",
    "lat": "50.31818",
    "lng": "19.2374"
  },
  {
    "country": "PL",
    "name": "Dąbrowa Chełmińska",
    "lat": "53.17518",
    "lng": "18.30537"
  },
  {
    "country": "PL",
    "name": "Dąbrowa",
    "lat": "52.74668",
    "lng": "17.94342"
  },
  {
    "country": "PL",
    "name": "Dąbrowa",
    "lat": "50.68352",
    "lng": "17.74957"
  },
  {
    "country": "PL",
    "name": "Dąbie",
    "lat": "52.08668",
    "lng": "18.8225"
  },
  {
    "country": "PL",
    "name": "Dąbie",
    "lat": "52.01056",
    "lng": "15.15221"
  },
  {
    "country": "PL",
    "name": "Czyżowice",
    "lat": "49.9849",
    "lng": "18.40433"
  },
  {
    "country": "PL",
    "name": "Czułów",
    "lat": "50.05956",
    "lng": "19.70106"
  },
  {
    "country": "PL",
    "name": "Człuchów",
    "lat": "53.66722",
    "lng": "17.35883"
  },
  {
    "country": "PL",
    "name": "Człopa",
    "lat": "53.08856",
    "lng": "16.12098"
  },
  {
    "country": "PL",
    "name": "Częstochowa",
    "lat": "50.79646",
    "lng": "19.12409"
  },
  {
    "country": "PL",
    "name": "Czerwonak",
    "lat": "52.46459",
    "lng": "16.98169"
  },
  {
    "country": "PL",
    "name": "Czerwionka-Leszczyny",
    "lat": "50.15007",
    "lng": "18.67762"
  },
  {
    "country": "PL",
    "name": "Czerwieńsk",
    "lat": "52.01289",
    "lng": "15.42317"
  },
  {
    "country": "PL",
    "name": "Czersk",
    "lat": "53.79589",
    "lng": "17.97647"
  },
  {
    "country": "PL",
    "name": "Czernikowo",
    "lat": "52.94688",
    "lng": "18.93803"
  },
  {
    "country": "PL",
    "name": "Czerniewice",
    "lat": "52.51157",
    "lng": "19.08694"
  },
  {
    "country": "PL",
    "name": "Czerniejewo",
    "lat": "52.4264",
    "lng": "17.48925"
  },
  {
    "country": "PL",
    "name": "Czernichów",
    "lat": "49.9892",
    "lng": "19.68115"
  },
  {
    "country": "PL",
    "name": "Czernichów",
    "lat": "49.75443",
    "lng": "19.20947"
  },
  {
    "country": "PL",
    "name": "Czernica",
    "lat": "51.04609",
    "lng": "17.2451"
  },
  {
    "country": "PL",
    "name": "Czernica",
    "lat": "50.08391",
    "lng": "18.40068"
  },
  {
    "country": "PL",
    "name": "Czermin",
    "lat": "51.95008",
    "lng": "17.74957"
  },
  {
    "country": "PL",
    "name": "Czempiń",
    "lat": "52.14404",
    "lng": "16.76408"
  },
  {
    "country": "PL",
    "name": "Czeladź",
    "lat": "50.31542",
    "lng": "19.07824"
  },
  {
    "country": "PL",
    "name": "Czechowice-Dziedzice",
    "lat": "49.91342",
    "lng": "19.00479"
  },
  {
    "country": "PL",
    "name": "Czastary",
    "lat": "51.25869",
    "lng": "18.31953"
  },
  {
    "country": "PL",
    "name": "Czarny Dunajec",
    "lat": "49.43663",
    "lng": "19.85161"
  },
  {
    "country": "PL",
    "name": "Czarny Bór",
    "lat": "50.77083",
    "lng": "16.1305"
  },
  {
    "country": "PL",
    "name": "Czarnożyły",
    "lat": "51.28533",
    "lng": "18.56106"
  },
  {
    "country": "PL",
    "name": "Czarnowąsy",
    "lat": "50.72858",
    "lng": "17.89819"
  },
  {
    "country": "PL",
    "name": "Czarnocin",
    "lat": "51.59142",
    "lng": "19.68158"
  },
  {
    "country": "PL",
    "name": "Czarnków",
    "lat": "52.90214",
    "lng": "16.56413"
  },
  {
    "country": "PL",
    "name": "Czarne",
    "lat": "53.6842",
    "lng": "16.93834"
  },
  {
    "country": "PL",
    "name": "Czarna Woda",
    "lat": "53.84458",
    "lng": "18.10006"
  },
  {
    "country": "PL",
    "name": "Czarków",
    "lat": "50.01833",
    "lng": "18.90678"
  },
  {
    "country": "PL",
    "name": "Czapury",
    "lat": "52.31719",
    "lng": "16.91268"
  },
  {
    "country": "PL",
    "name": "Czaplinek",
    "lat": "53.55775",
    "lng": "16.23333"
  },
  {
    "country": "PL",
    "name": "Czaniec",
    "lat": "49.85071",
    "lng": "19.25354"
  },
  {
    "country": "PL",
    "name": "Czajków",
    "lat": "51.49197",
    "lng": "18.32726"
  },
  {
    "country": "PL",
    "name": "Cybinka",
    "lat": "52.19446",
    "lng": "14.79567"
  },
  {
    "country": "PL",
    "name": "Cisownica",
    "lat": "49.72276",
    "lng": "18.76207"
  },
  {
    "country": "PL",
    "name": "Cisiec",
    "lat": "49.59213",
    "lng": "19.1054"
  },
  {
    "country": "PL",
    "name": "Cisek",
    "lat": "50.28232",
    "lng": "18.19988"
  },
  {
    "country": "PL",
    "name": "Cieszyn",
    "lat": "49.75133",
    "lng": "18.63213"
  },
  {
    "country": "PL",
    "name": "Cieszków",
    "lat": "51.63104",
    "lng": "17.35726"
  },
  {
    "country": "PL",
    "name": "Ciepłowody",
    "lat": "50.67477",
    "lng": "16.90871"
  },
  {
    "country": "PL",
    "name": "Cieplice Śląskie Zdrój",
    "lat": "50.86545",
    "lng": "15.68367"
  },
  {
    "country": "PL",
    "name": "Cięcina",
    "lat": "49.6022",
    "lng": "19.14102"
  },
  {
    "country": "PL",
    "name": "Ciechów",
    "lat": "51.13218",
    "lng": "16.56773"
  },
  {
    "country": "PL",
    "name": "Ciechocinek",
    "lat": "52.87908",
    "lng": "18.79505"
  },
  {
    "country": "PL",
    "name": "Ciechocin",
    "lat": "53.05581",
    "lng": "18.92635"
  },
  {
    "country": "PL",
    "name": "Ciasna",
    "lat": "50.75427",
    "lng": "18.60835"
  },
  {
    "country": "PL",
    "name": "Chyżne",
    "lat": "49.42672",
    "lng": "19.66956"
  },
  {
    "country": "PL",
    "name": "Chybie",
    "lat": "49.90249",
    "lng": "18.82756"
  },
  {
    "country": "PL",
    "name": "Chwaszczyno",
    "lat": "54.44379",
    "lng": "18.41875"
  },
  {
    "country": "PL",
    "name": "Chrzypsko Wielkie",
    "lat": "52.62817",
    "lng": "16.22852"
  },
  {
    "country": "PL",
    "name": "Chrząstowice",
    "lat": "50.66622",
    "lng": "18.07294"
  },
  {
    "country": "PL",
    "name": "Chrzanów",
    "lat": "50.13546",
    "lng": "19.40203"
  },
  {
    "country": "PL",
    "name": "Chruszczobród",
    "lat": "50.4147",
    "lng": "19.32718"
  },
  {
    "country": "PL",
    "name": "Chrostkowo",
    "lat": "52.94378",
    "lng": "19.25328"
  },
  {
    "country": "PL",
    "name": "Chrościna",
    "lat": "50.66578",
    "lng": "17.81759"
  },
  {
    "country": "PL",
    "name": "Chróścice",
    "lat": "50.78076",
    "lng": "17.81227"
  },
  {
    "country": "PL",
    "name": "Choszczno",
    "lat": "53.16905",
    "lng": "15.42054"
  },
  {
    "country": "PL",
    "name": "Chorzów",
    "lat": "50.30582",
    "lng": "18.9742"
  },
  {
    "country": "PL",
    "name": "Choroń",
    "lat": "50.68178",
    "lng": "19.26058"
  },
  {
    "country": "PL",
    "name": "Chmielowice",
    "lat": "50.64957",
    "lng": "17.86669"
  },
  {
    "country": "PL",
    "name": "Chojnów",
    "lat": "51.27373",
    "lng": "15.93661"
  },
  {
    "country": "PL",
    "name": "Chojnice",
    "lat": "53.69554",
    "lng": "17.55701"
  },
  {
    "country": "PL",
    "name": "Chojna",
    "lat": "52.96389",
    "lng": "14.42797"
  },
  {
    "country": "PL",
    "name": "Chodzież",
    "lat": "52.99505",
    "lng": "16.9198"
  },
  {
    "country": "PL",
    "name": "Chodów",
    "lat": "52.24961",
    "lng": "19.01218"
  },
  {
    "country": "PL",
    "name": "Chodecz",
    "lat": "52.40513",
    "lng": "19.02759"
  },
  {
    "country": "PL",
    "name": "Chocznia",
    "lat": "49.87417",
    "lng": "19.45438"
  },
  {
    "country": "PL",
    "name": "Choczewo",
    "lat": "54.73993",
    "lng": "17.89175"
  },
  {
    "country": "PL",
    "name": "Chocz",
    "lat": "51.97642",
    "lng": "17.86995"
  },
  {
    "country": "PL",
    "name": "Chociwel",
    "lat": "53.46696",
    "lng": "15.33342"
  },
  {
    "country": "PL",
    "name": "Chocianów",
    "lat": "51.41867",
    "lng": "15.90172"
  },
  {
    "country": "PL",
    "name": "Choceń",
    "lat": "52.48618",
    "lng": "19.01339"
  },
  {
    "country": "PL",
    "name": "Chmielno",
    "lat": "54.32543",
    "lng": "18.0986"
  },
  {
    "country": "PL",
    "name": "Chłapowo",
    "lat": "54.80365",
    "lng": "18.37352"
  },
  {
    "country": "PL",
    "name": "Chełmża",
    "lat": "53.18463",
    "lng": "18.60466"
  },
  {
    "country": "PL",
    "name": "Chełm Śląski",
    "lat": "50.10825",
    "lng": "19.19552"
  },
  {
    "country": "PL",
    "name": "Chełmno",
    "lat": "53.34855",
    "lng": "18.4251"
  },
  {
    "country": "PL",
    "name": "Chełmek",
    "lat": "50.10163",
    "lng": "19.24801"
  },
  {
    "country": "PL",
    "name": "Chąśno",
    "lat": "52.19535",
    "lng": "19.94259"
  },
  {
    "country": "PL",
    "name": "Chałupki",
    "lat": "49.92559",
    "lng": "18.3173"
  },
  {
    "country": "PL",
    "name": "Cewice",
    "lat": "54.43551",
    "lng": "17.73485"
  },
  {
    "country": "PL",
    "name": "Cerkwica",
    "lat": "54.00777",
    "lng": "15.10903"
  },
  {
    "country": "PL",
    "name": "Cekcyn",
    "lat": "53.57294",
    "lng": "18.01123"
  },
  {
    "country": "PL",
    "name": "Cedynia",
    "lat": "52.87931",
    "lng": "14.20249"
  },
  {
    "country": "PL",
    "name": "Cedry Wielkie",
    "lat": "54.24707",
    "lng": "18.84567"
  },
  {
    "country": "PL",
    "name": "Bytów",
    "lat": "54.17057",
    "lng": "17.49187"
  },
  {
    "country": "PL",
    "name": "Bytoń",
    "lat": "52.55757",
    "lng": "18.59522"
  },
  {
    "country": "PL",
    "name": "Bytom Odrzański",
    "lat": "51.73062",
    "lng": "15.82362"
  },
  {
    "country": "PL",
    "name": "Bytom",
    "lat": "50.34802",
    "lng": "18.93282"
  },
  {
    "country": "PL",
    "name": "Bytnica",
    "lat": "52.15066",
    "lng": "15.16946"
  },
  {
    "country": "PL",
    "name": "Bystrzyca Kłodzka",
    "lat": "50.30179",
    "lng": "16.64231"
  },
  {
    "country": "PL",
    "name": "Bystrzyca",
    "lat": "50.96048",
    "lng": "17.39702"
  },
  {
    "country": "PL",
    "name": "Bystra",
    "lat": "49.76042",
    "lng": "19.05973"
  },
  {
    "country": "PL",
    "name": "Bystra",
    "lat": "49.64796",
    "lng": "19.77994"
  },
  {
    "country": "PL",
    "name": "Bydgoszcz",
    "lat": "53.1235",
    "lng": "18.00762"
  },
  {
    "country": "PL",
    "name": "Byczyna",
    "lat": "51.11387",
    "lng": "18.21413"
  },
  {
    "country": "PL",
    "name": "Burzenin",
    "lat": "51.46077",
    "lng": "18.83233"
  },
  {
    "country": "PL",
    "name": "Bulowice",
    "lat": "49.8765",
    "lng": "19.28873"
  },
  {
    "country": "PL",
    "name": "Bukowno",
    "lat": "50.26474",
    "lng": "19.45962"
  },
  {
    "country": "PL",
    "name": "Bukowiec",
    "lat": "53.43383",
    "lng": "18.24048"
  },
  {
    "country": "PL",
    "name": "Buk",
    "lat": "52.35532",
    "lng": "16.51958"
  },
  {
    "country": "PL",
    "name": "Bujaków",
    "lat": "49.85182",
    "lng": "19.19432"
  },
  {
    "country": "PL",
    "name": "Budzyń",
    "lat": "52.88954",
    "lng": "16.98812"
  },
  {
    "country": "PL",
    "name": "Budzów",
    "lat": "50.59337",
    "lng": "16.71038"
  },
  {
    "country": "PL",
    "name": "Budzów",
    "lat": "49.77622",
    "lng": "19.67274"
  },
  {
    "country": "PL",
    "name": "Budziszewice",
    "lat": "51.66739",
    "lng": "19.93581"
  },
  {
    "country": "PL",
    "name": "Buczkowice",
    "lat": "49.72858",
    "lng": "19.06908"
  },
  {
    "country": "PL",
    "name": "Buczek",
    "lat": "51.50228",
    "lng": "19.16419"
  },
  {
    "country": "PL",
    "name": "Brzuze",
    "lat": "53.05458",
    "lng": "19.26195"
  },
  {
    "country": "PL",
    "name": "Brzozie",
    "lat": "53.32554",
    "lng": "19.60485"
  },
  {
    "country": "PL",
    "name": "Brzeźnio",
    "lat": "51.494",
    "lng": "18.62234"
  },
  {
    "country": "PL",
    "name": "Brzeźnica",
    "lat": "49.96497",
    "lng": "19.61952"
  },
  {
    "country": "PL",
    "name": "Brzeziny Śląskie",
    "lat": "50.35439",
    "lng": "18.98129"
  },
  {
    "country": "PL",
    "name": "Brzeziny",
    "lat": "51.80023",
    "lng": "19.75144"
  },
  {
    "country": "PL",
    "name": "Brzezinka",
    "lat": "50.04237",
    "lng": "19.1902"
  },
  {
    "country": "PL",
    "name": "Brzeszcze",
    "lat": "49.98203",
    "lng": "19.15157"
  },
  {
    "country": "PL",
    "name": "Brześć Kujawski",
    "lat": "52.60532",
    "lng": "18.90173"
  },
  {
    "country": "PL",
    "name": "Brzeg Dolny",
    "lat": "51.27299",
    "lng": "16.70815"
  },
  {
    "country": "PL",
    "name": "Brzeg",
    "lat": "50.86079",
    "lng": "17.4674"
  },
  {
    "country": "PL",
    "name": "Brusy",
    "lat": "53.88446",
    "lng": "17.71786"
  },
  {
    "country": "PL",
    "name": "Brudzew",
    "lat": "52.09949",
    "lng": "18.60432"
  },
  {
    "country": "PL",
    "name": "Brudzeń Duży",
    "lat": "52.66884",
    "lng": "19.50399"
  },
  {
    "country": "PL",
    "name": "Bronów",
    "lat": "49.87782",
    "lng": "18.92103"
  },
  {
    "country": "PL",
    "name": "Brojce",
    "lat": "53.95705",
    "lng": "15.35975"
  },
  {
    "country": "PL",
    "name": "Brójce",
    "lat": "52.31745",
    "lng": "15.67414"
  },
  {
    "country": "PL",
    "name": "Brójce",
    "lat": "51.66436",
    "lng": "19.64802"
  },
  {
    "country": "PL",
    "name": "Brody",
    "lat": "51.79046",
    "lng": "14.77335"
  },
  {
    "country": "PL",
    "name": "Brody",
    "lat": "49.86742",
    "lng": "19.69746"
  },
  {
    "country": "PL",
    "name": "Brodnica",
    "lat": "53.25967",
    "lng": "19.39653"
  },
  {
    "country": "PL",
    "name": "Brodnica",
    "lat": "52.14123",
    "lng": "16.89096"
  },
  {
    "country": "PL",
    "name": "Brodła",
    "lat": "50.04331",
    "lng": "19.58879"
  },
  {
    "country": "PL",
    "name": "Brenno",
    "lat": "51.92257",
    "lng": "16.21488"
  },
  {
    "country": "PL",
    "name": "Brenna",
    "lat": "49.72576",
    "lng": "18.90249"
  },
  {
    "country": "PL",
    "name": "Brdów",
    "lat": "52.3539",
    "lng": "18.7298"
  },
  {
    "country": "PL",
    "name": "Brąszewice",
    "lat": "51.49902",
    "lng": "18.44982"
  },
  {
    "country": "PL",
    "name": "Braniewo",
    "lat": "54.37971",
    "lng": "19.81959"
  },
  {
    "country": "PL",
    "name": "Branice",
    "lat": "50.05108",
    "lng": "17.79399"
  },
  {
    "country": "PL",
    "name": "Bralin",
    "lat": "51.28581",
    "lng": "17.90325"
  },
  {
    "country": "PL",
    "name": "Bozkow",
    "lat": "50.51315",
    "lng": "16.57528"
  },
  {
    "country": "PL",
    "name": "Borzytuchom",
    "lat": "54.20021",
    "lng": "17.36801"
  },
  {
    "country": "PL",
    "name": "Borzęta",
    "lat": "49.86228",
    "lng": "19.97924"
  },
  {
    "country": "PL",
    "name": "Borucin",
    "lat": "50.00763",
    "lng": "18.15748"
  },
  {
    "country": "PL",
    "name": "Borowno",
    "lat": "50.93247",
    "lng": "19.2738"
  },
  {
    "country": "PL",
    "name": "Boronów",
    "lat": "50.6746",
    "lng": "18.90678"
  },
  {
    "country": "PL",
    "name": "Borek Wielkopolski",
    "lat": "51.91674",
    "lng": "17.24133"
  },
  {
    "country": "PL",
    "name": "Boniewo",
    "lat": "52.46532",
    "lng": "18.89116"
  },
  {
    "country": "PL",
    "name": "Bolszewo",
    "lat": "54.61801",
    "lng": "18.17585"
  },
  {
    "country": "PL",
    "name": "Bolków",
    "lat": "50.92203",
    "lng": "16.10111"
  },
  {
    "country": "PL",
    "name": "Boleszkowice",
    "lat": "52.72493",
    "lng": "14.56901"
  },
  {
    "country": "PL",
    "name": "Bolesławiec",
    "lat": "51.26418",
    "lng": "15.5697"
  },
  {
    "country": "PL",
    "name": "Bolesławiec",
    "lat": "51.19866",
    "lng": "18.19147"
  },
  {
    "country": "PL",
    "name": "Bolesław",
    "lat": "50.29729",
    "lng": "19.48073"
  },
  {
    "country": "PL",
    "name": "Bolęcin",
    "lat": "50.1175",
    "lng": "19.48116"
  },
  {
    "country": "PL",
    "name": "Bolechowice",
    "lat": "50.14831",
    "lng": "19.79273"
  },
  {
    "country": "PL",
    "name": "Bojszowy Nowe",
    "lat": "50.05284",
    "lng": "19.05012"
  },
  {
    "country": "PL",
    "name": "Bojszowy",
    "lat": "50.0578",
    "lng": "19.10145"
  },
  {
    "country": "PL",
    "name": "Bojanowo Stare",
    "lat": "51.99302",
    "lng": "16.58369"
  },
  {
    "country": "PL",
    "name": "Bojanowo",
    "lat": "51.70749",
    "lng": "16.74827"
  },
  {
    "country": "PL",
    "name": "Bojano",
    "lat": "54.47123",
    "lng": "18.38408"
  },
  {
    "country": "PL",
    "name": "Bojadła",
    "lat": "51.95321",
    "lng": "15.81036"
  },
  {
    "country": "PL",
    "name": "Boguszów-Gorce",
    "lat": "50.75514",
    "lng": "16.20494"
  },
  {
    "country": "PL",
    "name": "Bogdaniec",
    "lat": "52.68897",
    "lng": "15.07127"
  },
  {
    "country": "PL",
    "name": "Bogatynia",
    "lat": "50.90747",
    "lng": "14.95634"
  },
  {
    "country": "PL",
    "name": "Bobrowo",
    "lat": "53.28549",
    "lng": "19.27053"
  },
  {
    "country": "PL",
    "name": "Bobrowniki",
    "lat": "52.78086",
    "lng": "18.96026"
  },
  {
    "country": "PL",
    "name": "Bobrowniki",
    "lat": "50.37985",
    "lng": "18.98661"
  },
  {
    "country": "PL",
    "name": "Bobrowice",
    "lat": "51.9485",
    "lng": "15.09058"
  },
  {
    "country": "PL",
    "name": "Bobowo",
    "lat": "53.88378",
    "lng": "18.55681"
  },
  {
    "country": "PL",
    "name": "Bobolice",
    "lat": "53.95508",
    "lng": "16.58893"
  },
  {
    "country": "PL",
    "name": "Blizanów",
    "lat": "51.90372",
    "lng": "18.01003"
  },
  {
    "country": "PL",
    "name": "Bledzew",
    "lat": "52.51711",
    "lng": "15.41382"
  },
  {
    "country": "PL",
    "name": "Błaszki",
    "lat": "51.65163",
    "lng": "18.43472"
  },
  {
    "country": "PL",
    "name": "Blachownia",
    "lat": "50.78015",
    "lng": "18.96389"
  },
  {
    "country": "PL",
    "name": "Bieżuń",
    "lat": "52.96107",
    "lng": "19.88976"
  },
  {
    "country": "PL",
    "name": "Bierzwnik",
    "lat": "53.03567",
    "lng": "15.665"
  },
  {
    "country": "PL",
    "name": "Bierutów",
    "lat": "51.12443",
    "lng": "17.54607"
  },
  {
    "country": "PL",
    "name": "Bieruń",
    "lat": "50.09",
    "lng": "19.09291"
  },
  {
    "country": "PL",
    "name": "Bierdzany",
    "lat": "50.81852",
    "lng": "18.15808"
  },
  {
    "country": "PL",
    "name": "Bierawa",
    "lat": "50.28111",
    "lng": "18.24177"
  },
  {
    "country": "PL",
    "name": "Bieńkówka",
    "lat": "49.776",
    "lng": "19.77179"
  },
  {
    "country": "PL",
    "name": "Bielsko-Biala",
    "lat": "49.82245",
    "lng": "19.04686"
  },
  {
    "country": "PL",
    "name": "Bielsk",
    "lat": "52.6718",
    "lng": "19.805"
  },
  {
    "country": "PL",
    "name": "Bielice",
    "lat": "53.20022",
    "lng": "14.7276"
  },
  {
    "country": "PL",
    "name": "Bielawy",
    "lat": "52.07539",
    "lng": "19.65557"
  },
  {
    "country": "PL",
    "name": "Bielawa",
    "lat": "50.69075",
    "lng": "16.623"
  },
  {
    "country": "PL",
    "name": "Bielany Wrocławskie",
    "lat": "51.0361",
    "lng": "16.9677"
  },
  {
    "country": "PL",
    "name": "Biały Bór",
    "lat": "53.8967",
    "lng": "16.83543"
  },
  {
    "country": "PL",
    "name": "Białośliwie",
    "lat": "53.10461",
    "lng": "17.12533"
  },
  {
    "country": "PL",
    "name": "Białogard",
    "lat": "54.00696",
    "lng": "15.98751"
  },
  {
    "country": "PL",
    "name": "Białe Błota",
    "lat": "53.09516",
    "lng": "17.91621"
  },
  {
    "country": "PL",
    "name": "Biała",
    "lat": "50.38587",
    "lng": "17.66035"
  },
  {
    "country": "PL",
    "name": "Białka",
    "lat": "49.69306",
    "lng": "19.67033"
  },
  {
    "country": "PL",
    "name": "Bestwinka",
    "lat": "49.93272",
    "lng": "19.06694"
  },
  {
    "country": "PL",
    "name": "Bestwina",
    "lat": "49.89712",
    "lng": "19.05776"
  },
  {
    "country": "PL",
    "name": "Bełsznica",
    "lat": "49.97811",
    "lng": "18.36313"
  },
  {
    "country": "PL",
    "name": "Bełk",
    "lat": "50.13048",
    "lng": "18.71667"
  },
  {
    "country": "PL",
    "name": "Bełchatów",
    "lat": "51.36883",
    "lng": "19.35671"
  },
  {
    "country": "PL",
    "name": "Będzin",
    "lat": "50.32607",
    "lng": "19.12565"
  },
  {
    "country": "PL",
    "name": "Bedlno",
    "lat": "52.20829",
    "lng": "19.57592"
  },
  {
    "country": "PL",
    "name": "Będków",
    "lat": "51.58763",
    "lng": "19.74956"
  },
  {
    "country": "PL",
    "name": "Bęczarka",
    "lat": "49.87793",
    "lng": "19.86723"
  },
  {
    "country": "PL",
    "name": "Bębło",
    "lat": "50.18053",
    "lng": "19.78741"
  },
  {
    "country": "PL",
    "name": "Bażanowice",
    "lat": "49.73791",
    "lng": "18.70345"
  },
  {
    "country": "PL",
    "name": "Barwice",
    "lat": "53.7449",
    "lng": "16.3553"
  },
  {
    "country": "PL",
    "name": "Barwałd Średni",
    "lat": "49.86632",
    "lng": "19.5936"
  },
  {
    "country": "PL",
    "name": "Barwałd Górny",
    "lat": "49.86211",
    "lng": "19.61746"
  },
  {
    "country": "PL",
    "name": "Baruchowo",
    "lat": "52.49412",
    "lng": "19.26496"
  },
  {
    "country": "PL",
    "name": "Barlinek",
    "lat": "52.99464",
    "lng": "15.21864"
  },
  {
    "country": "PL",
    "name": "Bardo",
    "lat": "50.50589",
    "lng": "16.73986"
  },
  {
    "country": "PL",
    "name": "Barcin",
    "lat": "52.86607",
    "lng": "17.94625"
  },
  {
    "country": "PL",
    "name": "Baranów",
    "lat": "51.26342",
    "lng": "18.0047"
  },
  {
    "country": "PL",
    "name": "Banino",
    "lat": "54.39215",
    "lng": "18.40622"
  },
  {
    "country": "PL",
    "name": "Banie",
    "lat": "53.10031",
    "lng": "14.66228"
  },
  {
    "country": "PL",
    "name": "Balin",
    "lat": "50.16799",
    "lng": "19.3834"
  },
  {
    "country": "PL",
    "name": "Balice",
    "lat": "50.08799",
    "lng": "19.79462"
  },
  {
    "country": "PL",
    "name": "Bąków",
    "lat": "49.89342",
    "lng": "18.71495"
  },
  {
    "country": "PL",
    "name": "Bachowice",
    "lat": "49.95812",
    "lng": "19.49369"
  },
  {
    "country": "PL",
    "name": "Baborów",
    "lat": "50.1576",
    "lng": "17.98513"
  },
  {
    "country": "PL",
    "name": "Babimost",
    "lat": "52.16488",
    "lng": "15.82769"
  },
  {
    "country": "PL",
    "name": "Babice",
    "lat": "50.06882",
    "lng": "19.44906"
  },
  {
    "country": "PL",
    "name": "Babice",
    "lat": "50.05565",
    "lng": "19.19955"
  },
  {
    "country": "PL",
    "name": "Babiak",
    "lat": "52.3453",
    "lng": "18.66663"
  },
  {
    "country": "PL",
    "name": "Andrychów",
    "lat": "49.85497",
    "lng": "19.33834"
  },
  {
    "country": "PL",
    "name": "Andrespol",
    "lat": "51.72783",
    "lng": "19.64175"
  },
  {
    "country": "PL",
    "name": "Alwernia",
    "lat": "50.06056",
    "lng": "19.53953"
  },
  {
    "country": "PL",
    "name": "Aleksandrów Łódzki",
    "lat": "51.81965",
    "lng": "19.30384"
  },
  {
    "country": "PL",
    "name": "Aleksandrów Kujawski",
    "lat": "52.87659",
    "lng": "18.69345"
  },
  {
    "country": "PL",
    "name": "Aleksandrów",
    "lat": "51.27126",
    "lng": "19.99005"
  },
  {
    "country": "PL",
    "name": "Ursynów",
    "lat": "52.15051",
    "lng": "21.05041"
  },
  {
    "country": "PL",
    "name": "Praga Północ",
    "lat": "52.25443",
    "lng": "21.03472"
  },
  {
    "country": "PL",
    "name": "Praga Południe",
    "lat": "52.24424",
    "lng": "21.08545"
  },
  {
    "country": "PL",
    "name": "Krościenko nad Dunajcem",
    "lat": "49.44081",
    "lng": "20.42624"
  },
  {
    "country": "PL",
    "name": "Grzybowo",
    "lat": "54.15892",
    "lng": "15.48557"
  },
  {
    "country": "PL",
    "name": "Rzgów",
    "lat": "51.66345",
    "lng": "19.49181"
  },
  {
    "country": "PL",
    "name": "Jelcz Laskowice",
    "lat": "51.02134",
    "lng": "17.31649"
  },
  {
    "country": "PL",
    "name": "Brody-Parcele",
    "lat": "52.47797",
    "lng": "20.74974"
  },
  {
    "country": "PL",
    "name": "Sztutowo",
    "lat": "54.32679",
    "lng": "19.17921"
  },
  {
    "country": "PL",
    "name": "Żarki-Letnisko",
    "lat": "50.62295",
    "lng": "19.27508"
  },
  {
    "country": "PL",
    "name": "Ostrówek",
    "lat": "52.38938",
    "lng": "21.36738"
  },
  {
    "country": "PL",
    "name": "Pogórze",
    "lat": "49.79961",
    "lng": "18.84327"
  },
  {
    "country": "PL",
    "name": "Podebłocie",
    "lat": "51.64023",
    "lng": "21.7442"
  },
  {
    "country": "PL",
    "name": "Sulbiny Górne",
    "lat": "51.87321",
    "lng": "21.63174"
  },
  {
    "country": "PL",
    "name": "Biskupiec",
    "lat": "53.50056",
    "lng": "19.35056"
  },
  {
    "country": "PL",
    "name": "Ruda-Huta",
    "lat": "51.23666",
    "lng": "23.59486"
  },
  {
    "country": "PL",
    "name": "Iłowo -Osada",
    "lat": "53.16808",
    "lng": "20.29295"
  },
  {
    "country": "PL",
    "name": "Koszyce Wielkie",
    "lat": "49.98076",
    "lng": "20.94552"
  },
  {
    "country": "PL",
    "name": "Radwanice",
    "lat": "51.57083",
    "lng": "15.94803"
  },
  {
    "country": "PL",
    "name": "Rutki-Kossaki",
    "lat": "53.08932",
    "lng": "22.44011"
  },
  {
    "country": "PL",
    "name": "Zalesie",
    "lat": "50.01226",
    "lng": "22.53262"
  },
  {
    "country": "PL",
    "name": "Bartniczka",
    "lat": "53.24776",
    "lng": "19.60433"
  },
  {
    "country": "PL",
    "name": "Lubicz Dolny",
    "lat": "53.03151",
    "lng": "18.74559"
  },
  {
    "country": "PL",
    "name": "Lubicz Górny",
    "lat": "53.02686",
    "lng": "18.771"
  },
  {
    "country": "PL",
    "name": "Tomaszkowice",
    "lat": "49.97918",
    "lng": "20.09966"
  },
  {
    "country": "PL",
    "name": "Chotcza",
    "lat": "51.24043",
    "lng": "21.77662"
  },
  {
    "country": "PL",
    "name": "Biała",
    "lat": "52.60524",
    "lng": "19.64956"
  },
  {
    "country": "PL",
    "name": "Mała Wieś",
    "lat": "52.45779",
    "lng": "20.10223"
  },
  {
    "country": "PL",
    "name": "Baranowo",
    "lat": "52.43525",
    "lng": "16.78631"
  },
  {
    "country": "PL",
    "name": "Wiśniewo",
    "lat": "53.06474",
    "lng": "20.34805"
  },
  {
    "country": "PL",
    "name": "Izabelin",
    "lat": "52.29992",
    "lng": "20.81729"
  },
  {
    "country": "PL",
    "name": "Świercze",
    "lat": "52.67055",
    "lng": "20.7639"
  },
  {
    "country": "PL",
    "name": "Łętownia",
    "lat": "49.69745",
    "lng": "19.87109"
  },
  {
    "country": "PL",
    "name": "Broniszewice",
    "lat": "51.96696",
    "lng": "17.81648"
  },
  {
    "country": "PL",
    "name": "Czarna Dąbrówka",
    "lat": "54.35631",
    "lng": "17.56456"
  },
  {
    "country": "PL",
    "name": "Skarbimierz Osiedle",
    "lat": "50.84584",
    "lng": "17.41865"
  },
  {
    "country": "PL",
    "name": "Wilczyce",
    "lat": "51.12944",
    "lng": "17.15472"
  },
  {
    "country": "PL",
    "name": "Krzczonów",
    "lat": "51.00727",
    "lng": "22.71097"
  },
  {
    "country": "PL",
    "name": "Bełżec",
    "lat": "50.38453",
    "lng": "23.43839"
  },
  {
    "country": "PL",
    "name": "Godziszów Pierwszy",
    "lat": "50.75753",
    "lng": "22.48386"
  },
  {
    "country": "PL",
    "name": "Rokiciny-Kolonia",
    "lat": "51.66468",
    "lng": "19.78312"
  },
  {
    "country": "PL",
    "name": "Nowe Ostrowy",
    "lat": "52.30318",
    "lng": "19.19217"
  },
  {
    "country": "PL",
    "name": "Kocierzew Południowy",
    "lat": "52.21728",
    "lng": "20.01812"
  },
  {
    "country": "PL",
    "name": "Zdziechowice Drugie",
    "lat": "50.78478",
    "lng": "22.10999"
  },
  {
    "country": "PL",
    "name": "Chróścina",
    "lat": "50.62306",
    "lng": "17.36861"
  },
  {
    "country": "PL",
    "name": "Mirków",
    "lat": "51.16105",
    "lng": "17.17026"
  },
  {
    "country": "PL",
    "name": "Radwanice",
    "lat": "51.05413",
    "lng": "17.10932"
  },
  {
    "country": "PL",
    "name": "Rotmanka",
    "lat": "54.27425",
    "lng": "18.6038"
  },
  {
    "country": "PL",
    "name": "Nowe Grocholice",
    "lat": "52.15924",
    "lng": "20.9111"
  },
  {
    "country": "PM",
    "name": "Saint-Pierre",
    "lat": "46.77914",
    "lng": "-56.1773"
  },
  {
    "country": "PM",
    "name": "Miquelon",
    "lat": "47.0975",
    "lng": "-56.38139"
  },
  {
    "country": "PN",
    "name": "Adamstown",
    "lat": "-25.06597",
    "lng": "-130.10147"
  },
  {
    "country": "PR",
    "name": "Aceitunas",
    "lat": "18.44328",
    "lng": "-67.0649"
  },
  {
    "country": "PR",
    "name": "Adjuntas",
    "lat": "18.16274",
    "lng": "-66.72212"
  },
  {
    "country": "PR",
    "name": "Aguada",
    "lat": "18.37939",
    "lng": "-67.18824"
  },
  {
    "country": "PR",
    "name": "Aguadilla",
    "lat": "18.42745",
    "lng": "-67.15407"
  },
  {
    "country": "PR",
    "name": "Aguas Buenas",
    "lat": "18.2569",
    "lng": "-66.10294"
  },
  {
    "country": "PR",
    "name": "Aguas Claras",
    "lat": "18.25273",
    "lng": "-65.6535"
  },
  {
    "country": "PR",
    "name": "Aguilita",
    "lat": "18.0233",
    "lng": "-66.53462"
  },
  {
    "country": "PR",
    "name": "Aibonito",
    "lat": "18.13996",
    "lng": "-66.266"
  },
  {
    "country": "PR",
    "name": "Añasco",
    "lat": "18.28273",
    "lng": "-67.13962"
  },
  {
    "country": "PR",
    "name": "Animas",
    "lat": "18.4455",
    "lng": "-66.6349"
  },
  {
    "country": "PR",
    "name": "Antón Ruiz",
    "lat": "18.18524",
    "lng": "-65.8085"
  },
  {
    "country": "PR",
    "name": "Arecibo",
    "lat": "18.47245",
    "lng": "-66.71573"
  },
  {
    "country": "PR",
    "name": "Arroyo",
    "lat": "17.9658",
    "lng": "-66.06128"
  },
  {
    "country": "PR",
    "name": "Bairoa",
    "lat": "18.25912",
    "lng": "-66.04044"
  },
  {
    "country": "PR",
    "name": "Bajadero",
    "lat": "18.42661",
    "lng": "-66.68323"
  },
  {
    "country": "PR",
    "name": "Bajandas",
    "lat": "18.15774",
    "lng": "-65.78155"
  },
  {
    "country": "PR",
    "name": "Barahona",
    "lat": "18.35134",
    "lng": "-66.44545"
  },
  {
    "country": "PR",
    "name": "Barceloneta",
    "lat": "18.4505",
    "lng": "-66.53851"
  },
  {
    "country": "PR",
    "name": "Barranquitas",
    "lat": "18.18662",
    "lng": "-66.30628"
  },
  {
    "country": "PR",
    "name": "Bartolo",
    "lat": "18.36134",
    "lng": "-65.8385"
  },
  {
    "country": "PR",
    "name": "Bayamón",
    "lat": "18.39856",
    "lng": "-66.15572"
  },
  {
    "country": "PR",
    "name": "Bayamon",
    "lat": "18.17774",
    "lng": "-66.11322"
  },
  {
    "country": "PR",
    "name": "Benitez",
    "lat": "18.27357",
    "lng": "-65.87905"
  },
  {
    "country": "PR",
    "name": "Boquerón",
    "lat": "18.02691",
    "lng": "-67.16907"
  },
  {
    "country": "PR",
    "name": "Boqueron",
    "lat": "18.20746",
    "lng": "-65.8485"
  },
  {
    "country": "PR",
    "name": "Brenas",
    "lat": "18.46717",
    "lng": "-66.341"
  },
  {
    "country": "PR",
    "name": "Buena Vista",
    "lat": "17.99635",
    "lng": "-66.05183"
  },
  {
    "country": "PR",
    "name": "Bufalo",
    "lat": "18.41828",
    "lng": "-66.57323"
  },
  {
    "country": "PR",
    "name": "Caban",
    "lat": "18.44328",
    "lng": "-67.13601"
  },
  {
    "country": "PR",
    "name": "Cabo Rojo",
    "lat": "18.08663",
    "lng": "-67.14573"
  },
  {
    "country": "PR",
    "name": "Cacao",
    "lat": "18.43661",
    "lng": "-66.93712"
  },
  {
    "country": "PR",
    "name": "Caguas",
    "lat": "18.23412",
    "lng": "-66.0485"
  },
  {
    "country": "PR",
    "name": "Campanilla",
    "lat": "18.42134",
    "lng": "-66.23683"
  },
  {
    "country": "PR",
    "name": "Campo Rico",
    "lat": "18.33717",
    "lng": "-65.89794"
  },
  {
    "country": "PR",
    "name": "Camuy",
    "lat": "18.48383",
    "lng": "-66.8449"
  },
  {
    "country": "PR",
    "name": "Candelaria",
    "lat": "18.40411",
    "lng": "-66.20878"
  },
  {
    "country": "PR",
    "name": "Candelaria Arenas",
    "lat": "18.41717",
    "lng": "-66.21739"
  },
  {
    "country": "PR",
    "name": "Candelero Arriba",
    "lat": "18.10191",
    "lng": "-65.83683"
  },
  {
    "country": "PR",
    "name": "Canovanas",
    "lat": "18.3751",
    "lng": "-65.89934"
  },
  {
    "country": "PR",
    "name": "Capitanejo",
    "lat": "18.01454",
    "lng": "-66.53372"
  },
  {
    "country": "PR",
    "name": "Carolina",
    "lat": "18.38078",
    "lng": "-65.95739"
  },
  {
    "country": "PR",
    "name": "Carrizales",
    "lat": "18.48189",
    "lng": "-66.7899"
  },
  {
    "country": "PR",
    "name": "Cataño",
    "lat": "18.44134",
    "lng": "-66.11822"
  },
  {
    "country": "PR",
    "name": "Cayey",
    "lat": "18.11191",
    "lng": "-66.166"
  },
  {
    "country": "PR",
    "name": "Cayuco",
    "lat": "18.29106",
    "lng": "-66.73934"
  },
  {
    "country": "PR",
    "name": "Ceiba",
    "lat": "18.26412",
    "lng": "-65.6485"
  },
  {
    "country": "PR",
    "name": "Ceiba",
    "lat": "18.44634",
    "lng": "-66.35073"
  },
  {
    "country": "PR",
    "name": "Celada",
    "lat": "18.27162",
    "lng": "-65.966"
  },
  {
    "country": "PR",
    "name": "Central Aguirre",
    "lat": "17.95358",
    "lng": "-66.22294"
  },
  {
    "country": "PR",
    "name": "Ciales",
    "lat": "18.33606",
    "lng": "-66.46878"
  },
  {
    "country": "PR",
    "name": "Cidra",
    "lat": "18.17579",
    "lng": "-66.16128"
  },
  {
    "country": "PR",
    "name": "Coamo",
    "lat": "18.07996",
    "lng": "-66.35795"
  },
  {
    "country": "PR",
    "name": "Coco",
    "lat": "18.00719",
    "lng": "-66.25933"
  },
  {
    "country": "PR",
    "name": "Comerío",
    "lat": "18.21801",
    "lng": "-66.226"
  },
  {
    "country": "PR",
    "name": "Comunas",
    "lat": "18.08719",
    "lng": "-65.84377"
  },
  {
    "country": "PR",
    "name": "Coquí",
    "lat": "17.97413",
    "lng": "-66.22711"
  },
  {
    "country": "PR",
    "name": "Corazón",
    "lat": "17.99274",
    "lng": "-66.08489"
  },
  {
    "country": "PR",
    "name": "Corcovado",
    "lat": "18.45856",
    "lng": "-66.77629"
  },
  {
    "country": "PR",
    "name": "Corozal",
    "lat": "18.34106",
    "lng": "-66.31684"
  },
  {
    "country": "PR",
    "name": "Coto Laurel",
    "lat": "18.04969",
    "lng": "-66.55128"
  },
  {
    "country": "PR",
    "name": "Coto Norte",
    "lat": "18.43078",
    "lng": "-66.43989"
  },
  {
    "country": "PR",
    "name": "Culebra",
    "lat": "18.30301",
    "lng": "-65.30099"
  },
  {
    "country": "PR",
    "name": "Daguao",
    "lat": "18.22635",
    "lng": "-65.68322"
  },
  {
    "country": "PR",
    "name": "Dorado",
    "lat": "18.45883",
    "lng": "-66.26767"
  },
  {
    "country": "PR",
    "name": "Duque",
    "lat": "18.23669",
    "lng": "-65.74172"
  },
  {
    "country": "PR",
    "name": "El Mangó",
    "lat": "18.23412",
    "lng": "-65.87961"
  },
  {
    "country": "PR",
    "name": "El Negro",
    "lat": "18.03747",
    "lng": "-65.85127"
  },
  {
    "country": "PR",
    "name": "El Ojo",
    "lat": "18.00385",
    "lng": "-66.39156"
  },
  {
    "country": "PR",
    "name": "Emajagua",
    "lat": "18.00052",
    "lng": "-65.88266"
  },
  {
    "country": "PR",
    "name": "Esperanza",
    "lat": "18.09719",
    "lng": "-65.47071"
  },
  {
    "country": "PR",
    "name": "Espino",
    "lat": "18.27634",
    "lng": "-67.11935"
  },
  {
    "country": "PR",
    "name": "Estancias de Florida",
    "lat": "18.36662",
    "lng": "-66.56962"
  },
  {
    "country": "PR",
    "name": "Fajardo",
    "lat": "18.32579",
    "lng": "-65.65238"
  },
  {
    "country": "PR",
    "name": "Florida",
    "lat": "18.36245",
    "lng": "-66.56128"
  },
  {
    "country": "PR",
    "name": "Franquez",
    "lat": "18.34023",
    "lng": "-66.42767"
  },
  {
    "country": "PR",
    "name": "Fuig",
    "lat": "17.98774",
    "lng": "-66.91601"
  },
  {
    "country": "PR",
    "name": "G. L. Garcia",
    "lat": "18.12746",
    "lng": "-66.10405"
  },
  {
    "country": "PR",
    "name": "Galateo",
    "lat": "18.36245",
    "lng": "-66.25878"
  },
  {
    "country": "PR",
    "name": "Garrochales",
    "lat": "18.45356",
    "lng": "-66.56628"
  },
  {
    "country": "PR",
    "name": "Guánica",
    "lat": "17.97163",
    "lng": "-66.90795"
  },
  {
    "country": "PR",
    "name": "Guayabal",
    "lat": "18.08135",
    "lng": "-66.50128"
  },
  {
    "country": "PR",
    "name": "Guayama",
    "lat": "17.98413",
    "lng": "-66.11378"
  },
  {
    "country": "PR",
    "name": "Guayanilla",
    "lat": "18.01913",
    "lng": "-66.79184"
  },
  {
    "country": "PR",
    "name": "Guaynabo",
    "lat": "18.35745",
    "lng": "-66.111"
  },
  {
    "country": "PR",
    "name": "Gurabo",
    "lat": "18.2544",
    "lng": "-65.97294"
  },
  {
    "country": "PR",
    "name": "H. Rivera Colon",
    "lat": "18.34773",
    "lng": "-66.27378"
  },
  {
    "country": "PR",
    "name": "Hatillo",
    "lat": "18.48633",
    "lng": "-66.82545"
  },
  {
    "country": "PR",
    "name": "Hato Candal",
    "lat": "18.37439",
    "lng": "-65.78711"
  },
  {
    "country": "PR",
    "name": "Hormigueros",
    "lat": "18.13968",
    "lng": "-67.1274"
  },
  {
    "country": "PR",
    "name": "Imbery",
    "lat": "18.43689",
    "lng": "-66.55239"
  },
  {
    "country": "PR",
    "name": "Indios",
    "lat": "17.99413",
    "lng": "-66.81934"
  },
  {
    "country": "PR",
    "name": "Ingenio",
    "lat": "18.44217",
    "lng": "-66.226"
  },
  {
    "country": "PR",
    "name": "Humacao",
    "lat": "18.14968",
    "lng": "-65.82738"
  },
  {
    "country": "PR",
    "name": "Isabel Segunda",
    "lat": "18.14913",
    "lng": "-65.44266"
  },
  {
    "country": "PR",
    "name": "Isabela",
    "lat": "18.50078",
    "lng": "-67.02435"
  },
  {
    "country": "PR",
    "name": "Jagual",
    "lat": "18.16163",
    "lng": "-65.99544"
  },
  {
    "country": "PR",
    "name": "Jauca",
    "lat": "17.96913",
    "lng": "-66.36572"
  },
  {
    "country": "PR",
    "name": "Jayuya",
    "lat": "18.21857",
    "lng": "-66.59156"
  },
  {
    "country": "PR",
    "name": "Jobos",
    "lat": "17.95524",
    "lng": "-66.16544"
  },
  {
    "country": "PR",
    "name": "Juana Díaz",
    "lat": "18.05246",
    "lng": "-66.50656"
  },
  {
    "country": "PR",
    "name": "Juncal",
    "lat": "18.31384",
    "lng": "-66.91907"
  },
  {
    "country": "PR",
    "name": "Juncos",
    "lat": "18.22746",
    "lng": "-65.921"
  },
  {
    "country": "PR",
    "name": "La Alianza",
    "lat": "18.39745",
    "lng": "-66.6024"
  },
  {
    "country": "PR",
    "name": "La Dolores",
    "lat": "18.3755",
    "lng": "-65.85572"
  },
  {
    "country": "PR",
    "name": "La Fermina",
    "lat": "18.17551",
    "lng": "-65.8535"
  },
  {
    "country": "PR",
    "name": "La Luisa",
    "lat": "18.44884",
    "lng": "-66.50989"
  },
  {
    "country": "PR",
    "name": "La Parguera",
    "lat": "17.97497",
    "lng": "-67.04657"
  },
  {
    "country": "PR",
    "name": "La Playa",
    "lat": "18.28745",
    "lng": "-67.18685"
  },
  {
    "country": "PR",
    "name": "La Plena",
    "lat": "18.04663",
    "lng": "-66.20461"
  },
  {
    "country": "PR",
    "name": "Lajas",
    "lat": "18.04996",
    "lng": "-67.05934"
  },
  {
    "country": "PR",
    "name": "Lamboglia",
    "lat": "17.98136",
    "lng": "-65.98572"
  },
  {
    "country": "PR",
    "name": "Lares",
    "lat": "18.29467",
    "lng": "-66.87712"
  },
  {
    "country": "PR",
    "name": "Las Marias",
    "lat": "18.29328",
    "lng": "-67.14629"
  },
  {
    "country": "PR",
    "name": "Las Marías",
    "lat": "18.2519",
    "lng": "-66.99212"
  },
  {
    "country": "PR",
    "name": "Las Ochenta",
    "lat": "17.98469",
    "lng": "-66.31795"
  },
  {
    "country": "PR",
    "name": "Las Ollas",
    "lat": "18.03302",
    "lng": "-66.42434"
  },
  {
    "country": "PR",
    "name": "Las Piedras",
    "lat": "18.18301",
    "lng": "-65.86627"
  },
  {
    "country": "PR",
    "name": "Levittown",
    "lat": "18.44995",
    "lng": "-66.18156"
  },
  {
    "country": "PR",
    "name": "Liborio Negron Torres",
    "lat": "18.04302",
    "lng": "-66.9424"
  },
  {
    "country": "PR",
    "name": "Lluveras",
    "lat": "18.0383",
    "lng": "-66.90462"
  },
  {
    "country": "PR",
    "name": "Loíza",
    "lat": "18.43134",
    "lng": "-65.88016"
  },
  {
    "country": "PR",
    "name": "Los Llanos",
    "lat": "18.05524",
    "lng": "-66.40573"
  },
  {
    "country": "PR",
    "name": "Luis Llorens Torres",
    "lat": "18.05691",
    "lng": "-66.52684"
  },
  {
    "country": "PR",
    "name": "Luis M. Cintron",
    "lat": "18.29968",
    "lng": "-65.63849"
  },
  {
    "country": "PR",
    "name": "Luquillo",
    "lat": "18.37245",
    "lng": "-65.71655"
  },
  {
    "country": "PR",
    "name": "Luyando",
    "lat": "18.36439",
    "lng": "-67.1574"
  },
  {
    "country": "PR",
    "name": "Magas Arriba",
    "lat": "18.01746",
    "lng": "-66.76906"
  },
  {
    "country": "PR",
    "name": "Manatí",
    "lat": "18.42745",
    "lng": "-66.49212"
  },
  {
    "country": "PR",
    "name": "Maria Antonia",
    "lat": "17.9783",
    "lng": "-66.88934"
  },
  {
    "country": "PR",
    "name": "Mariano Colón",
    "lat": "18.0233",
    "lng": "-66.33239"
  },
  {
    "country": "PR",
    "name": "Maricao",
    "lat": "18.18079",
    "lng": "-66.9799"
  },
  {
    "country": "PR",
    "name": "Martorell",
    "lat": "18.07607",
    "lng": "-65.89822"
  },
  {
    "country": "PR",
    "name": "Maunabo",
    "lat": "18.00719",
    "lng": "-65.89933"
  },
  {
    "country": "PR",
    "name": "Miranda",
    "lat": "18.38662",
    "lng": "-66.38378"
  },
  {
    "country": "PR",
    "name": "Moca",
    "lat": "18.39467",
    "lng": "-67.11324"
  },
  {
    "country": "PR",
    "name": "Monserrate",
    "lat": "18.43661",
    "lng": "-66.35961"
  },
  {
    "country": "PR",
    "name": "Monte Grande",
    "lat": "18.08746",
    "lng": "-67.1074"
  },
  {
    "country": "PR",
    "name": "Mora",
    "lat": "18.463",
    "lng": "-67.03268"
  },
  {
    "country": "PR",
    "name": "Morovis",
    "lat": "18.32578",
    "lng": "-66.40656"
  },
  {
    "country": "PR",
    "name": "Mucarabones",
    "lat": "18.39078",
    "lng": "-66.216"
  },
  {
    "country": "PR",
    "name": "Mayagüez",
    "lat": "18.20107",
    "lng": "-67.13962"
  },
  {
    "country": "PR",
    "name": "Naguabo",
    "lat": "18.21162",
    "lng": "-65.73488"
  },
  {
    "country": "PR",
    "name": "Naranjito",
    "lat": "18.30079",
    "lng": "-66.24489"
  },
  {
    "country": "PR",
    "name": "Olimpo",
    "lat": "18.00191",
    "lng": "-66.10822"
  },
  {
    "country": "PR",
    "name": "Orocovis",
    "lat": "18.2269",
    "lng": "-66.391"
  },
  {
    "country": "PR",
    "name": "Pájaros",
    "lat": "18.36856",
    "lng": "-66.21683"
  },
  {
    "country": "PR",
    "name": "Palmarejo",
    "lat": "18.06802",
    "lng": "-66.32545"
  },
  {
    "country": "PR",
    "name": "Palmarejo",
    "lat": "18.04024",
    "lng": "-67.07685"
  },
  {
    "country": "PR",
    "name": "Palmas",
    "lat": "17.98719",
    "lng": "-66.02544"
  },
  {
    "country": "PR",
    "name": "Palmer",
    "lat": "18.37051",
    "lng": "-65.77405"
  },
  {
    "country": "PR",
    "name": "Palo Seco",
    "lat": "18.00747",
    "lng": "-65.93683"
  },
  {
    "country": "PR",
    "name": "Palomas",
    "lat": "18.23246",
    "lng": "-66.25628"
  },
  {
    "country": "PR",
    "name": "Palomas",
    "lat": "18.01358",
    "lng": "-66.87323"
  },
  {
    "country": "PR",
    "name": "Parcelas La Milagrosa",
    "lat": "18.17079",
    "lng": "-66.18822"
  },
  {
    "country": "PR",
    "name": "Parcelas Nuevas",
    "lat": "18.14024",
    "lng": "-66.17239"
  },
  {
    "country": "PR",
    "name": "Parcelas Peñuelas",
    "lat": "17.99885",
    "lng": "-66.34128"
  },
  {
    "country": "PR",
    "name": "Pastos",
    "lat": "18.11774",
    "lng": "-66.25878"
  },
  {
    "country": "PR",
    "name": "Patillas",
    "lat": "18.00635",
    "lng": "-66.01572"
  },
  {
    "country": "PR",
    "name": "Peña Pobre",
    "lat": "18.21551",
    "lng": "-65.82211"
  },
  {
    "country": "PR",
    "name": "Peñuelas",
    "lat": "18.05635",
    "lng": "-66.72156"
  },
  {
    "country": "PR",
    "name": "Piedra Gorda",
    "lat": "18.43411",
    "lng": "-66.88768"
  },
  {
    "country": "PR",
    "name": "Playa Fortuna",
    "lat": "18.37967",
    "lng": "-65.74516"
  },
  {
    "country": "PR",
    "name": "Playita",
    "lat": "18.04469",
    "lng": "-65.90738"
  },
  {
    "country": "PR",
    "name": "Playita Cortada",
    "lat": "17.98497",
    "lng": "-66.43906"
  },
  {
    "country": "PR",
    "name": "Pole Ojea",
    "lat": "17.97496",
    "lng": "-67.18518"
  },
  {
    "country": "PR",
    "name": "Ponce",
    "lat": "18.01108",
    "lng": "-66.61406"
  },
  {
    "country": "PR",
    "name": "Potala Pastillo",
    "lat": "17.99135",
    "lng": "-66.49656"
  },
  {
    "country": "PR",
    "name": "Pueblito del Rio",
    "lat": "18.22801",
    "lng": "-65.86294"
  },
  {
    "country": "PR",
    "name": "Puerto Real",
    "lat": "18.07496",
    "lng": "-67.18712"
  },
  {
    "country": "PR",
    "name": "Punta Santiago",
    "lat": "18.16635",
    "lng": "-65.74822"
  },
  {
    "country": "PR",
    "name": "Quebrada",
    "lat": "18.35662",
    "lng": "-66.83212"
  },
  {
    "country": "PR",
    "name": "Quebradillas",
    "lat": "18.47383",
    "lng": "-66.93851"
  },
  {
    "country": "PR",
    "name": "Rafael Capo",
    "lat": "18.40717",
    "lng": "-66.78212"
  },
  {
    "country": "PR",
    "name": "Rafael Gonzalez",
    "lat": "18.42745",
    "lng": "-66.78684"
  },
  {
    "country": "PR",
    "name": "Rafael Hernandez",
    "lat": "18.47133",
    "lng": "-67.07907"
  },
  {
    "country": "PR",
    "name": "Ramos",
    "lat": "18.33967",
    "lng": "-65.71266"
  },
  {
    "country": "PR",
    "name": "Rincón",
    "lat": "18.34023",
    "lng": "-67.2499"
  },
  {
    "country": "PR",
    "name": "Río Blanco",
    "lat": "18.21829",
    "lng": "-65.7885"
  },
  {
    "country": "PR",
    "name": "Río Cañas Abajo",
    "lat": "18.0383",
    "lng": "-66.46767"
  },
  {
    "country": "PR",
    "name": "Río Grande",
    "lat": "18.38023",
    "lng": "-65.83127"
  },
  {
    "country": "PR",
    "name": "Río Lajas",
    "lat": "18.39467",
    "lng": "-66.26767"
  },
  {
    "country": "PR",
    "name": "Rosa Sanchez",
    "lat": "18.06163",
    "lng": "-65.9135"
  },
  {
    "country": "PR",
    "name": "Sabana",
    "lat": "18.46078",
    "lng": "-66.3585"
  },
  {
    "country": "PR",
    "name": "Sabana Eneas",
    "lat": "18.08607",
    "lng": "-67.08101"
  },
  {
    "country": "PR",
    "name": "Sabana Grande",
    "lat": "18.07774",
    "lng": "-66.96045"
  },
  {
    "country": "PR",
    "name": "Sabana Hoyos",
    "lat": "18.43384",
    "lng": "-66.61378"
  },
  {
    "country": "PR",
    "name": "Sabana Seca",
    "lat": "18.42689",
    "lng": "-66.18461"
  },
  {
    "country": "PR",
    "name": "Salinas",
    "lat": "17.97747",
    "lng": "-66.29795"
  },
  {
    "country": "PR",
    "name": "San Antonio",
    "lat": "18.49217",
    "lng": "-67.09851"
  },
  {
    "country": "PR",
    "name": "San Antonio",
    "lat": "18.44884",
    "lng": "-66.30267"
  },
  {
    "country": "PR",
    "name": "San Antonio",
    "lat": "18.45161",
    "lng": "-66.94962"
  },
  {
    "country": "PR",
    "name": "San Germán",
    "lat": "18.08163",
    "lng": "-67.0449"
  },
  {
    "country": "PR",
    "name": "San Isidro",
    "lat": "18.39217",
    "lng": "-65.88544"
  },
  {
    "country": "PR",
    "name": "San José",
    "lat": "18.39828",
    "lng": "-66.25572"
  },
  {
    "country": "PR",
    "name": "San Juan",
    "lat": "18.46633",
    "lng": "-66.10572"
  },
  {
    "country": "PR",
    "name": "San Lorenzo",
    "lat": "18.1894",
    "lng": "-65.961"
  },
  {
    "country": "PR",
    "name": "San Sebastián",
    "lat": "18.33662",
    "lng": "-66.99018"
  },
  {
    "country": "PR",
    "name": "Santa Barbara",
    "lat": "18.39356",
    "lng": "-65.91878"
  },
  {
    "country": "PR",
    "name": "Santa Clara",
    "lat": "18.21857",
    "lng": "-66.12878"
  },
  {
    "country": "PR",
    "name": "Santa Isabel",
    "lat": "17.96608",
    "lng": "-66.40489"
  },
  {
    "country": "PR",
    "name": "Santo Domingo",
    "lat": "18.0633",
    "lng": "-66.7524"
  },
  {
    "country": "PR",
    "name": "Stella",
    "lat": "18.32189",
    "lng": "-67.24685"
  },
  {
    "country": "PR",
    "name": "Suárez",
    "lat": "18.43022",
    "lng": "-65.8535"
  },
  {
    "country": "PR",
    "name": "Sumidero",
    "lat": "18.21857",
    "lng": "-66.12878"
  },
  {
    "country": "PR",
    "name": "Tallaboa",
    "lat": "17.99497",
    "lng": "-66.71629"
  },
  {
    "country": "PR",
    "name": "Tallaboa Alta",
    "lat": "18.05107",
    "lng": "-66.70017"
  },
  {
    "country": "PR",
    "name": "Tierras Nuevas Poniente",
    "lat": "18.46189",
    "lng": "-66.4885"
  },
  {
    "country": "PR",
    "name": "Toa Alta",
    "lat": "18.38828",
    "lng": "-66.24822"
  },
  {
    "country": "PR",
    "name": "Toa Baja",
    "lat": "18.44384",
    "lng": "-66.25961"
  },
  {
    "country": "PR",
    "name": "Trujillo Alto",
    "lat": "18.35467",
    "lng": "-66.00739"
  },
  {
    "country": "PR",
    "name": "Utuado",
    "lat": "18.26551",
    "lng": "-66.70045"
  },
  {
    "country": "PR",
    "name": "Vázquez",
    "lat": "18.0658",
    "lng": "-66.2385"
  },
  {
    "country": "PR",
    "name": "Vega Alta",
    "lat": "18.41217",
    "lng": "-66.33128"
  },
  {
    "country": "PR",
    "name": "Vega Baja",
    "lat": "18.44439",
    "lng": "-66.38767"
  },
  {
    "country": "PR",
    "name": "Vieques",
    "lat": "18.42495",
    "lng": "-65.83294"
  },
  {
    "country": "PR",
    "name": "Villalba",
    "lat": "18.12718",
    "lng": "-66.49212"
  },
  {
    "country": "PR",
    "name": "Yabucoa",
    "lat": "18.05052",
    "lng": "-65.87933"
  },
  {
    "country": "PR",
    "name": "Yauco",
    "lat": "18.03496",
    "lng": "-66.8499"
  },
  {
    "country": "PR",
    "name": "Yaurel",
    "lat": "18.02691",
    "lng": "-66.05711"
  },
  {
    "country": "PS",
    "name": "Shūkat aş Şūfī",
    "lat": "31.25997",
    "lng": "34.2826"
  },
  {
    "country": "PS",
    "name": "Rafaḩ",
    "lat": "31.29722",
    "lng": "34.24357"
  },
  {
    "country": "PS",
    "name": "An Nuşayrāt",
    "lat": "31.44861",
    "lng": "34.3925"
  },
  {
    "country": "PS",
    "name": "Khuzā‘ah",
    "lat": "31.30675",
    "lng": "34.3611"
  },
  {
    "country": "PS",
    "name": "Khān Yūnis",
    "lat": "31.34018",
    "lng": "34.30627"
  },
  {
    "country": "PS",
    "name": "Jabālyā",
    "lat": "31.5272",
    "lng": "34.48347"
  },
  {
    "country": "PS",
    "name": "Gaza",
    "lat": "31.50161",
    "lng": "34.46672"
  },
  {
    "country": "PS",
    "name": "Dayr al Balaḩ",
    "lat": "31.41783",
    "lng": "34.35033"
  },
  {
    "country": "PS",
    "name": "Bayt Lāhyā",
    "lat": "31.5464",
    "lng": "34.49514"
  },
  {
    "country": "PS",
    "name": "Bayt Ḩānūn",
    "lat": "31.5353",
    "lng": "34.53579"
  },
  {
    "country": "PS",
    "name": "Banī Suhaylā",
    "lat": "31.34337",
    "lng": "34.32337"
  },
  {
    "country": "PS",
    "name": "Al Fukhkhārī",
    "lat": "31.29278",
    "lng": "34.33061"
  },
  {
    "country": "PS",
    "name": "Al Burayj",
    "lat": "31.43944",
    "lng": "34.40306"
  },
  {
    "country": "PS",
    "name": "‘Abasān al Kabīrah",
    "lat": "31.31913",
    "lng": "34.34005"
  },
  {
    "country": "PS",
    "name": "Zubūbah",
    "lat": "32.54346",
    "lng": "35.22274"
  },
  {
    "country": "PS",
    "name": "Zaytā",
    "lat": "32.3856",
    "lng": "35.05122"
  },
  {
    "country": "PS",
    "name": "Zaytā Jammā‘īn",
    "lat": "32.13698",
    "lng": "35.18595"
  },
  {
    "country": "PS",
    "name": "Zawātā",
    "lat": "32.24611",
    "lng": "35.2265"
  },
  {
    "country": "PS",
    "name": "Za‘tarah",
    "lat": "31.67361",
    "lng": "35.25662"
  },
  {
    "country": "PS",
    "name": "Yuta",
    "lat": "31.4459",
    "lng": "35.09443"
  },
  {
    "country": "PS",
    "name": "Yatmā",
    "lat": "32.10889",
    "lng": "35.26909"
  },
  {
    "country": "PS",
    "name": "Yāsūf",
    "lat": "32.10841",
    "lng": "35.23784"
  },
  {
    "country": "PS",
    "name": "Yāşīd",
    "lat": "32.29688",
    "lng": "35.27757"
  },
  {
    "country": "PS",
    "name": "Ya‘bad",
    "lat": "32.44566",
    "lng": "35.16822"
  },
  {
    "country": "PS",
    "name": "Wādī Fūkīn",
    "lat": "31.70701",
    "lng": "35.10366"
  },
  {
    "country": "PS",
    "name": "‘Ūrīf",
    "lat": "32.15949",
    "lng": "35.22228"
  },
  {
    "country": "PS",
    "name": "Ūdalah",
    "lat": "32.15363",
    "lng": "35.27646"
  },
  {
    "country": "PS",
    "name": "Turmus‘ayyā",
    "lat": "32.03538",
    "lng": "35.28564"
  },
  {
    "country": "PS",
    "name": "Ţūlkarm",
    "lat": "32.31037",
    "lng": "35.02863"
  },
  {
    "country": "PS",
    "name": "Ţūbās",
    "lat": "32.32091",
    "lng": "35.36989"
  },
  {
    "country": "PS",
    "name": "Tayāsīr",
    "lat": "32.34042",
    "lng": "35.39604"
  },
  {
    "country": "PS",
    "name": "Tarqūmyā",
    "lat": "31.57551",
    "lng": "35.01223"
  },
  {
    "country": "PS",
    "name": "Ţammūn",
    "lat": "32.28347",
    "lng": "35.38367"
  },
  {
    "country": "PS",
    "name": "Ţallūzah",
    "lat": "32.27056",
    "lng": "35.29496"
  },
  {
    "country": "PS",
    "name": "Till",
    "lat": "32.20068",
    "lng": "35.21293"
  },
  {
    "country": "PS",
    "name": "Talfīt",
    "lat": "32.08664",
    "lng": "35.29094"
  },
  {
    "country": "PS",
    "name": "Taffūḩ",
    "lat": "31.53855",
    "lng": "35.04966"
  },
  {
    "country": "PS",
    "name": "Şūrīf",
    "lat": "31.65078",
    "lng": "35.06439"
  },
  {
    "country": "PS",
    "name": "Surdā",
    "lat": "31.93709",
    "lng": "35.20321"
  },
  {
    "country": "PS",
    "name": "Sīrīs",
    "lat": "32.32828",
    "lng": "35.29134"
  },
  {
    "country": "PS",
    "name": "Sinjil",
    "lat": "32.03334",
    "lng": "35.26545"
  },
  {
    "country": "PS",
    "name": "Silwād",
    "lat": "31.97625",
    "lng": "35.2613"
  },
  {
    "country": "PS",
    "name": "Sīlat az̧ Z̧ahr",
    "lat": "32.31934",
    "lng": "35.18418"
  },
  {
    "country": "PS",
    "name": "Sīlat al Ḩārithīyah",
    "lat": "32.50847",
    "lng": "35.22752"
  },
  {
    "country": "PS",
    "name": "Sa‘īr",
    "lat": "31.57855",
    "lng": "35.14017"
  },
  {
    "country": "PS",
    "name": "Shuqbā",
    "lat": "31.98695",
    "lng": "35.04012"
  },
  {
    "country": "PS",
    "name": "Shūfah",
    "lat": "32.27551",
    "lng": "35.08135"
  },
  {
    "country": "PS",
    "name": "Şaydā",
    "lat": "32.38489",
    "lng": "35.11856"
  },
  {
    "country": "PS",
    "name": "Şarţah",
    "lat": "32.10447",
    "lng": "35.09198"
  },
  {
    "country": "PS",
    "name": "Şarrah",
    "lat": "32.2097",
    "lng": "35.19147"
  },
  {
    "country": "PS",
    "name": "Şānūr",
    "lat": "32.35608",
    "lng": "35.24537"
  },
  {
    "country": "PS",
    "name": "Sannīryā",
    "lat": "32.12877",
    "lng": "35.04652"
  },
  {
    "country": "PS",
    "name": "Sālim",
    "lat": "32.20962",
    "lng": "35.33034"
  },
  {
    "country": "PS",
    "name": "Salfīt",
    "lat": "32.08371",
    "lng": "35.18079"
  },
  {
    "country": "PS",
    "name": "Şaffā",
    "lat": "31.90563",
    "lng": "35.06094"
  },
  {
    "country": "PS",
    "name": "Sabasţīyah",
    "lat": "32.27562",
    "lng": "35.19873"
  },
  {
    "country": "PS",
    "name": "Rummanah",
    "lat": "32.52451",
    "lng": "35.2048"
  },
  {
    "country": "PS",
    "name": "Rūjayb",
    "lat": "32.19061",
    "lng": "35.29332"
  },
  {
    "country": "PS",
    "name": "Rās Karkar",
    "lat": "31.9424",
    "lng": "35.10773"
  },
  {
    "country": "PS",
    "name": "Rantīs",
    "lat": "32.02797",
    "lng": "35.01879"
  },
  {
    "country": "PS",
    "name": "Rammūn",
    "lat": "31.93342",
    "lng": "35.29821"
  },
  {
    "country": "PS",
    "name": "Rāmīn",
    "lat": "32.2852",
    "lng": "35.14951"
  },
  {
    "country": "PS",
    "name": "Ramallah",
    "lat": "31.89964",
    "lng": "35.20422"
  },
  {
    "country": "PS",
    "name": "Rāfāt",
    "lat": "32.07806",
    "lng": "35.04417"
  },
  {
    "country": "PS",
    "name": "Rāfāt",
    "lat": "31.87096",
    "lng": "35.19182"
  },
  {
    "country": "PS",
    "name": "Rābā",
    "lat": "32.38679",
    "lng": "35.38298"
  },
  {
    "country": "PS",
    "name": "Quşrah",
    "lat": "32.08543",
    "lng": "35.33005"
  },
  {
    "country": "PS",
    "name": "Qūşīn",
    "lat": "32.23829",
    "lng": "35.18297"
  },
  {
    "country": "PS",
    "name": "Qīrah",
    "lat": "32.12214",
    "lng": "35.17173"
  },
  {
    "country": "PS",
    "name": "Qibyah",
    "lat": "31.97734",
    "lng": "35.00984"
  },
  {
    "country": "PS",
    "name": "Qaţanah",
    "lat": "31.83366",
    "lng": "35.11894"
  },
  {
    "country": "PS",
    "name": "Qaryūt",
    "lat": "32.07004",
    "lng": "35.29432"
  },
  {
    "country": "PS",
    "name": "Qarāwat Banī Zayd",
    "lat": "32.0547",
    "lng": "35.12908"
  },
  {
    "country": "PS",
    "name": "Qarāwat Banī Ḩasan",
    "lat": "32.12568",
    "lng": "35.10061"
  },
  {
    "country": "PS",
    "name": "Qalqīlyah",
    "lat": "32.18966",
    "lng": "34.97063"
  },
  {
    "country": "PS",
    "name": "Qalandiyā",
    "lat": "31.86289",
    "lng": "35.20815"
  },
  {
    "country": "PS",
    "name": "Qaffīn",
    "lat": "32.43274",
    "lng": "35.08266"
  },
  {
    "country": "PS",
    "name": "Qabāţīyah",
    "lat": "32.41035",
    "lng": "35.28087"
  },
  {
    "country": "PS",
    "name": "Qabalān",
    "lat": "32.10182",
    "lng": "35.28938"
  },
  {
    "country": "PS",
    "name": "Nūbā",
    "lat": "31.609",
    "lng": "35.03455"
  },
  {
    "country": "PS",
    "name": "Ni‘līn",
    "lat": "31.94746",
    "lng": "35.02031"
  },
  {
    "country": "PS",
    "name": "Nazlat ‘Īsá",
    "lat": "32.41562",
    "lng": "35.05888"
  },
  {
    "country": "PS",
    "name": "Naḩḩālīn",
    "lat": "31.68559",
    "lng": "35.12081"
  },
  {
    "country": "PS",
    "name": "Nablus",
    "lat": "32.22111",
    "lng": "35.25444"
  },
  {
    "country": "PS",
    "name": "Mikhmās",
    "lat": "31.8721",
    "lng": "35.27596"
  },
  {
    "country": "PS",
    "name": "Mislīyah",
    "lat": "32.38613",
    "lng": "35.2878"
  },
  {
    "country": "PS",
    "name": "Mirkah",
    "lat": "32.39583",
    "lng": "35.23807"
  },
  {
    "country": "PS",
    "name": "Banī Zayd ash Shārqīyah",
    "lat": "32.04935",
    "lng": "35.16593"
  },
  {
    "country": "PS",
    "name": "Maythalūn",
    "lat": "32.34798",
    "lng": "35.27446"
  },
  {
    "country": "PS",
    "name": "Masḩah",
    "lat": "32.10828",
    "lng": "35.05096"
  },
  {
    "country": "PS",
    "name": "Mardā",
    "lat": "32.11381",
    "lng": "35.19536"
  },
  {
    "country": "PS",
    "name": "Majdal Banī Fāḑil",
    "lat": "32.08357",
    "lng": "35.36378"
  },
  {
    "country": "PS",
    "name": "Mādamā",
    "lat": "32.18588",
    "lng": "35.23114"
  },
  {
    "country": "PS",
    "name": "Al Lubban ash Sharqīyah",
    "lat": "32.07011",
    "lng": "35.2403"
  },
  {
    "country": "PS",
    "name": "Kufayrit",
    "lat": "32.4438",
    "lng": "35.20184"
  },
  {
    "country": "PS",
    "name": "Kifil Ḩāris",
    "lat": "32.11827",
    "lng": "35.15719"
  },
  {
    "country": "PS",
    "name": "Ar Ramāḑīn",
    "lat": "31.37952",
    "lng": "34.91246"
  },
  {
    "country": "PS",
    "name": "Qalqas",
    "lat": "31.49212",
    "lng": "35.09535"
  },
  {
    "country": "PS",
    "name": "Imrīsh",
    "lat": "31.46895",
    "lng": "35.00819"
  },
  {
    "country": "PS",
    "name": "Marāḩ Rabbāḩ",
    "lat": "31.63406",
    "lng": "35.18688"
  },
  {
    "country": "PS",
    "name": "Dayr al ‘Asal al Fawqā",
    "lat": "31.46832",
    "lng": "34.93832"
  },
  {
    "country": "PS",
    "name": "Bayt Ta‘mar",
    "lat": "31.67927",
    "lng": "35.23986"
  },
  {
    "country": "PS",
    "name": "Bayt Ḩasan",
    "lat": "32.2376",
    "lng": "35.40407"
  },
  {
    "country": "PS",
    "name": "Bayt ‘Awwā",
    "lat": "31.50911",
    "lng": "34.94938"
  },
  {
    "country": "PS",
    "name": "Jannātah",
    "lat": "31.66959",
    "lng": "35.21961"
  },
  {
    "country": "PS",
    "name": "Ash Shaykh Sa‘d",
    "lat": "31.73721",
    "lng": "35.25742"
  },
  {
    "country": "PS",
    "name": "An Naşşārīyah",
    "lat": "32.23647",
    "lng": "35.38711"
  },
  {
    "country": "PS",
    "name": "Kharbathā al Mişbāḩ",
    "lat": "31.88546",
    "lng": "35.07185"
  },
  {
    "country": "PS",
    "name": "Al Majd",
    "lat": "31.48095",
    "lng": "34.95063"
  },
  {
    "country": "PS",
    "name": "Karmah",
    "lat": "31.45185",
    "lng": "35.02714"
  },
  {
    "country": "PS",
    "name": "Al Burj",
    "lat": "31.43609",
    "lng": "34.91697"
  },
  {
    "country": "PS",
    "name": "Shuyūkh al ‘Arrūb",
    "lat": "31.61735",
    "lng": "35.14366"
  },
  {
    "country": "PS",
    "name": "Khirbat Abū Falāḩ",
    "lat": "32.01678",
    "lng": "35.30135"
  },
  {
    "country": "PS",
    "name": "Kharbathā Banī Ḩārith",
    "lat": "31.94508",
    "lng": "35.07194"
  },
  {
    "country": "PS",
    "name": "Khārās",
    "lat": "31.6148",
    "lng": "35.04174"
  },
  {
    "country": "PS",
    "name": "Khallat al Mayyah",
    "lat": "31.44222",
    "lng": "35.14286"
  },
  {
    "country": "PS",
    "name": "Kūbar",
    "lat": "31.98722",
    "lng": "35.15788"
  },
  {
    "country": "PS",
    "name": "Kafr Zībād",
    "lat": "32.22583",
    "lng": "35.07179"
  },
  {
    "country": "PS",
    "name": "Kafr Thulth",
    "lat": "32.1533",
    "lng": "35.04698"
  },
  {
    "country": "PS",
    "name": "Kafr Şūr",
    "lat": "32.24366",
    "lng": "35.06394"
  },
  {
    "country": "PS",
    "name": "Kafr Rā‘ī",
    "lat": "32.37398",
    "lng": "35.15451"
  },
  {
    "country": "PS",
    "name": "Kafr Qūd",
    "lat": "32.45661",
    "lng": "35.22649"
  },
  {
    "country": "PS",
    "name": "Kafr Qallīl",
    "lat": "32.19351",
    "lng": "35.28284"
  },
  {
    "country": "PS",
    "name": "Kafr Qaddūm",
    "lat": "32.22162",
    "lng": "35.14471"
  },
  {
    "country": "PS",
    "name": "Kafr Mālik",
    "lat": "31.9884",
    "lng": "35.30932"
  },
  {
    "country": "PS",
    "name": "Kafr Jammāl",
    "lat": "32.22551",
    "lng": "35.04337"
  },
  {
    "country": "PS",
    "name": "Kafr Dān",
    "lat": "32.47852",
    "lng": "35.25425"
  },
  {
    "country": "PS",
    "name": "Kafr ‘Ayn",
    "lat": "32.04758",
    "lng": "35.12038"
  },
  {
    "country": "PS",
    "name": "Kafr al Labad",
    "lat": "32.29967",
    "lng": "35.10955"
  },
  {
    "country": "PS",
    "name": "Kafr ad Dīk",
    "lat": "32.0671",
    "lng": "35.08287"
  },
  {
    "country": "PS",
    "name": "Kafr ‘Abbūsh",
    "lat": "32.22353",
    "lng": "35.08504"
  },
  {
    "country": "PS",
    "name": "Jūrīsh",
    "lat": "32.10188",
    "lng": "35.32188"
  },
  {
    "country": "PS",
    "name": "Jūrat ash Sham‘ah",
    "lat": "31.65051",
    "lng": "35.17001"
  },
  {
    "country": "PS",
    "name": "Al Judayyidah",
    "lat": "32.33541",
    "lng": "35.30107"
  },
  {
    "country": "PS",
    "name": "Jīt",
    "lat": "32.21431",
    "lng": "35.17081"
  },
  {
    "country": "PS",
    "name": "Jifnā",
    "lat": "31.96192",
    "lng": "35.21338"
  },
  {
    "country": "PS",
    "name": "Jayyūs",
    "lat": "32.20125",
    "lng": "35.03416"
  },
  {
    "country": "PS",
    "name": "Janīn",
    "lat": "32.45943",
    "lng": "35.30086"
  },
  {
    "country": "PS",
    "name": "Jammā‘īn",
    "lat": "32.13164",
    "lng": "35.20403"
  },
  {
    "country": "PS",
    "name": "Jalqamūs",
    "lat": "32.42464",
    "lng": "35.36421"
  },
  {
    "country": "PS",
    "name": "Jalbūn",
    "lat": "32.45957",
    "lng": "35.41516"
  },
  {
    "country": "PS",
    "name": "Al Jalamah",
    "lat": "32.50821",
    "lng": "35.31317"
  },
  {
    "country": "PS",
    "name": "Jaba‘",
    "lat": "32.32409",
    "lng": "35.22133"
  },
  {
    "country": "PS",
    "name": "Jaba‘",
    "lat": "31.85727",
    "lng": "35.25868"
  },
  {
    "country": "PS",
    "name": "Immātīn",
    "lat": "32.19164",
    "lng": "35.15836"
  },
  {
    "country": "PS",
    "name": "‘Illār",
    "lat": "32.37024",
    "lng": "35.10708"
  },
  {
    "country": "PS",
    "name": "Iktābah",
    "lat": "32.3266",
    "lng": "35.05262"
  },
  {
    "country": "PS",
    "name": "Idhnā",
    "lat": "31.55874",
    "lng": "34.97436"
  },
  {
    "country": "PS",
    "name": "Ḩuwwārah",
    "lat": "32.15224",
    "lng": "35.25673"
  },
  {
    "country": "PS",
    "name": "Ḩūsān",
    "lat": "31.70931",
    "lng": "35.13475"
  },
  {
    "country": "PS",
    "name": "Ḩizmā",
    "lat": "31.83337",
    "lng": "35.26315"
  },
  {
    "country": "PS",
    "name": "Ḩāris",
    "lat": "32.11424",
    "lng": "35.14192"
  },
  {
    "country": "PS",
    "name": "Ḩalḩūl",
    "lat": "31.58029",
    "lng": "35.10178"
  },
  {
    "country": "PS",
    "name": "Ḩajjah",
    "lat": "32.20427",
    "lng": "35.13077"
  },
  {
    "country": "PS",
    "name": "Ḩablah",
    "lat": "32.16523",
    "lng": "34.97748"
  },
  {
    "country": "PS",
    "name": "Far‘ūn",
    "lat": "32.28613",
    "lng": "35.02326"
  },
  {
    "country": "PS",
    "name": "Farkhah",
    "lat": "32.06878",
    "lng": "35.15286"
  },
  {
    "country": "PS",
    "name": "Faqqū‘ah",
    "lat": "32.48998",
    "lng": "35.40163"
  },
  {
    "country": "PS",
    "name": "Faḩmah",
    "lat": "32.38291",
    "lng": "35.17912"
  },
  {
    "country": "PS",
    "name": "Dūrā al Qar‘",
    "lat": "31.95863",
    "lng": "35.22714"
  },
  {
    "country": "PS",
    "name": "Dūrā",
    "lat": "31.50777",
    "lng": "35.02929"
  },
  {
    "country": "PS",
    "name": "Domea",
    "lat": "32.05632",
    "lng": "35.36705"
  },
  {
    "country": "PS",
    "name": "Dhannābah",
    "lat": "32.31341",
    "lng": "35.04144"
  },
  {
    "country": "PS",
    "name": "Dayr Sharaf",
    "lat": "32.25326",
    "lng": "35.18893"
  },
  {
    "country": "PS",
    "name": "Dayr Qiddīs",
    "lat": "31.94862",
    "lng": "35.04437"
  },
  {
    "country": "PS",
    "name": "Dayr Jarīr",
    "lat": "31.96636",
    "lng": "35.29261"
  },
  {
    "country": "PS",
    "name": "Dayr Istiyā",
    "lat": "32.13096",
    "lng": "35.13963"
  },
  {
    "country": "PS",
    "name": "Dayr Ibzī‘",
    "lat": "31.91727",
    "lng": "35.12105"
  },
  {
    "country": "PS",
    "name": "Dayr Dibwān",
    "lat": "31.91112",
    "lng": "35.26661"
  },
  {
    "country": "PS",
    "name": "Dayr Ballūţ",
    "lat": "32.06551",
    "lng": "35.02451"
  },
  {
    "country": "PS",
    "name": "Dayr as Sūdān",
    "lat": "32.03213",
    "lng": "35.14845"
  },
  {
    "country": "PS",
    "name": "Dayr al Ḩaţab",
    "lat": "32.21734",
    "lng": "35.32127"
  },
  {
    "country": "PS",
    "name": "Dayr al Ghuşūn",
    "lat": "32.35244",
    "lng": "35.07689"
  },
  {
    "country": "PS",
    "name": "Dayr Abū Mash‘al",
    "lat": "31.99881",
    "lng": "35.06844"
  },
  {
    "country": "PS",
    "name": "Dayr Abū Ḑa‘īf",
    "lat": "32.45601",
    "lng": "35.36164"
  },
  {
    "country": "PS",
    "name": "Brūqīn",
    "lat": "32.07216",
    "lng": "35.09943"
  },
  {
    "country": "PS",
    "name": "Birqīn",
    "lat": "32.45461",
    "lng": "35.26076"
  },
  {
    "country": "PS",
    "name": "Burqah",
    "lat": "32.30177",
    "lng": "35.19263"
  },
  {
    "country": "PS",
    "name": "Burqah",
    "lat": "31.89682",
    "lng": "35.2543"
  },
  {
    "country": "PS",
    "name": "Būrīn",
    "lat": "32.18452",
    "lng": "35.25015"
  },
  {
    "country": "PS",
    "name": "Budrus",
    "lat": "31.96687",
    "lng": "34.99425"
  },
  {
    "country": "PS",
    "name": "Bīr Zayt",
    "lat": "31.96959",
    "lng": "35.19408"
  },
  {
    "country": "PS",
    "name": "Bīr Nabālā",
    "lat": "31.8508",
    "lng": "35.2036"
  },
  {
    "country": "PS",
    "name": "Bil‘īn",
    "lat": "31.92835",
    "lng": "35.07204"
  },
  {
    "country": "PS",
    "name": "Biddū",
    "lat": "31.83478",
    "lng": "35.14947"
  },
  {
    "country": "PS",
    "name": "Bidyā",
    "lat": "32.1146",
    "lng": "35.08028"
  },
  {
    "country": "PS",
    "name": "Bazzāryah",
    "lat": "32.30798",
    "lng": "35.16593"
  },
  {
    "country": "PS",
    "name": "Bayt Wazan",
    "lat": "32.23105",
    "lng": "35.21576"
  },
  {
    "country": "PS",
    "name": "Bayt ‘Ūr at Taḩtā",
    "lat": "31.89609",
    "lng": "35.08178"
  },
  {
    "country": "PS",
    "name": "Baytūnyā",
    "lat": "31.8966",
    "lng": "35.17048"
  },
  {
    "country": "PS",
    "name": "Bayt Imrīn",
    "lat": "32.29301",
    "lng": "35.2161"
  },
  {
    "country": "PS",
    "name": "Bayt Sūrīk",
    "lat": "31.82424",
    "lng": "35.14936"
  },
  {
    "country": "PS",
    "name": "Bayt Sīrā",
    "lat": "31.8878",
    "lng": "35.04623"
  },
  {
    "country": "PS",
    "name": "Bayt Sāḩūr",
    "lat": "31.70095",
    "lng": "35.22631"
  },
  {
    "country": "PS",
    "name": "Bayt Qād",
    "lat": "32.46968",
    "lng": "35.35626"
  },
  {
    "country": "PS",
    "name": "Bayt Liqyā",
    "lat": "31.86958",
    "lng": "35.0654"
  },
  {
    "country": "PS",
    "name": "Bayt Līd",
    "lat": "32.26089",
    "lng": "35.13169"
  },
  {
    "country": "PS",
    "name": "Bethlehem",
    "lat": "31.70487",
    "lng": "35.20376"
  },
  {
    "country": "PS",
    "name": "Bayt Kāḩil",
    "lat": "31.57011",
    "lng": "35.06502"
  },
  {
    "country": "PS",
    "name": "Bayt Jālā",
    "lat": "31.71545",
    "lng": "35.18788"
  },
  {
    "country": "PS",
    "name": "Bayt ‘Anān",
    "lat": "31.85069",
    "lng": "35.11248"
  },
  {
    "country": "PS",
    "name": "Baytīn",
    "lat": "31.92674",
    "lng": "35.24098"
  },
  {
    "country": "PS",
    "name": "Bayt Ūmmar",
    "lat": "31.62329",
    "lng": "35.10446"
  },
  {
    "country": "PS",
    "name": "Al Ittiḩād",
    "lat": "31.97552",
    "lng": "35.11595"
  },
  {
    "country": "PS",
    "name": "Bayt Iksā",
    "lat": "31.81732",
    "lng": "35.17934"
  },
  {
    "country": "PS",
    "name": "Bayt Ībā",
    "lat": "32.23719",
    "lng": "35.20977"
  },
  {
    "country": "PS",
    "name": "Bayt Fūrīk",
    "lat": "32.17689",
    "lng": "35.33541"
  },
  {
    "country": "PS",
    "name": "Bayt Fajjār",
    "lat": "31.62443",
    "lng": "35.15457"
  },
  {
    "country": "PS",
    "name": "Bayt Duqqū",
    "lat": "31.85911",
    "lng": "35.13124"
  },
  {
    "country": "PS",
    "name": "Bayt Dajan",
    "lat": "32.19303",
    "lng": "35.37127"
  },
  {
    "country": "PS",
    "name": "Bayt Ūlā",
    "lat": "31.59618",
    "lng": "35.0296"
  },
  {
    "country": "PS",
    "name": "Baytā al Fawqā",
    "lat": "32.1426",
    "lng": "35.28774"
  },
  {
    "country": "PS",
    "name": "Battīr",
    "lat": "31.71945",
    "lng": "35.14103"
  },
  {
    "country": "PS",
    "name": "Barţa‘ah ash Sharqīyah",
    "lat": "32.47304",
    "lng": "35.0936"
  },
  {
    "country": "PS",
    "name": "Bardalah",
    "lat": "32.38632",
    "lng": "35.48084"
  },
  {
    "country": "PS",
    "name": "Bāqah ash Sharqīyah",
    "lat": "32.41032",
    "lng": "35.07054"
  },
  {
    "country": "PS",
    "name": "Bāqat al Ḩaţab",
    "lat": "32.20434",
    "lng": "35.11433"
  },
  {
    "country": "PS",
    "name": "Banī Na‘īm",
    "lat": "31.51591",
    "lng": "35.16416"
  },
  {
    "country": "PS",
    "name": "Balāţah",
    "lat": "32.21207",
    "lng": "35.28561"
  },
  {
    "country": "PS",
    "name": "Bal‘ā",
    "lat": "32.33392",
    "lng": "35.1116"
  },
  {
    "country": "PS",
    "name": "‘Azzūn",
    "lat": "32.17496",
    "lng": "35.05752"
  },
  {
    "country": "PS",
    "name": "Az Zāwiyah",
    "lat": "32.09627",
    "lng": "35.03982"
  },
  {
    "country": "PS",
    "name": "Az̧ Z̧āhirīyah",
    "lat": "31.40967",
    "lng": "34.97329"
  },
  {
    "country": "PS",
    "name": "Az Zabābidah",
    "lat": "32.38665",
    "lng": "35.32411"
  },
  {
    "country": "PS",
    "name": "‘Azmūţ",
    "lat": "32.22297",
    "lng": "35.30989"
  },
  {
    "country": "PS",
    "name": "‘Ayn Yabrūd",
    "lat": "31.94918",
    "lng": "35.25122"
  },
  {
    "country": "PS",
    "name": "‘Ayn ‘Arīk",
    "lat": "31.90613",
    "lng": "35.14254"
  },
  {
    "country": "PS",
    "name": "‘Aynabūs",
    "lat": "32.14706",
    "lng": "35.24513"
  },
  {
    "country": "PS",
    "name": "Usarin",
    "lat": "32.12499",
    "lng": "35.30999"
  },
  {
    "country": "PS",
    "name": "‘Awartā",
    "lat": "32.16108",
    "lng": "35.28388"
  },
  {
    "country": "PS",
    "name": "Aţ Ţīrah",
    "lat": "31.87022",
    "lng": "35.12682"
  },
  {
    "country": "PS",
    "name": "‘Attīl",
    "lat": "32.36935",
    "lng": "35.07189"
  },
  {
    "country": "PS",
    "name": "Aţ Ţaybah",
    "lat": "32.51494",
    "lng": "35.18574"
  },
  {
    "country": "PS",
    "name": "Aţ Ţaybah",
    "lat": "31.95388",
    "lng": "35.2998"
  },
  {
    "country": "PS",
    "name": "‘Aţārah",
    "lat": "32.00058",
    "lng": "35.20466"
  },
  {
    "country": "PS",
    "name": "Kalandia",
    "lat": "31.86667",
    "lng": "35.21667"
  },
  {
    "country": "PS",
    "name": "As Sāwiyah",
    "lat": "32.08537",
    "lng": "35.25782"
  },
  {
    "country": "PS",
    "name": "As Samū‘",
    "lat": "31.39671",
    "lng": "35.06611"
  },
  {
    "country": "PS",
    "name": "‘Aşīrah ash Shamālīyah",
    "lat": "32.25124",
    "lng": "35.26716"
  },
  {
    "country": "PS",
    "name": "‘Aşīrah al Qiblīyah",
    "lat": "32.17842",
    "lng": "35.21569"
  },
  {
    "country": "PS",
    "name": "Ash Shuyūkh",
    "lat": "31.57004",
    "lng": "35.15606"
  },
  {
    "country": "PS",
    "name": "Ash Shuhadā’",
    "lat": "32.42949",
    "lng": "35.27112"
  },
  {
    "country": "PS",
    "name": "Arţās",
    "lat": "31.68939",
    "lng": "35.18681"
  },
  {
    "country": "PS",
    "name": "Ar Rīḩīyah",
    "lat": "31.4695",
    "lng": "35.07781"
  },
  {
    "country": "PS",
    "name": "‘Arrānah",
    "lat": "32.4972",
    "lng": "35.32271"
  },
  {
    "country": "PS",
    "name": "Ar Rām wa Ḑāḩiyat al Barīd",
    "lat": "31.84945",
    "lng": "35.2342"
  },
  {
    "country": "PS",
    "name": "‘Arrābah",
    "lat": "32.40517",
    "lng": "35.20189"
  },
  {
    "country": "PS",
    "name": "Jericho",
    "lat": "31.86667",
    "lng": "35.45"
  },
  {
    "country": "PS",
    "name": "Al ‘Araqa",
    "lat": "32.47057",
    "lng": "35.20027"
  },
  {
    "country": "PS",
    "name": "‘Aqrabā",
    "lat": "32.12495",
    "lng": "35.34547"
  },
  {
    "country": "PS",
    "name": "‘Anzah",
    "lat": "32.35916",
    "lng": "35.22011"
  },
  {
    "country": "PS",
    "name": "An Nuway‘imah",
    "lat": "31.89212",
    "lng": "35.43549"
  },
  {
    "country": "PS",
    "name": "An Nazlah ash Sharqīyah",
    "lat": "32.41072",
    "lng": "35.10916"
  },
  {
    "country": "PS",
    "name": "An Nāqūrah",
    "lat": "32.26506",
    "lng": "35.20135"
  },
  {
    "country": "PS",
    "name": "An Nabī Ilyās",
    "lat": "32.18482",
    "lng": "35.0176"
  },
  {
    "country": "PS",
    "name": "‘Anīn",
    "lat": "32.50259",
    "lng": "35.16668"
  },
  {
    "country": "PS",
    "name": "‘Anātā",
    "lat": "31.80924",
    "lng": "35.25902"
  },
  {
    "country": "PS",
    "name": "‘Anabtā",
    "lat": "32.30792",
    "lng": "35.11693"
  },
  {
    "country": "PS",
    "name": "Al Yāmūn",
    "lat": "32.48563",
    "lng": "35.23011"
  },
  {
    "country": "PS",
    "name": "Al Qubaybah",
    "lat": "31.83886",
    "lng": "35.13678"
  },
  {
    "country": "PS",
    "name": "Al Mughayyir",
    "lat": "32.42228",
    "lng": "35.38476"
  },
  {
    "country": "PS",
    "name": "Al Mughayyir",
    "lat": "32.0192",
    "lng": "35.34783"
  },
  {
    "country": "PS",
    "name": "Al Midyah",
    "lat": "31.93592",
    "lng": "35.005"
  },
  {
    "country": "PS",
    "name": "Al Mazra‘ah ash Sharqīyah",
    "lat": "32.00018",
    "lng": "35.28152"
  },
  {
    "country": "PS",
    "name": "Az Zaytūnīyah",
    "lat": "31.95403",
    "lng": "35.1624"
  },
  {
    "country": "PS",
    "name": "Al Lubban al Gharbī",
    "lat": "32.03504",
    "lng": "35.03928"
  },
  {
    "country": "PS",
    "name": "Al Khaḑir",
    "lat": "31.69405",
    "lng": "35.16685"
  },
  {
    "country": "PS",
    "name": "Hebron",
    "lat": "31.52935",
    "lng": "35.0938"
  },
  {
    "country": "PS",
    "name": "Al Judayrah",
    "lat": "31.85587",
    "lng": "35.19706"
  },
  {
    "country": "PS",
    "name": "Al Jīb",
    "lat": "31.85203",
    "lng": "35.18451"
  },
  {
    "country": "PS",
    "name": "Al Jāniyah",
    "lat": "31.93848",
    "lng": "35.12142"
  },
  {
    "country": "PS",
    "name": "Al Hāshimīyah",
    "lat": "32.46392",
    "lng": "35.21938"
  },
  {
    "country": "PS",
    "name": "Al Faşāyil",
    "lat": "32.02509",
    "lng": "35.44351"
  },
  {
    "country": "PS",
    "name": "Al Fandaqūmīyah",
    "lat": "32.3206",
    "lng": "35.20329"
  },
  {
    "country": "PS",
    "name": "Al Bīrah",
    "lat": "31.91001",
    "lng": "35.21645"
  },
  {
    "country": "PS",
    "name": "Al ‘Ayzarīyah",
    "lat": "31.77078",
    "lng": "35.26917"
  },
  {
    "country": "PS",
    "name": "Al ‘Awjā",
    "lat": "31.95069",
    "lng": "35.46756"
  },
  {
    "country": "PS",
    "name": "Al ‘Aţţārah",
    "lat": "32.32571",
    "lng": "35.16373"
  },
  {
    "country": "PS",
    "name": "‘Ajjūl",
    "lat": "32.02232",
    "lng": "35.17969"
  },
  {
    "country": "PS",
    "name": "‘Ajjah",
    "lat": "32.36074",
    "lng": "35.1959"
  },
  {
    "country": "PS",
    "name": "‘Ibwayn",
    "lat": "32.03144",
    "lng": "35.19992"
  },
  {
    "country": "PS",
    "name": "Abū Qashsh",
    "lat": "31.94883",
    "lng": "35.18426"
  },
  {
    "country": "PS",
    "name": "Abū Dīs",
    "lat": "31.76215",
    "lng": "35.26166"
  },
  {
    "country": "PS",
    "name": "‘Ābūd",
    "lat": "32.01637",
    "lng": "35.06833"
  },
  {
    "country": "PS",
    "name": "Old City",
    "lat": "31.77667",
    "lng": "35.23417"
  },
  {
    "country": "PS",
    "name": "An Naşr",
    "lat": "31.28137",
    "lng": "34.30253"
  },
  {
    "country": "PS",
    "name": "‘Abasān al Jadīdah",
    "lat": "31.34158",
    "lng": "34.34592"
  },
  {
    "country": "PS",
    "name": "Al Qarārah",
    "lat": "31.37389",
    "lng": "34.34085"
  },
  {
    "country": "PS",
    "name": "Umm an Naşr",
    "lat": "31.56085",
    "lng": "34.51863"
  },
  {
    "country": "PS",
    "name": "Juḩr ad Dīk",
    "lat": "31.45571",
    "lng": "34.43719"
  },
  {
    "country": "PS",
    "name": "Az Zuwāydah",
    "lat": "31.43954",
    "lng": "34.38053"
  },
  {
    "country": "PS",
    "name": "Al Muşaddar",
    "lat": "31.41052",
    "lng": "34.37802"
  },
  {
    "country": "PS",
    "name": "Wādī as Salqā",
    "lat": "31.40048",
    "lng": "34.33754"
  },
  {
    "country": "PS",
    "name": "Al Mughrāqah",
    "lat": "31.46587",
    "lng": "34.41208"
  },
  {
    "country": "PS",
    "name": "East Jerusalem",
    "lat": "31.78336",
    "lng": "35.23388"
  },
  {
    "country": "PS",
    "name": "Karney Shomron",
    "lat": "32.1714",
    "lng": "35.09767"
  },
  {
    "country": "PS",
    "name": "al-Kum",
    "lat": "31.53123",
    "lng": "34.96064"
  },
  {
    "country": "PS",
    "name": "Azun Atme",
    "lat": "32.12167",
    "lng": "35.02036"
  },
  {
    "country": "PS",
    "name": "Jinşāfūţ",
    "lat": "32.17916",
    "lng": "35.13038"
  },
  {
    "country": "PS",
    "name": "Banī Zayd",
    "lat": "32.03924",
    "lng": "35.10316"
  },
  {
    "country": "PS",
    "name": "Az Za‘ayyim",
    "lat": "31.78852",
    "lng": "35.26511"
  },
  {
    "country": "PS",
    "name": "Al ‘Ubaydīyah",
    "lat": "31.71697",
    "lng": "35.29007"
  },
  {
    "country": "PS",
    "name": "Khallat an Nu‘mān",
    "lat": "31.71749",
    "lng": "35.24227"
  },
  {
    "country": "PS",
    "name": "Khallat Ḩamāmah",
    "lat": "31.7216",
    "lng": "35.19243"
  },
  {
    "country": "PS",
    "name": "Ad Dawḩah",
    "lat": "31.69948",
    "lng": "35.18047"
  },
  {
    "country": "PS",
    "name": "Wādī Raḩḩāl",
    "lat": "31.66516",
    "lng": "35.16727"
  },
  {
    "country": "PS",
    "name": "‘Arab ar Rashāydah",
    "lat": "31.57112",
    "lng": "35.23227"
  },
  {
    "country": "PS",
    "name": "Bayt ‘Īnūn",
    "lat": "31.5587",
    "lng": "35.1244"
  },
  {
    "country": "PS",
    "name": "Bayt Maqdum",
    "lat": "31.53537",
    "lng": "34.97192"
  },
  {
    "country": "PS",
    "name": "Al Buq‘ah",
    "lat": "31.54199",
    "lng": "35.14279"
  },
  {
    "country": "PS",
    "name": "Khallat ad Dār",
    "lat": "31.49737",
    "lng": "35.11362"
  },
  {
    "country": "PS",
    "name": "Dayr Sāmit",
    "lat": "31.52057",
    "lng": "34.97442"
  },
  {
    "country": "PS",
    "name": "Al Ḩīlah",
    "lat": "31.47454",
    "lng": "35.10742"
  },
  {
    "country": "PS",
    "name": "Aş Şūrrah",
    "lat": "31.47097",
    "lng": "34.99897"
  },
  {
    "country": "PS",
    "name": "Bayt ‘Amrah",
    "lat": "31.4502",
    "lng": "35.04952"
  },
  {
    "country": "PS",
    "name": "Rābūd",
    "lat": "31.43909",
    "lng": "35.0162"
  },
  {
    "country": "PS",
    "name": "Al Karmil",
    "lat": "31.42301",
    "lng": "35.13278"
  },
  {
    "country": "PS",
    "name": "Khallat Şāliḩ",
    "lat": "31.42013",
    "lng": "35.11516"
  },
  {
    "country": "PS",
    "name": "Bīr al Bāshā",
    "lat": "32.42022",
    "lng": "35.23013"
  },
  {
    "country": "PS",
    "name": "Al Bādhān",
    "lat": "32.25857",
    "lng": "35.33247"
  },
  {
    "country": "PS",
    "name": "‘Ayn al Bayḑā",
    "lat": "32.38051",
    "lng": "35.50838"
  },
  {
    "country": "PS",
    "name": "Az Zubaydāt",
    "lat": "32.1733",
    "lng": "35.53005"
  },
  {
    "country": "PS",
    "name": "Al Jiftlik",
    "lat": "32.1407",
    "lng": "35.48738"
  },
  {
    "country": "PS",
    "name": "Khursā",
    "lat": "31.48232",
    "lng": "35.01742"
  },
  {
    "country": "PS",
    "name": "Givat Zeev",
    "lat": "31.86145",
    "lng": "35.16861"
  },
  {
    "country": "PS",
    "name": "Oranit",
    "lat": "32.13165",
    "lng": "34.99094"
  },
  {
    "country": "PT",
    "name": "Zambujeira do Mar",
    "lat": "37.52799",
    "lng": "-8.78483"
  },
  {
    "country": "PT",
    "name": "Vimeiro",
    "lat": "39.17768",
    "lng": "-9.31702"
  },
  {
    "country": "PT",
    "name": "Vila Viçosa",
    "lat": "38.7777",
    "lng": "-7.41793"
  },
  {
    "country": "PT",
    "name": "Vila Verde",
    "lat": "39.15489",
    "lng": "-9.11512"
  },
  {
    "country": "PT",
    "name": "Vila Velha de Ródão",
    "lat": "39.65646",
    "lng": "-7.6767"
  },
  {
    "country": "PT",
    "name": "Vila Real de Santo António",
    "lat": "37.195",
    "lng": "-7.41766"
  },
  {
    "country": "PT",
    "name": "Vila Nova de Milfontes",
    "lat": "37.72377",
    "lng": "-8.78278"
  },
  {
    "country": "PT",
    "name": "Vila Nova da Barquinha",
    "lat": "39.46081",
    "lng": "-8.43588"
  },
  {
    "country": "PT",
    "name": "Vila Franca de Xira",
    "lat": "38.95525",
    "lng": "-8.98966"
  },
  {
    "country": "PT",
    "name": "Vila Flor",
    "lat": "41.30904",
    "lng": "-7.15378"
  },
  {
    "country": "PT",
    "name": "Vila do Bispo",
    "lat": "37.08317",
    "lng": "-8.91144"
  },
  {
    "country": "PT",
    "name": "Vila de Rei",
    "lat": "39.67604",
    "lng": "-8.14577"
  },
  {
    "country": "PT",
    "name": "Vila Chã de Ourique",
    "lat": "39.17219",
    "lng": "-8.76658"
  },
  {
    "country": "PT",
    "name": "Vila Baleira",
    "lat": "33.05919",
    "lng": "-16.33371"
  },
  {
    "country": "PT",
    "name": "Vieira de Leiria",
    "lat": "39.86945",
    "lng": "-8.93238"
  },
  {
    "country": "PT",
    "name": "Vidigueira",
    "lat": "38.20995",
    "lng": "-7.8005"
  },
  {
    "country": "PT",
    "name": "Vidais",
    "lat": "39.36886",
    "lng": "-9.04916"
  },
  {
    "country": "PT",
    "name": "Viana do Alentejo",
    "lat": "38.33458",
    "lng": "-8.0044"
  },
  {
    "country": "PT",
    "name": "Vialonga",
    "lat": "38.87206",
    "lng": "-9.07805"
  },
  {
    "country": "PT",
    "name": "Vestiaria",
    "lat": "39.55271",
    "lng": "-8.9979"
  },
  {
    "country": "PT",
    "name": "Ventosa",
    "lat": "39.12696",
    "lng": "-9.08423"
  },
  {
    "country": "PT",
    "name": "Vendas Novas",
    "lat": "38.67706",
    "lng": "-8.45792"
  },
  {
    "country": "PT",
    "name": "Venda do Pinheiro",
    "lat": "38.92365",
    "lng": "-9.23178"
  },
  {
    "country": "PT",
    "name": "Vale de Santarém",
    "lat": "39.19052",
    "lng": "-8.72735"
  },
  {
    "country": "PT",
    "name": "Vale de Figueira",
    "lat": "39.30569",
    "lng": "-8.62876"
  },
  {
    "country": "PT",
    "name": "Vale da Amoreira",
    "lat": "39.06969",
    "lng": "-7.69849"
  },
  {
    "country": "PT",
    "name": "Valado de Frades",
    "lat": "39.58432",
    "lng": "-9.0229"
  },
  {
    "country": "PT",
    "name": "Urra",
    "lat": "39.2283",
    "lng": "-7.39856"
  },
  {
    "country": "PT",
    "name": "Unhos",
    "lat": "38.81958",
    "lng": "-9.12007"
  },
  {
    "country": "PT",
    "name": "Turquel",
    "lat": "39.46411",
    "lng": "-8.97743"
  },
  {
    "country": "PT",
    "name": "Tunes",
    "lat": "37.16592",
    "lng": "-8.25919"
  },
  {
    "country": "PT",
    "name": "Tramagal",
    "lat": "39.45",
    "lng": "-8.25"
  },
  {
    "country": "PT",
    "name": "Trafaria",
    "lat": "38.67222",
    "lng": "-9.23268"
  },
  {
    "country": "PT",
    "name": "Torres Vedras",
    "lat": "39.09109",
    "lng": "-9.2586"
  },
  {
    "country": "PT",
    "name": "Torres Novas",
    "lat": "39.48114",
    "lng": "-8.53949"
  },
  {
    "country": "PT",
    "name": "Tomar",
    "lat": "39.60199",
    "lng": "-8.40924"
  },
  {
    "country": "PT",
    "name": "Terrugem",
    "lat": "38.70647",
    "lng": "-9.28693"
  },
  {
    "country": "PT",
    "name": "Tavira",
    "lat": "37.12734",
    "lng": "-7.64861"
  },
  {
    "country": "PT",
    "name": "Souto da Carpalhosa",
    "lat": "39.84867",
    "lng": "-8.83506"
  },
  {
    "country": "PT",
    "name": "Sobreda",
    "lat": "38.64961",
    "lng": "-9.18977"
  },
  {
    "country": "PT",
    "name": "Sobralinho",
    "lat": "38.91703",
    "lng": "-9.02656"
  },
  {
    "country": "PT",
    "name": "Sobral de Monte Agraço",
    "lat": "39.01958",
    "lng": "-9.15081"
  },
  {
    "country": "PT",
    "name": "Sintra",
    "lat": "38.80097",
    "lng": "-9.37826"
  },
  {
    "country": "PT",
    "name": "Sines",
    "lat": "37.95622",
    "lng": "-8.86979"
  },
  {
    "country": "PT",
    "name": "Silves",
    "lat": "37.18921",
    "lng": "-8.43822"
  },
  {
    "country": "PT",
    "name": "Silveira",
    "lat": "39.1112",
    "lng": "-9.3643"
  },
  {
    "country": "PT",
    "name": "Sesimbra",
    "lat": "38.44451",
    "lng": "-9.10149"
  },
  {
    "country": "PT",
    "name": "Setúbal",
    "lat": "38.5244",
    "lng": "-8.8882"
  },
  {
    "country": "PT",
    "name": "Sertã",
    "lat": "39.80205",
    "lng": "-8.09589"
  },
  {
    "country": "PT",
    "name": "Serra de El-Rei",
    "lat": "39.33291",
    "lng": "-9.26843"
  },
  {
    "country": "PT",
    "name": "Serpa",
    "lat": "37.94581",
    "lng": "-7.59754"
  },
  {
    "country": "PT",
    "name": "Senhora da Luz",
    "lat": "37.08771",
    "lng": "-8.72649"
  },
  {
    "country": "PT",
    "name": "Seixal",
    "lat": "38.64008",
    "lng": "-9.10141"
  },
  {
    "country": "PT",
    "name": "Sarilhos Pequenos",
    "lat": "38.68176",
    "lng": "-8.98231"
  },
  {
    "country": "PT",
    "name": "Sardoal",
    "lat": "39.53449",
    "lng": "-8.16119"
  },
  {
    "country": "PT",
    "name": "São Vicente do Paul",
    "lat": "39.34946",
    "lng": "-8.62221"
  },
  {
    "country": "PT",
    "name": "São Vicente",
    "lat": "32.79673",
    "lng": "-17.04323"
  },
  {
    "country": "PT",
    "name": "São Teotónio",
    "lat": "37.51282",
    "lng": "-8.70708"
  },
  {
    "country": "PT",
    "name": "São Roque",
    "lat": "32.66667",
    "lng": "-16.91667"
  },
  {
    "country": "PT",
    "name": "São Pedro da Cadeira",
    "lat": "39.06983",
    "lng": "-9.37174"
  },
  {
    "country": "PT",
    "name": "São Miguel de Rio Torto",
    "lat": "39.43333",
    "lng": "-8.21667"
  },
  {
    "country": "PT",
    "name": "São Martinho do Porto",
    "lat": "39.51444",
    "lng": "-9.13111"
  },
  {
    "country": "PT",
    "name": "São Martinho",
    "lat": "32.6448",
    "lng": "-16.93843"
  },
  {
    "country": "PT",
    "name": "São Marcos da Serra",
    "lat": "37.361",
    "lng": "-8.37764"
  },
  {
    "country": "PT",
    "name": "São Luis",
    "lat": "37.71556",
    "lng": "-8.66472"
  },
  {
    "country": "PT",
    "name": "São Julião",
    "lat": "39.32268",
    "lng": "-7.31106"
  },
  {
    "country": "PT",
    "name": "São Jorge",
    "lat": "32.81667",
    "lng": "-16.9"
  },
  {
    "country": "PT",
    "name": "São João dos Montes",
    "lat": "38.93944",
    "lng": "-9.01892"
  },
  {
    "country": "PT",
    "name": "São João da Talha",
    "lat": "38.82378",
    "lng": "-9.09719"
  },
  {
    "country": "PT",
    "name": "São João das Lampas",
    "lat": "38.87376",
    "lng": "-9.39842"
  },
  {
    "country": "PT",
    "name": "São Domingos de Rana",
    "lat": "38.70194",
    "lng": "-9.34083"
  },
  {
    "country": "PT",
    "name": "São Brás de Alportel",
    "lat": "37.1531",
    "lng": "-7.88751"
  },
  {
    "country": "PT",
    "name": "São Bartolomeu de Messines",
    "lat": "37.25648",
    "lng": "-8.28672"
  },
  {
    "country": "PT",
    "name": "São Bartolomeu",
    "lat": "39.27511",
    "lng": "-9.27885"
  },
  {
    "country": "PT",
    "name": "Santo António da Charneca",
    "lat": "38.62561",
    "lng": "-9.03043"
  },
  {
    "country": "PT",
    "name": "Santo Antão do Tojal",
    "lat": "38.85151",
    "lng": "-9.13975"
  },
  {
    "country": "PT",
    "name": "Santo André",
    "lat": "39.05532",
    "lng": "-8.24414"
  },
  {
    "country": "PT",
    "name": "Santo André",
    "lat": "38.06078",
    "lng": "-8.7822"
  },
  {
    "country": "PT",
    "name": "Santiago do Cacém",
    "lat": "38.01693",
    "lng": "-8.69475"
  },
  {
    "country": "PT",
    "name": "Santarém",
    "lat": "39.23333",
    "lng": "-8.68333"
  },
  {
    "country": "PT",
    "name": "Santana",
    "lat": "32.8",
    "lng": "-16.88333"
  },
  {
    "country": "PT",
    "name": "Santa Margarida da Coutada",
    "lat": "39.45",
    "lng": "-8.31667"
  },
  {
    "country": "PT",
    "name": "Santa Luzia",
    "lat": "37.10224",
    "lng": "-7.66202"
  },
  {
    "country": "PT",
    "name": "Santa Iria da Azóia",
    "lat": "38.8411",
    "lng": "-9.09908"
  },
  {
    "country": "PT",
    "name": "Santa Cruz",
    "lat": "32.68806",
    "lng": "-16.79388"
  },
  {
    "country": "PT",
    "name": "Santa Catarina da Serra",
    "lat": "39.6796",
    "lng": "-8.68679"
  },
  {
    "country": "PT",
    "name": "Santa Bárbara de Nexe",
    "lat": "37.10619",
    "lng": "-7.96648"
  },
  {
    "country": "PT",
    "name": "Samouco",
    "lat": "38.72035",
    "lng": "-9.00471"
  },
  {
    "country": "PT",
    "name": "Samora Correia",
    "lat": "38.93709",
    "lng": "-8.87178"
  },
  {
    "country": "PT",
    "name": "Salvaterra de Magos",
    "lat": "39.02788",
    "lng": "-8.7935"
  },
  {
    "country": "PT",
    "name": "Salvada",
    "lat": "37.93771",
    "lng": "-7.77448"
  },
  {
    "country": "PT",
    "name": "Salir de Matos",
    "lat": "39.43186",
    "lng": "-9.09479"
  },
  {
    "country": "PT",
    "name": "Sagres",
    "lat": "37.00864",
    "lng": "-8.94311"
  },
  {
    "country": "PT",
    "name": "Sacavém",
    "lat": "38.79202",
    "lng": "-9.10801"
  },
  {
    "country": "PT",
    "name": "Rosairinho",
    "lat": "38.67734",
    "lng": "-9.00836"
  },
  {
    "country": "PT",
    "name": "Rio Maior",
    "lat": "39.33732",
    "lng": "-8.93906"
  },
  {
    "country": "PT",
    "name": "Rio de Mouro",
    "lat": "38.76613",
    "lng": "-9.32804"
  },
  {
    "country": "PT",
    "name": "Ribeira Brava",
    "lat": "32.67483",
    "lng": "-17.06288"
  },
  {
    "country": "PT",
    "name": "Riachos",
    "lat": "39.44472",
    "lng": "-8.5142"
  },
  {
    "country": "PT",
    "name": "Reguengos de Monsaraz",
    "lat": "38.42529",
    "lng": "-7.53494"
  },
  {
    "country": "PT",
    "name": "Reguengo",
    "lat": "39.29801",
    "lng": "-7.39234"
  },
  {
    "country": "PT",
    "name": "Redondo",
    "lat": "38.64872",
    "lng": "-7.54708"
  },
  {
    "country": "PT",
    "name": "Ramada",
    "lat": "38.80368",
    "lng": "-9.1877"
  },
  {
    "country": "PT",
    "name": "Quinta do Anjo",
    "lat": "38.56753",
    "lng": "-8.94228"
  },
  {
    "country": "PT",
    "name": "Queluz",
    "lat": "38.75657",
    "lng": "-9.25451"
  },
  {
    "country": "PT",
    "name": "Quejas",
    "lat": "38.71925",
    "lng": "-9.26255"
  },
  {
    "country": "PT",
    "name": "Quarteira",
    "lat": "37.06946",
    "lng": "-8.10064"
  },
  {
    "country": "PT",
    "name": "Proença-a-Nova",
    "lat": "39.7522",
    "lng": "-7.9239"
  },
  {
    "country": "PT",
    "name": "Praia do Ribatejo",
    "lat": "39.46667",
    "lng": "-8.35"
  },
  {
    "country": "PT",
    "name": "Pragal",
    "lat": "38.67459",
    "lng": "-9.16981"
  },
  {
    "country": "PT",
    "name": "Póvoa e Meadas",
    "lat": "39.51046",
    "lng": "-7.51765"
  },
  {
    "country": "PT",
    "name": "Póvoa de Santo Adrião",
    "lat": "38.8",
    "lng": "-9.16667"
  },
  {
    "country": "PT",
    "name": "Póvoa de Santa Iria",
    "lat": "38.86101",
    "lng": "-9.06453"
  },
  {
    "country": "PT",
    "name": "Porto Salvo",
    "lat": "38.72293",
    "lng": "-9.30473"
  },
  {
    "country": "PT",
    "name": "Porto Moniz",
    "lat": "32.86681",
    "lng": "-17.16667"
  },
  {
    "country": "PT",
    "name": "Porto de Mós",
    "lat": "39.60191",
    "lng": "-8.81839"
  },
  {
    "country": "PT",
    "name": "Porto da Cruz",
    "lat": "32.76667",
    "lng": "-16.83333"
  },
  {
    "country": "PT",
    "name": "Porto Covo",
    "lat": "37.85256",
    "lng": "-8.79018"
  },
  {
    "country": "PT",
    "name": "Portimão",
    "lat": "37.13856",
    "lng": "-8.53775"
  },
  {
    "country": "PT",
    "name": "Portel",
    "lat": "38.30697",
    "lng": "-7.70244"
  },
  {
    "country": "PT",
    "name": "Portalegre",
    "lat": "39.29379",
    "lng": "-7.43122"
  },
  {
    "country": "PT",
    "name": "Porches",
    "lat": "37.12665",
    "lng": "-8.40162"
  },
  {
    "country": "PT",
    "name": "Pontinha",
    "lat": "38.76771",
    "lng": "-9.19935"
  },
  {
    "country": "PT",
    "name": "Pontével",
    "lat": "39.14945",
    "lng": "-8.8388"
  },
  {
    "country": "PT",
    "name": "Ponte de Sôr",
    "lat": "39.24964",
    "lng": "-8.01009"
  },
  {
    "country": "PT",
    "name": "Ponta do Sol",
    "lat": "32.6798",
    "lng": "-17.1"
  },
  {
    "country": "PT",
    "name": "Pombal",
    "lat": "39.91674",
    "lng": "-8.62847"
  },
  {
    "country": "PT",
    "name": "Poceirão",
    "lat": "38.83095",
    "lng": "-8.79365"
  },
  {
    "country": "PT",
    "name": "Pinheiro Grande",
    "lat": "39.39212",
    "lng": "-8.4341"
  },
  {
    "country": "PT",
    "name": "Pinhal Novo",
    "lat": "38.63106",
    "lng": "-8.91376"
  },
  {
    "country": "PT",
    "name": "Piedade",
    "lat": "38.67005",
    "lng": "-9.15852"
  },
  {
    "country": "PT",
    "name": "Pero Pinheiro",
    "lat": "38.85783",
    "lng": "-9.32352"
  },
  {
    "country": "PT",
    "name": "Pêra",
    "lat": "37.12296",
    "lng": "-8.34115"
  },
  {
    "country": "PT",
    "name": "Peniche",
    "lat": "39.3558",
    "lng": "-9.38112"
  },
  {
    "country": "PT",
    "name": "Penedo Gordo",
    "lat": "37.98477",
    "lng": "-7.91651"
  },
  {
    "country": "PT",
    "name": "Pego",
    "lat": "39.46146",
    "lng": "-8.14955"
  },
  {
    "country": "PT",
    "name": "Pedrógão Grande",
    "lat": "39.91835",
    "lng": "-8.1459"
  },
  {
    "country": "PT",
    "name": "Pataias",
    "lat": "39.66978",
    "lng": "-8.9958"
  },
  {
    "country": "PT",
    "name": "Parede",
    "lat": "38.69282",
    "lng": "-9.35412"
  },
  {
    "country": "PT",
    "name": "Parchal",
    "lat": "37.13827",
    "lng": "-8.51703"
  },
  {
    "country": "PT",
    "name": "Palmela",
    "lat": "38.56902",
    "lng": "-8.90126"
  },
  {
    "country": "PT",
    "name": "Paialvo",
    "lat": "39.56399",
    "lng": "-8.46835"
  },
  {
    "country": "PT",
    "name": "Paderne",
    "lat": "37.17935",
    "lng": "-8.2015"
  },
  {
    "country": "PT",
    "name": "Paço de Arcos",
    "lat": "38.69569",
    "lng": "-9.29143"
  },
  {
    "country": "PT",
    "name": "Ourique",
    "lat": "37.6539",
    "lng": "-8.22569"
  },
  {
    "country": "PT",
    "name": "Ourém",
    "lat": "39.64167",
    "lng": "-8.5919"
  },
  {
    "country": "PT",
    "name": "Ota",
    "lat": "39.11199",
    "lng": "-8.99105"
  },
  {
    "country": "PT",
    "name": "Olival do Basto",
    "lat": "38.79079",
    "lng": "-9.16621"
  },
  {
    "country": "PT",
    "name": "Olivais",
    "lat": "38.76994",
    "lng": "-9.10674"
  },
  {
    "country": "PT",
    "name": "Olhos de Água",
    "lat": "37.09024",
    "lng": "-8.19168"
  },
  {
    "country": "PT",
    "name": "Olhão",
    "lat": "37.0286",
    "lng": "-7.8411"
  },
  {
    "country": "PT",
    "name": "Oleiros",
    "lat": "39.91893",
    "lng": "-7.9137"
  },
  {
    "country": "PT",
    "name": "Oeiras",
    "lat": "38.69105",
    "lng": "-9.31085"
  },
  {
    "country": "PT",
    "name": "Odivelas",
    "lat": "38.79269",
    "lng": "-9.1838"
  },
  {
    "country": "PT",
    "name": "Odemira",
    "lat": "37.59798",
    "lng": "-8.63972"
  },
  {
    "country": "PT",
    "name": "Óbidos",
    "lat": "39.36055",
    "lng": "-9.1567"
  },
  {
    "country": "PT",
    "name": "Nossa Senhora do Monte",
    "lat": "32.66667",
    "lng": "-16.9"
  },
  {
    "country": "PT",
    "name": "Nisa",
    "lat": "39.51499",
    "lng": "-7.64908"
  },
  {
    "country": "PT",
    "name": "Neves",
    "lat": "38.0227",
    "lng": "-7.81344"
  },
  {
    "country": "PT",
    "name": "Nazaré",
    "lat": "39.60289",
    "lng": "-9.06836"
  },
  {
    "country": "PT",
    "name": "Nadadouro",
    "lat": "39.41927",
    "lng": "-9.19091"
  },
  {
    "country": "PT",
    "name": "Mourão",
    "lat": "38.38356",
    "lng": "-7.34189"
  },
  {
    "country": "PT",
    "name": "Moura",
    "lat": "38.1401",
    "lng": "-7.44856"
  },
  {
    "country": "PT",
    "name": "Moscavide e Portela",
    "lat": "38.77929",
    "lng": "-9.10222"
  },
  {
    "country": "PT",
    "name": "Mora",
    "lat": "38.94351",
    "lng": "-8.16434"
  },
  {
    "country": "PT",
    "name": "Montijo",
    "lat": "38.70675",
    "lng": "-8.97388"
  },
  {
    "country": "PT",
    "name": "Monte Redondo",
    "lat": "39.8993",
    "lng": "-8.83171"
  },
  {
    "country": "PT",
    "name": "Monte Real",
    "lat": "39.8521",
    "lng": "-8.86349"
  },
  {
    "country": "PT",
    "name": "Montemor-o-Novo",
    "lat": "38.64812",
    "lng": "-8.21455"
  },
  {
    "country": "PT",
    "name": "Monte Gordo",
    "lat": "37.18192",
    "lng": "-7.45225"
  },
  {
    "country": "PT",
    "name": "Monte Estoril",
    "lat": "38.70636",
    "lng": "-9.40595"
  },
  {
    "country": "PT",
    "name": "Montargil",
    "lat": "39.07771",
    "lng": "-8.17044"
  },
  {
    "country": "PT",
    "name": "Montalvo",
    "lat": "39.48333",
    "lng": "-8.3"
  },
  {
    "country": "PT",
    "name": "Montalvinho",
    "lat": "39.48333",
    "lng": "-8.3"
  },
  {
    "country": "PT",
    "name": "Monsanto",
    "lat": "39.46203",
    "lng": "-8.7118"
  },
  {
    "country": "PT",
    "name": "Monforte",
    "lat": "39.05318",
    "lng": "-7.43689"
  },
  {
    "country": "PT",
    "name": "Monchique",
    "lat": "37.31775",
    "lng": "-8.55529"
  },
  {
    "country": "PT",
    "name": "Moncarapacho",
    "lat": "37.0836",
    "lng": "-7.78763"
  },
  {
    "country": "PT",
    "name": "Moita dos Ferreiros",
    "lat": "39.24825",
    "lng": "-9.22355"
  },
  {
    "country": "PT",
    "name": "Moita",
    "lat": "38.65078",
    "lng": "-8.99038"
  },
  {
    "country": "PT",
    "name": "Mira",
    "lat": "39.54315",
    "lng": "-8.71505"
  },
  {
    "country": "PT",
    "name": "Minde",
    "lat": "39.51631",
    "lng": "-8.68799"
  },
  {
    "country": "PT",
    "name": "Minas de São Domingos",
    "lat": "37.67322",
    "lng": "-7.49765"
  },
  {
    "country": "PT",
    "name": "Milharado",
    "lat": "38.94732",
    "lng": "-9.19914"
  },
  {
    "country": "PT",
    "name": "Mexilhoeira Grande",
    "lat": "37.15858",
    "lng": "-8.61487"
  },
  {
    "country": "PT",
    "name": "Mértola",
    "lat": "37.64304",
    "lng": "-7.6611"
  },
  {
    "country": "PT",
    "name": "Mem Martins",
    "lat": "38.79443",
    "lng": "-9.34284"
  },
  {
    "country": "PT",
    "name": "Meca",
    "lat": "39.08178",
    "lng": "-9.03459"
  },
  {
    "country": "PT",
    "name": "Massamá",
    "lat": "38.75279",
    "lng": "-9.2811"
  },
  {
    "country": "PT",
    "name": "Marvão",
    "lat": "39.39377",
    "lng": "-7.37663"
  },
  {
    "country": "PT",
    "name": "Marmelete",
    "lat": "37.31014",
    "lng": "-8.66813"
  },
  {
    "country": "PT",
    "name": "Marinhais",
    "lat": "39.0473",
    "lng": "-8.70236"
  },
  {
    "country": "PT",
    "name": "Marinha Grande",
    "lat": "39.74769",
    "lng": "-8.93228"
  },
  {
    "country": "PT",
    "name": "Malveira",
    "lat": "38.93213",
    "lng": "-9.25779"
  },
  {
    "country": "PT",
    "name": "Mafra",
    "lat": "38.93793",
    "lng": "-9.32756"
  },
  {
    "country": "PT",
    "name": "Madalena",
    "lat": "39.57133",
    "lng": "-8.44635"
  },
  {
    "country": "PT",
    "name": "Machico",
    "lat": "32.7162",
    "lng": "-16.76758"
  },
  {
    "country": "PT",
    "name": "Maceira",
    "lat": "39.68853",
    "lng": "-8.89423"
  },
  {
    "country": "PT",
    "name": "Mação",
    "lat": "39.55573",
    "lng": "-7.99421"
  },
  {
    "country": "PT",
    "name": "Luz",
    "lat": "37.09216",
    "lng": "-7.70433"
  },
  {
    "country": "PT",
    "name": "Lourinhã",
    "lat": "39.24166",
    "lng": "-9.31254"
  },
  {
    "country": "PT",
    "name": "Louriçal",
    "lat": "40.0039",
    "lng": "-8.73736"
  },
  {
    "country": "PT",
    "name": "Loures",
    "lat": "38.83091",
    "lng": "-9.16845"
  },
  {
    "country": "PT",
    "name": "Loulé",
    "lat": "37.13772",
    "lng": "-8.01968"
  },
  {
    "country": "PT",
    "name": "Lisbon",
    "lat": "38.71667",
    "lng": "-9.13333"
  },
  {
    "country": "PT",
    "name": "Linda-a-Velha",
    "lat": "38.71446",
    "lng": "-9.2422"
  },
  {
    "country": "PT",
    "name": "Leiria",
    "lat": "39.74362",
    "lng": "-8.80705"
  },
  {
    "country": "PT",
    "name": "Lavradio",
    "lat": "38.66808",
    "lng": "-9.05204"
  },
  {
    "country": "PT",
    "name": "Laranjeiro",
    "lat": "37.06799",
    "lng": "-7.8078"
  },
  {
    "country": "PT",
    "name": "Laranjeira",
    "lat": "38.65599",
    "lng": "-9.15376"
  },
  {
    "country": "PT",
    "name": "Lagos",
    "lat": "37.10202",
    "lng": "-8.67422"
  },
  {
    "country": "PT",
    "name": "Lagoa",
    "lat": "37.13535",
    "lng": "-8.45319"
  },
  {
    "country": "PT",
    "name": "Idanha-a-Nova",
    "lat": "39.92316",
    "lng": "-7.24082"
  },
  {
    "country": "PT",
    "name": "Guia",
    "lat": "37.12959",
    "lng": "-8.29963"
  },
  {
    "country": "PT",
    "name": "Grândola",
    "lat": "38.17718",
    "lng": "-8.56675"
  },
  {
    "country": "PT",
    "name": "Golegã",
    "lat": "39.40474",
    "lng": "-8.48625"
  },
  {
    "country": "PT",
    "name": "Gavião",
    "lat": "39.46443",
    "lng": "-7.93449"
  },
  {
    "country": "PT",
    "name": "Fuzeta",
    "lat": "37.05429",
    "lng": "-7.74699"
  },
  {
    "country": "PT",
    "name": "Funchal",
    "lat": "32.66568",
    "lng": "-16.92547"
  },
  {
    "country": "PT",
    "name": "Fronteira",
    "lat": "39.05629",
    "lng": "-7.64868"
  },
  {
    "country": "PT",
    "name": "Foz do Arelho",
    "lat": "39.43672",
    "lng": "-9.21374"
  },
  {
    "country": "PT",
    "name": "Fortios",
    "lat": "39.32494",
    "lng": "-7.50057"
  },
  {
    "country": "PT",
    "name": "Figueiró dos Vinhos",
    "lat": "39.90413",
    "lng": "-8.27511"
  },
  {
    "country": "PT",
    "name": "Ferrel",
    "lat": "39.36398",
    "lng": "-9.31541"
  },
  {
    "country": "PT",
    "name": "Ferreiras",
    "lat": "37.12926",
    "lng": "-8.23759"
  },
  {
    "country": "PT",
    "name": "Ferreira do Zêzere",
    "lat": "39.69406",
    "lng": "-8.29213"
  },
  {
    "country": "PT",
    "name": "Ferreira do Alentejo",
    "lat": "38.05",
    "lng": "-8.03333"
  },
  {
    "country": "PT",
    "name": "Ferragudo",
    "lat": "37.12474",
    "lng": "-8.51915"
  },
  {
    "country": "PT",
    "name": "Fazendas de Almeirim",
    "lat": "39.17553",
    "lng": "-8.56927"
  },
  {
    "country": "PT",
    "name": "Fátima",
    "lat": "39.62071",
    "lng": "-8.65237"
  },
  {
    "country": "PT",
    "name": "Faro",
    "lat": "37.01937",
    "lng": "-7.93223"
  },
  {
    "country": "PT",
    "name": "Famões",
    "lat": "38.78804",
    "lng": "-9.21033"
  },
  {
    "country": "PT",
    "name": "Famalicão",
    "lat": "39.53642",
    "lng": "-9.08308"
  },
  {
    "country": "PT",
    "name": "Fajã da Ovelha",
    "lat": "32.77457",
    "lng": "-17.23412"
  },
  {
    "country": "PT",
    "name": "Faial",
    "lat": "32.78333",
    "lng": "-16.85"
  },
  {
    "country": "PT",
    "name": "Évora",
    "lat": "38.56667",
    "lng": "-7.9"
  },
  {
    "country": "PT",
    "name": "Estremoz",
    "lat": "38.84432",
    "lng": "-7.58585"
  },
  {
    "country": "PT",
    "name": "Estreito da Calheta",
    "lat": "32.73704",
    "lng": "-17.18674"
  },
  {
    "country": "PT",
    "name": "Estoril",
    "lat": "38.70571",
    "lng": "-9.39773"
  },
  {
    "country": "PT",
    "name": "Estômbar",
    "lat": "37.14629",
    "lng": "-8.48505"
  },
  {
    "country": "PT",
    "name": "Estói",
    "lat": "37.09503",
    "lng": "-7.89445"
  },
  {
    "country": "PT",
    "name": "Ericeira",
    "lat": "38.96275",
    "lng": "-9.41563"
  },
  {
    "country": "PT",
    "name": "Entroncamento",
    "lat": "39.46667",
    "lng": "-8.46667"
  },
  {
    "country": "PT",
    "name": "Elvas",
    "lat": "38.8815",
    "lng": "-7.16282"
  },
  {
    "country": "PT",
    "name": "Curral das Freiras",
    "lat": "32.72029",
    "lng": "-16.96993"
  },
  {
    "country": "PT",
    "name": "Cuba",
    "lat": "38.16544",
    "lng": "-7.8924"
  },
  {
    "country": "PT",
    "name": "Costa de Caparica",
    "lat": "38.64458",
    "lng": "-9.23556"
  },
  {
    "country": "PT",
    "name": "Coruche",
    "lat": "38.95955",
    "lng": "-8.52524"
  },
  {
    "country": "PT",
    "name": "Corroios",
    "lat": "38.64004",
    "lng": "-9.1508"
  },
  {
    "country": "PT",
    "name": "Constância",
    "lat": "39.47796",
    "lng": "-8.33636"
  },
  {
    "country": "PT",
    "name": "Conceição",
    "lat": "37.14789",
    "lng": "-7.60426"
  },
  {
    "country": "PT",
    "name": "Comporta",
    "lat": "38.38059",
    "lng": "-8.78608"
  },
  {
    "country": "PT",
    "name": "Colares",
    "lat": "38.79921",
    "lng": "-9.44691"
  },
  {
    "country": "PT",
    "name": "Charneca",
    "lat": "38.78351",
    "lng": "-9.14348"
  },
  {
    "country": "PT",
    "name": "Charneca de Caparica",
    "lat": "38.62032",
    "lng": "-9.19426"
  },
  {
    "country": "PT",
    "name": "Cercal",
    "lat": "37.80129",
    "lng": "-8.674"
  },
  {
    "country": "PT",
    "name": "Cela",
    "lat": "39.54075",
    "lng": "-9.03449"
  },
  {
    "country": "PT",
    "name": "Caxias",
    "lat": "38.70314",
    "lng": "-9.27666"
  },
  {
    "country": "PT",
    "name": "Castro Verde",
    "lat": "37.69828",
    "lng": "-8.08581"
  },
  {
    "country": "PT",
    "name": "Castro Marim",
    "lat": "37.22068",
    "lng": "-7.4435"
  },
  {
    "country": "PT",
    "name": "Castelo de Vide",
    "lat": "39.41624",
    "lng": "-7.4568"
  },
  {
    "country": "PT",
    "name": "Castelo Branco",
    "lat": "39.82219",
    "lng": "-7.49087"
  },
  {
    "country": "PT",
    "name": "Castanheira do Ribatejo",
    "lat": "38.99298",
    "lng": "-8.97346"
  },
  {
    "country": "PT",
    "name": "Castanheira de Pêra",
    "lat": "40.00717",
    "lng": "-8.21048"
  },
  {
    "country": "PT",
    "name": "Cascais",
    "lat": "38.69681",
    "lng": "-9.42147"
  },
  {
    "country": "PT",
    "name": "Carvoeiro",
    "lat": "37.09736",
    "lng": "-8.46846"
  },
  {
    "country": "PT",
    "name": "Cartaxo",
    "lat": "39.16022",
    "lng": "-8.78741"
  },
  {
    "country": "PT",
    "name": "Carregado",
    "lat": "39.02362",
    "lng": "-8.97692"
  },
  {
    "country": "PT",
    "name": "Carnaxide",
    "lat": "38.72706",
    "lng": "-9.24671"
  },
  {
    "country": "PT",
    "name": "Carcavelos",
    "lat": "38.69105",
    "lng": "-9.32215"
  },
  {
    "country": "PT",
    "name": "Caranguejeira",
    "lat": "39.74619",
    "lng": "-8.7074"
  },
  {
    "country": "PT",
    "name": "Caparica",
    "lat": "38.66179",
    "lng": "-9.20032"
  },
  {
    "country": "PT",
    "name": "Caniço",
    "lat": "32.65078",
    "lng": "-16.83749"
  },
  {
    "country": "PT",
    "name": "Caniçal",
    "lat": "32.73834",
    "lng": "-16.73836"
  },
  {
    "country": "PT",
    "name": "Canhas",
    "lat": "32.69465",
    "lng": "-17.09867"
  },
  {
    "country": "PT",
    "name": "Caneças",
    "lat": "38.81321",
    "lng": "-9.22679"
  },
  {
    "country": "PT",
    "name": "Campo Maior",
    "lat": "39.01774",
    "lng": "-7.06497"
  },
  {
    "country": "PT",
    "name": "Campelos",
    "lat": "39.19678",
    "lng": "-9.23519"
  },
  {
    "country": "PT",
    "name": "Campanário",
    "lat": "32.66578",
    "lng": "-17.03576"
  },
  {
    "country": "PT",
    "name": "Camarate",
    "lat": "38.80358",
    "lng": "-9.12809"
  },
  {
    "country": "PT",
    "name": "Câmara de Lobos",
    "lat": "32.65043",
    "lng": "-16.97718"
  },
  {
    "country": "PT",
    "name": "Camacha",
    "lat": "32.67919",
    "lng": "-16.84462"
  },
  {
    "country": "PT",
    "name": "Calheta",
    "lat": "32.71667",
    "lng": "-17.18333"
  },
  {
    "country": "PT",
    "name": "Caldas da Rainha",
    "lat": "39.40326",
    "lng": "-9.13839"
  },
  {
    "country": "PT",
    "name": "Cadaval",
    "lat": "39.24298",
    "lng": "-9.10327"
  },
  {
    "country": "PT",
    "name": "Cadafais",
    "lat": "39.00461",
    "lng": "-9.00419"
  },
  {
    "country": "PT",
    "name": "Cacilhas",
    "lat": "38.68638",
    "lng": "-9.14938"
  },
  {
    "country": "PT",
    "name": "Cacém",
    "lat": "38.76698",
    "lng": "-9.29793"
  },
  {
    "country": "PT",
    "name": "Cabeça Gorda",
    "lat": "37.92401",
    "lng": "-7.7929"
  },
  {
    "country": "PT",
    "name": "Cabanas de Torres",
    "lat": "39.15581",
    "lng": "-9.06588"
  },
  {
    "country": "PT",
    "name": "Bucelas",
    "lat": "38.90193",
    "lng": "-9.11885"
  },
  {
    "country": "PT",
    "name": "Borba",
    "lat": "38.80553",
    "lng": "-7.45465"
  },
  {
    "country": "PT",
    "name": "Bombarral",
    "lat": "39.26723",
    "lng": "-9.15795"
  },
  {
    "country": "PT",
    "name": "Boliqueime",
    "lat": "37.13718",
    "lng": "-8.1582"
  },
  {
    "country": "PT",
    "name": "Bobadela",
    "lat": "38.80774",
    "lng": "-9.09925"
  },
  {
    "country": "PT",
    "name": "Boavista dos Pinheiros",
    "lat": "37.58058",
    "lng": "-8.66441"
  },
  {
    "country": "PT",
    "name": "Boaventura",
    "lat": "32.81846",
    "lng": "-16.97268"
  },
  {
    "country": "PT",
    "name": "Beringel",
    "lat": "38.05656",
    "lng": "-7.98427"
  },
  {
    "country": "PT",
    "name": "Bensafrim",
    "lat": "37.15583",
    "lng": "-8.7352"
  },
  {
    "country": "PT",
    "name": "Benedita",
    "lat": "39.4247",
    "lng": "-8.96996"
  },
  {
    "country": "PT",
    "name": "Benavente",
    "lat": "38.97919",
    "lng": "-8.80759"
  },
  {
    "country": "PT",
    "name": "Bemfica",
    "lat": "39.14325",
    "lng": "-8.68717"
  },
  {
    "country": "PT",
    "name": "Benfica",
    "lat": "38.75087",
    "lng": "-9.20282"
  },
  {
    "country": "PT",
    "name": "Belas",
    "lat": "38.7767",
    "lng": "-9.26353"
  },
  {
    "country": "PT",
    "name": "Beja",
    "lat": "38.01506",
    "lng": "-7.86323"
  },
  {
    "country": "PT",
    "name": "Beato António",
    "lat": "38.73327",
    "lng": "-9.10335"
  },
  {
    "country": "PT",
    "name": "Batalha",
    "lat": "39.66025",
    "lng": "-8.82475"
  },
  {
    "country": "PT",
    "name": "Barreiro",
    "lat": "38.66314",
    "lng": "-9.0724"
  },
  {
    "country": "PT",
    "name": "Barrancos",
    "lat": "38.13446",
    "lng": "-6.97604"
  },
  {
    "country": "PT",
    "name": "Barcarena",
    "lat": "38.73245",
    "lng": "-9.28"
  },
  {
    "country": "PT",
    "name": "Azinhaga",
    "lat": "39.34877",
    "lng": "-8.53005"
  },
  {
    "country": "PT",
    "name": "Azambuja",
    "lat": "39.07029",
    "lng": "-8.86822"
  },
  {
    "country": "PT",
    "name": "Avis",
    "lat": "39.05391",
    "lng": "-7.89156"
  },
  {
    "country": "PT",
    "name": "Aveiras de Cima",
    "lat": "39.13796",
    "lng": "-8.89932"
  },
  {
    "country": "PT",
    "name": "Atouguia da Baleia",
    "lat": "39.33814",
    "lng": "-9.3263"
  },
  {
    "country": "PT",
    "name": "Atalaia",
    "lat": "39.45551",
    "lng": "-7.87295"
  },
  {
    "country": "PT",
    "name": "Arruda dos Vinhos",
    "lat": "38.98411",
    "lng": "-9.07746"
  },
  {
    "country": "PT",
    "name": "Arronches",
    "lat": "39.12242",
    "lng": "-7.28619"
  },
  {
    "country": "PT",
    "name": "Arrentela",
    "lat": "38.625",
    "lng": "-9.10151"
  },
  {
    "country": "PT",
    "name": "Arranhó",
    "lat": "38.95378",
    "lng": "-9.13465"
  },
  {
    "country": "PT",
    "name": "Arraiolos",
    "lat": "38.72363",
    "lng": "-7.98478"
  },
  {
    "country": "PT",
    "name": "Armação de Pêra",
    "lat": "37.10256",
    "lng": "-8.35695"
  },
  {
    "country": "PT",
    "name": "Arco da Calheta",
    "lat": "32.71502",
    "lng": "-17.14974"
  },
  {
    "country": "PT",
    "name": "Apelação",
    "lat": "38.81387",
    "lng": "-9.13225"
  },
  {
    "country": "PT",
    "name": "Ansião",
    "lat": "39.91177",
    "lng": "-8.43568"
  },
  {
    "country": "PT",
    "name": "Amora",
    "lat": "38.62961",
    "lng": "-9.11557"
  },
  {
    "country": "PT",
    "name": "Amor",
    "lat": "39.80404",
    "lng": "-8.85984"
  },
  {
    "country": "PT",
    "name": "Amiães de Baixo",
    "lat": "39.44296",
    "lng": "-8.73358"
  },
  {
    "country": "PT",
    "name": "Amadora",
    "lat": "38.75382",
    "lng": "-9.23083"
  },
  {
    "country": "PT",
    "name": "Alvorninha",
    "lat": "39.38224",
    "lng": "-9.03674"
  },
  {
    "country": "PT",
    "name": "Alvor",
    "lat": "37.12994",
    "lng": "-8.59174"
  },
  {
    "country": "PT",
    "name": "Alvito",
    "lat": "38.25611",
    "lng": "-7.99158"
  },
  {
    "country": "PT",
    "name": "Alvaiázere",
    "lat": "39.82256",
    "lng": "-8.37999"
  },
  {
    "country": "PT",
    "name": "Altura",
    "lat": "37.1756",
    "lng": "-7.50064"
  },
  {
    "country": "PT",
    "name": "Alter do Chão",
    "lat": "39.19741",
    "lng": "-7.65893"
  },
  {
    "country": "PT",
    "name": "Alpiarça",
    "lat": "39.25712",
    "lng": "-8.58187"
  },
  {
    "country": "PT",
    "name": "Almograve",
    "lat": "37.65665",
    "lng": "-8.79214"
  },
  {
    "country": "PT",
    "name": "Almodôvar",
    "lat": "37.51279",
    "lng": "-8.06008"
  },
  {
    "country": "PT",
    "name": "Almeirim",
    "lat": "39.20837",
    "lng": "-8.62635"
  },
  {
    "country": "PT",
    "name": "Almargem",
    "lat": "38.84485",
    "lng": "-9.27315"
  },
  {
    "country": "PT",
    "name": "Almancil",
    "lat": "37.08686",
    "lng": "-8.03074"
  },
  {
    "country": "PT",
    "name": "Almada",
    "lat": "38.67902",
    "lng": "-9.1569"
  },
  {
    "country": "PT",
    "name": "Aljustrel",
    "lat": "37.87759",
    "lng": "-8.16516"
  },
  {
    "country": "PT",
    "name": "Aljubarrota",
    "lat": "39.56715",
    "lng": "-8.92925"
  },
  {
    "country": "PT",
    "name": "Aljezur",
    "lat": "37.31745",
    "lng": "-8.80147"
  },
  {
    "country": "PT",
    "name": "Alhos Vedros",
    "lat": "38.65486",
    "lng": "-9.02368"
  },
  {
    "country": "PT",
    "name": "Alhandra",
    "lat": "38.92732",
    "lng": "-9.00864"
  },
  {
    "country": "PT",
    "name": "Algueirão",
    "lat": "38.79764",
    "lng": "-9.3437"
  },
  {
    "country": "PT",
    "name": "Algoz",
    "lat": "37.16301",
    "lng": "-8.30359"
  },
  {
    "country": "PT",
    "name": "Algés",
    "lat": "38.70245",
    "lng": "-9.22936"
  },
  {
    "country": "PT",
    "name": "Alferrarede",
    "lat": "39.48333",
    "lng": "-8.16667"
  },
  {
    "country": "PT",
    "name": "Alfeizerão",
    "lat": "39.49971",
    "lng": "-9.10341"
  },
  {
    "country": "PT",
    "name": "Alenquer",
    "lat": "39.05315",
    "lng": "-9.00928"
  },
  {
    "country": "PT",
    "name": "Alegrete",
    "lat": "39.23983",
    "lng": "-7.32342"
  },
  {
    "country": "PT",
    "name": "Aldeia Nova de São Bento",
    "lat": "37.92603",
    "lng": "-7.40804"
  },
  {
    "country": "PT",
    "name": "Aldeia de Paio Pires",
    "lat": "38.61667",
    "lng": "-9.08333"
  },
  {
    "country": "PT",
    "name": "Alcoutim",
    "lat": "37.47432",
    "lng": "-7.47228"
  },
  {
    "country": "PT",
    "name": "Alcoentre",
    "lat": "39.20857",
    "lng": "-8.95953"
  },
  {
    "country": "PT",
    "name": "Alcochete",
    "lat": "38.75534",
    "lng": "-8.96086"
  },
  {
    "country": "PT",
    "name": "Alcobaça",
    "lat": "39.55223",
    "lng": "-8.97749"
  },
  {
    "country": "PT",
    "name": "Alcantarilha",
    "lat": "37.13044",
    "lng": "-8.34623"
  },
  {
    "country": "PT",
    "name": "Alcanhões",
    "lat": "39.29603",
    "lng": "-8.65847"
  },
  {
    "country": "PT",
    "name": "Alcanena",
    "lat": "39.459",
    "lng": "-8.66892"
  },
  {
    "country": "PT",
    "name": "Alcanede",
    "lat": "39.41501",
    "lng": "-8.82189"
  },
  {
    "country": "PT",
    "name": "Alcains",
    "lat": "39.91642",
    "lng": "-7.45655"
  },
  {
    "country": "PT",
    "name": "Alcácer do Sal",
    "lat": "38.37326",
    "lng": "-8.51444"
  },
  {
    "country": "PT",
    "name": "Alcabideche",
    "lat": "38.73366",
    "lng": "-9.40928"
  },
  {
    "country": "PT",
    "name": "Albufeira",
    "lat": "37.08819",
    "lng": "-8.2503"
  },
  {
    "country": "PT",
    "name": "Alandroal",
    "lat": "38.702",
    "lng": "-7.40309"
  },
  {
    "country": "PT",
    "name": "Alagoa",
    "lat": "39.36125",
    "lng": "-7.53894"
  },
  {
    "country": "PT",
    "name": "Água de Pena",
    "lat": "32.70143",
    "lng": "-16.77874"
  },
  {
    "country": "PT",
    "name": "A dos Francos",
    "lat": "39.32272",
    "lng": "-9.04743"
  },
  {
    "country": "PT",
    "name": "A dos Cunhados",
    "lat": "39.15237",
    "lng": "-9.2972"
  },
  {
    "country": "PT",
    "name": "Abrigada",
    "lat": "39.14416",
    "lng": "-9.01853"
  },
  {
    "country": "PT",
    "name": "Abrantes",
    "lat": "39.46667",
    "lng": "-8.2"
  },
  {
    "country": "PT",
    "name": "Vouzela",
    "lat": "40.72361",
    "lng": "-8.11283"
  },
  {
    "country": "PT",
    "name": "Vizela",
    "lat": "41.39096",
    "lng": "-8.26389"
  },
  {
    "country": "PT",
    "name": "Vizela",
    "lat": "41.38242",
    "lng": "-8.24887"
  },
  {
    "country": "PT",
    "name": "Viseu",
    "lat": "40.66101",
    "lng": "-7.90971"
  },
  {
    "country": "PT",
    "name": "Vinhais",
    "lat": "41.83509",
    "lng": "-7.00501"
  },
  {
    "country": "PT",
    "name": "Vimioso",
    "lat": "41.58473",
    "lng": "-6.52767"
  },
  {
    "country": "PT",
    "name": "Vilela",
    "lat": "41.22511",
    "lng": "-7.60338"
  },
  {
    "country": "PT",
    "name": "Vila Verde",
    "lat": "41.64729",
    "lng": "-8.43715"
  },
  {
    "country": "PT",
    "name": "Vila Seca",
    "lat": "41.50031",
    "lng": "-8.68525"
  },
  {
    "country": "PT",
    "name": "Vilarinho",
    "lat": "41.35955",
    "lng": "-8.33123"
  },
  {
    "country": "PT",
    "name": "Vila Real",
    "lat": "41.30062",
    "lng": "-7.74413"
  },
  {
    "country": "PT",
    "name": "Vilar do Paraíso",
    "lat": "41.08974",
    "lng": "-8.6211"
  },
  {
    "country": "PT",
    "name": "Vilar de Figos",
    "lat": "41.47555",
    "lng": "-8.65382"
  },
  {
    "country": "PT",
    "name": "Vilar de Andorinho",
    "lat": "41.10574",
    "lng": "-8.58622"
  },
  {
    "country": "PT",
    "name": "Vila Praia de Âncora",
    "lat": "41.81098",
    "lng": "-8.85255"
  },
  {
    "country": "PT",
    "name": "Vila Pouca de Aguiar",
    "lat": "41.50018",
    "lng": "-7.64383"
  },
  {
    "country": "PT",
    "name": "Vila Nova de Paiva",
    "lat": "40.85291",
    "lng": "-7.72791"
  },
  {
    "country": "PT",
    "name": "Vila Nova de Gaia",
    "lat": "41.12401",
    "lng": "-8.61241"
  },
  {
    "country": "PT",
    "name": "Vila Nova de Foz Côa",
    "lat": "41.08194",
    "lng": "-7.14146"
  },
  {
    "country": "PT",
    "name": "Vila Nova de Famalicão",
    "lat": "41.40797",
    "lng": "-8.51978"
  },
  {
    "country": "PT",
    "name": "Vila Nova da Telha",
    "lat": "41.0717",
    "lng": "-8.64146"
  },
  {
    "country": "PT",
    "name": "Vila Nova de Cerveira",
    "lat": "41.94118",
    "lng": "-8.7423"
  },
  {
    "country": "PT",
    "name": "Vila Frescainha",
    "lat": "41.53846",
    "lng": "-8.63971"
  },
  {
    "country": "PT",
    "name": "Vila do Conde",
    "lat": "41.35326",
    "lng": "-8.74516"
  },
  {
    "country": "PT",
    "name": "Vila Cova",
    "lat": "41.55107",
    "lng": "-8.71645"
  },
  {
    "country": "PT",
    "name": "Vila Chã",
    "lat": "40.86667",
    "lng": "-8.46667"
  },
  {
    "country": "PT",
    "name": "Vilaça",
    "lat": "41.51787",
    "lng": "-8.48357"
  },
  {
    "country": "PT",
    "name": "Vieira do Minho",
    "lat": "41.63292",
    "lng": "-8.14252"
  },
  {
    "country": "PT",
    "name": "Viana do Castelo",
    "lat": "41.69323",
    "lng": "-8.83287"
  },
  {
    "country": "PT",
    "name": "Várzea",
    "lat": "41.51512",
    "lng": "-8.584"
  },
  {
    "country": "PT",
    "name": "Valpaços",
    "lat": "41.60746",
    "lng": "-7.31088"
  },
  {
    "country": "PT",
    "name": "Valongo",
    "lat": "41.18883",
    "lng": "-8.49857"
  },
  {
    "country": "PT",
    "name": "Valongo",
    "lat": "40.61667",
    "lng": "-8.45"
  },
  {
    "country": "PT",
    "name": "Valença",
    "lat": "42.03104",
    "lng": "-8.64595"
  },
  {
    "country": "PT",
    "name": "Válega",
    "lat": "40.83629",
    "lng": "-8.58061"
  },
  {
    "country": "PT",
    "name": "Vale de Cambra",
    "lat": "40.8497",
    "lng": "-8.39389"
  },
  {
    "country": "PT",
    "name": "Valbom",
    "lat": "41.12921",
    "lng": "-8.56199"
  },
  {
    "country": "PT",
    "name": "Valadares",
    "lat": "41.14737",
    "lng": "-7.9812"
  },
  {
    "country": "PT",
    "name": "Vairão",
    "lat": "41.3329",
    "lng": "-8.66657"
  },
  {
    "country": "PT",
    "name": "Vagos",
    "lat": "40.556",
    "lng": "-8.68175"
  },
  {
    "country": "PT",
    "name": "Urgeses",
    "lat": "41.4272",
    "lng": "-8.29796"
  },
  {
    "country": "PT",
    "name": "Trofa",
    "lat": "41.33729",
    "lng": "-8.5596"
  },
  {
    "country": "PT",
    "name": "Treixedo",
    "lat": "40.43246",
    "lng": "-8.09428"
  },
  {
    "country": "PT",
    "name": "Travanca",
    "lat": "40.32357",
    "lng": "-8.18687"
  },
  {
    "country": "PT",
    "name": "Trancoso",
    "lat": "40.78329",
    "lng": "-7.35016"
  },
  {
    "country": "PT",
    "name": "Torre de Moncorvo",
    "lat": "41.17454",
    "lng": "-7.05364"
  },
  {
    "country": "PT",
    "name": "Tondela",
    "lat": "40.51682",
    "lng": "-8.08087"
  },
  {
    "country": "PT",
    "name": "Tocha",
    "lat": "40.31308",
    "lng": "-8.75339"
  },
  {
    "country": "PT",
    "name": "Terras de Bouro",
    "lat": "41.71769",
    "lng": "-8.30888"
  },
  {
    "country": "PT",
    "name": "Telões",
    "lat": "41.31054",
    "lng": "-8.11101"
  },
  {
    "country": "PT",
    "name": "Teixoso",
    "lat": "40.31448",
    "lng": "-7.45759"
  },
  {
    "country": "PT",
    "name": "Tebosa",
    "lat": "41.48253",
    "lng": "-8.48399"
  },
  {
    "country": "PT",
    "name": "Tavarede",
    "lat": "40.16692",
    "lng": "-8.84568"
  },
  {
    "country": "PT",
    "name": "Tarouca",
    "lat": "41.01763",
    "lng": "-7.77547"
  },
  {
    "country": "PT",
    "name": "Tabuaço",
    "lat": "41.11615",
    "lng": "-7.56793"
  },
  {
    "country": "PT",
    "name": "Tábua",
    "lat": "40.36207",
    "lng": "-8.02936"
  },
  {
    "country": "PT",
    "name": "Souto",
    "lat": "40.98496",
    "lng": "-8.62185"
  },
  {
    "country": "PT",
    "name": "Soure",
    "lat": "40.05989",
    "lng": "-8.62605"
  },
  {
    "country": "PT",
    "name": "Sobreira",
    "lat": "41.52371",
    "lng": "-7.80234"
  },
  {
    "country": "PT",
    "name": "Sobrado",
    "lat": "41.21041",
    "lng": "-8.45488"
  },
  {
    "country": "PT",
    "name": "Cinfães",
    "lat": "41.07197",
    "lng": "-8.08999"
  },
  {
    "country": "PT",
    "name": "Silvalde",
    "lat": "40.99205",
    "lng": "-8.62567"
  },
  {
    "country": "PT",
    "name": "Sever do Vouga",
    "lat": "40.73459",
    "lng": "-8.36722"
  },
  {
    "country": "PT",
    "name": "Serzedo",
    "lat": "41.40502",
    "lng": "-8.22926"
  },
  {
    "country": "PT",
    "name": "Serzedo",
    "lat": "41.05105",
    "lng": "-8.61605"
  },
  {
    "country": "PT",
    "name": "Serzedelo",
    "lat": "41.40128",
    "lng": "-8.36888"
  },
  {
    "country": "PT",
    "name": "Seroa",
    "lat": "41.26511",
    "lng": "-8.42892"
  },
  {
    "country": "PT",
    "name": "Sernancelhe",
    "lat": "40.89871",
    "lng": "-7.49342"
  },
  {
    "country": "PT",
    "name": "Sermonde",
    "lat": "41.04712",
    "lng": "-8.58449"
  },
  {
    "country": "PT",
    "name": "Sequeira",
    "lat": "40.55364",
    "lng": "-7.22594"
  },
  {
    "country": "PT",
    "name": "Senhora da Hora",
    "lat": "41.18641",
    "lng": "-8.65172"
  },
  {
    "country": "PT",
    "name": "Sendim",
    "lat": "41.38739",
    "lng": "-6.42625"
  },
  {
    "country": "PT",
    "name": "Semelhe",
    "lat": "41.55437",
    "lng": "-8.46281"
  },
  {
    "country": "PT",
    "name": "Selho",
    "lat": "41.41938",
    "lng": "-8.34599"
  },
  {
    "country": "PT",
    "name": "Seia",
    "lat": "40.4151",
    "lng": "-7.70859"
  },
  {
    "country": "PT",
    "name": "Sátão",
    "lat": "40.74177",
    "lng": "-7.73285"
  },
  {
    "country": "PT",
    "name": "São Roque",
    "lat": "40.87216",
    "lng": "-8.47149"
  },
  {
    "country": "PT",
    "name": "São Romão do Coronado",
    "lat": "41.28544",
    "lng": "-8.5632"
  },
  {
    "country": "PT",
    "name": "São Romão",
    "lat": "40.40118",
    "lng": "-7.71464"
  },
  {
    "country": "PT",
    "name": "São Pedro do Sul",
    "lat": "40.75537",
    "lng": "-8.07265"
  },
  {
    "country": "PT",
    "name": "São Pedro de Alva",
    "lat": "40.30044",
    "lng": "-8.16623"
  },
  {
    "country": "PT",
    "name": "São Pedro da Cova",
    "lat": "41.14331",
    "lng": "-8.50033"
  },
  {
    "country": "PT",
    "name": "São Miguel do Couto",
    "lat": "41.33167",
    "lng": "-8.46185"
  },
  {
    "country": "PT",
    "name": "São Mamede de Infesta",
    "lat": "41.19183",
    "lng": "-8.61105"
  },
  {
    "country": "PT",
    "name": "São João de Ver",
    "lat": "40.95527",
    "lng": "-8.55117"
  },
  {
    "country": "PT",
    "name": "São João de Areias",
    "lat": "40.38722",
    "lng": "-8.06783"
  },
  {
    "country": "PT",
    "name": "São João da Pesqueira",
    "lat": "41.14805",
    "lng": "-7.40489"
  },
  {
    "country": "PT",
    "name": "São João da Madeira",
    "lat": "40.9007",
    "lng": "-8.4902"
  },
  {
    "country": "PT",
    "name": "São João",
    "lat": "40.86802",
    "lng": "-8.60672"
  },
  {
    "country": "PT",
    "name": "São Félix da Marinha",
    "lat": "41.03555",
    "lng": "-8.62259"
  },
  {
    "country": "PT",
    "name": "Santo Tirso",
    "lat": "41.34257",
    "lng": "-8.47746"
  },
  {
    "country": "PT",
    "name": "Santo Izidoro",
    "lat": "41.21083",
    "lng": "-8.14224"
  },
  {
    "country": "PT",
    "name": "Santo António dos Olivais",
    "lat": "40.21805",
    "lng": "-8.40523"
  },
  {
    "country": "PT",
    "name": "Santa Marta de Penaguião",
    "lat": "41.20991",
    "lng": "-7.78386"
  },
  {
    "country": "PT",
    "name": "Santa Cruz do Bispo",
    "lat": "41.21462",
    "lng": "-8.67406"
  },
  {
    "country": "PT",
    "name": "Santa Cruz",
    "lat": "41.76007",
    "lng": "-7.46834"
  },
  {
    "country": "PT",
    "name": "Santa Comba Dão",
    "lat": "40.39856",
    "lng": "-8.1316"
  },
  {
    "country": "PT",
    "name": "Santa Clara",
    "lat": "40.19985",
    "lng": "-8.44018"
  },
  {
    "country": "PT",
    "name": "Sangalhos",
    "lat": "40.48678",
    "lng": "-8.46968"
  },
  {
    "country": "PT",
    "name": "Sanfins",
    "lat": "40.92979",
    "lng": "-8.52563"
  },
  {
    "country": "PT",
    "name": "Sandim",
    "lat": "41.03508",
    "lng": "-8.507"
  },
  {
    "country": "PT",
    "name": "Sande",
    "lat": "41.7019",
    "lng": "-8.39246"
  },
  {
    "country": "PT",
    "name": "Samil",
    "lat": "41.77632",
    "lng": "-6.75698"
  },
  {
    "country": "PT",
    "name": "Salreu",
    "lat": "40.73971",
    "lng": "-8.5572"
  },
  {
    "country": "PT",
    "name": "Sabugal",
    "lat": "40.35127",
    "lng": "-7.09104"
  },
  {
    "country": "PT",
    "name": "Sabrosa",
    "lat": "41.26702",
    "lng": "-7.57601"
  },
  {
    "country": "PT",
    "name": "Ronfe",
    "lat": "41.44146",
    "lng": "-8.38412"
  },
  {
    "country": "PT",
    "name": "Rio Tinto",
    "lat": "41.17872",
    "lng": "-8.55953"
  },
  {
    "country": "PT",
    "name": "Rio Meão",
    "lat": "40.95775",
    "lng": "-8.57818"
  },
  {
    "country": "PT",
    "name": "Rio Mau",
    "lat": "41.40422",
    "lng": "-8.67994"
  },
  {
    "country": "PT",
    "name": "Rio Mau",
    "lat": "41.05542",
    "lng": "-8.36891"
  },
  {
    "country": "PT",
    "name": "Rio de Loba",
    "lat": "40.66596",
    "lng": "-7.87781"
  },
  {
    "country": "PT",
    "name": "Ribeirão",
    "lat": "41.36081",
    "lng": "-8.56774"
  },
  {
    "country": "PT",
    "name": "Ribeira de Pena",
    "lat": "41.52147",
    "lng": "-7.80237"
  },
  {
    "country": "PT",
    "name": "Riba de Ave",
    "lat": "41.39648",
    "lng": "-8.38685"
  },
  {
    "country": "PT",
    "name": "Resende",
    "lat": "41.10582",
    "lng": "-7.9665"
  },
  {
    "country": "PT",
    "name": "Rendufe",
    "lat": "41.62898",
    "lng": "-8.40858"
  },
  {
    "country": "PT",
    "name": "Refojos de Basto",
    "lat": "41.51318",
    "lng": "-7.99517"
  },
  {
    "country": "PT",
    "name": "Recarei",
    "lat": "41.15356",
    "lng": "-8.41178"
  },
  {
    "country": "PT",
    "name": "Rebordosa",
    "lat": "41.22405",
    "lng": "-8.40669"
  },
  {
    "country": "PT",
    "name": "Rebordões",
    "lat": "41.35509",
    "lng": "-8.42355"
  },
  {
    "country": "PT",
    "name": "Real",
    "lat": "41.55841",
    "lng": "-8.4433"
  },
  {
    "country": "PT",
    "name": "Prado",
    "lat": "41.60246",
    "lng": "-8.46297"
  },
  {
    "country": "PT",
    "name": "Póvoa de Varzim",
    "lat": "41.38344",
    "lng": "-8.76364"
  },
  {
    "country": "PT",
    "name": "Póvoa de Lanhoso",
    "lat": "41.57873",
    "lng": "-8.28197"
  },
  {
    "country": "PT",
    "name": "Porto",
    "lat": "41.14961",
    "lng": "-8.61099"
  },
  {
    "country": "PT",
    "name": "Ponte de Lima",
    "lat": "41.76719",
    "lng": "-8.58393"
  },
  {
    "country": "PT",
    "name": "Ponte da Barca",
    "lat": "41.80451",
    "lng": "-8.41554"
  },
  {
    "country": "PT",
    "name": "Ponte",
    "lat": "41.47057",
    "lng": "-8.3299"
  },
  {
    "country": "PT",
    "name": "Poiares",
    "lat": "40.21026",
    "lng": "-8.25746"
  },
  {
    "country": "PT",
    "name": "Pinhel",
    "lat": "40.77403",
    "lng": "-7.06675"
  },
  {
    "country": "PT",
    "name": "Peso da Régua",
    "lat": "41.16491",
    "lng": "-7.78703"
  },
  {
    "country": "PT",
    "name": "Perozinho",
    "lat": "41.06513",
    "lng": "-8.58531"
  },
  {
    "country": "PT",
    "name": "Perelhal",
    "lat": "41.53075",
    "lng": "-8.68982"
  },
  {
    "country": "PT",
    "name": "Perafita",
    "lat": "41.18252",
    "lng": "-8.2545"
  },
  {
    "country": "PT",
    "name": "Penela",
    "lat": "40.03333",
    "lng": "-8.38333"
  },
  {
    "country": "PT",
    "name": "Penedono",
    "lat": "40.98875",
    "lng": "-7.39386"
  },
  {
    "country": "PT",
    "name": "Penamacor",
    "lat": "40.16895",
    "lng": "-7.16987"
  },
  {
    "country": "PT",
    "name": "Penafiel",
    "lat": "41.20835",
    "lng": "-8.28285"
  },
  {
    "country": "PT",
    "name": "Penacova",
    "lat": "40.26884",
    "lng": "-8.28237"
  },
  {
    "country": "PT",
    "name": "Pedrouços",
    "lat": "41.1888",
    "lng": "-8.58624"
  },
  {
    "country": "PT",
    "name": "Pedroso",
    "lat": "41.41103",
    "lng": "-8.74897"
  },
  {
    "country": "PT",
    "name": "Paredes de Coura",
    "lat": "41.91013",
    "lng": "-8.56094"
  },
  {
    "country": "PT",
    "name": "Paredes",
    "lat": "41.20485",
    "lng": "-8.33147"
  },
  {
    "country": "PT",
    "name": "Pardilhó",
    "lat": "40.79925",
    "lng": "-8.62598"
  },
  {
    "country": "PT",
    "name": "Pampilhosa do Botão",
    "lat": "40.3358",
    "lng": "-8.42738"
  },
  {
    "country": "PT",
    "name": "Pampilhosa da Serra",
    "lat": "40.0462",
    "lng": "-7.95182"
  },
  {
    "country": "PT",
    "name": "Paços de Ferreira",
    "lat": "41.27657",
    "lng": "-8.37617"
  },
  {
    "country": "PT",
    "name": "Paços de Brandão",
    "lat": "40.97541",
    "lng": "-8.5835"
  },
  {
    "country": "PT",
    "name": "Ovar",
    "lat": "40.85862",
    "lng": "-8.62513"
  },
  {
    "country": "PT",
    "name": "Oliveirinha",
    "lat": "40.60715",
    "lng": "-8.59198"
  },
  {
    "country": "PT",
    "name": "Oliveira do Mondego",
    "lat": "40.32305",
    "lng": "-8.22367"
  },
  {
    "country": "PT",
    "name": "Oliveira do Hospital",
    "lat": "40.3618",
    "lng": "-7.86014"
  },
  {
    "country": "PT",
    "name": "Oliveira do Douro",
    "lat": "41.12466",
    "lng": "-8.58463"
  },
  {
    "country": "PT",
    "name": "Oliveira do Bairro",
    "lat": "40.5146",
    "lng": "-8.49386"
  },
  {
    "country": "PT",
    "name": "Oliveira de Frades",
    "lat": "40.73357",
    "lng": "-8.17481"
  },
  {
    "country": "PT",
    "name": "Oliveira de Azemeis",
    "lat": "40.84101",
    "lng": "-8.47555"
  },
  {
    "country": "PT",
    "name": "Oliveira",
    "lat": "41.47819",
    "lng": "-8.46965"
  },
  {
    "country": "PT",
    "name": "Olival",
    "lat": "41.05024",
    "lng": "-8.54416"
  },
  {
    "country": "PT",
    "name": "Oiã",
    "lat": "40.54264",
    "lng": "-8.53856"
  },
  {
    "country": "PT",
    "name": "Nogueira da Regedoura",
    "lat": "41.0053",
    "lng": "-8.59195"
  },
  {
    "country": "PT",
    "name": "Nogueira",
    "lat": "41.24246",
    "lng": "-8.58685"
  },
  {
    "country": "PT",
    "name": "Nelas",
    "lat": "40.53216",
    "lng": "-7.85152"
  },
  {
    "country": "PT",
    "name": "Negrelos",
    "lat": "41.34946",
    "lng": "-8.40145"
  },
  {
    "country": "PT",
    "name": "Negreiros",
    "lat": "41.43552",
    "lng": "-8.61398"
  },
  {
    "country": "PT",
    "name": "Murtosa",
    "lat": "40.73695",
    "lng": "-8.6377"
  },
  {
    "country": "PT",
    "name": "Murça",
    "lat": "41.406",
    "lng": "-7.45485"
  },
  {
    "country": "PT",
    "name": "Mozelos",
    "lat": "41.86774",
    "lng": "-8.39776"
  },
  {
    "country": "PT",
    "name": "Mosteirô",
    "lat": "40.89843",
    "lng": "-8.53196"
  },
  {
    "country": "PT",
    "name": "Mortágua",
    "lat": "40.39675",
    "lng": "-8.23234"
  },
  {
    "country": "PT",
    "name": "Moreira de Conegos",
    "lat": "41.3868",
    "lng": "-8.3394"
  },
  {
    "country": "PT",
    "name": "Moreira",
    "lat": "41.24756",
    "lng": "-8.64788"
  },
  {
    "country": "PT",
    "name": "Moreira",
    "lat": "41.056",
    "lng": "-8.38939"
  },
  {
    "country": "PT",
    "name": "Montemor-o-Velho",
    "lat": "40.17287",
    "lng": "-8.68616"
  },
  {
    "country": "PT",
    "name": "Montalegre",
    "lat": "41.82357",
    "lng": "-7.78971"
  },
  {
    "country": "PT",
    "name": "Mondim de Basto",
    "lat": "41.41157",
    "lng": "-7.95441"
  },
  {
    "country": "PT",
    "name": "Monção",
    "lat": "42.07892",
    "lng": "-8.48076"
  },
  {
    "country": "PT",
    "name": "Moimenta da Beira",
    "lat": "40.98383",
    "lng": "-7.61765"
  },
  {
    "country": "PT",
    "name": "Mogadouro",
    "lat": "41.34034",
    "lng": "-6.71187"
  },
  {
    "country": "PT",
    "name": "Mirandela",
    "lat": "41.48739",
    "lng": "-7.18695"
  },
  {
    "country": "PT",
    "name": "Miranda do Douro",
    "lat": "41.49692",
    "lng": "-6.27308"
  },
  {
    "country": "PT",
    "name": "Miranda do Corvo",
    "lat": "40.09318",
    "lng": "-8.33261"
  },
  {
    "country": "PT",
    "name": "Mira",
    "lat": "40.42892",
    "lng": "-8.73746"
  },
  {
    "country": "PT",
    "name": "Mindelo",
    "lat": "41.31527",
    "lng": "-8.72124"
  },
  {
    "country": "PT",
    "name": "Milheirós de Poiares",
    "lat": "40.92163",
    "lng": "-8.46788"
  },
  {
    "country": "PT",
    "name": "Milheirós",
    "lat": "41.21478",
    "lng": "-8.58837"
  },
  {
    "country": "PT",
    "name": "Mesão Frio",
    "lat": "41.1598",
    "lng": "-7.88954"
  },
  {
    "country": "PT",
    "name": "Merelim",
    "lat": "41.58568",
    "lng": "-8.46555"
  },
  {
    "country": "PT",
    "name": "Melres",
    "lat": "41.06989",
    "lng": "-8.40091"
  },
  {
    "country": "PT",
    "name": "Melgaço",
    "lat": "42.11337",
    "lng": "-8.26016"
  },
  {
    "country": "PT",
    "name": "Meinedo",
    "lat": "41.24827",
    "lng": "-8.25807"
  },
  {
    "country": "PT",
    "name": "Mêda",
    "lat": "40.96635",
    "lng": "-7.26163"
  },
  {
    "country": "PT",
    "name": "Mealhada",
    "lat": "40.37806",
    "lng": "-8.44991"
  },
  {
    "country": "PT",
    "name": "Meadela",
    "lat": "41.70654",
    "lng": "-8.79628"
  },
  {
    "country": "PT",
    "name": "Matosinhos",
    "lat": "41.18207",
    "lng": "-8.68908"
  },
  {
    "country": "PT",
    "name": "Mariz",
    "lat": "41.52823",
    "lng": "-8.67081"
  },
  {
    "country": "PT",
    "name": "Marinhas",
    "lat": "41.55906",
    "lng": "-8.78297"
  },
  {
    "country": "PT",
    "name": "Margaride",
    "lat": "41.36478",
    "lng": "-8.19999"
  },
  {
    "country": "PT",
    "name": "Marco de Canavezes",
    "lat": "41.18389",
    "lng": "-8.14864"
  },
  {
    "country": "PT",
    "name": "Manteigas",
    "lat": "40.4028",
    "lng": "-7.53977"
  },
  {
    "country": "PT",
    "name": "Mangualde",
    "lat": "40.60425",
    "lng": "-7.76115"
  },
  {
    "country": "PT",
    "name": "Maia",
    "lat": "41.23574",
    "lng": "-8.6199"
  },
  {
    "country": "PT",
    "name": "Madalena",
    "lat": "41.21616",
    "lng": "-8.33451"
  },
  {
    "country": "PT",
    "name": "Macieira de Rates",
    "lat": "41.44092",
    "lng": "-8.63426"
  },
  {
    "country": "PT",
    "name": "Macieira de Cambra",
    "lat": "40.85939",
    "lng": "-8.37338"
  },
  {
    "country": "PT",
    "name": "Macedo de Cavaleiros",
    "lat": "41.53816",
    "lng": "-6.9611"
  },
  {
    "country": "PT",
    "name": "Lustosa",
    "lat": "41.34081",
    "lng": "-8.31715"
  },
  {
    "country": "PT",
    "name": "Luso",
    "lat": "40.38429",
    "lng": "-8.37845"
  },
  {
    "country": "PT",
    "name": "Lousada",
    "lat": "41.27822",
    "lng": "-8.27993"
  },
  {
    "country": "PT",
    "name": "Lousã",
    "lat": "40.11673",
    "lng": "-8.24921"
  },
  {
    "country": "PT",
    "name": "Lourosa",
    "lat": "40.9842",
    "lng": "-8.55142"
  },
  {
    "country": "PT",
    "name": "Lorvão",
    "lat": "40.25938",
    "lng": "-8.31683"
  },
  {
    "country": "PT",
    "name": "Loriga",
    "lat": "40.32513",
    "lng": "-7.68952"
  },
  {
    "country": "PT",
    "name": "Lordelo",
    "lat": "41.37411",
    "lng": "-8.38016"
  },
  {
    "country": "PT",
    "name": "Lordelo",
    "lat": "41.23451",
    "lng": "-8.40297"
  },
  {
    "country": "PT",
    "name": "Lobão",
    "lat": "40.98664",
    "lng": "-8.48566"
  },
  {
    "country": "PT",
    "name": "Leça do Bailio",
    "lat": "41.21201",
    "lng": "-8.63422"
  },
  {
    "country": "PT",
    "name": "Leça da Palmeira",
    "lat": "41.191",
    "lng": "-8.70027"
  },
  {
    "country": "PT",
    "name": "Lavra",
    "lat": "41.25935",
    "lng": "-8.71849"
  },
  {
    "country": "PT",
    "name": "Lavos",
    "lat": "40.09363",
    "lng": "-8.82826"
  },
  {
    "country": "PT",
    "name": "Lamego",
    "lat": "41.09741",
    "lng": "-7.80991"
  },
  {
    "country": "PT",
    "name": "Lamas",
    "lat": "40.98597",
    "lng": "-8.56923"
  },
  {
    "country": "PT",
    "name": "Lago",
    "lat": "41.62148",
    "lng": "-8.41258"
  },
  {
    "country": "PT",
    "name": "Jovim",
    "lat": "41.11102",
    "lng": "-8.51903"
  },
  {
    "country": "PT",
    "name": "Joane",
    "lat": "41.43906",
    "lng": "-8.40846"
  },
  {
    "country": "PT",
    "name": "Ílhavo",
    "lat": "40.60188",
    "lng": "-8.67021"
  },
  {
    "country": "PT",
    "name": "Gulpilhares",
    "lat": "41.08292",
    "lng": "-8.62679"
  },
  {
    "country": "PT",
    "name": "Guisande",
    "lat": "41.48264",
    "lng": "-8.44564"
  },
  {
    "country": "PT",
    "name": "Guimarães",
    "lat": "41.44443",
    "lng": "-8.29619"
  },
  {
    "country": "PT",
    "name": "Guifões",
    "lat": "41.19748",
    "lng": "-8.66899"
  },
  {
    "country": "PT",
    "name": "Gueral",
    "lat": "41.45859",
    "lng": "-8.62946"
  },
  {
    "country": "PT",
    "name": "Guarda",
    "lat": "40.53733",
    "lng": "-7.26575"
  },
  {
    "country": "PT",
    "name": "Grijó",
    "lat": "41.02836",
    "lng": "-8.58017"
  },
  {
    "country": "PT",
    "name": "Gondomar",
    "lat": "41.14454",
    "lng": "-8.53223"
  },
  {
    "country": "PT",
    "name": "Gondizalves",
    "lat": "41.54158",
    "lng": "-8.4557"
  },
  {
    "country": "PT",
    "name": "Góis",
    "lat": "40.15735",
    "lng": "-8.11007"
  },
  {
    "country": "PT",
    "name": "Godim",
    "lat": "41.17104",
    "lng": "-7.80303"
  },
  {
    "country": "PT",
    "name": "Gemunde",
    "lat": "41.26766",
    "lng": "-8.64515"
  },
  {
    "country": "PT",
    "name": "Gandra",
    "lat": "41.52185",
    "lng": "-8.76185"
  },
  {
    "country": "PT",
    "name": "Gandra",
    "lat": "41.20116",
    "lng": "-8.43376"
  },
  {
    "country": "PT",
    "name": "Galegos",
    "lat": "41.56268",
    "lng": "-8.57204"
  },
  {
    "country": "PT",
    "name": "Gafanha da Nazaré",
    "lat": "40.63621",
    "lng": "-8.71338"
  },
  {
    "country": "PT",
    "name": "Gafanha da Encarnação",
    "lat": "40.61806",
    "lng": "-8.73303"
  },
  {
    "country": "PT",
    "name": "Fundão",
    "lat": "40.14025",
    "lng": "-7.50135"
  },
  {
    "country": "PT",
    "name": "Frossos",
    "lat": "41.5659",
    "lng": "-8.45134"
  },
  {
    "country": "PT",
    "name": "Freixo de Espada à Cinta",
    "lat": "41.09033",
    "lng": "-6.80648"
  },
  {
    "country": "PT",
    "name": "Freamunde",
    "lat": "41.28835",
    "lng": "-8.33533"
  },
  {
    "country": "PT",
    "name": "Frazão",
    "lat": "41.25866",
    "lng": "-8.40014"
  },
  {
    "country": "PT",
    "name": "Fradelos",
    "lat": "41.36846",
    "lng": "-8.59887"
  },
  {
    "country": "PT",
    "name": "Foz do Sousa",
    "lat": "41.09668",
    "lng": "-8.50184"
  },
  {
    "country": "PT",
    "name": "Foz do Douro",
    "lat": "41.15119",
    "lng": "-8.67125"
  },
  {
    "country": "PT",
    "name": "Fornos de Algodres",
    "lat": "40.62807",
    "lng": "-7.54064"
  },
  {
    "country": "PT",
    "name": "Figueiró",
    "lat": "41.29922",
    "lng": "-8.16779"
  },
  {
    "country": "PT",
    "name": "Figueira de Castelo Rodrigo",
    "lat": "40.89262",
    "lng": "-6.9635"
  },
  {
    "country": "PT",
    "name": "Figueira da Foz",
    "lat": "40.15085",
    "lng": "-8.86179"
  },
  {
    "country": "PT",
    "name": "Fiães",
    "lat": "40.99446",
    "lng": "-8.52537"
  },
  {
    "country": "PT",
    "name": "Ferreiros",
    "lat": "41.631",
    "lng": "-8.36363"
  },
  {
    "country": "PT",
    "name": "Ferreiros",
    "lat": "41.35",
    "lng": "-8.55"
  },
  {
    "country": "PT",
    "name": "Ferreira",
    "lat": "41.26718",
    "lng": "-8.34434"
  },
  {
    "country": "PT",
    "name": "Felgueiras",
    "lat": "41.36806",
    "lng": "-8.19396"
  },
  {
    "country": "PT",
    "name": "Feira",
    "lat": "40.92535",
    "lng": "-8.54277"
  },
  {
    "country": "PT",
    "name": "Favaios",
    "lat": "41.26876",
    "lng": "-7.50465"
  },
  {
    "country": "PT",
    "name": "Faria",
    "lat": "41.48298",
    "lng": "-8.67152"
  },
  {
    "country": "PT",
    "name": "Apúlia e Fão",
    "lat": "41.51194",
    "lng": "-8.77288"
  },
  {
    "country": "PT",
    "name": "Fânzeres",
    "lat": "41.16754",
    "lng": "-8.52981"
  },
  {
    "country": "PT",
    "name": "Fafe",
    "lat": "41.45083",
    "lng": "-8.17258"
  },
  {
    "country": "PT",
    "name": "Estela",
    "lat": "41.44944",
    "lng": "-8.75166"
  },
  {
    "country": "PT",
    "name": "Estarreja",
    "lat": "40.75648",
    "lng": "-8.57207"
  },
  {
    "country": "PT",
    "name": "Esposende",
    "lat": "41.5361",
    "lng": "-8.78201"
  },
  {
    "country": "PT",
    "name": "Esporões",
    "lat": "41.51006",
    "lng": "-8.41729"
  },
  {
    "country": "PT",
    "name": "Espinho",
    "lat": "41.00763",
    "lng": "-8.64125"
  },
  {
    "country": "PT",
    "name": "Espargo",
    "lat": "40.92462",
    "lng": "-8.57495"
  },
  {
    "country": "PT",
    "name": "Esmoriz",
    "lat": "40.95773",
    "lng": "-8.62753"
  },
  {
    "country": "PT",
    "name": "Esgueira",
    "lat": "40.64899",
    "lng": "-8.62943"
  },
  {
    "country": "PT",
    "name": "Ervedosa do Douro",
    "lat": "41.16626",
    "lng": "-7.47305"
  },
  {
    "country": "PT",
    "name": "Ermesinde",
    "lat": "41.21653",
    "lng": "-8.55318"
  },
  {
    "country": "PT",
    "name": "Eixo",
    "lat": "40.62758",
    "lng": "-8.56922"
  },
  {
    "country": "PT",
    "name": "Darque",
    "lat": "41.68333",
    "lng": "-8.76667"
  },
  {
    "country": "PT",
    "name": "Custoias",
    "lat": "41.1053",
    "lng": "-7.32097"
  },
  {
    "country": "PT",
    "name": "Cucujães",
    "lat": "40.87413",
    "lng": "-8.50687"
  },
  {
    "country": "PT",
    "name": "Cristelo",
    "lat": "41.47964",
    "lng": "-8.69785"
  },
  {
    "country": "PT",
    "name": "Covilhã",
    "lat": "40.28106",
    "lng": "-7.50504"
  },
  {
    "country": "PT",
    "name": "Cortegaça",
    "lat": "40.94883",
    "lng": "-8.6213"
  },
  {
    "country": "PT",
    "name": "Condeixa-a-Nova",
    "lat": "40.11283",
    "lng": "-8.49804"
  },
  {
    "country": "PT",
    "name": "Coimbra",
    "lat": "40.20564",
    "lng": "-8.41955"
  },
  {
    "country": "PT",
    "name": "Chaves",
    "lat": "41.74019",
    "lng": "-7.46879"
  },
  {
    "country": "PT",
    "name": "Chavão",
    "lat": "41.45235",
    "lng": "-8.60194"
  },
  {
    "country": "PT",
    "name": "Celorico de Basto",
    "lat": "41.38714",
    "lng": "-8.00101"
  },
  {
    "country": "PT",
    "name": "Celorico da Beira",
    "lat": "40.63723",
    "lng": "-7.39037"
  },
  {
    "country": "PT",
    "name": "Castro Daire",
    "lat": "40.8984",
    "lng": "-7.93381"
  },
  {
    "country": "PT",
    "name": "Castelões de Cepeda",
    "lat": "41.20265",
    "lng": "-8.33516"
  },
  {
    "country": "PT",
    "name": "Castelo de Paiva",
    "lat": "41.06301",
    "lng": "-8.2647"
  },
  {
    "country": "PT",
    "name": "Carvalhosa",
    "lat": "41.30057",
    "lng": "-8.3608"
  },
  {
    "country": "PT",
    "name": "Carregal do Sal",
    "lat": "40.43333",
    "lng": "-8"
  },
  {
    "country": "PT",
    "name": "Carrazeda de Anciães",
    "lat": "41.24247",
    "lng": "-7.30721"
  },
  {
    "country": "PT",
    "name": "Carapinheira",
    "lat": "40.2062",
    "lng": "-8.6481"
  },
  {
    "country": "PT",
    "name": "Cantanhede",
    "lat": "40.34671",
    "lng": "-8.59419"
  },
  {
    "country": "PT",
    "name": "Canidelo",
    "lat": "41.12314",
    "lng": "-8.64654"
  },
  {
    "country": "PT",
    "name": "Canelas",
    "lat": "41.08333",
    "lng": "-8.6"
  },
  {
    "country": "PT",
    "name": "Candoso",
    "lat": "41.42768",
    "lng": "-8.32166"
  },
  {
    "country": "PT",
    "name": "Canas de Senhorim",
    "lat": "40.50012",
    "lng": "-7.89874"
  },
  {
    "country": "PT",
    "name": "Campo de Besteiros",
    "lat": "40.55655",
    "lng": "-8.13432"
  },
  {
    "country": "PT",
    "name": "Campo",
    "lat": "41.18516",
    "lng": "-8.46493"
  },
  {
    "country": "PT",
    "name": "Campo",
    "lat": "40.71086",
    "lng": "-7.91445"
  },
  {
    "country": "PT",
    "name": "Calendário",
    "lat": "41.40361",
    "lng": "-8.52967"
  },
  {
    "country": "PT",
    "name": "Caldelas",
    "lat": "41.67101",
    "lng": "-8.38148"
  },
  {
    "country": "PT",
    "name": "Caldas de Vizela",
    "lat": "41.38212",
    "lng": "-8.3089"
  },
  {
    "country": "PT",
    "name": "Caldas das Taipas",
    "lat": "41.48465",
    "lng": "-8.3485"
  },
  {
    "country": "PT",
    "name": "Cabeceiras de Basto",
    "lat": "41.51431",
    "lng": "-7.98942"
  },
  {
    "country": "PT",
    "name": "Cabanas de Viriato",
    "lat": "40.47662",
    "lng": "-7.97445"
  },
  {
    "country": "PT",
    "name": "Buarcos",
    "lat": "40.16604",
    "lng": "-8.8768"
  },
  {
    "country": "PT",
    "name": "Brito",
    "lat": "41.45821",
    "lng": "-8.36103"
  },
  {
    "country": "PT",
    "name": "Branca",
    "lat": "40.76653",
    "lng": "-8.48262"
  },
  {
    "country": "PT",
    "name": "Bragança",
    "lat": "41.80582",
    "lng": "-6.75719"
  },
  {
    "country": "PT",
    "name": "Braga",
    "lat": "41.55032",
    "lng": "-8.42005"
  },
  {
    "country": "PT",
    "name": "Bougado",
    "lat": "41.33979",
    "lng": "-8.5518"
  },
  {
    "country": "PT",
    "name": "Boticas",
    "lat": "41.68939",
    "lng": "-7.66914"
  },
  {
    "country": "PT",
    "name": "Belver",
    "lat": "41.24696",
    "lng": "-7.27594"
  },
  {
    "country": "PT",
    "name": "Belmonte",
    "lat": "40.3593",
    "lng": "-7.34869"
  },
  {
    "country": "PT",
    "name": "Beiriz de Baixo",
    "lat": "41.39727",
    "lng": "-8.72385"
  },
  {
    "country": "PT",
    "name": "Beduido",
    "lat": "40.76427",
    "lng": "-8.5611"
  },
  {
    "country": "PT",
    "name": "Barrosas",
    "lat": "41.35534",
    "lng": "-8.29943"
  },
  {
    "country": "PT",
    "name": "Barqueiros",
    "lat": "41.49111",
    "lng": "-8.73192"
  },
  {
    "country": "PT",
    "name": "Barcelos",
    "lat": "41.53174",
    "lng": "-8.61843"
  },
  {
    "country": "PT",
    "name": "Baltar",
    "lat": "41.19272",
    "lng": "-8.38768"
  },
  {
    "country": "PT",
    "name": "Balazar",
    "lat": "41.40435",
    "lng": "-8.62386"
  },
  {
    "country": "PT",
    "name": "Baião",
    "lat": "41.16273",
    "lng": "-8.0347"
  },
  {
    "country": "PT",
    "name": "Baguim do Monte",
    "lat": "41.19203",
    "lng": "-8.54118"
  },
  {
    "country": "PT",
    "name": "Azenha",
    "lat": "41.07651",
    "lng": "-8.62468"
  },
  {
    "country": "PT",
    "name": "Avintes",
    "lat": "41.10711",
    "lng": "-8.55131"
  },
  {
    "country": "PT",
    "name": "Aves",
    "lat": "41.37034",
    "lng": "-8.4101"
  },
  {
    "country": "PT",
    "name": "Aver-o-Mar",
    "lat": "41.40607",
    "lng": "-8.77958"
  },
  {
    "country": "PT",
    "name": "Aveleda",
    "lat": "41.52113",
    "lng": "-8.46682"
  },
  {
    "country": "PT",
    "name": "Aveiro",
    "lat": "40.64427",
    "lng": "-8.64554"
  },
  {
    "country": "PT",
    "name": "Avanca",
    "lat": "40.80771",
    "lng": "-8.5722"
  },
  {
    "country": "PT",
    "name": "Assafarge",
    "lat": "40.15895",
    "lng": "-8.43167"
  },
  {
    "country": "PT",
    "name": "Árvore",
    "lat": "41.33922",
    "lng": "-8.71806"
  },
  {
    "country": "PT",
    "name": "Arrifana",
    "lat": "40.91565",
    "lng": "-8.49657"
  },
  {
    "country": "PT",
    "name": "Arouca",
    "lat": "40.93057",
    "lng": "-8.24488"
  },
  {
    "country": "PT",
    "name": "Arões",
    "lat": "41.45553",
    "lng": "-8.21419"
  },
  {
    "country": "PT",
    "name": "Armamar",
    "lat": "41.10765",
    "lng": "-7.69139"
  },
  {
    "country": "PT",
    "name": "Argoncilhe",
    "lat": "41.02541",
    "lng": "-8.53885"
  },
  {
    "country": "PT",
    "name": "Argivai",
    "lat": "41.37744",
    "lng": "-8.72987"
  },
  {
    "country": "PT",
    "name": "Arganil",
    "lat": "40.21826",
    "lng": "-8.05403"
  },
  {
    "country": "PT",
    "name": "Areosa",
    "lat": "41.71779",
    "lng": "-8.85707"
  },
  {
    "country": "PT",
    "name": "Arcozelo",
    "lat": "41.06187",
    "lng": "-8.63192"
  },
  {
    "country": "PT",
    "name": "Arcos de Valdevez",
    "lat": "41.84668",
    "lng": "-8.41905"
  },
  {
    "country": "PT",
    "name": "Arcos",
    "lat": "41.52185",
    "lng": "-8.42151"
  },
  {
    "country": "PT",
    "name": "Arcos",
    "lat": "40.44779",
    "lng": "-8.44171"
  },
  {
    "country": "PT",
    "name": "Arazede",
    "lat": "40.28627",
    "lng": "-8.64999"
  },
  {
    "country": "PT",
    "name": "Aradas",
    "lat": "40.62084",
    "lng": "-8.64195"
  },
  {
    "country": "PT",
    "name": "Apúlia",
    "lat": "41.48512",
    "lng": "-8.76413"
  },
  {
    "country": "PT",
    "name": "Anta",
    "lat": "41.26634",
    "lng": "-8.62844"
  },
  {
    "country": "PT",
    "name": "Ançã",
    "lat": "40.27161",
    "lng": "-8.5209"
  },
  {
    "country": "PT",
    "name": "Anadia",
    "lat": "40.43841",
    "lng": "-8.43352"
  },
  {
    "country": "PT",
    "name": "Amorim",
    "lat": "41.40503",
    "lng": "-8.75046"
  },
  {
    "country": "PT",
    "name": "Amares",
    "lat": "41.63091",
    "lng": "-8.35117"
  },
  {
    "country": "PT",
    "name": "Amarante",
    "lat": "41.27271",
    "lng": "-8.08245"
  },
  {
    "country": "PT",
    "name": "Alpendurada",
    "lat": "41.08944",
    "lng": "-8.24643"
  },
  {
    "country": "PT",
    "name": "Alijó",
    "lat": "41.27536",
    "lng": "-7.47465"
  },
  {
    "country": "PT",
    "name": "Alhadas",
    "lat": "40.18607",
    "lng": "-8.79057"
  },
  {
    "country": "PT",
    "name": "Alfena",
    "lat": "41.23671",
    "lng": "-8.52454"
  },
  {
    "country": "PT",
    "name": "Alfarelos",
    "lat": "40.15057",
    "lng": "-8.65326"
  },
  {
    "country": "PT",
    "name": "Alfândega da Fé",
    "lat": "41.34315",
    "lng": "-6.96112"
  },
  {
    "country": "PT",
    "name": "Aldeia de Joanes",
    "lat": "40.13905",
    "lng": "-7.51694"
  },
  {
    "country": "PT",
    "name": "Albergaria-a-Velha",
    "lat": "40.69318",
    "lng": "-8.47994"
  },
  {
    "country": "PT",
    "name": "Aguiar da Beira",
    "lat": "40.81726",
    "lng": "-7.54431"
  },
  {
    "country": "PT",
    "name": "Águeda",
    "lat": "40.5772",
    "lng": "-8.44442"
  },
  {
    "country": "PT",
    "name": "Aguçadoura",
    "lat": "41.43116",
    "lng": "-8.77844"
  },
  {
    "country": "PT",
    "name": "Águas Santas",
    "lat": "41.21017",
    "lng": "-8.57599"
  },
  {
    "country": "PT",
    "name": "Aguada de Cima",
    "lat": "40.52291",
    "lng": "-8.427"
  },
  {
    "country": "PT",
    "name": "Adaúfe",
    "lat": "41.58732",
    "lng": "-8.39817"
  },
  {
    "country": "PT",
    "name": "Abraveses",
    "lat": "40.68137",
    "lng": "-7.92102"
  },
  {
    "country": "PT",
    "name": "Vila Franca do Campo",
    "lat": "37.71667",
    "lng": "-25.43333"
  },
  {
    "country": "PT",
    "name": "Velas",
    "lat": "38.68182",
    "lng": "-28.20909"
  },
  {
    "country": "PT",
    "name": "Senhora do Rosário",
    "lat": "37.83333",
    "lng": "-25.15"
  },
  {
    "country": "PT",
    "name": "São Vicente",
    "lat": "37.81829",
    "lng": "-25.66583"
  },
  {
    "country": "PT",
    "name": "São Sebastião",
    "lat": "38.66584",
    "lng": "-27.08976"
  },
  {
    "country": "PT",
    "name": "São Roque do Pico",
    "lat": "38.51631",
    "lng": "-28.30752"
  },
  {
    "country": "PT",
    "name": "São Roque",
    "lat": "37.75418",
    "lng": "-25.64127"
  },
  {
    "country": "PT",
    "name": "São Mateus",
    "lat": "38.6563",
    "lng": "-27.26935"
  },
  {
    "country": "PT",
    "name": "São Bartolomeu",
    "lat": "38.67491",
    "lng": "-27.29349"
  },
  {
    "country": "PT",
    "name": "Santa Cruz das Flores",
    "lat": "39.45782",
    "lng": "-31.12989"
  },
  {
    "country": "PT",
    "name": "Santa Cruz da Graciosa",
    "lat": "39.08577",
    "lng": "-28.0058"
  },
  {
    "country": "PT",
    "name": "Santa Bárbara",
    "lat": "38.69608",
    "lng": "-27.33907"
  },
  {
    "country": "PT",
    "name": "Rosto de Cão",
    "lat": "37.75",
    "lng": "-25.65"
  },
  {
    "country": "PT",
    "name": "Ribeirinha",
    "lat": "38.66203",
    "lng": "-27.18093"
  },
  {
    "country": "PT",
    "name": "Ribeira Seca",
    "lat": "38.6",
    "lng": "-27.98333"
  },
  {
    "country": "PT",
    "name": "Ribeira Seca",
    "lat": "37.81667",
    "lng": "-25.53333"
  },
  {
    "country": "PT",
    "name": "Ribeira Seca",
    "lat": "37.722",
    "lng": "-25.41791"
  },
  {
    "country": "PT",
    "name": "Ribeira Grande",
    "lat": "38.51667",
    "lng": "-28.7"
  },
  {
    "country": "PT",
    "name": "Ribeira Grande",
    "lat": "37.82175",
    "lng": "-25.52141"
  },
  {
    "country": "PT",
    "name": "Relva",
    "lat": "37.75271",
    "lng": "-25.71848"
  },
  {
    "country": "PT",
    "name": "Rabo de Peixe",
    "lat": "37.81022",
    "lng": "-25.58263"
  },
  {
    "country": "PT",
    "name": "Praia da Vitória",
    "lat": "38.73333",
    "lng": "-27.06667"
  },
  {
    "country": "PT",
    "name": "Povoação",
    "lat": "37.75",
    "lng": "-25.25"
  },
  {
    "country": "PT",
    "name": "Porto Martins",
    "lat": "38.68146",
    "lng": "-27.05835"
  },
  {
    "country": "PT",
    "name": "Porto Judeu",
    "lat": "38.64814",
    "lng": "-27.11944"
  },
  {
    "country": "PT",
    "name": "Ponta Garça",
    "lat": "37.71667",
    "lng": "-25.36667"
  },
  {
    "country": "PT",
    "name": "Mosteiros",
    "lat": "37.89017",
    "lng": "-25.81999"
  },
  {
    "country": "PT",
    "name": "Maia",
    "lat": "37.83247",
    "lng": "-25.38976"
  },
  {
    "country": "PT",
    "name": "Madalena",
    "lat": "38.53642",
    "lng": "-28.5266"
  },
  {
    "country": "PT",
    "name": "Lajes",
    "lat": "38.76352",
    "lng": "-27.10336"
  },
  {
    "country": "PT",
    "name": "Lajes",
    "lat": "38.39529",
    "lng": "-28.2522"
  },
  {
    "country": "PT",
    "name": "Lajes das Flores",
    "lat": "39.37744",
    "lng": "-31.17847"
  },
  {
    "country": "PT",
    "name": "Lagoa",
    "lat": "37.74486",
    "lng": "-25.57184"
  },
  {
    "country": "PT",
    "name": "Horta",
    "lat": "38.53737",
    "lng": "-28.62615"
  },
  {
    "country": "PT",
    "name": "Furnas",
    "lat": "37.77567",
    "lng": "-25.31035"
  },
  {
    "country": "PT",
    "name": "Fonte Bastardo",
    "lat": "38.69201",
    "lng": "-27.07942"
  },
  {
    "country": "PT",
    "name": "Feteira",
    "lat": "38.65429",
    "lng": "-27.14995"
  },
  {
    "country": "PT",
    "name": "Fenais da Luz",
    "lat": "37.8249",
    "lng": "-25.64229"
  },
  {
    "country": "PT",
    "name": "Fenais da Ajuda",
    "lat": "37.85128",
    "lng": "-25.32406"
  },
  {
    "country": "PT",
    "name": "Fajã de Baixo",
    "lat": "37.75",
    "lng": "-25.65"
  },
  {
    "country": "PT",
    "name": "Castelo Branco",
    "lat": "38.52198",
    "lng": "-28.71365"
  },
  {
    "country": "PT",
    "name": "Calheta",
    "lat": "38.60186",
    "lng": "-28.01792"
  },
  {
    "country": "PT",
    "name": "Cais do Pico",
    "lat": "38.52531",
    "lng": "-28.32074"
  },
  {
    "country": "PT",
    "name": "Cabouco",
    "lat": "37.76667",
    "lng": "-25.56667"
  },
  {
    "country": "PT",
    "name": "Biscoitos",
    "lat": "38.78333",
    "lng": "-27.25"
  },
  {
    "country": "PT",
    "name": "Arrifes",
    "lat": "37.76667",
    "lng": "-25.7"
  },
  {
    "country": "PT",
    "name": "Angústias",
    "lat": "38.52547",
    "lng": "-28.63132"
  },
  {
    "country": "PT",
    "name": "Angra do Heroísmo",
    "lat": "38.65483",
    "lng": "-27.21734"
  },
  {
    "country": "PT",
    "name": "Água de Pau",
    "lat": "37.72142",
    "lng": "-25.5117"
  },
  {
    "country": "PT",
    "name": "Vilamoura",
    "lat": "37.08728",
    "lng": "-8.11701"
  },
  {
    "country": "PT",
    "name": "Vila Nova De Cacela",
    "lat": "37.17447",
    "lng": "-7.53473"
  },
  {
    "country": "PT",
    "name": "Quinta Do Conde",
    "lat": "38.56528",
    "lng": "-9.04316"
  },
  {
    "country": "PT",
    "name": "Prior Velho",
    "lat": "38.79174",
    "lng": "-9.12119"
  },
  {
    "country": "PT",
    "name": "Valenza",
    "lat": "42.02418",
    "lng": "-8.63474"
  },
  {
    "country": "PT",
    "name": "Alfragide",
    "lat": "38.73203",
    "lng": "-9.2192"
  },
  {
    "country": "PT",
    "name": "Alvalade",
    "lat": "38.75328",
    "lng": "-9.14397"
  },
  {
    "country": "PT",
    "name": "Ponta Delgada",
    "lat": "37.74615",
    "lng": "-25.66689"
  },
  {
    "country": "PT",
    "name": "Santos-o-Velho",
    "lat": "38.7069",
    "lng": "-9.15611"
  },
  {
    "country": "PT",
    "name": "Vila",
    "lat": "42.0304",
    "lng": "-8.1588"
  },
  {
    "country": "PT",
    "name": "Cabanas de Tavira",
    "lat": "37.13521",
    "lng": "-7.60048"
  },
  {
    "country": "PT",
    "name": "Santo Isidoro",
    "lat": "38.99593",
    "lng": "-9.3994"
  },
  {
    "country": "PT",
    "name": "Azeitão",
    "lat": "38.51919",
    "lng": "-9.0139"
  },
  {
    "country": "PW",
    "name": "Koror",
    "lat": "7.33978",
    "lng": "134.47326"
  },
  {
    "country": "PW",
    "name": "Ulimang",
    "lat": "7.62416",
    "lng": "134.64208"
  },
  {
    "country": "PW",
    "name": "Melekeok Village",
    "lat": "7.49567",
    "lng": "134.63671"
  },
  {
    "country": "PW",
    "name": "Ngereklmadel",
    "lat": "7.48826",
    "lng": "134.48562"
  },
  {
    "country": "PW",
    "name": "Imeong Hamlet",
    "lat": "7.53134",
    "lng": "134.52713"
  },
  {
    "country": "PW",
    "name": "Ngchesar Hamlet",
    "lat": "7.46932",
    "lng": "134.60991"
  },
  {
    "country": "PW",
    "name": "Ngerkeai",
    "lat": "7.55456",
    "lng": "134.63612"
  },
  {
    "country": "PW",
    "name": "Mengellang",
    "lat": "7.6957",
    "lng": "134.63054"
  },
  {
    "country": "PW",
    "name": "Angaur State",
    "lat": "6.90601",
    "lng": "134.12997"
  },
  {
    "country": "PW",
    "name": "Tobi Village",
    "lat": "3.00488",
    "lng": "131.12168"
  },
  {
    "country": "PW",
    "name": "Sonsorol Village",
    "lat": "5.32608",
    "lng": "132.21943"
  },
  {
    "country": "PW",
    "name": "Kayangel",
    "lat": "8.08228",
    "lng": "134.71725"
  },
  {
    "country": "PW",
    "name": "Kloulklubed",
    "lat": "7.04192",
    "lng": "134.25561"
  },
  {
    "country": "PW",
    "name": "Ngetkib",
    "lat": "7.36451",
    "lng": "134.51484"
  },
  {
    "country": "PW",
    "name": "Ngchemiangel",
    "lat": "7.44613",
    "lng": "134.47678"
  },
  {
    "country": "PW",
    "name": "Ngardmau",
    "lat": "7.60986",
    "lng": "134.5744"
  },
  {
    "country": "PW",
    "name": "Koror Town",
    "lat": "7.34257",
    "lng": "134.47888"
  },
  {
    "country": "PW",
    "name": "Ngerulmud",
    "lat": "7.50077",
    "lng": "134.6238"
  },
  {
    "country": "PY",
    "name": "Yuty",
    "lat": "-26.61471",
    "lng": "-56.24607"
  },
  {
    "country": "PY",
    "name": "Ypacarai",
    "lat": "-25.40777",
    "lng": "-57.28889"
  },
  {
    "country": "PY",
    "name": "Yhú",
    "lat": "-25.05784",
    "lng": "-55.92267"
  },
  {
    "country": "PY",
    "name": "Ygatimi",
    "lat": "-24.12371",
    "lng": "-55.64418"
  },
  {
    "country": "PY",
    "name": "Yegros",
    "lat": "-26.45",
    "lng": "-56.4"
  },
  {
    "country": "PY",
    "name": "Ybycuí",
    "lat": "-26.01667",
    "lng": "-57.05"
  },
  {
    "country": "PY",
    "name": "Yataity del Norte",
    "lat": "-24.83333",
    "lng": "-56.35"
  },
  {
    "country": "PY",
    "name": "Yaguarón",
    "lat": "-25.56139",
    "lng": "-57.28343"
  },
  {
    "country": "PY",
    "name": "Villarrica",
    "lat": "-25.74946",
    "lng": "-56.43518"
  },
  {
    "country": "PY",
    "name": "Villa Hayes",
    "lat": "-25.09306",
    "lng": "-57.52361"
  },
  {
    "country": "PY",
    "name": "Villa Florida",
    "lat": "-26.38333",
    "lng": "-57.15"
  },
  {
    "country": "PY",
    "name": "Villa Elisa",
    "lat": "-25.3676",
    "lng": "-57.59274"
  },
  {
    "country": "PY",
    "name": "Unión",
    "lat": "-24.8079",
    "lng": "-56.52148"
  },
  {
    "country": "PY",
    "name": "Trinidad",
    "lat": "-27.11667",
    "lng": "-55.78333"
  },
  {
    "country": "PY",
    "name": "Tobatí",
    "lat": "-25.26111",
    "lng": "-57.08329"
  },
  {
    "country": "PY",
    "name": "Tacuatí",
    "lat": "-23.45",
    "lng": "-56.58333"
  },
  {
    "country": "PY",
    "name": "Sapucaí",
    "lat": "-25.66652",
    "lng": "-56.95215"
  },
  {
    "country": "PY",
    "name": "Santiago",
    "lat": "-27.1431",
    "lng": "-56.76803"
  },
  {
    "country": "PY",
    "name": "Santa Rosa Misiones",
    "lat": "-26.8873",
    "lng": "-56.84905"
  },
  {
    "country": "PY",
    "name": "Santa Rita",
    "lat": "-25.78333",
    "lng": "-55.06667"
  },
  {
    "country": "PY",
    "name": "Santa María",
    "lat": "-26.78333",
    "lng": "-56.93333"
  },
  {
    "country": "PY",
    "name": "Santa Elena",
    "lat": "-25.41327",
    "lng": "-56.79708"
  },
  {
    "country": "PY",
    "name": "San Pedro de Ycuamandiyú",
    "lat": "-24.08534",
    "lng": "-57.08745"
  },
  {
    "country": "PY",
    "name": "San Pedro del Paraná",
    "lat": "-26.83268",
    "lng": "-56.20575"
  },
  {
    "country": "PY",
    "name": "San Patricio",
    "lat": "-26.96667",
    "lng": "-56.81667"
  },
  {
    "country": "PY",
    "name": "San Miguel",
    "lat": "-26.5",
    "lng": "-57.05"
  },
  {
    "country": "PY",
    "name": "San Lorenzo",
    "lat": "-25.33968",
    "lng": "-57.50879"
  },
  {
    "country": "PY",
    "name": "San Juan Nepomuceno",
    "lat": "-26.11229",
    "lng": "-55.93861"
  },
  {
    "country": "PY",
    "name": "San Juan del Paraná",
    "lat": "-27.30168",
    "lng": "-55.96509"
  },
  {
    "country": "PY",
    "name": "San Juan Bautista",
    "lat": "-26.66944",
    "lng": "-57.14583"
  },
  {
    "country": "PY",
    "name": "San José",
    "lat": "-25.53333",
    "lng": "-56.73333"
  },
  {
    "country": "PY",
    "name": "San Joaquín",
    "lat": "-25.02853",
    "lng": "-56.0428"
  },
  {
    "country": "PY",
    "name": "San Isidro de Curuguaty",
    "lat": "-24.47184",
    "lng": "-55.69227"
  },
  {
    "country": "PY",
    "name": "San Cosme y Damián",
    "lat": "-27.31741",
    "lng": "-56.33087"
  },
  {
    "country": "PY",
    "name": "San Bernardino",
    "lat": "-25.31067",
    "lng": "-57.29628"
  },
  {
    "country": "PY",
    "name": "San Antonio",
    "lat": "-25.42126",
    "lng": "-57.54725"
  },
  {
    "country": "PY",
    "name": "San Alberto",
    "lat": "-24.96667",
    "lng": "-54.9"
  },
  {
    "country": "PY",
    "name": "Salto del Guairá",
    "lat": "-24.0625",
    "lng": "-54.30694"
  },
  {
    "country": "PY",
    "name": "Repatriación",
    "lat": "-25.53333",
    "lng": "-55.95"
  },
  {
    "country": "PY",
    "name": "Quiindy",
    "lat": "-25.97606",
    "lng": "-57.23353"
  },
  {
    "country": "PY",
    "name": "Puerto Rosario",
    "lat": "-24.44127",
    "lng": "-57.14272"
  },
  {
    "country": "PY",
    "name": "Puerto Mayor Otaño",
    "lat": "-26.4",
    "lng": "-54.7"
  },
  {
    "country": "PY",
    "name": "Presidente Franco",
    "lat": "-25.56384",
    "lng": "-54.61097"
  },
  {
    "country": "PY",
    "name": "Piribebuy",
    "lat": "-25.46498",
    "lng": "-57.04183"
  },
  {
    "country": "PY",
    "name": "Pirayú",
    "lat": "-25.48406",
    "lng": "-57.2349"
  },
  {
    "country": "PY",
    "name": "Pirapó",
    "lat": "-26.86012",
    "lng": "-55.54357"
  },
  {
    "country": "PY",
    "name": "Pilar",
    "lat": "-26.86879",
    "lng": "-58.29346"
  },
  {
    "country": "PY",
    "name": "Pedro Juan Caballero",
    "lat": "-22.54722",
    "lng": "-55.73333"
  },
  {
    "country": "PY",
    "name": "Paraguarí",
    "lat": "-25.62083",
    "lng": "-57.14722"
  },
  {
    "country": "PY",
    "name": "Obligado",
    "lat": "-27.03333",
    "lng": "-55.63333"
  },
  {
    "country": "PY",
    "name": "Nueva Italia",
    "lat": "-25.6108",
    "lng": "-57.46563"
  },
  {
    "country": "PY",
    "name": "Colonia Nueva Germania",
    "lat": "-23.91137",
    "lng": "-56.70091"
  },
  {
    "country": "PY",
    "name": "Nemby",
    "lat": "-25.3949",
    "lng": "-57.53574"
  },
  {
    "country": "PY",
    "name": "Natalio",
    "lat": "-26.75702",
    "lng": "-55.13777"
  },
  {
    "country": "PY",
    "name": "Natalicio Talavera",
    "lat": "-25.63333",
    "lng": "-56.3"
  },
  {
    "country": "PY",
    "name": "Naranjal",
    "lat": "-25.96667",
    "lng": "-55.18333"
  },
  {
    "country": "PY",
    "name": "Nanawua",
    "lat": "-25.2793",
    "lng": "-57.70307"
  },
  {
    "country": "PY",
    "name": "Mbuyapey",
    "lat": "-26.21921",
    "lng": "-56.75777"
  },
  {
    "country": "PY",
    "name": "Mbutuý",
    "lat": "-24.97518",
    "lng": "-56.30927"
  },
  {
    "country": "PY",
    "name": "Mbocayaty",
    "lat": "-25.71938",
    "lng": "-56.42179"
  },
  {
    "country": "PY",
    "name": "Cedrales",
    "lat": "-25.65668",
    "lng": "-54.72272"
  },
  {
    "country": "PY",
    "name": "Limpio",
    "lat": "-25.16611",
    "lng": "-57.48562"
  },
  {
    "country": "PY",
    "name": "Lima",
    "lat": "-23.88327",
    "lng": "-56.48217"
  },
  {
    "country": "PY",
    "name": "La Paloma",
    "lat": "-24.12957",
    "lng": "-54.61376"
  },
  {
    "country": "PY",
    "name": "Lambaré",
    "lat": "-25.34682",
    "lng": "-57.60647"
  },
  {
    "country": "PY",
    "name": "La Colmena",
    "lat": "-25.88627",
    "lng": "-56.84084"
  },
  {
    "country": "PY",
    "name": "Jesús",
    "lat": "-27.05598",
    "lng": "-55.7413"
  },
  {
    "country": "PY",
    "name": "Iturbe",
    "lat": "-26.05508",
    "lng": "-56.48463"
  },
  {
    "country": "PY",
    "name": "Itauguá",
    "lat": "-25.39258",
    "lng": "-57.35421"
  },
  {
    "country": "PY",
    "name": "Itakyry",
    "lat": "-24.98611",
    "lng": "-55.14963"
  },
  {
    "country": "PY",
    "name": "Itapé",
    "lat": "-25.85172",
    "lng": "-56.61385"
  },
  {
    "country": "PY",
    "name": "Itacurubí del Rosario",
    "lat": "-24.53541",
    "lng": "-56.82352"
  },
  {
    "country": "PY",
    "name": "Itacurubí de la Cordillera",
    "lat": "-25.46158",
    "lng": "-56.85333"
  },
  {
    "country": "PY",
    "name": "Itá",
    "lat": "-25.50054",
    "lng": "-57.36717"
  },
  {
    "country": "PY",
    "name": "Isla Pucú",
    "lat": "-25.30853",
    "lng": "-56.89986"
  },
  {
    "country": "PY",
    "name": "Independencia",
    "lat": "-25.691",
    "lng": "-56.26781"
  },
  {
    "country": "PY",
    "name": "Hohenau",
    "lat": "-27.07315",
    "lng": "-55.64247"
  },
  {
    "country": "PY",
    "name": "Guayaybi",
    "lat": "-24.53333",
    "lng": "-56.43333"
  },
  {
    "country": "PY",
    "name": "Guarambaré",
    "lat": "-25.49096",
    "lng": "-57.45567"
  },
  {
    "country": "PY",
    "name": "General José Eduvigis Díaz",
    "lat": "-27.20136",
    "lng": "-58.3674"
  },
  {
    "country": "PY",
    "name": "General Higinio Morínigo",
    "lat": "-25.95",
    "lng": "-55.91667"
  },
  {
    "country": "PY",
    "name": "General Elizardo Aquino",
    "lat": "-24.44417",
    "lng": "-56.90061"
  },
  {
    "country": "PY",
    "name": "General Delgado",
    "lat": "-27.09046",
    "lng": "-56.52474"
  },
  {
    "country": "PY",
    "name": "General Artigas",
    "lat": "-26.93522",
    "lng": "-56.22168"
  },
  {
    "country": "PY",
    "name": "Fuerte Olimpo",
    "lat": "-21.04153",
    "lng": "-57.87377"
  },
  {
    "country": "PY",
    "name": "Fram",
    "lat": "-26.98333",
    "lng": "-55.88333"
  },
  {
    "country": "PY",
    "name": "Fernando de la Mora",
    "lat": "-25.3386",
    "lng": "-57.52167"
  },
  {
    "country": "PY",
    "name": "Eusebio Ayala",
    "lat": "-25.38276",
    "lng": "-56.96088"
  },
  {
    "country": "PY",
    "name": "Encarnación",
    "lat": "-27.33056",
    "lng": "-55.86667"
  },
  {
    "country": "PY",
    "name": "Emboscada",
    "lat": "-25.15",
    "lng": "-57.35"
  },
  {
    "country": "PY",
    "name": "Edelira",
    "lat": "-26.76734",
    "lng": "-55.27872"
  },
  {
    "country": "PY",
    "name": "Doctor Juan Manuel Frutos",
    "lat": "-25.3838",
    "lng": "-55.83215"
  },
  {
    "country": "PY",
    "name": "Doctor Juan León Mallorquín",
    "lat": "-25.43053",
    "lng": "-55.25412"
  },
  {
    "country": "PY",
    "name": "Cecilio Baez",
    "lat": "-25.07158",
    "lng": "-56.24386"
  },
  {
    "country": "PY",
    "name": "Corpus Christi",
    "lat": "-24.0804",
    "lng": "-54.93933"
  },
  {
    "country": "PY",
    "name": "Coronel Oviedo",
    "lat": "-25.44444",
    "lng": "-56.44028"
  },
  {
    "country": "PY",
    "name": "Coronel Martínez",
    "lat": "-25.75862",
    "lng": "-56.61677"
  },
  {
    "country": "PY",
    "name": "Concepción",
    "lat": "-23.39985",
    "lng": "-57.43236"
  },
  {
    "country": "PY",
    "name": "Yguazú",
    "lat": "-25.46187",
    "lng": "-55.00007"
  },
  {
    "country": "PY",
    "name": "Colonia Minga Porá",
    "lat": "-24.86667",
    "lng": "-54.9"
  },
  {
    "country": "PY",
    "name": "Colonia Menno",
    "lat": "-22.36667",
    "lng": "-59.81667"
  },
  {
    "country": "PY",
    "name": "Colonia Mauricio José Troche",
    "lat": "-25.56667",
    "lng": "-56.28333"
  },
  {
    "country": "PY",
    "name": "Mariano Roque Alonso",
    "lat": "-25.20791",
    "lng": "-57.53202"
  },
  {
    "country": "PY",
    "name": "Colonia General Alfredo Stroessner",
    "lat": "-25.36395",
    "lng": "-55.7069"
  },
  {
    "country": "PY",
    "name": "Colonia Catuete",
    "lat": "-24.13333",
    "lng": "-54.61667"
  },
  {
    "country": "PY",
    "name": "Ciudad del Este",
    "lat": "-25.50972",
    "lng": "-54.61111"
  },
  {
    "country": "PY",
    "name": "Chore",
    "lat": "-24.18606",
    "lng": "-56.58251"
  },
  {
    "country": "PY",
    "name": "Cerrito",
    "lat": "-27.34215",
    "lng": "-57.64119"
  },
  {
    "country": "PY",
    "name": "Carmen del Paraná",
    "lat": "-27.22232",
    "lng": "-56.15243"
  },
  {
    "country": "PY",
    "name": "Colonia Carlos Antonio López",
    "lat": "-26.39853",
    "lng": "-54.7569"
  },
  {
    "country": "PY",
    "name": "Carayaó",
    "lat": "-25.1975",
    "lng": "-56.39878"
  },
  {
    "country": "PY",
    "name": "Carapeguá",
    "lat": "-25.8",
    "lng": "-57.23333"
  },
  {
    "country": "PY",
    "name": "Caraguatay",
    "lat": "-25.23844",
    "lng": "-56.82693"
  },
  {
    "country": "PY",
    "name": "Capitán Miranda",
    "lat": "-27.2",
    "lng": "-55.8"
  },
  {
    "country": "PY",
    "name": "Capitán Bado",
    "lat": "-23.26667",
    "lng": "-55.53333"
  },
  {
    "country": "PY",
    "name": "Capiíbary",
    "lat": "-24.8",
    "lng": "-56.03333"
  },
  {
    "country": "PY",
    "name": "Capiatá",
    "lat": "-25.3552",
    "lng": "-57.44545"
  },
  {
    "country": "PY",
    "name": "Caazapá",
    "lat": "-26.19583",
    "lng": "-56.36806"
  },
  {
    "country": "PY",
    "name": "Caapucú",
    "lat": "-26.23523",
    "lng": "-57.18212"
  },
  {
    "country": "PY",
    "name": "Caaguazú",
    "lat": "-25.47104",
    "lng": "-56.01603"
  },
  {
    "country": "PY",
    "name": "Caacupé",
    "lat": "-25.38575",
    "lng": "-57.14217"
  },
  {
    "country": "PY",
    "name": "Buena Vista",
    "lat": "-26.18387",
    "lng": "-56.08171"
  },
  {
    "country": "PY",
    "name": "Benjamín Aceval",
    "lat": "-24.96667",
    "lng": "-57.56667"
  },
  {
    "country": "PY",
    "name": "Bella Vista",
    "lat": "-27.05",
    "lng": "-55.55"
  },
  {
    "country": "PY",
    "name": "Bella Vista",
    "lat": "-22.13333",
    "lng": "-56.51667"
  },
  {
    "country": "PY",
    "name": "Belén",
    "lat": "-23.46611",
    "lng": "-57.26194"
  },
  {
    "country": "PY",
    "name": "Juan de Ayolas",
    "lat": "-27.38662",
    "lng": "-56.84724"
  },
  {
    "country": "PY",
    "name": "Atyrá",
    "lat": "-25.27876",
    "lng": "-57.17192"
  },
  {
    "country": "PY",
    "name": "Asunción",
    "lat": "-25.30066",
    "lng": "-57.63591"
  },
  {
    "country": "PY",
    "name": "Arroyos y Esteros",
    "lat": "-25.05478",
    "lng": "-57.09873"
  },
  {
    "country": "PY",
    "name": "Arquitecto Tomás Romero Pereira",
    "lat": "-26.48333",
    "lng": "-55.25"
  },
  {
    "country": "PY",
    "name": "Areguá",
    "lat": "-25.3125",
    "lng": "-57.38472"
  },
  {
    "country": "PY",
    "name": "Antequera",
    "lat": "-24.08526",
    "lng": "-57.20221"
  },
  {
    "country": "PY",
    "name": "Altos",
    "lat": "-25.26263",
    "lng": "-57.25443"
  },
  {
    "country": "PY",
    "name": "Acahay",
    "lat": "-25.91667",
    "lng": "-57.15"
  },
  {
    "country": "PY",
    "name": "Abaí",
    "lat": "-26.03333",
    "lng": "-55.93333"
  },
  {
    "country": "PY",
    "name": "Horqueta",
    "lat": "-23.34278",
    "lng": "-57.05972"
  },
  {
    "country": "PY",
    "name": "Filadelfia",
    "lat": "-22.33936",
    "lng": "-60.03157"
  },
  {
    "country": "PY",
    "name": "Colonia Neuland",
    "lat": "-22.66667",
    "lng": "-60.11667"
  },
  {
    "country": "PY",
    "name": "Capitán Pablo Lagerenza",
    "lat": "-19.91667",
    "lng": "-60.78333"
  },
  {
    "country": "PY",
    "name": "Nueva Esperanza",
    "lat": "-24.5076",
    "lng": "-54.8551"
  },
  {
    "country": "PY",
    "name": "Colonia San Lorenzo",
    "lat": "-26.49324",
    "lng": "-54.79989"
  },
  {
    "country": "QA",
    "name": "Umm Şalāl Muḩammad",
    "lat": "25.41524",
    "lng": "51.40647"
  },
  {
    "country": "QA",
    "name": "Umm Şalāl ‘Alī",
    "lat": "25.46972",
    "lng": "51.3975"
  },
  {
    "country": "QA",
    "name": "Musay‘īd",
    "lat": "24.99226",
    "lng": "51.55067"
  },
  {
    "country": "QA",
    "name": "Umm Bāb",
    "lat": "25.21417",
    "lng": "50.80722"
  },
  {
    "country": "QA",
    "name": "Madīnat ash Shamāl",
    "lat": "26.12933",
    "lng": "51.2009"
  },
  {
    "country": "QA",
    "name": "Dukhān",
    "lat": "25.42485",
    "lng": "50.78227"
  },
  {
    "country": "QA",
    "name": "Az̧ Z̧a‘āyin",
    "lat": "25.57744",
    "lng": "51.48306"
  },
  {
    "country": "QA",
    "name": "Ash Shīḩānīyah",
    "lat": "25.37088",
    "lng": "51.22264"
  },
  {
    "country": "QA",
    "name": "Ar Ruways",
    "lat": "26.13978",
    "lng": "51.21493"
  },
  {
    "country": "QA",
    "name": "Ar Rayyān",
    "lat": "25.29194",
    "lng": "51.42444"
  },
  {
    "country": "QA",
    "name": "Al Wukayr",
    "lat": "25.15107",
    "lng": "51.53718"
  },
  {
    "country": "QA",
    "name": "Al Wakrah",
    "lat": "25.17151",
    "lng": "51.60337"
  },
  {
    "country": "QA",
    "name": "Al Khawr",
    "lat": "25.68389",
    "lng": "51.50583"
  },
  {
    "country": "QA",
    "name": "Al Jumaylīyah",
    "lat": "25.61068",
    "lng": "51.09108"
  },
  {
    "country": "QA",
    "name": "Al Ghuwayrīyah",
    "lat": "25.82882",
    "lng": "51.24567"
  },
  {
    "country": "QA",
    "name": "Doha",
    "lat": "25.28545",
    "lng": "51.53096"
  },
  {
    "country": "QA",
    "name": "Fuwayriţ",
    "lat": "26.02565",
    "lng": "51.36971"
  },
  {
    "country": "RE",
    "name": "Les Trois-Bassins",
    "lat": "-21.1",
    "lng": "55.3"
  },
  {
    "country": "RE",
    "name": "Salazie",
    "lat": "-21.0271",
    "lng": "55.5395"
  },
  {
    "country": "RE",
    "name": "Saint-Pierre",
    "lat": "-21.3393",
    "lng": "55.47811"
  },
  {
    "country": "RE",
    "name": "Saint-Philippe",
    "lat": "-21.36086",
    "lng": "55.7679"
  },
  {
    "country": "RE",
    "name": "Saint-Paul",
    "lat": "-21.00961",
    "lng": "55.27134"
  },
  {
    "country": "RE",
    "name": "Saint-Louis",
    "lat": "-21.28585",
    "lng": "55.41124"
  },
  {
    "country": "RE",
    "name": "Saint-Leu",
    "lat": "-21.17059",
    "lng": "55.28824"
  },
  {
    "country": "RE",
    "name": "Saint-Joseph",
    "lat": "-21.3777",
    "lng": "55.61691"
  },
  {
    "country": "RE",
    "name": "Sainte-Suzanne",
    "lat": "-20.90616",
    "lng": "55.60788"
  },
  {
    "country": "RE",
    "name": "Sainte-Rose",
    "lat": "-21.12858",
    "lng": "55.79616"
  },
  {
    "country": "RE",
    "name": "Sainte-Marie",
    "lat": "-20.89686",
    "lng": "55.55056"
  },
  {
    "country": "RE",
    "name": "Saint-Denis",
    "lat": "-20.88231",
    "lng": "55.4504"
  },
  {
    "country": "RE",
    "name": "Saint-Benoît",
    "lat": "-21.03795",
    "lng": "55.71546"
  },
  {
    "country": "RE",
    "name": "Saint-André",
    "lat": "-20.96333",
    "lng": "55.65031"
  },
  {
    "country": "RE",
    "name": "Petite-Île",
    "lat": "-21.35327",
    "lng": "55.56427"
  },
  {
    "country": "RE",
    "name": "Le Tampon",
    "lat": "-21.2766",
    "lng": "55.51766"
  },
  {
    "country": "RE",
    "name": "Les Avirons",
    "lat": "-21.24063",
    "lng": "55.33685"
  },
  {
    "country": "RE",
    "name": "Le Port",
    "lat": "-20.93752",
    "lng": "55.29415"
  },
  {
    "country": "RE",
    "name": "La Possession",
    "lat": "-20.92909",
    "lng": "55.3348"
  },
  {
    "country": "RE",
    "name": "Entre-Deux",
    "lat": "-21.23333",
    "lng": "55.46667"
  },
  {
    "country": "RE",
    "name": "Cilaos",
    "lat": "-21.13641",
    "lng": "55.47187"
  },
  {
    "country": "RE",
    "name": "Bras-Panon",
    "lat": "-20.99667",
    "lng": "55.67823"
  },
  {
    "country": "RE",
    "name": "Piton Saint-Leu",
    "lat": "-21.21962",
    "lng": "55.31513"
  },
  {
    "country": "RO",
    "name": "Ghioca",
    "lat": "44.31667",
    "lng": "24.73333"
  },
  {
    "country": "RO",
    "name": "Zvoriştea",
    "lat": "47.83333",
    "lng": "26.28333"
  },
  {
    "country": "RO",
    "name": "Zorlenţu Mare",
    "lat": "45.45056",
    "lng": "21.95611"
  },
  {
    "country": "RO",
    "name": "Zorleni",
    "lat": "46.26667",
    "lng": "27.71667"
  },
  {
    "country": "RO",
    "name": "Zorile",
    "lat": "44.37864",
    "lng": "25.80678"
  },
  {
    "country": "RO",
    "name": "Zorești",
    "lat": "45.18177",
    "lng": "26.70291"
  },
  {
    "country": "RO",
    "name": "Zmeu",
    "lat": "47.19161",
    "lng": "27.17917"
  },
  {
    "country": "RO",
    "name": "Zlătunoaia",
    "lat": "47.65026",
    "lng": "27.00743"
  },
  {
    "country": "RO",
    "name": "Zlatna",
    "lat": "46.10633",
    "lng": "23.23162"
  },
  {
    "country": "RO",
    "name": "Zlătărei",
    "lat": "44.63057",
    "lng": "24.25788"
  },
  {
    "country": "RO",
    "name": "Zizin",
    "lat": "45.63697",
    "lng": "25.77898"
  },
  {
    "country": "RO",
    "name": "Zimnicele",
    "lat": "43.66126",
    "lng": "25.41291"
  },
  {
    "country": "RO",
    "name": "Zimnicea",
    "lat": "43.66667",
    "lng": "25.36667"
  },
  {
    "country": "RO",
    "name": "Zâmbreasca",
    "lat": "44.31667",
    "lng": "24.98333"
  },
  {
    "country": "RO",
    "name": "Zimbor",
    "lat": "47",
    "lng": "23.26667"
  },
  {
    "country": "RO",
    "name": "Zimandu Nou",
    "lat": "46.28333",
    "lng": "21.4"
  },
  {
    "country": "RO",
    "name": "Zidurile",
    "lat": "44.58176",
    "lng": "25.55458"
  },
  {
    "country": "RO",
    "name": "Ziduri",
    "lat": "45.3",
    "lng": "27.08333"
  },
  {
    "country": "RO",
    "name": "Zetea",
    "lat": "46.38333",
    "lng": "25.36667"
  },
  {
    "country": "RO",
    "name": "Zerind",
    "lat": "46.61667",
    "lng": "21.51667"
  },
  {
    "country": "RO",
    "name": "Zencani",
    "lat": "46.927",
    "lng": "25.33411"
  },
  {
    "country": "RO",
    "name": "Zemeş",
    "lat": "46.58333",
    "lng": "26.41667"
  },
  {
    "country": "RO",
    "name": "Zebil",
    "lat": "44.946",
    "lng": "28.76873"
  },
  {
    "country": "RO",
    "name": "Zdrapți",
    "lat": "46.15612",
    "lng": "22.86954"
  },
  {
    "country": "RO",
    "name": "Zăvoiu",
    "lat": "44.66038",
    "lng": "25.4035"
  },
  {
    "country": "RO",
    "name": "Zăvoi",
    "lat": "45.51667",
    "lng": "22.41667"
  },
  {
    "country": "RO",
    "name": "Zăvoaia",
    "lat": "44.95",
    "lng": "27.48333"
  },
  {
    "country": "RO",
    "name": "Zăval",
    "lat": "43.84717",
    "lng": "23.84208"
  },
  {
    "country": "RO",
    "name": "Zau de Câmpie",
    "lat": "46.61382",
    "lng": "24.1308"
  },
  {
    "country": "RO",
    "name": "Zăuan",
    "lat": "47.22495",
    "lng": "22.66328"
  },
  {
    "country": "RO",
    "name": "Zătreni",
    "lat": "44.76667",
    "lng": "23.85"
  },
  {
    "country": "RO",
    "name": "Zărneștii de Slănic",
    "lat": "45.27708",
    "lng": "26.75549"
  },
  {
    "country": "RO",
    "name": "Zărnești",
    "lat": "45.56093",
    "lng": "25.31787"
  },
  {
    "country": "RO",
    "name": "Zărneşti",
    "lat": "45.3",
    "lng": "26.86667"
  },
  {
    "country": "RO",
    "name": "Zărand",
    "lat": "46.4",
    "lng": "21.65"
  },
  {
    "country": "RO",
    "name": "Zăpodeni",
    "lat": "46.75",
    "lng": "27.65"
  },
  {
    "country": "RO",
    "name": "Zănoaga",
    "lat": "44.15511",
    "lng": "24.09832"
  },
  {
    "country": "RO",
    "name": "Zăneşti",
    "lat": "46.81667",
    "lng": "26.55"
  },
  {
    "country": "RO",
    "name": "Zamostea",
    "lat": "47.86667",
    "lng": "26.2"
  },
  {
    "country": "RO",
    "name": "Zam",
    "lat": "46",
    "lng": "22.45"
  },
  {
    "country": "RO",
    "name": "Zalha",
    "lat": "47.18333",
    "lng": "23.53333"
  },
  {
    "country": "RO",
    "name": "Zalău",
    "lat": "47.2",
    "lng": "23.05"
  },
  {
    "country": "RO",
    "name": "Zagra",
    "lat": "47.33333",
    "lng": "24.28333"
  },
  {
    "country": "RO",
    "name": "Zagon",
    "lat": "45.76667",
    "lng": "26.11667"
  },
  {
    "country": "RO",
    "name": "Zagavia",
    "lat": "47.41911",
    "lng": "26.8979"
  },
  {
    "country": "RO",
    "name": "Zagăr",
    "lat": "46.35",
    "lng": "24.61667"
  },
  {
    "country": "RO",
    "name": "Zădăreni",
    "lat": "46.13274",
    "lng": "21.21821"
  },
  {
    "country": "RO",
    "name": "Zăbrani",
    "lat": "46.06667",
    "lng": "21.55"
  },
  {
    "country": "RO",
    "name": "Zăbala",
    "lat": "45.9",
    "lng": "26.18333"
  },
  {
    "country": "RO",
    "name": "Vutcani",
    "lat": "46.46667",
    "lng": "27.96667"
  },
  {
    "country": "RO",
    "name": "Vurpăr",
    "lat": "46",
    "lng": "23.46667"
  },
  {
    "country": "RO",
    "name": "Vurpăr",
    "lat": "45.9",
    "lng": "24.35"
  },
  {
    "country": "RO",
    "name": "Vulturu",
    "lat": "45.61667",
    "lng": "27.41667"
  },
  {
    "country": "RO",
    "name": "Vulturu",
    "lat": "44.65",
    "lng": "28.26667"
  },
  {
    "country": "RO",
    "name": "Vultureşti",
    "lat": "47.51667",
    "lng": "26.45"
  },
  {
    "country": "RO",
    "name": "Vultureşti",
    "lat": "46.81667",
    "lng": "27.53333"
  },
  {
    "country": "RO",
    "name": "Vulturești",
    "lat": "45.06618",
    "lng": "25.08347"
  },
  {
    "country": "RO",
    "name": "Vultureşti",
    "lat": "44.73333",
    "lng": "24.31667"
  },
  {
    "country": "RO",
    "name": "Vultureni",
    "lat": "46.96667",
    "lng": "23.56667"
  },
  {
    "country": "RO",
    "name": "Vultureni",
    "lat": "46.36667",
    "lng": "27.28333"
  },
  {
    "country": "RO",
    "name": "Vulpeni",
    "lat": "44.46667",
    "lng": "23.91667"
  },
  {
    "country": "RO",
    "name": "Vulcăneasa",
    "lat": "45.77388",
    "lng": "26.90981"
  },
  {
    "country": "RO",
    "name": "Vulcana-Pandele",
    "lat": "45.01558",
    "lng": "25.39319"
  },
  {
    "country": "RO",
    "name": "Vulcana de Sus",
    "lat": "45.10125",
    "lng": "25.35826"
  },
  {
    "country": "RO",
    "name": "Vulcana Băi",
    "lat": "45.07982",
    "lng": "25.38219"
  },
  {
    "country": "RO",
    "name": "Vulcan",
    "lat": "45.63333",
    "lng": "25.41667"
  },
  {
    "country": "RO",
    "name": "Vulcan",
    "lat": "45.38333",
    "lng": "23.26667"
  },
  {
    "country": "RO",
    "name": "Vrâncioaia",
    "lat": "45.85",
    "lng": "26.73333"
  },
  {
    "country": "RO",
    "name": "Vrata",
    "lat": "44.19197",
    "lng": "22.84928"
  },
  {
    "country": "RO",
    "name": "Vrănești",
    "lat": "44.84595",
    "lng": "25.00716"
  },
  {
    "country": "RO",
    "name": "Voșlăbeni",
    "lat": "46.65",
    "lng": "25.63333"
  },
  {
    "country": "RO",
    "name": "Vorţa",
    "lat": "46.01667",
    "lng": "22.68333"
  },
  {
    "country": "RO",
    "name": "Vorona Teodoru",
    "lat": "47.55",
    "lng": "26.6"
  },
  {
    "country": "RO",
    "name": "Vorona",
    "lat": "47.57714",
    "lng": "26.63078"
  },
  {
    "country": "RO",
    "name": "Vorniceni",
    "lat": "47.98333",
    "lng": "26.66667"
  },
  {
    "country": "RO",
    "name": "Voluntari",
    "lat": "44.49002",
    "lng": "26.17338"
  },
  {
    "country": "RO",
    "name": "Volovăţ",
    "lat": "47.81667",
    "lng": "25.9"
  },
  {
    "country": "RO",
    "name": "Voloiac",
    "lat": "44.61667",
    "lng": "23.1"
  },
  {
    "country": "RO",
    "name": "Voivozi",
    "lat": "47.21562",
    "lng": "22.39024"
  },
  {
    "country": "RO",
    "name": "Voivodeni",
    "lat": "46.7",
    "lng": "24.63333"
  },
  {
    "country": "RO",
    "name": "Voievodeasa",
    "lat": "47.79953",
    "lng": "25.74939"
  },
  {
    "country": "RO",
    "name": "Voitinel",
    "lat": "47.88366",
    "lng": "25.75735"
  },
  {
    "country": "RO",
    "name": "Voiteștii din Vale",
    "lat": "45.08746",
    "lng": "23.42145"
  },
  {
    "country": "RO",
    "name": "Voiteg",
    "lat": "45.46889",
    "lng": "21.23917"
  },
  {
    "country": "RO",
    "name": "Voineşti",
    "lat": "47.06667",
    "lng": "27.41667"
  },
  {
    "country": "RO",
    "name": "Voineşti",
    "lat": "46.56667",
    "lng": "27.41667"
  },
  {
    "country": "RO",
    "name": "Voinești",
    "lat": "45.30007",
    "lng": "25.07225"
  },
  {
    "country": "RO",
    "name": "Voineşti",
    "lat": "45.06667",
    "lng": "25.25"
  },
  {
    "country": "RO",
    "name": "Voineasa",
    "lat": "45.41667",
    "lng": "23.95"
  },
  {
    "country": "RO",
    "name": "Voineasa",
    "lat": "44.28333",
    "lng": "24.13333"
  },
  {
    "country": "RO",
    "name": "Voila",
    "lat": "45.81839",
    "lng": "24.84215"
  },
  {
    "country": "RO",
    "name": "Voetin",
    "lat": "45.4437",
    "lng": "27.14587"
  },
  {
    "country": "RO",
    "name": "Voiceşti",
    "lat": "44.6",
    "lng": "24.28333"
  },
  {
    "country": "RO",
    "name": "Vlăsineşti",
    "lat": "47.93333",
    "lng": "26.88333"
  },
  {
    "country": "RO",
    "name": "Vlăsceni",
    "lat": "44.58522",
    "lng": "25.59931"
  },
  {
    "country": "RO",
    "name": "Vlașca",
    "lat": "44.39664",
    "lng": "27.84865"
  },
  {
    "country": "RO",
    "name": "Vlăhiţa",
    "lat": "46.35",
    "lng": "25.51667"
  },
  {
    "country": "RO",
    "name": "Vlăduleni",
    "lat": "44.88857",
    "lng": "23.23727"
  },
  {
    "country": "RO",
    "name": "Vlad Ţepeş",
    "lat": "44.35",
    "lng": "27.08333"
  },
  {
    "country": "RO",
    "name": "Vlad Țepeș",
    "lat": "44.13282",
    "lng": "26.13355"
  },
  {
    "country": "RO",
    "name": "Vladimirescu",
    "lat": "46.16628",
    "lng": "21.40102"
  },
  {
    "country": "RO",
    "name": "Vlădila",
    "lat": "44",
    "lng": "24.4"
  },
  {
    "country": "RO",
    "name": "Vlădești",
    "lat": "45.15",
    "lng": "24.91667"
  },
  {
    "country": "RO",
    "name": "Vlădeşti",
    "lat": "45.85",
    "lng": "28.08333"
  },
  {
    "country": "RO",
    "name": "Vlădeşti",
    "lat": "45.11667",
    "lng": "24.3"
  },
  {
    "country": "RO",
    "name": "Vlădeni-Deal",
    "lat": "47.5225",
    "lng": "26.87295"
  },
  {
    "country": "RO",
    "name": "Vlădeni",
    "lat": "47.71667",
    "lng": "26.51667"
  },
  {
    "country": "RO",
    "name": "Vlădeni",
    "lat": "47.41667",
    "lng": "27.33333"
  },
  {
    "country": "RO",
    "name": "Vlădeni",
    "lat": "44.8755",
    "lng": "25.77318"
  },
  {
    "country": "RO",
    "name": "Vlădeni",
    "lat": "44.61667",
    "lng": "27.88333"
  },
  {
    "country": "RO",
    "name": "Vlădaia",
    "lat": "44.35",
    "lng": "23.03333"
  },
  {
    "country": "RO",
    "name": "Vizurești",
    "lat": "44.6404",
    "lng": "25.8074"
  },
  {
    "country": "RO",
    "name": "Viziru",
    "lat": "45.01667",
    "lng": "27.7"
  },
  {
    "country": "RO",
    "name": "Vizantea-Mânăstirească",
    "lat": "45.98333",
    "lng": "26.78333"
  },
  {
    "country": "RO",
    "name": "Vitomireşti",
    "lat": "44.86667",
    "lng": "24.4"
  },
  {
    "country": "RO",
    "name": "Vitănești",
    "lat": "44.5273",
    "lng": "24.69585"
  },
  {
    "country": "RO",
    "name": "Vităneşti",
    "lat": "44",
    "lng": "25.41667"
  },
  {
    "country": "RO",
    "name": "Viștea de Jos",
    "lat": "45.79582",
    "lng": "24.7238"
  },
  {
    "country": "RO",
    "name": "Vişineşti",
    "lat": "45.1",
    "lng": "25.55"
  },
  {
    "country": "RO",
    "name": "Vișina Nouă",
    "lat": "43.87434",
    "lng": "24.4182"
  },
  {
    "country": "RO",
    "name": "Vişina",
    "lat": "44.58333",
    "lng": "25.33333"
  },
  {
    "country": "RO",
    "name": "Vişina",
    "lat": "43.86667",
    "lng": "24.45"
  },
  {
    "country": "RO",
    "name": "Vişeu de Sus",
    "lat": "47.71667",
    "lng": "24.43333"
  },
  {
    "country": "RO",
    "name": "Vișeu de Mijloc",
    "lat": "47.71562",
    "lng": "24.40661"
  },
  {
    "country": "RO",
    "name": "Vişeu de Jos",
    "lat": "47.72558",
    "lng": "24.36613"
  },
  {
    "country": "RO",
    "name": "Viscri",
    "lat": "46.05522",
    "lng": "25.09389"
  },
  {
    "country": "RO",
    "name": "Vişani",
    "lat": "45.15",
    "lng": "27.28333"
  },
  {
    "country": "RO",
    "name": "Vârvoru de Jos",
    "lat": "44.24415",
    "lng": "23.6079"
  },
  {
    "country": "RO",
    "name": "Vârtop",
    "lat": "44.20682",
    "lng": "23.34869"
  },
  {
    "country": "RO",
    "name": "Vârtoapele de Sus",
    "lat": "44.19182",
    "lng": "25.20025"
  },
  {
    "country": "RO",
    "name": "Vârtoapele de Jos",
    "lat": "44.18333",
    "lng": "25.2"
  },
  {
    "country": "RO",
    "name": "Vârteşcoiu",
    "lat": "45.73333",
    "lng": "27.08333"
  },
  {
    "country": "RO",
    "name": "Vârteju",
    "lat": "44.35606",
    "lng": "25.99183"
  },
  {
    "country": "RO",
    "name": "Vârşolţ",
    "lat": "47.2",
    "lng": "22.93333"
  },
  {
    "country": "RO",
    "name": "Vârlezi",
    "lat": "45.9",
    "lng": "27.85"
  },
  {
    "country": "RO",
    "name": "Vârghiş",
    "lat": "46.13333",
    "lng": "25.53333"
  },
  {
    "country": "RO",
    "name": "Vârfurile",
    "lat": "46.31667",
    "lng": "22.51667"
  },
  {
    "country": "RO",
    "name": "Vârfuri",
    "lat": "45.1",
    "lng": "25.51667"
  },
  {
    "country": "RO",
    "name": "Vârfu Câmpului",
    "lat": "47.84566",
    "lng": "26.33056"
  },
  {
    "country": "RO",
    "name": "Vârciorova",
    "lat": "45.3271",
    "lng": "22.35208"
  },
  {
    "country": "RO",
    "name": "Vârciorog",
    "lat": "46.96667",
    "lng": "22.3"
  },
  {
    "country": "RO",
    "name": "Vipereşti",
    "lat": "45.23333",
    "lng": "26.46667"
  },
  {
    "country": "RO",
    "name": "Vintileasca",
    "lat": "45.6",
    "lng": "26.73333"
  },
  {
    "country": "RO",
    "name": "Vintileanca",
    "lat": "44.985",
    "lng": "26.58005"
  },
  {
    "country": "RO",
    "name": "Vintilă Vodă",
    "lat": "45.46667",
    "lng": "26.71667"
  },
  {
    "country": "RO",
    "name": "Vintere",
    "lat": "46.76883",
    "lng": "22.14652"
  },
  {
    "country": "RO",
    "name": "Vânju-Mare",
    "lat": "44.42528",
    "lng": "22.86972"
  },
  {
    "country": "RO",
    "name": "Vânjuleţ",
    "lat": "44.44111",
    "lng": "22.7925"
  },
  {
    "country": "RO",
    "name": "Vinga",
    "lat": "46.01667",
    "lng": "21.2"
  },
  {
    "country": "RO",
    "name": "Vinerea",
    "lat": "45.88632",
    "lng": "23.35289"
  },
  {
    "country": "RO",
    "name": "Vinderei",
    "lat": "46.15",
    "lng": "27.8"
  },
  {
    "country": "RO",
    "name": "Vânători-Neamţ",
    "lat": "47.2",
    "lng": "26.31667"
  },
  {
    "country": "RO",
    "name": "Vânătorii Mici",
    "lat": "44.49028",
    "lng": "25.55889"
  },
  {
    "country": "RO",
    "name": "Vânătorii Mari",
    "lat": "44.48898",
    "lng": "25.54548"
  },
  {
    "country": "RO",
    "name": "Vânători",
    "lat": "47.3598",
    "lng": "26.76423"
  },
  {
    "country": "RO",
    "name": "Vânători",
    "lat": "47.23333",
    "lng": "27.53333"
  },
  {
    "country": "RO",
    "name": "Vânători",
    "lat": "46.62456",
    "lng": "21.67332"
  },
  {
    "country": "RO",
    "name": "Vânători",
    "lat": "46.23333",
    "lng": "24.93333"
  },
  {
    "country": "RO",
    "name": "Vânători",
    "lat": "45.73333",
    "lng": "27.25"
  },
  {
    "country": "RO",
    "name": "Vânători",
    "lat": "45.53333",
    "lng": "28.01667"
  },
  {
    "country": "RO",
    "name": "Vânători",
    "lat": "44.24278",
    "lng": "22.92889"
  },
  {
    "country": "RO",
    "name": "Vima Mică",
    "lat": "47.4",
    "lng": "23.71667"
  },
  {
    "country": "RO",
    "name": "Vâlcelele de Sus",
    "lat": "44.28461",
    "lng": "24.55821"
  },
  {
    "country": "RO",
    "name": "Vâlcelele",
    "lat": "45.3443",
    "lng": "27.34937"
  },
  {
    "country": "RO",
    "name": "Vâlcelele",
    "lat": "44.38834",
    "lng": "27.15022"
  },
  {
    "country": "RO",
    "name": "Vâlcele",
    "lat": "46.29801",
    "lng": "26.60005"
  },
  {
    "country": "RO",
    "name": "Vâlcele",
    "lat": "45.85",
    "lng": "25.68333"
  },
  {
    "country": "RO",
    "name": "Vâlcele",
    "lat": "45.08692",
    "lng": "26.63353"
  },
  {
    "country": "RO",
    "name": "Vâlcele",
    "lat": "44.28263",
    "lng": "24.54376"
  },
  {
    "country": "RO",
    "name": "Vâlcăneşti",
    "lat": "45.11667",
    "lng": "25.93333"
  },
  {
    "country": "RO",
    "name": "Viișoara",
    "lat": "47.10332",
    "lng": "24.44949"
  },
  {
    "country": "RO",
    "name": "Viişoara",
    "lat": "48.16667",
    "lng": "26.73333"
  },
  {
    "country": "RO",
    "name": "Viişoara",
    "lat": "47.38333",
    "lng": "22.45"
  },
  {
    "country": "RO",
    "name": "Viişoara",
    "lat": "46.93333",
    "lng": "26.23333"
  },
  {
    "country": "RO",
    "name": "Viişoara",
    "lat": "46.55",
    "lng": "23.91667"
  },
  {
    "country": "RO",
    "name": "Viişoara",
    "lat": "46.38333",
    "lng": "27.88333"
  },
  {
    "country": "RO",
    "name": "Viișoara",
    "lat": "46.28325",
    "lng": "26.66187"
  },
  {
    "country": "RO",
    "name": "Viişoara",
    "lat": "46.28333",
    "lng": "24.6"
  },
  {
    "country": "RO",
    "name": "Viișoara",
    "lat": "46.0516",
    "lng": "27.09593"
  },
  {
    "country": "RO",
    "name": "Viișoara",
    "lat": "44.88116",
    "lng": "25.4273"
  },
  {
    "country": "RO",
    "name": "Viișoara",
    "lat": "44.07758",
    "lng": "28.19424"
  },
  {
    "country": "RO",
    "name": "Viişoara",
    "lat": "43.78333",
    "lng": "25.16667"
  },
  {
    "country": "RO",
    "name": "Viile Satu Mare",
    "lat": "47.66667",
    "lng": "22.95"
  },
  {
    "country": "RO",
    "name": "Viile",
    "lat": "45.80691",
    "lng": "27.94748"
  },
  {
    "country": "RO",
    "name": "Viile",
    "lat": "44.162",
    "lng": "27.75769"
  },
  {
    "country": "RO",
    "name": "Viforâta",
    "lat": "44.96011",
    "lng": "25.45796"
  },
  {
    "country": "RO",
    "name": "Vieru",
    "lat": "43.88787",
    "lng": "25.80974"
  },
  {
    "country": "RO",
    "name": "Vierșani",
    "lat": "44.87875",
    "lng": "23.5312"
  },
  {
    "country": "RO",
    "name": "Vidra",
    "lat": "46.36758",
    "lng": "22.88811"
  },
  {
    "country": "RO",
    "name": "Vidra",
    "lat": "45.91667",
    "lng": "26.9"
  },
  {
    "country": "RO",
    "name": "Vidra",
    "lat": "44.26056",
    "lng": "26.16972"
  },
  {
    "country": "RO",
    "name": "Videle",
    "lat": "44.27806",
    "lng": "25.52444"
  },
  {
    "country": "RO",
    "name": "Victor Vlad Delamarina",
    "lat": "45.64056",
    "lng": "21.89278"
  },
  {
    "country": "RO",
    "name": "Victoria",
    "lat": "47.61018",
    "lng": "27.1673"
  },
  {
    "country": "RO",
    "name": "Victoria",
    "lat": "47.28333",
    "lng": "27.58333"
  },
  {
    "country": "RO",
    "name": "Victoria",
    "lat": "45.72968",
    "lng": "24.7028"
  },
  {
    "country": "RO",
    "name": "Victoria",
    "lat": "44.81667",
    "lng": "27.61667"
  },
  {
    "country": "RO",
    "name": "Vicovu de Sus",
    "lat": "47.93333",
    "lng": "25.68333"
  },
  {
    "country": "RO",
    "name": "Vicovu de Jos",
    "lat": "47.9",
    "lng": "25.73333"
  },
  {
    "country": "RO",
    "name": "Veza",
    "lat": "46.16747",
    "lng": "23.9247"
  },
  {
    "country": "RO",
    "name": "Vetiş",
    "lat": "47.8",
    "lng": "22.76667"
  },
  {
    "country": "RO",
    "name": "Veţel",
    "lat": "45.9",
    "lng": "22.81667"
  },
  {
    "country": "RO",
    "name": "Veţca",
    "lat": "46.35",
    "lng": "24.78333"
  },
  {
    "country": "RO",
    "name": "Veștem",
    "lat": "45.71752",
    "lng": "24.23958"
  },
  {
    "country": "RO",
    "name": "Veseuș",
    "lat": "46.27456",
    "lng": "24.14276"
  },
  {
    "country": "RO",
    "name": "Verșești",
    "lat": "46.44904",
    "lng": "26.70183"
  },
  {
    "country": "RO",
    "name": "Verșeni",
    "lat": "47.11294",
    "lng": "26.64341"
  },
  {
    "country": "RO",
    "name": "Verneşti",
    "lat": "45.21667",
    "lng": "26.73333"
  },
  {
    "country": "RO",
    "name": "Vermești",
    "lat": "46.42172",
    "lng": "26.4766"
  },
  {
    "country": "RO",
    "name": "Vermeş",
    "lat": "45.52056",
    "lng": "21.65972"
  },
  {
    "country": "RO",
    "name": "Verguleasa",
    "lat": "44.65",
    "lng": "24.31667"
  },
  {
    "country": "RO",
    "name": "Vereşti",
    "lat": "47.6",
    "lng": "26.43333"
  },
  {
    "country": "RO",
    "name": "Verendin",
    "lat": "45.07755",
    "lng": "22.23917"
  },
  {
    "country": "RO",
    "name": "Verbiţa",
    "lat": "44.3",
    "lng": "23.16667"
  },
  {
    "country": "RO",
    "name": "Vela",
    "lat": "44.28333",
    "lng": "23.41667"
  },
  {
    "country": "RO",
    "name": "Vedea",
    "lat": "44.78333",
    "lng": "24.61667"
  },
  {
    "country": "RO",
    "name": "Vedea",
    "lat": "44.08333",
    "lng": "25.06667"
  },
  {
    "country": "RO",
    "name": "Vedea",
    "lat": "43.78333",
    "lng": "25.78333"
  },
  {
    "country": "RO",
    "name": "Vatra Moldoviţei",
    "lat": "47.65",
    "lng": "25.56667"
  },
  {
    "country": "RO",
    "name": "Vatra Dornei",
    "lat": "47.35",
    "lng": "25.36667"
  },
  {
    "country": "RO",
    "name": "Vătava",
    "lat": "46.96667",
    "lng": "24.76667"
  },
  {
    "country": "RO",
    "name": "Vaţa de Jos",
    "lat": "46.18333",
    "lng": "22.6"
  },
  {
    "country": "RO",
    "name": "Vaslui",
    "lat": "46.63333",
    "lng": "27.73333"
  },
  {
    "country": "RO",
    "name": "Umbrărești-Deal",
    "lat": "45.7",
    "lng": "27.46667"
  },
  {
    "country": "RO",
    "name": "Vasilaţi",
    "lat": "44.28778",
    "lng": "26.4475"
  },
  {
    "country": "RO",
    "name": "Vaşcău",
    "lat": "46.46667",
    "lng": "22.46667"
  },
  {
    "country": "RO",
    "name": "Vășad",
    "lat": "47.5186",
    "lng": "22.2566"
  },
  {
    "country": "RO",
    "name": "Vărşag",
    "lat": "46.51667",
    "lng": "25.35"
  },
  {
    "country": "RO",
    "name": "Varnița",
    "lat": "44.80679",
    "lng": "25.9453"
  },
  {
    "country": "RO",
    "name": "Variaş",
    "lat": "46.01667",
    "lng": "20.95"
  },
  {
    "country": "RO",
    "name": "Vărgata",
    "lat": "46.56667",
    "lng": "24.8"
  },
  {
    "country": "RO",
    "name": "Vărbilău",
    "lat": "45.18333",
    "lng": "25.95"
  },
  {
    "country": "RO",
    "name": "Vărbila",
    "lat": "45.04654",
    "lng": "26.19691"
  },
  {
    "country": "RO",
    "name": "Văratec",
    "lat": "47.63988",
    "lng": "26.40312"
  },
  {
    "country": "RO",
    "name": "Vărăşti",
    "lat": "44.23778",
    "lng": "26.24861"
  },
  {
    "country": "RO",
    "name": "Vărăști",
    "lat": "44.21244",
    "lng": "26.97188"
  },
  {
    "country": "RO",
    "name": "Vărădia de Mureş",
    "lat": "46.01667",
    "lng": "22.15"
  },
  {
    "country": "RO",
    "name": "Vărădia",
    "lat": "45.07833",
    "lng": "21.54694"
  },
  {
    "country": "RO",
    "name": "Vama Buzăului",
    "lat": "45.59668",
    "lng": "25.99359"
  },
  {
    "country": "RO",
    "name": "Vama",
    "lat": "47.83333",
    "lng": "23.4"
  },
  {
    "country": "RO",
    "name": "Vama",
    "lat": "47.56667",
    "lng": "25.68333"
  },
  {
    "country": "RO",
    "name": "Valu lui Traian",
    "lat": "44.16667",
    "lng": "28.46667"
  },
  {
    "country": "RO",
    "name": "Văliug",
    "lat": "45.23333",
    "lng": "22.03333"
  },
  {
    "country": "RO",
    "name": "Vălişoara",
    "lat": "46.05",
    "lng": "22.85"
  },
  {
    "country": "RO",
    "name": "Văleni-Podgoria",
    "lat": "44.85755",
    "lng": "24.9893"
  },
  {
    "country": "RO",
    "name": "Vălenii Șomcutei",
    "lat": "47.47291",
    "lng": "23.45138"
  },
  {
    "country": "RO",
    "name": "Vălenii de Mureș",
    "lat": "46.89274",
    "lng": "24.79793"
  },
  {
    "country": "RO",
    "name": "Vălenii de Munte",
    "lat": "45.18333",
    "lng": "26.03333"
  },
  {
    "country": "RO",
    "name": "Văleni-Dâmbovița",
    "lat": "45.16667",
    "lng": "25.18333"
  },
  {
    "country": "RO",
    "name": "Văleni",
    "lat": "46.90291",
    "lng": "26.38945"
  },
  {
    "country": "RO",
    "name": "Văleni",
    "lat": "47.78559",
    "lng": "24.01625"
  },
  {
    "country": "RO",
    "name": "Văleni",
    "lat": "47.03104",
    "lng": "26.68846"
  },
  {
    "country": "RO",
    "name": "Văleni",
    "lat": "46.74733",
    "lng": "27.7596"
  },
  {
    "country": "RO",
    "name": "Văleni",
    "lat": "44.23333",
    "lng": "24.78333"
  },
  {
    "country": "RO",
    "name": "Valea Vișeului",
    "lat": "47.91203",
    "lng": "24.15842"
  },
  {
    "country": "RO",
    "name": "Valea Vinului",
    "lat": "47.71667",
    "lng": "23.18333"
  },
  {
    "country": "RO",
    "name": "Valea Viilor",
    "lat": "46.08333",
    "lng": "24.28333"
  },
  {
    "country": "RO",
    "name": "Valea Ursului",
    "lat": "46.81667",
    "lng": "27.08333"
  },
  {
    "country": "RO",
    "name": "Valea Târsei",
    "lat": "45.17711",
    "lng": "25.63323"
  },
  {
    "country": "RO",
    "name": "Valea Teilor",
    "lat": "45.1115",
    "lng": "28.48801"
  },
  {
    "country": "RO",
    "name": "Valea Strâmbă",
    "lat": "46.69429",
    "lng": "25.59956"
  },
  {
    "country": "RO",
    "name": "Valea Stanciului",
    "lat": "43.98333",
    "lng": "23.86667"
  },
  {
    "country": "RO",
    "name": "Valea Șoșii",
    "lat": "46.4618",
    "lng": "26.54992"
  },
  {
    "country": "RO",
    "name": "Valea Seacă",
    "lat": "48.0808",
    "lng": "23.16489"
  },
  {
    "country": "RO",
    "name": "Valea Seacă",
    "lat": "47.29219",
    "lng": "26.66876"
  },
  {
    "country": "RO",
    "name": "Valea Seacă",
    "lat": "47.13944",
    "lng": "26.29956"
  },
  {
    "country": "RO",
    "name": "Valea Seacă",
    "lat": "46.46475",
    "lng": "26.88054"
  },
  {
    "country": "RO",
    "name": "Valea Seacă",
    "lat": "46.24281",
    "lng": "27.04594"
  },
  {
    "country": "RO",
    "name": "Ştefan Cel Mare",
    "lat": "46.20526",
    "lng": "26.85488"
  },
  {
    "country": "RO",
    "name": "Valea Sării",
    "lat": "45.87686",
    "lng": "26.79873"
  },
  {
    "country": "RO",
    "name": "Valea Salciei",
    "lat": "45.49622",
    "lng": "26.82361"
  },
  {
    "country": "RO",
    "name": "Valea Roșie",
    "lat": "44.17755",
    "lng": "26.63457"
  },
  {
    "country": "RO",
    "name": "Valea Râmnicului",
    "lat": "45.36395",
    "lng": "27.04197"
  },
  {
    "country": "RO",
    "name": "Valea Rece",
    "lat": "46.62082",
    "lng": "25.95827"
  },
  {
    "country": "RO",
    "name": "Valea Popii",
    "lat": "45.09253",
    "lng": "25.0224"
  },
  {
    "country": "RO",
    "name": "Valea Părului",
    "lat": "45.36374",
    "lng": "26.77706"
  },
  {
    "country": "RO",
    "name": "Valea Părului",
    "lat": "43.91727",
    "lng": "25.46589"
  },
  {
    "country": "RO",
    "name": "Valea Nucarilor",
    "lat": "45.03333",
    "lng": "28.93333"
  },
  {
    "country": "RO",
    "name": "Valea Moldovei",
    "lat": "47.46667",
    "lng": "26.03333"
  },
  {
    "country": "RO",
    "name": "Valea Merilor",
    "lat": "44.47169",
    "lng": "24.65611"
  },
  {
    "country": "RO",
    "name": "Valea Mărului",
    "lat": "45.83866",
    "lng": "27.69138"
  },
  {
    "country": "RO",
    "name": "Valea Mare Pravăț",
    "lat": "45.29171",
    "lng": "25.0925"
  },
  {
    "country": "RO",
    "name": "Valea Mare-Podgoria",
    "lat": "44.88513",
    "lng": "24.90613"
  },
  {
    "country": "RO",
    "name": "Valea Mare",
    "lat": "45.76667",
    "lng": "26"
  },
  {
    "country": "RO",
    "name": "Valea Mare",
    "lat": "45.11263",
    "lng": "23.08004"
  },
  {
    "country": "RO",
    "name": "Valea Mare",
    "lat": "44.93783",
    "lng": "24.23883"
  },
  {
    "country": "RO",
    "name": "Valea Mare",
    "lat": "44.78333",
    "lng": "25.23333"
  },
  {
    "country": "RO",
    "name": "Valea Mare",
    "lat": "44.66667",
    "lng": "24"
  },
  {
    "country": "RO",
    "name": "Valea Mare",
    "lat": "44.46667",
    "lng": "24.43333"
  },
  {
    "country": "RO",
    "name": "Valea Măcrișului",
    "lat": "44.74379",
    "lng": "26.83015"
  },
  {
    "country": "RO",
    "name": "Valea Lupului",
    "lat": "47.1792",
    "lng": "27.49965"
  },
  {
    "country": "RO",
    "name": "Valea Lungă Ogrea",
    "lat": "45.05978",
    "lng": "25.59024"
  },
  {
    "country": "RO",
    "name": "Valea Lungă-Cricov",
    "lat": "45.06528",
    "lng": "25.58793"
  },
  {
    "country": "RO",
    "name": "Valea Lungă Alba Romania",
    "lat": "46.12592",
    "lng": "24.04541"
  },
  {
    "country": "RO",
    "name": "Valea lui Mihai",
    "lat": "47.51667",
    "lng": "22.15"
  },
  {
    "country": "RO",
    "name": "Valea lui Ion",
    "lat": "46.7035",
    "lng": "26.62499"
  },
  {
    "country": "RO",
    "name": "Valea Leurzii",
    "lat": "45.16186",
    "lng": "25.48533"
  },
  {
    "country": "RO",
    "name": "Valea Largă",
    "lat": "46.62257",
    "lng": "24.07758"
  },
  {
    "country": "RO",
    "name": "Valea Izvoarelor",
    "lat": "46.43855",
    "lng": "24.37597"
  },
  {
    "country": "RO",
    "name": "Valea Ierii",
    "lat": "46.65",
    "lng": "23.35"
  },
  {
    "country": "RO",
    "name": "Valea Iaşului",
    "lat": "45.18333",
    "lng": "24.71667"
  },
  {
    "country": "RO",
    "name": "Valea Grecului",
    "lat": "46.71985",
    "lng": "28.10123"
  },
  {
    "country": "RO",
    "name": "Valea Dulce",
    "lat": "45.11428",
    "lng": "26.20787"
  },
  {
    "country": "RO",
    "name": "Valea Dragului",
    "lat": "44.21222",
    "lng": "26.30361"
  },
  {
    "country": "RO",
    "name": "Valea Danului",
    "lat": "45.18333",
    "lng": "24.65"
  },
  {
    "country": "RO",
    "name": "Valea Dacilor",
    "lat": "44.19495",
    "lng": "28.31776"
  },
  {
    "country": "RO",
    "name": "Valea Cucului",
    "lat": "45.06525",
    "lng": "26.22793"
  },
  {
    "country": "RO",
    "name": "Valea Crişului",
    "lat": "45.91667",
    "lng": "25.76667"
  },
  {
    "country": "RO",
    "name": "Valea Cireșului",
    "lat": "44.16699",
    "lng": "25.56437"
  },
  {
    "country": "RO",
    "name": "Valea Ciorii",
    "lat": "44.71667",
    "lng": "27.56667"
  },
  {
    "country": "RO",
    "name": "Valea Cânepii",
    "lat": "45.08333",
    "lng": "27.81667"
  },
  {
    "country": "RO",
    "name": "Valea Chioarului",
    "lat": "47.43333",
    "lng": "23.48333"
  },
  {
    "country": "RO",
    "name": "Valea Caselor",
    "lat": "45.35",
    "lng": "25.16667"
  },
  {
    "country": "RO",
    "name": "Valea Călugărească",
    "lat": "44.96667",
    "lng": "26.15"
  },
  {
    "country": "RO",
    "name": "Valea Borcutului",
    "lat": "47.37483",
    "lng": "24.65293"
  },
  {
    "country": "RO",
    "name": "Valea Bolvașnița",
    "lat": "44.94602",
    "lng": "22.39019"
  },
  {
    "country": "RO",
    "name": "Valea Arinilor",
    "lat": "46.49793",
    "lng": "26.50918"
  },
  {
    "country": "RO",
    "name": "Valea Arini",
    "lat": "47.12694",
    "lng": "26.29377"
  },
  {
    "country": "RO",
    "name": "Valea Argovei",
    "lat": "44.35",
    "lng": "26.78333"
  },
  {
    "country": "RO",
    "name": "Vale",
    "lat": "46.9491",
    "lng": "25.37869"
  },
  {
    "country": "RO",
    "name": "Valcău de Jos",
    "lat": "47.11667",
    "lng": "22.73333"
  },
  {
    "country": "RO",
    "name": "Vălcani",
    "lat": "46.00357",
    "lng": "20.39865"
  },
  {
    "country": "RO",
    "name": "Vaideeni",
    "lat": "45.16667",
    "lng": "23.93333"
  },
  {
    "country": "RO",
    "name": "Vaida-Cămăraș",
    "lat": "46.82823",
    "lng": "23.94724"
  },
  {
    "country": "RO",
    "name": "Văgiuleşti",
    "lat": "44.71667",
    "lng": "23.08333"
  },
  {
    "country": "RO",
    "name": "Vadu Sorești",
    "lat": "45.315",
    "lng": "26.87748"
  },
  {
    "country": "RO",
    "name": "Vadu Săpat",
    "lat": "45.03973",
    "lng": "26.387"
  },
  {
    "country": "RO",
    "name": "Vadu Roșca",
    "lat": "45.63864",
    "lng": "27.45716"
  },
  {
    "country": "RO",
    "name": "Vădurele",
    "lat": "46.93319",
    "lng": "26.25074"
  },
  {
    "country": "RO",
    "name": "Vădurele",
    "lat": "46.72958",
    "lng": "26.57173"
  },
  {
    "country": "RO",
    "name": "Vadu Paşii",
    "lat": "45.16667",
    "lng": "26.9"
  },
  {
    "country": "RO",
    "name": "Vadu Părului",
    "lat": "44.93132",
    "lng": "26.2094"
  },
  {
    "country": "RO",
    "name": "Vadu Moţilor",
    "lat": "46.4",
    "lng": "22.96667"
  },
  {
    "country": "RO",
    "name": "Vadu Moldovei",
    "lat": "47.38333",
    "lng": "26.36667"
  },
  {
    "country": "RO",
    "name": "Vadu Izei",
    "lat": "47.93333",
    "lng": "23.88333"
  },
  {
    "country": "RO",
    "name": "Vadu Izei",
    "lat": "47.88821",
    "lng": "23.93209"
  },
  {
    "country": "RO",
    "name": "Vadu Crişului",
    "lat": "46.98333",
    "lng": "22.51667"
  },
  {
    "country": "RO",
    "name": "Vădeni",
    "lat": "45.36667",
    "lng": "27.93333"
  },
  {
    "country": "RO",
    "name": "Vădăstriţa",
    "lat": "43.85",
    "lng": "24.33333"
  },
  {
    "country": "RO",
    "name": "Vădastra",
    "lat": "43.86667",
    "lng": "24.36667"
  },
  {
    "country": "RO",
    "name": "Vad",
    "lat": "47.2",
    "lng": "23.75"
  },
  {
    "country": "RO",
    "name": "Văculeşti",
    "lat": "47.88333",
    "lng": "26.41667"
  },
  {
    "country": "RO",
    "name": "Văcăreşti",
    "lat": "44.85",
    "lng": "25.48333"
  },
  {
    "country": "RO",
    "name": "Văcăreni",
    "lat": "45.32415",
    "lng": "28.19512"
  },
  {
    "country": "RO",
    "name": "Uzunu",
    "lat": "44.14716",
    "lng": "25.96719"
  },
  {
    "country": "RO",
    "name": "Utvin",
    "lat": "45.71298",
    "lng": "21.13011"
  },
  {
    "country": "RO",
    "name": "Ususău",
    "lat": "46.07063",
    "lng": "21.81371"
  },
  {
    "country": "RO",
    "name": "Urzicuţa",
    "lat": "44.01667",
    "lng": "23.55"
  },
  {
    "country": "RO",
    "name": "Urziceni",
    "lat": "47.73333",
    "lng": "22.4"
  },
  {
    "country": "RO",
    "name": "Urziceni",
    "lat": "44.71667",
    "lng": "26.63333"
  },
  {
    "country": "RO",
    "name": "Urziceanca",
    "lat": "44.63052",
    "lng": "25.8424"
  },
  {
    "country": "RO",
    "name": "Urși",
    "lat": "44.99404",
    "lng": "24.08895"
  },
  {
    "country": "RO",
    "name": "Urseni",
    "lat": "45.69269",
    "lng": "21.30993"
  },
  {
    "country": "RO",
    "name": "Ursa",
    "lat": "43.78783",
    "lng": "24.63787"
  },
  {
    "country": "RO",
    "name": "Urmeniş",
    "lat": "46.76667",
    "lng": "24.36667"
  },
  {
    "country": "RO",
    "name": "Urleta",
    "lat": "45.08732",
    "lng": "25.79354"
  },
  {
    "country": "RO",
    "name": "Urleasca",
    "lat": "45.13697",
    "lng": "27.64736"
  },
  {
    "country": "RO",
    "name": "Urlaţi",
    "lat": "44.98333",
    "lng": "26.23333"
  },
  {
    "country": "RO",
    "name": "Uriu",
    "lat": "47.2",
    "lng": "24.05"
  },
  {
    "country": "RO",
    "name": "Uricani",
    "lat": "45.33731",
    "lng": "23.1524"
  },
  {
    "country": "RO",
    "name": "Urecheşti",
    "lat": "46.13333",
    "lng": "27.08333"
  },
  {
    "country": "RO",
    "name": "Urecheşti",
    "lat": "45.6",
    "lng": "27.06667"
  },
  {
    "country": "RO",
    "name": "Urecheni",
    "lat": "47.16667",
    "lng": "26.51667"
  },
  {
    "country": "RO",
    "name": "Urdari",
    "lat": "44.8",
    "lng": "23.3"
  },
  {
    "country": "RO",
    "name": "Urca",
    "lat": "46.54885",
    "lng": "23.96187"
  },
  {
    "country": "RO",
    "name": "Unţeni",
    "lat": "47.8",
    "lng": "26.78333"
  },
  {
    "country": "RO",
    "name": "Unirea",
    "lat": "47.1606",
    "lng": "24.53078"
  },
  {
    "country": "RO",
    "name": "Unirea",
    "lat": "46.40387",
    "lng": "23.81314"
  },
  {
    "country": "RO",
    "name": "Unirea",
    "lat": "45.7402",
    "lng": "27.10741"
  },
  {
    "country": "RO",
    "name": "General Berthelot",
    "lat": "45.61667",
    "lng": "22.88333"
  },
  {
    "country": "RO",
    "name": "Unirea",
    "lat": "45.11667",
    "lng": "27.81667"
  },
  {
    "country": "RO",
    "name": "Unirea",
    "lat": "44.26667",
    "lng": "27.63333"
  },
  {
    "country": "RO",
    "name": "Unirea",
    "lat": "44.15",
    "lng": "23.18333"
  },
  {
    "country": "RO",
    "name": "Unguriu",
    "lat": "45.27933",
    "lng": "26.63208"
  },
  {
    "country": "RO",
    "name": "Arini",
    "lat": "46.35",
    "lng": "27.18333"
  },
  {
    "country": "RO",
    "name": "Ungureni-Jianu",
    "lat": "47.88333",
    "lng": "26.78333"
  },
  {
    "country": "RO",
    "name": "Ungureni",
    "lat": "46.51667",
    "lng": "26.95"
  },
  {
    "country": "RO",
    "name": "Ungureni",
    "lat": "47.54631",
    "lng": "23.95241"
  },
  {
    "country": "RO",
    "name": "Ungureni",
    "lat": "46.52283",
    "lng": "27.11186"
  },
  {
    "country": "RO",
    "name": "Ungureni",
    "lat": "45.91307",
    "lng": "27.47"
  },
  {
    "country": "RO",
    "name": "Ungureni",
    "lat": "44.87147",
    "lng": "25.3918"
  },
  {
    "country": "RO",
    "name": "Ungureni",
    "lat": "44.57804",
    "lng": "25.50006"
  },
  {
    "country": "RO",
    "name": "Unguraş",
    "lat": "47.11667",
    "lng": "24.05"
  },
  {
    "country": "RO",
    "name": "Ungra",
    "lat": "45.98333",
    "lng": "25.26667"
  },
  {
    "country": "RO",
    "name": "Ungheni",
    "lat": "46.48333",
    "lng": "24.46667"
  },
  {
    "country": "RO",
    "name": "Ungheni",
    "lat": "44.5",
    "lng": "24.96667"
  },
  {
    "country": "RO",
    "name": "Umbrărești",
    "lat": "45.84835",
    "lng": "27.91845"
  },
  {
    "country": "RO",
    "name": "Umbrăreşti",
    "lat": "45.71667",
    "lng": "27.46667"
  },
  {
    "country": "RO",
    "name": "Ulmu",
    "lat": "44.95",
    "lng": "27.31667"
  },
  {
    "country": "RO",
    "name": "Ulmu",
    "lat": "44.26667",
    "lng": "26.91667"
  },
  {
    "country": "RO",
    "name": "Ulmi",
    "lat": "44.9",
    "lng": "25.5"
  },
  {
    "country": "RO",
    "name": "Ulmi",
    "lat": "44.48667",
    "lng": "25.78028"
  },
  {
    "country": "RO",
    "name": "Ulmeni",
    "lat": "47.46667",
    "lng": "23.3"
  },
  {
    "country": "RO",
    "name": "Ulmeni",
    "lat": "45.06667",
    "lng": "26.65"
  },
  {
    "country": "RO",
    "name": "Ulmeni",
    "lat": "44.15",
    "lng": "26.71667"
  },
  {
    "country": "RO",
    "name": "Ulma",
    "lat": "47.88333",
    "lng": "25.3"
  },
  {
    "country": "RO",
    "name": "Ulieşti",
    "lat": "44.58333",
    "lng": "25.41667"
  },
  {
    "country": "RO",
    "name": "Uivar",
    "lat": "45.65806",
    "lng": "20.90583"
  },
  {
    "country": "RO",
    "name": "Uioara de Jos",
    "lat": "46.37087",
    "lng": "23.83863"
  },
  {
    "country": "RO",
    "name": "Udupu",
    "lat": "44.39657",
    "lng": "25.14488"
  },
  {
    "country": "RO",
    "name": "Udeşti",
    "lat": "47.56667",
    "lng": "26.41667"
  },
  {
    "country": "RO",
    "name": "Uda-Paciurea",
    "lat": "43.87979",
    "lng": "24.72379"
  },
  {
    "country": "RO",
    "name": "Uda-Clocociov",
    "lat": "43.88791",
    "lng": "24.71437"
  },
  {
    "country": "RO",
    "name": "Uda",
    "lat": "47.33645",
    "lng": "26.57165"
  },
  {
    "country": "RO",
    "name": "Uda",
    "lat": "44.91667",
    "lng": "24.56667"
  },
  {
    "country": "RO",
    "name": "Ucea de Sus",
    "lat": "45.75",
    "lng": "24.68333"
  },
  {
    "country": "RO",
    "name": "Ucea de Jos",
    "lat": "45.7841",
    "lng": "24.67097"
  },
  {
    "country": "RO",
    "name": "Tuzla",
    "lat": "44",
    "lng": "28.63333"
  },
  {
    "country": "RO",
    "name": "Tutova",
    "lat": "46.11667",
    "lng": "27.55"
  },
  {
    "country": "RO",
    "name": "Ţuţora",
    "lat": "47.13333",
    "lng": "27.78333"
  },
  {
    "country": "RO",
    "name": "Tutana",
    "lat": "45.04286",
    "lng": "24.65122"
  },
  {
    "country": "RO",
    "name": "Tuta",
    "lat": "46.25643",
    "lng": "26.69103"
  },
  {
    "country": "RO",
    "name": "Tușnadu Nou",
    "lat": "46.19364",
    "lng": "25.88757"
  },
  {
    "country": "RO",
    "name": "Tuşnad",
    "lat": "46.2",
    "lng": "25.9"
  },
  {
    "country": "RO",
    "name": "Turulung",
    "lat": "47.93333",
    "lng": "23.08333"
  },
  {
    "country": "RO",
    "name": "Turţ",
    "lat": "47.98333",
    "lng": "23.21667"
  },
  {
    "country": "RO",
    "name": "Turnu Ruieni",
    "lat": "45.3907",
    "lng": "22.33557"
  },
  {
    "country": "RO",
    "name": "Turnu Roşu",
    "lat": "45.63333",
    "lng": "24.3"
  },
  {
    "country": "RO",
    "name": "Turnu Măgurele",
    "lat": "43.75",
    "lng": "24.86667"
  },
  {
    "country": "RO",
    "name": "Turnu",
    "lat": "46.25764",
    "lng": "21.12657"
  },
  {
    "country": "RO",
    "name": "Turluianu",
    "lat": "46.45298",
    "lng": "26.64607"
  },
  {
    "country": "RO",
    "name": "Turia",
    "lat": "46.03333",
    "lng": "26.05"
  },
  {
    "country": "RO",
    "name": "Tureni",
    "lat": "46.62934",
    "lng": "23.7024"
  },
  {
    "country": "RO",
    "name": "Tureac",
    "lat": "47.22967",
    "lng": "24.80589"
  },
  {
    "country": "RO",
    "name": "Turdaş",
    "lat": "45.85",
    "lng": "23.11667"
  },
  {
    "country": "RO",
    "name": "Turda",
    "lat": "46.56667",
    "lng": "23.78333"
  },
  {
    "country": "RO",
    "name": "Turda",
    "lat": "44.97501",
    "lng": "28.62402"
  },
  {
    "country": "RO",
    "name": "Turcoaia",
    "lat": "45.11667",
    "lng": "28.18333"
  },
  {
    "country": "RO",
    "name": "Turcineşti",
    "lat": "45.1",
    "lng": "23.33333"
  },
  {
    "country": "RO",
    "name": "Turcești",
    "lat": "45.04023",
    "lng": "23.86574"
  },
  {
    "country": "RO",
    "name": "Turceni",
    "lat": "44.68333",
    "lng": "23.36667"
  },
  {
    "country": "RO",
    "name": "Turburea",
    "lat": "44.71667",
    "lng": "23.51667"
  },
  {
    "country": "RO",
    "name": "Tur",
    "lat": "47.88231",
    "lng": "23.39045"
  },
  {
    "country": "RO",
    "name": "Tupilaţi",
    "lat": "47.06667",
    "lng": "26.63333"
  },
  {
    "country": "RO",
    "name": "Tunelu-Teliu",
    "lat": "45.7",
    "lng": "25.85"
  },
  {
    "country": "RO",
    "name": "Tunari",
    "lat": "44.55",
    "lng": "26.15"
  },
  {
    "country": "RO",
    "name": "Tuluceşti",
    "lat": "45.56667",
    "lng": "28.03333"
  },
  {
    "country": "RO",
    "name": "Tulnici",
    "lat": "45.91667",
    "lng": "26.66667"
  },
  {
    "country": "RO",
    "name": "Tulgheş",
    "lat": "46.95",
    "lng": "25.76667"
  },
  {
    "country": "RO",
    "name": "Tulcea",
    "lat": "45.16667",
    "lng": "28.8"
  },
  {
    "country": "RO",
    "name": "Tulca",
    "lat": "46.78333",
    "lng": "21.78333"
  },
  {
    "country": "RO",
    "name": "Ţuglui",
    "lat": "44.18333",
    "lng": "23.81667"
  },
  {
    "country": "RO",
    "name": "Tufeşti",
    "lat": "45.05",
    "lng": "27.81667"
  },
  {
    "country": "RO",
    "name": "Tufeni",
    "lat": "45.0579",
    "lng": "25.83976"
  },
  {
    "country": "RO",
    "name": "Tufeni",
    "lat": "44.36667",
    "lng": "24.78333"
  },
  {
    "country": "RO",
    "name": "Tudor Vladimirescu",
    "lat": "47.68635",
    "lng": "27.17211"
  },
  {
    "country": "RO",
    "name": "Suceveni",
    "lat": "46.01222",
    "lng": "28.01806"
  },
  {
    "country": "RO",
    "name": "Tudor Vladimirescu",
    "lat": "45.56667",
    "lng": "27.65"
  },
  {
    "country": "RO",
    "name": "Tudor Vladimirescu",
    "lat": "45.21667",
    "lng": "27.8"
  },
  {
    "country": "RO",
    "name": "Tudor Vladimirescu",
    "lat": "43.94761",
    "lng": "24.90616"
  },
  {
    "country": "RO",
    "name": "Tudora",
    "lat": "47.51667",
    "lng": "26.63333"
  },
  {
    "country": "RO",
    "name": "Truşeşti",
    "lat": "47.76667",
    "lng": "27.01667"
  },
  {
    "country": "RO",
    "name": "Troianul",
    "lat": "44",
    "lng": "25"
  },
  {
    "country": "RO",
    "name": "Trivalea-Moşteni",
    "lat": "44.26667",
    "lng": "25.23333"
  },
  {
    "country": "RO",
    "name": "Tritenii de Sus",
    "lat": "46.60544",
    "lng": "23.99849"
  },
  {
    "country": "RO",
    "name": "Tritenii de Jos",
    "lat": "46.58333",
    "lng": "24"
  },
  {
    "country": "RO",
    "name": "Trip",
    "lat": "47.9245",
    "lng": "23.37648"
  },
  {
    "country": "RO",
    "name": "Trifeşti",
    "lat": "47.45",
    "lng": "27.51667"
  },
  {
    "country": "RO",
    "name": "Trifeşti",
    "lat": "46.91667",
    "lng": "26.81667"
  },
  {
    "country": "RO",
    "name": "Treznea",
    "lat": "47.1",
    "lng": "23.11667"
  },
  {
    "country": "RO",
    "name": "Trestieni",
    "lat": "44.50449",
    "lng": "25.75789"
  },
  {
    "country": "RO",
    "name": "Trei Sate",
    "lat": "46.47572",
    "lng": "24.89855"
  },
  {
    "country": "RO",
    "name": "Trăisteni",
    "lat": "45.33857",
    "lng": "25.72767"
  },
  {
    "country": "RO",
    "name": "Traian Vuia",
    "lat": "45.8",
    "lng": "22.06667"
  },
  {
    "country": "RO",
    "name": "Traian",
    "lat": "46.9914",
    "lng": "26.90438"
  },
  {
    "country": "RO",
    "name": "Traian",
    "lat": "46.83335",
    "lng": "26.57655"
  },
  {
    "country": "RO",
    "name": "Traian",
    "lat": "46.63333",
    "lng": "27.03333"
  },
  {
    "country": "RO",
    "name": "Traian",
    "lat": "45.18333",
    "lng": "27.73333"
  },
  {
    "country": "RO",
    "name": "Traian",
    "lat": "45.02876",
    "lng": "28.23518"
  },
  {
    "country": "RO",
    "name": "Traian",
    "lat": "44.7635",
    "lng": "27.34337"
  },
  {
    "country": "RO",
    "name": "Traian",
    "lat": "44.01667",
    "lng": "24.45"
  },
  {
    "country": "RO",
    "name": "Traian",
    "lat": "43.76667",
    "lng": "25"
  },
  {
    "country": "RO",
    "name": "Totoești",
    "lat": "47.25107",
    "lng": "27.28879"
  },
  {
    "country": "RO",
    "name": "Toteşti",
    "lat": "45.56667",
    "lng": "22.88333"
  },
  {
    "country": "RO",
    "name": "Tortoman",
    "lat": "44.35",
    "lng": "28.21667"
  },
  {
    "country": "RO",
    "name": "Tormac",
    "lat": "45.52083",
    "lng": "21.49361"
  },
  {
    "country": "RO",
    "name": "Topraisar",
    "lat": "44.01667",
    "lng": "28.45"
  },
  {
    "country": "RO",
    "name": "Toporu",
    "lat": "44.01056",
    "lng": "25.65278"
  },
  {
    "country": "RO",
    "name": "Topoloveni",
    "lat": "44.81667",
    "lng": "25.08333"
  },
  {
    "country": "RO",
    "name": "Topolovăţu Mare",
    "lat": "45.77389",
    "lng": "21.61889"
  },
  {
    "country": "RO",
    "name": "Topolog",
    "lat": "44.88333",
    "lng": "28.36667"
  },
  {
    "country": "RO",
    "name": "Topolița",
    "lat": "47.16787",
    "lng": "26.38345"
  },
  {
    "country": "RO",
    "name": "Topliţa",
    "lat": "45.68333",
    "lng": "22.78333"
  },
  {
    "country": "RO",
    "name": "Toplița",
    "lat": "45.09022",
    "lng": "24.73236"
  },
  {
    "country": "RO",
    "name": "Topliceni",
    "lat": "45.41667",
    "lng": "27"
  },
  {
    "country": "RO",
    "name": "Topleţ",
    "lat": "44.79722",
    "lng": "22.39444"
  },
  {
    "country": "RO",
    "name": "Topile",
    "lat": "47.2634",
    "lng": "26.66883"
  },
  {
    "country": "RO",
    "name": "Topana",
    "lat": "44.81667",
    "lng": "24.51667"
  },
  {
    "country": "RO",
    "name": "Topalu",
    "lat": "44.55",
    "lng": "28.05"
  },
  {
    "country": "RO",
    "name": "Tomşani",
    "lat": "45.11667",
    "lng": "24.05"
  },
  {
    "country": "RO",
    "name": "Tomşani",
    "lat": "44.95",
    "lng": "26.28333"
  },
  {
    "country": "RO",
    "name": "Tomnatic",
    "lat": "45.98857",
    "lng": "20.66186"
  },
  {
    "country": "RO",
    "name": "Tomeşti",
    "lat": "47.11667",
    "lng": "27.68333"
  },
  {
    "country": "RO",
    "name": "Tomești",
    "lat": "46.55617",
    "lng": "25.77922"
  },
  {
    "country": "RO",
    "name": "Tomeşti",
    "lat": "46.21667",
    "lng": "22.65"
  },
  {
    "country": "RO",
    "name": "Tomeşti",
    "lat": "45.78333",
    "lng": "22.3"
  },
  {
    "country": "RO",
    "name": "Țolici",
    "lat": "47.1184",
    "lng": "26.44841"
  },
  {
    "country": "RO",
    "name": "Tohanu Nou",
    "lat": "45.55208",
    "lng": "25.38622"
  },
  {
    "country": "RO",
    "name": "Toflea",
    "lat": "46.06372",
    "lng": "27.33411"
  },
  {
    "country": "RO",
    "name": "Todireşti",
    "lat": "47.7",
    "lng": "26.03333"
  },
  {
    "country": "RO",
    "name": "Todireşti",
    "lat": "47.31667",
    "lng": "26.83333"
  },
  {
    "country": "RO",
    "name": "Todireşti",
    "lat": "46.85",
    "lng": "27.36667"
  },
  {
    "country": "RO",
    "name": "Todireni",
    "lat": "47.61667",
    "lng": "27.11667"
  },
  {
    "country": "RO",
    "name": "Tocileni",
    "lat": "47.71104",
    "lng": "26.78657"
  },
  {
    "country": "RO",
    "name": "Toboliu",
    "lat": "47.04182",
    "lng": "21.71946"
  },
  {
    "country": "RO",
    "name": "Tiur",
    "lat": "46.16009",
    "lng": "23.88927"
  },
  {
    "country": "RO",
    "name": "Titu",
    "lat": "44.65",
    "lng": "25.53333"
  },
  {
    "country": "RO",
    "name": "Titești",
    "lat": "45.41971",
    "lng": "24.39323"
  },
  {
    "country": "RO",
    "name": "Titeşti",
    "lat": "45.01667",
    "lng": "25"
  },
  {
    "country": "RO",
    "name": "Tismana",
    "lat": "45.05",
    "lng": "22.96667"
  },
  {
    "country": "RO",
    "name": "Tisa",
    "lat": "47.94844",
    "lng": "23.95768"
  },
  {
    "country": "RO",
    "name": "Târşolţel",
    "lat": "47.95",
    "lng": "23.35"
  },
  {
    "country": "RO",
    "name": "Târşolţ",
    "lat": "47.95",
    "lng": "23.35"
  },
  {
    "country": "RO",
    "name": "Târnova",
    "lat": "46.31667",
    "lng": "21.8"
  },
  {
    "country": "RO",
    "name": "Târnova",
    "lat": "45.3425",
    "lng": "22.00611"
  },
  {
    "country": "RO",
    "name": "Târnăveni",
    "lat": "46.33191",
    "lng": "24.29662"
  },
  {
    "country": "RO",
    "name": "Târnava",
    "lat": "46.13975",
    "lng": "24.28926"
  },
  {
    "country": "RO",
    "name": "Târnava",
    "lat": "44.1444",
    "lng": "25.56347"
  },
  {
    "country": "RO",
    "name": "Târlişua",
    "lat": "47.38333",
    "lng": "24.18333"
  },
  {
    "country": "RO",
    "name": "Târgu Trotuş",
    "lat": "46.26667",
    "lng": "26.66667"
  },
  {
    "country": "RO",
    "name": "Târguşor",
    "lat": "44.45",
    "lng": "28.41667"
  },
  {
    "country": "RO",
    "name": "Târgu Secuiesc",
    "lat": "46",
    "lng": "26.13333"
  },
  {
    "country": "RO",
    "name": "Târgu Ocna",
    "lat": "46.27899",
    "lng": "26.61301"
  },
  {
    "country": "RO",
    "name": "Târgu Neamţ",
    "lat": "47.2",
    "lng": "26.36667"
  },
  {
    "country": "RO",
    "name": "Târgu-Mureş",
    "lat": "46.54245",
    "lng": "24.55747"
  },
  {
    "country": "RO",
    "name": "Târgu Lăpuş",
    "lat": "47.45261",
    "lng": "23.86539"
  },
  {
    "country": "RO",
    "name": "Târgu Jiu",
    "lat": "45.05",
    "lng": "23.28333"
  },
  {
    "country": "RO",
    "name": "Târgu Frumos",
    "lat": "47.2",
    "lng": "27"
  },
  {
    "country": "RO",
    "name": "Târgu Cărbuneşti",
    "lat": "44.95",
    "lng": "23.51667"
  },
  {
    "country": "RO",
    "name": "Târgşoru Vechi",
    "lat": "44.86667",
    "lng": "25.91667"
  },
  {
    "country": "RO",
    "name": "Târgovişte",
    "lat": "44.92543",
    "lng": "25.4567"
  },
  {
    "country": "RO",
    "name": "Tiream",
    "lat": "47.61667",
    "lng": "22.46667"
  },
  {
    "country": "RO",
    "name": "Țipar",
    "lat": "46.47563",
    "lng": "21.63431"
  },
  {
    "country": "RO",
    "name": "Ţinteşti",
    "lat": "45.06667",
    "lng": "26.86667"
  },
  {
    "country": "RO",
    "name": "Țintea",
    "lat": "45.03403",
    "lng": "25.9046"
  },
  {
    "country": "RO",
    "name": "Tântava",
    "lat": "44.41511",
    "lng": "25.8245"
  },
  {
    "country": "RO",
    "name": "Ţânţăreni",
    "lat": "44.6",
    "lng": "23.48333"
  },
  {
    "country": "RO",
    "name": "Tinosu",
    "lat": "44.81667",
    "lng": "26.01667"
  },
  {
    "country": "RO",
    "name": "Tânganu",
    "lat": "44.40628",
    "lng": "26.31262"
  },
  {
    "country": "RO",
    "name": "Tinca",
    "lat": "46.77529",
    "lng": "21.933"
  },
  {
    "country": "RO",
    "name": "Tâmna",
    "lat": "44.56667",
    "lng": "23.01667"
  },
  {
    "country": "RO",
    "name": "Timişoara",
    "lat": "45.75372",
    "lng": "21.22571"
  },
  {
    "country": "RO",
    "name": "Timişeşti",
    "lat": "47.23333",
    "lng": "26.55"
  },
  {
    "country": "RO",
    "name": "Tâmboeşti",
    "lat": "45.51667",
    "lng": "27.05"
  },
  {
    "country": "RO",
    "name": "Tilişca",
    "lat": "45.8",
    "lng": "23.85"
  },
  {
    "country": "RO",
    "name": "Tileagd",
    "lat": "47.06667",
    "lng": "22.2"
  },
  {
    "country": "RO",
    "name": "Tihău",
    "lat": "47.22724",
    "lng": "23.32964"
  },
  {
    "country": "RO",
    "name": "Tiha Bârgăului",
    "lat": "47.23333",
    "lng": "24.76667"
  },
  {
    "country": "RO",
    "name": "Tigveni",
    "lat": "45.13333",
    "lng": "24.58333"
  },
  {
    "country": "RO",
    "name": "Ţigăneşti",
    "lat": "43.9",
    "lng": "25.36667"
  },
  {
    "country": "RO",
    "name": "Ţigănaşi",
    "lat": "47.33333",
    "lng": "27.46667"
  },
  {
    "country": "RO",
    "name": "Ţifeşti",
    "lat": "45.85",
    "lng": "27.1"
  },
  {
    "country": "RO",
    "name": "Ticvaniu Mare",
    "lat": "45.13528",
    "lng": "21.63806"
  },
  {
    "country": "RO",
    "name": "Ticuşu Vechi",
    "lat": "45.93333",
    "lng": "25.1"
  },
  {
    "country": "RO",
    "name": "Ţicleni",
    "lat": "44.88333",
    "lng": "23.4"
  },
  {
    "country": "RO",
    "name": "Tichileşti",
    "lat": "45.11667",
    "lng": "27.9"
  },
  {
    "country": "RO",
    "name": "Ţibucani",
    "lat": "47.1",
    "lng": "26.53333"
  },
  {
    "country": "RO",
    "name": "Țibeni",
    "lat": "47.81618",
    "lng": "26.02438"
  },
  {
    "country": "RO",
    "name": "Ţibăneşti",
    "lat": "46.91667",
    "lng": "27.33333"
  },
  {
    "country": "RO",
    "name": "Ţibana",
    "lat": "46.98333",
    "lng": "27.33333"
  },
  {
    "country": "RO",
    "name": "Tia Mare",
    "lat": "43.86667",
    "lng": "24.63333"
  },
  {
    "country": "RO",
    "name": "Tetoiu",
    "lat": "44.75",
    "lng": "23.91667"
  },
  {
    "country": "RO",
    "name": "Tețcoiu",
    "lat": "44.68188",
    "lng": "25.43846"
  },
  {
    "country": "RO",
    "name": "Teslui",
    "lat": "44.51667",
    "lng": "24.36667"
  },
  {
    "country": "RO",
    "name": "Teșila",
    "lat": "45.30352",
    "lng": "25.72324"
  },
  {
    "country": "RO",
    "name": "Terpeziţa",
    "lat": "44.29191",
    "lng": "23.50559"
  },
  {
    "country": "RO",
    "name": "Teremia Mare",
    "lat": "45.93528",
    "lng": "20.525"
  },
  {
    "country": "RO",
    "name": "Teregova",
    "lat": "45.15",
    "lng": "22.28333"
  },
  {
    "country": "RO",
    "name": "Terebeşti",
    "lat": "47.68333",
    "lng": "22.71667"
  },
  {
    "country": "RO",
    "name": "Ţepu",
    "lat": "45.96667",
    "lng": "27.36667"
  },
  {
    "country": "RO",
    "name": "Țelna",
    "lat": "46.15902",
    "lng": "23.50099"
  },
  {
    "country": "RO",
    "name": "Teliucu Inferior",
    "lat": "45.71667",
    "lng": "22.88333"
  },
  {
    "country": "RO",
    "name": "Teliu",
    "lat": "45.69856",
    "lng": "25.8559"
  },
  {
    "country": "RO",
    "name": "Teleşti",
    "lat": "45",
    "lng": "23.08333"
  },
  {
    "country": "RO",
    "name": "Teleormanu",
    "lat": "43.96271",
    "lng": "25.45876"
  },
  {
    "country": "RO",
    "name": "Telega",
    "lat": "45.13333",
    "lng": "25.78333"
  },
  {
    "country": "RO",
    "name": "Telec",
    "lat": "46.87979",
    "lng": "25.87775"
  },
  {
    "country": "RO",
    "name": "Telciu",
    "lat": "47.43333",
    "lng": "24.4"
  },
  {
    "country": "RO",
    "name": "Telcișor",
    "lat": "47.46",
    "lng": "24.45158"
  },
  {
    "country": "RO",
    "name": "Teiuş",
    "lat": "46.2",
    "lng": "23.68333"
  },
  {
    "country": "RO",
    "name": "Teiu",
    "lat": "44.66667",
    "lng": "25.1"
  },
  {
    "country": "RO",
    "name": "Teişani",
    "lat": "45.23333",
    "lng": "25.98333"
  },
  {
    "country": "RO",
    "name": "Teiș",
    "lat": "44.96285",
    "lng": "25.4028"
  },
  {
    "country": "RO",
    "name": "Tecuci",
    "lat": "45.84973",
    "lng": "27.43441"
  },
  {
    "country": "RO",
    "name": "Tecuci",
    "lat": "44.34179",
    "lng": "24.85966"
  },
  {
    "country": "RO",
    "name": "Techirghiol",
    "lat": "44.05",
    "lng": "28.6"
  },
  {
    "country": "RO",
    "name": "Teasc",
    "lat": "44.16454",
    "lng": "23.86461"
  },
  {
    "country": "RO",
    "name": "Teaca",
    "lat": "46.91667",
    "lng": "24.51667"
  },
  {
    "country": "RO",
    "name": "Tazlău",
    "lat": "46.71667",
    "lng": "26.46667"
  },
  {
    "country": "RO",
    "name": "Tăuții-Măgherăuș",
    "lat": "47.65",
    "lng": "23.48333"
  },
  {
    "country": "RO",
    "name": "Tăuții de Sus",
    "lat": "47.65665",
    "lng": "23.65841"
  },
  {
    "country": "RO",
    "name": "Tăuteu",
    "lat": "47.26667",
    "lng": "22.33333"
  },
  {
    "country": "RO",
    "name": "Tăut",
    "lat": "46.7199",
    "lng": "21.83845"
  },
  {
    "country": "RO",
    "name": "Tauţ",
    "lat": "46.28333",
    "lng": "21.91667"
  },
  {
    "country": "RO",
    "name": "Tăureni",
    "lat": "46.26667",
    "lng": "25.25"
  },
  {
    "country": "RO",
    "name": "Tătuleşti",
    "lat": "44.63333",
    "lng": "24.63333"
  },
  {
    "country": "RO",
    "name": "Tătăruşi",
    "lat": "47.35",
    "lng": "26.6"
  },
  {
    "country": "RO",
    "name": "Tătaru",
    "lat": "45.1",
    "lng": "26.33333"
  },
  {
    "country": "RO",
    "name": "Tătaru",
    "lat": "44.84482",
    "lng": "27.43376"
  },
  {
    "country": "RO",
    "name": "Tătărăștii de Sus",
    "lat": "44.40768",
    "lng": "25.12192"
  },
  {
    "country": "RO",
    "name": "Tătărăștii de Jos",
    "lat": "44.37501",
    "lng": "25.17721"
  },
  {
    "country": "RO",
    "name": "Tătărăști",
    "lat": "46.21667",
    "lng": "27.2"
  },
  {
    "country": "RO",
    "name": "Tătăranu",
    "lat": "45.51667",
    "lng": "27.31667"
  },
  {
    "country": "RO",
    "name": "Tătărăni",
    "lat": "46.69422",
    "lng": "27.96443"
  },
  {
    "country": "RO",
    "name": "Tătărani",
    "lat": "45",
    "lng": "25.26667"
  },
  {
    "country": "RO",
    "name": "Tătărani",
    "lat": "44.89763",
    "lng": "26.03509"
  },
  {
    "country": "RO",
    "name": "Tăşnad",
    "lat": "47.48333",
    "lng": "22.58333"
  },
  {
    "country": "RO",
    "name": "Taşca",
    "lat": "46.9",
    "lng": "26.01667"
  },
  {
    "country": "RO",
    "name": "Tășad",
    "lat": "46.93773",
    "lng": "22.12516"
  },
  {
    "country": "RO",
    "name": "Tărtăşeşti",
    "lat": "44.57722",
    "lng": "25.81278"
  },
  {
    "country": "RO",
    "name": "Tărlungeni",
    "lat": "45.63333",
    "lng": "25.75"
  },
  {
    "country": "RO",
    "name": "Tariverde",
    "lat": "44.56268",
    "lng": "28.60245"
  },
  {
    "country": "RO",
    "name": "Tăriceni",
    "lat": "44.79624",
    "lng": "25.96958"
  },
  {
    "country": "RO",
    "name": "Tarcea",
    "lat": "47.45",
    "lng": "22.18333"
  },
  {
    "country": "RO",
    "name": "Tarcău",
    "lat": "46.86667",
    "lng": "26.13333"
  },
  {
    "country": "RO",
    "name": "Tărcaia",
    "lat": "46.63333",
    "lng": "22.36667"
  },
  {
    "country": "RO",
    "name": "Tansa",
    "lat": "47.30139",
    "lng": "27.07653"
  },
  {
    "country": "RO",
    "name": "Tansa",
    "lat": "46.91667",
    "lng": "27.23333"
  },
  {
    "country": "RO",
    "name": "Ţăndărei",
    "lat": "44.65",
    "lng": "27.66667"
  },
  {
    "country": "RO",
    "name": "Tănăsoaia",
    "lat": "46.1",
    "lng": "27.36667"
  },
  {
    "country": "RO",
    "name": "Tanacu",
    "lat": "46.68333",
    "lng": "27.81667"
  },
  {
    "country": "RO",
    "name": "Tamaşi",
    "lat": "46.48333",
    "lng": "26.98333"
  },
  {
    "country": "RO",
    "name": "Tamași",
    "lat": "44.58438",
    "lng": "26.00724"
  },
  {
    "country": "RO",
    "name": "Tămășeu",
    "lat": "47.22116",
    "lng": "21.9276"
  },
  {
    "country": "RO",
    "name": "Tămăşeni",
    "lat": "46.98333",
    "lng": "26.93333"
  },
  {
    "country": "RO",
    "name": "Tămașda",
    "lat": "46.64453",
    "lng": "21.55685"
  },
  {
    "country": "RO",
    "name": "Tămădău Mare",
    "lat": "44.46667",
    "lng": "26.55"
  },
  {
    "country": "RO",
    "name": "Talpoș",
    "lat": "46.69124",
    "lng": "21.80335"
  },
  {
    "country": "RO",
    "name": "Tălpigi",
    "lat": "46.00796",
    "lng": "27.47247"
  },
  {
    "country": "RO",
    "name": "Talpa-Trivalea",
    "lat": "44.28333",
    "lng": "25.28333"
  },
  {
    "country": "RO",
    "name": "Tălpaș",
    "lat": "44.68227",
    "lng": "23.74553"
  },
  {
    "country": "RO",
    "name": "Talpa-Ogrăzile",
    "lat": "44.28726",
    "lng": "25.29328"
  },
  {
    "country": "RO",
    "name": "Tălmaciu",
    "lat": "45.66714",
    "lng": "24.26464"
  },
  {
    "country": "RO",
    "name": "Tălmăcel",
    "lat": "45.64712",
    "lng": "24.2427"
  },
  {
    "country": "RO",
    "name": "Talea",
    "lat": "45.22564",
    "lng": "25.56433"
  },
  {
    "country": "RO",
    "name": "Ţaga",
    "lat": "46.95",
    "lng": "24.05"
  },
  {
    "country": "RO",
    "name": "Tăcuta",
    "lat": "46.91667",
    "lng": "27.68333"
  },
  {
    "country": "RO",
    "name": "Tăbărăști",
    "lat": "45.07948",
    "lng": "26.91943"
  },
  {
    "country": "RO",
    "name": "Tabăra",
    "lat": "47.57395",
    "lng": "27.41213"
  },
  {
    "country": "RO",
    "name": "Sviniţa",
    "lat": "44.49972",
    "lng": "22.10611"
  },
  {
    "country": "RO",
    "name": "Sutești",
    "lat": "44.66851",
    "lng": "24.21476"
  },
  {
    "country": "RO",
    "name": "Şuţeşti",
    "lat": "45.21667",
    "lng": "27.43333"
  },
  {
    "country": "RO",
    "name": "Suseni Socetu",
    "lat": "44.75618",
    "lng": "25.79829"
  },
  {
    "country": "RO",
    "name": "Susenii Bârgăului",
    "lat": "47.22311",
    "lng": "24.7073"
  },
  {
    "country": "RO",
    "name": "Suseni",
    "lat": "46.81381",
    "lng": "24.73194"
  },
  {
    "country": "RO",
    "name": "Suseni",
    "lat": "46.66667",
    "lng": "25.55"
  },
  {
    "country": "RO",
    "name": "Suseni",
    "lat": "44.90092",
    "lng": "25.14423"
  },
  {
    "country": "RO",
    "name": "Suseni",
    "lat": "44.71667",
    "lng": "24.95"
  },
  {
    "country": "RO",
    "name": "Şuşani",
    "lat": "44.58333",
    "lng": "24.1"
  },
  {
    "country": "RO",
    "name": "Surdulești",
    "lat": "44.39217",
    "lng": "24.95798"
  },
  {
    "country": "RO",
    "name": "Surduc",
    "lat": "47.25",
    "lng": "23.35"
  },
  {
    "country": "RO",
    "name": "Surdila-Greci",
    "lat": "45.06667",
    "lng": "27.26667"
  },
  {
    "country": "RO",
    "name": "Surdila-Găiseanca",
    "lat": "45.06667",
    "lng": "27.33333"
  },
  {
    "country": "RO",
    "name": "Șurdești",
    "lat": "47.60215",
    "lng": "23.76899"
  },
  {
    "country": "RO",
    "name": "Surani",
    "lat": "45.2",
    "lng": "26.16667"
  },
  {
    "country": "RO",
    "name": "Şura Mică",
    "lat": "45.83333",
    "lng": "24.06667"
  },
  {
    "country": "RO",
    "name": "Şura Mare",
    "lat": "45.85",
    "lng": "24.16667"
  },
  {
    "country": "RO",
    "name": "Suraia",
    "lat": "45.68333",
    "lng": "27.4"
  },
  {
    "country": "RO",
    "name": "Supuru de Jos",
    "lat": "47.46667",
    "lng": "22.8"
  },
  {
    "country": "RO",
    "name": "Suplacu de Barcău",
    "lat": "47.25729",
    "lng": "22.53195"
  },
  {
    "country": "RO",
    "name": "Suplac",
    "lat": "46.38333",
    "lng": "24.51667"
  },
  {
    "country": "RO",
    "name": "Șupitca",
    "lat": "47.60941",
    "lng": "26.78359"
  },
  {
    "country": "RO",
    "name": "Şuncuiuş",
    "lat": "46.93333",
    "lng": "22.53333"
  },
  {
    "country": "RO",
    "name": "Sultana",
    "lat": "44.26062",
    "lng": "26.85424"
  },
  {
    "country": "RO",
    "name": "Sulița",
    "lat": "47.65",
    "lng": "26.91667"
  },
  {
    "country": "RO",
    "name": "Sulina",
    "lat": "45.1559",
    "lng": "29.65356"
  },
  {
    "country": "RO",
    "name": "Şuletea",
    "lat": "46.28333",
    "lng": "27.9"
  },
  {
    "country": "RO",
    "name": "Şuici",
    "lat": "45.25",
    "lng": "24.53333"
  },
  {
    "country": "RO",
    "name": "Suhurlui",
    "lat": "45.72873",
    "lng": "27.82678"
  },
  {
    "country": "RO",
    "name": "Suhuleț",
    "lat": "46.90368",
    "lng": "27.25849"
  },
  {
    "country": "RO",
    "name": "Suharău",
    "lat": "48.13333",
    "lng": "26.41667"
  },
  {
    "country": "RO",
    "name": "Suhaia",
    "lat": "43.73333",
    "lng": "25.25"
  },
  {
    "country": "RO",
    "name": "Şugag",
    "lat": "45.76667",
    "lng": "23.63333"
  },
  {
    "country": "RO",
    "name": "Sudiți",
    "lat": "45.2689",
    "lng": "26.87183"
  },
  {
    "country": "RO",
    "name": "Sudiţi",
    "lat": "44.58333",
    "lng": "27.6"
  },
  {
    "country": "RO",
    "name": "Suciu de Sus",
    "lat": "47.43333",
    "lng": "24.03333"
  },
  {
    "country": "RO",
    "name": "Suciu de Jos",
    "lat": "47.44584",
    "lng": "23.9825"
  },
  {
    "country": "RO",
    "name": "Suceviţa",
    "lat": "47.78333",
    "lng": "25.71667"
  },
  {
    "country": "RO",
    "name": "Suceava",
    "lat": "47.63333",
    "lng": "26.25"
  },
  {
    "country": "RO",
    "name": "Suceagu",
    "lat": "46.78432",
    "lng": "23.46511"
  },
  {
    "country": "RO",
    "name": "Subcetate",
    "lat": "46.85",
    "lng": "25.45"
  },
  {
    "country": "RO",
    "name": "Suatu",
    "lat": "46.76667",
    "lng": "23.96667"
  },
  {
    "country": "RO",
    "name": "Stulpicani",
    "lat": "47.46667",
    "lng": "25.76667"
  },
  {
    "country": "RO",
    "name": "Studinița",
    "lat": "43.97691",
    "lng": "24.42668"
  },
  {
    "country": "RO",
    "name": "Studina",
    "lat": "43.96667",
    "lng": "24.41667"
  },
  {
    "country": "RO",
    "name": "Strunga",
    "lat": "47.16667",
    "lng": "26.98333"
  },
  {
    "country": "RO",
    "name": "Strugari",
    "lat": "46.53333",
    "lng": "26.71667"
  },
  {
    "country": "RO",
    "name": "Stroiești",
    "lat": "47.61042",
    "lng": "26.96562"
  },
  {
    "country": "RO",
    "name": "Stroiești",
    "lat": "47.61667",
    "lng": "26.13333"
  },
  {
    "country": "RO",
    "name": "Stroești",
    "lat": "45.12953",
    "lng": "24.79418"
  },
  {
    "country": "RO",
    "name": "Stroeşti",
    "lat": "45.08333",
    "lng": "23.9"
  },
  {
    "country": "RO",
    "name": "Trestiana",
    "lat": "46.2",
    "lng": "27.65"
  },
  {
    "country": "RO",
    "name": "Strâmtura",
    "lat": "47.78333",
    "lng": "24.13333"
  },
  {
    "country": "RO",
    "name": "Strâmtura",
    "lat": "47.58082",
    "lng": "25.68144"
  },
  {
    "country": "RO",
    "name": "Strâmbeni",
    "lat": "44.46897",
    "lng": "24.97315"
  },
  {
    "country": "RO",
    "name": "Stremţ",
    "lat": "46.21667",
    "lng": "23.63333"
  },
  {
    "country": "RO",
    "name": "Strejnicu",
    "lat": "44.91676",
    "lng": "25.95109"
  },
  {
    "country": "RO",
    "name": "Strejeștii de Sus",
    "lat": "44.54389",
    "lng": "24.22772"
  },
  {
    "country": "RO",
    "name": "Strejeşti",
    "lat": "44.53333",
    "lng": "24.26667"
  },
  {
    "country": "RO",
    "name": "Strehaia",
    "lat": "44.61667",
    "lng": "23.2"
  },
  {
    "country": "RO",
    "name": "Străteni",
    "lat": "47.93677",
    "lng": "26.29664"
  },
  {
    "country": "RO",
    "name": "Străoane",
    "lat": "45.93333",
    "lng": "27.05"
  },
  {
    "country": "RO",
    "name": "Straja",
    "lat": "47.91667",
    "lng": "25.55"
  },
  {
    "country": "RO",
    "name": "Straja",
    "lat": "46.43989",
    "lng": "26.36258"
  },
  {
    "country": "RO",
    "name": "Storobăneasa",
    "lat": "43.88333",
    "lng": "25.45"
  },
  {
    "country": "RO",
    "name": "Stornești",
    "lat": "47.11667",
    "lng": "27.18333"
  },
  {
    "country": "RO",
    "name": "Storeşti",
    "lat": "47.55",
    "lng": "26.86667"
  },
  {
    "country": "RO",
    "name": "Stolnici",
    "lat": "44.56667",
    "lng": "24.78333"
  },
  {
    "country": "RO",
    "name": "Stolniceni-Prăjescu",
    "lat": "47.19858",
    "lng": "26.7481"
  },
  {
    "country": "RO",
    "name": "Stolniceni",
    "lat": "45.03948",
    "lng": "24.3064"
  },
  {
    "country": "RO",
    "name": "Stoina",
    "lat": "44.68333",
    "lng": "23.63333"
  },
  {
    "country": "RO",
    "name": "Stoileşti",
    "lat": "44.9",
    "lng": "24.38333"
  },
  {
    "country": "RO",
    "name": "Stoicăneşti",
    "lat": "44.18333",
    "lng": "24.63333"
  },
  {
    "country": "RO",
    "name": "Stoeneşti",
    "lat": "45.25",
    "lng": "25.16667"
  },
  {
    "country": "RO",
    "name": "Stoeneşti",
    "lat": "45.11667",
    "lng": "24.16667"
  },
  {
    "country": "RO",
    "name": "Stoenești",
    "lat": "44.92422",
    "lng": "25.85881"
  },
  {
    "country": "RO",
    "name": "Stoenești",
    "lat": "44.48569",
    "lng": "25.71196"
  },
  {
    "country": "RO",
    "name": "Stoeneşti",
    "lat": "44.14444",
    "lng": "25.895"
  },
  {
    "country": "RO",
    "name": "Stoeneşti",
    "lat": "44.11667",
    "lng": "24.5"
  },
  {
    "country": "RO",
    "name": "Ştiuca",
    "lat": "45.57139",
    "lng": "21.97667"
  },
  {
    "country": "RO",
    "name": "Ştiubieni",
    "lat": "47.96667",
    "lng": "26.78333"
  },
  {
    "country": "RO",
    "name": "Stârciu",
    "lat": "47.08747",
    "lng": "22.91998"
  },
  {
    "country": "RO",
    "name": "Stângăceaua",
    "lat": "44.60896",
    "lng": "23.31273"
  },
  {
    "country": "RO",
    "name": "Stâncești",
    "lat": "47.75",
    "lng": "26.6"
  },
  {
    "country": "RO",
    "name": "Stânceni",
    "lat": "46.98333",
    "lng": "25.23333"
  },
  {
    "country": "RO",
    "name": "Stânca",
    "lat": "47.23069",
    "lng": "26.13139"
  },
  {
    "country": "RO",
    "name": "Stâna",
    "lat": "47.50757",
    "lng": "22.96423"
  },
  {
    "country": "RO",
    "name": "Stâlpu",
    "lat": "45.08333",
    "lng": "26.71667"
  },
  {
    "country": "RO",
    "name": "Stâlpeni",
    "lat": "45.05",
    "lng": "24.96667"
  },
  {
    "country": "RO",
    "name": "Sticlăria",
    "lat": "47.40115",
    "lng": "26.83797"
  },
  {
    "country": "RO",
    "name": "Sterpoaia",
    "lat": "44.79058",
    "lng": "23.43601"
  },
  {
    "country": "RO",
    "name": "Stelnica",
    "lat": "44.41667",
    "lng": "27.88333"
  },
  {
    "country": "RO",
    "name": "Stejaru",
    "lat": "46.91888",
    "lng": "26.18023"
  },
  {
    "country": "RO",
    "name": "Stejaru",
    "lat": "44.76667",
    "lng": "28.55"
  },
  {
    "country": "RO",
    "name": "Stejaru",
    "lat": "44.18333",
    "lng": "24.88333"
  },
  {
    "country": "RO",
    "name": "Stejari",
    "lat": "44.76667",
    "lng": "23.68333"
  },
  {
    "country": "RO",
    "name": "Steierdorf",
    "lat": "45.06359",
    "lng": "21.85216"
  },
  {
    "country": "RO",
    "name": "Ştefeşti",
    "lat": "45.21667",
    "lng": "25.9"
  },
  {
    "country": "RO",
    "name": "Ştefan Vodă",
    "lat": "44.31667",
    "lng": "27.31667"
  },
  {
    "country": "RO",
    "name": "Ştefăneşti-Sat",
    "lat": "47.78333",
    "lng": "27.18333"
  },
  {
    "country": "RO",
    "name": "Ştefăneştii de Jos",
    "lat": "44.53333",
    "lng": "26.2"
  },
  {
    "country": "RO",
    "name": "Ștefănești",
    "lat": "47.79169",
    "lng": "27.20053"
  },
  {
    "country": "RO",
    "name": "Ştefăneşti",
    "lat": "44.86506",
    "lng": "24.94961"
  },
  {
    "country": "RO",
    "name": "Ştefăneşti",
    "lat": "44.61667",
    "lng": "24.25"
  },
  {
    "country": "RO",
    "name": "Ştefan cel Mare",
    "lat": "46.98482",
    "lng": "26.5107"
  },
  {
    "country": "RO",
    "name": "Ştefan cel Mare",
    "lat": "46.71668",
    "lng": "27.62873"
  },
  {
    "country": "RO",
    "name": "Ștefan cel Mare",
    "lat": "44.42639",
    "lng": "27.64556"
  },
  {
    "country": "RO",
    "name": "Ştefan cel Mare",
    "lat": "44.49283",
    "lng": "25.24418"
  },
  {
    "country": "RO",
    "name": "Ştefan cel Mare",
    "lat": "43.81124",
    "lng": "24.22039"
  },
  {
    "country": "RO",
    "name": "Stăvaru",
    "lat": "43.86445",
    "lng": "24.25902"
  },
  {
    "country": "RO",
    "name": "Stăuceni",
    "lat": "47.71667",
    "lng": "26.75"
  },
  {
    "country": "RO",
    "name": "Starchiojd",
    "lat": "45.31667",
    "lng": "26.18333"
  },
  {
    "country": "RO",
    "name": "Stăniţa",
    "lat": "47.01667",
    "lng": "27.1"
  },
  {
    "country": "RO",
    "name": "Stănişeşti",
    "lat": "46.43333",
    "lng": "27.3"
  },
  {
    "country": "RO",
    "name": "Stănileşti",
    "lat": "46.61833",
    "lng": "28.17139"
  },
  {
    "country": "RO",
    "name": "Stăneşti",
    "lat": "45.11667",
    "lng": "23.25"
  },
  {
    "country": "RO",
    "name": "Stăneşti",
    "lat": "43.91667",
    "lng": "25.83333"
  },
  {
    "country": "RO",
    "name": "Stăncuţa",
    "lat": "44.9",
    "lng": "27.83333"
  },
  {
    "country": "RO",
    "name": "Stăncești",
    "lat": "45.12665",
    "lng": "26.92319"
  },
  {
    "country": "RO",
    "name": "Stancea",
    "lat": "44.1368",
    "lng": "26.81226"
  },
  {
    "country": "RO",
    "name": "Stamate",
    "lat": "47.60598",
    "lng": "26.51698"
  },
  {
    "country": "RO",
    "name": "Spulber",
    "lat": "45.75186",
    "lng": "26.7608"
  },
  {
    "country": "RO",
    "name": "Şpring",
    "lat": "45.96667",
    "lng": "23.78333"
  },
  {
    "country": "RO",
    "name": "Sprâncenata",
    "lat": "44.08333",
    "lng": "24.63333"
  },
  {
    "country": "RO",
    "name": "Spiru Haret",
    "lat": "44.86715",
    "lng": "27.74463"
  },
  {
    "country": "RO",
    "name": "Spinuş",
    "lat": "47.2",
    "lng": "22.2"
  },
  {
    "country": "RO",
    "name": "Spermezeu",
    "lat": "47.3",
    "lng": "24.15"
  },
  {
    "country": "RO",
    "name": "Speriețeni",
    "lat": "44.76611",
    "lng": "25.45223"
  },
  {
    "country": "RO",
    "name": "Spătărei",
    "lat": "43.88848",
    "lng": "25.1365"
  },
  {
    "country": "RO",
    "name": "Spanţov",
    "lat": "44.11667",
    "lng": "26.78333"
  },
  {
    "country": "RO",
    "name": "Sovata",
    "lat": "46.58333",
    "lng": "25.06667"
  },
  {
    "country": "RO",
    "name": "Şovarna",
    "lat": "44.85361",
    "lng": "22.7925"
  },
  {
    "country": "RO",
    "name": "Şotrile",
    "lat": "45.21667",
    "lng": "25.71667"
  },
  {
    "country": "RO",
    "name": "Şotânga",
    "lat": "44.98333",
    "lng": "25.36667"
  },
  {
    "country": "RO",
    "name": "Şopotu Nou",
    "lat": "44.84194",
    "lng": "21.86278"
  },
  {
    "country": "RO",
    "name": "Sopot",
    "lat": "44.41667",
    "lng": "23.5"
  },
  {
    "country": "RO",
    "name": "Soporu de Câmpie",
    "lat": "46.69618",
    "lng": "24.00658"
  },
  {
    "country": "RO",
    "name": "Şopârliţa",
    "lat": "44.28333",
    "lng": "24.28333"
  },
  {
    "country": "RO",
    "name": "Şona",
    "lat": "46.21667",
    "lng": "24.01667"
  },
  {
    "country": "RO",
    "name": "Somușca",
    "lat": "46.40147",
    "lng": "26.91189"
  },
  {
    "country": "RO",
    "name": "Somova",
    "lat": "45.18333",
    "lng": "28.66667"
  },
  {
    "country": "RO",
    "name": "Someş-Odorhei",
    "lat": "47.31667",
    "lng": "23.26667"
  },
  {
    "country": "RO",
    "name": "Şomcuta Mare",
    "lat": "47.51667",
    "lng": "23.46667"
  },
  {
    "country": "RO",
    "name": "Solovăstru",
    "lat": "46.76667",
    "lng": "24.76667"
  },
  {
    "country": "RO",
    "name": "Solonţ",
    "lat": "46.55",
    "lng": "26.51667"
  },
  {
    "country": "RO",
    "name": "Soloneț",
    "lat": "47.68682",
    "lng": "26.03222"
  },
  {
    "country": "RO",
    "name": "Soleşti",
    "lat": "46.76667",
    "lng": "27.78333"
  },
  {
    "country": "RO",
    "name": "Şoldanu",
    "lat": "44.21667",
    "lng": "26.51667"
  },
  {
    "country": "RO",
    "name": "Solca",
    "lat": "47.7",
    "lng": "25.85"
  },
  {
    "country": "RO",
    "name": "Şoimuş",
    "lat": "45.91667",
    "lng": "22.9"
  },
  {
    "country": "RO",
    "name": "Şoimi",
    "lat": "46.68333",
    "lng": "22.11667"
  },
  {
    "country": "RO",
    "name": "Şoimari",
    "lat": "45.18333",
    "lng": "26.2"
  },
  {
    "country": "RO",
    "name": "Sohodol",
    "lat": "45.05531",
    "lng": "22.88194"
  },
  {
    "country": "RO",
    "name": "Sohodol",
    "lat": "46.35581",
    "lng": "23.02923"
  },
  {
    "country": "RO",
    "name": "Sohodol",
    "lat": "45.52829",
    "lng": "25.40244"
  },
  {
    "country": "RO",
    "name": "Sohatu",
    "lat": "44.31667",
    "lng": "26.5"
  },
  {
    "country": "RO",
    "name": "Şofronea",
    "lat": "46.26667",
    "lng": "21.3"
  },
  {
    "country": "RO",
    "name": "Sodomeni",
    "lat": "47.22233",
    "lng": "26.68805"
  },
  {
    "country": "RO",
    "name": "Socond",
    "lat": "47.56667",
    "lng": "22.95"
  },
  {
    "country": "RO",
    "name": "Socol",
    "lat": "44.86083",
    "lng": "21.37028"
  },
  {
    "country": "RO",
    "name": "Socodor",
    "lat": "46.51667",
    "lng": "21.43333"
  },
  {
    "country": "RO",
    "name": "Soci",
    "lat": "47.18573",
    "lng": "26.64446"
  },
  {
    "country": "RO",
    "name": "Socetu",
    "lat": "44.19502",
    "lng": "24.85421"
  },
  {
    "country": "RO",
    "name": "Şoarş",
    "lat": "45.92859",
    "lng": "24.92867"
  },
  {
    "country": "RO",
    "name": "Snagov",
    "lat": "44.7",
    "lng": "26.18333"
  },
  {
    "country": "RO",
    "name": "Smulţi",
    "lat": "45.93333",
    "lng": "27.75"
  },
  {
    "country": "RO",
    "name": "Smirna",
    "lat": "44.72405",
    "lng": "27.35478"
  },
  {
    "country": "RO",
    "name": "Smârdioasa",
    "lat": "43.85",
    "lng": "25.43333"
  },
  {
    "country": "RO",
    "name": "Smârdan",
    "lat": "45.48333",
    "lng": "27.93333"
  },
  {
    "country": "RO",
    "name": "Smârdan",
    "lat": "43.93382",
    "lng": "22.96592"
  },
  {
    "country": "RO",
    "name": "Smeeni",
    "lat": "44.98333",
    "lng": "26.85"
  },
  {
    "country": "RO",
    "name": "Slon",
    "lat": "45.35521",
    "lng": "26.04189"
  },
  {
    "country": "RO",
    "name": "Slobozia Moara",
    "lat": "44.6",
    "lng": "25.71667"
  },
  {
    "country": "RO",
    "name": "Slobozia-Mândra",
    "lat": "43.91667",
    "lng": "24.7"
  },
  {
    "country": "RO",
    "name": "Slobozia Conachi",
    "lat": "45.58333",
    "lng": "27.78333"
  },
  {
    "country": "RO",
    "name": "Slobozia-Ciorăşti",
    "lat": "45.61667",
    "lng": "27.2"
  },
  {
    "country": "RO",
    "name": "Slobozia-Câmpineanca",
    "lat": "45.7",
    "lng": "27.13333"
  },
  {
    "country": "RO",
    "name": "Slobozia Bradului",
    "lat": "45.5",
    "lng": "27.05"
  },
  {
    "country": "RO",
    "name": "Slobozia",
    "lat": "47.4772",
    "lng": "26.88958"
  },
  {
    "country": "RO",
    "name": "Slobozia",
    "lat": "47.05758",
    "lng": "27.41446"
  },
  {
    "country": "RO",
    "name": "Slobozia",
    "lat": "46.84892",
    "lng": "26.53344"
  },
  {
    "country": "RO",
    "name": "Slobozia",
    "lat": "46.47495",
    "lng": "27.31111"
  },
  {
    "country": "RO",
    "name": "Slobozia",
    "lat": "44.52527",
    "lng": "25.24263"
  },
  {
    "country": "RO",
    "name": "Slobozia",
    "lat": "43.85",
    "lng": "25.9"
  },
  {
    "country": "RO",
    "name": "Slivileşti",
    "lat": "44.78333",
    "lng": "23.13333"
  },
  {
    "country": "RO",
    "name": "Slimnic",
    "lat": "45.91667",
    "lng": "24.16667"
  },
  {
    "country": "RO",
    "name": "Slăveni",
    "lat": "44.08558",
    "lng": "24.52843"
  },
  {
    "country": "RO",
    "name": "Slava Rusă",
    "lat": "44.85029",
    "lng": "28.60557"
  },
  {
    "country": "RO",
    "name": "Slava Cercheză",
    "lat": "44.90128",
    "lng": "28.54753"
  },
  {
    "country": "RO",
    "name": "Slătioara",
    "lat": "44.4",
    "lng": "24.31667"
  },
  {
    "country": "RO",
    "name": "Slatina-Timiş",
    "lat": "45.25",
    "lng": "22.28333"
  },
  {
    "country": "RO",
    "name": "Slatina",
    "lat": "47.45",
    "lng": "26.01667"
  },
  {
    "country": "RO",
    "name": "Slatina",
    "lat": "44.43333",
    "lng": "24.36667"
  },
  {
    "country": "RO",
    "name": "Slănic-Moldova",
    "lat": "46.22308",
    "lng": "26.47413"
  },
  {
    "country": "RO",
    "name": "Slănic",
    "lat": "45.25",
    "lng": "25.93333"
  },
  {
    "country": "RO",
    "name": "Slănic",
    "lat": "45.23108",
    "lng": "24.89411"
  },
  {
    "country": "RO",
    "name": "Șivița",
    "lat": "45.61285",
    "lng": "28.05757"
  },
  {
    "country": "RO",
    "name": "Sita Buzăului",
    "lat": "45.65",
    "lng": "26.06667"
  },
  {
    "country": "RO",
    "name": "Şiştarovăţ",
    "lat": "46.01667",
    "lng": "21.73333"
  },
  {
    "country": "RO",
    "name": "Șisești",
    "lat": "47.63506",
    "lng": "23.70794"
  },
  {
    "country": "RO",
    "name": "Şişeşti",
    "lat": "44.7775",
    "lng": "22.83944"
  },
  {
    "country": "RO",
    "name": "Şirna",
    "lat": "44.8",
    "lng": "25.95"
  },
  {
    "country": "RO",
    "name": "Şirineasa",
    "lat": "44.93333",
    "lng": "24.2"
  },
  {
    "country": "RO",
    "name": "Şiria",
    "lat": "46.26667",
    "lng": "21.63333"
  },
  {
    "country": "RO",
    "name": "Sireţel",
    "lat": "47.4",
    "lng": "26.73333"
  },
  {
    "country": "RO",
    "name": "Siret",
    "lat": "47.95",
    "lng": "26.06667"
  },
  {
    "country": "RO",
    "name": "Sârbii-Măgura",
    "lat": "44.55",
    "lng": "24.71667"
  },
  {
    "country": "RO",
    "name": "Sârbi",
    "lat": "47.94268",
    "lng": "26.91818"
  },
  {
    "country": "RO",
    "name": "Sârbi",
    "lat": "47.76184",
    "lng": "23.9449"
  },
  {
    "country": "RO",
    "name": "Sârbi",
    "lat": "47.19315",
    "lng": "22.12215"
  },
  {
    "country": "RO",
    "name": "Sârbeni",
    "lat": "44.46667",
    "lng": "25.38333"
  },
  {
    "country": "RO",
    "name": "Șipotu",
    "lat": "45.04076",
    "lng": "26.01714"
  },
  {
    "country": "RO",
    "name": "Şipote",
    "lat": "47.46667",
    "lng": "27.21667"
  },
  {
    "country": "RO",
    "name": "Sânzieni",
    "lat": "46.05",
    "lng": "26.13333"
  },
  {
    "country": "RO",
    "name": "Sântion",
    "lat": "47.09634",
    "lng": "21.8366"
  },
  {
    "country": "RO",
    "name": "Sântimbru",
    "lat": "46.28126",
    "lng": "25.85439"
  },
  {
    "country": "RO",
    "name": "Sântimbru",
    "lat": "46.13333",
    "lng": "23.65"
  },
  {
    "country": "RO",
    "name": "Şinteu",
    "lat": "47.15",
    "lng": "22.48333"
  },
  {
    "country": "RO",
    "name": "Sintești",
    "lat": "44.30046",
    "lng": "26.12126"
  },
  {
    "country": "RO",
    "name": "Şintereag",
    "lat": "47.18333",
    "lng": "24.3"
  },
  {
    "country": "RO",
    "name": "Sintea Mare",
    "lat": "46.51667",
    "lng": "21.6"
  },
  {
    "country": "RO",
    "name": "Sântandrei",
    "lat": "47.06615",
    "lng": "21.85352"
  },
  {
    "country": "RO",
    "name": "Sântana de Mureş",
    "lat": "46.56667",
    "lng": "24.55"
  },
  {
    "country": "RO",
    "name": "Sântana",
    "lat": "46.35",
    "lng": "21.5"
  },
  {
    "country": "RO",
    "name": "Sântămăria-Orlea",
    "lat": "45.58874",
    "lng": "22.97042"
  },
  {
    "country": "RO",
    "name": "Santa Mare",
    "lat": "47.61667",
    "lng": "27.35"
  },
  {
    "country": "RO",
    "name": "Sânsimion",
    "lat": "46.25",
    "lng": "25.88333"
  },
  {
    "country": "RO",
    "name": "Sânpetru Mare",
    "lat": "46.04515",
    "lng": "20.81834"
  },
  {
    "country": "RO",
    "name": "Sânpetru German",
    "lat": "46.11327",
    "lng": "21.04932"
  },
  {
    "country": "RO",
    "name": "Sânpetru de Câmpie",
    "lat": "46.71589",
    "lng": "24.26243"
  },
  {
    "country": "RO",
    "name": "Sânpetru",
    "lat": "45.71082",
    "lng": "25.63678"
  },
  {
    "country": "RO",
    "name": "Sânpaul",
    "lat": "46.88333",
    "lng": "23.41667"
  },
  {
    "country": "RO",
    "name": "Sânpaul",
    "lat": "46.45",
    "lng": "24.35"
  },
  {
    "country": "RO",
    "name": "Sânnicolau Român",
    "lat": "46.96101",
    "lng": "21.71466"
  },
  {
    "country": "RO",
    "name": "Sânnicolau Mare",
    "lat": "46.08333",
    "lng": "20.63333"
  },
  {
    "country": "RO",
    "name": "Sânnicoară",
    "lat": "46.7899",
    "lng": "23.7257"
  },
  {
    "country": "RO",
    "name": "Sânmihaiu Român",
    "lat": "45.70444",
    "lng": "21.08889"
  },
  {
    "country": "RO",
    "name": "Sânmihaiu de Câmpie",
    "lat": "46.89257",
    "lng": "24.33589"
  },
  {
    "country": "RO",
    "name": "Sânmihaiu Almaşului",
    "lat": "47.01667",
    "lng": "23.3"
  },
  {
    "country": "RO",
    "name": "Sânmărtin",
    "lat": "47.00953",
    "lng": "24.07811"
  },
  {
    "country": "RO",
    "name": "Sînmartin",
    "lat": "47.00726",
    "lng": "21.97418"
  },
  {
    "country": "RO",
    "name": "Sânmărtin",
    "lat": "46.9",
    "lng": "23.56667"
  },
  {
    "country": "RO",
    "name": "Sânmartin",
    "lat": "46.41653",
    "lng": "21.34821"
  },
  {
    "country": "RO",
    "name": "Sânmartin",
    "lat": "46.26667",
    "lng": "25.93333"
  },
  {
    "country": "RO",
    "name": "Sânmărghita",
    "lat": "47.15649",
    "lng": "23.99461"
  },
  {
    "country": "RO",
    "name": "Singureni",
    "lat": "44.23361",
    "lng": "25.94333"
  },
  {
    "country": "RO",
    "name": "Sângeru",
    "lat": "45.13333",
    "lng": "26.35"
  },
  {
    "country": "RO",
    "name": "Sânger",
    "lat": "46.55829",
    "lng": "24.13769"
  },
  {
    "country": "RO",
    "name": "Sângeorz-Băi",
    "lat": "47.3685",
    "lng": "24.67212"
  },
  {
    "country": "RO",
    "name": "Sângeorgiu de Pădure",
    "lat": "46.43061",
    "lng": "24.84274"
  },
  {
    "country": "RO",
    "name": "Sângeorgiu de Mureş",
    "lat": "46.5696",
    "lng": "24.59453"
  },
  {
    "country": "RO",
    "name": "Sineşti",
    "lat": "47.11667",
    "lng": "27.18333"
  },
  {
    "country": "RO",
    "name": "Sineşti",
    "lat": "44.95",
    "lng": "23.85"
  },
  {
    "country": "RO",
    "name": "Sineşti",
    "lat": "44.56667",
    "lng": "26.38333"
  },
  {
    "country": "RO",
    "name": "Sinești",
    "lat": "44.46777",
    "lng": "24.66585"
  },
  {
    "country": "RO",
    "name": "Șindrilari",
    "lat": "45.79083",
    "lng": "26.87947"
  },
  {
    "country": "RO",
    "name": "Sândominic",
    "lat": "46.584",
    "lng": "25.78028"
  },
  {
    "country": "RO",
    "name": "Sâncraiu de Mureş",
    "lat": "46.55119",
    "lng": "24.52663"
  },
  {
    "country": "RO",
    "name": "Sâncraiu",
    "lat": "46.83333",
    "lng": "22.98333"
  },
  {
    "country": "RO",
    "name": "Sâncrai",
    "lat": "46.36667",
    "lng": "25.31667"
  },
  {
    "country": "RO",
    "name": "Sâncrăieni",
    "lat": "46.31439",
    "lng": "25.83941"
  },
  {
    "country": "RO",
    "name": "Sâncrai",
    "lat": "46.29394",
    "lng": "23.75209"
  },
  {
    "country": "RO",
    "name": "Sâncel",
    "lat": "46.2",
    "lng": "23.95"
  },
  {
    "country": "RO",
    "name": "Şinca Veche",
    "lat": "45.76667",
    "lng": "25.16667"
  },
  {
    "country": "RO",
    "name": "Șinca Nouă",
    "lat": "45.69457",
    "lng": "25.24348"
  },
  {
    "country": "RO",
    "name": "Şincai",
    "lat": "46.65",
    "lng": "24.38333"
  },
  {
    "country": "RO",
    "name": "Sânandrei",
    "lat": "45.85306",
    "lng": "21.16806"
  },
  {
    "country": "RO",
    "name": "Sinaia",
    "lat": "45.35",
    "lng": "25.55"
  },
  {
    "country": "RO",
    "name": "Simoneşti",
    "lat": "46.33333",
    "lng": "25.1"
  },
  {
    "country": "RO",
    "name": "Șimon",
    "lat": "45.48484",
    "lng": "25.35664"
  },
  {
    "country": "RO",
    "name": "Şimnicu de Sus",
    "lat": "44.38333",
    "lng": "23.8"
  },
  {
    "country": "RO",
    "name": "Şimleu Silvaniei",
    "lat": "47.23333",
    "lng": "22.8"
  },
  {
    "country": "RO",
    "name": "Șimișna",
    "lat": "47.23202",
    "lng": "23.6237"
  },
  {
    "country": "RO",
    "name": "Siminoc",
    "lat": "44.16866",
    "lng": "28.35277"
  },
  {
    "country": "RO",
    "name": "Siminicea",
    "lat": "47.7",
    "lng": "26.4"
  },
  {
    "country": "RO",
    "name": "Şimian",
    "lat": "47.48333",
    "lng": "22.1"
  },
  {
    "country": "RO",
    "name": "Şimian",
    "lat": "44.61417",
    "lng": "22.70722"
  },
  {
    "country": "RO",
    "name": "Simeria",
    "lat": "45.85",
    "lng": "23.01667"
  },
  {
    "country": "RO",
    "name": "Sâmbureşti",
    "lat": "44.8",
    "lng": "24.41667"
  },
  {
    "country": "RO",
    "name": "Sâmbotin",
    "lat": "45.13333",
    "lng": "23.33333"
  },
  {
    "country": "RO",
    "name": "Sâmbăteni",
    "lat": "46.1411",
    "lng": "21.52689"
  },
  {
    "country": "RO",
    "name": "Sâmbăta de Sus",
    "lat": "45.76178",
    "lng": "24.82053"
  },
  {
    "country": "RO",
    "name": "Sâmbăta",
    "lat": "46.80173",
    "lng": "22.20357"
  },
  {
    "country": "RO",
    "name": "Şimand",
    "lat": "46.43333",
    "lng": "21.45"
  },
  {
    "country": "RO",
    "name": "Silivașu de Câmpie",
    "lat": "46.78333",
    "lng": "24.3"
  },
  {
    "country": "RO",
    "name": "Siliștea Snagovului",
    "lat": "44.7392",
    "lng": "26.17942"
  },
  {
    "country": "RO",
    "name": "Siliștea Gumești",
    "lat": "44.38333",
    "lng": "25"
  },
  {
    "country": "RO",
    "name": "Siliştea Crucii",
    "lat": "44.03333",
    "lng": "23.48333"
  },
  {
    "country": "RO",
    "name": "Siliștea",
    "lat": "46.77781",
    "lng": "26.69303"
  },
  {
    "country": "RO",
    "name": "Siliştea",
    "lat": "45.3",
    "lng": "27.85"
  },
  {
    "country": "RO",
    "name": "Siliştea",
    "lat": "44.4",
    "lng": "28.16667"
  },
  {
    "country": "RO",
    "name": "Siliştea",
    "lat": "44.38333",
    "lng": "25.35"
  },
  {
    "country": "RO",
    "name": "Șilindru",
    "lat": "47.43725",
    "lng": "22.04683"
  },
  {
    "country": "RO",
    "name": "Şilindia",
    "lat": "46.35",
    "lng": "21.91667"
  },
  {
    "country": "RO",
    "name": "Sihlea",
    "lat": "45.5",
    "lng": "27.11667"
  },
  {
    "country": "RO",
    "name": "Sighetu Marmaţiei",
    "lat": "47.93195",
    "lng": "23.88603"
  },
  {
    "country": "RO",
    "name": "Sâg",
    "lat": "47.07545",
    "lng": "22.78084"
  },
  {
    "country": "RO",
    "name": "Şieuţ",
    "lat": "46.98333",
    "lng": "24.65"
  },
  {
    "country": "RO",
    "name": "Şieu-Odorhei",
    "lat": "47.15194",
    "lng": "24.29159"
  },
  {
    "country": "RO",
    "name": "Şieu-Măgheruş",
    "lat": "47.08333",
    "lng": "24.38333"
  },
  {
    "country": "RO",
    "name": "Șieu",
    "lat": "47.72462",
    "lng": "24.22389"
  },
  {
    "country": "RO",
    "name": "Şieu",
    "lat": "47.01667",
    "lng": "24.6"
  },
  {
    "country": "RO",
    "name": "Siculeni",
    "lat": "46.41667",
    "lng": "25.75"
  },
  {
    "country": "RO",
    "name": "Şicula",
    "lat": "46.43333",
    "lng": "21.75"
  },
  {
    "country": "RO",
    "name": "Șiclău",
    "lat": "46.49124",
    "lng": "21.36834"
  },
  {
    "country": "RO",
    "name": "Sicheviţa",
    "lat": "44.735",
    "lng": "21.84861"
  },
  {
    "country": "RO",
    "name": "Sic",
    "lat": "46.93333",
    "lng": "23.88333"
  },
  {
    "country": "RO",
    "name": "Şibot",
    "lat": "45.95",
    "lng": "23.33333"
  },
  {
    "country": "RO",
    "name": "Sibiu",
    "lat": "45.8",
    "lng": "24.15"
  },
  {
    "country": "RO",
    "name": "Sfârcea",
    "lat": "44.48613",
    "lng": "23.54661"
  },
  {
    "country": "RO",
    "name": "Sfântu Gheorghe",
    "lat": "45.86667",
    "lng": "25.78333"
  },
  {
    "country": "RO",
    "name": "Sfântu Gheorghe",
    "lat": "44.88333",
    "lng": "29.6"
  },
  {
    "country": "RO",
    "name": "Sfântu Gheorghe",
    "lat": "44.65",
    "lng": "26.83333"
  },
  {
    "country": "RO",
    "name": "Sfinţeşti",
    "lat": "44.18333",
    "lng": "25.1"
  },
  {
    "country": "RO",
    "name": "Serdanu",
    "lat": "44.62732",
    "lng": "25.63124"
  },
  {
    "country": "RO",
    "name": "Şercaia",
    "lat": "45.83333",
    "lng": "25.13333"
  },
  {
    "country": "RO",
    "name": "Șerboeni",
    "lat": "44.63818",
    "lng": "24.89355"
  },
  {
    "country": "RO",
    "name": "Șerbăuți",
    "lat": "47.82684",
    "lng": "26.14009"
  },
  {
    "country": "RO",
    "name": "Ștefan Vodă",
    "lat": "46.31692",
    "lng": "26.5125"
  },
  {
    "country": "RO",
    "name": "Șerbănești",
    "lat": "47.81014",
    "lng": "26.31922"
  },
  {
    "country": "RO",
    "name": "Șerbănești",
    "lat": "44.68142",
    "lng": "24.99236"
  },
  {
    "country": "RO",
    "name": "Şerbăneşti",
    "lat": "44.33333",
    "lng": "24.7"
  },
  {
    "country": "RO",
    "name": "Șepreuș",
    "lat": "46.57125",
    "lng": "21.73417"
  },
  {
    "country": "RO",
    "name": "Şendriceni",
    "lat": "47.95",
    "lng": "26.3"
  },
  {
    "country": "RO",
    "name": "Şendreni",
    "lat": "45.4",
    "lng": "27.91667"
  },
  {
    "country": "RO",
    "name": "Semlac",
    "lat": "46.11667",
    "lng": "20.93333"
  },
  {
    "country": "RO",
    "name": "Şelimbăr",
    "lat": "45.76667",
    "lng": "24.2"
  },
  {
    "country": "RO",
    "name": "Seleuș",
    "lat": "46.24261",
    "lng": "24.69427"
  },
  {
    "country": "RO",
    "name": "Seleuş",
    "lat": "46.38333",
    "lng": "21.71667"
  },
  {
    "country": "RO",
    "name": "Şelaru",
    "lat": "44.47667",
    "lng": "25.29997"
  },
  {
    "country": "RO",
    "name": "Şeitin",
    "lat": "46.1",
    "lng": "20.85"
  },
  {
    "country": "RO",
    "name": "Seini",
    "lat": "47.75",
    "lng": "23.28333"
  },
  {
    "country": "RO",
    "name": "Seimeni",
    "lat": "44.38333",
    "lng": "28.06667"
  },
  {
    "country": "RO",
    "name": "Şeica Mică",
    "lat": "46.05",
    "lng": "24.13333"
  },
  {
    "country": "RO",
    "name": "Şeíca Mare",
    "lat": "46.01667",
    "lng": "24.15"
  },
  {
    "country": "RO",
    "name": "Segarcea Vale",
    "lat": "43.81667",
    "lng": "24.8"
  },
  {
    "country": "RO",
    "name": "Segarcea-Deal",
    "lat": "43.82548",
    "lng": "24.8402"
  },
  {
    "country": "RO",
    "name": "Segarcea",
    "lat": "44.1",
    "lng": "23.75"
  },
  {
    "country": "RO",
    "name": "Secusigiu",
    "lat": "46.08333",
    "lng": "20.98333"
  },
  {
    "country": "RO",
    "name": "Secui",
    "lat": "44.19186",
    "lng": "23.86319"
  },
  {
    "country": "RO",
    "name": "Secuieni",
    "lat": "46.65",
    "lng": "27.1"
  },
  {
    "country": "RO",
    "name": "Secuieni",
    "lat": "46.85",
    "lng": "26.83333"
  },
  {
    "country": "RO",
    "name": "Secu",
    "lat": "44.46667",
    "lng": "23.3"
  },
  {
    "country": "RO",
    "name": "Seciu",
    "lat": "45.03275",
    "lng": "26.06474"
  },
  {
    "country": "RO",
    "name": "Secaş",
    "lat": "45.885",
    "lng": "21.81917"
  },
  {
    "country": "RO",
    "name": "Secăria",
    "lat": "45.28333",
    "lng": "25.68333"
  },
  {
    "country": "RO",
    "name": "Sebiş",
    "lat": "46.36667",
    "lng": "22.11667"
  },
  {
    "country": "RO",
    "name": "Sebeșel",
    "lat": "45.88771",
    "lng": "23.56606"
  },
  {
    "country": "RO",
    "name": "Sebeş",
    "lat": "45.95646",
    "lng": "23.571"
  },
  {
    "country": "RO",
    "name": "Seaca de Pădure",
    "lat": "44.36611",
    "lng": "23.30587"
  },
  {
    "country": "RO",
    "name": "Seaca de Câmp",
    "lat": "43.93333",
    "lng": "23.21667"
  },
  {
    "country": "RO",
    "name": "Seaca",
    "lat": "44.16667",
    "lng": "24.75"
  },
  {
    "country": "RO",
    "name": "Seaca",
    "lat": "43.75",
    "lng": "25.06667"
  },
  {
    "country": "RO",
    "name": "Scutelnici",
    "lat": "44.85",
    "lng": "26.91667"
  },
  {
    "country": "RO",
    "name": "Scurtu Mare",
    "lat": "44.35",
    "lng": "25.26667"
  },
  {
    "country": "RO",
    "name": "Scurtești",
    "lat": "45.23759",
    "lng": "25.90264"
  },
  {
    "country": "RO",
    "name": "Scurtești",
    "lat": "45.13829",
    "lng": "26.90397"
  },
  {
    "country": "RO",
    "name": "Scurta",
    "lat": "46.26133",
    "lng": "27.01548"
  },
  {
    "country": "RO",
    "name": "Scundu",
    "lat": "44.83333",
    "lng": "24.2"
  },
  {
    "country": "RO",
    "name": "Sculia",
    "lat": "45.44429",
    "lng": "21.43225"
  },
  {
    "country": "RO",
    "name": "Scrioaştea",
    "lat": "44.15",
    "lng": "24.95"
  },
  {
    "country": "RO",
    "name": "Scorţoasa",
    "lat": "45.36403",
    "lng": "26.66116"
  },
  {
    "country": "RO",
    "name": "Scorţeni",
    "lat": "46.55",
    "lng": "26.65"
  },
  {
    "country": "RO",
    "name": "Scorţeni",
    "lat": "45.1",
    "lng": "25.85"
  },
  {
    "country": "RO",
    "name": "Scorțaru Vechi",
    "lat": "45.21886",
    "lng": "27.75489"
  },
  {
    "country": "RO",
    "name": "Scorţaru Nou",
    "lat": "45.31667",
    "lng": "27.6"
  },
  {
    "country": "RO",
    "name": "Scorniceşti",
    "lat": "44.56667",
    "lng": "24.55"
  },
  {
    "country": "RO",
    "name": "Scobinţi",
    "lat": "47.38333",
    "lng": "26.93333"
  },
  {
    "country": "RO",
    "name": "Scoarţa",
    "lat": "45.01667",
    "lng": "23.45"
  },
  {
    "country": "RO",
    "name": "Scânteia",
    "lat": "46.91667",
    "lng": "27.56667"
  },
  {
    "country": "RO",
    "name": "Scânteia",
    "lat": "44.73404",
    "lng": "27.46593"
  },
  {
    "country": "RO",
    "name": "Scânteiești",
    "lat": "45.68333",
    "lng": "27.98333"
  },
  {
    "country": "RO",
    "name": "Schiulești",
    "lat": "45.28471",
    "lng": "25.95403"
  },
  {
    "country": "RO",
    "name": "Schitu-Goleşti",
    "lat": "45.2",
    "lng": "25"
  },
  {
    "country": "RO",
    "name": "Schitu Frumoasa",
    "lat": "46.63541",
    "lng": "26.48761"
  },
  {
    "country": "RO",
    "name": "Schitu-Duca",
    "lat": "47.03333",
    "lng": "27.76667"
  },
  {
    "country": "RO",
    "name": "Schitu",
    "lat": "44.35",
    "lng": "24.56667"
  },
  {
    "country": "RO",
    "name": "Schitu",
    "lat": "44.14083",
    "lng": "25.83667"
  },
  {
    "country": "RO",
    "name": "Schitu",
    "lat": "43.94279",
    "lng": "28.62829"
  },
  {
    "country": "RO",
    "name": "Văleni",
    "lat": "46.59278",
    "lng": "28.0625"
  },
  {
    "country": "RO",
    "name": "Schela",
    "lat": "45.5",
    "lng": "27.81667"
  },
  {
    "country": "RO",
    "name": "Scheiu de Sus",
    "lat": "44.95602",
    "lng": "25.19317"
  },
  {
    "country": "RO",
    "name": "Scheiu de Jos",
    "lat": "44.9346",
    "lng": "25.19986"
  },
  {
    "country": "RO",
    "name": "Scheia",
    "lat": "47.65",
    "lng": "26.23333"
  },
  {
    "country": "RO",
    "name": "Scheia",
    "lat": "47.11725",
    "lng": "26.88153"
  },
  {
    "country": "RO",
    "name": "Şcheia",
    "lat": "46.93333",
    "lng": "27.51667"
  },
  {
    "country": "RO",
    "name": "Scărişoara",
    "lat": "46.46667",
    "lng": "22.85"
  },
  {
    "country": "RO",
    "name": "Scărişoara",
    "lat": "44",
    "lng": "24.56667"
  },
  {
    "country": "RO",
    "name": "Scăeşti",
    "lat": "44.46667",
    "lng": "23.58333"
  },
  {
    "country": "RO",
    "name": "Săvârşin",
    "lat": "46.01667",
    "lng": "22.23333"
  },
  {
    "country": "RO",
    "name": "Săvineşti",
    "lat": "46.85",
    "lng": "26.46667"
  },
  {
    "country": "RO",
    "name": "Săveni",
    "lat": "47.95",
    "lng": "26.86667"
  },
  {
    "country": "RO",
    "name": "Săveni",
    "lat": "44.6",
    "lng": "27.65"
  },
  {
    "country": "RO",
    "name": "Săvădisla",
    "lat": "46.68333",
    "lng": "23.45"
  },
  {
    "country": "RO",
    "name": "Şăulia",
    "lat": "46.63333",
    "lng": "24.21667"
  },
  {
    "country": "RO",
    "name": "Săuleşti",
    "lat": "44.8",
    "lng": "23.48333"
  },
  {
    "country": "RO",
    "name": "Săucești",
    "lat": "46.61853",
    "lng": "26.94141"
  },
  {
    "country": "RO",
    "name": "Săuca",
    "lat": "47.46667",
    "lng": "22.48333"
  },
  {
    "country": "RO",
    "name": "Sauca",
    "lat": "46.65268",
    "lng": "27.60523"
  },
  {
    "country": "RO",
    "name": "Sat-Șugatag",
    "lat": "47.79796",
    "lng": "23.90637"
  },
  {
    "country": "RO",
    "name": "Satu Nou Calopăr",
    "lat": "44.16667",
    "lng": "23.76667"
  },
  {
    "country": "RO",
    "name": "Satu Nou",
    "lat": "47.32147",
    "lng": "27.09555"
  },
  {
    "country": "RO",
    "name": "Satu Nou",
    "lat": "46.69608",
    "lng": "27.74876"
  },
  {
    "country": "RO",
    "name": "Satu Nou",
    "lat": "46.35806",
    "lng": "28.15"
  },
  {
    "country": "RO",
    "name": "Satu Nou",
    "lat": "46.24447",
    "lng": "26.65343"
  },
  {
    "country": "RO",
    "name": "Satu Nou",
    "lat": "44.26918",
    "lng": "28.22579"
  },
  {
    "country": "RO",
    "name": "Satu Mare",
    "lat": "47.83333",
    "lng": "26.01667"
  },
  {
    "country": "RO",
    "name": "Satu Mare",
    "lat": "47.79926",
    "lng": "22.86255"
  },
  {
    "country": "RO",
    "name": "Satu Mare",
    "lat": "46.34082",
    "lng": "25.38378"
  },
  {
    "country": "RO",
    "name": "Satu Mare",
    "lat": "46.06628",
    "lng": "20.95826"
  },
  {
    "country": "RO",
    "name": "Satulung",
    "lat": "47.56667",
    "lng": "23.43333"
  },
  {
    "country": "RO",
    "name": "Sătmărel",
    "lat": "47.7347",
    "lng": "22.79536"
  },
  {
    "country": "RO",
    "name": "Săteni",
    "lat": "44.97129",
    "lng": "25.41683"
  },
  {
    "country": "RO",
    "name": "Satchinez",
    "lat": "45.9375",
    "lng": "21.04056"
  },
  {
    "country": "RO",
    "name": "Sălcioara",
    "lat": "44.76667",
    "lng": "28.88333"
  },
  {
    "country": "RO",
    "name": "Sascut-Sat",
    "lat": "46.18727",
    "lng": "27.06851"
  },
  {
    "country": "RO",
    "name": "Sascut",
    "lat": "46.2",
    "lng": "27.1"
  },
  {
    "country": "RO",
    "name": "Săsciori",
    "lat": "45.86667",
    "lng": "23.58333"
  },
  {
    "country": "RO",
    "name": "Saschiz",
    "lat": "46.18333",
    "lng": "24.96667"
  },
  {
    "country": "RO",
    "name": "Sasca Montană",
    "lat": "44.88546",
    "lng": "21.70915"
  },
  {
    "country": "RO",
    "name": "Săsar",
    "lat": "47.64406",
    "lng": "23.49869"
  },
  {
    "country": "RO",
    "name": "Sărulești-Gară",
    "lat": "44.44444",
    "lng": "26.6578"
  },
  {
    "country": "RO",
    "name": "Săruleşti",
    "lat": "45.5",
    "lng": "26.75"
  },
  {
    "country": "RO",
    "name": "Săruleşti",
    "lat": "44.41667",
    "lng": "26.65"
  },
  {
    "country": "RO",
    "name": "Şaru Dornei",
    "lat": "47.28333",
    "lng": "25.35"
  },
  {
    "country": "RO",
    "name": "Șaroș pe Târnave",
    "lat": "46.2",
    "lng": "24.55"
  },
  {
    "country": "RO",
    "name": "Sarmizegetusa",
    "lat": "45.51667",
    "lng": "22.78333"
  },
  {
    "country": "RO",
    "name": "Sărmaşu",
    "lat": "46.75",
    "lng": "24.16667"
  },
  {
    "country": "RO",
    "name": "Şărmăşag",
    "lat": "47.35",
    "lng": "22.83333"
  },
  {
    "country": "RO",
    "name": "Sărmaş",
    "lat": "46.88333",
    "lng": "25.46667"
  },
  {
    "country": "RO",
    "name": "Sarichioi",
    "lat": "44.95",
    "lng": "28.85"
  },
  {
    "country": "RO",
    "name": "Șard",
    "lat": "46.12814",
    "lng": "23.5352"
  },
  {
    "country": "RO",
    "name": "Saravale",
    "lat": "46.06929",
    "lng": "20.74085"
  },
  {
    "country": "RO",
    "name": "Sărăuad",
    "lat": "47.47944",
    "lng": "22.62559"
  },
  {
    "country": "RO",
    "name": "Sărățeni",
    "lat": "46.56247",
    "lng": "25.01331"
  },
  {
    "country": "RO",
    "name": "Sărățeni",
    "lat": "44.63422",
    "lng": "26.92686"
  },
  {
    "country": "RO",
    "name": "Sărata",
    "lat": "46.50249",
    "lng": "26.86857"
  },
  {
    "country": "RO",
    "name": "Sărata",
    "lat": "43.77436",
    "lng": "24.03351"
  },
  {
    "country": "RO",
    "name": "Sarasău",
    "lat": "47.9551",
    "lng": "23.82874"
  },
  {
    "country": "RO",
    "name": "Saraiu",
    "lat": "44.71667",
    "lng": "28.15"
  },
  {
    "country": "RO",
    "name": "Sarafinești",
    "lat": "47.61708",
    "lng": "26.6074"
  },
  {
    "country": "RO",
    "name": "Săpunari",
    "lat": "44.50141",
    "lng": "26.83665"
  },
  {
    "country": "RO",
    "name": "Săpoca",
    "lat": "45.25",
    "lng": "26.75"
  },
  {
    "country": "RO",
    "name": "Săpânţa",
    "lat": "47.96667",
    "lng": "23.7"
  },
  {
    "country": "RO",
    "name": "Santău",
    "lat": "47.51667",
    "lng": "22.51667"
  },
  {
    "country": "RO",
    "name": "Șanț",
    "lat": "47.45",
    "lng": "24.9"
  },
  {
    "country": "RO",
    "name": "Sanislău",
    "lat": "47.63333",
    "lng": "22.33333"
  },
  {
    "country": "RO",
    "name": "Sănduleşti",
    "lat": "46.58333",
    "lng": "23.71667"
  },
  {
    "country": "RO",
    "name": "Sănduleni",
    "lat": "46.45",
    "lng": "26.73333"
  },
  {
    "country": "RO",
    "name": "Şandra",
    "lat": "45.925",
    "lng": "20.89028"
  },
  {
    "country": "RO",
    "name": "Şamşud",
    "lat": "47.35",
    "lng": "22.95"
  },
  {
    "country": "RO",
    "name": "Samarineşti",
    "lat": "44.75",
    "lng": "23.05"
  },
  {
    "country": "RO",
    "name": "Salva",
    "lat": "47.3",
    "lng": "24.35"
  },
  {
    "country": "RO",
    "name": "Sălsig",
    "lat": "47.53333",
    "lng": "23.3"
  },
  {
    "country": "RO",
    "name": "Salonta",
    "lat": "46.8",
    "lng": "21.65"
  },
  {
    "country": "RO",
    "name": "Săliştea de Sus",
    "lat": "47.65",
    "lng": "24.35"
  },
  {
    "country": "RO",
    "name": "Săliştea-Deal",
    "lat": "45.9",
    "lng": "23.4"
  },
  {
    "country": "RO",
    "name": "Săliștea",
    "lat": "45.90744",
    "lng": "23.39789"
  },
  {
    "country": "RO",
    "name": "Sălişte",
    "lat": "45.79633",
    "lng": "23.88677"
  },
  {
    "country": "RO",
    "name": "Saligny",
    "lat": "44.28111",
    "lng": "28.09092"
  },
  {
    "country": "RO",
    "name": "Sălcuța",
    "lat": "44.64374",
    "lng": "25.58103"
  },
  {
    "country": "RO",
    "name": "Sălcuţa",
    "lat": "44.25",
    "lng": "23.43333"
  },
  {
    "country": "RO",
    "name": "Sălcuța",
    "lat": "44.15986",
    "lng": "23.70247"
  },
  {
    "country": "RO",
    "name": "Sălciua de Sus",
    "lat": "46.4",
    "lng": "23.41667"
  },
  {
    "country": "RO",
    "name": "Sălcioara",
    "lat": "45.30874",
    "lng": "27.17692"
  },
  {
    "country": "RO",
    "name": "Sălcioara",
    "lat": "44.71667",
    "lng": "25.58333"
  },
  {
    "country": "RO",
    "name": "Sălcioara",
    "lat": "44.53333",
    "lng": "26.88333"
  },
  {
    "country": "RO",
    "name": "Sălciile",
    "lat": "44.81667",
    "lng": "26.48333"
  },
  {
    "country": "RO",
    "name": "Salcia Tudor",
    "lat": "45.36667",
    "lng": "27.51667"
  },
  {
    "country": "RO",
    "name": "Salcia",
    "lat": "45.18333",
    "lng": "26.33333"
  },
  {
    "country": "RO",
    "name": "Salcia",
    "lat": "44.48195",
    "lng": "23.44645"
  },
  {
    "country": "RO",
    "name": "Salcia",
    "lat": "44.14083",
    "lng": "22.92778"
  },
  {
    "country": "RO",
    "name": "Salcia",
    "lat": "43.95",
    "lng": "24.91667"
  },
  {
    "country": "RO",
    "name": "Salcea",
    "lat": "47.65",
    "lng": "26.36667"
  },
  {
    "country": "RO",
    "name": "Sălătrucu",
    "lat": "45.33333",
    "lng": "24.51667"
  },
  {
    "country": "RO",
    "name": "Sălătrucel",
    "lat": "45.25",
    "lng": "24.38333"
  },
  {
    "country": "RO",
    "name": "Sălăţig",
    "lat": "47.36667",
    "lng": "23.13333"
  },
  {
    "country": "RO",
    "name": "Sălaşu de Sus",
    "lat": "45.51667",
    "lng": "22.95"
  },
  {
    "country": "RO",
    "name": "Sălard",
    "lat": "47.21667",
    "lng": "22.05"
  },
  {
    "country": "RO",
    "name": "Sălacea",
    "lat": "47.46667",
    "lng": "22.31667"
  },
  {
    "country": "RO",
    "name": "Săhăteni",
    "lat": "45.03333",
    "lng": "26.51667"
  },
  {
    "country": "RO",
    "name": "Şagu",
    "lat": "46.05",
    "lng": "21.28333"
  },
  {
    "country": "RO",
    "name": "Sagna",
    "lat": "46.98333",
    "lng": "27.01667"
  },
  {
    "country": "RO",
    "name": "Săgeata",
    "lat": "45.1",
    "lng": "26.98333"
  },
  {
    "country": "RO",
    "name": "Şag",
    "lat": "45.64861",
    "lng": "21.17556"
  },
  {
    "country": "RO",
    "name": "Șaeș",
    "lat": "46.15638",
    "lng": "24.76894"
  },
  {
    "country": "RO",
    "name": "Saelele",
    "lat": "43.85577",
    "lng": "24.72789"
  },
  {
    "country": "RO",
    "name": "Sadu",
    "lat": "45.66667",
    "lng": "24.18333"
  },
  {
    "country": "RO",
    "name": "Sadova",
    "lat": "47.53333",
    "lng": "25.5"
  },
  {
    "country": "RO",
    "name": "Sadova",
    "lat": "43.9",
    "lng": "23.95"
  },
  {
    "country": "RO",
    "name": "Sadina",
    "lat": "44.41143",
    "lng": "25.52953"
  },
  {
    "country": "RO",
    "name": "Săcuieu",
    "lat": "46.82335",
    "lng": "22.88824"
  },
  {
    "country": "RO",
    "name": "Săcueni",
    "lat": "47.35",
    "lng": "22.1"
  },
  {
    "country": "RO",
    "name": "Săcueni",
    "lat": "44.91077",
    "lng": "25.57223"
  },
  {
    "country": "RO",
    "name": "Sacu",
    "lat": "45.56667",
    "lng": "22.11667"
  },
  {
    "country": "RO",
    "name": "Sacoşu Turcesc",
    "lat": "45.65194",
    "lng": "21.42889"
  },
  {
    "country": "RO",
    "name": "Sacoșu Mare",
    "lat": "45.58503",
    "lng": "21.72958"
  },
  {
    "country": "RO",
    "name": "Săceni",
    "lat": "44.23333",
    "lng": "25.06667"
  },
  {
    "country": "RO",
    "name": "Săcelu",
    "lat": "45.1",
    "lng": "23.53333"
  },
  {
    "country": "RO",
    "name": "Săcele",
    "lat": "45.61674",
    "lng": "25.71101"
  },
  {
    "country": "RO",
    "name": "Săcele",
    "lat": "44.48333",
    "lng": "28.65"
  },
  {
    "country": "RO",
    "name": "Săcel",
    "lat": "47.63333",
    "lng": "24.43333"
  },
  {
    "country": "RO",
    "name": "Săcel",
    "lat": "46.3",
    "lng": "24.93333"
  },
  {
    "country": "RO",
    "name": "Săcăşeni",
    "lat": "47.48333",
    "lng": "22.68333"
  },
  {
    "country": "RO",
    "name": "Săcălaz",
    "lat": "45.75833",
    "lng": "21.11222"
  },
  {
    "country": "RO",
    "name": "Săcălășeni",
    "lat": "47.5818",
    "lng": "23.56432"
  },
  {
    "country": "RO",
    "name": "Săcădat",
    "lat": "47.03333",
    "lng": "22.15"
  },
  {
    "country": "RO",
    "name": "Sabasa",
    "lat": "47.20174",
    "lng": "25.8176"
  },
  {
    "country": "RO",
    "name": "Săbăreni",
    "lat": "44.50185",
    "lng": "25.8882"
  },
  {
    "country": "RO",
    "name": "Săbăoani",
    "lat": "47.01667",
    "lng": "26.85"
  },
  {
    "country": "RO",
    "name": "Ruşii Munţi",
    "lat": "46.91667",
    "lng": "24.85"
  },
  {
    "country": "RO",
    "name": "Ruşeţu",
    "lat": "44.95",
    "lng": "27.21667"
  },
  {
    "country": "RO",
    "name": "Ruseni",
    "lat": "46.79841",
    "lng": "26.53943"
  },
  {
    "country": "RO",
    "name": "Ruscova",
    "lat": "47.79289",
    "lng": "24.28546"
  },
  {
    "country": "RO",
    "name": "Rusca Montană",
    "lat": "45.56741",
    "lng": "22.45816"
  },
  {
    "country": "RO",
    "name": "Rusca",
    "lat": "45.14517",
    "lng": "22.33859"
  },
  {
    "country": "RO",
    "name": "Rusăneşti",
    "lat": "43.93333",
    "lng": "24.6"
  },
  {
    "country": "RO",
    "name": "Rus",
    "lat": "47.28333",
    "lng": "23.6"
  },
  {
    "country": "RO",
    "name": "Rupea",
    "lat": "46.03333",
    "lng": "25.21667"
  },
  {
    "country": "RO",
    "name": "Runcu Salvei",
    "lat": "47.34382",
    "lng": "24.32529"
  },
  {
    "country": "RO",
    "name": "Runcu",
    "lat": "45.18333",
    "lng": "25.38333"
  },
  {
    "country": "RO",
    "name": "Runcu",
    "lat": "45.16667",
    "lng": "24.45"
  },
  {
    "country": "RO",
    "name": "Runcu",
    "lat": "45.11667",
    "lng": "23.13333"
  },
  {
    "country": "RO",
    "name": "Ruja",
    "lat": "46.01175",
    "lng": "24.65048"
  },
  {
    "country": "RO",
    "name": "Ruginoasa",
    "lat": "47.25",
    "lng": "26.85"
  },
  {
    "country": "RO",
    "name": "Ruginoasa",
    "lat": "46.98622",
    "lng": "26.70635"
  },
  {
    "country": "RO",
    "name": "Rugineşti",
    "lat": "46.06667",
    "lng": "27.11667"
  },
  {
    "country": "RO",
    "name": "Rugășești",
    "lat": "47.23147",
    "lng": "23.87326"
  },
  {
    "country": "RO",
    "name": "Rudeni",
    "lat": "44.47242",
    "lng": "25.97325"
  },
  {
    "country": "RO",
    "name": "Rucăreni",
    "lat": "45.99438",
    "lng": "26.65496"
  },
  {
    "country": "RO",
    "name": "Rucăr",
    "lat": "45.4",
    "lng": "25.16667"
  },
  {
    "country": "RO",
    "name": "Rubla",
    "lat": "45.353",
    "lng": "27.07525"
  },
  {
    "country": "RO",
    "name": "Roznov",
    "lat": "46.83333",
    "lng": "26.51667"
  },
  {
    "country": "RO",
    "name": "Rozavlea",
    "lat": "47.73333",
    "lng": "24.21667"
  },
  {
    "country": "RO",
    "name": "Pecica",
    "lat": "46.16667",
    "lng": "21.06667"
  },
  {
    "country": "RO",
    "name": "Rovine",
    "lat": "44.6954",
    "lng": "27.09364"
  },
  {
    "country": "RO",
    "name": "Rovinari",
    "lat": "44.91667",
    "lng": "23.18333"
  },
  {
    "country": "RO",
    "name": "Rotunda",
    "lat": "47.48745",
    "lng": "26.52466"
  },
  {
    "country": "RO",
    "name": "Rotunda",
    "lat": "47.0221",
    "lng": "26.96266"
  },
  {
    "country": "RO",
    "name": "Rotunda",
    "lat": "43.98333",
    "lng": "24.31667"
  },
  {
    "country": "RO",
    "name": "Roșu",
    "lat": "44.45025",
    "lng": "26.01122"
  },
  {
    "country": "RO",
    "name": "Roșiorii de Vede",
    "lat": "44.11667",
    "lng": "24.98333"
  },
  {
    "country": "RO",
    "name": "Roșiori",
    "lat": "47.76095",
    "lng": "26.72167"
  },
  {
    "country": "RO",
    "name": "Roșiori",
    "lat": "47.25677",
    "lng": "21.95209"
  },
  {
    "country": "RO",
    "name": "Roşiori",
    "lat": "46.71667",
    "lng": "27.08333"
  },
  {
    "country": "RO",
    "name": "Roşiori",
    "lat": "44.8",
    "lng": "27.38333"
  },
  {
    "country": "RO",
    "name": "Roșiori",
    "lat": "44.61265",
    "lng": "26.53496"
  },
  {
    "country": "RO",
    "name": "Roșiori",
    "lat": "44.25633",
    "lng": "22.92838"
  },
  {
    "country": "RO",
    "name": "Roşiile",
    "lat": "44.86667",
    "lng": "23.93333"
  },
  {
    "country": "RO",
    "name": "Roşieşti",
    "lat": "46.43333",
    "lng": "27.88333"
  },
  {
    "country": "RO",
    "name": "Roșia Montană",
    "lat": "46.30669",
    "lng": "23.13373"
  },
  {
    "country": "RO",
    "name": "Roşia de Secaş",
    "lat": "46.05",
    "lng": "23.88333"
  },
  {
    "country": "RO",
    "name": "Roşia de Amaradia",
    "lat": "45.05",
    "lng": "23.75"
  },
  {
    "country": "RO",
    "name": "Roşia",
    "lat": "46.8",
    "lng": "22.4"
  },
  {
    "country": "RO",
    "name": "Roşia",
    "lat": "45.81667",
    "lng": "24.31667"
  },
  {
    "country": "RO",
    "name": "Roseţi",
    "lat": "44.21482",
    "lng": "27.44848"
  },
  {
    "country": "RO",
    "name": "Roșcani",
    "lat": "47.53346",
    "lng": "26.54909"
  },
  {
    "country": "RO",
    "name": "Roșcani",
    "lat": "47.45581",
    "lng": "27.40021"
  },
  {
    "country": "RO",
    "name": "Rona de Sus",
    "lat": "47.9",
    "lng": "24.05"
  },
  {
    "country": "RO",
    "name": "Rona de Jos",
    "lat": "47.91667",
    "lng": "24.01667"
  },
  {
    "country": "RO",
    "name": "Romuli",
    "lat": "47.53333",
    "lng": "24.43333"
  },
  {
    "country": "RO",
    "name": "Romos",
    "lat": "45.83333",
    "lng": "23.28333"
  },
  {
    "country": "RO",
    "name": "Români",
    "lat": "46.78333",
    "lng": "26.68333"
  },
  {
    "country": "RO",
    "name": "Româneşti",
    "lat": "47.28333",
    "lng": "27.31667"
  },
  {
    "country": "RO",
    "name": "Românești",
    "lat": "44.86667",
    "lng": "26.06667"
  },
  {
    "country": "RO",
    "name": "Românești",
    "lat": "44.56667",
    "lng": "25.61667"
  },
  {
    "country": "RO",
    "name": "Românaşi",
    "lat": "47.1",
    "lng": "23.18333"
  },
  {
    "country": "RO",
    "name": "Romanu",
    "lat": "45.28333",
    "lng": "27.73333"
  },
  {
    "country": "RO",
    "name": "Români",
    "lat": "44.9731",
    "lng": "24.20513"
  },
  {
    "country": "RO",
    "name": "Românești",
    "lat": "47.73141",
    "lng": "27.24027"
  },
  {
    "country": "RO",
    "name": "Roman",
    "lat": "46.92119",
    "lng": "26.92646"
  },
  {
    "country": "RO",
    "name": "Roma",
    "lat": "47.83333",
    "lng": "26.6"
  },
  {
    "country": "RO",
    "name": "Rojiște",
    "lat": "44.06683",
    "lng": "23.93898"
  },
  {
    "country": "RO",
    "name": "Rogoz",
    "lat": "47.46749",
    "lng": "23.93214"
  },
  {
    "country": "RO",
    "name": "Rogova",
    "lat": "44.47167",
    "lng": "22.80667"
  },
  {
    "country": "RO",
    "name": "Roeşti",
    "lat": "44.91667",
    "lng": "24.08333"
  },
  {
    "country": "RO",
    "name": "Rodna",
    "lat": "47.41667",
    "lng": "24.81667"
  },
  {
    "country": "RO",
    "name": "Rociu",
    "lat": "44.66667",
    "lng": "25.03333"
  },
  {
    "country": "RO",
    "name": "Robeasca",
    "lat": "45.16667",
    "lng": "27.13333"
  },
  {
    "country": "RO",
    "name": "Roata de Jos",
    "lat": "44.41083",
    "lng": "25.54333"
  },
  {
    "country": "RO",
    "name": "Râu Sadului",
    "lat": "45.61667",
    "lng": "24.06667"
  },
  {
    "country": "RO",
    "name": "Râu de Mori",
    "lat": "45.48333",
    "lng": "22.85"
  },
  {
    "country": "RO",
    "name": "Râu Alb de Jos",
    "lat": "45.13653",
    "lng": "25.34745"
  },
  {
    "country": "RO",
    "name": "Râşnov",
    "lat": "45.58333",
    "lng": "25.45"
  },
  {
    "country": "RO",
    "name": "Râșești",
    "lat": "46.77219",
    "lng": "28.14273"
  },
  {
    "country": "RO",
    "name": "Râşca",
    "lat": "47.36667",
    "lng": "26.23333"
  },
  {
    "country": "RO",
    "name": "Râșca",
    "lat": "46.73967",
    "lng": "23.10625"
  },
  {
    "country": "RO",
    "name": "Ripiceni",
    "lat": "47.95",
    "lng": "27.13333"
  },
  {
    "country": "RO",
    "name": "Rânzești",
    "lat": "46.22101",
    "lng": "28.09468"
  },
  {
    "country": "RO",
    "name": "Râncăciov",
    "lat": "44.88872",
    "lng": "25.35778"
  },
  {
    "country": "RO",
    "name": "Râmnicu Vâlcea",
    "lat": "45.1",
    "lng": "24.36667"
  },
  {
    "country": "RO",
    "name": "Râmnicu Sărat",
    "lat": "45.38333",
    "lng": "27.05"
  },
  {
    "country": "RO",
    "name": "Râmniceni",
    "lat": "45.51322",
    "lng": "27.44843"
  },
  {
    "country": "RO",
    "name": "Râmnicelu",
    "lat": "45.36381",
    "lng": "27.11121"
  },
  {
    "country": "RO",
    "name": "Râmnicelu",
    "lat": "45.28333",
    "lng": "27.53333"
  },
  {
    "country": "RO",
    "name": "Rimetea",
    "lat": "46.45",
    "lng": "23.56667"
  },
  {
    "country": "RO",
    "name": "Râmești",
    "lat": "44.56667",
    "lng": "24.1"
  },
  {
    "country": "RO",
    "name": "Râfov",
    "lat": "44.86667",
    "lng": "26.13333"
  },
  {
    "country": "RO",
    "name": "Rieni",
    "lat": "46.57485",
    "lng": "22.44584"
  },
  {
    "country": "RO",
    "name": "Râciu",
    "lat": "46.68333",
    "lng": "24.4"
  },
  {
    "country": "RO",
    "name": "Râca",
    "lat": "44.43426",
    "lng": "25.04333"
  },
  {
    "country": "RO",
    "name": "Ribiţa",
    "lat": "46.18333",
    "lng": "22.76667"
  },
  {
    "country": "RO",
    "name": "Reviga",
    "lat": "44.71667",
    "lng": "27.1"
  },
  {
    "country": "RO",
    "name": "Retevoiești",
    "lat": "45.14016",
    "lng": "24.83797"
  },
  {
    "country": "RO",
    "name": "Reteag",
    "lat": "47.19582",
    "lng": "24.01862"
  },
  {
    "country": "RO",
    "name": "Reşiţa",
    "lat": "45.30083",
    "lng": "21.88917"
  },
  {
    "country": "RO",
    "name": "Repedea",
    "lat": "47.83333",
    "lng": "24.4"
  },
  {
    "country": "RO",
    "name": "Remuș",
    "lat": "43.94295",
    "lng": "25.98039"
  },
  {
    "country": "RO",
    "name": "Remeţi",
    "lat": "47.98333",
    "lng": "23.63333"
  },
  {
    "country": "RO",
    "name": "Remetea Mare",
    "lat": "45.77944",
    "lng": "21.37611"
  },
  {
    "country": "RO",
    "name": "Remetea Chioarului",
    "lat": "47.53333",
    "lng": "23.55"
  },
  {
    "country": "RO",
    "name": "Remetea",
    "lat": "46.78333",
    "lng": "25.45"
  },
  {
    "country": "RO",
    "name": "Remetea",
    "lat": "46.73333",
    "lng": "22.35"
  },
  {
    "country": "RO",
    "name": "Remetea",
    "lat": "46.57432",
    "lng": "24.51359"
  },
  {
    "country": "RO",
    "name": "Reghiu",
    "lat": "45.78333",
    "lng": "26.83333"
  },
  {
    "country": "RO",
    "name": "Reghin-Sat",
    "lat": "46.78333",
    "lng": "24.71667"
  },
  {
    "country": "RO",
    "name": "Reghin",
    "lat": "46.7742",
    "lng": "24.70216"
  },
  {
    "country": "RO",
    "name": "Rediu",
    "lat": "46.63374",
    "lng": "27.69439"
  },
  {
    "country": "RO",
    "name": "Rediu",
    "lat": "48.23075",
    "lng": "26.77841"
  },
  {
    "country": "RO",
    "name": "Rediu",
    "lat": "47.24033",
    "lng": "26.86406"
  },
  {
    "country": "RO",
    "name": "Rediu",
    "lat": "47.21667",
    "lng": "27.5"
  },
  {
    "country": "RO",
    "name": "Rediu",
    "lat": "46.75598",
    "lng": "26.56254"
  },
  {
    "country": "RO",
    "name": "Rediu",
    "lat": "45.71667",
    "lng": "27.83333"
  },
  {
    "country": "RO",
    "name": "Redea",
    "lat": "44.05",
    "lng": "24.3"
  },
  {
    "country": "RO",
    "name": "Reci",
    "lat": "45.85",
    "lng": "25.93333"
  },
  {
    "country": "RO",
    "name": "Recea Cristur",
    "lat": "47.06667",
    "lng": "23.53333"
  },
  {
    "country": "RO",
    "name": "Recea",
    "lat": "47.63333",
    "lng": "23.51667"
  },
  {
    "country": "RO",
    "name": "Recea",
    "lat": "45.71334",
    "lng": "24.93152"
  },
  {
    "country": "RO",
    "name": "Recea",
    "lat": "44.53333",
    "lng": "25.01667"
  },
  {
    "country": "RO",
    "name": "Recea",
    "lat": "44.31949",
    "lng": "22.91659"
  },
  {
    "country": "RO",
    "name": "Recaş",
    "lat": "45.79889",
    "lng": "21.50083"
  },
  {
    "country": "RO",
    "name": "Rebrişoara",
    "lat": "47.28333",
    "lng": "24.45"
  },
  {
    "country": "RO",
    "name": "Rebricea",
    "lat": "46.86667",
    "lng": "27.55"
  },
  {
    "country": "RO",
    "name": "Rebra",
    "lat": "47.31667",
    "lng": "24.5"
  },
  {
    "country": "RO",
    "name": "Răzvani",
    "lat": "44.42114",
    "lng": "26.88092"
  },
  {
    "country": "RO",
    "name": "Răzvad",
    "lat": "44.93333",
    "lng": "25.53333"
  },
  {
    "country": "RO",
    "name": "Războienii de Jos",
    "lat": "47.06887",
    "lng": "26.56374"
  },
  {
    "country": "RO",
    "name": "Războieni-Cetate",
    "lat": "46.41335",
    "lng": "23.87158"
  },
  {
    "country": "RO",
    "name": "Războieni",
    "lat": "47.21754",
    "lng": "27.05039"
  },
  {
    "country": "RO",
    "name": "Răuseni",
    "lat": "47.56667",
    "lng": "27.2"
  },
  {
    "country": "RO",
    "name": "Răuceşti",
    "lat": "47.25",
    "lng": "26.41667"
  },
  {
    "country": "RO",
    "name": "Răteşti",
    "lat": "44.73333",
    "lng": "25.13333"
  },
  {
    "country": "RO",
    "name": "Răsuceni",
    "lat": "44.09167",
    "lng": "25.66389"
  },
  {
    "country": "RO",
    "name": "Rast",
    "lat": "43.88333",
    "lng": "23.28333"
  },
  {
    "country": "RO",
    "name": "Răstoliţa",
    "lat": "46.97258",
    "lng": "24.99287"
  },
  {
    "country": "RO",
    "name": "Răstoaca",
    "lat": "45.66083",
    "lng": "27.28723"
  },
  {
    "country": "RO",
    "name": "Rasova",
    "lat": "44.25",
    "lng": "27.93333"
  },
  {
    "country": "RO",
    "name": "Răsmireşti",
    "lat": "43.98333",
    "lng": "25.55"
  },
  {
    "country": "RO",
    "name": "Răşinari",
    "lat": "45.7",
    "lng": "24.06667"
  },
  {
    "country": "RO",
    "name": "Rași",
    "lat": "44.53534",
    "lng": "26.92485"
  },
  {
    "country": "RO",
    "name": "Răscruci",
    "lat": "46.90569",
    "lng": "23.7686"
  },
  {
    "country": "RO",
    "name": "Răscăeți",
    "lat": "44.59221",
    "lng": "25.2699"
  },
  {
    "country": "RO",
    "name": "Rasa",
    "lat": "44.21404",
    "lng": "27.14717"
  },
  {
    "country": "RO",
    "name": "Rapoltu Mare",
    "lat": "45.86667",
    "lng": "23.06667"
  },
  {
    "country": "RO",
    "name": "Răpănaşu",
    "lat": "47.38333",
    "lng": "24.18333"
  },
  {
    "country": "RO",
    "name": "Ramna",
    "lat": "45.43833",
    "lng": "21.68833"
  },
  {
    "country": "RO",
    "name": "Rafaila",
    "lat": "46.80064",
    "lng": "27.36236"
  },
  {
    "country": "RO",
    "name": "Radu Vodă",
    "lat": "44.38563",
    "lng": "26.92541"
  },
  {
    "country": "RO",
    "name": "Răducăneni",
    "lat": "46.95",
    "lng": "27.93333"
  },
  {
    "country": "RO",
    "name": "Radovanu",
    "lat": "44.2",
    "lng": "26.51667"
  },
  {
    "country": "RO",
    "name": "Radovan",
    "lat": "44.16667",
    "lng": "23.61667"
  },
  {
    "country": "RO",
    "name": "Radomir",
    "lat": "44.12115",
    "lng": "24.16832"
  },
  {
    "country": "RO",
    "name": "Radomireşti",
    "lat": "44.11667",
    "lng": "24.68333"
  },
  {
    "country": "RO",
    "name": "Rădoiești-Deal",
    "lat": "44.15",
    "lng": "25.13333"
  },
  {
    "country": "RO",
    "name": "Radna",
    "lat": "46.09444",
    "lng": "21.68732"
  },
  {
    "country": "RO",
    "name": "Rădeşti",
    "lat": "46.26667",
    "lng": "23.71667"
  },
  {
    "country": "RO",
    "name": "Rădești",
    "lat": "46.07263",
    "lng": "27.78936"
  },
  {
    "country": "RO",
    "name": "Rădești",
    "lat": "45.07184",
    "lng": "25.00207"
  },
  {
    "country": "RO",
    "name": "Rădeni",
    "lat": "47.51186",
    "lng": "26.89249"
  },
  {
    "country": "RO",
    "name": "Rădeni",
    "lat": "47.1426",
    "lng": "26.53703"
  },
  {
    "country": "RO",
    "name": "Rădăuți-Prut",
    "lat": "48.23333",
    "lng": "26.8"
  },
  {
    "country": "RO",
    "name": "Rădăuți",
    "lat": "47.85",
    "lng": "25.91667"
  },
  {
    "country": "RO",
    "name": "Rădăşeni",
    "lat": "47.46667",
    "lng": "26.25"
  },
  {
    "country": "RO",
    "name": "Racu",
    "lat": "46.45178",
    "lng": "25.7606"
  },
  {
    "country": "RO",
    "name": "Racşa",
    "lat": "47.82068",
    "lng": "23.33247"
  },
  {
    "country": "RO",
    "name": "Racoviţeni",
    "lat": "45.36667",
    "lng": "26.9"
  },
  {
    "country": "RO",
    "name": "Racoviţa",
    "lat": "45.69833",
    "lng": "21.63583"
  },
  {
    "country": "RO",
    "name": "Racoviţa",
    "lat": "45.68333",
    "lng": "24.35"
  },
  {
    "country": "RO",
    "name": "Racoviţa",
    "lat": "45.41667",
    "lng": "24.31667"
  },
  {
    "country": "RO",
    "name": "Racoviţa",
    "lat": "45.3",
    "lng": "27.45"
  },
  {
    "country": "RO",
    "name": "Racovița",
    "lat": "44.97081",
    "lng": "24.97582"
  },
  {
    "country": "RO",
    "name": "Racovița",
    "lat": "44.83927",
    "lng": "25.62082"
  },
  {
    "country": "RO",
    "name": "Racova",
    "lat": "46.7",
    "lng": "26.75"
  },
  {
    "country": "RO",
    "name": "Răcoasa",
    "lat": "46",
    "lng": "26.88333"
  },
  {
    "country": "RO",
    "name": "Raciu",
    "lat": "44.81791",
    "lng": "25.44106"
  },
  {
    "country": "RO",
    "name": "Gârlenii de Sus",
    "lat": "46.65414",
    "lng": "26.79491"
  },
  {
    "country": "RO",
    "name": "Răchitova",
    "lat": "45.6",
    "lng": "22.75"
  },
  {
    "country": "RO",
    "name": "Răchitoasa",
    "lat": "46.43333",
    "lng": "27.36667"
  },
  {
    "country": "RO",
    "name": "Răchiţi",
    "lat": "47.76667",
    "lng": "26.68333"
  },
  {
    "country": "RO",
    "name": "Răchiteni",
    "lat": "47.05347",
    "lng": "26.9173"
  },
  {
    "country": "RO",
    "name": "Răchita",
    "lat": "45.83827",
    "lng": "22.10615"
  },
  {
    "country": "RO",
    "name": "Rachieri",
    "lat": "44.95438",
    "lng": "26.12841"
  },
  {
    "country": "RO",
    "name": "Rachelu",
    "lat": "45.28667",
    "lng": "28.32349"
  },
  {
    "country": "RO",
    "name": "Răcăuți",
    "lat": "46.22476",
    "lng": "26.78723"
  },
  {
    "country": "RO",
    "name": "Răcăşdia",
    "lat": "44.99306",
    "lng": "21.61806"
  },
  {
    "country": "RO",
    "name": "Răcarii de Sus",
    "lat": "44.53539",
    "lng": "23.55746"
  },
  {
    "country": "RO",
    "name": "Răcari",
    "lat": "44.63333",
    "lng": "25.73333"
  },
  {
    "country": "RO",
    "name": "Răcăciuni",
    "lat": "46.33333",
    "lng": "26.98333"
  },
  {
    "country": "RO",
    "name": "Răbăgani",
    "lat": "46.75",
    "lng": "22.23333"
  },
  {
    "country": "RO",
    "name": "Puțuri",
    "lat": "44.13835",
    "lng": "24.01017"
  },
  {
    "country": "RO",
    "name": "Putna",
    "lat": "47.86667",
    "lng": "25.61667"
  },
  {
    "country": "RO",
    "name": "Putineiu",
    "lat": "43.9",
    "lng": "25.73333"
  },
  {
    "country": "RO",
    "name": "Putineiu",
    "lat": "43.9",
    "lng": "24.96667"
  },
  {
    "country": "RO",
    "name": "Pustiana",
    "lat": "46.5899",
    "lng": "26.63083"
  },
  {
    "country": "RO",
    "name": "Pusta",
    "lat": "47.24596",
    "lng": "22.72374"
  },
  {
    "country": "RO",
    "name": "Pușcași",
    "lat": "46.62154",
    "lng": "27.64503"
  },
  {
    "country": "RO",
    "name": "Purcăreni",
    "lat": "45.64476",
    "lng": "25.79129"
  },
  {
    "country": "RO",
    "name": "Purcăreni",
    "lat": "44.96847",
    "lng": "24.88736"
  },
  {
    "country": "RO",
    "name": "Stănești",
    "lat": "44.81667",
    "lng": "24.05"
  },
  {
    "country": "RO",
    "name": "Purani",
    "lat": "44.36125",
    "lng": "25.42528"
  },
  {
    "country": "RO",
    "name": "Purani",
    "lat": "43.97989",
    "lng": "25.43656"
  },
  {
    "country": "RO",
    "name": "Punghina",
    "lat": "44.28194",
    "lng": "22.93472"
  },
  {
    "country": "RO",
    "name": "Pungeşti",
    "lat": "46.7",
    "lng": "27.33333"
  },
  {
    "country": "RO",
    "name": "Puieşti",
    "lat": "46.41667",
    "lng": "27.5"
  },
  {
    "country": "RO",
    "name": "Pui",
    "lat": "45.51667",
    "lng": "23.1"
  },
  {
    "country": "RO",
    "name": "Pufeşti",
    "lat": "46",
    "lng": "27.2"
  },
  {
    "country": "RO",
    "name": "Puieștii de Jos",
    "lat": "45.40267",
    "lng": "27.22013"
  },
  {
    "country": "RO",
    "name": "Puieni",
    "lat": "44.07675",
    "lng": "26.19114"
  },
  {
    "country": "RO",
    "name": "Pucioasa",
    "lat": "45.07807",
    "lng": "25.43232"
  },
  {
    "country": "RO",
    "name": "Puchenii Moșneni",
    "lat": "44.81213",
    "lng": "26.08701"
  },
  {
    "country": "RO",
    "name": "Puchenii Mari",
    "lat": "44.81667",
    "lng": "26.08333"
  },
  {
    "country": "RO",
    "name": "Pucheni",
    "lat": "45.18333",
    "lng": "25.28333"
  },
  {
    "country": "RO",
    "name": "Prunişor",
    "lat": "44.60944",
    "lng": "22.91528"
  },
  {
    "country": "RO",
    "name": "Prundu Bârgăului",
    "lat": "47.21975",
    "lng": "24.74123"
  },
  {
    "country": "RO",
    "name": "Prundu",
    "lat": "44.09472",
    "lng": "26.22694"
  },
  {
    "country": "RO",
    "name": "Prundu",
    "lat": "43.82394",
    "lng": "24.69196"
  },
  {
    "country": "RO",
    "name": "Prundeni",
    "lat": "44.73333",
    "lng": "24.26667"
  },
  {
    "country": "RO",
    "name": "Proviţa de Sus",
    "lat": "45.13333",
    "lng": "25.63333"
  },
  {
    "country": "RO",
    "name": "Proviţa de Jos",
    "lat": "45.11667",
    "lng": "25.65"
  },
  {
    "country": "RO",
    "name": "Prohozești",
    "lat": "46.48155",
    "lng": "26.5517"
  },
  {
    "country": "RO",
    "name": "Progresu",
    "lat": "44.35886",
    "lng": "26.4611"
  },
  {
    "country": "RO",
    "name": "Produleşti",
    "lat": "44.7",
    "lng": "25.5"
  },
  {
    "country": "RO",
    "name": "Probota",
    "lat": "47.37584",
    "lng": "26.62415"
  },
  {
    "country": "RO",
    "name": "Probota",
    "lat": "47.38333",
    "lng": "27.5"
  },
  {
    "country": "RO",
    "name": "Pristol",
    "lat": "44.22472",
    "lng": "22.70917"
  },
  {
    "country": "RO",
    "name": "Priseaca",
    "lat": "44.51667",
    "lng": "24.45"
  },
  {
    "country": "RO",
    "name": "Prisăcani",
    "lat": "47.08333",
    "lng": "27.88333"
  },
  {
    "country": "RO",
    "name": "Priponeşti",
    "lat": "46.08333",
    "lng": "27.43333"
  },
  {
    "country": "RO",
    "name": "Prigoria",
    "lat": "45.06667",
    "lng": "23.68333"
  },
  {
    "country": "RO",
    "name": "Prigor",
    "lat": "44.93833",
    "lng": "22.11333"
  },
  {
    "country": "RO",
    "name": "Pricaz",
    "lat": "45.85929",
    "lng": "23.17266"
  },
  {
    "country": "RO",
    "name": "Priboiu",
    "lat": "45.03006",
    "lng": "25.2579"
  },
  {
    "country": "RO",
    "name": "Priboieni",
    "lat": "44.88333",
    "lng": "25.08333"
  },
  {
    "country": "RO",
    "name": "Pribești",
    "lat": "46.91001",
    "lng": "27.79659"
  },
  {
    "country": "RO",
    "name": "Preuteşti",
    "lat": "47.45",
    "lng": "26.41667"
  },
  {
    "country": "RO",
    "name": "Prelipca",
    "lat": "47.61085",
    "lng": "26.35414"
  },
  {
    "country": "RO",
    "name": "Prejmer",
    "lat": "45.71667",
    "lng": "25.76667"
  },
  {
    "country": "RO",
    "name": "Predeşti",
    "lat": "44.35",
    "lng": "23.6"
  },
  {
    "country": "RO",
    "name": "Predeal",
    "lat": "45.5",
    "lng": "25.56667"
  },
  {
    "country": "RO",
    "name": "Preajba",
    "lat": "44.26511",
    "lng": "23.85024"
  },
  {
    "country": "RO",
    "name": "Prapor",
    "lat": "43.94487",
    "lng": "24.17475"
  },
  {
    "country": "RO",
    "name": "Prajila",
    "lat": "45.0827",
    "lng": "24.16949"
  },
  {
    "country": "RO",
    "name": "Prăjești",
    "lat": "46.65469",
    "lng": "26.97631"
  },
  {
    "country": "RO",
    "name": "Prăjeni",
    "lat": "47.51667",
    "lng": "27.01667"
  },
  {
    "country": "RO",
    "name": "Prăjani",
    "lat": "45.20422",
    "lng": "25.95151"
  },
  {
    "country": "RO",
    "name": "Praid",
    "lat": "46.55",
    "lng": "25.13333"
  },
  {
    "country": "RO",
    "name": "Potoceni",
    "lat": "45.1966",
    "lng": "26.77649"
  },
  {
    "country": "RO",
    "name": "Potlogi",
    "lat": "44.55",
    "lng": "25.58333"
  },
  {
    "country": "RO",
    "name": "Potlogeni",
    "lat": "43.87995",
    "lng": "24.63092"
  },
  {
    "country": "RO",
    "name": "Potigrafu",
    "lat": "44.78504",
    "lng": "26.10014"
  },
  {
    "country": "RO",
    "name": "Potelu",
    "lat": "43.76577",
    "lng": "24.20535"
  },
  {
    "country": "RO",
    "name": "Potcoava Fălcoeni",
    "lat": "44.49484",
    "lng": "24.6165"
  },
  {
    "country": "RO",
    "name": "Potcoava",
    "lat": "44.48333",
    "lng": "24.65"
  },
  {
    "country": "RO",
    "name": "Potcoava",
    "lat": "44.26332",
    "lng": "27.13223"
  },
  {
    "country": "RO",
    "name": "Potău",
    "lat": "47.75673",
    "lng": "23.1209"
  },
  {
    "country": "RO",
    "name": "Poşta Câlnău",
    "lat": "45.23333",
    "lng": "26.85"
  },
  {
    "country": "RO",
    "name": "Poseștii-Pământeni",
    "lat": "45.26667",
    "lng": "26.15"
  },
  {
    "country": "RO",
    "name": "Poşaga de Sus",
    "lat": "46.46667",
    "lng": "23.38333"
  },
  {
    "country": "RO",
    "name": "Posada",
    "lat": "45.28714",
    "lng": "25.61882"
  },
  {
    "country": "RO",
    "name": "Porumbești",
    "lat": "47.98305",
    "lng": "22.98076"
  },
  {
    "country": "RO",
    "name": "Porumbenii Mari",
    "lat": "46.27549",
    "lng": "25.1362"
  },
  {
    "country": "RO",
    "name": "Porumbacu de Jos",
    "lat": "45.75",
    "lng": "24.45"
  },
  {
    "country": "RO",
    "name": "Poroschia",
    "lat": "43.93333",
    "lng": "25.36667"
  },
  {
    "country": "RO",
    "name": "Poroina Mare",
    "lat": "44.49528",
    "lng": "22.93639"
  },
  {
    "country": "RO",
    "name": "Popricani",
    "lat": "47.3",
    "lng": "27.51667"
  },
  {
    "country": "RO",
    "name": "Popoveni",
    "lat": "44.288",
    "lng": "23.78208"
  },
  {
    "country": "RO",
    "name": "Poporogi",
    "lat": "44.36667",
    "lng": "25.18333"
  },
  {
    "country": "RO",
    "name": "Poplaca",
    "lat": "45.71667",
    "lng": "24.05"
  },
  {
    "country": "RO",
    "name": "Popeşti-Leordeni",
    "lat": "44.38333",
    "lng": "26.16667"
  },
  {
    "country": "RO",
    "name": "Popeşti",
    "lat": "47.23333",
    "lng": "22.41667"
  },
  {
    "country": "RO",
    "name": "Popeşti",
    "lat": "47.15",
    "lng": "27.23333"
  },
  {
    "country": "RO",
    "name": "Popești",
    "lat": "45.59533",
    "lng": "27.07916"
  },
  {
    "country": "RO",
    "name": "Popeşti",
    "lat": "44.98333",
    "lng": "24.1"
  },
  {
    "country": "RO",
    "name": "Popești",
    "lat": "44.86076",
    "lng": "25.99557"
  },
  {
    "country": "RO",
    "name": "Popeşti",
    "lat": "44.76667",
    "lng": "25.06667"
  },
  {
    "country": "RO",
    "name": "Popeşti",
    "lat": "44.44181",
    "lng": "25.10007"
  },
  {
    "country": "RO",
    "name": "Popești",
    "lat": "44.30444",
    "lng": "25.9637"
  },
  {
    "country": "RO",
    "name": "Popeni",
    "lat": "46.24667",
    "lng": "27.8052"
  },
  {
    "country": "RO",
    "name": "Ponor",
    "lat": "46.33333",
    "lng": "23.41667"
  },
  {
    "country": "RO",
    "name": "Ponoarele",
    "lat": "44.97389",
    "lng": "22.76444"
  },
  {
    "country": "RO",
    "name": "Pomârla",
    "lat": "48.06667",
    "lng": "26.31667"
  },
  {
    "country": "RO",
    "name": "Pomi",
    "lat": "47.7",
    "lng": "23.31667"
  },
  {
    "country": "RO",
    "name": "Pomezeu",
    "lat": "46.78333",
    "lng": "22.28333"
  },
  {
    "country": "RO",
    "name": "Polovragi",
    "lat": "45.18333",
    "lng": "23.8"
  },
  {
    "country": "RO",
    "name": "Poloboc",
    "lat": "46.76109",
    "lng": "26.54975"
  },
  {
    "country": "RO",
    "name": "Pojorâta",
    "lat": "47.51667",
    "lng": "25.45"
  },
  {
    "country": "RO",
    "name": "Pojogeni",
    "lat": "44.99119",
    "lng": "23.48425"
  },
  {
    "country": "RO",
    "name": "Pojejena",
    "lat": "44.77417",
    "lng": "21.57917"
  },
  {
    "country": "RO",
    "name": "Poienile-Mogoş",
    "lat": "46.28333",
    "lng": "23.28333"
  },
  {
    "country": "RO",
    "name": "Poienile Izei",
    "lat": "47.7",
    "lng": "24.11667"
  },
  {
    "country": "RO",
    "name": "Poienile de sub Munte",
    "lat": "47.81667",
    "lng": "24.43333"
  },
  {
    "country": "RO",
    "name": "Poienile",
    "lat": "46.93333",
    "lng": "27.18333"
  },
  {
    "country": "RO",
    "name": "Poieneşti",
    "lat": "46.61667",
    "lng": "27.53333"
  },
  {
    "country": "RO",
    "name": "Poienari",
    "lat": "46.88777",
    "lng": "27.12765"
  },
  {
    "country": "RO",
    "name": "Poiana Vadului",
    "lat": "46.4",
    "lng": "22.88333"
  },
  {
    "country": "RO",
    "name": "Poiana Teiului",
    "lat": "47.1",
    "lng": "25.96667"
  },
  {
    "country": "RO",
    "name": "Poiana Țapului",
    "lat": "45.39344",
    "lng": "25.54066"
  },
  {
    "country": "RO",
    "name": "Poiana Stampei",
    "lat": "47.31667",
    "lng": "25.13333"
  },
  {
    "country": "RO",
    "name": "Poiana Sibiului",
    "lat": "45.8",
    "lng": "23.73333"
  },
  {
    "country": "RO",
    "name": "Poiana Mărului",
    "lat": "47.41188",
    "lng": "26.04077"
  },
  {
    "country": "RO",
    "name": "Poiana Mărului",
    "lat": "47.37951",
    "lng": "26.89243"
  },
  {
    "country": "RO",
    "name": "Poiana Mărului (Brașov)",
    "lat": "45.6",
    "lng": "25.3"
  },
  {
    "country": "RO",
    "name": "Poiana Mare",
    "lat": "43.91667",
    "lng": "23.06667"
  },
  {
    "country": "RO",
    "name": "Poiana Lacului",
    "lat": "44.81667",
    "lng": "24.73333"
  },
  {
    "country": "RO",
    "name": "Poiana Ilvei",
    "lat": "47.35749",
    "lng": "24.74104"
  },
  {
    "country": "RO",
    "name": "Poiana Cristei",
    "lat": "45.65",
    "lng": "26.98333"
  },
  {
    "country": "RO",
    "name": "Poiana Crăcăoani",
    "lat": "47.06667",
    "lng": "26.31667"
  },
  {
    "country": "RO",
    "name": "Poiana Copăceni",
    "lat": "45.16392",
    "lng": "26.06918"
  },
  {
    "country": "RO",
    "name": "Poiana Codrului",
    "lat": "47.62667",
    "lng": "23.25056"
  },
  {
    "country": "RO",
    "name": "Poiana Câmpina",
    "lat": "45.13333",
    "lng": "25.68333"
  },
  {
    "country": "RO",
    "name": "Poiana Blenchii",
    "lat": "47.3",
    "lng": "23.75"
  },
  {
    "country": "RO",
    "name": "Poiana",
    "lat": "47.60149",
    "lng": "26.60826"
  },
  {
    "country": "RO",
    "name": "Poiana",
    "lat": "47.56436",
    "lng": "26.86387"
  },
  {
    "country": "RO",
    "name": "Poiana",
    "lat": "47.49299",
    "lng": "26.86387"
  },
  {
    "country": "RO",
    "name": "Poiana",
    "lat": "46.69819",
    "lng": "27.01765"
  },
  {
    "country": "RO",
    "name": "Poiana",
    "lat": "45.99228",
    "lng": "27.25609"
  },
  {
    "country": "RO",
    "name": "Poiana",
    "lat": "45.24536",
    "lng": "25.66302"
  },
  {
    "country": "RO",
    "name": "Poiana",
    "lat": "44.65174",
    "lng": "23.53148"
  },
  {
    "country": "RO",
    "name": "Poiana",
    "lat": "44.56667",
    "lng": "25.68333"
  },
  {
    "country": "RO",
    "name": "Poiana",
    "lat": "43.74192",
    "lng": "24.95244"
  },
  {
    "country": "RO",
    "name": "Poian",
    "lat": "46.06667",
    "lng": "26.15"
  },
  {
    "country": "RO",
    "name": "Pogonești",
    "lat": "46.15229",
    "lng": "27.53225"
  },
  {
    "country": "RO",
    "name": "Pogonele",
    "lat": "45.08645",
    "lng": "26.86454"
  },
  {
    "country": "RO",
    "name": "Pogoanele",
    "lat": "44.91667",
    "lng": "27"
  },
  {
    "country": "RO",
    "name": "Pogănești",
    "lat": "46.69237",
    "lng": "28.16779"
  },
  {
    "country": "RO",
    "name": "Pogana",
    "lat": "46.31667",
    "lng": "27.56667"
  },
  {
    "country": "RO",
    "name": "Pogăceaua",
    "lat": "46.68333",
    "lng": "24.3"
  },
  {
    "country": "RO",
    "name": "Poieni-Solca",
    "lat": "47.68626",
    "lng": "25.89374"
  },
  {
    "country": "RO",
    "name": "Poieni",
    "lat": "46.9188",
    "lng": "22.85826"
  },
  {
    "country": "RO",
    "name": "Poieni",
    "lat": "46.83333",
    "lng": "26.35"
  },
  {
    "country": "RO",
    "name": "Poeni",
    "lat": "44.4",
    "lng": "25.33333"
  },
  {
    "country": "RO",
    "name": "Poienarii Apostoli",
    "lat": "44.77204",
    "lng": "26.05388"
  },
  {
    "country": "RO",
    "name": "Poienarii Burchii",
    "lat": "44.75",
    "lng": "26.01667"
  },
  {
    "country": "RO",
    "name": "Poienari",
    "lat": "45.21667",
    "lng": "25.05"
  },
  {
    "country": "RO",
    "name": "Podu Turcului",
    "lat": "46.2",
    "lng": "27.38333"
  },
  {
    "country": "RO",
    "name": "Poduri",
    "lat": "46.61667",
    "lng": "24.06667"
  },
  {
    "country": "RO",
    "name": "Poduri",
    "lat": "46.46667",
    "lng": "26.53333"
  },
  {
    "country": "RO",
    "name": "Podu Iloaiei",
    "lat": "47.21667",
    "lng": "27.26667"
  },
  {
    "country": "RO",
    "name": "Podolenii de Sus",
    "lat": "46.85716",
    "lng": "28.01545"
  },
  {
    "country": "RO",
    "name": "Podoleni",
    "lat": "46.8",
    "lng": "26.61667"
  },
  {
    "country": "RO",
    "name": "Podoleni",
    "lat": "45.7483",
    "lng": "27.44661"
  },
  {
    "country": "RO",
    "name": "Podgoria",
    "lat": "45.41667",
    "lng": "27.01667"
  },
  {
    "country": "RO",
    "name": "Podenii Vechi",
    "lat": "45.08939",
    "lng": "26.11584"
  },
  {
    "country": "RO",
    "name": "Podenii Noi",
    "lat": "45.11667",
    "lng": "26.16667"
  },
  {
    "country": "RO",
    "name": "Podeni",
    "lat": "44.88139",
    "lng": "22.54333"
  },
  {
    "country": "RO",
    "name": "Podari",
    "lat": "44.25",
    "lng": "23.78333"
  },
  {
    "country": "RO",
    "name": "Pocruia",
    "lat": "45.0447",
    "lng": "22.92495"
  },
  {
    "country": "RO",
    "name": "Pocola",
    "lat": "46.68333",
    "lng": "22.28333"
  },
  {
    "country": "RO",
    "name": "Pociovaliștea",
    "lat": "45.15315",
    "lng": "23.64392"
  },
  {
    "country": "RO",
    "name": "Pochidia",
    "lat": "46.04318",
    "lng": "27.58746"
  },
  {
    "country": "RO",
    "name": "Poboru",
    "lat": "44.66667",
    "lng": "24.5"
  },
  {
    "country": "RO",
    "name": "Poarta Albă",
    "lat": "44.21667",
    "lng": "28.4"
  },
  {
    "country": "RO",
    "name": "Plugova",
    "lat": "44.9625",
    "lng": "22.35864"
  },
  {
    "country": "RO",
    "name": "Plugari",
    "lat": "47.48333",
    "lng": "27.1"
  },
  {
    "country": "RO",
    "name": "Plutonița",
    "lat": "47.48081",
    "lng": "25.79145"
  },
  {
    "country": "RO",
    "name": "Ploștina",
    "lat": "44.82398",
    "lng": "22.98791"
  },
  {
    "country": "RO",
    "name": "Ploscuțeni",
    "lat": "46.07859",
    "lng": "27.27032"
  },
  {
    "country": "RO",
    "name": "Ploscoș",
    "lat": "46.64303",
    "lng": "23.84663"
  },
  {
    "country": "RO",
    "name": "Plosca",
    "lat": "44.03333",
    "lng": "25.13333"
  },
  {
    "country": "RO",
    "name": "Plopu",
    "lat": "46.39256",
    "lng": "26.50268"
  },
  {
    "country": "RO",
    "name": "Plopu",
    "lat": "45.14847",
    "lng": "27.51387"
  },
  {
    "country": "RO",
    "name": "Plopu",
    "lat": "45.01667",
    "lng": "26.15"
  },
  {
    "country": "RO",
    "name": "Plopşoru",
    "lat": "44.78333",
    "lng": "23.35"
  },
  {
    "country": "RO",
    "name": "Plopșoru",
    "lat": "44.0119",
    "lng": "25.99306"
  },
  {
    "country": "RO",
    "name": "Plopiş",
    "lat": "47.13333",
    "lng": "22.68333"
  },
  {
    "country": "RO",
    "name": "Plopii Slăviţeştí",
    "lat": "43.96667",
    "lng": "24.68333"
  },
  {
    "country": "RO",
    "name": "Plopeni",
    "lat": "47.65874",
    "lng": "26.33913"
  },
  {
    "country": "RO",
    "name": "Plopeni",
    "lat": "45.04955",
    "lng": "25.95202"
  },
  {
    "country": "RO",
    "name": "Plopeni",
    "lat": "43.95089",
    "lng": "28.19452"
  },
  {
    "country": "RO",
    "name": "Plopana",
    "lat": "46.68333",
    "lng": "27.21667"
  },
  {
    "country": "RO",
    "name": "Ploieşti",
    "lat": "44.95",
    "lng": "26.01667"
  },
  {
    "country": "RO",
    "name": "Ploieștiori",
    "lat": "44.98157",
    "lng": "26.01795"
  },
  {
    "country": "RO",
    "name": "Plevna",
    "lat": "45.37815",
    "lng": "27.0131"
  },
  {
    "country": "RO",
    "name": "Pleşoiu",
    "lat": "44.46667",
    "lng": "24.26667"
  },
  {
    "country": "RO",
    "name": "Pleșoi",
    "lat": "44.35077",
    "lng": "23.53345"
  },
  {
    "country": "RO",
    "name": "Pleşcuţa",
    "lat": "46.3",
    "lng": "22.43333"
  },
  {
    "country": "RO",
    "name": "Pleniţa",
    "lat": "44.21667",
    "lng": "23.18333"
  },
  {
    "country": "RO",
    "name": "Pleașov",
    "lat": "43.84971",
    "lng": "24.74886"
  },
  {
    "country": "RO",
    "name": "Pleașa",
    "lat": "45.00583",
    "lng": "26.07211"
  },
  {
    "country": "RO",
    "name": "Plăvălari",
    "lat": "47.56832",
    "lng": "26.35925"
  },
  {
    "country": "RO",
    "name": "Platonești",
    "lat": "44.60712",
    "lng": "27.69706"
  },
  {
    "country": "RO",
    "name": "Plătăreşti",
    "lat": "44.35",
    "lng": "26.36667"
  },
  {
    "country": "RO",
    "name": "Piteşti",
    "lat": "44.85",
    "lng": "24.86667"
  },
  {
    "country": "RO",
    "name": "Piteasca",
    "lat": "44.49339",
    "lng": "26.33025"
  },
  {
    "country": "RO",
    "name": "Pitaru",
    "lat": "44.59061",
    "lng": "25.58407"
  },
  {
    "country": "RO",
    "name": "Piscu Vechi",
    "lat": "43.9",
    "lng": "23.16667"
  },
  {
    "country": "RO",
    "name": "Piscu Sadovei",
    "lat": "43.87729",
    "lng": "23.93687"
  },
  {
    "country": "RO",
    "name": "Piscu Nou",
    "lat": "43.924",
    "lng": "23.17917"
  },
  {
    "country": "RO",
    "name": "Piscu",
    "lat": "45.5",
    "lng": "27.73333"
  },
  {
    "country": "RO",
    "name": "Pişcolt",
    "lat": "47.58333",
    "lng": "22.3"
  },
  {
    "country": "RO",
    "name": "Piscoiu",
    "lat": "44.85211",
    "lng": "23.75387"
  },
  {
    "country": "RO",
    "name": "Pişchia",
    "lat": "45.90306",
    "lng": "21.33722"
  },
  {
    "country": "RO",
    "name": "Pârşcoveni",
    "lat": "44.3",
    "lng": "24.23333"
  },
  {
    "country": "RO",
    "name": "Pârscov",
    "lat": "45.28333",
    "lng": "26.55"
  },
  {
    "country": "RO",
    "name": "Pârjol",
    "lat": "46.58333",
    "lng": "26.6"
  },
  {
    "country": "RO",
    "name": "Pârâu",
    "lat": "45.85",
    "lng": "25.18333"
  },
  {
    "country": "RO",
    "name": "Pârgăreşti",
    "lat": "46.25",
    "lng": "26.65"
  },
  {
    "country": "RO",
    "name": "Pârcovaci",
    "lat": "47.43586",
    "lng": "26.85075"
  },
  {
    "country": "RO",
    "name": "Pâraie",
    "lat": "47.46299",
    "lng": "26.06608"
  },
  {
    "country": "RO",
    "name": "Pir",
    "lat": "47.46667",
    "lng": "22.36667"
  },
  {
    "country": "RO",
    "name": "Pipirig",
    "lat": "47.25",
    "lng": "26.06667"
  },
  {
    "country": "RO",
    "name": "Pângăraţi",
    "lat": "46.93333",
    "lng": "26.15"
  },
  {
    "country": "RO",
    "name": "Pângărăcior",
    "lat": "46.93333",
    "lng": "26.21667"
  },
  {
    "country": "RO",
    "name": "Pâncota",
    "lat": "46.33333",
    "lng": "21.7"
  },
  {
    "country": "RO",
    "name": "Pânceşti",
    "lat": "46.90296",
    "lng": "27.15314"
  },
  {
    "country": "RO",
    "name": "Pilu",
    "lat": "46.56667",
    "lng": "21.35"
  },
  {
    "country": "RO",
    "name": "Pildești",
    "lat": "46.99675",
    "lng": "26.82558"
  },
  {
    "country": "RO",
    "name": "Pietrosu",
    "lat": "47.34118",
    "lng": "26.60817"
  },
  {
    "country": "RO",
    "name": "Pietrosu",
    "lat": "45.05928",
    "lng": "26.75827"
  },
  {
    "country": "RO",
    "name": "Pietroşiţa",
    "lat": "45.18333",
    "lng": "25.43333"
  },
  {
    "country": "RO",
    "name": "Pietroşani",
    "lat": "45.18333",
    "lng": "24.85"
  },
  {
    "country": "RO",
    "name": "Pietroșani",
    "lat": "44.83963",
    "lng": "26.10382"
  },
  {
    "country": "RO",
    "name": "Pietroşani",
    "lat": "43.71667",
    "lng": "25.63333"
  },
  {
    "country": "RO",
    "name": "Pietroasele",
    "lat": "45.1",
    "lng": "26.56667"
  },
  {
    "country": "RO",
    "name": "Pietroasa",
    "lat": "46.58333",
    "lng": "22.55"
  },
  {
    "country": "RO",
    "name": "Pietroasa",
    "lat": "45.83333",
    "lng": "22.4"
  },
  {
    "country": "RO",
    "name": "Pietrișu",
    "lat": "43.72508",
    "lng": "25.67464"
  },
  {
    "country": "RO",
    "name": "Pietreni",
    "lat": "44.09609",
    "lng": "28.06833"
  },
  {
    "country": "RO",
    "name": "Pietrele",
    "lat": "44.06258",
    "lng": "26.12019"
  },
  {
    "country": "RO",
    "name": "Pietrarii de Sus",
    "lat": "45.11697",
    "lng": "24.09336"
  },
  {
    "country": "RO",
    "name": "Pietrari",
    "lat": "45.1",
    "lng": "24.13333"
  },
  {
    "country": "RO",
    "name": "Pietrari",
    "lat": "45.09377",
    "lng": "25.29289"
  },
  {
    "country": "RO",
    "name": "Pieleştí",
    "lat": "44.33333",
    "lng": "23.95"
  },
  {
    "country": "RO",
    "name": "Picior de Munte",
    "lat": "44.78247",
    "lng": "25.39047"
  },
  {
    "country": "RO",
    "name": "Piatra Şoimului",
    "lat": "46.83333",
    "lng": "26.43333"
  },
  {
    "country": "RO",
    "name": "Piatra Olt",
    "lat": "44.36667",
    "lng": "24.26667"
  },
  {
    "country": "RO",
    "name": "Piatra Neamţ",
    "lat": "46.91667",
    "lng": "26.33333"
  },
  {
    "country": "RO",
    "name": "Piatra",
    "lat": "44.40492",
    "lng": "28.56143"
  },
  {
    "country": "RO",
    "name": "Piatra",
    "lat": "44.36054",
    "lng": "24.29557"
  },
  {
    "country": "RO",
    "name": "Piatra",
    "lat": "43.81667",
    "lng": "25.16667"
  },
  {
    "country": "RO",
    "name": "Pianu de Sus",
    "lat": "45.9",
    "lng": "23.48333"
  },
  {
    "country": "RO",
    "name": "Pianu de Jos",
    "lat": "45.93528",
    "lng": "23.48912"
  },
  {
    "country": "RO",
    "name": "Petrova",
    "lat": "47.82981",
    "lng": "24.21533"
  },
  {
    "country": "RO",
    "name": "Petroșnița",
    "lat": "45.32351",
    "lng": "22.2592"
  },
  {
    "country": "RO",
    "name": "Petroşani",
    "lat": "45.41667",
    "lng": "23.36667"
  },
  {
    "country": "RO",
    "name": "Petriș",
    "lat": "47.10301",
    "lng": "24.62314"
  },
  {
    "country": "RO",
    "name": "Petriş",
    "lat": "46.05",
    "lng": "22.38333"
  },
  {
    "country": "RO",
    "name": "Petrila",
    "lat": "45.45",
    "lng": "23.41667"
  },
  {
    "country": "RO",
    "name": "Pietriceaua",
    "lat": "45.2191",
    "lng": "25.80859"
  },
  {
    "country": "RO",
    "name": "Petricani",
    "lat": "47.16667",
    "lng": "26.46667"
  },
  {
    "country": "RO",
    "name": "Petreu",
    "lat": "47.33738",
    "lng": "22.29607"
  },
  {
    "country": "RO",
    "name": "Petreştii de Jos",
    "lat": "46.58333",
    "lng": "23.65"
  },
  {
    "country": "RO",
    "name": "Petreşti",
    "lat": "47.6",
    "lng": "22.36667"
  },
  {
    "country": "RO",
    "name": "Petrești",
    "lat": "45.92102",
    "lng": "23.56083"
  },
  {
    "country": "RO",
    "name": "Petrești",
    "lat": "45.04364",
    "lng": "24.88989"
  },
  {
    "country": "RO",
    "name": "Petreşti",
    "lat": "44.65",
    "lng": "25.33333"
  },
  {
    "country": "RO",
    "name": "Petrăchioaia",
    "lat": "44.58099",
    "lng": "26.31269"
  },
  {
    "country": "RO",
    "name": "Petelea",
    "lat": "46.72892",
    "lng": "24.70654"
  },
  {
    "country": "RO",
    "name": "Peştişu Mic",
    "lat": "45.8",
    "lng": "22.88333"
  },
  {
    "country": "RO",
    "name": "Peștișu Mare",
    "lat": "45.80192",
    "lng": "22.92704"
  },
  {
    "country": "RO",
    "name": "Peştişani",
    "lat": "45.06667",
    "lng": "23.03333"
  },
  {
    "country": "RO",
    "name": "Peștiș",
    "lat": "47.07252",
    "lng": "22.41226"
  },
  {
    "country": "RO",
    "name": "Peştera",
    "lat": "44.18333",
    "lng": "28.13333"
  },
  {
    "country": "RO",
    "name": "Peșteana Jiu",
    "lat": "44.84695",
    "lng": "23.30401"
  },
  {
    "country": "RO",
    "name": "Peșteana de Jos",
    "lat": "44.83333",
    "lng": "23.26974"
  },
  {
    "country": "RO",
    "name": "Pesceana",
    "lat": "44.88333",
    "lng": "24.15"
  },
  {
    "country": "RO",
    "name": "Glăvile",
    "lat": "44.81667",
    "lng": "24.15"
  },
  {
    "country": "RO",
    "name": "Coronini",
    "lat": "44.68004",
    "lng": "21.68552"
  },
  {
    "country": "RO",
    "name": "Pesac",
    "lat": "45.9959",
    "lng": "20.83522"
  },
  {
    "country": "RO",
    "name": "Perșunari",
    "lat": "45.05682",
    "lng": "26.44784"
  },
  {
    "country": "RO",
    "name": "Perșinari",
    "lat": "44.80185",
    "lng": "25.4988"
  },
  {
    "country": "RO",
    "name": "Perșani",
    "lat": "45.7816",
    "lng": "25.21285"
  },
  {
    "country": "RO",
    "name": "Perișoru",
    "lat": "45.11268",
    "lng": "27.49817"
  },
  {
    "country": "RO",
    "name": "Perişoru",
    "lat": "44.45",
    "lng": "27.55"
  },
  {
    "country": "RO",
    "name": "Perișor",
    "lat": "44.14331",
    "lng": "23.47509"
  },
  {
    "country": "RO",
    "name": "Perişani",
    "lat": "45.38333",
    "lng": "24.4"
  },
  {
    "country": "RO",
    "name": "Periş",
    "lat": "44.68472",
    "lng": "26.01389"
  },
  {
    "country": "RO",
    "name": "Perii Broșteni",
    "lat": "44.20336",
    "lng": "25.26377"
  },
  {
    "country": "RO",
    "name": "Perieţi",
    "lat": "44.55",
    "lng": "27.21667"
  },
  {
    "country": "RO",
    "name": "Perieţi",
    "lat": "44.4",
    "lng": "24.55"
  },
  {
    "country": "RO",
    "name": "Perieni",
    "lat": "47.38469",
    "lng": "27.47453"
  },
  {
    "country": "RO",
    "name": "Perieni",
    "lat": "46.3",
    "lng": "27.61667"
  },
  {
    "country": "RO",
    "name": "Pericei",
    "lat": "47.23333",
    "lng": "22.88333"
  },
  {
    "country": "RO",
    "name": "Periam",
    "lat": "46.05",
    "lng": "20.86667"
  },
  {
    "country": "RO",
    "name": "Peretu",
    "lat": "44.05",
    "lng": "25.08333"
  },
  {
    "country": "RO",
    "name": "Peregu Mic",
    "lat": "46.25021",
    "lng": "20.94885"
  },
  {
    "country": "RO",
    "name": "Peregu Mare",
    "lat": "46.23333",
    "lng": "20.9"
  },
  {
    "country": "RO",
    "name": "Peciu Nou",
    "lat": "45.60639",
    "lng": "21.05778"
  },
  {
    "country": "RO",
    "name": "Pecineaga",
    "lat": "43.9",
    "lng": "28.5"
  },
  {
    "country": "RO",
    "name": "Pechea",
    "lat": "45.63333",
    "lng": "27.8"
  },
  {
    "country": "RO",
    "name": "Peceneaga",
    "lat": "45.01667",
    "lng": "28.13333"
  },
  {
    "country": "RO",
    "name": "Peceiu",
    "lat": "47.12415",
    "lng": "22.86238"
  },
  {
    "country": "RO",
    "name": "Păuşeşti-Măglaşi",
    "lat": "45.13333",
    "lng": "24.25"
  },
  {
    "country": "RO",
    "name": "Păușești",
    "lat": "47.1581",
    "lng": "27.32594"
  },
  {
    "country": "RO",
    "name": "Păuşeşti",
    "lat": "45.07358",
    "lng": "24.13473"
  },
  {
    "country": "RO",
    "name": "Păuneşti",
    "lat": "46.03333",
    "lng": "27.1"
  },
  {
    "country": "RO",
    "name": "Păuliş",
    "lat": "46.11667",
    "lng": "21.58333"
  },
  {
    "country": "RO",
    "name": "Păuleşti",
    "lat": "47.78333",
    "lng": "22.91667"
  },
  {
    "country": "RO",
    "name": "Păulești",
    "lat": "45.89154",
    "lng": "26.68914"
  },
  {
    "country": "RO",
    "name": "Păuleşti",
    "lat": "45",
    "lng": "25.98333"
  },
  {
    "country": "RO",
    "name": "Păuleni-Ciuc",
    "lat": "46.4",
    "lng": "25.83333"
  },
  {
    "country": "RO",
    "name": "Păuca",
    "lat": "46.01667",
    "lng": "23.9"
  },
  {
    "country": "RO",
    "name": "Pătuleni",
    "lat": "44.73247",
    "lng": "25.16495"
  },
  {
    "country": "RO",
    "name": "Pătulele",
    "lat": "44.34528",
    "lng": "22.77278"
  },
  {
    "country": "RO",
    "name": "Patru Frați",
    "lat": "44.73672",
    "lng": "26.47059"
  },
  {
    "country": "RO",
    "name": "Pătrăuţi",
    "lat": "47.71667",
    "lng": "26.2"
  },
  {
    "country": "RO",
    "name": "Pătârlagele",
    "lat": "45.32081",
    "lng": "26.36134"
  },
  {
    "country": "RO",
    "name": "Păstrăveni",
    "lat": "47.16667",
    "lng": "26.56667"
  },
  {
    "country": "RO",
    "name": "Păsăreni",
    "lat": "46.48333",
    "lng": "24.7"
  },
  {
    "country": "RO",
    "name": "Parva",
    "lat": "47.4",
    "lng": "24.55"
  },
  {
    "country": "RO",
    "name": "Părteştii de Jos",
    "lat": "47.63333",
    "lng": "25.96667"
  },
  {
    "country": "RO",
    "name": "Parța",
    "lat": "45.62888",
    "lng": "21.13877"
  },
  {
    "country": "RO",
    "name": "Parincea",
    "lat": "46.48333",
    "lng": "27.1"
  },
  {
    "country": "RO",
    "name": "Părhăuți",
    "lat": "47.71057",
    "lng": "26.09012"
  },
  {
    "country": "RO",
    "name": "Parepa-Rușani",
    "lat": "44.90577",
    "lng": "26.35478"
  },
  {
    "country": "RO",
    "name": "Pardoşi",
    "lat": "45.36667",
    "lng": "26.9"
  },
  {
    "country": "RO",
    "name": "Pardina",
    "lat": "45.3",
    "lng": "28.96667"
  },
  {
    "country": "RO",
    "name": "Parava",
    "lat": "46.3",
    "lng": "27"
  },
  {
    "country": "RO",
    "name": "Papiu Ilarian",
    "lat": "46.55",
    "lng": "24.2"
  },
  {
    "country": "RO",
    "name": "Păpăuți",
    "lat": "45.78333",
    "lng": "26.13333"
  },
  {
    "country": "RO",
    "name": "Panticeu",
    "lat": "47.03333",
    "lng": "23.56667"
  },
  {
    "country": "RO",
    "name": "Pantelimon de Jos",
    "lat": "44.56667",
    "lng": "28.38333"
  },
  {
    "country": "RO",
    "name": "Pantelimon",
    "lat": "44.54589",
    "lng": "28.33094"
  },
  {
    "country": "RO",
    "name": "Pantelimon",
    "lat": "44.45",
    "lng": "26.2"
  },
  {
    "country": "RO",
    "name": "Pantazi",
    "lat": "44.93492",
    "lng": "26.1402"
  },
  {
    "country": "RO",
    "name": "Pănet",
    "lat": "46.55514",
    "lng": "24.46973"
  },
  {
    "country": "RO",
    "name": "Panciu",
    "lat": "45.9",
    "lng": "27.08333"
  },
  {
    "country": "RO",
    "name": "Pănceşti",
    "lat": "46.33333",
    "lng": "27.08333"
  },
  {
    "country": "RO",
    "name": "Păncești",
    "lat": "46.21118",
    "lng": "27.06797"
  },
  {
    "country": "RO",
    "name": "Pănătău",
    "lat": "45.32113",
    "lng": "26.39442"
  },
  {
    "country": "RO",
    "name": "Panaci",
    "lat": "47.26667",
    "lng": "25.38333"
  },
  {
    "country": "RO",
    "name": "Păltinoasa",
    "lat": "47.55",
    "lng": "25.95"
  },
  {
    "country": "RO",
    "name": "Păltiniş",
    "lat": "48.21667",
    "lng": "26.65"
  },
  {
    "country": "RO",
    "name": "Păltiniş",
    "lat": "45.43333",
    "lng": "22.15"
  },
  {
    "country": "RO",
    "name": "Păltineni",
    "lat": "45.39596",
    "lng": "26.32334"
  },
  {
    "country": "RO",
    "name": "Paltin",
    "lat": "45.78333",
    "lng": "26.71667"
  },
  {
    "country": "RO",
    "name": "Paleu",
    "lat": "47.11531",
    "lng": "21.95929"
  },
  {
    "country": "RO",
    "name": "Palazu Mare",
    "lat": "44.22902",
    "lng": "28.60114"
  },
  {
    "country": "RO",
    "name": "Pălatca",
    "lat": "46.85",
    "lng": "23.98333"
  },
  {
    "country": "RO",
    "name": "Palanca",
    "lat": "46.53333",
    "lng": "26.11667"
  },
  {
    "country": "RO",
    "name": "Palanca",
    "lat": "44.81562",
    "lng": "26.19995"
  },
  {
    "country": "RO",
    "name": "Palanca",
    "lat": "44.47575",
    "lng": "25.72565"
  },
  {
    "country": "RO",
    "name": "Pădureni",
    "lat": "46.59316",
    "lng": "24.027"
  },
  {
    "country": "RO",
    "name": "Pădureni",
    "lat": "47.97434",
    "lng": "26.31672"
  },
  {
    "country": "RO",
    "name": "Pădureni",
    "lat": "46.62192",
    "lng": "28.08258"
  },
  {
    "country": "RO",
    "name": "Pădureni",
    "lat": "45.60039",
    "lng": "21.21773"
  },
  {
    "country": "RO",
    "name": "Pădureni",
    "lat": "44.34576",
    "lng": "25.80469"
  },
  {
    "country": "RO",
    "name": "Pădurea Neagră",
    "lat": "47.16554",
    "lng": "22.41323"
  },
  {
    "country": "RO",
    "name": "Padina Mică",
    "lat": "44.42722",
    "lng": "22.9925"
  },
  {
    "country": "RO",
    "name": "Padina Matei",
    "lat": "44.75843",
    "lng": "21.75067"
  },
  {
    "country": "RO",
    "name": "Padina",
    "lat": "44.83333",
    "lng": "27.11667"
  },
  {
    "country": "RO",
    "name": "Padeş",
    "lat": "45.01667",
    "lng": "22.85"
  },
  {
    "country": "RO",
    "name": "Padea",
    "lat": "44.02128",
    "lng": "23.86827"
  },
  {
    "country": "RO",
    "name": "Păcureţi",
    "lat": "45.15",
    "lng": "26.13333"
  },
  {
    "country": "RO",
    "name": "Ozun",
    "lat": "45.8",
    "lng": "25.85"
  },
  {
    "country": "RO",
    "name": "Ovidiu",
    "lat": "44.26667",
    "lng": "28.56667"
  },
  {
    "country": "RO",
    "name": "Oveselu",
    "lat": "44.75",
    "lng": "24.01667"
  },
  {
    "country": "RO",
    "name": "Otopeni",
    "lat": "44.55",
    "lng": "26.06667"
  },
  {
    "country": "RO",
    "name": "Otetelișu",
    "lat": "44.63839",
    "lng": "23.95917"
  },
  {
    "country": "RO",
    "name": "Oteşani",
    "lat": "45.06667",
    "lng": "24.03333"
  },
  {
    "country": "RO",
    "name": "Oţelu Roşu",
    "lat": "45.53333",
    "lng": "22.36667"
  },
  {
    "country": "RO",
    "name": "Oţeleni",
    "lat": "47.08333",
    "lng": "27.03333"
  },
  {
    "country": "RO",
    "name": "Otelec",
    "lat": "45.61478",
    "lng": "20.84952"
  },
  {
    "country": "RO",
    "name": "Ostrovu Mare",
    "lat": "44.37931",
    "lng": "22.51581"
  },
  {
    "country": "RO",
    "name": "Ostrovu",
    "lat": "45.20351",
    "lng": "25.90345"
  },
  {
    "country": "RO",
    "name": "Ostroveni",
    "lat": "43.8",
    "lng": "23.9"
  },
  {
    "country": "RO",
    "name": "Ostrov",
    "lat": "44.93333",
    "lng": "28.15"
  },
  {
    "country": "RO",
    "name": "Ostrov",
    "lat": "44.11667",
    "lng": "27.36667"
  },
  {
    "country": "RO",
    "name": "Ostra",
    "lat": "47.4",
    "lng": "25.76667"
  },
  {
    "country": "RO",
    "name": "Oșorhei",
    "lat": "47.03333",
    "lng": "22.05"
  },
  {
    "country": "RO",
    "name": "Osoi",
    "lat": "47.09479",
    "lng": "27.80091"
  },
  {
    "country": "RO",
    "name": "Osica de Sus",
    "lat": "44.25",
    "lng": "24.31667"
  },
  {
    "country": "RO",
    "name": "Osica de Jos",
    "lat": "44.24439",
    "lng": "24.27926"
  },
  {
    "country": "RO",
    "name": "Oşeşti",
    "lat": "46.76667",
    "lng": "27.46667"
  },
  {
    "country": "RO",
    "name": "Osebiți",
    "lat": "46.53839",
    "lng": "26.83946"
  },
  {
    "country": "RO",
    "name": "Orţişoara",
    "lat": "45.96361",
    "lng": "21.19833"
  },
  {
    "country": "RO",
    "name": "Orşova",
    "lat": "44.72528",
    "lng": "22.39611"
  },
  {
    "country": "RO",
    "name": "Oroftiana",
    "lat": "48.17758",
    "lng": "26.34856"
  },
  {
    "country": "RO",
    "name": "Orodel",
    "lat": "44.23333",
    "lng": "23.23333"
  },
  {
    "country": "RO",
    "name": "Ormeniş",
    "lat": "46.01667",
    "lng": "25.55"
  },
  {
    "country": "RO",
    "name": "Orleşti",
    "lat": "44.8",
    "lng": "24.21667"
  },
  {
    "country": "RO",
    "name": "Orlea Nouă",
    "lat": "43.75522",
    "lng": "24.35834"
  },
  {
    "country": "RO",
    "name": "Orlea",
    "lat": "43.75",
    "lng": "24.38333"
  },
  {
    "country": "RO",
    "name": "Orlat",
    "lat": "45.75",
    "lng": "23.96667"
  },
  {
    "country": "RO",
    "name": "Orevița Mare",
    "lat": "44.45715",
    "lng": "22.91317"
  },
  {
    "country": "RO",
    "name": "Oreavu",
    "lat": "45.36826",
    "lng": "27.02301"
  },
  {
    "country": "RO",
    "name": "Orbeni",
    "lat": "46.28333",
    "lng": "27.01667"
  },
  {
    "country": "RO",
    "name": "Orbeasca de Sus",
    "lat": "44.15",
    "lng": "25.31667"
  },
  {
    "country": "RO",
    "name": "Orbeasca de Jos",
    "lat": "44.12177",
    "lng": "25.32952"
  },
  {
    "country": "RO",
    "name": "Oraviţa",
    "lat": "45.0325",
    "lng": "21.68944"
  },
  {
    "country": "RO",
    "name": "Oraşu Nou",
    "lat": "47.83333",
    "lng": "23.28333"
  },
  {
    "country": "RO",
    "name": "Orăştioara de Sus",
    "lat": "45.73333",
    "lng": "23.16667"
  },
  {
    "country": "RO",
    "name": "Orăştie",
    "lat": "45.83333",
    "lng": "23.2"
  },
  {
    "country": "RO",
    "name": "Orășeni-Deal",
    "lat": "47.67597",
    "lng": "26.67671"
  },
  {
    "country": "RO",
    "name": "Orășa",
    "lat": "46.42225",
    "lng": "26.7437"
  },
  {
    "country": "RO",
    "name": "Oradea",
    "lat": "47.0458",
    "lng": "21.91833"
  },
  {
    "country": "RO",
    "name": "Optaşi",
    "lat": "44.58333",
    "lng": "24.65"
  },
  {
    "country": "RO",
    "name": "Oprişor",
    "lat": "44.28333",
    "lng": "23.08333"
  },
  {
    "country": "RO",
    "name": "Oporelu",
    "lat": "44.6",
    "lng": "24.41667"
  },
  {
    "country": "RO",
    "name": "Oniceni",
    "lat": "47.32441",
    "lng": "26.46217"
  },
  {
    "country": "RO",
    "name": "Oniceni",
    "lat": "46.81667",
    "lng": "27.15"
  },
  {
    "country": "RO",
    "name": "Oneaga",
    "lat": "47.57626",
    "lng": "26.73244"
  },
  {
    "country": "RO",
    "name": "Oncești",
    "lat": "47.84814",
    "lng": "23.98183"
  },
  {
    "country": "RO",
    "name": "Onceşti",
    "lat": "46.46667",
    "lng": "27.25"
  },
  {
    "country": "RO",
    "name": "Oltina",
    "lat": "44.16667",
    "lng": "27.66667"
  },
  {
    "country": "RO",
    "name": "Olteniţa",
    "lat": "44.08333",
    "lng": "26.63333"
  },
  {
    "country": "RO",
    "name": "Olteni",
    "lat": "44.39307",
    "lng": "25.95021"
  },
  {
    "country": "RO",
    "name": "Olteni",
    "lat": "44.18333",
    "lng": "25.28333"
  },
  {
    "country": "RO",
    "name": "Olteneşti",
    "lat": "46.58333",
    "lng": "27.9"
  },
  {
    "country": "RO",
    "name": "Olteanca",
    "lat": "43.83047",
    "lng": "24.79597"
  },
  {
    "country": "RO",
    "name": "Ologeni",
    "lat": "44.7337",
    "lng": "25.95059"
  },
  {
    "country": "RO",
    "name": "Oleșești",
    "lat": "45.84781",
    "lng": "27.10097"
  },
  {
    "country": "RO",
    "name": "Olcea",
    "lat": "46.68333",
    "lng": "21.98333"
  },
  {
    "country": "RO",
    "name": "Olari",
    "lat": "46.38333",
    "lng": "21.55"
  },
  {
    "country": "RO",
    "name": "Olari",
    "lat": "44.78482",
    "lng": "26.21728"
  },
  {
    "country": "RO",
    "name": "Olari",
    "lat": "44.30783",
    "lng": "24.20857"
  },
  {
    "country": "RO",
    "name": "Olanu",
    "lat": "44.86667",
    "lng": "24.3"
  },
  {
    "country": "RO",
    "name": "Olănești",
    "lat": "45.18209",
    "lng": "24.2599"
  },
  {
    "country": "RO",
    "name": "Ojdula",
    "lat": "45.98333",
    "lng": "26.25"
  },
  {
    "country": "RO",
    "name": "Oituz",
    "lat": "46.2",
    "lng": "26.61667"
  },
  {
    "country": "RO",
    "name": "Oinacu",
    "lat": "43.95",
    "lng": "26.01667"
  },
  {
    "country": "RO",
    "name": "Ohaba Lungă",
    "lat": "45.9074",
    "lng": "21.98535"
  },
  {
    "country": "RO",
    "name": "Ohaba",
    "lat": "46.06667",
    "lng": "23.78333"
  },
  {
    "country": "RO",
    "name": "Ogrezeni",
    "lat": "44.41972",
    "lng": "25.76833"
  },
  {
    "country": "RO",
    "name": "Ogretin",
    "lat": "45.26483",
    "lng": "26.09169"
  },
  {
    "country": "RO",
    "name": "Ograda",
    "lat": "44.61457",
    "lng": "27.57047"
  },
  {
    "country": "RO",
    "name": "Ogra",
    "lat": "46.43333",
    "lng": "24.31667"
  },
  {
    "country": "RO",
    "name": "Oglinzi",
    "lat": "47.25055",
    "lng": "26.35026"
  },
  {
    "country": "RO",
    "name": "Oeștii Pământeni",
    "lat": "45.25241",
    "lng": "24.65658"
  },
  {
    "country": "RO",
    "name": "Odorheiu Secuiesc",
    "lat": "46.3",
    "lng": "25.3"
  },
  {
    "country": "RO",
    "name": "Odoreu",
    "lat": "47.8",
    "lng": "23"
  },
  {
    "country": "RO",
    "name": "Odobești",
    "lat": "46.67608",
    "lng": "27.14983"
  },
  {
    "country": "RO",
    "name": "Odobeşti",
    "lat": "45.76667",
    "lng": "27.05"
  },
  {
    "country": "RO",
    "name": "Odobeşti",
    "lat": "44.61667",
    "lng": "25.56667"
  },
  {
    "country": "RO",
    "name": "Odăile",
    "lat": "45.38333",
    "lng": "26.55"
  },
  {
    "country": "RO",
    "name": "Odaia Turcului",
    "lat": "44.69777",
    "lng": "25.45082"
  },
  {
    "country": "RO",
    "name": "Odaia Manolache",
    "lat": "45.54897",
    "lng": "27.99057"
  },
  {
    "country": "RO",
    "name": "Ocoliş",
    "lat": "46.48333",
    "lng": "23.46667"
  },
  {
    "country": "RO",
    "name": "Ocnița",
    "lat": "46.86266",
    "lng": "24.48677"
  },
  {
    "country": "RO",
    "name": "Ocniţa",
    "lat": "44.98333",
    "lng": "25.55"
  },
  {
    "country": "RO",
    "name": "Ocna Şugatag",
    "lat": "47.78333",
    "lng": "23.93333"
  },
  {
    "country": "RO",
    "name": "Ocna Sibiului",
    "lat": "45.88333",
    "lng": "24.05"
  },
  {
    "country": "RO",
    "name": "Ocna Mureş",
    "lat": "46.38333",
    "lng": "23.85"
  },
  {
    "country": "RO",
    "name": "Ocna de Sus",
    "lat": "46.52729",
    "lng": "25.15131"
  },
  {
    "country": "RO",
    "name": "Ocna Dejului",
    "lat": "47.11581",
    "lng": "23.85934"
  },
  {
    "country": "RO",
    "name": "Ocna de Jos",
    "lat": "46.52635",
    "lng": "25.12945"
  },
  {
    "country": "RO",
    "name": "Ocland",
    "lat": "46.16667",
    "lng": "25.41667"
  },
  {
    "country": "RO",
    "name": "Ocina de Sus",
    "lat": "45.2006",
    "lng": "25.59882"
  },
  {
    "country": "RO",
    "name": "Obrejița",
    "lat": "45.50102",
    "lng": "27.08974"
  },
  {
    "country": "RO",
    "name": "Obreja",
    "lat": "45.48333",
    "lng": "22.25"
  },
  {
    "country": "RO",
    "name": "Oboga",
    "lat": "44.41667",
    "lng": "24.1"
  },
  {
    "country": "RO",
    "name": "Obârşia-Cloşani",
    "lat": "45.01667",
    "lng": "22.68333"
  },
  {
    "country": "RO",
    "name": "Obârșia de Câmp",
    "lat": "44.17222",
    "lng": "22.98"
  },
  {
    "country": "RO",
    "name": "Obârşia",
    "lat": "43.88333",
    "lng": "24.33333"
  },
  {
    "country": "RO",
    "name": "Oarţa de Jos",
    "lat": "47.45827",
    "lng": "23.12742"
  },
  {
    "country": "RO",
    "name": "Oarja Sat",
    "lat": "44.76429",
    "lng": "24.97141"
  },
  {
    "country": "RO",
    "name": "Oarda",
    "lat": "46.03333",
    "lng": "23.56667"
  },
  {
    "country": "RO",
    "name": "Oar",
    "lat": "47.80569",
    "lng": "22.73085"
  },
  {
    "country": "RO",
    "name": "Oanțu",
    "lat": "46.9097",
    "lng": "26.19887"
  },
  {
    "country": "RO",
    "name": "Oancea",
    "lat": "45.91667",
    "lng": "28.1"
  },
  {
    "country": "RO",
    "name": "Nuşfalău",
    "lat": "47.2",
    "lng": "22.73333"
  },
  {
    "country": "RO",
    "name": "Nuşeni",
    "lat": "47.1",
    "lng": "24.2"
  },
  {
    "country": "RO",
    "name": "Nuntași",
    "lat": "44.53755",
    "lng": "28.6488"
  },
  {
    "country": "RO",
    "name": "Nufăru",
    "lat": "45.15",
    "lng": "28.91667"
  },
  {
    "country": "RO",
    "name": "Nucşoara",
    "lat": "45.33333",
    "lng": "24.78333"
  },
  {
    "country": "RO",
    "name": "Nuci",
    "lat": "44.71667",
    "lng": "26.3"
  },
  {
    "country": "RO",
    "name": "Nucet",
    "lat": "46.48732",
    "lng": "22.5585"
  },
  {
    "country": "RO",
    "name": "Nucet",
    "lat": "44.78333",
    "lng": "25.55"
  },
  {
    "country": "RO",
    "name": "Novaci",
    "lat": "45.18333",
    "lng": "23.66667"
  },
  {
    "country": "RO",
    "name": "Novaci",
    "lat": "44.30109",
    "lng": "25.98632"
  },
  {
    "country": "RO",
    "name": "Nou",
    "lat": "45.83333",
    "lng": "24.28333"
  },
  {
    "country": "RO",
    "name": "Noşlac",
    "lat": "46.4",
    "lng": "23.93333"
  },
  {
    "country": "RO",
    "name": "Nojorid",
    "lat": "46.98333",
    "lng": "21.88333"
  },
  {
    "country": "RO",
    "name": "Nocrich",
    "lat": "45.9",
    "lng": "24.45"
  },
  {
    "country": "RO",
    "name": "Niţchidorf",
    "lat": "45.58333",
    "lng": "21.53333"
  },
  {
    "country": "RO",
    "name": "Nistru",
    "lat": "47.72088",
    "lng": "23.45495"
  },
  {
    "country": "RO",
    "name": "Nistoreşti",
    "lat": "45.83333",
    "lng": "26.73333"
  },
  {
    "country": "RO",
    "name": "Nisiporești",
    "lat": "47.0772",
    "lng": "26.73791"
  },
  {
    "country": "RO",
    "name": "Nisipari",
    "lat": "44.25964",
    "lng": "28.3984"
  },
  {
    "country": "RO",
    "name": "Nireș",
    "lat": "47.11499",
    "lng": "23.98092"
  },
  {
    "country": "RO",
    "name": "Nimigea de Sus",
    "lat": "47.28333",
    "lng": "24.31667"
  },
  {
    "country": "RO",
    "name": "Nimigea de Jos",
    "lat": "47.25357",
    "lng": "24.30084"
  },
  {
    "country": "RO",
    "name": "Niculiţel",
    "lat": "45.18333",
    "lng": "28.48333"
  },
  {
    "country": "RO",
    "name": "Niculești",
    "lat": "44.68266",
    "lng": "25.94221"
  },
  {
    "country": "RO",
    "name": "Nicşeni",
    "lat": "47.86667",
    "lng": "26.63333"
  },
  {
    "country": "RO",
    "name": "Nicoreşti",
    "lat": "45.93223",
    "lng": "27.30866"
  },
  {
    "country": "RO",
    "name": "Nicolești",
    "lat": "46.43918",
    "lng": "25.84446"
  },
  {
    "country": "RO",
    "name": "Nicolae Titulescu",
    "lat": "44.3",
    "lng": "24.8"
  },
  {
    "country": "RO",
    "name": "Nicolae Bălcescu",
    "lat": "47.56664",
    "lng": "26.89629"
  },
  {
    "country": "RO",
    "name": "Nicolae Bălcescu",
    "lat": "46.46667",
    "lng": "26.91667"
  },
  {
    "country": "RO",
    "name": "Nicolae Bălcescu",
    "lat": "44.99714",
    "lng": "28.58757"
  },
  {
    "country": "RO",
    "name": "Nicolae Bălcescu",
    "lat": "44.45",
    "lng": "26.76667"
  },
  {
    "country": "RO",
    "name": "Nicolae Bălcescu",
    "lat": "44.38333",
    "lng": "28.38333"
  },
  {
    "country": "RO",
    "name": "Nicolae Bălcescu",
    "lat": "44.37427",
    "lng": "22.85837"
  },
  {
    "country": "RO",
    "name": "Nicolae Bălcescu",
    "lat": "44.28604",
    "lng": "27.07877"
  },
  {
    "country": "RO",
    "name": "Neudorf",
    "lat": "46.0696",
    "lng": "21.61899"
  },
  {
    "country": "RO",
    "name": "Nereju Mic",
    "lat": "45.70618",
    "lng": "26.69641"
  },
  {
    "country": "RO",
    "name": "Nereju",
    "lat": "45.71667",
    "lng": "26.71667"
  },
  {
    "country": "RO",
    "name": "Nerău",
    "lat": "45.96929",
    "lng": "20.5607"
  },
  {
    "country": "RO",
    "name": "Nepos",
    "lat": "47.2775",
    "lng": "24.5332"
  },
  {
    "country": "RO",
    "name": "Nenciulești",
    "lat": "44.03486",
    "lng": "25.20061"
  },
  {
    "country": "RO",
    "name": "Nemțișor",
    "lat": "47.23962",
    "lng": "26.27209"
  },
  {
    "country": "RO",
    "name": "Nehoiu",
    "lat": "45.41667",
    "lng": "26.3"
  },
  {
    "country": "RO",
    "name": "Negru Vodă",
    "lat": "43.81667",
    "lng": "28.2"
  },
  {
    "country": "RO",
    "name": "Negrilești",
    "lat": "47.27068",
    "lng": "24.04936"
  },
  {
    "country": "RO",
    "name": "Negrilești",
    "lat": "45.95729",
    "lng": "27.48085"
  },
  {
    "country": "RO",
    "name": "Negrilești",
    "lat": "45.93697",
    "lng": "26.70635"
  },
  {
    "country": "RO",
    "name": "Negrileasa",
    "lat": "47.42348",
    "lng": "25.81617"
  },
  {
    "country": "RO",
    "name": "Negri",
    "lat": "46.7",
    "lng": "26.96667"
  },
  {
    "country": "RO",
    "name": "Negreşti-Oaş",
    "lat": "47.86667",
    "lng": "23.43333"
  },
  {
    "country": "RO",
    "name": "Negrești",
    "lat": "47.02938",
    "lng": "26.37958"
  },
  {
    "country": "RO",
    "name": "Negreşti",
    "lat": "46.83333",
    "lng": "27.43333"
  },
  {
    "country": "RO",
    "name": "Negreni",
    "lat": "46.95378",
    "lng": "22.76347"
  },
  {
    "country": "RO",
    "name": "Negreni",
    "lat": "44.56848",
    "lng": "24.59535"
  },
  {
    "country": "RO",
    "name": "Negraşi",
    "lat": "44.6",
    "lng": "25.11667"
  },
  {
    "country": "RO",
    "name": "Negostina",
    "lat": "47.92282",
    "lng": "26.08209"
  },
  {
    "country": "RO",
    "name": "Negomir",
    "lat": "44.83333",
    "lng": "23.16667"
  },
  {
    "country": "RO",
    "name": "Negoi",
    "lat": "43.91396",
    "lng": "23.37288"
  },
  {
    "country": "RO",
    "name": "Negoiești",
    "lat": "44.87393",
    "lng": "25.9816"
  },
  {
    "country": "RO",
    "name": "Negoiești",
    "lat": "44.53584",
    "lng": "23.7269"
  },
  {
    "country": "RO",
    "name": "Negoești",
    "lat": "44.23065",
    "lng": "26.50151"
  },
  {
    "country": "RO",
    "name": "Nedelea",
    "lat": "44.97191",
    "lng": "25.81647"
  },
  {
    "country": "RO",
    "name": "Nedeia",
    "lat": "43.84992",
    "lng": "23.77643"
  },
  {
    "country": "RO",
    "name": "Necşeşti",
    "lat": "44.25",
    "lng": "25.15"
  },
  {
    "country": "RO",
    "name": "Neaua",
    "lat": "46.48333",
    "lng": "24.83333"
  },
  {
    "country": "RO",
    "name": "Neagra Șarului",
    "lat": "47.23907",
    "lng": "25.32923"
  },
  {
    "country": "RO",
    "name": "Nazna",
    "lat": "46.53552",
    "lng": "24.5021"
  },
  {
    "country": "RO",
    "name": "Năvodari",
    "lat": "44.31667",
    "lng": "28.6"
  },
  {
    "country": "RO",
    "name": "Năvodari",
    "lat": "43.74208",
    "lng": "25.0941"
  },
  {
    "country": "RO",
    "name": "Năsturelu",
    "lat": "43.66667",
    "lng": "25.46667"
  },
  {
    "country": "RO",
    "name": "Năsăud",
    "lat": "47.28333",
    "lng": "24.4"
  },
  {
    "country": "RO",
    "name": "Năruja",
    "lat": "45.83333",
    "lng": "26.78333"
  },
  {
    "country": "RO",
    "name": "Năpradea",
    "lat": "47.36667",
    "lng": "23.31667"
  },
  {
    "country": "RO",
    "name": "Nanov",
    "lat": "44",
    "lng": "25.3"
  },
  {
    "country": "RO",
    "name": "Năneşti",
    "lat": "45.55",
    "lng": "27.5"
  },
  {
    "country": "RO",
    "name": "Nana",
    "lat": "44.26667",
    "lng": "26.58333"
  },
  {
    "country": "RO",
    "name": "Nămoloasa-Sat",
    "lat": "45.53333",
    "lng": "27.58333"
  },
  {
    "country": "RO",
    "name": "Nămoloasa",
    "lat": "45.5361",
    "lng": "27.55226"
  },
  {
    "country": "RO",
    "name": "Nalbant",
    "lat": "45.05",
    "lng": "28.61667"
  },
  {
    "country": "RO",
    "name": "Naipu",
    "lat": "44.15187",
    "lng": "25.76175"
  },
  {
    "country": "RO",
    "name": "Naidăș",
    "lat": "44.88108",
    "lng": "21.59061"
  },
  {
    "country": "RO",
    "name": "Năeni",
    "lat": "45.1",
    "lng": "26.48333"
  },
  {
    "country": "RO",
    "name": "Nădrag",
    "lat": "45.65",
    "lng": "22.18333"
  },
  {
    "country": "RO",
    "name": "Nădlac",
    "lat": "46.16667",
    "lng": "20.75"
  },
  {
    "country": "RO",
    "name": "Nadeş",
    "lat": "46.31667",
    "lng": "24.73333"
  },
  {
    "country": "RO",
    "name": "Nadăș",
    "lat": "46.2249",
    "lng": "21.95036"
  },
  {
    "country": "RO",
    "name": "Nadab",
    "lat": "46.48195",
    "lng": "21.51178"
  },
  {
    "country": "RO",
    "name": "Mușătești",
    "lat": "45.21651",
    "lng": "24.77941"
  },
  {
    "country": "RO",
    "name": "Muşeteşti",
    "lat": "45.15",
    "lng": "23.46667"
  },
  {
    "country": "RO",
    "name": "Muşeniţa",
    "lat": "47.96667",
    "lng": "26"
  },
  {
    "country": "RO",
    "name": "Murighiol",
    "lat": "45.03333",
    "lng": "29.16667"
  },
  {
    "country": "RO",
    "name": "Murgeşti",
    "lat": "45.4",
    "lng": "26.88333"
  },
  {
    "country": "RO",
    "name": "Murgeni",
    "lat": "46.20444",
    "lng": "28.01972"
  },
  {
    "country": "RO",
    "name": "Murgași",
    "lat": "44.49968",
    "lng": "23.86698"
  },
  {
    "country": "RO",
    "name": "Murfatlar",
    "lat": "44.18333",
    "lng": "28.41667"
  },
  {
    "country": "RO",
    "name": "Muntenii de Sus",
    "lat": "46.68968",
    "lng": "27.77763"
  },
  {
    "country": "RO",
    "name": "Muntenii de Jos",
    "lat": "46.61667",
    "lng": "27.76667"
  },
  {
    "country": "RO",
    "name": "Munteni Buzău",
    "lat": "44.63333",
    "lng": "26.98333"
  },
  {
    "country": "RO",
    "name": "Munteni",
    "lat": "47.3153",
    "lng": "27.13839"
  },
  {
    "country": "RO",
    "name": "Munteni",
    "lat": "45.93333",
    "lng": "27.43333"
  },
  {
    "country": "RO",
    "name": "Muntele Mic",
    "lat": "45.38333",
    "lng": "22.33333"
  },
  {
    "country": "RO",
    "name": "Muncelu de Sus",
    "lat": "47.12384",
    "lng": "26.73518"
  },
  {
    "country": "RO",
    "name": "Mugeni",
    "lat": "46.25",
    "lng": "25.21667"
  },
  {
    "country": "RO",
    "name": "Muereasca",
    "lat": "45.18333",
    "lng": "24.33333"
  },
  {
    "country": "RO",
    "name": "Mozăceni",
    "lat": "44.56667",
    "lng": "25.16667"
  },
  {
    "country": "RO",
    "name": "Moviliţa",
    "lat": "45.95",
    "lng": "27.1"
  },
  {
    "country": "RO",
    "name": "Moviliţa",
    "lat": "44.65",
    "lng": "26.48333"
  },
  {
    "country": "RO",
    "name": "Movileni",
    "lat": "47.31667",
    "lng": "27.35"
  },
  {
    "country": "RO",
    "name": "Movileni",
    "lat": "45.76154",
    "lng": "27.37184"
  },
  {
    "country": "RO",
    "name": "Movileni",
    "lat": "44.36667",
    "lng": "24.65"
  },
  {
    "country": "RO",
    "name": "Movila Miresii",
    "lat": "45.21667",
    "lng": "27.6"
  },
  {
    "country": "RO",
    "name": "Movila Banului",
    "lat": "44.98333",
    "lng": "26.68333"
  },
  {
    "country": "RO",
    "name": "Movila",
    "lat": "44.55",
    "lng": "27.7"
  },
  {
    "country": "RO",
    "name": "Motru",
    "lat": "44.80333",
    "lng": "22.97194"
  },
  {
    "country": "RO",
    "name": "Motoşeni",
    "lat": "46.33333",
    "lng": "27.38333"
  },
  {
    "country": "RO",
    "name": "Moţca",
    "lat": "47.25",
    "lng": "26.61667"
  },
  {
    "country": "RO",
    "name": "Moţăţei",
    "lat": "44.08333",
    "lng": "23.2"
  },
  {
    "country": "RO",
    "name": "Moțăieni",
    "lat": "45.1",
    "lng": "25.41667"
  },
  {
    "country": "RO",
    "name": "Moșteni",
    "lat": "44.19787",
    "lng": "25.50854"
  },
  {
    "country": "RO",
    "name": "Moşoaia",
    "lat": "44.81667",
    "lng": "24.76667"
  },
  {
    "country": "RO",
    "name": "Moşniţa Nouă",
    "lat": "45.71722",
    "lng": "21.32528"
  },
  {
    "country": "RO",
    "name": "Moșnița Veche",
    "lat": "45.73549",
    "lng": "21.33396"
  },
  {
    "country": "RO",
    "name": "Moșneni",
    "lat": "43.93487",
    "lng": "28.53132"
  },
  {
    "country": "RO",
    "name": "Moşna",
    "lat": "46.91667",
    "lng": "27.95"
  },
  {
    "country": "RO",
    "name": "Moşna",
    "lat": "46.08333",
    "lng": "24.4"
  },
  {
    "country": "RO",
    "name": "Moscu",
    "lat": "45.9026",
    "lng": "27.9312"
  },
  {
    "country": "RO",
    "name": "Morunglav",
    "lat": "44.46667",
    "lng": "24.11667"
  },
  {
    "country": "RO",
    "name": "Morteni",
    "lat": "44.66667",
    "lng": "25.23333"
  },
  {
    "country": "RO",
    "name": "Moroeni",
    "lat": "45.21667",
    "lng": "25.43333"
  },
  {
    "country": "RO",
    "name": "Moreni",
    "lat": "44.98301",
    "lng": "25.64415"
  },
  {
    "country": "RO",
    "name": "Moraviţa",
    "lat": "45.25583",
    "lng": "21.27028"
  },
  {
    "country": "RO",
    "name": "Morăreşti",
    "lat": "45.01667",
    "lng": "24.56667"
  },
  {
    "country": "RO",
    "name": "Monor",
    "lat": "46.96667",
    "lng": "24.7"
  },
  {
    "country": "RO",
    "name": "Moneasa",
    "lat": "46.45",
    "lng": "22.25"
  },
  {
    "country": "RO",
    "name": "Moldoviţa",
    "lat": "47.68333",
    "lng": "25.53333"
  },
  {
    "country": "RO",
    "name": "Moldoveni",
    "lat": "46.83333",
    "lng": "26.76667"
  },
  {
    "country": "RO",
    "name": "Moldoveni",
    "lat": "44.71425",
    "lng": "26.51879"
  },
  {
    "country": "RO",
    "name": "Moldoveni",
    "lat": "43.77772",
    "lng": "24.72802"
  },
  {
    "country": "RO",
    "name": "Moldoveneşti",
    "lat": "46.5",
    "lng": "23.65"
  },
  {
    "country": "RO",
    "name": "Moldova Suliţa",
    "lat": "47.68333",
    "lng": "25.25"
  },
  {
    "country": "RO",
    "name": "Moldova Nouă",
    "lat": "44.7375",
    "lng": "21.66694"
  },
  {
    "country": "RO",
    "name": "Moișeni",
    "lat": "47.92798",
    "lng": "23.46833"
  },
  {
    "country": "RO",
    "name": "Moisei",
    "lat": "47.65562",
    "lng": "24.54011"
  },
  {
    "country": "RO",
    "name": "Moineşti",
    "lat": "46.47523",
    "lng": "26.48907"
  },
  {
    "country": "RO",
    "name": "Mogoşoaia",
    "lat": "44.52917",
    "lng": "26"
  },
  {
    "country": "RO",
    "name": "Mogoşeşti-Siret",
    "lat": "47.13333",
    "lng": "26.78333"
  },
  {
    "country": "RO",
    "name": "Mogoşeşti",
    "lat": "47.03333",
    "lng": "27.53333"
  },
  {
    "country": "RO",
    "name": "Mogoşani",
    "lat": "44.68333",
    "lng": "25.4"
  },
  {
    "country": "RO",
    "name": "Mogoș",
    "lat": "46.27554",
    "lng": "23.28038"
  },
  {
    "country": "RO",
    "name": "Moftinu Mic",
    "lat": "47.68669",
    "lng": "22.60054"
  },
  {
    "country": "RO",
    "name": "Moftinu Mare",
    "lat": "47.66667",
    "lng": "22.66667"
  },
  {
    "country": "RO",
    "name": "Mofleni",
    "lat": "44.3022",
    "lng": "23.75848"
  },
  {
    "country": "RO",
    "name": "Moeciu de Jos",
    "lat": "45.48333",
    "lng": "25.31667"
  },
  {
    "country": "RO",
    "name": "Modelu",
    "lat": "44.19574",
    "lng": "27.3872"
  },
  {
    "country": "RO",
    "name": "Mociu",
    "lat": "46.8",
    "lng": "24.03333"
  },
  {
    "country": "RO",
    "name": "Moceşti",
    "lat": "45.05",
    "lng": "26.25"
  },
  {
    "country": "RO",
    "name": "Moara Vlăsiei",
    "lat": "44.6409",
    "lng": "26.20616"
  },
  {
    "country": "RO",
    "name": "Moara Nica",
    "lat": "47.60086",
    "lng": "26.22262"
  },
  {
    "country": "RO",
    "name": "Moara Grecilor",
    "lat": "46.67145",
    "lng": "27.74569"
  },
  {
    "country": "RO",
    "name": "Moara Domnească",
    "lat": "46.71448",
    "lng": "27.7589"
  },
  {
    "country": "RO",
    "name": "Moara Carp",
    "lat": "47.56667",
    "lng": "26.23333"
  },
  {
    "country": "RO",
    "name": "Moacşa",
    "lat": "45.86667",
    "lng": "25.96667"
  },
  {
    "country": "RO",
    "name": "Mlenăuți",
    "lat": "48.12663",
    "lng": "26.48961"
  },
  {
    "country": "RO",
    "name": "Mizil",
    "lat": "45.01667",
    "lng": "26.45"
  },
  {
    "country": "RO",
    "name": "Mitrofani",
    "lat": "44.73268",
    "lng": "24.2091"
  },
  {
    "country": "RO",
    "name": "Mitreni",
    "lat": "44.16667",
    "lng": "26.6"
  },
  {
    "country": "RO",
    "name": "Mitocu Dragomirnei",
    "lat": "47.73333",
    "lng": "26.25"
  },
  {
    "country": "RO",
    "name": "Mitoc",
    "lat": "48.1",
    "lng": "27.03333"
  },
  {
    "country": "RO",
    "name": "Mislea",
    "lat": "45.09668",
    "lng": "25.82444"
  },
  {
    "country": "RO",
    "name": "Misentea",
    "lat": "46.32714",
    "lng": "25.89506"
  },
  {
    "country": "RO",
    "name": "Mischii",
    "lat": "44.38333",
    "lng": "23.85"
  },
  {
    "country": "RO",
    "name": "Mișca",
    "lat": "47.26291",
    "lng": "22.25914"
  },
  {
    "country": "RO",
    "name": "Mișca",
    "lat": "46.6028",
    "lng": "21.59998"
  },
  {
    "country": "RO",
    "name": "Mâsca",
    "lat": "46.3",
    "lng": "21.68333"
  },
  {
    "country": "RO",
    "name": "Mârzăneşti",
    "lat": "43.93333",
    "lng": "25.46667"
  },
  {
    "country": "RO",
    "name": "Mârţeşti",
    "lat": "44.71667",
    "lng": "24.75"
  },
  {
    "country": "RO",
    "name": "Mirşid",
    "lat": "47.23333",
    "lng": "23.13333"
  },
  {
    "country": "RO",
    "name": "Mârşani",
    "lat": "44.01667",
    "lng": "24.01667"
  },
  {
    "country": "RO",
    "name": "Mârşa",
    "lat": "44.37417",
    "lng": "25.55694"
  },
  {
    "country": "RO",
    "name": "Miroslovești",
    "lat": "47.15",
    "lng": "26.65"
  },
  {
    "country": "RO",
    "name": "Miroslăvești",
    "lat": "44.80383",
    "lng": "26.08689"
  },
  {
    "country": "RO",
    "name": "Miroslava",
    "lat": "47.15",
    "lng": "27.51667"
  },
  {
    "country": "RO",
    "name": "Miroşi",
    "lat": "44.41667",
    "lng": "24.93333"
  },
  {
    "country": "RO",
    "name": "Mironeasa",
    "lat": "46.96667",
    "lng": "27.41667"
  },
  {
    "country": "RO",
    "name": "Miron Costin",
    "lat": "46.9203",
    "lng": "26.80567"
  },
  {
    "country": "RO",
    "name": "Mironu",
    "lat": "47.48799",
    "lng": "26.00952"
  },
  {
    "country": "RO",
    "name": "Mireşu Mare",
    "lat": "47.5",
    "lng": "23.33333"
  },
  {
    "country": "RO",
    "name": "Mireșu Mare",
    "lat": "45.13508",
    "lng": "26.37714"
  },
  {
    "country": "RO",
    "name": "Mirceștii Noi",
    "lat": "45.75072",
    "lng": "27.2726"
  },
  {
    "country": "RO",
    "name": "Mirceşti",
    "lat": "47.08333",
    "lng": "26.83333"
  },
  {
    "country": "RO",
    "name": "Călăraşi",
    "lat": "44.2051",
    "lng": "27.31356"
  },
  {
    "country": "RO",
    "name": "Mircea Vodă",
    "lat": "45.11667",
    "lng": "27.38333"
  },
  {
    "country": "RO",
    "name": "Mircea Vodă",
    "lat": "44.28333",
    "lng": "28.16667"
  },
  {
    "country": "RO",
    "name": "Mirăslău",
    "lat": "46.36667",
    "lng": "23.71667"
  },
  {
    "country": "RO",
    "name": "Miorcani",
    "lat": "48.20223",
    "lng": "26.85279"
  },
  {
    "country": "RO",
    "name": "Mânzăleşti",
    "lat": "45.5",
    "lng": "26.65"
  },
  {
    "country": "RO",
    "name": "Mintiu Gherlii",
    "lat": "47.05",
    "lng": "23.95"
  },
  {
    "country": "RO",
    "name": "Minieri",
    "lat": "44.98372",
    "lng": "25.76083"
  },
  {
    "country": "RO",
    "name": "Mineri",
    "lat": "45.16472",
    "lng": "28.71573"
  },
  {
    "country": "RO",
    "name": "Mândruloc",
    "lat": "46.14863",
    "lng": "21.4657"
  },
  {
    "country": "RO",
    "name": "Mândrești",
    "lat": "47.73333",
    "lng": "26.48333"
  },
  {
    "country": "RO",
    "name": "Mândrești",
    "lat": "45.88333",
    "lng": "27.7"
  },
  {
    "country": "RO",
    "name": "Mândra",
    "lat": "45.81667",
    "lng": "25.05"
  },
  {
    "country": "RO",
    "name": "Mânău",
    "lat": "47.48179",
    "lng": "23.26247"
  },
  {
    "country": "RO",
    "name": "Mânăstireni",
    "lat": "46.76667",
    "lng": "23.08333"
  },
  {
    "country": "RO",
    "name": "Mănăstirea Humorului",
    "lat": "47.6",
    "lng": "25.86667"
  },
  {
    "country": "RO",
    "name": "Mânăstirea Caşin",
    "lat": "46.15",
    "lng": "26.68333"
  },
  {
    "country": "RO",
    "name": "Mănăstirea",
    "lat": "46.95",
    "lng": "27.2"
  },
  {
    "country": "RO",
    "name": "Mânăstirea",
    "lat": "44.21667",
    "lng": "26.9"
  },
  {
    "country": "RO",
    "name": "Miloşeşti",
    "lat": "44.73333",
    "lng": "27.23333"
  },
  {
    "country": "RO",
    "name": "Milişăuţi",
    "lat": "47.78333",
    "lng": "26"
  },
  {
    "country": "RO",
    "name": "Mileanca",
    "lat": "48.08333",
    "lng": "26.7"
  },
  {
    "country": "RO",
    "name": "Milcovul",
    "lat": "45.65",
    "lng": "27.25"
  },
  {
    "country": "RO",
    "name": "Milcovățu",
    "lat": "44.2657",
    "lng": "25.69882"
  },
  {
    "country": "RO",
    "name": "Milcoiu",
    "lat": "45.05",
    "lng": "24.46667"
  },
  {
    "country": "RO",
    "name": "Milaş",
    "lat": "46.81667",
    "lng": "24.43333"
  },
  {
    "country": "RO",
    "name": "Mijlocenii Bârgăului",
    "lat": "47.21592",
    "lng": "24.68936"
  },
  {
    "country": "RO",
    "name": "Mija",
    "lat": "44.91356",
    "lng": "25.67585"
  },
  {
    "country": "RO",
    "name": "Mihoveni",
    "lat": "47.67994",
    "lng": "26.1822"
  },
  {
    "country": "RO",
    "name": "Miheşu de Câmpie",
    "lat": "46.68333",
    "lng": "24.15"
  },
  {
    "country": "RO",
    "name": "Mihalţ",
    "lat": "46.15",
    "lng": "23.73333"
  },
  {
    "country": "RO",
    "name": "Mihălceni",
    "lat": "45.44493",
    "lng": "27.30466"
  },
  {
    "country": "RO",
    "name": "Mihălăşeni",
    "lat": "47.88333",
    "lng": "27.06667"
  },
  {
    "country": "RO",
    "name": "Mihai Vodă",
    "lat": "44.43916",
    "lng": "25.81957"
  },
  {
    "country": "RO",
    "name": "Mihai Viteazu",
    "lat": "46.53333",
    "lng": "23.75"
  },
  {
    "country": "RO",
    "name": "Mihai Viteazu",
    "lat": "44.63333",
    "lng": "28.68333"
  },
  {
    "country": "RO",
    "name": "Mihai Viteazu",
    "lat": "44.34864",
    "lng": "27.07361"
  },
  {
    "country": "RO",
    "name": "Mihail Kogălniceanu",
    "lat": "45.03333",
    "lng": "28.73333"
  },
  {
    "country": "RO",
    "name": "Mihail Kogălniceanu",
    "lat": "44.68333",
    "lng": "27.73333"
  },
  {
    "country": "RO",
    "name": "Mihail Kogălniceanu",
    "lat": "44.36798",
    "lng": "28.46"
  },
  {
    "country": "RO",
    "name": "Mihăileşti",
    "lat": "44.91667",
    "lng": "26.66667"
  },
  {
    "country": "RO",
    "name": "Mihăileşti",
    "lat": "44.32667",
    "lng": "25.90833"
  },
  {
    "country": "RO",
    "name": "Mihăileni",
    "lat": "47.96667",
    "lng": "26.15"
  },
  {
    "country": "RO",
    "name": "Mihăileni",
    "lat": "46.46667",
    "lng": "25.81667"
  },
  {
    "country": "RO",
    "name": "Mihăileni",
    "lat": "45.98333",
    "lng": "24.35"
  },
  {
    "country": "RO",
    "name": "Mihai Bravu",
    "lat": "47.2578",
    "lng": "21.93811"
  },
  {
    "country": "RO",
    "name": "Mihai Bravu",
    "lat": "44.95",
    "lng": "28.65"
  },
  {
    "country": "RO",
    "name": "Mihai Bravu",
    "lat": "44.78469",
    "lng": "27.72144"
  },
  {
    "country": "RO",
    "name": "Mihai Bravu",
    "lat": "44.14056",
    "lng": "26.06278"
  },
  {
    "country": "RO",
    "name": "Mihăiești",
    "lat": "47.51563",
    "lng": "26.21734"
  },
  {
    "country": "RO",
    "name": "Mihăeşti",
    "lat": "45.11667",
    "lng": "25"
  },
  {
    "country": "RO",
    "name": "Mihăeşti",
    "lat": "45.03333",
    "lng": "24.25"
  },
  {
    "country": "RO",
    "name": "Mihăeşti",
    "lat": "44.13333",
    "lng": "24.78333"
  },
  {
    "country": "RO",
    "name": "Miercurea Sibiului",
    "lat": "45.88333",
    "lng": "23.8"
  },
  {
    "country": "RO",
    "name": "Miercurea Nirajului",
    "lat": "46.53333",
    "lng": "24.8"
  },
  {
    "country": "RO",
    "name": "Miercurea-Ciuc",
    "lat": "46.35",
    "lng": "25.8"
  },
  {
    "country": "RO",
    "name": "Micula",
    "lat": "47.9",
    "lng": "22.95"
  },
  {
    "country": "RO",
    "name": "Micleşti",
    "lat": "46.81667",
    "lng": "27.83333"
  },
  {
    "country": "RO",
    "name": "Micfalău",
    "lat": "46.05342",
    "lng": "25.83737"
  },
  {
    "country": "RO",
    "name": "Miceştii de Câmpie",
    "lat": "46.86667",
    "lng": "24.31667"
  },
  {
    "country": "RO",
    "name": "Micești",
    "lat": "46.10141",
    "lng": "23.55573"
  },
  {
    "country": "RO",
    "name": "Miceşti",
    "lat": "44.95",
    "lng": "24.86667"
  },
  {
    "country": "RO",
    "name": "Micăsasa",
    "lat": "46.08333",
    "lng": "24.11667"
  },
  {
    "country": "RO",
    "name": "Mica",
    "lat": "47.13333",
    "lng": "23.93333"
  },
  {
    "country": "RO",
    "name": "Mica",
    "lat": "46.36667",
    "lng": "24.41667"
  },
  {
    "country": "RO",
    "name": "Meziad",
    "lat": "46.7409",
    "lng": "22.42846"
  },
  {
    "country": "RO",
    "name": "Meteş",
    "lat": "46.1",
    "lng": "23.41667"
  },
  {
    "country": "RO",
    "name": "Meseşenii de Jos",
    "lat": "47.15",
    "lng": "22.98333"
  },
  {
    "country": "RO",
    "name": "Merişani",
    "lat": "44.9682",
    "lng": "24.74327"
  },
  {
    "country": "RO",
    "name": "Merișani",
    "lat": "44.2519",
    "lng": "24.8755"
  },
  {
    "country": "RO",
    "name": "Merișani",
    "lat": "44.11669",
    "lng": "25.3998"
  },
  {
    "country": "RO",
    "name": "Merii Petchii",
    "lat": "44.73532",
    "lng": "26.30054"
  },
  {
    "country": "RO",
    "name": "Meri",
    "lat": "44.83366",
    "lng": "26.30863"
  },
  {
    "country": "RO",
    "name": "Merghindeal",
    "lat": "45.96667",
    "lng": "24.73333"
  },
  {
    "country": "RO",
    "name": "Mereşti",
    "lat": "46.23333",
    "lng": "25.45"
  },
  {
    "country": "RO",
    "name": "Merenii de Sus",
    "lat": "44.22839",
    "lng": "25.62103"
  },
  {
    "country": "RO",
    "name": "Merenii de Jos",
    "lat": "44.23214",
    "lng": "25.64346"
  },
  {
    "country": "RO",
    "name": "Mereni",
    "lat": "46.07924",
    "lng": "26.23597"
  },
  {
    "country": "RO",
    "name": "Mereni",
    "lat": "44.05",
    "lng": "28.36667"
  },
  {
    "country": "RO",
    "name": "Merei",
    "lat": "45.13333",
    "lng": "26.68333"
  },
  {
    "country": "RO",
    "name": "Mera",
    "lat": "46.81525",
    "lng": "23.45405"
  },
  {
    "country": "RO",
    "name": "Mera",
    "lat": "45.76667",
    "lng": "26.95"
  },
  {
    "country": "RO",
    "name": "Melineşti",
    "lat": "44.56667",
    "lng": "23.71667"
  },
  {
    "country": "RO",
    "name": "Mehadica",
    "lat": "45.03333",
    "lng": "22.26667"
  },
  {
    "country": "RO",
    "name": "Mehadia",
    "lat": "44.90083",
    "lng": "22.36694"
  },
  {
    "country": "RO",
    "name": "Medieşu Aurit",
    "lat": "47.78333",
    "lng": "23.15"
  },
  {
    "country": "RO",
    "name": "Mediaş",
    "lat": "46.16667",
    "lng": "24.35"
  },
  {
    "country": "RO",
    "name": "Medgidia",
    "lat": "44.25",
    "lng": "28.28333"
  },
  {
    "country": "RO",
    "name": "Măzănăești",
    "lat": "47.52795",
    "lng": "26.08401"
  },
  {
    "country": "RO",
    "name": "Maxut",
    "lat": "47.4404",
    "lng": "26.89204"
  },
  {
    "country": "RO",
    "name": "Măxineni",
    "lat": "45.4",
    "lng": "27.63333"
  },
  {
    "country": "RO",
    "name": "Maxenu",
    "lat": "45.05162",
    "lng": "26.85498"
  },
  {
    "country": "RO",
    "name": "Mavrodin",
    "lat": "44.64919",
    "lng": "25.71731"
  },
  {
    "country": "RO",
    "name": "Mavrodin",
    "lat": "44.03333",
    "lng": "25.25"
  },
  {
    "country": "RO",
    "name": "Măureni",
    "lat": "45.40389",
    "lng": "21.5025"
  },
  {
    "country": "RO",
    "name": "Mătești",
    "lat": "45.21339",
    "lng": "26.75607"
  },
  {
    "country": "RO",
    "name": "Matei",
    "lat": "46.98333",
    "lng": "24.26667"
  },
  {
    "country": "RO",
    "name": "Mateeşti",
    "lat": "45.06667",
    "lng": "23.85"
  },
  {
    "country": "RO",
    "name": "Matca",
    "lat": "45.85",
    "lng": "27.53333"
  },
  {
    "country": "RO",
    "name": "Mățău",
    "lat": "45.23565",
    "lng": "25.08286"
  },
  {
    "country": "RO",
    "name": "Mătăsaru",
    "lat": "44.71667",
    "lng": "25.41667"
  },
  {
    "country": "RO",
    "name": "Mătăsari",
    "lat": "44.85",
    "lng": "23.08333"
  },
  {
    "country": "RO",
    "name": "Mătăcina",
    "lat": "45.88333",
    "lng": "26.8"
  },
  {
    "country": "RO",
    "name": "Măstăcani",
    "lat": "45.78333",
    "lng": "28.03333"
  },
  {
    "country": "RO",
    "name": "Mastacăn",
    "lat": "46.78918",
    "lng": "26.48677"
  },
  {
    "country": "RO",
    "name": "Maşloc",
    "lat": "45.99806",
    "lng": "21.44972"
  },
  {
    "country": "RO",
    "name": "Mărunțișu",
    "lat": "45.2861",
    "lng": "26.35421"
  },
  {
    "country": "RO",
    "name": "Mărunţei",
    "lat": "44.2",
    "lng": "24.46667"
  },
  {
    "country": "RO",
    "name": "Măru",
    "lat": "45.47586",
    "lng": "22.45039"
  },
  {
    "country": "RO",
    "name": "Mărtiniş",
    "lat": "46.23333",
    "lng": "25.38333"
  },
  {
    "country": "RO",
    "name": "Mărtineşti",
    "lat": "45.81667",
    "lng": "23.13333"
  },
  {
    "country": "RO",
    "name": "Marpod",
    "lat": "45.86667",
    "lng": "24.5"
  },
  {
    "country": "RO",
    "name": "Măriței",
    "lat": "47.7527",
    "lng": "26.14626"
  },
  {
    "country": "RO",
    "name": "Mărişelu",
    "lat": "47.01667",
    "lng": "24.51667"
  },
  {
    "country": "RO",
    "name": "Mărişel",
    "lat": "46.65",
    "lng": "23.13333"
  },
  {
    "country": "RO",
    "name": "Marin",
    "lat": "47.12754",
    "lng": "22.81055"
  },
  {
    "country": "RO",
    "name": "Mărgineni Slobozia",
    "lat": "44.53121",
    "lng": "24.55675"
  },
  {
    "country": "RO",
    "name": "Mărgineni-Munteni",
    "lat": "46.6",
    "lng": "26.9"
  },
  {
    "country": "RO",
    "name": "Mărginenii de Sus",
    "lat": "44.93172",
    "lng": "25.75228"
  },
  {
    "country": "RO",
    "name": "Mărginenii de Jos",
    "lat": "44.9591",
    "lng": "25.75989"
  },
  {
    "country": "RO",
    "name": "Mărgineni",
    "lat": "46.9",
    "lng": "26.63333"
  },
  {
    "country": "RO",
    "name": "Mărgineni",
    "lat": "46.5876",
    "lng": "26.85095"
  },
  {
    "country": "RO",
    "name": "Marginea",
    "lat": "47.81667",
    "lng": "25.81667"
  },
  {
    "country": "RO",
    "name": "Margina",
    "lat": "45.85841",
    "lng": "22.26654"
  },
  {
    "country": "RO",
    "name": "Marghita",
    "lat": "47.35",
    "lng": "22.33333"
  },
  {
    "country": "RO",
    "name": "Mărgău",
    "lat": "46.75",
    "lng": "22.96667"
  },
  {
    "country": "RO",
    "name": "Mărgăriteşti",
    "lat": "45.43333",
    "lng": "26.83333"
  },
  {
    "country": "RO",
    "name": "Marga",
    "lat": "45.5",
    "lng": "22.51667"
  },
  {
    "country": "RO",
    "name": "Mareș",
    "lat": "44.77824",
    "lng": "24.79005"
  },
  {
    "country": "RO",
    "name": "Mărculești",
    "lat": "44.56698",
    "lng": "27.51562"
  },
  {
    "country": "RO",
    "name": "Mărcești",
    "lat": "44.80537",
    "lng": "25.70951"
  },
  {
    "country": "RO",
    "name": "Marca",
    "lat": "47.21667",
    "lng": "22.56667"
  },
  {
    "country": "RO",
    "name": "Măraşu",
    "lat": "44.85",
    "lng": "27.96667"
  },
  {
    "country": "RO",
    "name": "Mărășești",
    "lat": "45.88333",
    "lng": "27.23333"
  },
  {
    "country": "RO",
    "name": "Mărăcineni",
    "lat": "45.2",
    "lng": "26.8"
  },
  {
    "country": "RO",
    "name": "Mărăcineni",
    "lat": "44.9",
    "lng": "24.88333"
  },
  {
    "country": "RO",
    "name": "Mara",
    "lat": "47.75552",
    "lng": "23.83126"
  },
  {
    "country": "RO",
    "name": "Manoleasa",
    "lat": "47.98333",
    "lng": "27.06667"
  },
  {
    "country": "RO",
    "name": "Mangalia",
    "lat": "43.8",
    "lng": "28.58333"
  },
  {
    "country": "RO",
    "name": "Măneşti",
    "lat": "44.96667",
    "lng": "25.28333"
  },
  {
    "country": "RO",
    "name": "Măneşti",
    "lat": "44.86667",
    "lng": "25.85"
  },
  {
    "country": "RO",
    "name": "Măneciu-Ungureni",
    "lat": "45.31667",
    "lng": "25.98333"
  },
  {
    "country": "RO",
    "name": "Mănăștur",
    "lat": "46.00949",
    "lng": "21.13362"
  },
  {
    "country": "RO",
    "name": "Mănăştiur",
    "lat": "45.81667",
    "lng": "22.06667"
  },
  {
    "country": "RO",
    "name": "Manasia",
    "lat": "44.7",
    "lng": "26.66667"
  },
  {
    "country": "RO",
    "name": "Mănăilești",
    "lat": "45.02464",
    "lng": "24.12451"
  },
  {
    "country": "RO",
    "name": "Mamaia-Sat",
    "lat": "44.31159",
    "lng": "28.62546"
  },
  {
    "country": "RO",
    "name": "Măluşteni",
    "lat": "46.18333",
    "lng": "27.91667"
  },
  {
    "country": "RO",
    "name": "Malu Spart",
    "lat": "44.44391",
    "lng": "25.71758"
  },
  {
    "country": "RO",
    "name": "Malu Roșu",
    "lat": "44.78088",
    "lng": "26.57945"
  },
  {
    "country": "RO",
    "name": "Mălureni",
    "lat": "45.1",
    "lng": "24.8"
  },
  {
    "country": "RO",
    "name": "Malu Mare",
    "lat": "44.24182",
    "lng": "23.85321"
  },
  {
    "country": "RO",
    "name": "Malu cu Flori",
    "lat": "45.15",
    "lng": "25.2"
  },
  {
    "country": "RO",
    "name": "Malu",
    "lat": "43.81518",
    "lng": "25.81863"
  },
  {
    "country": "RO",
    "name": "Malovăţ",
    "lat": "44.70444",
    "lng": "22.73111"
  },
  {
    "country": "RO",
    "name": "Malnaş",
    "lat": "46.01667",
    "lng": "25.83333"
  },
  {
    "country": "RO",
    "name": "Mălini",
    "lat": "47.46667",
    "lng": "26.08333"
  },
  {
    "country": "RO",
    "name": "Mălâncrav",
    "lat": "46.11003",
    "lng": "24.6481"
  },
  {
    "country": "RO",
    "name": "Măldăreşti",
    "lat": "45.11667",
    "lng": "24"
  },
  {
    "country": "RO",
    "name": "Măldăeni",
    "lat": "44.11667",
    "lng": "24.93333"
  },
  {
    "country": "RO",
    "name": "Malcoci",
    "lat": "45.13851",
    "lng": "28.88824"
  },
  {
    "country": "RO",
    "name": "Malaia",
    "lat": "45.35",
    "lng": "24.03333"
  },
  {
    "country": "RO",
    "name": "Mal",
    "lat": "47.06979",
    "lng": "22.81441"
  },
  {
    "country": "RO",
    "name": "Mailat",
    "lat": "46.04189",
    "lng": "21.10702"
  },
  {
    "country": "RO",
    "name": "Măieruş",
    "lat": "45.9",
    "lng": "25.53333"
  },
  {
    "country": "RO",
    "name": "Măieru",
    "lat": "47.4",
    "lng": "24.75"
  },
  {
    "country": "RO",
    "name": "Măicăneşti",
    "lat": "45.5",
    "lng": "27.5"
  },
  {
    "country": "RO",
    "name": "Maia",
    "lat": "44.73616",
    "lng": "26.40151"
  },
  {
    "country": "RO",
    "name": "Mahmudia",
    "lat": "45.08333",
    "lng": "29.08333"
  },
  {
    "country": "RO",
    "name": "Măguri-Răcătău",
    "lat": "46.645",
    "lng": "23.197"
  },
  {
    "country": "RO",
    "name": "Măguri",
    "lat": "46.62849",
    "lng": "23.10294"
  },
  {
    "country": "RO",
    "name": "Măgureni",
    "lat": "45.06667",
    "lng": "25.73333"
  },
  {
    "country": "RO",
    "name": "Măgurele",
    "lat": "45.1",
    "lng": "26.03333"
  },
  {
    "country": "RO",
    "name": "Măgurele",
    "lat": "44.35",
    "lng": "26.03333"
  },
  {
    "country": "RO",
    "name": "Măgura Ilvei",
    "lat": "47.38333",
    "lng": "24.8"
  },
  {
    "country": "RO",
    "name": "Măgura",
    "lat": "46.56667",
    "lng": "26.85"
  },
  {
    "country": "RO",
    "name": "Măgura",
    "lat": "45.26667",
    "lng": "26.58333"
  },
  {
    "country": "RO",
    "name": "Măgura",
    "lat": "44.03333",
    "lng": "25.4"
  },
  {
    "country": "RO",
    "name": "Magula",
    "lat": "44.93185",
    "lng": "26.30114"
  },
  {
    "country": "RO",
    "name": "Maglavit",
    "lat": "44.03333",
    "lng": "23.1"
  },
  {
    "country": "RO",
    "name": "Măgireşti",
    "lat": "46.51667",
    "lng": "26.55"
  },
  {
    "country": "RO",
    "name": "Măgherani",
    "lat": "46.56667",
    "lng": "24.9"
  },
  {
    "country": "RO",
    "name": "Măgeşti",
    "lat": "47.01667",
    "lng": "22.45"
  },
  {
    "country": "RO",
    "name": "Mogești",
    "lat": "45.11667",
    "lng": "23.91667"
  },
  {
    "country": "RO",
    "name": "Măerişte",
    "lat": "47.31667",
    "lng": "22.8"
  },
  {
    "country": "RO",
    "name": "Mădulari",
    "lat": "45.03333",
    "lng": "24"
  },
  {
    "country": "RO",
    "name": "Mădârjac",
    "lat": "47.04994",
    "lng": "27.26182"
  },
  {
    "country": "RO",
    "name": "Măderat",
    "lat": "46.29493",
    "lng": "21.71137"
  },
  {
    "country": "RO",
    "name": "Mădăras",
    "lat": "47.68403",
    "lng": "22.86554"
  },
  {
    "country": "RO",
    "name": "Mădăraş",
    "lat": "46.83333",
    "lng": "21.68333"
  },
  {
    "country": "RO",
    "name": "Mădăraș",
    "lat": "46.60488",
    "lng": "24.43446"
  },
  {
    "country": "RO",
    "name": "Mădăraș",
    "lat": "46.49472",
    "lng": "25.7475"
  },
  {
    "country": "RO",
    "name": "Măcin",
    "lat": "45.24371",
    "lng": "28.13564"
  },
  {
    "country": "RO",
    "name": "Măceşu de Sus",
    "lat": "43.91667",
    "lng": "23.7"
  },
  {
    "country": "RO",
    "name": "Măceşu de Jos",
    "lat": "43.88333",
    "lng": "23.71667"
  },
  {
    "country": "RO",
    "name": "Macea",
    "lat": "46.38333",
    "lng": "21.3"
  },
  {
    "country": "RO",
    "name": "Lupşanu",
    "lat": "44.38333",
    "lng": "26.9"
  },
  {
    "country": "RO",
    "name": "Lupşa",
    "lat": "46.36667",
    "lng": "23.2"
  },
  {
    "country": "RO",
    "name": "Lupeni",
    "lat": "46.38333",
    "lng": "25.21667"
  },
  {
    "country": "RO",
    "name": "Lupeni",
    "lat": "45.36029",
    "lng": "23.23832"
  },
  {
    "country": "RO",
    "name": "Lupac",
    "lat": "45.28",
    "lng": "21.81278"
  },
  {
    "country": "RO",
    "name": "Lunguleţu",
    "lat": "44.61667",
    "lng": "25.65"
  },
  {
    "country": "RO",
    "name": "Lungeşti",
    "lat": "44.56667",
    "lng": "24.18333"
  },
  {
    "country": "RO",
    "name": "Lungani",
    "lat": "47.18333",
    "lng": "27.15"
  },
  {
    "country": "RO",
    "name": "Lunga",
    "lat": "46.01822",
    "lng": "26.21208"
  },
  {
    "country": "RO",
    "name": "Luncșoara",
    "lat": "47.03663",
    "lng": "22.54213"
  },
  {
    "country": "RO",
    "name": "Luncoiu de Jos",
    "lat": "46.1",
    "lng": "22.76667"
  },
  {
    "country": "RO",
    "name": "Luncaviţa",
    "lat": "45.28333",
    "lng": "28.26667"
  },
  {
    "country": "RO",
    "name": "Luncaviţa",
    "lat": "45.08333",
    "lng": "22.26667"
  },
  {
    "country": "RO",
    "name": "Lunca Priporului",
    "lat": "45.43909",
    "lng": "26.30869"
  },
  {
    "country": "RO",
    "name": "Lunca Prahovei",
    "lat": "45.04714",
    "lng": "25.77161"
  },
  {
    "country": "RO",
    "name": "Luncani",
    "lat": "46.47274",
    "lng": "23.95095"
  },
  {
    "country": "RO",
    "name": "Lunca Mureşului",
    "lat": "46.43333",
    "lng": "23.9"
  },
  {
    "country": "RO",
    "name": "Lunca Leșului",
    "lat": "47.30943",
    "lng": "24.77602"
  },
  {
    "country": "RO",
    "name": "Lunca la Tisa",
    "lat": "47.95213",
    "lng": "24.05216"
  },
  {
    "country": "RO",
    "name": "Lunca Jariștei",
    "lat": "45.47881",
    "lng": "26.26049"
  },
  {
    "country": "RO",
    "name": "Lunca Ilvei",
    "lat": "47.36667",
    "lng": "24.98333"
  },
  {
    "country": "RO",
    "name": "Lunca de Sus",
    "lat": "46.53333",
    "lng": "25.96667"
  },
  {
    "country": "RO",
    "name": "Lunca de Jos",
    "lat": "46.56667",
    "lng": "25.98333"
  },
  {
    "country": "RO",
    "name": "Lunca Corbului",
    "lat": "44.68391",
    "lng": "24.75855"
  },
  {
    "country": "RO",
    "name": "Lunca Cetățuii",
    "lat": "47.0966",
    "lng": "27.56319"
  },
  {
    "country": "RO",
    "name": "Lunca Cernii de Jos",
    "lat": "45.63333",
    "lng": "22.61667"
  },
  {
    "country": "RO",
    "name": "Lunca Bradului",
    "lat": "46.95595",
    "lng": "25.1114"
  },
  {
    "country": "RO",
    "name": "Lunca Banului",
    "lat": "46.595",
    "lng": "28.16833"
  },
  {
    "country": "RO",
    "name": "Lunca",
    "lat": "47.28144",
    "lng": "26.73708"
  },
  {
    "country": "RO",
    "name": "Lunca",
    "lat": "47.61667",
    "lng": "26.98333"
  },
  {
    "country": "RO",
    "name": "Lunca",
    "lat": "47.22765",
    "lng": "26.29979"
  },
  {
    "country": "RO",
    "name": "Lunca",
    "lat": "46.85",
    "lng": "24.56667"
  },
  {
    "country": "RO",
    "name": "Lunca",
    "lat": "46.51667",
    "lng": "22.46667"
  },
  {
    "country": "RO",
    "name": "Lunca",
    "lat": "45.20022",
    "lng": "25.44351"
  },
  {
    "country": "RO",
    "name": "Lunca",
    "lat": "45.00494",
    "lng": "27.21335"
  },
  {
    "country": "RO",
    "name": "Lunca",
    "lat": "44.73288",
    "lng": "28.77495"
  },
  {
    "country": "RO",
    "name": "Lunca",
    "lat": "43.83333",
    "lng": "24.76667"
  },
  {
    "country": "RO",
    "name": "Luna de Sus",
    "lat": "46.74313",
    "lng": "23.43539"
  },
  {
    "country": "RO",
    "name": "Luminiș",
    "lat": "46.81332",
    "lng": "26.45275"
  },
  {
    "country": "RO",
    "name": "Lumina",
    "lat": "44.28333",
    "lng": "28.56667"
  },
  {
    "country": "RO",
    "name": "Luizi-Călugăra",
    "lat": "46.53333",
    "lng": "26.83333"
  },
  {
    "country": "RO",
    "name": "Luica",
    "lat": "44.23333",
    "lng": "26.58333"
  },
  {
    "country": "RO",
    "name": "Lugoj",
    "lat": "45.68861",
    "lng": "21.90306"
  },
  {
    "country": "RO",
    "name": "Lugaşu de Jos",
    "lat": "47.06667",
    "lng": "22.35"
  },
  {
    "country": "RO",
    "name": "Lueta",
    "lat": "46.26667",
    "lng": "25.48333"
  },
  {
    "country": "RO",
    "name": "Luduş",
    "lat": "46.48333",
    "lng": "24.1"
  },
  {
    "country": "RO",
    "name": "Ludoş",
    "lat": "45.91667",
    "lng": "23.9"
  },
  {
    "country": "RO",
    "name": "Ludeşti",
    "lat": "44.86667",
    "lng": "25.23333"
  },
  {
    "country": "RO",
    "name": "Ludași",
    "lat": "46.61962",
    "lng": "26.57926"
  },
  {
    "country": "RO",
    "name": "Luciu",
    "lat": "44.96667",
    "lng": "27.08333"
  },
  {
    "country": "RO",
    "name": "Luciu",
    "lat": "44.74722",
    "lng": "27.7276"
  },
  {
    "country": "RO",
    "name": "Lucieni",
    "lat": "44.85",
    "lng": "25.43333"
  },
  {
    "country": "RO",
    "name": "Lucăceni",
    "lat": "47.74194",
    "lng": "22.47819"
  },
  {
    "country": "RO",
    "name": "Lozna",
    "lat": "47.95144",
    "lng": "26.27723"
  },
  {
    "country": "RO",
    "name": "Lozna",
    "lat": "47.31667",
    "lng": "23.46667"
  },
  {
    "country": "RO",
    "name": "Lovrin",
    "lat": "45.96806",
    "lng": "20.77028"
  },
  {
    "country": "RO",
    "name": "Lopătari",
    "lat": "45.48333",
    "lng": "26.58333"
  },
  {
    "country": "RO",
    "name": "Lopadea Nouă",
    "lat": "46.2909",
    "lng": "23.81901"
  },
  {
    "country": "RO",
    "name": "Loloiasca",
    "lat": "44.96808",
    "lng": "26.29141"
  },
  {
    "country": "RO",
    "name": "Logrești Moșteni",
    "lat": "44.90663",
    "lng": "23.7048"
  },
  {
    "country": "RO",
    "name": "Logreşti",
    "lat": "44.9",
    "lng": "23.7"
  },
  {
    "country": "RO",
    "name": "Loamneş",
    "lat": "45.93333",
    "lng": "24.1"
  },
  {
    "country": "RO",
    "name": "Livezi-Vale",
    "lat": "46.41667",
    "lng": "26.73333"
  },
  {
    "country": "RO",
    "name": "Livezile",
    "lat": "47.18333",
    "lng": "24.56667"
  },
  {
    "country": "RO",
    "name": "Livezile",
    "lat": "46.35",
    "lng": "23.63333"
  },
  {
    "country": "RO",
    "name": "Livezile",
    "lat": "45.39026",
    "lng": "21.05794"
  },
  {
    "country": "RO",
    "name": "Livezile",
    "lat": "44.51222",
    "lng": "22.86333"
  },
  {
    "country": "RO",
    "name": "Livezi",
    "lat": "46.40639",
    "lng": "26.73613"
  },
  {
    "country": "RO",
    "name": "Livezi",
    "lat": "44.84029",
    "lng": "23.82505"
  },
  {
    "country": "RO",
    "name": "Livezeni",
    "lat": "46.55",
    "lng": "24.63333"
  },
  {
    "country": "RO",
    "name": "Livezeni",
    "lat": "45.03838",
    "lng": "24.97676"
  },
  {
    "country": "RO",
    "name": "Livadia",
    "lat": "45.20546",
    "lng": "24.24192"
  },
  {
    "country": "RO",
    "name": "Livadea",
    "lat": "45.18663",
    "lng": "25.92805"
  },
  {
    "country": "RO",
    "name": "Livada de Bihor",
    "lat": "47.01039",
    "lng": "21.80836"
  },
  {
    "country": "RO",
    "name": "Livada",
    "lat": "47.86667",
    "lng": "23.13333"
  },
  {
    "country": "RO",
    "name": "Livada",
    "lat": "46.22284",
    "lng": "21.38403"
  },
  {
    "country": "RO",
    "name": "Liubcova",
    "lat": "44.65885",
    "lng": "21.89559"
  },
  {
    "country": "RO",
    "name": "Liteni",
    "lat": "47.56667",
    "lng": "26.2"
  },
  {
    "country": "RO",
    "name": "Liteni",
    "lat": "47.52049",
    "lng": "26.5283"
  },
  {
    "country": "RO",
    "name": "Liteni",
    "lat": "47.30169",
    "lng": "27.03837"
  },
  {
    "country": "RO",
    "name": "Liţa",
    "lat": "43.8",
    "lng": "24.81667"
  },
  {
    "country": "RO",
    "name": "Lișteava",
    "lat": "43.83418",
    "lng": "23.92022"
  },
  {
    "country": "RO",
    "name": "Lisa",
    "lat": "45.71667",
    "lng": "24.85"
  },
  {
    "country": "RO",
    "name": "Lisa",
    "lat": "43.8",
    "lng": "25.13333"
  },
  {
    "country": "RO",
    "name": "Lipovu",
    "lat": "44.1",
    "lng": "23.63333"
  },
  {
    "country": "RO",
    "name": "Lipovăţ",
    "lat": "46.56667",
    "lng": "27.7"
  },
  {
    "country": "RO",
    "name": "Lipova",
    "lat": "46.71667",
    "lng": "27.23333"
  },
  {
    "country": "RO",
    "name": "Lipova",
    "lat": "46.09085",
    "lng": "21.69628"
  },
  {
    "country": "RO",
    "name": "Lipniţa",
    "lat": "44.1",
    "lng": "27.6"
  },
  {
    "country": "RO",
    "name": "Lipia",
    "lat": "45.1397",
    "lng": "26.73505"
  },
  {
    "country": "RO",
    "name": "Lipia",
    "lat": "44.71003",
    "lng": "26.26445"
  },
  {
    "country": "RO",
    "name": "Lipăneşti",
    "lat": "45.05",
    "lng": "26.01667"
  },
  {
    "country": "RO",
    "name": "Izvoru",
    "lat": "45.19249",
    "lng": "26.59154"
  },
  {
    "country": "RO",
    "name": "Limpeziș",
    "lat": "44.95357",
    "lng": "26.7049"
  },
  {
    "country": "RO",
    "name": "Limanu",
    "lat": "43.8",
    "lng": "28.53333"
  },
  {
    "country": "RO",
    "name": "Liliești",
    "lat": "45.03458",
    "lng": "25.88554"
  },
  {
    "country": "RO",
    "name": "Lilieci",
    "lat": "46.62861",
    "lng": "26.87176"
  },
  {
    "country": "RO",
    "name": "Lieşti",
    "lat": "45.61667",
    "lng": "27.51667"
  },
  {
    "country": "RO",
    "name": "Liebling",
    "lat": "45.5775",
    "lng": "21.32167"
  },
  {
    "country": "RO",
    "name": "Licurici",
    "lat": "44.91667",
    "lng": "23.61667"
  },
  {
    "country": "RO",
    "name": "Libotin",
    "lat": "47.50541",
    "lng": "23.96833"
  },
  {
    "country": "RO",
    "name": "Leu",
    "lat": "44.18333",
    "lng": "24"
  },
  {
    "country": "RO",
    "name": "Letea Veche",
    "lat": "46.55",
    "lng": "26.95"
  },
  {
    "country": "RO",
    "name": "Letca Veche",
    "lat": "44.19911",
    "lng": "25.68681"
  },
  {
    "country": "RO",
    "name": "Letca Nouă",
    "lat": "44.23496",
    "lng": "25.74262"
  },
  {
    "country": "RO",
    "name": "Leţcani",
    "lat": "47.18333",
    "lng": "27.41667"
  },
  {
    "country": "RO",
    "name": "Letca",
    "lat": "47.33333",
    "lng": "23.45"
  },
  {
    "country": "RO",
    "name": "Leşu",
    "lat": "47.31667",
    "lng": "24.75"
  },
  {
    "country": "RO",
    "name": "Lespezi",
    "lat": "47.36667",
    "lng": "26.7"
  },
  {
    "country": "RO",
    "name": "Lespezi",
    "lat": "46.66493",
    "lng": "26.76882"
  },
  {
    "country": "RO",
    "name": "Lespezi",
    "lat": "46.16027",
    "lng": "27.24065"
  },
  {
    "country": "RO",
    "name": "Lereşti",
    "lat": "45.33333",
    "lng": "25.06667"
  },
  {
    "country": "RO",
    "name": "Leordina",
    "lat": "47.78333",
    "lng": "24.25"
  },
  {
    "country": "RO",
    "name": "Leordeni",
    "lat": "44.78333",
    "lng": "25.11667"
  },
  {
    "country": "RO",
    "name": "Leorda",
    "lat": "47.81667",
    "lng": "26.45"
  },
  {
    "country": "RO",
    "name": "Lenauheim",
    "lat": "45.87194",
    "lng": "20.79944"
  },
  {
    "country": "RO",
    "name": "Lemnia",
    "lat": "46.05",
    "lng": "26.26667"
  },
  {
    "country": "RO",
    "name": "Leliceni",
    "lat": "46.34713",
    "lng": "25.84782"
  },
  {
    "country": "RO",
    "name": "Leleşti",
    "lat": "45.1",
    "lng": "23.2"
  },
  {
    "country": "RO",
    "name": "Lelese",
    "lat": "45.73333",
    "lng": "22.7"
  },
  {
    "country": "RO",
    "name": "Leleasca",
    "lat": "44.78333",
    "lng": "24.43333"
  },
  {
    "country": "RO",
    "name": "Leicești",
    "lat": "45.09586",
    "lng": "24.86108"
  },
  {
    "country": "RO",
    "name": "Lehliu-Gară",
    "lat": "44.43333",
    "lng": "26.85"
  },
  {
    "country": "RO",
    "name": "Lehliu",
    "lat": "44.46667",
    "lng": "26.81667"
  },
  {
    "country": "RO",
    "name": "Lechinţa",
    "lat": "47.01667",
    "lng": "24.35"
  },
  {
    "country": "RO",
    "name": "Lazuri de Beiuş",
    "lat": "46.58333",
    "lng": "22.4"
  },
  {
    "country": "RO",
    "name": "Lazuri",
    "lat": "47.85",
    "lng": "22.86667"
  },
  {
    "country": "RO",
    "name": "Lazuri",
    "lat": "44.87859",
    "lng": "25.54964"
  },
  {
    "country": "RO",
    "name": "Lăzărești",
    "lat": "45.15659",
    "lng": "24.9954"
  },
  {
    "country": "RO",
    "name": "Lăzăreni",
    "lat": "46.86667",
    "lng": "22.06667"
  },
  {
    "country": "RO",
    "name": "Lăzarea",
    "lat": "46.75",
    "lng": "25.53333"
  },
  {
    "country": "RO",
    "name": "Laza",
    "lat": "46.65",
    "lng": "27.58333"
  },
  {
    "country": "RO",
    "name": "Laslea",
    "lat": "46.21667",
    "lng": "24.65"
  },
  {
    "country": "RO",
    "name": "Largu",
    "lat": "44.96667",
    "lng": "27.15"
  },
  {
    "country": "RO",
    "name": "Larga",
    "lat": "46.3506",
    "lng": "26.53321"
  },
  {
    "country": "RO",
    "name": "Lăpuşnicu Mare",
    "lat": "44.91306",
    "lng": "21.94417"
  },
  {
    "country": "RO",
    "name": "Lăpuşnicel",
    "lat": "44.98306",
    "lng": "22.22694"
  },
  {
    "country": "RO",
    "name": "Lăpușel",
    "lat": "47.6183",
    "lng": "23.47913"
  },
  {
    "country": "RO",
    "name": "Lăpuş",
    "lat": "47.5",
    "lng": "24.01667"
  },
  {
    "country": "RO",
    "name": "Lăpugiu de Jos",
    "lat": "45.88333",
    "lng": "22.48333"
  },
  {
    "country": "RO",
    "name": "Lapoș",
    "lat": "45.15197",
    "lng": "26.41911"
  },
  {
    "country": "RO",
    "name": "Lăpoș",
    "lat": "46.39363",
    "lng": "26.46245"
  },
  {
    "country": "RO",
    "name": "Lanurile",
    "lat": "45.04149",
    "lng": "27.74916"
  },
  {
    "country": "RO",
    "name": "Lancrăm",
    "lat": "45.98708",
    "lng": "23.55665"
  },
  {
    "country": "RO",
    "name": "Lămășeni",
    "lat": "47.49322",
    "lng": "26.22806"
  },
  {
    "country": "RO",
    "name": "Laloşu",
    "lat": "44.55",
    "lng": "24.01667"
  },
  {
    "country": "RO",
    "name": "Lădeşti",
    "lat": "44.88333",
    "lng": "24.05"
  },
  {
    "country": "RO",
    "name": "Lăcusteni",
    "lat": "44.69544",
    "lng": "23.89984"
  },
  {
    "country": "RO",
    "name": "Lăcusteni",
    "lat": "44.60715",
    "lng": "27.67569"
  },
  {
    "country": "RO",
    "name": "Lacu Sărat",
    "lat": "45.21867",
    "lng": "27.88764"
  },
  {
    "country": "RO",
    "name": "Lăculețe",
    "lat": "45.01837",
    "lng": "25.43108"
  },
  {
    "country": "RO",
    "name": "Lăceni",
    "lat": "44.08466",
    "lng": "25.3327"
  },
  {
    "country": "RO",
    "name": "Jurilovca",
    "lat": "44.76667",
    "lng": "28.86667"
  },
  {
    "country": "RO",
    "name": "Jupânești",
    "lat": "45.06667",
    "lng": "24.85"
  },
  {
    "country": "RO",
    "name": "Jupâneşti",
    "lat": "44.9",
    "lng": "23.53333"
  },
  {
    "country": "RO",
    "name": "Jugureni",
    "lat": "45.1",
    "lng": "26.45"
  },
  {
    "country": "RO",
    "name": "Jugureanu",
    "lat": "44.94313",
    "lng": "27.27878"
  },
  {
    "country": "RO",
    "name": "Jugur",
    "lat": "45.19255",
    "lng": "25.08493"
  },
  {
    "country": "RO",
    "name": "Josenii Bârgăului",
    "lat": "47.21667",
    "lng": "24.68333"
  },
  {
    "country": "RO",
    "name": "Joseni",
    "lat": "46.7",
    "lng": "25.5"
  },
  {
    "country": "RO",
    "name": "Jorăşti",
    "lat": "45.98333",
    "lng": "27.86667"
  },
  {
    "country": "RO",
    "name": "Jorăști",
    "lat": "45.71477",
    "lng": "27.26335"
  },
  {
    "country": "RO",
    "name": "Joldești",
    "lat": "47.56004",
    "lng": "26.57705"
  },
  {
    "country": "RO",
    "name": "Joiţa",
    "lat": "44.49417",
    "lng": "25.85389"
  },
  {
    "country": "RO",
    "name": "Jiu-Paroșeni",
    "lat": "45.36175",
    "lng": "23.26044"
  },
  {
    "country": "RO",
    "name": "Jitia",
    "lat": "45.58333",
    "lng": "26.71667"
  },
  {
    "country": "RO",
    "name": "Jirov",
    "lat": "44.67098",
    "lng": "23.08693"
  },
  {
    "country": "RO",
    "name": "Jirlău",
    "lat": "45.16667",
    "lng": "27.16667"
  },
  {
    "country": "RO",
    "name": "Jina",
    "lat": "45.78333",
    "lng": "23.68333"
  },
  {
    "country": "RO",
    "name": "Jimbolia",
    "lat": "45.79139",
    "lng": "20.71722"
  },
  {
    "country": "RO",
    "name": "Jilavele",
    "lat": "44.76667",
    "lng": "26.53333"
  },
  {
    "country": "RO",
    "name": "Jilava",
    "lat": "44.33333",
    "lng": "26.07806"
  },
  {
    "country": "RO",
    "name": "Jijila",
    "lat": "45.3",
    "lng": "28.15"
  },
  {
    "country": "RO",
    "name": "Jieni",
    "lat": "43.95095",
    "lng": "24.59349"
  },
  {
    "country": "RO",
    "name": "Jidvei",
    "lat": "46.21667",
    "lng": "24.1"
  },
  {
    "country": "RO",
    "name": "Jidoștița",
    "lat": "44.71582",
    "lng": "22.59311"
  },
  {
    "country": "RO",
    "name": "Jichişu de Jos",
    "lat": "47.11667",
    "lng": "23.8"
  },
  {
    "country": "RO",
    "name": "Jibou",
    "lat": "47.25896",
    "lng": "23.25651"
  },
  {
    "country": "RO",
    "name": "Jiblea Veche",
    "lat": "45.2436",
    "lng": "24.35163"
  },
  {
    "country": "RO",
    "name": "Jibert",
    "lat": "46",
    "lng": "25.06667"
  },
  {
    "country": "RO",
    "name": "Jiana Veche",
    "lat": "44.39083",
    "lng": "22.66861"
  },
  {
    "country": "RO",
    "name": "Jiana",
    "lat": "44.40184",
    "lng": "22.71278"
  },
  {
    "country": "RO",
    "name": "Jegălia",
    "lat": "44.3",
    "lng": "27.63333"
  },
  {
    "country": "RO",
    "name": "Jebel",
    "lat": "45.55556",
    "lng": "21.21361"
  },
  {
    "country": "RO",
    "name": "Jariştea",
    "lat": "45.78333",
    "lng": "27.06667"
  },
  {
    "country": "RO",
    "name": "Jamu Mare",
    "lat": "45.25417",
    "lng": "21.41694"
  },
  {
    "country": "RO",
    "name": "Jabenița",
    "lat": "46.78407",
    "lng": "24.79671"
  },
  {
    "country": "RO",
    "name": "Izvoru Dulce",
    "lat": "45.34178",
    "lng": "26.7773"
  },
  {
    "country": "RO",
    "name": "Izvoru de Sus",
    "lat": "44.81667",
    "lng": "24.65"
  },
  {
    "country": "RO",
    "name": "Izvoru Crişului",
    "lat": "46.83333",
    "lng": "23.1"
  },
  {
    "country": "RO",
    "name": "Izvoru Bârzii",
    "lat": "44.70667",
    "lng": "22.67417"
  },
  {
    "country": "RO",
    "name": "Izvoru Berheciului",
    "lat": "46.58333",
    "lng": "27.21667"
  },
  {
    "country": "RO",
    "name": "Izvoru",
    "lat": "44.49414",
    "lng": "25.0647"
  },
  {
    "country": "RO",
    "name": "Izvoarele Sucevei",
    "lat": "47.75",
    "lng": "25.18333"
  },
  {
    "country": "RO",
    "name": "Izvoarele",
    "lat": "47.04241",
    "lng": "26.9023"
  },
  {
    "country": "RO",
    "name": "Izvoarele",
    "lat": "46.17011",
    "lng": "23.90377"
  },
  {
    "country": "RO",
    "name": "Izvoarele",
    "lat": "45.03333",
    "lng": "28.53333"
  },
  {
    "country": "RO",
    "name": "Izvoarele",
    "lat": "45.03333",
    "lng": "25.26667"
  },
  {
    "country": "RO",
    "name": "Izvoarele",
    "lat": "44.30958",
    "lng": "22.66348"
  },
  {
    "country": "RO",
    "name": "Izvoarele",
    "lat": "44.26667",
    "lng": "24.51667"
  },
  {
    "country": "RO",
    "name": "Izvoarele",
    "lat": "44.16968",
    "lng": "26.31374"
  },
  {
    "country": "RO",
    "name": "Izvoarele",
    "lat": "44.03389",
    "lng": "25.77472"
  },
  {
    "country": "RO",
    "name": "Izvoarele",
    "lat": "43.81667",
    "lng": "25.38333"
  },
  {
    "country": "RO",
    "name": "Izvoare",
    "lat": "46.91013",
    "lng": "26.47014"
  },
  {
    "country": "RO",
    "name": "Izvoare",
    "lat": "46.74699",
    "lng": "26.80221"
  },
  {
    "country": "RO",
    "name": "Izvoare",
    "lat": "44.14773",
    "lng": "23.29582"
  },
  {
    "country": "RO",
    "name": "Izvin",
    "lat": "45.80034",
    "lng": "21.46066"
  },
  {
    "country": "RO",
    "name": "Izimșa",
    "lat": "44.17819",
    "lng": "22.95649"
  },
  {
    "country": "RO",
    "name": "Izbiceni",
    "lat": "43.83333",
    "lng": "24.65"
  },
  {
    "country": "RO",
    "name": "Iveşti",
    "lat": "46.18333",
    "lng": "27.53333"
  },
  {
    "country": "RO",
    "name": "Iveşti",
    "lat": "45.68333",
    "lng": "27.51667"
  },
  {
    "country": "RO",
    "name": "Ivănești",
    "lat": "46.63481",
    "lng": "27.46048"
  },
  {
    "country": "RO",
    "name": "Iugani",
    "lat": "47.04431",
    "lng": "26.82891"
  },
  {
    "country": "RO",
    "name": "Viile Tecii",
    "lat": "46.93333",
    "lng": "24.48333"
  },
  {
    "country": "RO",
    "name": "Iteşti",
    "lat": "46.65309",
    "lng": "26.87256"
  },
  {
    "country": "RO",
    "name": "Isverna",
    "lat": "44.97972",
    "lng": "22.62917"
  },
  {
    "country": "RO",
    "name": "Istria",
    "lat": "44.56667",
    "lng": "28.71667"
  },
  {
    "country": "RO",
    "name": "Islaz",
    "lat": "44.46117",
    "lng": "26.38724"
  },
  {
    "country": "RO",
    "name": "Islaz",
    "lat": "43.73333",
    "lng": "24.75"
  },
  {
    "country": "RO",
    "name": "Iscroni",
    "lat": "45.37794",
    "lng": "23.34201"
  },
  {
    "country": "RO",
    "name": "Işalniţa",
    "lat": "44.4",
    "lng": "23.73333"
  },
  {
    "country": "RO",
    "name": "Isaccea",
    "lat": "45.26667",
    "lng": "28.46667"
  },
  {
    "country": "RO",
    "name": "Irești",
    "lat": "45.92993",
    "lng": "26.94393"
  },
  {
    "country": "RO",
    "name": "Iratoşu",
    "lat": "46.31667",
    "lng": "21.2"
  },
  {
    "country": "RO",
    "name": "Ipoteşti",
    "lat": "47.61667",
    "lng": "26.28333"
  },
  {
    "country": "RO",
    "name": "Ipotești",
    "lat": "44.32529",
    "lng": "24.40089"
  },
  {
    "country": "RO",
    "name": "Ipatele",
    "lat": "46.91667",
    "lng": "27.41667"
  },
  {
    "country": "RO",
    "name": "Ip",
    "lat": "47.23333",
    "lng": "22.65"
  },
  {
    "country": "RO",
    "name": "Iordăcheanu",
    "lat": "45.04392",
    "lng": "26.2392"
  },
  {
    "country": "RO",
    "name": "Ion Roată",
    "lat": "44.66667",
    "lng": "26.76667"
  },
  {
    "country": "RO",
    "name": "Ion Neculce",
    "lat": "47.20344",
    "lng": "27.05268"
  },
  {
    "country": "RO",
    "name": "I. L. Caragiale",
    "lat": "44.90963",
    "lng": "25.70251"
  },
  {
    "country": "RO",
    "name": "Ioneşti",
    "lat": "44.85",
    "lng": "24.23333"
  },
  {
    "country": "RO",
    "name": "Ionești",
    "lat": "44.69374",
    "lng": "25.2778"
  },
  {
    "country": "RO",
    "name": "Ioneşti",
    "lat": "44.61667",
    "lng": "23.43333"
  },
  {
    "country": "RO",
    "name": "Ion Corvin",
    "lat": "44.11667",
    "lng": "27.8"
  },
  {
    "country": "RO",
    "name": "Ionășeni",
    "lat": "47.73029",
    "lng": "26.99329"
  },
  {
    "country": "RO",
    "name": "Iojib",
    "lat": "47.81617",
    "lng": "23.15603"
  },
  {
    "country": "RO",
    "name": "Intregalde",
    "lat": "46.25",
    "lng": "23.41667"
  },
  {
    "country": "RO",
    "name": "Întorsura Buzăului",
    "lat": "45.68333",
    "lng": "26.03333"
  },
  {
    "country": "RO",
    "name": "Întorsura",
    "lat": "44.11226",
    "lng": "23.57574"
  },
  {
    "country": "RO",
    "name": "Însurăţei",
    "lat": "44.91667",
    "lng": "27.6"
  },
  {
    "country": "RO",
    "name": "Inotești",
    "lat": "44.96146",
    "lng": "26.35782"
  },
  {
    "country": "RO",
    "name": "Ineu",
    "lat": "47.08333",
    "lng": "22.11667"
  },
  {
    "country": "RO",
    "name": "Ineu",
    "lat": "46.5453",
    "lng": "25.76357"
  },
  {
    "country": "RO",
    "name": "Ineu",
    "lat": "46.43372",
    "lng": "21.84048"
  },
  {
    "country": "RO",
    "name": "Independenţa",
    "lat": "45.48333",
    "lng": "27.75"
  },
  {
    "country": "RO",
    "name": "Independenţa",
    "lat": "44.28333",
    "lng": "27.15"
  },
  {
    "country": "RO",
    "name": "Independenţa",
    "lat": "43.96667",
    "lng": "28.08333"
  },
  {
    "country": "RO",
    "name": "Imper",
    "lat": "46.21667",
    "lng": "26.1"
  },
  {
    "country": "RO",
    "name": "Ilva Mică",
    "lat": "47.31667",
    "lng": "24.66667"
  },
  {
    "country": "RO",
    "name": "Ilva Mare",
    "lat": "47.36667",
    "lng": "24.9"
  },
  {
    "country": "RO",
    "name": "Iloviţa",
    "lat": "44.75639",
    "lng": "22.47278"
  },
  {
    "country": "RO",
    "name": "Ilovăț",
    "lat": "44.81197",
    "lng": "22.76333"
  },
  {
    "country": "RO",
    "name": "Ilișești",
    "lat": "47.60878",
    "lng": "26.05061"
  },
  {
    "country": "RO",
    "name": "Ilieni",
    "lat": "45.8",
    "lng": "25.76667"
  },
  {
    "country": "RO",
    "name": "Ilia",
    "lat": "45.93333",
    "lng": "22.65"
  },
  {
    "country": "RO",
    "name": "Ileanda",
    "lat": "47.33333",
    "lng": "23.63333"
  },
  {
    "country": "RO",
    "name": "Ileana",
    "lat": "44.51667",
    "lng": "26.66667"
  },
  {
    "country": "RO",
    "name": "Ilba",
    "lat": "47.7128",
    "lng": "23.35765"
  },
  {
    "country": "RO",
    "name": "Igriș",
    "lat": "46.11313",
    "lng": "20.78496"
  },
  {
    "country": "RO",
    "name": "Igoiu",
    "lat": "45.04824",
    "lng": "23.80835"
  },
  {
    "country": "RO",
    "name": "Igneşti",
    "lat": "46.4",
    "lng": "22.16667"
  },
  {
    "country": "RO",
    "name": "Ighiu",
    "lat": "46.15",
    "lng": "23.51667"
  },
  {
    "country": "RO",
    "name": "Ighișu Nou",
    "lat": "46.11121",
    "lng": "24.3492"
  },
  {
    "country": "RO",
    "name": "Ighiel",
    "lat": "46.1468",
    "lng": "23.47968"
  },
  {
    "country": "RO",
    "name": "Igești",
    "lat": "45.82043",
    "lng": "27.18253"
  },
  {
    "country": "RO",
    "name": "Iezeru",
    "lat": "44.28617",
    "lng": "27.62447"
  },
  {
    "country": "RO",
    "name": "Ieud",
    "lat": "47.67796",
    "lng": "24.23399"
  },
  {
    "country": "RO",
    "name": "Iernuțeni",
    "lat": "46.76387",
    "lng": "24.71919"
  },
  {
    "country": "RO",
    "name": "Iernut",
    "lat": "46.45",
    "lng": "24.25"
  },
  {
    "country": "RO",
    "name": "Iecea Mică",
    "lat": "45.82147",
    "lng": "20.92322"
  },
  {
    "country": "RO",
    "name": "Iecea Mare",
    "lat": "45.85074",
    "lng": "20.8931"
  },
  {
    "country": "RO",
    "name": "Ideciu de Jos",
    "lat": "46.8",
    "lng": "24.75"
  },
  {
    "country": "RO",
    "name": "Icuseşti",
    "lat": "46.8",
    "lng": "26.93333"
  },
  {
    "country": "RO",
    "name": "Icușeni",
    "lat": "47.59269",
    "lng": "26.59605"
  },
  {
    "country": "RO",
    "name": "Icoana",
    "lat": "44.49309",
    "lng": "25.74623"
  },
  {
    "country": "RO",
    "name": "Icoana",
    "lat": "44.41667",
    "lng": "24.71667"
  },
  {
    "country": "RO",
    "name": "Iclod",
    "lat": "46.98333",
    "lng": "23.8"
  },
  {
    "country": "RO",
    "name": "Iclănzel",
    "lat": "46.53333",
    "lng": "24.28333"
  },
  {
    "country": "RO",
    "name": "Ibrianu",
    "lat": "44.77509",
    "lng": "25.84375"
  },
  {
    "country": "RO",
    "name": "Ibănești-Pădure",
    "lat": "46.75893",
    "lng": "24.98676"
  },
  {
    "country": "RO",
    "name": "Ibăneşti",
    "lat": "48.06667",
    "lng": "26.36667"
  },
  {
    "country": "RO",
    "name": "Ibăneşti",
    "lat": "46.76667",
    "lng": "24.93333"
  },
  {
    "country": "RO",
    "name": "Ibănești",
    "lat": "46.39482",
    "lng": "27.62548"
  },
  {
    "country": "RO",
    "name": "Iazurile",
    "lat": "45.02162",
    "lng": "28.94281"
  },
  {
    "country": "RO",
    "name": "Iazu Nou",
    "lat": "47.48272",
    "lng": "27.20913"
  },
  {
    "country": "RO",
    "name": "Iazu",
    "lat": "44.7312",
    "lng": "27.42074"
  },
  {
    "country": "RO",
    "name": "Iazu",
    "lat": "44.71764",
    "lng": "25.83119"
  },
  {
    "country": "RO",
    "name": "Iaslovăț",
    "lat": "47.75862",
    "lng": "25.97742"
  },
  {
    "country": "RO",
    "name": "Iaşi",
    "lat": "47.16667",
    "lng": "27.6"
  },
  {
    "country": "RO",
    "name": "Iara",
    "lat": "46.55",
    "lng": "23.51667"
  },
  {
    "country": "RO",
    "name": "Iapa",
    "lat": "47.92513",
    "lng": "23.82539"
  },
  {
    "country": "RO",
    "name": "Ianoșda",
    "lat": "46.83791",
    "lng": "21.80778"
  },
  {
    "country": "RO",
    "name": "Iancu Jianu",
    "lat": "44.5",
    "lng": "24.03333"
  },
  {
    "country": "RO",
    "name": "Ianca",
    "lat": "45.13333",
    "lng": "27.45"
  },
  {
    "country": "RO",
    "name": "Ianca",
    "lat": "43.78333",
    "lng": "24.18333"
  },
  {
    "country": "RO",
    "name": "Iana",
    "lat": "46.38333",
    "lng": "27.55"
  },
  {
    "country": "RO",
    "name": "Iadăra",
    "lat": "47.47927",
    "lng": "23.39893"
  },
  {
    "country": "RO",
    "name": "Iacobeni",
    "lat": "47.86115",
    "lng": "26.91304"
  },
  {
    "country": "RO",
    "name": "Iacobeni",
    "lat": "47.43333",
    "lng": "25.31667"
  },
  {
    "country": "RO",
    "name": "Iacobeni",
    "lat": "46.05",
    "lng": "24.71667"
  },
  {
    "country": "RO",
    "name": "Iablaniţa",
    "lat": "44.95028",
    "lng": "22.31417"
  },
  {
    "country": "RO",
    "name": "Huta Certeze",
    "lat": "47.92583",
    "lng": "23.48715"
  },
  {
    "country": "RO",
    "name": "Husnicioara",
    "lat": "44.67806",
    "lng": "22.8425"
  },
  {
    "country": "RO",
    "name": "Huşi",
    "lat": "46.67361",
    "lng": "28.05944"
  },
  {
    "country": "RO",
    "name": "Husasău de Tinca",
    "lat": "46.81667",
    "lng": "21.91667"
  },
  {
    "country": "RO",
    "name": "Hurjuieni",
    "lat": "47.91667",
    "lng": "25.81667"
  },
  {
    "country": "RO",
    "name": "Huruiești",
    "lat": "46.26667",
    "lng": "27.25"
  },
  {
    "country": "RO",
    "name": "Hurezani",
    "lat": "44.8",
    "lng": "23.65"
  },
  {
    "country": "RO",
    "name": "Hunia",
    "lat": "44.05532",
    "lng": "23.09893"
  },
  {
    "country": "RO",
    "name": "Hunedoara",
    "lat": "45.75",
    "lng": "22.9"
  },
  {
    "country": "RO",
    "name": "Humoreni",
    "lat": "47.66667",
    "lng": "25.98333"
  },
  {
    "country": "RO",
    "name": "Humulești",
    "lat": "47.19846",
    "lng": "26.35273"
  },
  {
    "country": "RO",
    "name": "Humele",
    "lat": "44.52612",
    "lng": "24.97714"
  },
  {
    "country": "RO",
    "name": "Hulubeşti",
    "lat": "44.83333",
    "lng": "25.23333"
  },
  {
    "country": "RO",
    "name": "Huedin",
    "lat": "46.86667",
    "lng": "23.05"
  },
  {
    "country": "RO",
    "name": "Hudeşti",
    "lat": "48.15",
    "lng": "26.5"
  },
  {
    "country": "RO",
    "name": "Hotarele",
    "lat": "44.1725",
    "lng": "26.37028"
  },
  {
    "country": "RO",
    "name": "Hotar",
    "lat": "47.01967",
    "lng": "22.28515"
  },
  {
    "country": "RO",
    "name": "Horodnic de Sus",
    "lat": "47.84012",
    "lng": "25.82354"
  },
  {
    "country": "RO",
    "name": "Horodnic de Jos",
    "lat": "47.86523",
    "lng": "25.81856"
  },
  {
    "country": "RO",
    "name": "Horodniceni",
    "lat": "47.53333",
    "lng": "26.16667"
  },
  {
    "country": "RO",
    "name": "Horoatu Crasnei",
    "lat": "47.13333",
    "lng": "22.88333"
  },
  {
    "country": "RO",
    "name": "Horleşti",
    "lat": "47.11667",
    "lng": "27.36667"
  },
  {
    "country": "RO",
    "name": "Horia",
    "lat": "46.20847",
    "lng": "21.46287"
  },
  {
    "country": "RO",
    "name": "Horia",
    "lat": "45.01667",
    "lng": "28.45"
  },
  {
    "country": "RO",
    "name": "Horia",
    "lat": "44.63333",
    "lng": "28.11667"
  },
  {
    "country": "RO",
    "name": "Horgeşti",
    "lat": "46.43333",
    "lng": "27.06667"
  },
  {
    "country": "RO",
    "name": "Horezu",
    "lat": "45.15",
    "lng": "24.01667"
  },
  {
    "country": "RO",
    "name": "Hopârta",
    "lat": "46.32134",
    "lng": "23.87244"
  },
  {
    "country": "RO",
    "name": "Homorodu de Jos",
    "lat": "47.66667",
    "lng": "23.08333"
  },
  {
    "country": "RO",
    "name": "Homorod",
    "lat": "46.05",
    "lng": "25.26667"
  },
  {
    "country": "RO",
    "name": "Homorâciu",
    "lat": "45.2694",
    "lng": "26.01634"
  },
  {
    "country": "RO",
    "name": "Homocea",
    "lat": "46.13333",
    "lng": "27.23333"
  },
  {
    "country": "RO",
    "name": "Holt",
    "lat": "46.57856",
    "lng": "26.97499"
  },
  {
    "country": "RO",
    "name": "Holod",
    "lat": "46.78333",
    "lng": "22.13333"
  },
  {
    "country": "RO",
    "name": "Holboca",
    "lat": "47.15",
    "lng": "27.7"
  },
  {
    "country": "RO",
    "name": "Holbav",
    "lat": "45.65922",
    "lng": "25.38744"
  },
  {
    "country": "RO",
    "name": "Hoghiz",
    "lat": "45.98333",
    "lng": "25.3"
  },
  {
    "country": "RO",
    "name": "Hoghilag",
    "lat": "46.23333",
    "lng": "24.61667"
  },
  {
    "country": "RO",
    "name": "Hodoșa",
    "lat": "46.86558",
    "lng": "25.4462"
  },
  {
    "country": "RO",
    "name": "Hodoşa",
    "lat": "46.63333",
    "lng": "24.81667"
  },
  {
    "country": "RO",
    "name": "Hodora",
    "lat": "47.33712",
    "lng": "27.0197"
  },
  {
    "country": "RO",
    "name": "Hodoni",
    "lat": "45.90646",
    "lng": "21.08851"
  },
  {
    "country": "RO",
    "name": "Hodod",
    "lat": "47.4",
    "lng": "23.03333"
  },
  {
    "country": "RO",
    "name": "Hodac",
    "lat": "46.76667",
    "lng": "24.91667"
  },
  {
    "country": "RO",
    "name": "Hociungi",
    "lat": "46.81311",
    "lng": "26.77596"
  },
  {
    "country": "RO",
    "name": "Hoceni",
    "lat": "46.53917",
    "lng": "28.00667"
  },
  {
    "country": "RO",
    "name": "Hlipiceni",
    "lat": "47.6",
    "lng": "27.15"
  },
  {
    "country": "RO",
    "name": "Hlăpești",
    "lat": "47.03817",
    "lng": "26.59842"
  },
  {
    "country": "RO",
    "name": "Hârtop",
    "lat": "47.49",
    "lng": "26.37226"
  },
  {
    "country": "RO",
    "name": "Hârtoape",
    "lat": "47.32164",
    "lng": "26.72459"
  },
  {
    "country": "RO",
    "name": "Hârtieşti",
    "lat": "45.11667",
    "lng": "25.1"
  },
  {
    "country": "RO",
    "name": "Hârşova",
    "lat": "44.68574",
    "lng": "27.94819"
  },
  {
    "country": "RO",
    "name": "Hârseşti",
    "lat": "44.53333",
    "lng": "24.78333"
  },
  {
    "country": "RO",
    "name": "Hârşeni",
    "lat": "45.75",
    "lng": "25.01667"
  },
  {
    "country": "RO",
    "name": "Hârlău",
    "lat": "47.43333",
    "lng": "26.9"
  },
  {
    "country": "RO",
    "name": "Hinova",
    "lat": "44.54056",
    "lng": "22.77694"
  },
  {
    "country": "RO",
    "name": "Hilişeu-Horia",
    "lat": "48.03333",
    "lng": "26.25"
  },
  {
    "country": "RO",
    "name": "Hidişelu de Sus",
    "lat": "46.95",
    "lng": "22.05"
  },
  {
    "country": "RO",
    "name": "Hida",
    "lat": "47.06667",
    "lng": "23.28333"
  },
  {
    "country": "RO",
    "name": "Herla",
    "lat": "47.44286",
    "lng": "26.01254"
  },
  {
    "country": "RO",
    "name": "Hereclean",
    "lat": "47.25",
    "lng": "23.01667"
  },
  {
    "country": "RO",
    "name": "Herculian",
    "lat": "46.13402",
    "lng": "25.70977"
  },
  {
    "country": "RO",
    "name": "Herăști",
    "lat": "44.21174",
    "lng": "26.35903"
  },
  {
    "country": "RO",
    "name": "Hemeiuș",
    "lat": "46.62643",
    "lng": "26.8544"
  },
  {
    "country": "RO",
    "name": "Heleșteni",
    "lat": "47.20303",
    "lng": "26.87755"
  },
  {
    "country": "RO",
    "name": "Helegiu",
    "lat": "46.35",
    "lng": "26.75"
  },
  {
    "country": "RO",
    "name": "Heci",
    "lat": "47.34325",
    "lng": "26.66226"
  },
  {
    "country": "RO",
    "name": "Havârna",
    "lat": "48.06667",
    "lng": "26.65"
  },
  {
    "country": "RO",
    "name": "Haţeg",
    "lat": "45.61667",
    "lng": "22.95"
  },
  {
    "country": "RO",
    "name": "Hășmaș",
    "lat": "46.5",
    "lng": "22.08333"
  },
  {
    "country": "RO",
    "name": "Hărțăgani",
    "lat": "46.05012",
    "lng": "22.92183"
  },
  {
    "country": "RO",
    "name": "Hărmăneștii Vechi",
    "lat": "47.27732",
    "lng": "26.81394"
  },
  {
    "country": "RO",
    "name": "Hărmăneasa",
    "lat": "47.2",
    "lng": "26.86667"
  },
  {
    "country": "RO",
    "name": "Hărman",
    "lat": "45.71667",
    "lng": "25.68333"
  },
  {
    "country": "RO",
    "name": "Hărău",
    "lat": "45.9",
    "lng": "22.95"
  },
  {
    "country": "RO",
    "name": "Hanu Conachi",
    "lat": "45.5865",
    "lng": "27.59481"
  },
  {
    "country": "RO",
    "name": "Hănțești",
    "lat": "47.75507",
    "lng": "26.37366"
  },
  {
    "country": "RO",
    "name": "Hangu",
    "lat": "47.05",
    "lng": "26.03333"
  },
  {
    "country": "RO",
    "name": "Hăneşti",
    "lat": "47.91667",
    "lng": "26.98333"
  },
  {
    "country": "RO",
    "name": "Hamcearca",
    "lat": "45.11667",
    "lng": "28.36667"
  },
  {
    "country": "RO",
    "name": "Halmeu",
    "lat": "47.96667",
    "lng": "23.01667"
  },
  {
    "country": "RO",
    "name": "Halmăşd",
    "lat": "47.15",
    "lng": "22.61667"
  },
  {
    "country": "RO",
    "name": "Hălmagiu",
    "lat": "46.26667",
    "lng": "22.58333"
  },
  {
    "country": "RO",
    "name": "Hălmăgel",
    "lat": "46.26667",
    "lng": "22.61667"
  },
  {
    "country": "RO",
    "name": "Halânga",
    "lat": "44.68116",
    "lng": "22.69037"
  },
  {
    "country": "RO",
    "name": "Hălchiu",
    "lat": "45.76667",
    "lng": "25.55"
  },
  {
    "country": "RO",
    "name": "Hălăuceşti",
    "lat": "47.1",
    "lng": "26.8"
  },
  {
    "country": "RO",
    "name": "Hălărești",
    "lat": "46.39447",
    "lng": "27.55614"
  },
  {
    "country": "RO",
    "name": "Hăghig",
    "lat": "45.83333",
    "lng": "25.58333"
  },
  {
    "country": "RO",
    "name": "Hăghiac",
    "lat": "46.312",
    "lng": "26.51841"
  },
  {
    "country": "RO",
    "name": "Hăbeni",
    "lat": "44.85629",
    "lng": "25.62873"
  },
  {
    "country": "RO",
    "name": "Gvardinița",
    "lat": "44.39505",
    "lng": "23.14635"
  },
  {
    "country": "RO",
    "name": "Guşoeni",
    "lat": "44.73333",
    "lng": "24.11667"
  },
  {
    "country": "RO",
    "name": "Guruieni",
    "lat": "44.05845",
    "lng": "25.39656"
  },
  {
    "country": "RO",
    "name": "Gurghiu",
    "lat": "46.76667",
    "lng": "24.85"
  },
  {
    "country": "RO",
    "name": "Gurbediu",
    "lat": "46.79379",
    "lng": "21.8648"
  },
  {
    "country": "RO",
    "name": "Gurbăneşti",
    "lat": "44.38333",
    "lng": "26.7"
  },
  {
    "country": "RO",
    "name": "Gurba",
    "lat": "46.46756",
    "lng": "21.78789"
  },
  {
    "country": "RO",
    "name": "Gura Vulcanei",
    "lat": "45.02442",
    "lng": "25.39596"
  },
  {
    "country": "RO",
    "name": "Gura Viţioarei",
    "lat": "45.15",
    "lng": "26.03333"
  },
  {
    "country": "RO",
    "name": "Gura Văii",
    "lat": "46.33333",
    "lng": "26.73333"
  },
  {
    "country": "RO",
    "name": "Gura Văii",
    "lat": "46.27234",
    "lng": "26.82604"
  },
  {
    "country": "RO",
    "name": "Gura Văii",
    "lat": "44.66732",
    "lng": "22.55646"
  },
  {
    "country": "RO",
    "name": "Gura Vadului",
    "lat": "45.05",
    "lng": "26.46667"
  },
  {
    "country": "RO",
    "name": "Gura Teghii",
    "lat": "45.48333",
    "lng": "26.41667"
  },
  {
    "country": "RO",
    "name": "Gura Şuţii",
    "lat": "44.75",
    "lng": "25.51667"
  },
  {
    "country": "RO",
    "name": "Gura Suhașului",
    "lat": "45.08803",
    "lng": "24.29886"
  },
  {
    "country": "RO",
    "name": "Gura Râului",
    "lat": "45.73333",
    "lng": "23.98333"
  },
  {
    "country": "RO",
    "name": "Gura Putnei",
    "lat": "47.89951",
    "lng": "25.5951"
  },
  {
    "country": "RO",
    "name": "Gura Padinii",
    "lat": "43.75704",
    "lng": "24.31615"
  },
  {
    "country": "RO",
    "name": "Gura Ocniței",
    "lat": "44.94166",
    "lng": "25.56846"
  },
  {
    "country": "RO",
    "name": "Gura Ialomiței",
    "lat": "44.71608",
    "lng": "27.7531"
  },
  {
    "country": "RO",
    "name": "Gura Humorului",
    "lat": "47.55",
    "lng": "25.9"
  },
  {
    "country": "RO",
    "name": "Gurahonţ",
    "lat": "46.26667",
    "lng": "22.35"
  },
  {
    "country": "RO",
    "name": "Gura Foii",
    "lat": "44.75",
    "lng": "25.28333"
  },
  {
    "country": "RO",
    "name": "Gura Căluiu",
    "lat": "44.45903",
    "lng": "24.03547"
  },
  {
    "country": "RO",
    "name": "Gura Caliţei",
    "lat": "45.58333",
    "lng": "27.01667"
  },
  {
    "country": "RO",
    "name": "Gura Beliei",
    "lat": "45.21064",
    "lng": "25.64946"
  },
  {
    "country": "RO",
    "name": "Gulia",
    "lat": "47.41203",
    "lng": "26.60854"
  },
  {
    "country": "RO",
    "name": "Gulia",
    "lat": "44.54687",
    "lng": "25.87304"
  },
  {
    "country": "RO",
    "name": "Gugești",
    "lat": "46.76342",
    "lng": "27.9005"
  },
  {
    "country": "RO",
    "name": "Gugeşti",
    "lat": "45.56667",
    "lng": "27.13333"
  },
  {
    "country": "RO",
    "name": "Grunji",
    "lat": "45.5",
    "lng": "26.65"
  },
  {
    "country": "RO",
    "name": "Grumăzeşti",
    "lat": "47.13333",
    "lng": "26.36667"
  },
  {
    "country": "RO",
    "name": "Gruiu",
    "lat": "44.73333",
    "lng": "26.23333"
  },
  {
    "country": "RO",
    "name": "Gruia",
    "lat": "44.2675",
    "lng": "22.70472"
  },
  {
    "country": "RO",
    "name": "Grozeşti",
    "lat": "46.99083",
    "lng": "28.05056"
  },
  {
    "country": "RO",
    "name": "Grozeşti",
    "lat": "44.65",
    "lng": "23.31667"
  },
  {
    "country": "RO",
    "name": "Grozăvești",
    "lat": "44.56882",
    "lng": "25.4536"
  },
  {
    "country": "RO",
    "name": "Groșii Țibleșului",
    "lat": "47.48983",
    "lng": "24.06368"
  },
  {
    "country": "RO",
    "name": "Groşi",
    "lat": "47.61667",
    "lng": "23.61667"
  },
  {
    "country": "RO",
    "name": "Groși",
    "lat": "47.04525",
    "lng": "22.47965"
  },
  {
    "country": "RO",
    "name": "Groșani",
    "lat": "45.24822",
    "lng": "25.94795"
  },
  {
    "country": "RO",
    "name": "Gropșani",
    "lat": "44.44072",
    "lng": "23.97047"
  },
  {
    "country": "RO",
    "name": "Gropniţa",
    "lat": "47.35",
    "lng": "27.25"
  },
  {
    "country": "RO",
    "name": "Grojdibodu",
    "lat": "43.75",
    "lng": "24.26667"
  },
  {
    "country": "RO",
    "name": "Griviţa",
    "lat": "46.15",
    "lng": "27.65"
  },
  {
    "country": "RO",
    "name": "Griviţa",
    "lat": "45.71667",
    "lng": "27.65"
  },
  {
    "country": "RO",
    "name": "Griviţa",
    "lat": "44.73333",
    "lng": "27.28333"
  },
  {
    "country": "RO",
    "name": "Grinţieş",
    "lat": "47.05",
    "lng": "25.86667"
  },
  {
    "country": "RO",
    "name": "Grindu",
    "lat": "45.4",
    "lng": "28.21667"
  },
  {
    "country": "RO",
    "name": "Grindu",
    "lat": "44.76667",
    "lng": "26.91667"
  },
  {
    "country": "RO",
    "name": "Greoni",
    "lat": "45.08901",
    "lng": "21.61731"
  },
  {
    "country": "RO",
    "name": "Greci",
    "lat": "45.18333",
    "lng": "28.23333"
  },
  {
    "country": "RO",
    "name": "Greci",
    "lat": "44.66132",
    "lng": "25.34346"
  },
  {
    "country": "RO",
    "name": "Greci",
    "lat": "44.55",
    "lng": "23.11667"
  },
  {
    "country": "RO",
    "name": "Greci",
    "lat": "44.33025",
    "lng": "24.55923"
  },
  {
    "country": "RO",
    "name": "Greci",
    "lat": "44.28125",
    "lng": "24.35238"
  },
  {
    "country": "RO",
    "name": "Greceşti",
    "lat": "44.45",
    "lng": "23.28333"
  },
  {
    "country": "RO",
    "name": "Greceanca",
    "lat": "45.07863",
    "lng": "26.54468"
  },
  {
    "country": "RO",
    "name": "Greblești",
    "lat": "45.47514",
    "lng": "24.31182"
  },
  {
    "country": "RO",
    "name": "Grebenişu de Câmpie",
    "lat": "46.6",
    "lng": "24.3"
  },
  {
    "country": "RO",
    "name": "Greaca",
    "lat": "44.10944",
    "lng": "26.33944"
  },
  {
    "country": "RO",
    "name": "Grebănu",
    "lat": "45.38333",
    "lng": "26.96667"
  },
  {
    "country": "RO",
    "name": "Gratia",
    "lat": "44.43333",
    "lng": "25.45"
  },
  {
    "country": "RO",
    "name": "Grăniceşti",
    "lat": "47.81667",
    "lng": "26.06667"
  },
  {
    "country": "RO",
    "name": "Grăniceri",
    "lat": "46.51667",
    "lng": "21.3"
  },
  {
    "country": "RO",
    "name": "Grămeşti",
    "lat": "47.91667",
    "lng": "26.15"
  },
  {
    "country": "RO",
    "name": "Grajduri",
    "lat": "46.96667",
    "lng": "27.51667"
  },
  {
    "country": "RO",
    "name": "Grăjdana",
    "lat": "45.20865",
    "lng": "26.63114"
  },
  {
    "country": "RO",
    "name": "Grădiştea",
    "lat": "45.26667",
    "lng": "27.38333"
  },
  {
    "country": "RO",
    "name": "Gradiștea",
    "lat": "44.88803",
    "lng": "26.5152"
  },
  {
    "country": "RO",
    "name": "Grădiştea",
    "lat": "44.86667",
    "lng": "23.81667"
  },
  {
    "country": "RO",
    "name": "Grădiştea",
    "lat": "44.66667",
    "lng": "26.28333"
  },
  {
    "country": "RO",
    "name": "Grădiştea",
    "lat": "44.23333",
    "lng": "27.21667"
  },
  {
    "country": "RO",
    "name": "Grădiștea",
    "lat": "44.21062",
    "lng": "26.16547"
  },
  {
    "country": "RO",
    "name": "Grădinari",
    "lat": "45.11861",
    "lng": "21.59889"
  },
  {
    "country": "RO",
    "name": "Grădinari",
    "lat": "44.56667",
    "lng": "24.26667"
  },
  {
    "country": "RO",
    "name": "Grădina",
    "lat": "44.5552",
    "lng": "28.43236"
  },
  {
    "country": "RO",
    "name": "Grabăț",
    "lat": "45.87861",
    "lng": "20.74238"
  },
  {
    "country": "RO",
    "name": "Gottlob",
    "lat": "45.936",
    "lng": "20.71168"
  },
  {
    "country": "RO",
    "name": "Gostinu",
    "lat": "44",
    "lng": "26.11667"
  },
  {
    "country": "RO",
    "name": "Goştinari-Văcăreşti",
    "lat": "44.18333",
    "lng": "26.21667"
  },
  {
    "country": "RO",
    "name": "Gostinari",
    "lat": "44.18624",
    "lng": "26.22807"
  },
  {
    "country": "RO",
    "name": "Gostavăţu",
    "lat": "44.08333",
    "lng": "24.53333"
  },
  {
    "country": "RO",
    "name": "Goșmani",
    "lat": "46.8362",
    "lng": "26.71522"
  },
  {
    "country": "RO",
    "name": "Goruni",
    "lat": "47.10389",
    "lng": "27.71854"
  },
  {
    "country": "RO",
    "name": "Goruna",
    "lat": "45.08696",
    "lng": "25.94202"
  },
  {
    "country": "RO",
    "name": "Goruia",
    "lat": "45.18722",
    "lng": "21.77917"
  },
  {
    "country": "RO",
    "name": "Gornet-Cricov",
    "lat": "45.08333",
    "lng": "26.26667"
  },
  {
    "country": "RO",
    "name": "Gornet",
    "lat": "45.11667",
    "lng": "26.06667"
  },
  {
    "country": "RO",
    "name": "Gorneşti",
    "lat": "46.67129",
    "lng": "24.64757"
  },
  {
    "country": "RO",
    "name": "Gorgota",
    "lat": "44.97626",
    "lng": "25.50837"
  },
  {
    "country": "RO",
    "name": "Gorgota",
    "lat": "44.78333",
    "lng": "26.08333"
  },
  {
    "country": "RO",
    "name": "Gorganu",
    "lat": "44.84241",
    "lng": "25.03838"
  },
  {
    "country": "RO",
    "name": "Goreni",
    "lat": "46.85474",
    "lng": "24.65569"
  },
  {
    "country": "RO",
    "name": "Gorbăneşti",
    "lat": "47.78333",
    "lng": "26.85"
  },
  {
    "country": "RO",
    "name": "Gorban",
    "lat": "46.87611",
    "lng": "28.07889"
  },
  {
    "country": "RO",
    "name": "Goranu",
    "lat": "45.10523",
    "lng": "24.38431"
  },
  {
    "country": "RO",
    "name": "Gologanu",
    "lat": "45.60979",
    "lng": "27.27091"
  },
  {
    "country": "RO",
    "name": "Goleşti",
    "lat": "45.66667",
    "lng": "27.13333"
  },
  {
    "country": "RO",
    "name": "Golești",
    "lat": "44.8397",
    "lng": "24.9653"
  },
  {
    "country": "RO",
    "name": "Golăiești",
    "lat": "47.23333",
    "lng": "27.7"
  },
  {
    "country": "RO",
    "name": "Goicea",
    "lat": "43.91667",
    "lng": "23.61667"
  },
  {
    "country": "RO",
    "name": "Gohor",
    "lat": "46.06667",
    "lng": "27.4"
  },
  {
    "country": "RO",
    "name": "Gogoşu",
    "lat": "44.41667",
    "lng": "23.36667"
  },
  {
    "country": "RO",
    "name": "Gogoşu",
    "lat": "44.37389",
    "lng": "22.59306"
  },
  {
    "country": "RO",
    "name": "Gogoşari",
    "lat": "43.86667",
    "lng": "25.7"
  },
  {
    "country": "RO",
    "name": "Goești",
    "lat": "47.15654",
    "lng": "27.13659"
  },
  {
    "country": "RO",
    "name": "Goiești",
    "lat": "44.48333",
    "lng": "23.76667"
  },
  {
    "country": "RO",
    "name": "Godineşti",
    "lat": "45",
    "lng": "22.96667"
  },
  {
    "country": "RO",
    "name": "Godeni",
    "lat": "45.23333",
    "lng": "24.98333"
  },
  {
    "country": "RO",
    "name": "Godeanu",
    "lat": "44.80111",
    "lng": "22.60861"
  },
  {
    "country": "RO",
    "name": "Glogova",
    "lat": "44.92806",
    "lng": "22.90667"
  },
  {
    "country": "RO",
    "name": "Glodenii Gândului",
    "lat": "46.95158",
    "lng": "27.29938"
  },
  {
    "country": "RO",
    "name": "Glodeni",
    "lat": "45.06345",
    "lng": "25.45342"
  },
  {
    "country": "RO",
    "name": "Glodeni",
    "lat": "46.65",
    "lng": "24.6"
  },
  {
    "country": "RO",
    "name": "Glodeni",
    "lat": "45.01667",
    "lng": "25.46667"
  },
  {
    "country": "RO",
    "name": "Glodeanu-Siliştea",
    "lat": "44.83333",
    "lng": "26.8"
  },
  {
    "country": "RO",
    "name": "Glodeanu-Sărat",
    "lat": "44.86667",
    "lng": "26.65"
  },
  {
    "country": "RO",
    "name": "Glod",
    "lat": "45.24163",
    "lng": "25.44994"
  },
  {
    "country": "RO",
    "name": "Glina",
    "lat": "44.38333",
    "lng": "26.25"
  },
  {
    "country": "RO",
    "name": "Glimboca",
    "lat": "45.48333",
    "lng": "22.31667"
  },
  {
    "country": "RO",
    "name": "Glăvăneşti",
    "lat": "46.25",
    "lng": "27.38333"
  },
  {
    "country": "RO",
    "name": "Giuvărăşti",
    "lat": "43.8",
    "lng": "24.7"
  },
  {
    "country": "RO",
    "name": "Giurtelecu Șimleului",
    "lat": "47.2968",
    "lng": "22.79557"
  },
  {
    "country": "RO",
    "name": "Giurgiu",
    "lat": "43.88333",
    "lng": "25.96667"
  },
  {
    "country": "RO",
    "name": "Giurgiţa",
    "lat": "44.01667",
    "lng": "23.63333"
  },
  {
    "country": "RO",
    "name": "Giurgeni",
    "lat": "44.76667",
    "lng": "27.88333"
  },
  {
    "country": "RO",
    "name": "Giulvăz",
    "lat": "45.54889",
    "lng": "20.98444"
  },
  {
    "country": "RO",
    "name": "Giuleşti",
    "lat": "47.81667",
    "lng": "23.93333"
  },
  {
    "country": "RO",
    "name": "Giubega",
    "lat": "44.1274",
    "lng": "23.40757"
  },
  {
    "country": "RO",
    "name": "Girov",
    "lat": "46.95",
    "lng": "26.51667"
  },
  {
    "country": "RO",
    "name": "Giroc",
    "lat": "45.69417",
    "lng": "21.23583"
  },
  {
    "country": "RO",
    "name": "Gârnic",
    "lat": "44.78639",
    "lng": "21.79444"
  },
  {
    "country": "RO",
    "name": "Gârliciu",
    "lat": "44.76667",
    "lng": "28.08333"
  },
  {
    "country": "RO",
    "name": "Gârleni",
    "lat": "46.66667",
    "lng": "26.8"
  },
  {
    "country": "RO",
    "name": "Gârla-Mare",
    "lat": "44.20917",
    "lng": "22.775"
  },
  {
    "country": "RO",
    "name": "Girișu de Criș",
    "lat": "47.06416",
    "lng": "21.76108"
  },
  {
    "country": "RO",
    "name": "Gârdani",
    "lat": "47.55135",
    "lng": "23.3088"
  },
  {
    "country": "RO",
    "name": "Gârda de Sus",
    "lat": "46.45",
    "lng": "22.81667"
  },
  {
    "country": "RO",
    "name": "Gârcov",
    "lat": "43.76667",
    "lng": "24.63333"
  },
  {
    "country": "RO",
    "name": "Gârcina",
    "lat": "46.97691",
    "lng": "26.34573"
  },
  {
    "country": "RO",
    "name": "Gârceni",
    "lat": "46.76667",
    "lng": "27.28333"
  },
  {
    "country": "RO",
    "name": "Gârbovi",
    "lat": "44.78333",
    "lng": "26.76667"
  },
  {
    "country": "RO",
    "name": "Gârbova",
    "lat": "45.86667",
    "lng": "23.73333"
  },
  {
    "country": "RO",
    "name": "Gârbou",
    "lat": "47.15",
    "lng": "23.43333"
  },
  {
    "country": "RO",
    "name": "Gârbești",
    "lat": "46.98333",
    "lng": "27.3"
  },
  {
    "country": "RO",
    "name": "Gârbău",
    "lat": "46.83305",
    "lng": "23.3524"
  },
  {
    "country": "RO",
    "name": "Gângiova",
    "lat": "43.9",
    "lng": "23.85"
  },
  {
    "country": "RO",
    "name": "Gâlgău Almaşului",
    "lat": "47.2",
    "lng": "23.33333"
  },
  {
    "country": "RO",
    "name": "Gâlgău",
    "lat": "47.28183",
    "lng": "23.70157"
  },
  {
    "country": "RO",
    "name": "Gâldău",
    "lat": "44.30544",
    "lng": "27.66972"
  },
  {
    "country": "RO",
    "name": "Gilău",
    "lat": "46.73245",
    "lng": "23.36174"
  },
  {
    "country": "RO",
    "name": "Gighera",
    "lat": "43.85",
    "lng": "23.8"
  },
  {
    "country": "RO",
    "name": "Giera",
    "lat": "45.40722",
    "lng": "20.99222"
  },
  {
    "country": "RO",
    "name": "Gâdinţi",
    "lat": "46.93333",
    "lng": "27.01667"
  },
  {
    "country": "RO",
    "name": "Giarmata-Vii",
    "lat": "45.7996",
    "lng": "21.30026"
  },
  {
    "country": "RO",
    "name": "Giarmata",
    "lat": "45.83833",
    "lng": "21.31083"
  },
  {
    "country": "RO",
    "name": "Ghizela",
    "lat": "45.82417",
    "lng": "21.73722"
  },
  {
    "country": "RO",
    "name": "Ghizdăvești",
    "lat": "44.05757",
    "lng": "24.10811"
  },
  {
    "country": "RO",
    "name": "Ghiroda",
    "lat": "45.76389",
    "lng": "21.30028"
  },
  {
    "country": "RO",
    "name": "Ghirdoveni",
    "lat": "44.94059",
    "lng": "25.67368"
  },
  {
    "country": "RO",
    "name": "Ghioșești",
    "lat": "45.24235",
    "lng": "25.62671"
  },
  {
    "country": "RO",
    "name": "Ghioroiu",
    "lat": "44.7",
    "lng": "23.83333"
  },
  {
    "country": "RO",
    "name": "Ghioroc",
    "lat": "46.15",
    "lng": "21.58333"
  },
  {
    "country": "RO",
    "name": "Ghiorac",
    "lat": "46.7134",
    "lng": "21.68309"
  },
  {
    "country": "RO",
    "name": "Ghinești",
    "lat": "44.74774",
    "lng": "25.553"
  },
  {
    "country": "RO",
    "name": "Ghindeni",
    "lat": "44.21223",
    "lng": "23.92336"
  },
  {
    "country": "RO",
    "name": "Ghindari",
    "lat": "46.5",
    "lng": "24.91667"
  },
  {
    "country": "RO",
    "name": "Ghindăreşti",
    "lat": "44.65",
    "lng": "28.03333"
  },
  {
    "country": "RO",
    "name": "Ghindăoani",
    "lat": "47.10983",
    "lng": "26.33909"
  },
  {
    "country": "RO",
    "name": "Ghimpețeni",
    "lat": "44.28101",
    "lng": "24.77458"
  },
  {
    "country": "RO",
    "name": "Ghimpați",
    "lat": "44.19586",
    "lng": "25.78336"
  },
  {
    "country": "RO",
    "name": "Ghimpați",
    "lat": "44.15359",
    "lng": "24.42698"
  },
  {
    "country": "RO",
    "name": "Ghimeş-Făget",
    "lat": "46.58333",
    "lng": "26.06667"
  },
  {
    "country": "RO",
    "name": "Ghimeș",
    "lat": "46.56821",
    "lng": "26.08886"
  },
  {
    "country": "RO",
    "name": "Ghimbav",
    "lat": "45.66667",
    "lng": "25.5"
  },
  {
    "country": "RO",
    "name": "Ghilad",
    "lat": "45.46501",
    "lng": "21.13824"
  },
  {
    "country": "RO",
    "name": "Ghighișeni",
    "lat": "46.55141",
    "lng": "22.43148"
  },
  {
    "country": "RO",
    "name": "Ghidigeni",
    "lat": "46.05",
    "lng": "27.5"
  },
  {
    "country": "RO",
    "name": "Ghidici",
    "lat": "43.89103",
    "lng": "23.19454"
  },
  {
    "country": "RO",
    "name": "Ghidfalău",
    "lat": "45.9",
    "lng": "25.85"
  },
  {
    "country": "RO",
    "name": "Gheaba",
    "lat": "45.30916",
    "lng": "26.00626"
  },
  {
    "country": "RO",
    "name": "Gherteniș",
    "lat": "45.43315",
    "lng": "21.58126"
  },
  {
    "country": "RO",
    "name": "Gherţa Mică",
    "lat": "47.93333",
    "lng": "23.23333"
  },
  {
    "country": "RO",
    "name": "Gherța Mare",
    "lat": "47.96884",
    "lng": "23.20853"
  },
  {
    "country": "RO",
    "name": "Ghermănești",
    "lat": "46.82998",
    "lng": "28.08105"
  },
  {
    "country": "RO",
    "name": "Ghermănești",
    "lat": "44.68829",
    "lng": "26.14962"
  },
  {
    "country": "RO",
    "name": "Gherla",
    "lat": "47.03333",
    "lng": "23.91667"
  },
  {
    "country": "RO",
    "name": "Gherghiţa",
    "lat": "44.8",
    "lng": "26.26667"
  },
  {
    "country": "RO",
    "name": "Ghergheşti",
    "lat": "46.5",
    "lng": "27.51667"
  },
  {
    "country": "RO",
    "name": "Ghergheasa",
    "lat": "45.26667",
    "lng": "27.2"
  },
  {
    "country": "RO",
    "name": "Gherăseni",
    "lat": "45.02589",
    "lng": "26.79128"
  },
  {
    "country": "RO",
    "name": "Gherăeşti",
    "lat": "47.01667",
    "lng": "26.81667"
  },
  {
    "country": "RO",
    "name": "Gheorgheni",
    "lat": "46.72292",
    "lng": "25.60055"
  },
  {
    "country": "RO",
    "name": "Gheorghieni",
    "lat": "46.71393",
    "lng": "23.68853"
  },
  {
    "country": "RO",
    "name": "Gheorghe Lazăr",
    "lat": "44.63333",
    "lng": "27.45"
  },
  {
    "country": "RO",
    "name": "Onesti",
    "lat": "46.25",
    "lng": "26.75"
  },
  {
    "country": "RO",
    "name": "Gheorghe Doja",
    "lat": "46.46667",
    "lng": "24.5"
  },
  {
    "country": "RO",
    "name": "Gheorghe Doja",
    "lat": "46.37831",
    "lng": "26.96248"
  },
  {
    "country": "RO",
    "name": "Ghelinţa",
    "lat": "45.95",
    "lng": "26.23333"
  },
  {
    "country": "RO",
    "name": "Ghelari",
    "lat": "45.71667",
    "lng": "22.78333"
  },
  {
    "country": "RO",
    "name": "Gheja",
    "lat": "46.44727",
    "lng": "24.06491"
  },
  {
    "country": "RO",
    "name": "Gheboieni",
    "lat": "44.98701",
    "lng": "25.3067"
  },
  {
    "country": "RO",
    "name": "Gheboaia",
    "lat": "44.80203",
    "lng": "25.74875"
  },
  {
    "country": "RO",
    "name": "Gepiu",
    "lat": "46.93034",
    "lng": "21.79016"
  },
  {
    "country": "RO",
    "name": "Gioseni",
    "lat": "46.42925",
    "lng": "26.99239"
  },
  {
    "country": "RO",
    "name": "George Enescu",
    "lat": "48.03333",
    "lng": "26.48333"
  },
  {
    "country": "RO",
    "name": "Geoagiu",
    "lat": "45.91667",
    "lng": "23.2"
  },
  {
    "country": "RO",
    "name": "Gemeni",
    "lat": "44.17265",
    "lng": "23.08251"
  },
  {
    "country": "RO",
    "name": "Gemenele",
    "lat": "45.28333",
    "lng": "27.61667"
  },
  {
    "country": "RO",
    "name": "Gemenea Brătulești",
    "lat": "45.10839",
    "lng": "25.23155"
  },
  {
    "country": "RO",
    "name": "Gelu",
    "lat": "46.00591",
    "lng": "21.06002"
  },
  {
    "country": "RO",
    "name": "Geamăna",
    "lat": "44.82005",
    "lng": "24.89109"
  },
  {
    "country": "RO",
    "name": "Geaca",
    "lat": "46.86667",
    "lng": "24.1"
  },
  {
    "country": "RO",
    "name": "Găzărie",
    "lat": "46.48928",
    "lng": "26.51877"
  },
  {
    "country": "RO",
    "name": "Gavojdia",
    "lat": "45.61667",
    "lng": "22.01667"
  },
  {
    "country": "RO",
    "name": "Găvănești",
    "lat": "45.08825",
    "lng": "27.06499"
  },
  {
    "country": "RO",
    "name": "Găvănești",
    "lat": "44.41724",
    "lng": "24.01654"
  },
  {
    "country": "RO",
    "name": "Găujani",
    "lat": "43.73333",
    "lng": "25.7"
  },
  {
    "country": "RO",
    "name": "Gătaia",
    "lat": "45.43111",
    "lng": "21.43"
  },
  {
    "country": "RO",
    "name": "Garvăn",
    "lat": "45.3471",
    "lng": "28.16187"
  },
  {
    "country": "RO",
    "name": "Garoafa",
    "lat": "45.78333",
    "lng": "27.2"
  },
  {
    "country": "RO",
    "name": "Gărăgău",
    "lat": "44.23186",
    "lng": "25.1892"
  },
  {
    "country": "RO",
    "name": "Dâlga-Gară",
    "lat": "44.43333",
    "lng": "27.05"
  },
  {
    "country": "RO",
    "name": "Găneşti",
    "lat": "46.33333",
    "lng": "24.35"
  },
  {
    "country": "RO",
    "name": "Gănești",
    "lat": "46.0897",
    "lng": "27.99337"
  },
  {
    "country": "RO",
    "name": "Găneasa",
    "lat": "44.48333",
    "lng": "26.28333"
  },
  {
    "country": "RO",
    "name": "Găneasa",
    "lat": "44.41667",
    "lng": "24.28333"
  },
  {
    "country": "RO",
    "name": "Galșa",
    "lat": "46.2881",
    "lng": "21.65137"
  },
  {
    "country": "RO",
    "name": "Galoșpetreu",
    "lat": "47.48345",
    "lng": "22.2173"
  },
  {
    "country": "RO",
    "name": "Galiciuica",
    "lat": "44.10324",
    "lng": "23.39067"
  },
  {
    "country": "RO",
    "name": "Galicea Mare",
    "lat": "44.1",
    "lng": "23.3"
  },
  {
    "country": "RO",
    "name": "Galicea",
    "lat": "44.91667",
    "lng": "24.28333"
  },
  {
    "country": "RO",
    "name": "Găleşti",
    "lat": "46.51667",
    "lng": "24.75"
  },
  {
    "country": "RO",
    "name": "Galda de Jos",
    "lat": "46.18333",
    "lng": "23.61667"
  },
  {
    "country": "RO",
    "name": "Gălbinaşi",
    "lat": "45.08333",
    "lng": "26.91667"
  },
  {
    "country": "RO",
    "name": "Gălbinași",
    "lat": "44.31724",
    "lng": "26.41941"
  },
  {
    "country": "RO",
    "name": "Galbenu",
    "lat": "45.21667",
    "lng": "27.16667"
  },
  {
    "country": "RO",
    "name": "Galbeni",
    "lat": "46.45661",
    "lng": "26.94664"
  },
  {
    "country": "RO",
    "name": "Gălăuţaş",
    "lat": "46.91667",
    "lng": "25.43333"
  },
  {
    "country": "RO",
    "name": "Galaţii Bistriţei",
    "lat": "46.98333",
    "lng": "24.4"
  },
  {
    "country": "RO",
    "name": "Galaţi",
    "lat": "45.45",
    "lng": "28.05"
  },
  {
    "country": "RO",
    "name": "Gălăţeni",
    "lat": "44.21667",
    "lng": "25.35"
  },
  {
    "country": "RO",
    "name": "Gălășești",
    "lat": "44.95593",
    "lng": "24.78602"
  },
  {
    "country": "RO",
    "name": "Gălăneşti",
    "lat": "47.91667",
    "lng": "25.8"
  },
  {
    "country": "RO",
    "name": "Găiseni",
    "lat": "44.515",
    "lng": "25.64528"
  },
  {
    "country": "RO",
    "name": "Găinești",
    "lat": "47.41968",
    "lng": "25.91809"
  },
  {
    "country": "RO",
    "name": "Găiceana",
    "lat": "46.33333",
    "lng": "27.21667"
  },
  {
    "country": "RO",
    "name": "Găgeşti",
    "lat": "46.33333",
    "lng": "27.96667"
  },
  {
    "country": "RO",
    "name": "Găgești",
    "lat": "45.85598",
    "lng": "27.0554"
  },
  {
    "country": "RO",
    "name": "Găgeni",
    "lat": "45.02164",
    "lng": "25.94585"
  },
  {
    "country": "RO",
    "name": "Găeşti",
    "lat": "44.71667",
    "lng": "25.31667"
  },
  {
    "country": "RO",
    "name": "Furtunești",
    "lat": "45.4594",
    "lng": "26.3976"
  },
  {
    "country": "RO",
    "name": "Furculești",
    "lat": "43.87202",
    "lng": "25.14285"
  },
  {
    "country": "RO",
    "name": "Furcenii Noi",
    "lat": "45.81118",
    "lng": "27.33954"
  },
  {
    "country": "RO",
    "name": "Fundu Răcăciuni",
    "lat": "46.35864",
    "lng": "26.88987"
  },
  {
    "country": "RO",
    "name": "Fundu Moldovei",
    "lat": "47.53333",
    "lng": "25.4"
  },
  {
    "country": "RO",
    "name": "Fundulea",
    "lat": "44.46667",
    "lng": "26.51667"
  },
  {
    "country": "RO",
    "name": "Fundeni",
    "lat": "45.54123",
    "lng": "27.54056"
  },
  {
    "country": "RO",
    "name": "Fundeni",
    "lat": "45.29141",
    "lng": "26.88028"
  },
  {
    "country": "RO",
    "name": "Fundeni",
    "lat": "44.45892",
    "lng": "26.16565"
  },
  {
    "country": "RO",
    "name": "Fundeni",
    "lat": "44.38333",
    "lng": "26.35"
  },
  {
    "country": "RO",
    "name": "Fundata",
    "lat": "45.45",
    "lng": "25.3"
  },
  {
    "country": "RO",
    "name": "Fulga de Sus",
    "lat": "44.9",
    "lng": "26.45"
  },
  {
    "country": "RO",
    "name": "Fulga de Jos",
    "lat": "44.88152",
    "lng": "26.44258"
  },
  {
    "country": "RO",
    "name": "Frunzi",
    "lat": "46.9",
    "lng": "24.33333"
  },
  {
    "country": "RO",
    "name": "Fruntișeni",
    "lat": "46.20634",
    "lng": "27.76904"
  },
  {
    "country": "RO",
    "name": "Frumuşiţa",
    "lat": "45.66667",
    "lng": "28.06667"
  },
  {
    "country": "RO",
    "name": "Frumuşica",
    "lat": "47.53333",
    "lng": "26.9"
  },
  {
    "country": "RO",
    "name": "Frumușelu",
    "lat": "46.27796",
    "lng": "27.35203"
  },
  {
    "country": "RO",
    "name": "Frumuşani",
    "lat": "44.29611",
    "lng": "26.32556"
  },
  {
    "country": "RO",
    "name": "Frumosu",
    "lat": "47.61667",
    "lng": "25.65"
  },
  {
    "country": "RO",
    "name": "Frumoasa",
    "lat": "46.66298",
    "lng": "26.54196"
  },
  {
    "country": "RO",
    "name": "Frumoasa",
    "lat": "46.45",
    "lng": "25.85"
  },
  {
    "country": "RO",
    "name": "Frumoasa",
    "lat": "43.8",
    "lng": "25.46667"
  },
  {
    "country": "RO",
    "name": "Frecăţei",
    "lat": "45.1",
    "lng": "28.66667"
  },
  {
    "country": "RO",
    "name": "Frecăţei",
    "lat": "44.9",
    "lng": "28.11667"
  },
  {
    "country": "RO",
    "name": "Fratoștița",
    "lat": "44.58671",
    "lng": "23.57044"
  },
  {
    "country": "RO",
    "name": "Frăteşti",
    "lat": "43.96667",
    "lng": "25.96667"
  },
  {
    "country": "RO",
    "name": "Frătăuţii Vechi",
    "lat": "47.9",
    "lng": "25.88333"
  },
  {
    "country": "RO",
    "name": "Frătăuţii Noi",
    "lat": "47.94257",
    "lng": "25.84465"
  },
  {
    "country": "RO",
    "name": "Frata",
    "lat": "46.7",
    "lng": "24.05"
  },
  {
    "country": "RO",
    "name": "Frăsinet",
    "lat": "44.31667",
    "lng": "26.8"
  },
  {
    "country": "RO",
    "name": "Frăsinet",
    "lat": "44.18038",
    "lng": "25.38238"
  },
  {
    "country": "RO",
    "name": "Frasin",
    "lat": "47.53333",
    "lng": "25.8"
  },
  {
    "country": "RO",
    "name": "Forotic",
    "lat": "45.23028",
    "lng": "21.5875"
  },
  {
    "country": "RO",
    "name": "Forău",
    "lat": "46.7107",
    "lng": "22.20113"
  },
  {
    "country": "RO",
    "name": "Forăşti",
    "lat": "47.35",
    "lng": "26.46667"
  },
  {
    "country": "RO",
    "name": "Folteşti",
    "lat": "45.75",
    "lng": "28.05"
  },
  {
    "country": "RO",
    "name": "Foglaş",
    "lat": "47.25",
    "lng": "22.53333"
  },
  {
    "country": "RO",
    "name": "Foieni",
    "lat": "47.7",
    "lng": "22.38333"
  },
  {
    "country": "RO",
    "name": "Foeni",
    "lat": "45.49861",
    "lng": "20.87583"
  },
  {
    "country": "RO",
    "name": "Focuri",
    "lat": "47.35",
    "lng": "27.21667"
  },
  {
    "country": "RO",
    "name": "Focșani",
    "lat": "45.7",
    "lng": "27.18333"
  },
  {
    "country": "RO",
    "name": "Floroaia",
    "lat": "45.69497",
    "lng": "26.01563"
  },
  {
    "country": "RO",
    "name": "Florica",
    "lat": "44.90802",
    "lng": "26.76627"
  },
  {
    "country": "RO",
    "name": "Floreşti",
    "lat": "46.74574",
    "lng": "23.49375"
  },
  {
    "country": "RO",
    "name": "Floreşti",
    "lat": "45.05",
    "lng": "25.78333"
  },
  {
    "country": "RO",
    "name": "Floreşti",
    "lat": "44.76306",
    "lng": "22.94778"
  },
  {
    "country": "RO",
    "name": "Florești",
    "lat": "44.61918",
    "lng": "23.52838"
  },
  {
    "country": "RO",
    "name": "Florești",
    "lat": "44.51313",
    "lng": "25.69658"
  },
  {
    "country": "RO",
    "name": "Flămânzi",
    "lat": "47.55",
    "lng": "26.86667"
  },
  {
    "country": "RO",
    "name": "Fizeşu Gherlii",
    "lat": "47.01667",
    "lng": "23.98333"
  },
  {
    "country": "RO",
    "name": "Fizeș",
    "lat": "45.36403",
    "lng": "21.59517"
  },
  {
    "country": "RO",
    "name": "Fitioneşti",
    "lat": "45.98333",
    "lng": "27.05"
  },
  {
    "country": "RO",
    "name": "Fâstâci",
    "lat": "46.73058",
    "lng": "27.44901"
  },
  {
    "country": "RO",
    "name": "Fișer",
    "lat": "46.07912",
    "lng": "25.15103"
  },
  {
    "country": "RO",
    "name": "Fârţăneşti",
    "lat": "45.81667",
    "lng": "27.98333"
  },
  {
    "country": "RO",
    "name": "Fârliug",
    "lat": "45.48833",
    "lng": "21.84944"
  },
  {
    "country": "RO",
    "name": "Fârdea",
    "lat": "45.73333",
    "lng": "22.16667"
  },
  {
    "country": "RO",
    "name": "Fântânele",
    "lat": "47.57463",
    "lng": "26.53277"
  },
  {
    "country": "RO",
    "name": "Fântânele",
    "lat": "47.51667",
    "lng": "26.31667"
  },
  {
    "country": "RO",
    "name": "Fântânele",
    "lat": "47.41498",
    "lng": "27.18066"
  },
  {
    "country": "RO",
    "name": "Fântânele",
    "lat": "46.41667",
    "lng": "24.75"
  },
  {
    "country": "RO",
    "name": "Fântânele",
    "lat": "46.1237",
    "lng": "21.3842"
  },
  {
    "country": "RO",
    "name": "Fântânele",
    "lat": "45.70152",
    "lng": "28.00354"
  },
  {
    "country": "RO",
    "name": "Fântânele",
    "lat": "45.007",
    "lng": "26.3772"
  },
  {
    "country": "RO",
    "name": "Fântânele",
    "lat": "44.71667",
    "lng": "25.86667"
  },
  {
    "country": "RO",
    "name": "Fântânele",
    "lat": "44.61278",
    "lng": "28.57655"
  },
  {
    "country": "RO",
    "name": "Fântânele",
    "lat": "43.72104",
    "lng": "25.29265"
  },
  {
    "country": "RO",
    "name": "Fântâna Mare",
    "lat": "47.41432",
    "lng": "26.30015"
  },
  {
    "country": "RO",
    "name": "Finta Mare",
    "lat": "44.8",
    "lng": "25.8"
  },
  {
    "country": "RO",
    "name": "Finiş",
    "lat": "46.63333",
    "lng": "22.31667"
  },
  {
    "country": "RO",
    "name": "Filipeştii de Târg",
    "lat": "44.98333",
    "lng": "25.78333"
  },
  {
    "country": "RO",
    "name": "Filipeştii de Pădure",
    "lat": "45",
    "lng": "25.75"
  },
  {
    "country": "RO",
    "name": "Filipeşti",
    "lat": "46.75",
    "lng": "26.88333"
  },
  {
    "country": "RO",
    "name": "Filipeni",
    "lat": "46.53333",
    "lng": "27.18333"
  },
  {
    "country": "RO",
    "name": "Filioara",
    "lat": "47.1604",
    "lng": "26.2792"
  },
  {
    "country": "RO",
    "name": "Filiaşi",
    "lat": "44.55",
    "lng": "23.51667"
  },
  {
    "country": "RO",
    "name": "Filiaș",
    "lat": "46.27075",
    "lng": "25.0212"
  },
  {
    "country": "RO",
    "name": "Filia",
    "lat": "46.14409",
    "lng": "25.6214"
  },
  {
    "country": "RO",
    "name": "Fildu de Jos",
    "lat": "46.93333",
    "lng": "23.06667"
  },
  {
    "country": "RO",
    "name": "Fierbinţi-Târg",
    "lat": "44.7",
    "lng": "26.35"
  },
  {
    "country": "RO",
    "name": "Fierbinții de Sus",
    "lat": "44.68186",
    "lng": "26.402"
  },
  {
    "country": "RO",
    "name": "Fierbinții de Jos",
    "lat": "44.69523",
    "lng": "26.39629"
  },
  {
    "country": "RO",
    "name": "Fierbinți",
    "lat": "44.50747",
    "lng": "25.2876"
  },
  {
    "country": "RO",
    "name": "Fieni",
    "lat": "45.13333",
    "lng": "25.41667"
  },
  {
    "country": "RO",
    "name": "Fibiș",
    "lat": "45.9728",
    "lng": "21.42355"
  },
  {
    "country": "RO",
    "name": "Fetești-Gară",
    "lat": "44.4196",
    "lng": "27.82536"
  },
  {
    "country": "RO",
    "name": "Fetești",
    "lat": "47.40932",
    "lng": "26.90885"
  },
  {
    "country": "RO",
    "name": "Feteşti",
    "lat": "44.38333",
    "lng": "27.83333"
  },
  {
    "country": "RO",
    "name": "Ferești",
    "lat": "46.78179",
    "lng": "27.70093"
  },
  {
    "country": "RO",
    "name": "Ferestrău-Oituz",
    "lat": "46.20249",
    "lng": "26.57629"
  },
  {
    "country": "RO",
    "name": "Feneș",
    "lat": "46.10431",
    "lng": "23.29511"
  },
  {
    "country": "RO",
    "name": "Felnac",
    "lat": "46.11667",
    "lng": "21.15"
  },
  {
    "country": "RO",
    "name": "Feliceni",
    "lat": "46.26667",
    "lng": "25.26667"
  },
  {
    "country": "RO",
    "name": "Feleacu",
    "lat": "46.71667",
    "lng": "23.61667"
  },
  {
    "country": "RO",
    "name": "Feldru",
    "lat": "47.28333",
    "lng": "24.6"
  },
  {
    "country": "RO",
    "name": "Feldioara",
    "lat": "45.81667",
    "lng": "25.6"
  },
  {
    "country": "RO",
    "name": "Feisa",
    "lat": "46.22608",
    "lng": "24.14492"
  },
  {
    "country": "RO",
    "name": "Făureşti",
    "lat": "44.56667",
    "lng": "24.01667"
  },
  {
    "country": "RO",
    "name": "Făurei",
    "lat": "46.91667",
    "lng": "26.68333"
  },
  {
    "country": "RO",
    "name": "Făurei",
    "lat": "45.08333",
    "lng": "27.26667"
  },
  {
    "country": "RO",
    "name": "Fărtăţeşti",
    "lat": "44.78333",
    "lng": "24"
  },
  {
    "country": "RO",
    "name": "Fărcașu de Jos",
    "lat": "44.13539",
    "lng": "24.45901"
  },
  {
    "country": "RO",
    "name": "Fărcaș",
    "lat": "44.6",
    "lng": "23.75"
  },
  {
    "country": "RO",
    "name": "Fărcăşeşti",
    "lat": "44.86667",
    "lng": "23.2"
  },
  {
    "country": "RO",
    "name": "Fărcășeni",
    "lat": "47.15987",
    "lng": "26.89615"
  },
  {
    "country": "RO",
    "name": "Fărcaşele",
    "lat": "44.15",
    "lng": "24.43333"
  },
  {
    "country": "RO",
    "name": "Grădinari",
    "lat": "44.39222",
    "lng": "25.81556"
  },
  {
    "country": "RO",
    "name": "Fărcaşa",
    "lat": "47.58333",
    "lng": "23.33333"
  },
  {
    "country": "RO",
    "name": "Fărcaşa",
    "lat": "47.16667",
    "lng": "25.83333"
  },
  {
    "country": "RO",
    "name": "Fărău",
    "lat": "46.33333",
    "lng": "24.01667"
  },
  {
    "country": "RO",
    "name": "Faraoaní",
    "lat": "46.43333",
    "lng": "26.9"
  },
  {
    "country": "RO",
    "name": "Fărăgău",
    "lat": "46.76667",
    "lng": "24.51667"
  },
  {
    "country": "RO",
    "name": "Fălticeni",
    "lat": "47.45",
    "lng": "26.3"
  },
  {
    "country": "RO",
    "name": "Fălcoiu",
    "lat": "44.23333",
    "lng": "24.36667"
  },
  {
    "country": "RO",
    "name": "Fălciu",
    "lat": "46.29611",
    "lng": "28.14083"
  },
  {
    "country": "RO",
    "name": "Falcău",
    "lat": "47.91087",
    "lng": "25.46908"
  },
  {
    "country": "RO",
    "name": "Falaștoaca",
    "lat": "44.19098",
    "lng": "26.18475"
  },
  {
    "country": "RO",
    "name": "Făgetu",
    "lat": "45.13668",
    "lng": "26.02018"
  },
  {
    "country": "RO",
    "name": "Făgeţelu",
    "lat": "44.78333",
    "lng": "24.53333"
  },
  {
    "country": "RO",
    "name": "Făget",
    "lat": "46.58891",
    "lng": "26.05349"
  },
  {
    "country": "RO",
    "name": "Făget",
    "lat": "45.85",
    "lng": "22.18333"
  },
  {
    "country": "RO",
    "name": "Făgăraș",
    "lat": "45.85",
    "lng": "24.96667"
  },
  {
    "country": "RO",
    "name": "Făclia",
    "lat": "44.28039",
    "lng": "28.10583"
  },
  {
    "country": "RO",
    "name": "Făcăi",
    "lat": "44.27356",
    "lng": "23.82029"
  },
  {
    "country": "RO",
    "name": "Făcăeni",
    "lat": "44.56667",
    "lng": "27.9"
  },
  {
    "country": "RO",
    "name": "Ezeriş",
    "lat": "45.41083",
    "lng": "21.88583"
  },
  {
    "country": "RO",
    "name": "Estelnic",
    "lat": "46.10445",
    "lng": "26.21262"
  },
  {
    "country": "RO",
    "name": "Eşelniţa",
    "lat": "44.69917",
    "lng": "22.36222"
  },
  {
    "country": "RO",
    "name": "Ernei",
    "lat": "46.60505",
    "lng": "24.64148"
  },
  {
    "country": "RO",
    "name": "Eremitu",
    "lat": "46.66667",
    "lng": "24.93333"
  },
  {
    "country": "RO",
    "name": "Erbiceni",
    "lat": "47.26667",
    "lng": "27.23333"
  },
  {
    "country": "RO",
    "name": "Iepureşti",
    "lat": "44.25806",
    "lng": "25.88222"
  },
  {
    "country": "RO",
    "name": "Epureni",
    "lat": "46.70769",
    "lng": "28.03829"
  },
  {
    "country": "RO",
    "name": "Epureni",
    "lat": "46.24693",
    "lng": "27.91123"
  },
  {
    "country": "RO",
    "name": "Enisala",
    "lat": "44.87956",
    "lng": "28.81872"
  },
  {
    "country": "RO",
    "name": "Emil Racoviță",
    "lat": "46.87147",
    "lng": "27.67937"
  },
  {
    "country": "RO",
    "name": "Eliseni",
    "lat": "46.29235",
    "lng": "24.93724"
  },
  {
    "country": "RO",
    "name": "Eftimie Murgu",
    "lat": "44.90028",
    "lng": "22.09278"
  },
  {
    "country": "RO",
    "name": "Eforie Sud",
    "lat": "44.02294",
    "lng": "28.64943"
  },
  {
    "country": "RO",
    "name": "Eforie Nord",
    "lat": "44.0653",
    "lng": "28.63211"
  },
  {
    "country": "RO",
    "name": "Eforie",
    "lat": "44.03973",
    "lng": "28.64685"
  },
  {
    "country": "RO",
    "name": "Iedera de Sus",
    "lat": "45.04174",
    "lng": "25.63084"
  },
  {
    "country": "RO",
    "name": "Iedera de Jos",
    "lat": "45.03333",
    "lng": "25.63333"
  },
  {
    "country": "RO",
    "name": "Durneşti",
    "lat": "47.76667",
    "lng": "27.1"
  },
  {
    "country": "RO",
    "name": "Dunăreni",
    "lat": "44.20463",
    "lng": "27.79058"
  },
  {
    "country": "RO",
    "name": "Cârna",
    "lat": "43.88613",
    "lng": "23.60153"
  },
  {
    "country": "RO",
    "name": "Dumitrița",
    "lat": "47.07143",
    "lng": "24.62579"
  },
  {
    "country": "RO",
    "name": "Dumitrești",
    "lat": "45.55243",
    "lng": "26.92727"
  },
  {
    "country": "RO",
    "name": "Dumitrești",
    "lat": "44.6837",
    "lng": "24.31628"
  },
  {
    "country": "RO",
    "name": "Dumitra",
    "lat": "47.21667",
    "lng": "24.48333"
  },
  {
    "country": "RO",
    "name": "Dumeşti",
    "lat": "47.18333",
    "lng": "27.35"
  },
  {
    "country": "RO",
    "name": "Dumeşti",
    "lat": "46.85",
    "lng": "27.28333"
  },
  {
    "country": "RO",
    "name": "Dumeni",
    "lat": "48.00724",
    "lng": "26.54287"
  },
  {
    "country": "RO",
    "name": "Dumbrăvița",
    "lat": "48.019",
    "lng": "26.42724"
  },
  {
    "country": "RO",
    "name": "Dumbrăviţa",
    "lat": "47.6",
    "lng": "23.65"
  },
  {
    "country": "RO",
    "name": "Dumbrăvița",
    "lat": "47.39845",
    "lng": "26.34578"
  },
  {
    "country": "RO",
    "name": "Dumbrăvița",
    "lat": "47.25483",
    "lng": "26.84169"
  },
  {
    "country": "RO",
    "name": "Dumbrăviţa",
    "lat": "45.79694",
    "lng": "21.2425"
  },
  {
    "country": "RO",
    "name": "Dumbrăviţa",
    "lat": "45.76667",
    "lng": "25.43333"
  },
  {
    "country": "RO",
    "name": "Dumbrăveşti",
    "lat": "45.08333",
    "lng": "26"
  },
  {
    "country": "RO",
    "name": "Dumbrăveni",
    "lat": "47.65",
    "lng": "26.41667"
  },
  {
    "country": "RO",
    "name": "Dumbrăveni",
    "lat": "46.23333",
    "lng": "24.56667"
  },
  {
    "country": "RO",
    "name": "Dumbrăveni",
    "lat": "45.53333",
    "lng": "27.11667"
  },
  {
    "country": "RO",
    "name": "Dumbrăveni",
    "lat": "43.93333",
    "lng": "27.98333"
  },
  {
    "country": "RO",
    "name": "Dumbrava Roşie",
    "lat": "46.88333",
    "lng": "26.43333"
  },
  {
    "country": "RO",
    "name": "Dumbrava de Sus",
    "lat": "44.51667",
    "lng": "23.11667"
  },
  {
    "country": "RO",
    "name": "Dumbrava",
    "lat": "47.84418",
    "lng": "23.0806"
  },
  {
    "country": "RO",
    "name": "Dumbrava",
    "lat": "47.2162",
    "lng": "26.46309"
  },
  {
    "country": "RO",
    "name": "Dumbrava",
    "lat": "47.07578",
    "lng": "27.55174"
  },
  {
    "country": "RO",
    "name": "Dumbrava",
    "lat": "46.30969",
    "lng": "26.89087"
  },
  {
    "country": "RO",
    "name": "Dumbrava",
    "lat": "45.81667",
    "lng": "22.11667"
  },
  {
    "country": "RO",
    "name": "Dumbrava",
    "lat": "44.88333",
    "lng": "26.18333"
  },
  {
    "country": "RO",
    "name": "Dulceşti",
    "lat": "46.96667",
    "lng": "26.76667"
  },
  {
    "country": "RO",
    "name": "Dulcești",
    "lat": "43.90506",
    "lng": "28.54796"
  },
  {
    "country": "RO",
    "name": "Dudu",
    "lat": "43.97897",
    "lng": "24.67786"
  },
  {
    "country": "RO",
    "name": "Dudeştii Vechi",
    "lat": "46.05",
    "lng": "20.48333"
  },
  {
    "country": "RO",
    "name": "Dudeștii Noi",
    "lat": "45.83989",
    "lng": "21.10215"
  },
  {
    "country": "RO",
    "name": "Dudeşti",
    "lat": "44.9",
    "lng": "27.43333"
  },
  {
    "country": "RO",
    "name": "Dudașu",
    "lat": "44.65253",
    "lng": "22.69683"
  },
  {
    "country": "RO",
    "name": "Duda",
    "lat": "46.7525",
    "lng": "28.03722"
  },
  {
    "country": "RO",
    "name": "Dubova",
    "lat": "44.61667",
    "lng": "22.26667"
  },
  {
    "country": "RO",
    "name": "Drobeta-Turnu Severin",
    "lat": "44.63194",
    "lng": "22.65611"
  },
  {
    "country": "RO",
    "name": "Băile Drânceni",
    "lat": "46.81361",
    "lng": "28.10083"
  },
  {
    "country": "RO",
    "name": "Drânceni",
    "lat": "46.80146",
    "lng": "28.13264"
  },
  {
    "country": "RO",
    "name": "Dridu",
    "lat": "44.7",
    "lng": "26.45"
  },
  {
    "country": "RO",
    "name": "Drauț",
    "lat": "46.26048",
    "lng": "21.80924"
  },
  {
    "country": "RO",
    "name": "Dranovățu",
    "lat": "44.43619",
    "lng": "24.27894"
  },
  {
    "country": "RO",
    "name": "Drănic",
    "lat": "44.05519",
    "lng": "23.84678"
  },
  {
    "country": "RO",
    "name": "Drajna Nouă",
    "lat": "44.42262",
    "lng": "27.38007"
  },
  {
    "country": "RO",
    "name": "Drajna de Sus",
    "lat": "45.25709",
    "lng": "26.07388"
  },
  {
    "country": "RO",
    "name": "Drajna de Jos",
    "lat": "45.21667",
    "lng": "26.05"
  },
  {
    "country": "RO",
    "name": "Drăguţeşti",
    "lat": "44.96667",
    "lng": "23.23333"
  },
  {
    "country": "RO",
    "name": "Drăguşeni",
    "lat": "48.01667",
    "lng": "26.81667"
  },
  {
    "country": "RO",
    "name": "Drăgușeni",
    "lat": "47.90541",
    "lng": "23.0778"
  },
  {
    "country": "RO",
    "name": "Drăguşeni",
    "lat": "47.28333",
    "lng": "26.48333"
  },
  {
    "country": "RO",
    "name": "Drăgușeni",
    "lat": "46.90116",
    "lng": "27.5126"
  },
  {
    "country": "RO",
    "name": "Drăguşeni",
    "lat": "45.96667",
    "lng": "27.75"
  },
  {
    "country": "RO",
    "name": "Drăguș",
    "lat": "45.76146",
    "lng": "24.77906"
  },
  {
    "country": "RO",
    "name": "Drăgugești",
    "lat": "46.36796",
    "lng": "26.77433"
  },
  {
    "country": "RO",
    "name": "Dragu",
    "lat": "47.01667",
    "lng": "23.4"
  },
  {
    "country": "RO",
    "name": "Drăgoteşti",
    "lat": "44.8",
    "lng": "23.16667"
  },
  {
    "country": "RO",
    "name": "Drăgoteşti",
    "lat": "44.25",
    "lng": "24.1"
  },
  {
    "country": "RO",
    "name": "Dragosloveni",
    "lat": "46",
    "lng": "26.66667"
  },
  {
    "country": "RO",
    "name": "Dragoș Vodă",
    "lat": "44.43333",
    "lng": "27.15"
  },
  {
    "country": "RO",
    "name": "Dragomireşti-Vale",
    "lat": "44.475",
    "lng": "25.935"
  },
  {
    "country": "RO",
    "name": "Dragomirești-Deal",
    "lat": "44.4624",
    "lng": "25.94478"
  },
  {
    "country": "RO",
    "name": "Dragomireşti",
    "lat": "47.66839",
    "lng": "24.29111"
  },
  {
    "country": "RO",
    "name": "Dragomireşti",
    "lat": "47.01667",
    "lng": "26.53333"
  },
  {
    "country": "RO",
    "name": "Dragomireşti",
    "lat": "46.63333",
    "lng": "27.35"
  },
  {
    "country": "RO",
    "name": "Dragomireşti",
    "lat": "44.91667",
    "lng": "25.33333"
  },
  {
    "country": "RO",
    "name": "Dragomir",
    "lat": "46.41373",
    "lng": "26.63163"
  },
  {
    "country": "RO",
    "name": "Drăgoeşti-Snagov",
    "lat": "44.56667",
    "lng": "26.53333"
  },
  {
    "country": "RO",
    "name": "Drăgoiești",
    "lat": "47.55",
    "lng": "26.08333"
  },
  {
    "country": "RO",
    "name": "Drăgoeşti",
    "lat": "44.81667",
    "lng": "24.3"
  },
  {
    "country": "RO",
    "name": "Drăgoești",
    "lat": "44.56786",
    "lng": "26.5395"
  },
  {
    "country": "RO",
    "name": "Dragodănești",
    "lat": "45.05552",
    "lng": "25.23631"
  },
  {
    "country": "RO",
    "name": "Dragodana",
    "lat": "44.73333",
    "lng": "25.35"
  },
  {
    "country": "RO",
    "name": "Drăghinești",
    "lat": "44.43093",
    "lng": "25.42608"
  },
  {
    "country": "RO",
    "name": "Drăghici",
    "lat": "45.12865",
    "lng": "25.04508"
  },
  {
    "country": "RO",
    "name": "Drăghiceni",
    "lat": "44.13333",
    "lng": "24.25"
  },
  {
    "country": "RO",
    "name": "Drăgeşti",
    "lat": "46.88333",
    "lng": "22.13333"
  },
  {
    "country": "RO",
    "name": "Drăgăşani",
    "lat": "44.65",
    "lng": "24.26667"
  },
  {
    "country": "RO",
    "name": "Drăganu-Olteni",
    "lat": "44.93333",
    "lng": "24.71667"
  },
  {
    "country": "RO",
    "name": "Drăgăneşti-Vlaşca",
    "lat": "44.10139",
    "lng": "25.59806"
  },
  {
    "country": "RO",
    "name": "Drăgăneşti-Olt",
    "lat": "44.16667",
    "lng": "24.53333"
  },
  {
    "country": "RO",
    "name": "Drăgăneşti de Vede",
    "lat": "44.13333",
    "lng": "25.05"
  },
  {
    "country": "RO",
    "name": "Drăgănești",
    "lat": "47.30886",
    "lng": "26.40551"
  },
  {
    "country": "RO",
    "name": "Drăgăneşti",
    "lat": "46.61667",
    "lng": "22.38333"
  },
  {
    "country": "RO",
    "name": "Drăgăneşti",
    "lat": "45.78333",
    "lng": "27.46667"
  },
  {
    "country": "RO",
    "name": "Drăgăneşti",
    "lat": "44.81667",
    "lng": "26.3"
  },
  {
    "country": "RO",
    "name": "Drăgăneasa",
    "lat": "45.10467",
    "lng": "25.68138"
  },
  {
    "country": "RO",
    "name": "Dragalina",
    "lat": "44.43333",
    "lng": "27.31667"
  },
  {
    "country": "RO",
    "name": "Drăgăești Ungureni",
    "lat": "44.94557",
    "lng": "25.31048"
  },
  {
    "country": "RO",
    "name": "Draxini",
    "lat": "47.65",
    "lng": "26.81667"
  },
  {
    "country": "RO",
    "name": "Dracșani",
    "lat": "47.62945",
    "lng": "26.93029"
  },
  {
    "country": "RO",
    "name": "Drăcşani",
    "lat": "44.21667",
    "lng": "24.98333"
  },
  {
    "country": "RO",
    "name": "Dracea",
    "lat": "43.84914",
    "lng": "25.05194"
  },
  {
    "country": "RO",
    "name": "23 August",
    "lat": "43.91667",
    "lng": "28.58333"
  },
  {
    "country": "RO",
    "name": "Doştat",
    "lat": "45.96667",
    "lng": "23.85"
  },
  {
    "country": "RO",
    "name": "Dorolţ",
    "lat": "47.85",
    "lng": "22.81667"
  },
  {
    "country": "RO",
    "name": "Dorohoi",
    "lat": "47.95",
    "lng": "26.4"
  },
  {
    "country": "RO",
    "name": "Dorobanţu",
    "lat": "44.95",
    "lng": "28.26667"
  },
  {
    "country": "RO",
    "name": "Dorobanțu",
    "lat": "44.41035",
    "lng": "28.32687"
  },
  {
    "country": "RO",
    "name": "Dorobanțu",
    "lat": "44.35416",
    "lng": "26.39341"
  },
  {
    "country": "RO",
    "name": "Dorobanţu",
    "lat": "44.21667",
    "lng": "26.95"
  },
  {
    "country": "RO",
    "name": "Dorobanți",
    "lat": "47.88234",
    "lng": "26.64723"
  },
  {
    "country": "RO",
    "name": "Dorobanți",
    "lat": "46.35022",
    "lng": "21.24441"
  },
  {
    "country": "RO",
    "name": "Dorneşti",
    "lat": "47.87174",
    "lng": "26.0043"
  },
  {
    "country": "RO",
    "name": "Dorna Cândrenilor",
    "lat": "47.35",
    "lng": "25.25"
  },
  {
    "country": "RO",
    "name": "Dor Mărunt",
    "lat": "44.45",
    "lng": "26.91667"
  },
  {
    "country": "RO",
    "name": "Dorgoş",
    "lat": "46.05",
    "lng": "21.83333"
  },
  {
    "country": "RO",
    "name": "Domnița",
    "lat": "47.02091",
    "lng": "27.335"
  },
  {
    "country": "RO",
    "name": "Domnești-Târg",
    "lat": "46.01667",
    "lng": "27.18333"
  },
  {
    "country": "RO",
    "name": "Domneşti-Sârbi",
    "lat": "44.38333",
    "lng": "25.91667"
  },
  {
    "country": "RO",
    "name": "Domneşti",
    "lat": "45.2",
    "lng": "24.83333"
  },
  {
    "country": "RO",
    "name": "Domnești",
    "lat": "44.39919",
    "lng": "25.91618"
  },
  {
    "country": "RO",
    "name": "Domaşnea",
    "lat": "45.08333",
    "lng": "22.31667"
  },
  {
    "country": "RO",
    "name": "Domănești",
    "lat": "47.71071",
    "lng": "22.58975"
  },
  {
    "country": "RO",
    "name": "Doljeşti",
    "lat": "47.03333",
    "lng": "26.98333"
  },
  {
    "country": "RO",
    "name": "Dolheștii Mici",
    "lat": "47.43633",
    "lng": "26.55178"
  },
  {
    "country": "RO",
    "name": "Dolheștii-Mari",
    "lat": "47.4502",
    "lng": "26.51326"
  },
  {
    "country": "RO",
    "name": "Dolhești",
    "lat": "47.21189",
    "lng": "26.06738"
  },
  {
    "country": "RO",
    "name": "Dolheşti",
    "lat": "46.86667",
    "lng": "27.9"
  },
  {
    "country": "RO",
    "name": "Dolhasca",
    "lat": "47.43333",
    "lng": "26.6"
  },
  {
    "country": "RO",
    "name": "Doiceşti",
    "lat": "44.98333",
    "lng": "25.4"
  },
  {
    "country": "RO",
    "name": "Dognecea",
    "lat": "45.27417",
    "lng": "21.75694"
  },
  {
    "country": "RO",
    "name": "Dofteana",
    "lat": "46.31667",
    "lng": "26.51667"
  },
  {
    "country": "RO",
    "name": "Doftana",
    "lat": "45.15",
    "lng": "25.8"
  },
  {
    "country": "RO",
    "name": "Dodești",
    "lat": "46.35455",
    "lng": "27.89311"
  },
  {
    "country": "RO",
    "name": "Dodeni",
    "lat": "46.92587",
    "lng": "26.09277"
  },
  {
    "country": "RO",
    "name": "Ștei",
    "lat": "46.53333",
    "lng": "22.45"
  },
  {
    "country": "RO",
    "name": "Doclin",
    "lat": "45.29694",
    "lng": "21.65389"
  },
  {
    "country": "RO",
    "name": "Dochia",
    "lat": "46.90731",
    "lng": "26.56763"
  },
  {
    "country": "RO",
    "name": "Dobrușa",
    "lat": "44.62642",
    "lng": "24.20779"
  },
  {
    "country": "RO",
    "name": "Dobrun",
    "lat": "44.26667",
    "lng": "24.21667"
  },
  {
    "country": "RO",
    "name": "Dobrovăţ",
    "lat": "46.95",
    "lng": "27.7"
  },
  {
    "country": "RO",
    "name": "Dobrotu",
    "lat": "45.20633",
    "lng": "24.65859"
  },
  {
    "country": "RO",
    "name": "Dobrotinet",
    "lat": "44.47957",
    "lng": "24.3473"
  },
  {
    "country": "RO",
    "name": "Dobroteşti",
    "lat": "44.28333",
    "lng": "24.88333"
  },
  {
    "country": "RO",
    "name": "Dobrotești",
    "lat": "43.96141",
    "lng": "24.12405"
  },
  {
    "country": "RO",
    "name": "Dobroteasa",
    "lat": "44.78333",
    "lng": "24.38333"
  },
  {
    "country": "RO",
    "name": "Dobrosloveni",
    "lat": "44.18333",
    "lng": "24.36667"
  },
  {
    "country": "RO",
    "name": "Dobromir",
    "lat": "44.01667",
    "lng": "27.78333"
  },
  {
    "country": "RO",
    "name": "Dobroeşti",
    "lat": "44.45",
    "lng": "26.18333"
  },
  {
    "country": "RO",
    "name": "Dobrița",
    "lat": "45.13504",
    "lng": "23.17406"
  },
  {
    "country": "RO",
    "name": "Dobrin",
    "lat": "47.28333",
    "lng": "23.13333"
  },
  {
    "country": "RO",
    "name": "Dobridor",
    "lat": "44.11866",
    "lng": "23.16969"
  },
  {
    "country": "RO",
    "name": "Dobric",
    "lat": "47.2469",
    "lng": "24.12777"
  },
  {
    "country": "RO",
    "name": "Dobreţu",
    "lat": "44.5",
    "lng": "23.95"
  },
  {
    "country": "RO",
    "name": "Dobreşti",
    "lat": "46.85",
    "lng": "22.3"
  },
  {
    "country": "RO",
    "name": "Dobreşti",
    "lat": "44.96667",
    "lng": "25.13333"
  },
  {
    "country": "RO",
    "name": "Dobreşti",
    "lat": "43.96667",
    "lng": "23.95"
  },
  {
    "country": "RO",
    "name": "Dobreni",
    "lat": "46.98333",
    "lng": "26.41667"
  },
  {
    "country": "RO",
    "name": "Dobreni",
    "lat": "44.41667",
    "lng": "25.11667"
  },
  {
    "country": "RO",
    "name": "Dobreni",
    "lat": "44.2543",
    "lng": "26.21344"
  },
  {
    "country": "RO",
    "name": "Dobra",
    "lat": "47.49477",
    "lng": "22.82762"
  },
  {
    "country": "RO",
    "name": "Dobra",
    "lat": "45.91667",
    "lng": "22.56667"
  },
  {
    "country": "RO",
    "name": "Dobra",
    "lat": "45.76913",
    "lng": "23.64218"
  },
  {
    "country": "RO",
    "name": "Dobra",
    "lat": "44.78333",
    "lng": "25.71667"
  },
  {
    "country": "RO",
    "name": "Doboșeni",
    "lat": "46.12431",
    "lng": "25.59347"
  },
  {
    "country": "RO",
    "name": "Dobârlău",
    "lat": "45.73333",
    "lng": "25.88333"
  },
  {
    "country": "RO",
    "name": "Dobârceni",
    "lat": "47.81667",
    "lng": "27.06667"
  },
  {
    "country": "RO",
    "name": "Doba",
    "lat": "47.73333",
    "lng": "22.71667"
  },
  {
    "country": "RO",
    "name": "Doanca",
    "lat": "43.8487",
    "lng": "24.64949"
  },
  {
    "country": "RO",
    "name": "Ditrău",
    "lat": "46.81667",
    "lng": "25.51667"
  },
  {
    "country": "RO",
    "name": "Dițești",
    "lat": "44.9799",
    "lng": "25.72655"
  },
  {
    "country": "RO",
    "name": "Dârza",
    "lat": "44.60175",
    "lng": "25.94956"
  },
  {
    "country": "RO",
    "name": "Dârvari",
    "lat": "44.42108",
    "lng": "25.87989"
  },
  {
    "country": "RO",
    "name": "Dârvari",
    "lat": "44.2",
    "lng": "23.05"
  },
  {
    "country": "RO",
    "name": "Dârlos",
    "lat": "46.18333",
    "lng": "24.4"
  },
  {
    "country": "RO",
    "name": "Dârjiu",
    "lat": "46.2",
    "lng": "25.2"
  },
  {
    "country": "RO",
    "name": "Dioşti",
    "lat": "44.11667",
    "lng": "24.18333"
  },
  {
    "country": "RO",
    "name": "Dioșod",
    "lat": "47.29238",
    "lng": "23.02099"
  },
  {
    "country": "RO",
    "name": "Diosig",
    "lat": "47.3",
    "lng": "22"
  },
  {
    "country": "RO",
    "name": "Dângeni",
    "lat": "47.85",
    "lng": "26.96667"
  },
  {
    "country": "RO",
    "name": "Hurdugi",
    "lat": "46.50778",
    "lng": "28.05472"
  },
  {
    "country": "RO",
    "name": "Dâmbu",
    "lat": "45.04533",
    "lng": "25.88854"
  },
  {
    "country": "RO",
    "name": "Dâmbroca",
    "lat": "45.12328",
    "lng": "26.95578"
  },
  {
    "country": "RO",
    "name": "Dâmbovicioara",
    "lat": "45.45",
    "lng": "25.23333"
  },
  {
    "country": "RO",
    "name": "Dâmbovicioara",
    "lat": "44.67569",
    "lng": "25.55374"
  },
  {
    "country": "RO",
    "name": "Dâmbău",
    "lat": "46.31998",
    "lng": "24.23443"
  },
  {
    "country": "RO",
    "name": "Dimăcheni",
    "lat": "47.91139",
    "lng": "26.5456"
  },
  {
    "country": "RO",
    "name": "Dieci",
    "lat": "46.31667",
    "lng": "22.25"
  },
  {
    "country": "RO",
    "name": "Diculești",
    "lat": "44.59351",
    "lng": "23.98968"
  },
  {
    "country": "RO",
    "name": "Dichiseni",
    "lat": "44.23333",
    "lng": "27.53333"
  },
  {
    "country": "RO",
    "name": "Dezna",
    "lat": "46.4",
    "lng": "22.25"
  },
  {
    "country": "RO",
    "name": "Dezmir",
    "lat": "46.76475",
    "lng": "23.72451"
  },
  {
    "country": "RO",
    "name": "Deveselu",
    "lat": "44.06667",
    "lng": "24.38333"
  },
  {
    "country": "RO",
    "name": "Devesel",
    "lat": "44.46889",
    "lng": "22.66722"
  },
  {
    "country": "RO",
    "name": "Deva",
    "lat": "45.88333",
    "lng": "22.9"
  },
  {
    "country": "RO",
    "name": "Deta",
    "lat": "45.38889",
    "lng": "21.22444"
  },
  {
    "country": "RO",
    "name": "Deseşti",
    "lat": "47.76667",
    "lng": "23.85"
  },
  {
    "country": "RO",
    "name": "Desa",
    "lat": "43.86667",
    "lng": "23.03333"
  },
  {
    "country": "RO",
    "name": "Derșida",
    "lat": "47.3881",
    "lng": "22.8017"
  },
  {
    "country": "RO",
    "name": "Dersca",
    "lat": "47.98333",
    "lng": "26.2"
  },
  {
    "country": "RO",
    "name": "Derna",
    "lat": "47.2",
    "lng": "22.3"
  },
  {
    "country": "RO",
    "name": "Deparați",
    "lat": "44.28116",
    "lng": "25.22151"
  },
  {
    "country": "RO",
    "name": "Denta",
    "lat": "45.35389",
    "lng": "21.24917"
  },
  {
    "country": "RO",
    "name": "Densuş",
    "lat": "45.58333",
    "lng": "22.8"
  },
  {
    "country": "RO",
    "name": "Demacușa",
    "lat": "47.69717",
    "lng": "25.50499"
  },
  {
    "country": "RO",
    "name": "Beznea",
    "lat": "46.95967",
    "lng": "22.61954"
  },
  {
    "country": "RO",
    "name": "Deleşti",
    "lat": "46.7",
    "lng": "27.55"
  },
  {
    "country": "RO",
    "name": "Deleni",
    "lat": "46.2634",
    "lng": "24.34119"
  },
  {
    "country": "RO",
    "name": "Deleni",
    "lat": "47.46667",
    "lng": "26.88333"
  },
  {
    "country": "RO",
    "name": "Deleni",
    "lat": "46.55",
    "lng": "27.75"
  },
  {
    "country": "RO",
    "name": "Deleni",
    "lat": "46.3536",
    "lng": "26.77628"
  },
  {
    "country": "RO",
    "name": "Deleni",
    "lat": "44.1",
    "lng": "28.01667"
  },
  {
    "country": "RO",
    "name": "Dejești",
    "lat": "44.83093",
    "lng": "24.35648"
  },
  {
    "country": "RO",
    "name": "Deja",
    "lat": "47.35537",
    "lng": "23.183"
  },
  {
    "country": "RO",
    "name": "Dej",
    "lat": "47.15",
    "lng": "23.86667"
  },
  {
    "country": "RO",
    "name": "Dedulești",
    "lat": "45.14679",
    "lng": "27.38907"
  },
  {
    "country": "RO",
    "name": "Dedrad",
    "lat": "46.82632",
    "lng": "24.65799"
  },
  {
    "country": "RO",
    "name": "Dedulești",
    "lat": "45.47003",
    "lng": "26.96737"
  },
  {
    "country": "RO",
    "name": "Deda",
    "lat": "46.93333",
    "lng": "24.9"
  },
  {
    "country": "RO",
    "name": "Decindeni",
    "lat": "44.91234",
    "lng": "25.32607"
  },
  {
    "country": "RO",
    "name": "Decebal",
    "lat": "47.7663",
    "lng": "22.75603"
  },
  {
    "country": "RO",
    "name": "Dealu Morii",
    "lat": "46.31667",
    "lng": "27.23333"
  },
  {
    "country": "RO",
    "name": "Dealu Mare",
    "lat": "45.16072",
    "lng": "25.44871"
  },
  {
    "country": "RO",
    "name": "Dealu Frumos",
    "lat": "45.18575",
    "lng": "25.41329"
  },
  {
    "country": "RO",
    "name": "Dealu Dănicei",
    "lat": "44.9",
    "lng": "24.43333"
  },
  {
    "country": "RO",
    "name": "Dealu Aluniș",
    "lat": "44.98252",
    "lng": "23.86749"
  },
  {
    "country": "RO",
    "name": "Dealu",
    "lat": "46.4",
    "lng": "25.3"
  },
  {
    "country": "RO",
    "name": "Dealu",
    "lat": "44.39938",
    "lng": "25.64857"
  },
  {
    "country": "RO",
    "name": "Deaj",
    "lat": "46.34711",
    "lng": "24.40206"
  },
  {
    "country": "RO",
    "name": "Davideşti",
    "lat": "45.01667",
    "lng": "25.03333"
  },
  {
    "country": "RO",
    "name": "Dascălu",
    "lat": "44.6",
    "lng": "26.23333"
  },
  {
    "country": "RO",
    "name": "Dăscălești",
    "lat": "45.40626",
    "lng": "27.25039"
  },
  {
    "country": "RO",
    "name": "Darova Nouă",
    "lat": "45.63333",
    "lng": "21.76667"
  },
  {
    "country": "RO",
    "name": "Darova",
    "lat": "45.642",
    "lng": "21.77333"
  },
  {
    "country": "RO",
    "name": "Dărmăneşti",
    "lat": "47.73333",
    "lng": "26.15"
  },
  {
    "country": "RO",
    "name": "Dărmăneşti",
    "lat": "46.36667",
    "lng": "26.48333"
  },
  {
    "country": "RO",
    "name": "Dărmăneşti",
    "lat": "45.01667",
    "lng": "24.9"
  },
  {
    "country": "RO",
    "name": "Dărmăneşti",
    "lat": "44.91667",
    "lng": "25.78333"
  },
  {
    "country": "RO",
    "name": "Dărăști-Vlașca",
    "lat": "44.29401",
    "lng": "26.01119"
  },
  {
    "country": "RO",
    "name": "Dărăşti-Ilfov",
    "lat": "44.30889",
    "lng": "26.01833"
  },
  {
    "country": "RO",
    "name": "Darabani",
    "lat": "48.18333",
    "lng": "26.58333"
  },
  {
    "country": "RO",
    "name": "Dara",
    "lat": "47.81636",
    "lng": "22.75216"
  },
  {
    "country": "RO",
    "name": "Dăneţi",
    "lat": "43.98333",
    "lng": "24.05"
  },
  {
    "country": "RO",
    "name": "Dăneşti",
    "lat": "46.85",
    "lng": "27.66667"
  },
  {
    "country": "RO",
    "name": "Dăneşti",
    "lat": "46.51667",
    "lng": "25.75"
  },
  {
    "country": "RO",
    "name": "Dăneşti",
    "lat": "44.96667",
    "lng": "23.33333"
  },
  {
    "country": "RO",
    "name": "Daneş",
    "lat": "46.21667",
    "lng": "24.7"
  },
  {
    "country": "RO",
    "name": "Dăneasa",
    "lat": "44.15",
    "lng": "24.56667"
  },
  {
    "country": "RO",
    "name": "Dancu",
    "lat": "47.15417",
    "lng": "27.66623"
  },
  {
    "country": "RO",
    "name": "Dănciuleşti",
    "lat": "44.73333",
    "lng": "23.75"
  },
  {
    "country": "RO",
    "name": "Dănceu",
    "lat": "44.36416",
    "lng": "22.72098"
  },
  {
    "country": "RO",
    "name": "Dămuc",
    "lat": "46.8",
    "lng": "25.9"
  },
  {
    "country": "RO",
    "name": "Dămoc",
    "lat": "46.46667",
    "lng": "26.86667"
  },
  {
    "country": "RO",
    "name": "Dămieneşti",
    "lat": "46.73333",
    "lng": "26.98333"
  },
  {
    "country": "RO",
    "name": "Dămăcușeni",
    "lat": "47.45709",
    "lng": "23.90914"
  },
  {
    "country": "RO",
    "name": "Dalnic",
    "lat": "45.92242",
    "lng": "25.98741"
  },
  {
    "country": "RO",
    "name": "Dalboșeț",
    "lat": "44.86399",
    "lng": "21.95854"
  },
  {
    "country": "RO",
    "name": "Daia Română",
    "lat": "46.01667",
    "lng": "23.66667"
  },
  {
    "country": "RO",
    "name": "Daia",
    "lat": "44",
    "lng": "25.98333"
  },
  {
    "country": "RO",
    "name": "Dagâţa",
    "lat": "46.93333",
    "lng": "27.18333"
  },
  {
    "country": "RO",
    "name": "Dăești",
    "lat": "45.20107",
    "lng": "24.38684"
  },
  {
    "country": "RO",
    "name": "Dăeşti",
    "lat": "44.96667",
    "lng": "24.13333"
  },
  {
    "country": "RO",
    "name": "Dăeni",
    "lat": "44.83333",
    "lng": "28.11667"
  },
  {
    "country": "RO",
    "name": "Dăbuleni",
    "lat": "43.8",
    "lng": "24.08333"
  },
  {
    "country": "RO",
    "name": "Dăbâca",
    "lat": "46.98333",
    "lng": "23.66667"
  },
  {
    "country": "RO",
    "name": "Cuza Vodă",
    "lat": "45.59595",
    "lng": "27.79267"
  },
  {
    "country": "RO",
    "name": "Cuza Vodă",
    "lat": "45.39017",
    "lng": "27.44838"
  },
  {
    "country": "RO",
    "name": "Cuza Vodă",
    "lat": "44.92513",
    "lng": "27.73273"
  },
  {
    "country": "RO",
    "name": "Cuza Vodă",
    "lat": "44.28773",
    "lng": "28.31005"
  },
  {
    "country": "RO",
    "name": "Cuza Vodă",
    "lat": "44.26667",
    "lng": "27.26667"
  },
  {
    "country": "RO",
    "name": "Cuzăplac",
    "lat": "46.96667",
    "lng": "23.2"
  },
  {
    "country": "RO",
    "name": "Cuzap",
    "lat": "47.20288",
    "lng": "22.41523"
  },
  {
    "country": "RO",
    "name": "Cuvin",
    "lat": "46.17001",
    "lng": "21.5936"
  },
  {
    "country": "RO",
    "name": "Cut",
    "lat": "46.88258",
    "lng": "26.41928"
  },
  {
    "country": "RO",
    "name": "Cut",
    "lat": "45.93972",
    "lng": "23.66719"
  },
  {
    "country": "RO",
    "name": "Cuzdrioara",
    "lat": "47.16667",
    "lng": "23.91667"
  },
  {
    "country": "RO",
    "name": "Curtuișeni",
    "lat": "47.54633",
    "lng": "22.20263"
  },
  {
    "country": "RO",
    "name": "Curtişoara",
    "lat": "44.5",
    "lng": "24.33333"
  },
  {
    "country": "RO",
    "name": "Curtici",
    "lat": "46.35",
    "lng": "21.3"
  },
  {
    "country": "RO",
    "name": "Curteşti",
    "lat": "47.71667",
    "lng": "26.65"
  },
  {
    "country": "RO",
    "name": "Curtea de Argeş",
    "lat": "45.13422",
    "lng": "24.67409"
  },
  {
    "country": "RO",
    "name": "Curtea",
    "lat": "45.81667",
    "lng": "22.3"
  },
  {
    "country": "RO",
    "name": "Curcani",
    "lat": "44.2",
    "lng": "26.58333"
  },
  {
    "country": "RO",
    "name": "Curăţele",
    "lat": "46.7",
    "lng": "22.41667"
  },
  {
    "country": "RO",
    "name": "Cupşeni",
    "lat": "47.55",
    "lng": "23.93333"
  },
  {
    "country": "RO",
    "name": "Cungrea",
    "lat": "44.66667",
    "lng": "24.38333"
  },
  {
    "country": "RO",
    "name": "Cumpăna",
    "lat": "44.11667",
    "lng": "28.56667"
  },
  {
    "country": "RO",
    "name": "Culciu Mic",
    "lat": "47.76667",
    "lng": "23.03333"
  },
  {
    "country": "RO",
    "name": "Cujmir",
    "lat": "44.20667",
    "lng": "22.92667"
  },
  {
    "country": "RO",
    "name": "Cugir",
    "lat": "45.83651",
    "lng": "23.36998"
  },
  {
    "country": "RO",
    "name": "Cuejdiu",
    "lat": "46.9904",
    "lng": "26.29455"
  },
  {
    "country": "RO",
    "name": "Cudalbi",
    "lat": "45.78333",
    "lng": "27.7"
  },
  {
    "country": "RO",
    "name": "Cucuteni",
    "lat": "47.28333",
    "lng": "26.93333"
  },
  {
    "country": "RO",
    "name": "Cucuruzu",
    "lat": "44.0802",
    "lng": "25.73242"
  },
  {
    "country": "RO",
    "name": "Cucuieți",
    "lat": "46.5898",
    "lng": "26.52875"
  },
  {
    "country": "RO",
    "name": "Cucuieți",
    "lat": "46.32731",
    "lng": "26.55504"
  },
  {
    "country": "RO",
    "name": "Cucueți",
    "lat": "44.18432",
    "lng": "24.94826"
  },
  {
    "country": "RO",
    "name": "Cuciulata",
    "lat": "45.94389",
    "lng": "25.27541"
  },
  {
    "country": "RO",
    "name": "Cuci",
    "lat": "46.46667",
    "lng": "24.15"
  },
  {
    "country": "RO",
    "name": "Cucerdea",
    "lat": "46.4",
    "lng": "24.26667"
  },
  {
    "country": "RO",
    "name": "Cuca",
    "lat": "45.73333",
    "lng": "27.88333"
  },
  {
    "country": "RO",
    "name": "Cuca",
    "lat": "44.95",
    "lng": "24.51667"
  },
  {
    "country": "RO",
    "name": "Cubulcut",
    "lat": "47.3227",
    "lng": "22.18648"
  },
  {
    "country": "RO",
    "name": "Crușovu",
    "lat": "43.92473",
    "lng": "24.41486"
  },
  {
    "country": "RO",
    "name": "Crușeț",
    "lat": "44.63333",
    "lng": "23.66667"
  },
  {
    "country": "RO",
    "name": "Crucişor",
    "lat": "47.68333",
    "lng": "23.25"
  },
  {
    "country": "RO",
    "name": "Crucea",
    "lat": "47.35",
    "lng": "25.61667"
  },
  {
    "country": "RO",
    "name": "Crucea",
    "lat": "47.16567",
    "lng": "27.17093"
  },
  {
    "country": "RO",
    "name": "Crucea",
    "lat": "44.53333",
    "lng": "28.23333"
  },
  {
    "country": "RO",
    "name": "Crovu",
    "lat": "44.58947",
    "lng": "25.53684"
  },
  {
    "country": "RO",
    "name": "Croitori",
    "lat": "44.57512",
    "lng": "25.41356"
  },
  {
    "country": "RO",
    "name": "Crizbav",
    "lat": "45.81515",
    "lng": "25.46718"
  },
  {
    "country": "RO",
    "name": "Crivina",
    "lat": "45.58333",
    "lng": "25.98333"
  },
  {
    "country": "RO",
    "name": "Crivina",
    "lat": "44.78636",
    "lng": "26.05604"
  },
  {
    "country": "RO",
    "name": "Crivești",
    "lat": "47.3243",
    "lng": "26.7824"
  },
  {
    "country": "RO",
    "name": "Crivăț",
    "lat": "44.19338",
    "lng": "26.43846"
  },
  {
    "country": "RO",
    "name": "Cristuru Secuiesc",
    "lat": "46.28333",
    "lng": "25.03333"
  },
  {
    "country": "RO",
    "name": "Cristur",
    "lat": "45.82936",
    "lng": "22.94323"
  },
  {
    "country": "RO",
    "name": "Cristolţ",
    "lat": "47.2",
    "lng": "23.43333"
  },
  {
    "country": "RO",
    "name": "Criştioru de Jos",
    "lat": "46.41937",
    "lng": "22.53457"
  },
  {
    "country": "RO",
    "name": "Cristineşti",
    "lat": "48.1",
    "lng": "26.38333"
  },
  {
    "country": "RO",
    "name": "Cristian",
    "lat": "45.78333",
    "lng": "24.03333"
  },
  {
    "country": "RO",
    "name": "Cristian",
    "lat": "45.61667",
    "lng": "25.46667"
  },
  {
    "country": "RO",
    "name": "Cristeștii Ciceului",
    "lat": "47.19326",
    "lng": "24.09605"
  },
  {
    "country": "RO",
    "name": "Cristeşti",
    "lat": "47.63333",
    "lng": "26.73333"
  },
  {
    "country": "RO",
    "name": "Cristeşti",
    "lat": "47.26667",
    "lng": "26.56667"
  },
  {
    "country": "RO",
    "name": "Cristești",
    "lat": "47.16224",
    "lng": "27.08155"
  },
  {
    "country": "RO",
    "name": "Cristeşti",
    "lat": "46.5",
    "lng": "24.48333"
  },
  {
    "country": "RO",
    "name": "Crişeni",
    "lat": "47.23333",
    "lng": "23.05"
  },
  {
    "country": "RO",
    "name": "Crişcior",
    "lat": "46.11667",
    "lng": "22.86667"
  },
  {
    "country": "RO",
    "name": "Crişan",
    "lat": "44.96667",
    "lng": "29.46667"
  },
  {
    "country": "RO",
    "name": "Crângurile de Sus",
    "lat": "44.76667",
    "lng": "25.23333"
  },
  {
    "country": "RO",
    "name": "Crângu",
    "lat": "43.84611",
    "lng": "25.0735"
  },
  {
    "country": "RO",
    "name": "Crângeni",
    "lat": "44.03333",
    "lng": "24.78333"
  },
  {
    "country": "RO",
    "name": "Crâmpoia",
    "lat": "44.30215",
    "lng": "24.74513"
  },
  {
    "country": "RO",
    "name": "Criciova",
    "lat": "45.63333",
    "lng": "22.06667"
  },
  {
    "country": "RO",
    "name": "Cricău",
    "lat": "46.18333",
    "lng": "23.56667"
  },
  {
    "country": "RO",
    "name": "Crevenicu",
    "lat": "44.24083",
    "lng": "25.58861"
  },
  {
    "country": "RO",
    "name": "Crevedia Mare",
    "lat": "44.42917",
    "lng": "25.62556"
  },
  {
    "country": "RO",
    "name": "Crevedia",
    "lat": "44.6",
    "lng": "25.93333"
  },
  {
    "country": "RO",
    "name": "Crețești",
    "lat": "46.63333",
    "lng": "27.95"
  },
  {
    "country": "RO",
    "name": "Crețești",
    "lat": "44.28238",
    "lng": "26.1353"
  },
  {
    "country": "RO",
    "name": "Creţeni",
    "lat": "44.68333",
    "lng": "24.18333"
  },
  {
    "country": "RO",
    "name": "Creaca",
    "lat": "47.2",
    "lng": "23.25"
  },
  {
    "country": "RO",
    "name": "Crasna Vișeului",
    "lat": "47.82869",
    "lng": "24.23"
  },
  {
    "country": "RO",
    "name": "Crasna",
    "lat": "47.16667",
    "lng": "22.9"
  },
  {
    "country": "RO",
    "name": "Crasna",
    "lat": "45.16667",
    "lng": "23.5"
  },
  {
    "country": "RO",
    "name": "Craiva",
    "lat": "46.58333",
    "lng": "21.96667"
  },
  {
    "country": "RO",
    "name": "Craiova",
    "lat": "44.31667",
    "lng": "23.8"
  },
  {
    "country": "RO",
    "name": "Crăieşti",
    "lat": "46.3",
    "lng": "24.18333"
  },
  {
    "country": "RO",
    "name": "Craidorolţ",
    "lat": "47.61667",
    "lng": "22.7"
  },
  {
    "country": "RO",
    "name": "Crăiești",
    "lat": "46.75771",
    "lng": "24.42499"
  },
  {
    "country": "RO",
    "name": "Crăiești",
    "lat": "45.94314",
    "lng": "27.81136"
  },
  {
    "country": "RO",
    "name": "Crăciunești",
    "lat": "47.95551",
    "lng": "23.98267"
  },
  {
    "country": "RO",
    "name": "Crăciuneşti",
    "lat": "46.4793",
    "lng": "24.58234"
  },
  {
    "country": "RO",
    "name": "Crăciunelu de Jos",
    "lat": "46.18333",
    "lng": "23.83333"
  },
  {
    "country": "RO",
    "name": "Crăciunei",
    "lat": "44.14575",
    "lng": "24.66309"
  },
  {
    "country": "RO",
    "name": "Cracăul Negru",
    "lat": "47.09363",
    "lng": "26.24061"
  },
  {
    "country": "RO",
    "name": "Crăcăoani",
    "lat": "47.09836",
    "lng": "26.31111"
  },
  {
    "country": "RO",
    "name": "Cozmeşti",
    "lat": "46.88333",
    "lng": "27.98333"
  },
  {
    "country": "RO",
    "name": "Cozmești",
    "lat": "46.73375",
    "lng": "27.50164"
  },
  {
    "country": "RO",
    "name": "Cozmeni",
    "lat": "46.22678",
    "lng": "25.94209"
  },
  {
    "country": "RO",
    "name": "Cozma",
    "lat": "46.81667",
    "lng": "24.53333"
  },
  {
    "country": "RO",
    "name": "Cozieni",
    "lat": "45.33333",
    "lng": "26.48333"
  },
  {
    "country": "RO",
    "name": "Cozia",
    "lat": "47.00319",
    "lng": "27.89434"
  },
  {
    "country": "RO",
    "name": "Covrigi",
    "lat": "44.73825",
    "lng": "23.14921"
  },
  {
    "country": "RO",
    "name": "Covasna",
    "lat": "47.00255",
    "lng": "27.85106"
  },
  {
    "country": "RO",
    "name": "Covasna",
    "lat": "45.85",
    "lng": "26.18333"
  },
  {
    "country": "RO",
    "name": "Covăsinţ",
    "lat": "46.2",
    "lng": "21.6"
  },
  {
    "country": "RO",
    "name": "Cotu Vameș",
    "lat": "46.906",
    "lng": "26.95535"
  },
  {
    "country": "RO",
    "name": "Coţuşca",
    "lat": "48.13333",
    "lng": "26.85"
  },
  {
    "country": "RO",
    "name": "Cotumba",
    "lat": "46.49743",
    "lng": "26.19112"
  },
  {
    "country": "RO",
    "name": "Coțofenii din Față",
    "lat": "44.45971",
    "lng": "23.65688"
  },
  {
    "country": "RO",
    "name": "Coţofenii din Dos",
    "lat": "44.43333",
    "lng": "23.61667"
  },
  {
    "country": "RO",
    "name": "Coţofăneşti",
    "lat": "46.15",
    "lng": "26.98333"
  },
  {
    "country": "RO",
    "name": "Cotnari",
    "lat": "47.35",
    "lng": "26.98333"
  },
  {
    "country": "RO",
    "name": "Cotmeana",
    "lat": "44.96667",
    "lng": "24.61667"
  },
  {
    "country": "RO",
    "name": "Coteşti",
    "lat": "45.65",
    "lng": "27.05"
  },
  {
    "country": "RO",
    "name": "Cotenești",
    "lat": "45.23462",
    "lng": "25.18617"
  },
  {
    "country": "RO",
    "name": "Coteana",
    "lat": "44.3",
    "lng": "24.46667"
  },
  {
    "country": "RO",
    "name": "Coțatcu",
    "lat": "45.46643",
    "lng": "27.01486"
  },
  {
    "country": "RO",
    "name": "Coșula",
    "lat": "47.6257",
    "lng": "26.77827"
  },
  {
    "country": "RO",
    "name": "Costuleni",
    "lat": "47.03333",
    "lng": "27.85"
  },
  {
    "country": "RO",
    "name": "Costişa",
    "lat": "46.75",
    "lng": "26.65"
  },
  {
    "country": "RO",
    "name": "Costineşti",
    "lat": "43.95",
    "lng": "28.63333"
  },
  {
    "country": "RO",
    "name": "Costâna",
    "lat": "47.69265",
    "lng": "26.119"
  },
  {
    "country": "RO",
    "name": "Costeştii din Vale",
    "lat": "44.65",
    "lng": "25.48333"
  },
  {
    "country": "RO",
    "name": "Costeștii din Deal",
    "lat": "44.68132",
    "lng": "25.48938"
  },
  {
    "country": "RO",
    "name": "Costești",
    "lat": "47.80032",
    "lng": "26.67584"
  },
  {
    "country": "RO",
    "name": "Costești",
    "lat": "47.23428",
    "lng": "26.92622"
  },
  {
    "country": "RO",
    "name": "Costeşti",
    "lat": "46.5",
    "lng": "27.75"
  },
  {
    "country": "RO",
    "name": "Costeşti",
    "lat": "45.15",
    "lng": "24.06667"
  },
  {
    "country": "RO",
    "name": "Costeşti",
    "lat": "45.05",
    "lng": "26.76667"
  },
  {
    "country": "RO",
    "name": "Costești",
    "lat": "44.73264",
    "lng": "23.44491"
  },
  {
    "country": "RO",
    "name": "Costeşti",
    "lat": "44.66667",
    "lng": "24.88333"
  },
  {
    "country": "RO",
    "name": "Coşteiu",
    "lat": "45.74111",
    "lng": "21.84917"
  },
  {
    "country": "RO",
    "name": "Costache Negri",
    "lat": "45.7",
    "lng": "27.71667"
  },
  {
    "country": "RO",
    "name": "Coşoveni",
    "lat": "44.25",
    "lng": "23.93333"
  },
  {
    "country": "RO",
    "name": "Cosoba",
    "lat": "44.52268",
    "lng": "25.81903"
  },
  {
    "country": "RO",
    "name": "Coșna",
    "lat": "47.37098",
    "lng": "25.18133"
  },
  {
    "country": "RO",
    "name": "Cosmina de Jos",
    "lat": "45.15",
    "lng": "25.88333"
  },
  {
    "country": "RO",
    "name": "Cosmeștii-Vale",
    "lat": "45.86931",
    "lng": "27.28771"
  },
  {
    "country": "RO",
    "name": "Cosmeşti",
    "lat": "45.87017",
    "lng": "27.31115"
  },
  {
    "country": "RO",
    "name": "Cosmeşti",
    "lat": "44.3",
    "lng": "25.38333"
  },
  {
    "country": "RO",
    "name": "Cosâmbeşti",
    "lat": "44.55929",
    "lng": "27.43441"
  },
  {
    "country": "RO",
    "name": "Coşeşti",
    "lat": "45.06667",
    "lng": "24.86667"
  },
  {
    "country": "RO",
    "name": "Coşereni",
    "lat": "44.68333",
    "lng": "26.56667"
  },
  {
    "country": "RO",
    "name": "Coşeiu",
    "lat": "47.31667",
    "lng": "22.98333"
  },
  {
    "country": "RO",
    "name": "Coşbuc",
    "lat": "47.3654",
    "lng": "24.39115"
  },
  {
    "country": "RO",
    "name": "Coșani",
    "lat": "45.00788",
    "lng": "24.19188"
  },
  {
    "country": "RO",
    "name": "Corund",
    "lat": "46.46667",
    "lng": "25.18333"
  },
  {
    "country": "RO",
    "name": "Corunca",
    "lat": "46.52075",
    "lng": "24.61792"
  },
  {
    "country": "RO",
    "name": "Coropceni",
    "lat": "46.94193",
    "lng": "27.8371"
  },
  {
    "country": "RO",
    "name": "Coroisânmartin",
    "lat": "46.4",
    "lng": "24.6"
  },
  {
    "country": "RO",
    "name": "Coroieşti",
    "lat": "46.25",
    "lng": "27.48333"
  },
  {
    "country": "RO",
    "name": "Coroieni",
    "lat": "47.36667",
    "lng": "23.76667"
  },
  {
    "country": "RO",
    "name": "Corod",
    "lat": "45.9",
    "lng": "27.61667"
  },
  {
    "country": "RO",
    "name": "Corocăiești",
    "lat": "47.63333",
    "lng": "26.48333"
  },
  {
    "country": "RO",
    "name": "Cornuțel",
    "lat": "45.43489",
    "lng": "22.09556"
  },
  {
    "country": "RO",
    "name": "Cornu Luncii",
    "lat": "47.46667",
    "lng": "26.15"
  },
  {
    "country": "RO",
    "name": "Cornu de Sus",
    "lat": "45.16667",
    "lng": "25.7"
  },
  {
    "country": "RO",
    "name": "Cornu de Jos",
    "lat": "45.15665",
    "lng": "25.70452"
  },
  {
    "country": "RO",
    "name": "Corni-Albești",
    "lat": "46.51813",
    "lng": "27.87171"
  },
  {
    "country": "RO",
    "name": "Corni",
    "lat": "47.65",
    "lng": "26.58333"
  },
  {
    "country": "RO",
    "name": "Corni",
    "lat": "45.85",
    "lng": "27.76667"
  },
  {
    "country": "RO",
    "name": "Cornetu",
    "lat": "45.50456",
    "lng": "27.05305"
  },
  {
    "country": "RO",
    "name": "Cornetu",
    "lat": "44.34167",
    "lng": "25.94083"
  },
  {
    "country": "RO",
    "name": "Corneşti",
    "lat": "47.03333",
    "lng": "23.68333"
  },
  {
    "country": "RO",
    "name": "Cornești",
    "lat": "46.29218",
    "lng": "24.21277"
  },
  {
    "country": "RO",
    "name": "Corneşti",
    "lat": "44.78333",
    "lng": "25.86667"
  },
  {
    "country": "RO",
    "name": "Cornereva",
    "lat": "45.06667",
    "lng": "22.41667"
  },
  {
    "country": "RO",
    "name": "Cornea",
    "lat": "45.03333",
    "lng": "22.31667"
  },
  {
    "country": "RO",
    "name": "Cornăţelu",
    "lat": "44.75",
    "lng": "25.66667"
  },
  {
    "country": "RO",
    "name": "Cornățel",
    "lat": "44.57972",
    "lng": "24.95487"
  },
  {
    "country": "RO",
    "name": "Cormaia",
    "lat": "47.36667",
    "lng": "24.68333"
  },
  {
    "country": "RO",
    "name": "Corlătești",
    "lat": "44.91341",
    "lng": "26.08726"
  },
  {
    "country": "RO",
    "name": "Corlăteni",
    "lat": "47.93333",
    "lng": "26.55"
  },
  {
    "country": "RO",
    "name": "Corlăţel",
    "lat": "44.39861",
    "lng": "22.93306"
  },
  {
    "country": "RO",
    "name": "Cordun",
    "lat": "46.95",
    "lng": "26.86667"
  },
  {
    "country": "RO",
    "name": "Cordău",
    "lat": "46.95",
    "lng": "21.98333"
  },
  {
    "country": "RO",
    "name": "Cordăreni",
    "lat": "47.98333",
    "lng": "26.58333"
  },
  {
    "country": "RO",
    "name": "Corcova",
    "lat": "44.7",
    "lng": "23.05"
  },
  {
    "country": "RO",
    "name": "Corbu Nou",
    "lat": "45.40996",
    "lng": "27.59191"
  },
  {
    "country": "RO",
    "name": "Corbu",
    "lat": "46.98333",
    "lng": "25.7"
  },
  {
    "country": "RO",
    "name": "Corbu",
    "lat": "45.32108",
    "lng": "26.24936"
  },
  {
    "country": "RO",
    "name": "Corbu",
    "lat": "44.48333",
    "lng": "24.71667"
  },
  {
    "country": "RO",
    "name": "Corbu",
    "lat": "44.38333",
    "lng": "28.65"
  },
  {
    "country": "RO",
    "name": "Corbiţa",
    "lat": "46.15",
    "lng": "27.3"
  },
  {
    "country": "RO",
    "name": "Corbii Mari",
    "lat": "44.55",
    "lng": "25.5"
  },
  {
    "country": "RO",
    "name": "Corbi",
    "lat": "45.28333",
    "lng": "24.8"
  },
  {
    "country": "RO",
    "name": "Corbeni",
    "lat": "45.3",
    "lng": "24.65"
  },
  {
    "country": "RO",
    "name": "Corbeanca",
    "lat": "44.6",
    "lng": "26.05"
  },
  {
    "country": "RO",
    "name": "Corbasca",
    "lat": "46.28333",
    "lng": "27.16667"
  },
  {
    "country": "RO",
    "name": "Corabia",
    "lat": "43.78333",
    "lng": "24.5"
  },
  {
    "country": "RO",
    "name": "Copşa Mică",
    "lat": "46.11667",
    "lng": "24.25"
  },
  {
    "country": "RO",
    "name": "Copalnic Mănăştur",
    "lat": "47.5",
    "lng": "23.68333"
  },
  {
    "country": "RO",
    "name": "Copălău",
    "lat": "47.61667",
    "lng": "26.83333"
  },
  {
    "country": "RO",
    "name": "Copaciu",
    "lat": "44.18178",
    "lng": "25.76921"
  },
  {
    "country": "RO",
    "name": "Copăceni",
    "lat": "44.26297",
    "lng": "26.09374"
  },
  {
    "country": "RO",
    "name": "Copăceni",
    "lat": "46.59675",
    "lng": "23.73886"
  },
  {
    "country": "RO",
    "name": "Copăceni",
    "lat": "45",
    "lng": "23.98333"
  },
  {
    "country": "RO",
    "name": "Copăcelu",
    "lat": "45.06762",
    "lng": "24.31161"
  },
  {
    "country": "RO",
    "name": "Copăcele",
    "lat": "45.5",
    "lng": "22.1"
  },
  {
    "country": "RO",
    "name": "Copăcel",
    "lat": "46.98333",
    "lng": "22.16667"
  },
  {
    "country": "RO",
    "name": "Conțești",
    "lat": "47.3096",
    "lng": "26.65605"
  },
  {
    "country": "RO",
    "name": "Conțești",
    "lat": "44.98494",
    "lng": "25.01032"
  },
  {
    "country": "RO",
    "name": "Conțești",
    "lat": "44.68518",
    "lng": "25.63879"
  },
  {
    "country": "RO",
    "name": "Conţeşti",
    "lat": "43.8",
    "lng": "25.48333"
  },
  {
    "country": "RO",
    "name": "Constantin Daicoviciu",
    "lat": "45.55",
    "lng": "22.15"
  },
  {
    "country": "RO",
    "name": "Constanţa",
    "lat": "44.18073",
    "lng": "28.63432"
  },
  {
    "country": "RO",
    "name": "Conop",
    "lat": "46.10186",
    "lng": "21.8797"
  },
  {
    "country": "RO",
    "name": "Conduratu",
    "lat": "44.97236",
    "lng": "26.43365"
  },
  {
    "country": "RO",
    "name": "Condeești",
    "lat": "44.62761",
    "lng": "26.69147"
  },
  {
    "country": "RO",
    "name": "Conceşti",
    "lat": "48.16667",
    "lng": "26.55"
  },
  {
    "country": "RO",
    "name": "Comoșteni",
    "lat": "43.87405",
    "lng": "23.86356"
  },
  {
    "country": "RO",
    "name": "Comloşu Mare",
    "lat": "45.89056",
    "lng": "20.62722"
  },
  {
    "country": "RO",
    "name": "Comişani",
    "lat": "44.88333",
    "lng": "25.58333"
  },
  {
    "country": "RO",
    "name": "Comarnic",
    "lat": "45.25",
    "lng": "25.63333"
  },
  {
    "country": "RO",
    "name": "Comarna",
    "lat": "47.05",
    "lng": "27.78333"
  },
  {
    "country": "RO",
    "name": "Comani",
    "lat": "44.18286",
    "lng": "24.4916"
  },
  {
    "country": "RO",
    "name": "Comănești",
    "lat": "47.66939",
    "lng": "25.98836"
  },
  {
    "country": "RO",
    "name": "Comăneşti",
    "lat": "46.42135",
    "lng": "26.43645"
  },
  {
    "country": "RO",
    "name": "Comandău",
    "lat": "45.76667",
    "lng": "26.26667"
  },
  {
    "country": "RO",
    "name": "Comanda",
    "lat": "44.64863",
    "lng": "23.16413"
  },
  {
    "country": "RO",
    "name": "Comanca",
    "lat": "44.0779",
    "lng": "24.35863"
  },
  {
    "country": "RO",
    "name": "Comana de Sus",
    "lat": "45.9",
    "lng": "25.26667"
  },
  {
    "country": "RO",
    "name": "Comana de Jos",
    "lat": "45.91375",
    "lng": "25.23129"
  },
  {
    "country": "RO",
    "name": "Comana",
    "lat": "44.17056",
    "lng": "26.145"
  },
  {
    "country": "RO",
    "name": "Comana",
    "lat": "43.9",
    "lng": "28.31667"
  },
  {
    "country": "RO",
    "name": "Colţi",
    "lat": "45.38333",
    "lng": "26.38333"
  },
  {
    "country": "RO",
    "name": "Coltău",
    "lat": "47.59837",
    "lng": "23.52459"
  },
  {
    "country": "RO",
    "name": "Colonia Fabricii",
    "lat": "45.7662",
    "lng": "22.31463"
  },
  {
    "country": "RO",
    "name": "Colonia Bod",
    "lat": "45.75588",
    "lng": "25.5996"
  },
  {
    "country": "RO",
    "name": "Coloneşti",
    "lat": "46.56667",
    "lng": "27.3"
  },
  {
    "country": "RO",
    "name": "Coloneşti",
    "lat": "44.65",
    "lng": "24.66667"
  },
  {
    "country": "RO",
    "name": "Colibași",
    "lat": "44.93544",
    "lng": "24.90905"
  },
  {
    "country": "RO",
    "name": "Colibaşi",
    "lat": "44.20222",
    "lng": "26.19472"
  },
  {
    "country": "RO",
    "name": "Colelia",
    "lat": "44.76112",
    "lng": "27.00693"
  },
  {
    "country": "RO",
    "name": "Colceag",
    "lat": "44.95",
    "lng": "26.35"
  },
  {
    "country": "RO",
    "name": "Colacu",
    "lat": "47.5383",
    "lng": "25.37211"
  },
  {
    "country": "RO",
    "name": "Colacu",
    "lat": "44.66895",
    "lng": "25.75881"
  },
  {
    "country": "RO",
    "name": "Cojocna",
    "lat": "46.75",
    "lng": "23.83333"
  },
  {
    "country": "RO",
    "name": "Cojasca",
    "lat": "44.71667",
    "lng": "25.85"
  },
  {
    "country": "RO",
    "name": "Cogeasca",
    "lat": "47.16644",
    "lng": "27.38537"
  },
  {
    "country": "RO",
    "name": "Cogealac",
    "lat": "44.55",
    "lng": "28.56667"
  },
  {
    "country": "RO",
    "name": "Codlea",
    "lat": "45.7",
    "lng": "25.45"
  },
  {
    "country": "RO",
    "name": "Codăeşti",
    "lat": "46.86667",
    "lng": "27.75"
  },
  {
    "country": "RO",
    "name": "Cocu",
    "lat": "44.86667",
    "lng": "24.65"
  },
  {
    "country": "RO",
    "name": "Cocoreni",
    "lat": "44.82772",
    "lng": "23.31405"
  },
  {
    "country": "RO",
    "name": "Cocorăștii Mislii",
    "lat": "45.08528",
    "lng": "25.92206"
  },
  {
    "country": "RO",
    "name": "Cocorăștii Colț",
    "lat": "44.83425",
    "lng": "25.89937"
  },
  {
    "country": "RO",
    "name": "Cocora",
    "lat": "44.73333",
    "lng": "27.05"
  },
  {
    "country": "RO",
    "name": "Coconi",
    "lat": "44.24769",
    "lng": "26.88409"
  },
  {
    "country": "RO",
    "name": "Cociuba Mare",
    "lat": "46.73333",
    "lng": "22"
  },
  {
    "country": "RO",
    "name": "Cociu",
    "lat": "47.19926",
    "lng": "24.23238"
  },
  {
    "country": "RO",
    "name": "Cochirleanca",
    "lat": "45.21667",
    "lng": "27.03333"
  },
  {
    "country": "RO",
    "name": "Cobadin",
    "lat": "44.08333",
    "lng": "28.21667"
  },
  {
    "country": "RO",
    "name": "Coaș",
    "lat": "47.53957",
    "lng": "23.58584"
  },
  {
    "country": "RO",
    "name": "Coarnele Caprei",
    "lat": "47.38333",
    "lng": "27.1"
  },
  {
    "country": "RO",
    "name": "Coada Izvorului",
    "lat": "44.85766",
    "lng": "25.81851"
  },
  {
    "country": "RO",
    "name": "Cluj-Napoca",
    "lat": "46.76667",
    "lng": "23.6"
  },
  {
    "country": "RO",
    "name": "Cloșani",
    "lat": "45.06897",
    "lng": "22.8025"
  },
  {
    "country": "RO",
    "name": "Clocotici",
    "lat": "45.24495",
    "lng": "21.83467"
  },
  {
    "country": "RO",
    "name": "Clit",
    "lat": "47.75396",
    "lng": "25.85691"
  },
  {
    "country": "RO",
    "name": "Clinceni",
    "lat": "44.37333",
    "lng": "25.95472"
  },
  {
    "country": "RO",
    "name": "Clejani",
    "lat": "44.31972",
    "lng": "25.69944"
  },
  {
    "country": "RO",
    "name": "Cleja",
    "lat": "46.41667",
    "lng": "26.9"
  },
  {
    "country": "RO",
    "name": "Cleanov",
    "lat": "44.35288",
    "lng": "23.21032"
  },
  {
    "country": "RO",
    "name": "Cizer",
    "lat": "47.06667",
    "lng": "22.88333"
  },
  {
    "country": "RO",
    "name": "Ciutelec",
    "lat": "47.262",
    "lng": "22.3869"
  },
  {
    "country": "RO",
    "name": "Ciușlea",
    "lat": "45.78761",
    "lng": "27.30644"
  },
  {
    "country": "RO",
    "name": "Ciuruleasa",
    "lat": "46.25",
    "lng": "23.03333"
  },
  {
    "country": "RO",
    "name": "Ciurila",
    "lat": "46.65",
    "lng": "23.55"
  },
  {
    "country": "RO",
    "name": "Ciurea",
    "lat": "47.05",
    "lng": "27.56667"
  },
  {
    "country": "RO",
    "name": "Ciupercenii Vechi",
    "lat": "43.94512",
    "lng": "22.89469"
  },
  {
    "country": "RO",
    "name": "Ciupercenii Noi",
    "lat": "43.90972",
    "lng": "22.94833"
  },
  {
    "country": "RO",
    "name": "Ciuperceni",
    "lat": "44.93333",
    "lng": "23.01667"
  },
  {
    "country": "RO",
    "name": "Ciuperceni",
    "lat": "44.3175",
    "lng": "25.37869"
  },
  {
    "country": "RO",
    "name": "Ciuperceni",
    "lat": "43.76667",
    "lng": "24.95"
  },
  {
    "country": "RO",
    "name": "Ciumești",
    "lat": "47.66382",
    "lng": "22.34069"
  },
  {
    "country": "RO",
    "name": "Ciumeghiu",
    "lat": "46.73333",
    "lng": "21.58333"
  },
  {
    "country": "RO",
    "name": "Ciumbrud",
    "lat": "46.3081",
    "lng": "23.76222"
  },
  {
    "country": "RO",
    "name": "Ciumani",
    "lat": "46.68333",
    "lng": "25.51667"
  },
  {
    "country": "RO",
    "name": "Ciulnița",
    "lat": "44.78769",
    "lng": "25.15388"
  },
  {
    "country": "RO",
    "name": "Ciulniţa",
    "lat": "44.53333",
    "lng": "27.35"
  },
  {
    "country": "RO",
    "name": "Ciugud",
    "lat": "46.05",
    "lng": "23.61667"
  },
  {
    "country": "RO",
    "name": "Ciugheș",
    "lat": "46.5222",
    "lng": "26.1197"
  },
  {
    "country": "RO",
    "name": "Ciudanoviţa",
    "lat": "45.14472",
    "lng": "21.79778"
  },
  {
    "country": "RO",
    "name": "Ciucurova",
    "lat": "44.93333",
    "lng": "28.48333"
  },
  {
    "country": "RO",
    "name": "Ciucsângeorgiu",
    "lat": "46.31667",
    "lng": "25.95"
  },
  {
    "country": "RO",
    "name": "Ciuchici",
    "lat": "44.94139",
    "lng": "21.61"
  },
  {
    "country": "RO",
    "name": "Ciucea",
    "lat": "46.95",
    "lng": "22.81667"
  },
  {
    "country": "RO",
    "name": "Ciucani",
    "lat": "46.25701",
    "lng": "25.94744"
  },
  {
    "country": "RO",
    "name": "Ciuani",
    "lat": "44.23333",
    "lng": "25.65"
  },
  {
    "country": "RO",
    "name": "Câţcău",
    "lat": "47.2",
    "lng": "23.78333"
  },
  {
    "country": "RO",
    "name": "Cisnădie",
    "lat": "45.71667",
    "lng": "24.15"
  },
  {
    "country": "RO",
    "name": "Cișmele",
    "lat": "45.51634",
    "lng": "27.92975"
  },
  {
    "country": "RO",
    "name": "Cislău",
    "lat": "45.25",
    "lng": "26.36667"
  },
  {
    "country": "RO",
    "name": "Cârţişoara",
    "lat": "45.71667",
    "lng": "24.58333"
  },
  {
    "country": "RO",
    "name": "Cârţa",
    "lat": "46.53333",
    "lng": "25.75"
  },
  {
    "country": "RO",
    "name": "Cârţa",
    "lat": "45.78333",
    "lng": "24.56667"
  },
  {
    "country": "RO",
    "name": "Cârniceni",
    "lat": "47.33942",
    "lng": "27.50508"
  },
  {
    "country": "RO",
    "name": "Cârlogani",
    "lat": "44.51667",
    "lng": "24.15"
  },
  {
    "country": "RO",
    "name": "Cârligi",
    "lat": "46.76583",
    "lng": "26.85053"
  },
  {
    "country": "RO",
    "name": "Cârligele",
    "lat": "45.68333",
    "lng": "27.1"
  },
  {
    "country": "RO",
    "name": "Cârlibaba",
    "lat": "47.58333",
    "lng": "25.13333"
  },
  {
    "country": "RO",
    "name": "Cârjoaia",
    "lat": "47.34032",
    "lng": "26.90863"
  },
  {
    "country": "RO",
    "name": "Cârjiţi",
    "lat": "45.85",
    "lng": "22.83333"
  },
  {
    "country": "RO",
    "name": "Cârja",
    "lat": "46.14878",
    "lng": "28.11012"
  },
  {
    "country": "RO",
    "name": "Cireşu",
    "lat": "44.95",
    "lng": "27.35"
  },
  {
    "country": "RO",
    "name": "Cireşu",
    "lat": "44.82333",
    "lng": "22.53806"
  },
  {
    "country": "RO",
    "name": "Cireșoaia",
    "lat": "47.14265",
    "lng": "24.06217"
  },
  {
    "country": "RO",
    "name": "Cireșoaia",
    "lat": "46.24816",
    "lng": "26.54929"
  },
  {
    "country": "RO",
    "name": "Cârcea",
    "lat": "44.26917",
    "lng": "23.90007"
  },
  {
    "country": "RO",
    "name": "Ciprian Porumbescu",
    "lat": "47.56667",
    "lng": "26.06667"
  },
  {
    "country": "RO",
    "name": "Cipău",
    "lat": "46.44876",
    "lng": "24.27786"
  },
  {
    "country": "RO",
    "name": "Ciorteşti",
    "lat": "46.9",
    "lng": "27.83333"
  },
  {
    "country": "RO",
    "name": "Cioroiași",
    "lat": "44.08333",
    "lng": "23.45"
  },
  {
    "country": "RO",
    "name": "Ciorogârla",
    "lat": "44.4425",
    "lng": "25.88333"
  },
  {
    "country": "RO",
    "name": "Cioroboreni",
    "lat": "44.38877",
    "lng": "22.76326"
  },
  {
    "country": "RO",
    "name": "Ciorăști",
    "lat": "46.1138",
    "lng": "27.45311"
  },
  {
    "country": "RO",
    "name": "Ciorăşti",
    "lat": "45.43333",
    "lng": "27.3"
  },
  {
    "country": "RO",
    "name": "Cioranii de Sus",
    "lat": "44.83923",
    "lng": "26.39473"
  },
  {
    "country": "RO",
    "name": "Cioranii de Jos",
    "lat": "44.81667",
    "lng": "26.41667"
  },
  {
    "country": "RO",
    "name": "Ciorani",
    "lat": "45.98824",
    "lng": "27.21614"
  },
  {
    "country": "RO",
    "name": "Ciomăgeşti",
    "lat": "44.83333",
    "lng": "24.45"
  },
  {
    "country": "RO",
    "name": "Ciolpani",
    "lat": "44.73333",
    "lng": "26.08333"
  },
  {
    "country": "RO",
    "name": "Ciohorăni",
    "lat": "47.1352",
    "lng": "26.68955"
  },
  {
    "country": "RO",
    "name": "Ciofrângeni",
    "lat": "45.08333",
    "lng": "24.53333"
  },
  {
    "country": "RO",
    "name": "Ciofliceni",
    "lat": "44.68122",
    "lng": "26.11923"
  },
  {
    "country": "RO",
    "name": "Ciocârlia de Sus",
    "lat": "44.11712",
    "lng": "28.33402"
  },
  {
    "country": "RO",
    "name": "Ciocârlia",
    "lat": "44.8",
    "lng": "26.66667"
  },
  {
    "country": "RO",
    "name": "Ciocârlia",
    "lat": "44.1",
    "lng": "28.28333"
  },
  {
    "country": "RO",
    "name": "Ciocile",
    "lat": "44.81667",
    "lng": "27.23333"
  },
  {
    "country": "RO",
    "name": "Ciochiuța",
    "lat": "44.60306",
    "lng": "23.11698"
  },
  {
    "country": "RO",
    "name": "Ciochina",
    "lat": "44.58333",
    "lng": "27.06667"
  },
  {
    "country": "RO",
    "name": "Ciocani",
    "lat": "46.26044",
    "lng": "27.55994"
  },
  {
    "country": "RO",
    "name": "Ciocănești",
    "lat": "47.48107",
    "lng": "25.27912"
  },
  {
    "country": "RO",
    "name": "Cicănești",
    "lat": "45.24601",
    "lng": "24.60526"
  },
  {
    "country": "RO",
    "name": "Ciocăneşti",
    "lat": "44.6",
    "lng": "25.85"
  },
  {
    "country": "RO",
    "name": "Ciocăneşti",
    "lat": "44.2",
    "lng": "27.06667"
  },
  {
    "country": "RO",
    "name": "Ciocănari",
    "lat": "44.6977",
    "lng": "25.97717"
  },
  {
    "country": "RO",
    "name": "Ciobanu",
    "lat": "44.71759",
    "lng": "27.98698"
  },
  {
    "country": "RO",
    "name": "Cintei",
    "lat": "46.44434",
    "lng": "21.56556"
  },
  {
    "country": "RO",
    "name": "Cândeşti Vale",
    "lat": "45.08333",
    "lng": "25.21667"
  },
  {
    "country": "RO",
    "name": "Cândeşti",
    "lat": "47.93333",
    "lng": "26.2"
  },
  {
    "country": "RO",
    "name": "Cândeşti",
    "lat": "46.71667",
    "lng": "26.58333"
  },
  {
    "country": "RO",
    "name": "Cincu",
    "lat": "45.91667",
    "lng": "24.8"
  },
  {
    "country": "RO",
    "name": "Câmpurile de Jos",
    "lat": "46.01667",
    "lng": "26.78333"
  },
  {
    "country": "RO",
    "name": "Câmpuri",
    "lat": "46.01535",
    "lng": "26.78802"
  },
  {
    "country": "RO",
    "name": "Câmpurelu",
    "lat": "44.23392",
    "lng": "26.18719"
  },
  {
    "country": "RO",
    "name": "Câmpulung Moldovenesc",
    "lat": "47.53333",
    "lng": "25.56667"
  },
  {
    "country": "RO",
    "name": "Câmpulung la Tisa",
    "lat": "47.98651",
    "lng": "23.77263"
  },
  {
    "country": "RO",
    "name": "Câmpulung",
    "lat": "45.26667",
    "lng": "25.05"
  },
  {
    "country": "RO",
    "name": "Câmpineanca",
    "lat": "45.71166",
    "lng": "27.12832"
  },
  {
    "country": "RO",
    "name": "Câmpina",
    "lat": "45.12619",
    "lng": "25.73496"
  },
  {
    "country": "RO",
    "name": "Câmpia Turzii",
    "lat": "46.55",
    "lng": "23.88333"
  },
  {
    "country": "RO",
    "name": "Câmpeni",
    "lat": "46.36667",
    "lng": "23.05"
  },
  {
    "country": "RO",
    "name": "Câmpani",
    "lat": "46.51415",
    "lng": "22.52186"
  },
  {
    "country": "RO",
    "name": "Câmpani de Pomezeu",
    "lat": "46.8",
    "lng": "22.31667"
  },
  {
    "country": "RO",
    "name": "Câlnic",
    "lat": "44.95",
    "lng": "23.08333"
  },
  {
    "country": "RO",
    "name": "Câlnic",
    "lat": "45.88333",
    "lng": "23.66667"
  },
  {
    "country": "RO",
    "name": "Câlnic",
    "lat": "45.33844",
    "lng": "21.85754"
  },
  {
    "country": "RO",
    "name": "Cilieni",
    "lat": "43.9",
    "lng": "24.61667"
  },
  {
    "country": "RO",
    "name": "Cilibia",
    "lat": "45.06667",
    "lng": "27.06667"
  },
  {
    "country": "RO",
    "name": "Câinenii Mici",
    "lat": "45.48333",
    "lng": "24.3"
  },
  {
    "country": "RO",
    "name": "Cidreag",
    "lat": "47.98677",
    "lng": "22.96395"
  },
  {
    "country": "RO",
    "name": "Ciclova-Română",
    "lat": "45.01361",
    "lng": "21.71917"
  },
  {
    "country": "RO",
    "name": "Cicârlău",
    "lat": "47.69155",
    "lng": "23.4038"
  },
  {
    "country": "RO",
    "name": "Ciceu-Mihăiești",
    "lat": "47.18568",
    "lng": "23.9748"
  },
  {
    "country": "RO",
    "name": "Ciceu-Giurgeşti",
    "lat": "47.25",
    "lng": "24.01667"
  },
  {
    "country": "RO",
    "name": "Ciceu",
    "lat": "46.41328",
    "lng": "25.78204"
  },
  {
    "country": "RO",
    "name": "Ciacova",
    "lat": "45.50806",
    "lng": "21.12861"
  },
  {
    "country": "RO",
    "name": "Chiuza",
    "lat": "47.23333",
    "lng": "24.25"
  },
  {
    "country": "RO",
    "name": "Chiuiești",
    "lat": "47.29686",
    "lng": "23.87553"
  },
  {
    "country": "RO",
    "name": "Chițorani",
    "lat": "44.97458",
    "lng": "26.11895"
  },
  {
    "country": "RO",
    "name": "Chițoc",
    "lat": "46.59545",
    "lng": "27.6745"
  },
  {
    "country": "RO",
    "name": "Chitila",
    "lat": "44.50806",
    "lng": "25.98222"
  },
  {
    "country": "RO",
    "name": "Chișoda",
    "lat": "45.7038",
    "lng": "21.21437"
  },
  {
    "country": "RO",
    "name": "Chişlaz",
    "lat": "47.28333",
    "lng": "22.23333"
  },
  {
    "country": "RO",
    "name": "Chişineu-Criş",
    "lat": "46.52509",
    "lng": "21.51844"
  },
  {
    "country": "RO",
    "name": "Chisindia",
    "lat": "46.28333",
    "lng": "22.1"
  },
  {
    "country": "RO",
    "name": "Chiselet",
    "lat": "44.18333",
    "lng": "26.85"
  },
  {
    "country": "RO",
    "name": "Chișcăreni",
    "lat": "47.46974",
    "lng": "27.19626"
  },
  {
    "country": "RO",
    "name": "Chiscani",
    "lat": "45.18333",
    "lng": "27.93333"
  },
  {
    "country": "RO",
    "name": "Chirpăr",
    "lat": "45.9",
    "lng": "24.6"
  },
  {
    "country": "RO",
    "name": "Chirnogi",
    "lat": "44.11667",
    "lng": "26.56667"
  },
  {
    "country": "RO",
    "name": "Chirnogeni",
    "lat": "43.9",
    "lng": "28.23333"
  },
  {
    "country": "RO",
    "name": "Chiriacu",
    "lat": "44.05036",
    "lng": "25.77726"
  },
  {
    "country": "RO",
    "name": "Chircești",
    "lat": "46.84629",
    "lng": "27.8492"
  },
  {
    "country": "RO",
    "name": "Chiraftei",
    "lat": "45.7722",
    "lng": "28.02716"
  },
  {
    "country": "RO",
    "name": "Chiojdu",
    "lat": "45.35",
    "lng": "26.2"
  },
  {
    "country": "RO",
    "name": "Chiojdeni",
    "lat": "45.55",
    "lng": "26.86667"
  },
  {
    "country": "RO",
    "name": "Chiojdeanca",
    "lat": "45.16667",
    "lng": "26.26667"
  },
  {
    "country": "RO",
    "name": "Chiochiş",
    "lat": "46.98333",
    "lng": "24.18333"
  },
  {
    "country": "RO",
    "name": "Chintinici",
    "lat": "46.82754",
    "lng": "26.49339"
  },
  {
    "country": "RO",
    "name": "Chinteni",
    "lat": "46.86667",
    "lng": "23.53333"
  },
  {
    "country": "RO",
    "name": "Chiliile",
    "lat": "45.45",
    "lng": "26.58333"
  },
  {
    "country": "RO",
    "name": "Chilii",
    "lat": "46.80254",
    "lng": "27.03394"
  },
  {
    "country": "RO",
    "name": "Chilia Veche",
    "lat": "45.41667",
    "lng": "29.28333"
  },
  {
    "country": "RO",
    "name": "Chiheru de Jos",
    "lat": "46.68333",
    "lng": "24.88333"
  },
  {
    "country": "RO",
    "name": "Chieşd",
    "lat": "47.38333",
    "lng": "22.88333"
  },
  {
    "country": "RO",
    "name": "Chier",
    "lat": "46.34199",
    "lng": "21.82488"
  },
  {
    "country": "RO",
    "name": "Chichiş",
    "lat": "45.78333",
    "lng": "25.8"
  },
  {
    "country": "RO",
    "name": "Chibed",
    "lat": "46.53328",
    "lng": "24.96215"
  },
  {
    "country": "RO",
    "name": "Chiajna",
    "lat": "44.46",
    "lng": "25.97333"
  },
  {
    "country": "RO",
    "name": "Chevereşu Mare",
    "lat": "45.66694",
    "lng": "21.49083"
  },
  {
    "country": "RO",
    "name": "Cheţani",
    "lat": "46.46667",
    "lng": "24.03333"
  },
  {
    "country": "RO",
    "name": "Cheț",
    "lat": "47.41943",
    "lng": "22.33877"
  },
  {
    "country": "RO",
    "name": "Chesinț",
    "lat": "46.04973",
    "lng": "21.57944"
  },
  {
    "country": "RO",
    "name": "Cheșereu",
    "lat": "47.42779",
    "lng": "22.11416"
  },
  {
    "country": "RO",
    "name": "Chereluș",
    "lat": "46.4686",
    "lng": "21.70706"
  },
  {
    "country": "RO",
    "name": "Cherechiu",
    "lat": "47.38333",
    "lng": "22.13333"
  },
  {
    "country": "RO",
    "name": "Chendu",
    "lat": "46.39234",
    "lng": "24.72912"
  },
  {
    "country": "RO",
    "name": "Chendrea",
    "lat": "47.12236",
    "lng": "23.29904"
  },
  {
    "country": "RO",
    "name": "Chelința",
    "lat": "47.45311",
    "lng": "23.31799"
  },
  {
    "country": "RO",
    "name": "Cheia",
    "lat": "45.18306",
    "lng": "24.21666"
  },
  {
    "country": "RO",
    "name": "Checea",
    "lat": "45.75298",
    "lng": "20.83596"
  },
  {
    "country": "RO",
    "name": "Cezieni",
    "lat": "44.18333",
    "lng": "24.26667"
  },
  {
    "country": "RO",
    "name": "Cetăţeni",
    "lat": "45.2",
    "lng": "25.18333"
  },
  {
    "country": "RO",
    "name": "Cetatea de Baltă",
    "lat": "46.24794",
    "lng": "24.17244"
  },
  {
    "country": "RO",
    "name": "Cetatea",
    "lat": "43.95105",
    "lng": "25.9345"
  },
  {
    "country": "RO",
    "name": "Cetate",
    "lat": "44.1",
    "lng": "23.05"
  },
  {
    "country": "RO",
    "name": "Cetariu",
    "lat": "47.13333",
    "lng": "22.01667"
  },
  {
    "country": "RO",
    "name": "Cervenia",
    "lat": "43.83333",
    "lng": "25.46667"
  },
  {
    "country": "RO",
    "name": "Ceru-Băcăinţi",
    "lat": "45.98333",
    "lng": "23.25"
  },
  {
    "country": "RO",
    "name": "Certeze",
    "lat": "47.9",
    "lng": "23.46667"
  },
  {
    "country": "RO",
    "name": "Cerţeşti",
    "lat": "46.01667",
    "lng": "27.61667"
  },
  {
    "country": "RO",
    "name": "Certeju de Sus",
    "lat": "45.96667",
    "lng": "22.96667"
  },
  {
    "country": "RO",
    "name": "Cernu",
    "lat": "46.46999",
    "lng": "26.58477"
  },
  {
    "country": "RO",
    "name": "Cernişoara",
    "lat": "45.03333",
    "lng": "23.98333"
  },
  {
    "country": "RO",
    "name": "Cernica",
    "lat": "44.41667",
    "lng": "26.28333"
  },
  {
    "country": "RO",
    "name": "Cernetu",
    "lat": "43.90727",
    "lng": "25.45688"
  },
  {
    "country": "RO",
    "name": "Cerneți",
    "lat": "44.63476",
    "lng": "22.70931"
  },
  {
    "country": "RO",
    "name": "Cerneşti",
    "lat": "47.51667",
    "lng": "23.75"
  },
  {
    "country": "RO",
    "name": "Cernele",
    "lat": "44.33363",
    "lng": "23.7414"
  },
  {
    "country": "RO",
    "name": "Cernavodă",
    "lat": "44.33957",
    "lng": "28.03273"
  },
  {
    "country": "RO",
    "name": "Cernăteşti",
    "lat": "45.26667",
    "lng": "26.76667"
  },
  {
    "country": "RO",
    "name": "Cernăteşti",
    "lat": "44.45",
    "lng": "23.43333"
  },
  {
    "country": "RO",
    "name": "Cernat",
    "lat": "45.95",
    "lng": "26.03333"
  },
  {
    "country": "RO",
    "name": "Cerna",
    "lat": "45.08333",
    "lng": "28.31667"
  },
  {
    "country": "RO",
    "name": "Cermei",
    "lat": "46.55",
    "lng": "21.85"
  },
  {
    "country": "RO",
    "name": "Cergău Mic",
    "lat": "46.08333",
    "lng": "23.93333"
  },
  {
    "country": "RO",
    "name": "Cergău Mare",
    "lat": "46.09869",
    "lng": "23.92284"
  },
  {
    "country": "RO",
    "name": "Didești",
    "lat": "44.21667",
    "lng": "24.88333"
  },
  {
    "country": "RO",
    "name": "Cerdac",
    "lat": "46.23794",
    "lng": "26.51638"
  },
  {
    "country": "RO",
    "name": "Ceardac",
    "lat": "45.66967",
    "lng": "27.16611"
  },
  {
    "country": "RO",
    "name": "Cerchezu",
    "lat": "43.81667",
    "lng": "28.1"
  },
  {
    "country": "RO",
    "name": "Cerbăl",
    "lat": "45.78333",
    "lng": "22.71667"
  },
  {
    "country": "RO",
    "name": "Cerăt",
    "lat": "44.06667",
    "lng": "23.66667"
  },
  {
    "country": "RO",
    "name": "Ceraşu",
    "lat": "45.31667",
    "lng": "26.03333"
  },
  {
    "country": "RO",
    "name": "Ceptura de Sus",
    "lat": "45.01667",
    "lng": "26.31667"
  },
  {
    "country": "RO",
    "name": "Ceptura de Jos",
    "lat": "45.02088",
    "lng": "26.32722"
  },
  {
    "country": "RO",
    "name": "Cepleniţa",
    "lat": "47.38333",
    "lng": "27.01667"
  },
  {
    "country": "RO",
    "name": "Ceparii Pământeni",
    "lat": "45.21667",
    "lng": "24.56667"
  },
  {
    "country": "RO",
    "name": "Cepari",
    "lat": "44.49733",
    "lng": "24.17122"
  },
  {
    "country": "RO",
    "name": "Cenei",
    "lat": "45.71583",
    "lng": "20.90389"
  },
  {
    "country": "RO",
    "name": "Cenade",
    "lat": "46.05",
    "lng": "24.01667"
  },
  {
    "country": "RO",
    "name": "Cenad",
    "lat": "46.13333",
    "lng": "20.58333"
  },
  {
    "country": "RO",
    "name": "Celaru",
    "lat": "44.05",
    "lng": "24.13333"
  },
  {
    "country": "RO",
    "name": "Ceica",
    "lat": "46.85",
    "lng": "22.18333"
  },
  {
    "country": "RO",
    "name": "Cehu Silvaniei",
    "lat": "47.41177",
    "lng": "23.17489"
  },
  {
    "country": "RO",
    "name": "Cehei",
    "lat": "47.25632",
    "lng": "22.77507"
  },
  {
    "country": "RO",
    "name": "Cehal",
    "lat": "47.38333",
    "lng": "22.6"
  },
  {
    "country": "RO",
    "name": "Cegani",
    "lat": "44.46279",
    "lng": "27.90175"
  },
  {
    "country": "RO",
    "name": "Cefa",
    "lat": "46.91667",
    "lng": "21.73333"
  },
  {
    "country": "RO",
    "name": "Ceuașu de Câmpie",
    "lat": "46.63333",
    "lng": "24.51667"
  },
  {
    "country": "RO",
    "name": "Ceauru",
    "lat": "45.01175",
    "lng": "23.20211"
  },
  {
    "country": "RO",
    "name": "Ceatalchioi",
    "lat": "45.28333",
    "lng": "28.78333"
  },
  {
    "country": "RO",
    "name": "Ceanu Mare",
    "lat": "46.66667",
    "lng": "23.95"
  },
  {
    "country": "RO",
    "name": "Ceamurlia de Sus",
    "lat": "44.76373",
    "lng": "28.60881"
  },
  {
    "country": "RO",
    "name": "Ceamurlia de Jos",
    "lat": "44.73333",
    "lng": "28.71667"
  },
  {
    "country": "RO",
    "name": "Ceahlău",
    "lat": "47.05",
    "lng": "25.96667"
  },
  {
    "country": "RO",
    "name": "Ceacu",
    "lat": "44.2653",
    "lng": "27.25213"
  },
  {
    "country": "RO",
    "name": "Cazasu",
    "lat": "45.27172",
    "lng": "27.89011"
  },
  {
    "country": "RO",
    "name": "Căzăneşti",
    "lat": "44.72333",
    "lng": "22.89056"
  },
  {
    "country": "RO",
    "name": "Căzăneşti",
    "lat": "44.61667",
    "lng": "27.01667"
  },
  {
    "country": "RO",
    "name": "Cazaci",
    "lat": "44.80152",
    "lng": "25.55405"
  },
  {
    "country": "RO",
    "name": "Cavnic",
    "lat": "47.66667",
    "lng": "23.86667"
  },
  {
    "country": "RO",
    "name": "Cavadineşti",
    "lat": "46.06667",
    "lng": "28.01694"
  },
  {
    "country": "RO",
    "name": "Căuaş",
    "lat": "47.56667",
    "lng": "22.55"
  },
  {
    "country": "RO",
    "name": "Cătunele",
    "lat": "44.86442",
    "lng": "22.90707"
  },
  {
    "country": "RO",
    "name": "Cătina",
    "lat": "46.85",
    "lng": "24.18333"
  },
  {
    "country": "RO",
    "name": "Cătina",
    "lat": "45.3",
    "lng": "26.25"
  },
  {
    "country": "RO",
    "name": "Cătina",
    "lat": "45.00984",
    "lng": "25.78395"
  },
  {
    "country": "RO",
    "name": "Cățelu",
    "lat": "44.40292",
    "lng": "26.21975"
  },
  {
    "country": "RO",
    "name": "Căteasca",
    "lat": "44.76667",
    "lng": "25.08333"
  },
  {
    "country": "RO",
    "name": "Catanele",
    "lat": "44.38199",
    "lng": "24.56145"
  },
  {
    "country": "RO",
    "name": "Catane",
    "lat": "43.92671",
    "lng": "23.41178"
  },
  {
    "country": "RO",
    "name": "Cătămărești-Deal",
    "lat": "47.76999",
    "lng": "26.59897"
  },
  {
    "country": "RO",
    "name": "Cataloi",
    "lat": "45.09581",
    "lng": "28.72856"
  },
  {
    "country": "RO",
    "name": "Catalina",
    "lat": "45.96667",
    "lng": "26.15"
  },
  {
    "country": "RO",
    "name": "Caţa",
    "lat": "46.08333",
    "lng": "25.26667"
  },
  {
    "country": "RO",
    "name": "Castrele Traiane",
    "lat": "44.22865",
    "lng": "23.13921"
  },
  {
    "country": "RO",
    "name": "Castranova",
    "lat": "44.11667",
    "lng": "24.01667"
  },
  {
    "country": "RO",
    "name": "Castelu",
    "lat": "44.25",
    "lng": "28.33333"
  },
  {
    "country": "RO",
    "name": "Căstău",
    "lat": "45.81465",
    "lng": "23.21173"
  },
  {
    "country": "RO",
    "name": "Cașoca",
    "lat": "45.48263",
    "lng": "26.25892"
  },
  {
    "country": "RO",
    "name": "Caşin",
    "lat": "46.2",
    "lng": "26.75"
  },
  {
    "country": "RO",
    "name": "Casimcea",
    "lat": "44.73333",
    "lng": "28.36667"
  },
  {
    "country": "RO",
    "name": "Căşeiu",
    "lat": "47.18333",
    "lng": "23.86667"
  },
  {
    "country": "RO",
    "name": "Căscioarele",
    "lat": "44.49911",
    "lng": "25.63817"
  },
  {
    "country": "RO",
    "name": "Căscioarele",
    "lat": "44.12611",
    "lng": "26.46972"
  },
  {
    "country": "RO",
    "name": "Cartojani",
    "lat": "44.43221",
    "lng": "25.48994"
  },
  {
    "country": "RO",
    "name": "Cărpiniș",
    "lat": "45.18407",
    "lng": "23.58052"
  },
  {
    "country": "RO",
    "name": "Cărpiniş",
    "lat": "45.78722",
    "lng": "20.90417"
  },
  {
    "country": "RO",
    "name": "Cărpinet",
    "lat": "46.45",
    "lng": "22.48333"
  },
  {
    "country": "RO",
    "name": "Carpen",
    "lat": "44.33333",
    "lng": "23.25"
  },
  {
    "country": "RO",
    "name": "C.A. Rosetti",
    "lat": "45.3",
    "lng": "29.56667"
  },
  {
    "country": "RO",
    "name": "C.a. Rosetti",
    "lat": "45.04622",
    "lng": "27.1664"
  },
  {
    "country": "RO",
    "name": "Carei",
    "lat": "47.68333",
    "lng": "22.46667"
  },
  {
    "country": "RO",
    "name": "Carcaliu",
    "lat": "45.18333",
    "lng": "28.15"
  },
  {
    "country": "RO",
    "name": "Cărbuneşti",
    "lat": "45.23333",
    "lng": "26.2"
  },
  {
    "country": "RO",
    "name": "Cărbunari",
    "lat": "44.83444",
    "lng": "21.74417"
  },
  {
    "country": "RO",
    "name": "Caraula",
    "lat": "44.18333",
    "lng": "23.25"
  },
  {
    "country": "RO",
    "name": "Carastelec",
    "lat": "47.3",
    "lng": "22.7"
  },
  {
    "country": "RO",
    "name": "Caraşova",
    "lat": "45.19861",
    "lng": "21.87"
  },
  {
    "country": "RO",
    "name": "Cărășeu",
    "lat": "47.74126",
    "lng": "23.09798"
  },
  {
    "country": "RO",
    "name": "Caransebeş",
    "lat": "45.41667",
    "lng": "22.21667"
  },
  {
    "country": "RO",
    "name": "Carani",
    "lat": "45.91095",
    "lng": "21.15686"
  },
  {
    "country": "RO",
    "name": "Cărand",
    "lat": "46.45",
    "lng": "22.08333"
  },
  {
    "country": "RO",
    "name": "Caraclău",
    "lat": "46.30696",
    "lng": "26.71641"
  },
  {
    "country": "RO",
    "name": "Caracal",
    "lat": "44.11667",
    "lng": "24.35"
  },
  {
    "country": "RO",
    "name": "Căpuşu Mare",
    "lat": "46.78333",
    "lng": "23.3"
  },
  {
    "country": "RO",
    "name": "Capu Piscului",
    "lat": "45.17999",
    "lng": "24.97679"
  },
  {
    "country": "RO",
    "name": "Capu Codrului",
    "lat": "47.53117",
    "lng": "25.98724"
  },
  {
    "country": "RO",
    "name": "Capu Câmpului",
    "lat": "47.50822",
    "lng": "25.97959"
  },
  {
    "country": "RO",
    "name": "Căprioru",
    "lat": "44.98236",
    "lng": "25.28116"
  },
  {
    "country": "RO",
    "name": "Căpreni",
    "lat": "44.75",
    "lng": "23.61667"
  },
  {
    "country": "RO",
    "name": "Caporal Alexa",
    "lat": "46.33793",
    "lng": "21.58316"
  },
  {
    "country": "RO",
    "name": "Căpleni",
    "lat": "47.71667",
    "lng": "22.5"
  },
  {
    "country": "RO",
    "name": "Căpâlniţa",
    "lat": "46.36667",
    "lng": "25.51667"
  },
  {
    "country": "RO",
    "name": "Căpâlna",
    "lat": "46.73333",
    "lng": "22.1"
  },
  {
    "country": "RO",
    "name": "Căpeni",
    "lat": "46.04111",
    "lng": "25.57858"
  },
  {
    "country": "RO",
    "name": "Căpățânești",
    "lat": "45.18333",
    "lng": "26.8"
  },
  {
    "country": "RO",
    "name": "Căpățânenii Pământeni",
    "lat": "45.31667",
    "lng": "24.65"
  },
  {
    "country": "RO",
    "name": "Căneşti",
    "lat": "45.4",
    "lng": "26.6"
  },
  {
    "country": "RO",
    "name": "Cămin",
    "lat": "47.72836",
    "lng": "22.47987"
  },
  {
    "country": "RO",
    "name": "Cămărzana",
    "lat": "48",
    "lng": "23.31667"
  },
  {
    "country": "RO",
    "name": "Cămăraşu",
    "lat": "46.78333",
    "lng": "24.13333"
  },
  {
    "country": "RO",
    "name": "Camăr",
    "lat": "47.3",
    "lng": "22.61667"
  },
  {
    "country": "RO",
    "name": "Calvini",
    "lat": "45.25",
    "lng": "26.3"
  },
  {
    "country": "RO",
    "name": "Călui",
    "lat": "44.45297",
    "lng": "24.0636"
  },
  {
    "country": "RO",
    "name": "Călugăreni",
    "lat": "45.08333",
    "lng": "26.38333"
  },
  {
    "country": "RO",
    "name": "Călugăreni",
    "lat": "44.17167",
    "lng": "25.99556"
  },
  {
    "country": "RO",
    "name": "Calopăr",
    "lat": "44.16502",
    "lng": "23.7606"
  },
  {
    "country": "RO",
    "name": "Calomfirești",
    "lat": "43.91736",
    "lng": "25.35801"
  },
  {
    "country": "RO",
    "name": "Călmăţuiu",
    "lat": "43.96667",
    "lng": "24.86667"
  },
  {
    "country": "RO",
    "name": "Călineşti-Oaş",
    "lat": "47.9",
    "lng": "23.3"
  },
  {
    "country": "RO",
    "name": "Călinești",
    "lat": "47.80329",
    "lng": "26.15345"
  },
  {
    "country": "RO",
    "name": "Călineşti",
    "lat": "47.78333",
    "lng": "23.98333"
  },
  {
    "country": "RO",
    "name": "Călineşti",
    "lat": "44.81667",
    "lng": "25.05"
  },
  {
    "country": "RO",
    "name": "Călineşti",
    "lat": "44.08333",
    "lng": "25.23333"
  },
  {
    "country": "RO",
    "name": "Călinești",
    "lat": "44.07727",
    "lng": "24.68796"
  },
  {
    "country": "RO",
    "name": "Călina",
    "lat": "44.70205",
    "lng": "24.25439"
  },
  {
    "country": "RO",
    "name": "Călimăneşti",
    "lat": "45.23333",
    "lng": "24.33333"
  },
  {
    "country": "RO",
    "name": "Căldărăști",
    "lat": "44.89375",
    "lng": "27.034"
  },
  {
    "country": "RO",
    "name": "Căldăraru",
    "lat": "44.45",
    "lng": "24.95"
  },
  {
    "country": "RO",
    "name": "Căldăraru",
    "lat": "44.41307",
    "lng": "26.26313"
  },
  {
    "country": "RO",
    "name": "Călăţele",
    "lat": "46.76667",
    "lng": "23.01667"
  },
  {
    "country": "RO",
    "name": "Călăraşi",
    "lat": "47.61667",
    "lng": "27.26667"
  },
  {
    "country": "RO",
    "name": "Călăraşi",
    "lat": "46.48333",
    "lng": "23.86667"
  },
  {
    "country": "RO",
    "name": "Călăraşi",
    "lat": "43.8",
    "lng": "24.05"
  },
  {
    "country": "RO",
    "name": "Călan",
    "lat": "45.73333",
    "lng": "22.98333"
  },
  {
    "country": "RO",
    "name": "Calafindeşti",
    "lat": "47.85",
    "lng": "26.11667"
  },
  {
    "country": "RO",
    "name": "Calafat",
    "lat": "43.99111",
    "lng": "22.93278"
  },
  {
    "country": "RO",
    "name": "Călacea",
    "lat": "46.67687",
    "lng": "21.93292"
  },
  {
    "country": "RO",
    "name": "Cajvana",
    "lat": "47.7",
    "lng": "25.96667"
  },
  {
    "country": "RO",
    "name": "Căiuţi-Sat",
    "lat": "46.18333",
    "lng": "26.93333"
  },
  {
    "country": "RO",
    "name": "Căiuți",
    "lat": "46.18057",
    "lng": "26.92571"
  },
  {
    "country": "RO",
    "name": "Căianu Mic",
    "lat": "47.23333",
    "lng": "24.15"
  },
  {
    "country": "RO",
    "name": "Căianu Mic",
    "lat": "46.78333",
    "lng": "23.91667"
  },
  {
    "country": "RO",
    "name": "Căianu",
    "lat": "46.7846",
    "lng": "23.9185"
  },
  {
    "country": "RO",
    "name": "Cadea",
    "lat": "47.31185",
    "lng": "22.06225"
  },
  {
    "country": "RO",
    "name": "Căciulați",
    "lat": "44.62741",
    "lng": "26.17255"
  },
  {
    "country": "RO",
    "name": "Cacica",
    "lat": "47.63333",
    "lng": "25.9"
  },
  {
    "country": "RO",
    "name": "Căbeşti",
    "lat": "46.76667",
    "lng": "22.36667"
  },
  {
    "country": "RO",
    "name": "Buzoeşti",
    "lat": "44.58333",
    "lng": "24.91667"
  },
  {
    "country": "RO",
    "name": "Buznea",
    "lat": "47.19515",
    "lng": "27.01572"
  },
  {
    "country": "RO",
    "name": "Buziaş",
    "lat": "45.64917",
    "lng": "21.60361"
  },
  {
    "country": "RO",
    "name": "Buzescu",
    "lat": "44.01667",
    "lng": "25.23333"
  },
  {
    "country": "RO",
    "name": "Buzău",
    "lat": "45.15",
    "lng": "26.83333"
  },
  {
    "country": "RO",
    "name": "Buza",
    "lat": "46.9",
    "lng": "24.15"
  },
  {
    "country": "RO",
    "name": "Buturugeni",
    "lat": "44.36528",
    "lng": "25.83528"
  },
  {
    "country": "RO",
    "name": "Butoieşti",
    "lat": "44.58333",
    "lng": "23.36667"
  },
  {
    "country": "RO",
    "name": "Butimanu",
    "lat": "44.68333",
    "lng": "25.9"
  },
  {
    "country": "RO",
    "name": "Buteni",
    "lat": "46.31667",
    "lng": "22.11667"
  },
  {
    "country": "RO",
    "name": "Butea",
    "lat": "47.06667",
    "lng": "26.91667"
  },
  {
    "country": "RO",
    "name": "Bustuchin",
    "lat": "44.96667",
    "lng": "23.73333"
  },
  {
    "country": "RO",
    "name": "Buşteni",
    "lat": "45.4",
    "lng": "25.53333"
  },
  {
    "country": "RO",
    "name": "Bușca",
    "lat": "44.11166",
    "lng": "24.80238"
  },
  {
    "country": "RO",
    "name": "Burzuc",
    "lat": "47.15552",
    "lng": "22.17096"
  },
  {
    "country": "RO",
    "name": "Burueneşti",
    "lat": "45.31667",
    "lng": "26.35"
  },
  {
    "country": "RO",
    "name": "Buruienești",
    "lat": "46.99595",
    "lng": "26.97732"
  },
  {
    "country": "RO",
    "name": "Bursuceni",
    "lat": "47.65097",
    "lng": "26.4753"
  },
  {
    "country": "RO",
    "name": "Burla",
    "lat": "47.79033",
    "lng": "25.92696"
  },
  {
    "country": "RO",
    "name": "Burjuc",
    "lat": "45.95",
    "lng": "22.48333"
  },
  {
    "country": "RO",
    "name": "Burila Mare",
    "lat": "44.45278",
    "lng": "22.57361"
  },
  {
    "country": "RO",
    "name": "Buriaș",
    "lat": "44.73304",
    "lng": "25.98053"
  },
  {
    "country": "RO",
    "name": "Burca",
    "lat": "45.91224",
    "lng": "26.94905"
  },
  {
    "country": "RO",
    "name": "Bunteşti",
    "lat": "46.61667",
    "lng": "22.46667"
  },
  {
    "country": "RO",
    "name": "Bunila",
    "lat": "45.7",
    "lng": "22.66667"
  },
  {
    "country": "RO",
    "name": "Bungetu",
    "lat": "44.84323",
    "lng": "25.53816"
  },
  {
    "country": "RO",
    "name": "Bunești",
    "lat": "47.52501",
    "lng": "26.28826"
  },
  {
    "country": "RO",
    "name": "Buneşti",
    "lat": "46.83333",
    "lng": "27.96667"
  },
  {
    "country": "RO",
    "name": "Buneşti",
    "lat": "46.1",
    "lng": "25.05"
  },
  {
    "country": "RO",
    "name": "Buneşti",
    "lat": "45.11667",
    "lng": "24.18333"
  },
  {
    "country": "RO",
    "name": "Bumbeşti-Jiu",
    "lat": "45.16667",
    "lng": "23.4"
  },
  {
    "country": "RO",
    "name": "Bulzeștii de Sus",
    "lat": "46.3007",
    "lng": "22.76118"
  },
  {
    "country": "RO",
    "name": "Bulzeşti",
    "lat": "44.53333",
    "lng": "23.88333"
  },
  {
    "country": "RO",
    "name": "Bulz",
    "lat": "46.91667",
    "lng": "22.68333"
  },
  {
    "country": "RO",
    "name": "Buliga",
    "lat": "44.35731",
    "lng": "27.79225"
  },
  {
    "country": "RO",
    "name": "Bulgăruș",
    "lat": "45.91947",
    "lng": "20.82219"
  },
  {
    "country": "RO",
    "name": "Bulbucata",
    "lat": "44.28333",
    "lng": "25.80333"
  },
  {
    "country": "RO",
    "name": "Bujoru",
    "lat": "43.71667",
    "lng": "25.56667"
  },
  {
    "country": "RO",
    "name": "Bujoreni",
    "lat": "45.13333",
    "lng": "24.35"
  },
  {
    "country": "RO",
    "name": "Târgu Bujor",
    "lat": "45.86667",
    "lng": "27.9"
  },
  {
    "country": "RO",
    "name": "Buhuşi",
    "lat": "46.71667",
    "lng": "26.7"
  },
  {
    "country": "RO",
    "name": "Buhoci",
    "lat": "46.56667",
    "lng": "27.01667"
  },
  {
    "country": "RO",
    "name": "Buhalnița",
    "lat": "47.37892",
    "lng": "26.91547"
  },
  {
    "country": "RO",
    "name": "Bughea de Sus",
    "lat": "45.29812",
    "lng": "25.03284"
  },
  {
    "country": "RO",
    "name": "Bughea de Jos",
    "lat": "45.26667",
    "lng": "25"
  },
  {
    "country": "RO",
    "name": "Bughea de Jos",
    "lat": "45.17985",
    "lng": "26.02044"
  },
  {
    "country": "RO",
    "name": "Buftea",
    "lat": "44.56139",
    "lng": "25.94889"
  },
  {
    "country": "RO",
    "name": "Buești",
    "lat": "44.54473",
    "lng": "27.18729"
  },
  {
    "country": "RO",
    "name": "Buduslău",
    "lat": "47.4",
    "lng": "22.26667"
  },
  {
    "country": "RO",
    "name": "Budureasa",
    "lat": "46.66667",
    "lng": "22.5"
  },
  {
    "country": "RO",
    "name": "Budila",
    "lat": "45.66667",
    "lng": "25.8"
  },
  {
    "country": "RO",
    "name": "Budeşti",
    "lat": "47.73333",
    "lng": "23.95"
  },
  {
    "country": "RO",
    "name": "Budești",
    "lat": "46.94084",
    "lng": "26.71177"
  },
  {
    "country": "RO",
    "name": "Budeşti",
    "lat": "46.88333",
    "lng": "24.25"
  },
  {
    "country": "RO",
    "name": "Budești",
    "lat": "45.62779",
    "lng": "27.05669"
  },
  {
    "country": "RO",
    "name": "Budeşti",
    "lat": "45.05",
    "lng": "24.38333"
  },
  {
    "country": "RO",
    "name": "Budeşti",
    "lat": "44.23472",
    "lng": "26.46583"
  },
  {
    "country": "RO",
    "name": "Budeni",
    "lat": "47.41383",
    "lng": "26.65927"
  },
  {
    "country": "RO",
    "name": "Budeasa Mică",
    "lat": "44.95",
    "lng": "24.85"
  },
  {
    "country": "RO",
    "name": "Budeasa",
    "lat": "45.01667",
    "lng": "24.85"
  },
  {
    "country": "RO",
    "name": "Budăi",
    "lat": "47.21773",
    "lng": "27.22282"
  },
  {
    "country": "RO",
    "name": "Budacu de Sus",
    "lat": "47.06118",
    "lng": "24.65752"
  },
  {
    "country": "RO",
    "name": "Budacu de Jos",
    "lat": "47.08333",
    "lng": "24.51667"
  },
  {
    "country": "RO",
    "name": "Buda",
    "lat": "47.40318",
    "lng": "26.67835"
  },
  {
    "country": "RO",
    "name": "Buda",
    "lat": "46.76231",
    "lng": "27.42113"
  },
  {
    "country": "RO",
    "name": "Buda",
    "lat": "46.67111",
    "lng": "26.71953"
  },
  {
    "country": "RO",
    "name": "Buda",
    "lat": "45.5",
    "lng": "26.9"
  },
  {
    "country": "RO",
    "name": "Buda",
    "lat": "44.82443",
    "lng": "26.18522"
  },
  {
    "country": "RO",
    "name": "Bucharest",
    "lat": "44.43225",
    "lng": "26.10626"
  },
  {
    "country": "RO",
    "name": "Bucureşci",
    "lat": "46.13333",
    "lng": "22.9"
  },
  {
    "country": "RO",
    "name": "Bucu",
    "lat": "44.60532",
    "lng": "27.49337"
  },
  {
    "country": "RO",
    "name": "Bucșoaia",
    "lat": "47.53972",
    "lng": "25.81118"
  },
  {
    "country": "RO",
    "name": "Bucșești",
    "lat": "46.48381",
    "lng": "26.5823"
  },
  {
    "country": "RO",
    "name": "Bucșenești-Lotași",
    "lat": "45.01307",
    "lng": "24.96845"
  },
  {
    "country": "RO",
    "name": "Bucșenești",
    "lat": "45.30096",
    "lng": "24.65841"
  },
  {
    "country": "RO",
    "name": "Bucşani",
    "lat": "44.86667",
    "lng": "25.65"
  },
  {
    "country": "RO",
    "name": "Bucşani",
    "lat": "44.37611",
    "lng": "25.65528"
  },
  {
    "country": "RO",
    "name": "Bucovineni",
    "lat": "47.85",
    "lng": "26.33333"
  },
  {
    "country": "RO",
    "name": "Bucovăț",
    "lat": "45.75569",
    "lng": "21.38324"
  },
  {
    "country": "RO",
    "name": "Bucovăţ",
    "lat": "44.3",
    "lng": "23.75"
  },
  {
    "country": "RO",
    "name": "Bucova",
    "lat": "45.50906",
    "lng": "22.63731"
  },
  {
    "country": "RO",
    "name": "Bucov",
    "lat": "44.96667",
    "lng": "26.08333"
  },
  {
    "country": "RO",
    "name": "Bucoşniţa",
    "lat": "45.3",
    "lng": "22.26667"
  },
  {
    "country": "RO",
    "name": "Bucium-Orlea",
    "lat": "45.58333",
    "lng": "22.96667"
  },
  {
    "country": "RO",
    "name": "Buciumi",
    "lat": "47.03333",
    "lng": "23.06667"
  },
  {
    "country": "RO",
    "name": "Buciumi",
    "lat": "46.2023",
    "lng": "26.78445"
  },
  {
    "country": "RO",
    "name": "Buciumeni",
    "lat": "46",
    "lng": "27.3"
  },
  {
    "country": "RO",
    "name": "Buciumeni",
    "lat": "45.15",
    "lng": "25.45"
  },
  {
    "country": "RO",
    "name": "Buciumeni",
    "lat": "44.54975",
    "lng": "25.96419"
  },
  {
    "country": "RO",
    "name": "Bucium",
    "lat": "46.26402",
    "lng": "23.1791"
  },
  {
    "country": "RO",
    "name": "Bucium",
    "lat": "46.23333",
    "lng": "23.21667"
  },
  {
    "country": "RO",
    "name": "Bucinişu",
    "lat": "43.95",
    "lng": "24.25"
  },
  {
    "country": "RO",
    "name": "Buchin",
    "lat": "45.36667",
    "lng": "22.25"
  },
  {
    "country": "RO",
    "name": "Bucești",
    "lat": "45.6525",
    "lng": "27.53008"
  },
  {
    "country": "RO",
    "name": "Buceş",
    "lat": "46.18333",
    "lng": "22.93333"
  },
  {
    "country": "RO",
    "name": "Bucerdea-Grânoasă",
    "lat": "46.2",
    "lng": "23.83333"
  },
  {
    "country": "RO",
    "name": "Bucecea",
    "lat": "47.76667",
    "lng": "26.43333"
  },
  {
    "country": "RO",
    "name": "Brusturoasa",
    "lat": "46.51667",
    "lng": "26.2"
  },
  {
    "country": "RO",
    "name": "Brusturi",
    "lat": "47.28333",
    "lng": "26.38333"
  },
  {
    "country": "RO",
    "name": "Brusturi",
    "lat": "47.15",
    "lng": "22.25"
  },
  {
    "country": "RO",
    "name": "Bruiu",
    "lat": "45.86667",
    "lng": "24.7"
  },
  {
    "country": "RO",
    "name": "Broșteni",
    "lat": "47.30459",
    "lng": "26.55625"
  },
  {
    "country": "RO",
    "name": "Broşteni",
    "lat": "47.23333",
    "lng": "25.7"
  },
  {
    "country": "RO",
    "name": "Broşteni",
    "lat": "45.75",
    "lng": "27.03333"
  },
  {
    "country": "RO",
    "name": "Broşteni",
    "lat": "44.76083",
    "lng": "22.97944"
  },
  {
    "country": "RO",
    "name": "Broșteni",
    "lat": "44.72053",
    "lng": "25.50935"
  },
  {
    "country": "RO",
    "name": "Broșteni",
    "lat": "44.67192",
    "lng": "26.74787"
  },
  {
    "country": "RO",
    "name": "Broscăuţi",
    "lat": "47.95",
    "lng": "26.45"
  },
  {
    "country": "RO",
    "name": "Brodoc",
    "lat": "46.6509",
    "lng": "27.67669"
  },
  {
    "country": "RO",
    "name": "Brodina",
    "lat": "47.88333",
    "lng": "25.41667"
  },
  {
    "country": "RO",
    "name": "Brâncoveni",
    "lat": "44.31667",
    "lng": "24.3"
  },
  {
    "country": "RO",
    "name": "Brâncoveneşti",
    "lat": "46.85632",
    "lng": "24.75941"
  },
  {
    "country": "RO",
    "name": "Brâncoveanca",
    "lat": "43.94075",
    "lng": "24.69336"
  },
  {
    "country": "RO",
    "name": "Brânceni",
    "lat": "43.88333",
    "lng": "25.4"
  },
  {
    "country": "RO",
    "name": "Brezoi",
    "lat": "45.33797",
    "lng": "24.24863"
  },
  {
    "country": "RO",
    "name": "Brezoaele",
    "lat": "44.58333",
    "lng": "25.73333"
  },
  {
    "country": "RO",
    "name": "Brezoaia",
    "lat": "44.55683",
    "lng": "25.78527"
  },
  {
    "country": "RO",
    "name": "Brezniţa Ocol",
    "lat": "44.66667",
    "lng": "22.61833"
  },
  {
    "country": "RO",
    "name": "Brezniţa-Motru",
    "lat": "44.56667",
    "lng": "23.21667"
  },
  {
    "country": "RO",
    "name": "Bretea Română",
    "lat": "45.66085",
    "lng": "23.01739"
  },
  {
    "country": "RO",
    "name": "Breţcu",
    "lat": "46.05",
    "lng": "26.3"
  },
  {
    "country": "RO",
    "name": "Brestovăț",
    "lat": "45.87342",
    "lng": "21.68201"
  },
  {
    "country": "RO",
    "name": "Brehuiești",
    "lat": "47.70194",
    "lng": "26.54472"
  },
  {
    "country": "RO",
    "name": "Brebu Nou",
    "lat": "45.23333",
    "lng": "22.13333"
  },
  {
    "country": "RO",
    "name": "Brebu Mânăstirei",
    "lat": "45.18333",
    "lng": "25.76667"
  },
  {
    "country": "RO",
    "name": "Brebu Megieșesc",
    "lat": "45.16774",
    "lng": "25.77474"
  },
  {
    "country": "RO",
    "name": "Brebu",
    "lat": "45.42028",
    "lng": "21.9925"
  },
  {
    "country": "RO",
    "name": "Brebeni",
    "lat": "44.36667",
    "lng": "24.45"
  },
  {
    "country": "RO",
    "name": "Breb",
    "lat": "47.74854",
    "lng": "23.90494"
  },
  {
    "country": "RO",
    "name": "Breazu",
    "lat": "47.21343",
    "lng": "27.51815"
  },
  {
    "country": "RO",
    "name": "Breaza de Sus",
    "lat": "45.19879",
    "lng": "25.65578"
  },
  {
    "country": "RO",
    "name": "Breaza de Jos",
    "lat": "45.17125",
    "lng": "25.67571"
  },
  {
    "country": "RO",
    "name": "Breaza",
    "lat": "47.61502",
    "lng": "25.31816"
  },
  {
    "country": "RO",
    "name": "Breaza",
    "lat": "47.35108",
    "lng": "24.0622"
  },
  {
    "country": "RO",
    "name": "Breaza",
    "lat": "46.76667",
    "lng": "24.63333"
  },
  {
    "country": "RO",
    "name": "Breaza",
    "lat": "45.18333",
    "lng": "25.66667"
  },
  {
    "country": "RO",
    "name": "Breaza",
    "lat": "45.1",
    "lng": "26.53333"
  },
  {
    "country": "RO",
    "name": "Breasta",
    "lat": "44.33333",
    "lng": "23.68333"
  },
  {
    "country": "RO",
    "name": "Brazii de Sus",
    "lat": "44.86667",
    "lng": "26.01667"
  },
  {
    "country": "RO",
    "name": "Brazii",
    "lat": "46.23333",
    "lng": "22.33333"
  },
  {
    "country": "RO",
    "name": "Rădulești",
    "lat": "44.76667",
    "lng": "26.35"
  },
  {
    "country": "RO",
    "name": "Brazi",
    "lat": "45.48716",
    "lng": "22.8404"
  },
  {
    "country": "RO",
    "name": "Bratovoești",
    "lat": "44.13333",
    "lng": "23.9"
  },
  {
    "country": "RO",
    "name": "Brătila",
    "lat": "46.32348",
    "lng": "26.77442"
  },
  {
    "country": "RO",
    "name": "Brătești",
    "lat": "47.19135",
    "lng": "26.6858"
  },
  {
    "country": "RO",
    "name": "Brătești",
    "lat": "46.3254",
    "lng": "26.64333"
  },
  {
    "country": "RO",
    "name": "Brateş",
    "lat": "45.83333",
    "lng": "26.06667"
  },
  {
    "country": "RO",
    "name": "Brateiu",
    "lat": "46.16667",
    "lng": "24.41667"
  },
  {
    "country": "RO",
    "name": "Bratca",
    "lat": "46.93333",
    "lng": "22.61667"
  },
  {
    "country": "RO",
    "name": "Brastavățu",
    "lat": "43.90634",
    "lng": "24.40784"
  },
  {
    "country": "RO",
    "name": "Braşov",
    "lat": "45.64861",
    "lng": "25.60613"
  },
  {
    "country": "RO",
    "name": "Braniştea",
    "lat": "47.16667",
    "lng": "24.06667"
  },
  {
    "country": "RO",
    "name": "Braniştea",
    "lat": "45.45",
    "lng": "27.85"
  },
  {
    "country": "RO",
    "name": "Braniştea",
    "lat": "44.68333",
    "lng": "25.58333"
  },
  {
    "country": "RO",
    "name": "Braniștea",
    "lat": "44.24201",
    "lng": "22.97354"
  },
  {
    "country": "RO",
    "name": "Braniștea",
    "lat": "43.96315",
    "lng": "26.03812"
  },
  {
    "country": "RO",
    "name": "Brăniștari",
    "lat": "44.17626",
    "lng": "26.05953"
  },
  {
    "country": "RO",
    "name": "Brănişca",
    "lat": "45.91667",
    "lng": "22.78333"
  },
  {
    "country": "RO",
    "name": "Braneț",
    "lat": "44.32576",
    "lng": "24.17792"
  },
  {
    "country": "RO",
    "name": "Brăneşti",
    "lat": "45.03333",
    "lng": "25.41667"
  },
  {
    "country": "RO",
    "name": "Brăneşti",
    "lat": "44.65",
    "lng": "23.46667"
  },
  {
    "country": "RO",
    "name": "Brăneşti",
    "lat": "44.45",
    "lng": "26.33333"
  },
  {
    "country": "RO",
    "name": "Bran",
    "lat": "45.51667",
    "lng": "25.35"
  },
  {
    "country": "RO",
    "name": "Braloştiţa",
    "lat": "44.5",
    "lng": "23.51667"
  },
  {
    "country": "RO",
    "name": "Brăila",
    "lat": "45.26667",
    "lng": "27.98333"
  },
  {
    "country": "RO",
    "name": "Brăhăşeştii de Sus",
    "lat": "46.05",
    "lng": "27.35"
  },
  {
    "country": "RO",
    "name": "Brăhășești",
    "lat": "46.03333",
    "lng": "27.36667"
  },
  {
    "country": "RO",
    "name": "Bragadiru",
    "lat": "44.37111",
    "lng": "25.9775"
  },
  {
    "country": "RO",
    "name": "Bragadiru",
    "lat": "43.76667",
    "lng": "25.51667"
  },
  {
    "country": "RO",
    "name": "Brăeşti",
    "lat": "47.86667",
    "lng": "26.45"
  },
  {
    "country": "RO",
    "name": "Brăiești",
    "lat": "47.49673",
    "lng": "26.07182"
  },
  {
    "country": "RO",
    "name": "Brăeşti",
    "lat": "47.15",
    "lng": "27.1"
  },
  {
    "country": "RO",
    "name": "Brăeşti",
    "lat": "45.43333",
    "lng": "26.5"
  },
  {
    "country": "RO",
    "name": "Brăduţ",
    "lat": "46.13333",
    "lng": "25.61667"
  },
  {
    "country": "RO",
    "name": "Brăduleţ",
    "lat": "45.28333",
    "lng": "24.76667"
  },
  {
    "country": "RO",
    "name": "Bradu",
    "lat": "45.72221",
    "lng": "24.33234"
  },
  {
    "country": "RO",
    "name": "Bradu",
    "lat": "44.78333",
    "lng": "24.9"
  },
  {
    "country": "RO",
    "name": "Brădicești",
    "lat": "46.8481",
    "lng": "27.9027"
  },
  {
    "country": "RO",
    "name": "Brădeşti",
    "lat": "46.35",
    "lng": "25.35"
  },
  {
    "country": "RO",
    "name": "Brădeşti",
    "lat": "44.48333",
    "lng": "23.63333"
  },
  {
    "country": "RO",
    "name": "Brădeni",
    "lat": "46.08333",
    "lng": "24.83333"
  },
  {
    "country": "RO",
    "name": "Brădeanu",
    "lat": "44.93333",
    "lng": "26.85"
  },
  {
    "country": "RO",
    "name": "Brad",
    "lat": "46.13333",
    "lng": "22.78333"
  },
  {
    "country": "RO",
    "name": "Brabova",
    "lat": "44.36667",
    "lng": "23.43333"
  },
  {
    "country": "RO",
    "name": "Brabeți",
    "lat": "43.96098",
    "lng": "24.01339"
  },
  {
    "country": "RO",
    "name": "Bozovici",
    "lat": "44.93889",
    "lng": "22.00167"
  },
  {
    "country": "RO",
    "name": "Bozioru",
    "lat": "45.38333",
    "lng": "26.48333"
  },
  {
    "country": "RO",
    "name": "Bozieni",
    "lat": "46.83333",
    "lng": "27.15"
  },
  {
    "country": "RO",
    "name": "Boureni",
    "lat": "47.26497",
    "lng": "26.97672"
  },
  {
    "country": "RO",
    "name": "Boureni",
    "lat": "47.21314",
    "lng": "26.63092"
  },
  {
    "country": "RO",
    "name": "Boureni",
    "lat": "44.01589",
    "lng": "23.43393"
  },
  {
    "country": "RO",
    "name": "Botoşeşti-Paia",
    "lat": "44.4",
    "lng": "23.26667"
  },
  {
    "country": "RO",
    "name": "Botoşani",
    "lat": "47.75",
    "lng": "26.66667"
  },
  {
    "country": "RO",
    "name": "Botoşana",
    "lat": "47.68333",
    "lng": "25.95"
  },
  {
    "country": "RO",
    "name": "Botoroaga",
    "lat": "44.14833",
    "lng": "25.54472"
  },
  {
    "country": "RO",
    "name": "Botiza",
    "lat": "47.66667",
    "lng": "24.15"
  },
  {
    "country": "RO",
    "name": "Botiz",
    "lat": "47.83333",
    "lng": "22.95"
  },
  {
    "country": "RO",
    "name": "Botești",
    "lat": "47.052",
    "lng": "26.74863"
  },
  {
    "country": "RO",
    "name": "Boţeşti",
    "lat": "46.8",
    "lng": "27.88333"
  },
  {
    "country": "RO",
    "name": "Boţeşti",
    "lat": "45.01667",
    "lng": "25.13333"
  },
  {
    "country": "RO",
    "name": "Boteni",
    "lat": "45.18333",
    "lng": "25.11667"
  },
  {
    "country": "RO",
    "name": "Boşorod",
    "lat": "45.68333",
    "lng": "23.08333"
  },
  {
    "country": "RO",
    "name": "Bosia",
    "lat": "47.21696",
    "lng": "27.76707"
  },
  {
    "country": "RO",
    "name": "Bosanci",
    "lat": "47.58333",
    "lng": "26.31667"
  },
  {
    "country": "RO",
    "name": "Borsec",
    "lat": "46.95",
    "lng": "25.56667"
  },
  {
    "country": "RO",
    "name": "Borşa",
    "lat": "47.65527",
    "lng": "24.66328"
  },
  {
    "country": "RO",
    "name": "Borşa",
    "lat": "46.93333",
    "lng": "23.66667"
  },
  {
    "country": "RO",
    "name": "Borş",
    "lat": "47.11667",
    "lng": "21.81667"
  },
  {
    "country": "RO",
    "name": "Borosoaia",
    "lat": "47.463",
    "lng": "27.09862"
  },
  {
    "country": "RO",
    "name": "Boroşneu Mare",
    "lat": "45.81667",
    "lng": "26"
  },
  {
    "country": "RO",
    "name": "Borod",
    "lat": "46.98333",
    "lng": "22.63333"
  },
  {
    "country": "RO",
    "name": "Boroaia",
    "lat": "47.35",
    "lng": "26.33333"
  },
  {
    "country": "RO",
    "name": "Borlova",
    "lat": "45.36738",
    "lng": "22.352"
  },
  {
    "country": "RO",
    "name": "Borleşti",
    "lat": "46.76667",
    "lng": "26.48333"
  },
  {
    "country": "RO",
    "name": "Borduşani",
    "lat": "44.48333",
    "lng": "27.9"
  },
  {
    "country": "RO",
    "name": "Bordeşti",
    "lat": "45.55",
    "lng": "27.05"
  },
  {
    "country": "RO",
    "name": "Bordenii Mari",
    "lat": "45.08951",
    "lng": "25.86964"
  },
  {
    "country": "RO",
    "name": "Bordei Verde",
    "lat": "45.08333",
    "lng": "27.56667"
  },
  {
    "country": "RO",
    "name": "Bordeasca Veche",
    "lat": "45.54447",
    "lng": "27.3173"
  },
  {
    "country": "RO",
    "name": "Borcut",
    "lat": "47.482",
    "lng": "23.84071"
  },
  {
    "country": "RO",
    "name": "Borcea",
    "lat": "44.33333",
    "lng": "27.75"
  },
  {
    "country": "RO",
    "name": "Borca",
    "lat": "47.18333",
    "lng": "25.76667"
  },
  {
    "country": "RO",
    "name": "Borăscu",
    "lat": "44.7",
    "lng": "23.28333"
  },
  {
    "country": "RO",
    "name": "Borănești",
    "lat": "44.66069",
    "lng": "26.60505"
  },
  {
    "country": "RO",
    "name": "Bolvașnița",
    "lat": "45.34558",
    "lng": "22.31012"
  },
  {
    "country": "RO",
    "name": "Bolovăniș",
    "lat": "46.61633",
    "lng": "26.05263"
  },
  {
    "country": "RO",
    "name": "Boloteşti",
    "lat": "45.83333",
    "lng": "27.06667"
  },
  {
    "country": "RO",
    "name": "Bolintin Vale",
    "lat": "44.44889",
    "lng": "25.75778"
  },
  {
    "country": "RO",
    "name": "Bolintin Deal",
    "lat": "44.45917",
    "lng": "25.82111"
  },
  {
    "country": "RO",
    "name": "Boldur",
    "lat": "45.69417",
    "lng": "21.77667"
  },
  {
    "country": "RO",
    "name": "Boldu",
    "lat": "45.33333",
    "lng": "27.23333"
  },
  {
    "country": "RO",
    "name": "Boldeşti-Scăeni",
    "lat": "45.03333",
    "lng": "26.03333"
  },
  {
    "country": "RO",
    "name": "Boldeşti",
    "lat": "44.86597",
    "lng": "26.54906"
  },
  {
    "country": "RO",
    "name": "Bolboşi",
    "lat": "44.75",
    "lng": "23.21667"
  },
  {
    "country": "RO",
    "name": "Bolătău",
    "lat": "46.63345",
    "lng": "26.40149"
  },
  {
    "country": "RO",
    "name": "Boiu Mare",
    "lat": "47.4",
    "lng": "23.58333"
  },
  {
    "country": "RO",
    "name": "Boiu",
    "lat": "46.26632",
    "lng": "24.87285"
  },
  {
    "country": "RO",
    "name": "Boița",
    "lat": "45.63454",
    "lng": "24.26037"
  },
  {
    "country": "RO",
    "name": "Boişoara",
    "lat": "45.43333",
    "lng": "24.38333"
  },
  {
    "country": "RO",
    "name": "Boinești",
    "lat": "47.91567",
    "lng": "23.35117"
  },
  {
    "country": "RO",
    "name": "Boianu Mare",
    "lat": "47.38333",
    "lng": "22.53333"
  },
  {
    "country": "RO",
    "name": "Boian",
    "lat": "46.20159",
    "lng": "24.22862"
  },
  {
    "country": "RO",
    "name": "Bohotin",
    "lat": "46.93914",
    "lng": "27.97782"
  },
  {
    "country": "RO",
    "name": "Bogza",
    "lat": "45.50798",
    "lng": "27.19773"
  },
  {
    "country": "RO",
    "name": "Boghiș",
    "lat": "47.15512",
    "lng": "22.7388"
  },
  {
    "country": "RO",
    "name": "Boghicea",
    "lat": "47.05414",
    "lng": "27.06935"
  },
  {
    "country": "RO",
    "name": "Bogheşti",
    "lat": "46.16667",
    "lng": "27.4"
  },
  {
    "country": "RO",
    "name": "Bogei",
    "lat": "47.2655",
    "lng": "22.36079"
  },
  {
    "country": "RO",
    "name": "Bogdan Vodă",
    "lat": "47.69197",
    "lng": "24.26605"
  },
  {
    "country": "RO",
    "name": "Bogdăniţa",
    "lat": "46.45",
    "lng": "27.68333"
  },
  {
    "country": "RO",
    "name": "Bogdăneşti",
    "lat": "46.63333",
    "lng": "23.13333"
  },
  {
    "country": "RO",
    "name": "Bogdăneşti",
    "lat": "47.36667",
    "lng": "26.28333"
  },
  {
    "country": "RO",
    "name": "Bogdănești",
    "lat": "46.44965",
    "lng": "27.72679"
  },
  {
    "country": "RO",
    "name": "Bogdăneşti",
    "lat": "46.21667",
    "lng": "26.68333"
  },
  {
    "country": "RO",
    "name": "Bogdand",
    "lat": "47.41667",
    "lng": "22.93333"
  },
  {
    "country": "RO",
    "name": "Bogdana",
    "lat": "46.52668",
    "lng": "27.63278"
  },
  {
    "country": "RO",
    "name": "Bogdana",
    "lat": "43.93333",
    "lng": "25.08333"
  },
  {
    "country": "RO",
    "name": "Bogda",
    "lat": "45.97833",
    "lng": "21.5725"
  },
  {
    "country": "RO",
    "name": "Bogaţi",
    "lat": "44.86667",
    "lng": "25.13333"
  },
  {
    "country": "RO",
    "name": "Bogata",
    "lat": "47.40789",
    "lng": "26.18655"
  },
  {
    "country": "RO",
    "name": "Bogata",
    "lat": "46.45",
    "lng": "24.06667"
  },
  {
    "country": "RO",
    "name": "Bodoc",
    "lat": "45.95",
    "lng": "25.85"
  },
  {
    "country": "RO",
    "name": "Bodeștii de Jos",
    "lat": "47.02752",
    "lng": "26.44483"
  },
  {
    "country": "RO",
    "name": "Bodeşti",
    "lat": "47.03333",
    "lng": "26.41667"
  },
  {
    "country": "RO",
    "name": "Bodești",
    "lat": "45.14167",
    "lng": "24.11549"
  },
  {
    "country": "RO",
    "name": "Bod",
    "lat": "45.76667",
    "lng": "25.65"
  },
  {
    "country": "RO",
    "name": "Bocsig",
    "lat": "46.41667",
    "lng": "21.95"
  },
  {
    "country": "RO",
    "name": "Bocşa",
    "lat": "47.2939",
    "lng": "22.91405"
  },
  {
    "country": "RO",
    "name": "Bocşa",
    "lat": "45.37333",
    "lng": "21.70917"
  },
  {
    "country": "RO",
    "name": "Bocicoiu Mare",
    "lat": "47.96667",
    "lng": "24"
  },
  {
    "country": "RO",
    "name": "Bobulești",
    "lat": "47.75135",
    "lng": "27.22697"
  },
  {
    "country": "RO",
    "name": "Bobota",
    "lat": "47.38333",
    "lng": "22.76667"
  },
  {
    "country": "RO",
    "name": "Bobolia",
    "lat": "45.09395",
    "lng": "25.74259"
  },
  {
    "country": "RO",
    "name": "Bobohalma",
    "lat": "46.35191",
    "lng": "24.23166"
  },
  {
    "country": "RO",
    "name": "Boboiești",
    "lat": "47.2537",
    "lng": "26.03749"
  },
  {
    "country": "RO",
    "name": "Boboc",
    "lat": "45.1957",
    "lng": "26.98136"
  },
  {
    "country": "RO",
    "name": "Bobâlna",
    "lat": "47.14385",
    "lng": "23.64461"
  },
  {
    "country": "RO",
    "name": "Bobiceşti",
    "lat": "44.38333",
    "lng": "24.15"
  },
  {
    "country": "RO",
    "name": "Blânzi",
    "lat": "45.93575",
    "lng": "27.65063"
  },
  {
    "country": "RO",
    "name": "Blândiana",
    "lat": "45.97943",
    "lng": "23.38543"
  },
  {
    "country": "RO",
    "name": "Blândeşti",
    "lat": "47.7",
    "lng": "26.86667"
  },
  {
    "country": "RO",
    "name": "Blideşti",
    "lat": "46.3",
    "lng": "23.13333"
  },
  {
    "country": "RO",
    "name": "Blejoi",
    "lat": "45",
    "lng": "26.01667"
  },
  {
    "country": "RO",
    "name": "Blejeşti",
    "lat": "44.3",
    "lng": "25.46667"
  },
  {
    "country": "RO",
    "name": "Bălcaciu",
    "lat": "46.19122",
    "lng": "24.06139"
  },
  {
    "country": "RO",
    "name": "Blăjeni",
    "lat": "46.23333",
    "lng": "22.9"
  },
  {
    "country": "RO",
    "name": "Blăjel",
    "lat": "46.21667",
    "lng": "24.31667"
  },
  {
    "country": "RO",
    "name": "Blăjani",
    "lat": "45.31667",
    "lng": "26.81667"
  },
  {
    "country": "RO",
    "name": "Blaj",
    "lat": "46.17508",
    "lng": "23.91578"
  },
  {
    "country": "RO",
    "name": "Blăgeşti",
    "lat": "46.68333",
    "lng": "26.65"
  },
  {
    "country": "RO",
    "name": "Blăgeşti",
    "lat": "46.13722",
    "lng": "28.01306"
  },
  {
    "country": "RO",
    "name": "Bixad",
    "lat": "47.93333",
    "lng": "23.4"
  },
  {
    "country": "RO",
    "name": "Bivolărie",
    "lat": "47.91464",
    "lng": "25.65525"
  },
  {
    "country": "RO",
    "name": "Bivolari",
    "lat": "47.53333",
    "lng": "27.43333"
  },
  {
    "country": "RO",
    "name": "Bistriţa Bârgăului",
    "lat": "47.21667",
    "lng": "24.76667"
  },
  {
    "country": "RO",
    "name": "Bistriţa",
    "lat": "47.13316",
    "lng": "24.50011"
  },
  {
    "country": "RO",
    "name": "Bistrița",
    "lat": "46.94856",
    "lng": "26.29598"
  },
  {
    "country": "RO",
    "name": "Bistrița",
    "lat": "45.18612",
    "lng": "24.0401"
  },
  {
    "country": "RO",
    "name": "Bistrița",
    "lat": "44.58511",
    "lng": "22.78762"
  },
  {
    "country": "RO",
    "name": "Bistreț",
    "lat": "43.9",
    "lng": "23.5"
  },
  {
    "country": "RO",
    "name": "Bistra Mureșului",
    "lat": "46.96093",
    "lng": "24.90608"
  },
  {
    "country": "RO",
    "name": "Bistra",
    "lat": "47.86667",
    "lng": "24.2"
  },
  {
    "country": "RO",
    "name": "Bistra",
    "lat": "47.25478",
    "lng": "22.42295"
  },
  {
    "country": "RO",
    "name": "Bistra",
    "lat": "46.3782",
    "lng": "23.10081"
  },
  {
    "country": "RO",
    "name": "Bisoca",
    "lat": "45.53333",
    "lng": "26.7"
  },
  {
    "country": "RO",
    "name": "Bâscoveni",
    "lat": "44.24444",
    "lng": "25.35998"
  },
  {
    "country": "RO",
    "name": "Bâscenii de Sus",
    "lat": "45.26662",
    "lng": "26.27073"
  },
  {
    "country": "RO",
    "name": "Bâscenii de Jos",
    "lat": "45.24708",
    "lng": "26.32122"
  },
  {
    "country": "RO",
    "name": "Bâsca Rozilei",
    "lat": "45.45387",
    "lng": "26.33714"
  },
  {
    "country": "RO",
    "name": "Bâsca Chiojdului",
    "lat": "45.3712",
    "lng": "26.18355"
  },
  {
    "country": "RO",
    "name": "Bârzești",
    "lat": "46.75",
    "lng": "27.55"
  },
  {
    "country": "RO",
    "name": "Bârzava",
    "lat": "46.11667",
    "lng": "21.98333"
  },
  {
    "country": "RO",
    "name": "Bârza",
    "lat": "46.55",
    "lng": "24.13333"
  },
  {
    "country": "RO",
    "name": "Bârza",
    "lat": "44.32811",
    "lng": "24.14188"
  },
  {
    "country": "RO",
    "name": "Bârseşti",
    "lat": "45.91667",
    "lng": "26.73333"
  },
  {
    "country": "RO",
    "name": "Bârsău de Sus",
    "lat": "47.6",
    "lng": "23.21667"
  },
  {
    "country": "RO",
    "name": "Bârsăneşti",
    "lat": "46.33333",
    "lng": "26.7"
  },
  {
    "country": "RO",
    "name": "Bârsana",
    "lat": "47.81667",
    "lng": "24.06667"
  },
  {
    "country": "RO",
    "name": "Bârsa",
    "lat": "46.38333",
    "lng": "22.06667"
  },
  {
    "country": "RO",
    "name": "Bârnova",
    "lat": "47.06667",
    "lng": "27.61667"
  },
  {
    "country": "RO",
    "name": "Bârna",
    "lat": "45.71667",
    "lng": "22.05"
  },
  {
    "country": "RO",
    "name": "Bârlogu",
    "lat": "44.62658",
    "lng": "25.08066"
  },
  {
    "country": "RO",
    "name": "Bârlad",
    "lat": "46.23175",
    "lng": "27.66907"
  },
  {
    "country": "RO",
    "name": "Bârla",
    "lat": "44.42606",
    "lng": "24.77743"
  },
  {
    "country": "RO",
    "name": "Bârghiş",
    "lat": "45.98333",
    "lng": "24.53333"
  },
  {
    "country": "RO",
    "name": "Birda",
    "lat": "45.42996",
    "lng": "21.34359"
  },
  {
    "country": "RO",
    "name": "Bircii",
    "lat": "44.51673",
    "lng": "24.60324"
  },
  {
    "country": "RO",
    "name": "Birchiş",
    "lat": "45.96667",
    "lng": "22.16667"
  },
  {
    "country": "RO",
    "name": "Bârca",
    "lat": "43.96667",
    "lng": "23.61667"
  },
  {
    "country": "RO",
    "name": "Bâra",
    "lat": "47.03333",
    "lng": "27.05"
  },
  {
    "country": "RO",
    "name": "Bâlvăneşti",
    "lat": "44.7975",
    "lng": "22.68028"
  },
  {
    "country": "RO",
    "name": "Bâlteni",
    "lat": "44.86919",
    "lng": "23.27311"
  },
  {
    "country": "RO",
    "name": "Bâlta",
    "lat": "45.11791",
    "lng": "23.1022"
  },
  {
    "country": "RO",
    "name": "Bâlta",
    "lat": "44.53564",
    "lng": "23.47019"
  },
  {
    "country": "RO",
    "name": "Biliești",
    "lat": "45.72106",
    "lng": "27.34879"
  },
  {
    "country": "RO",
    "name": "Biled",
    "lat": "45.88639",
    "lng": "20.95889"
  },
  {
    "country": "RO",
    "name": "Bâldana",
    "lat": "44.603",
    "lng": "25.77836"
  },
  {
    "country": "RO",
    "name": "Bilciureşti",
    "lat": "44.73333",
    "lng": "25.8"
  },
  {
    "country": "RO",
    "name": "Bilca",
    "lat": "47.91667",
    "lng": "25.75"
  },
  {
    "country": "RO",
    "name": "Bilbor",
    "lat": "47.05",
    "lng": "25.51667"
  },
  {
    "country": "RO",
    "name": "Biia",
    "lat": "46.23097",
    "lng": "24.00461"
  },
  {
    "country": "RO",
    "name": "Biharia",
    "lat": "47.15",
    "lng": "21.91667"
  },
  {
    "country": "RO",
    "name": "Biertan",
    "lat": "46.13333",
    "lng": "24.51667"
  },
  {
    "country": "RO",
    "name": "Bâcu",
    "lat": "44.48259",
    "lng": "25.88904"
  },
  {
    "country": "RO",
    "name": "Bixad",
    "lat": "46.1",
    "lng": "25.86667"
  },
  {
    "country": "RO",
    "name": "Bâcleș",
    "lat": "44.48333",
    "lng": "23.13333"
  },
  {
    "country": "RO",
    "name": "Bichiş",
    "lat": "46.36667",
    "lng": "24.1"
  },
  {
    "country": "RO",
    "name": "Bichigiu",
    "lat": "47.42522",
    "lng": "24.33893"
  },
  {
    "country": "RO",
    "name": "Bicazu Ardelean",
    "lat": "46.85",
    "lng": "25.93333"
  },
  {
    "country": "RO",
    "name": "Bicaz-Chei",
    "lat": "46.81667",
    "lng": "25.88333"
  },
  {
    "country": "RO",
    "name": "Bicaz",
    "lat": "47.46667",
    "lng": "23.03333"
  },
  {
    "country": "RO",
    "name": "Bicaz",
    "lat": "46.91667",
    "lng": "26.06667"
  },
  {
    "country": "RO",
    "name": "Bezdead",
    "lat": "45.15",
    "lng": "25.51667"
  },
  {
    "country": "RO",
    "name": "Beuca",
    "lat": "44.252",
    "lng": "24.96637"
  },
  {
    "country": "RO",
    "name": "Bethausen",
    "lat": "45.83306",
    "lng": "21.95278"
  },
  {
    "country": "RO",
    "name": "Beștepe",
    "lat": "45.09241",
    "lng": "29.01478"
  },
  {
    "country": "RO",
    "name": "Berzunţi",
    "lat": "46.4",
    "lng": "26.63333"
  },
  {
    "country": "RO",
    "name": "Berzovia",
    "lat": "45.42611",
    "lng": "21.62806"
  },
  {
    "country": "RO",
    "name": "Berzasca",
    "lat": "44.64712",
    "lng": "21.95428"
  },
  {
    "country": "RO",
    "name": "Berveni",
    "lat": "47.75",
    "lng": "22.46667"
  },
  {
    "country": "RO",
    "name": "Berteştii de Jos",
    "lat": "44.83333",
    "lng": "27.75"
  },
  {
    "country": "RO",
    "name": "Bertea",
    "lat": "45.23333",
    "lng": "25.86667"
  },
  {
    "country": "RO",
    "name": "Berlişte",
    "lat": "44.98667",
    "lng": "21.46306"
  },
  {
    "country": "RO",
    "name": "Berleşti",
    "lat": "44.91667",
    "lng": "23.66667"
  },
  {
    "country": "RO",
    "name": "Beriu",
    "lat": "45.78333",
    "lng": "23.18333"
  },
  {
    "country": "RO",
    "name": "Berislăveşti",
    "lat": "45.25",
    "lng": "24.41667"
  },
  {
    "country": "RO",
    "name": "Berghin",
    "lat": "46.07782",
    "lng": "23.73742"
  },
  {
    "country": "RO",
    "name": "Berezeni",
    "lat": "46.37611",
    "lng": "28.14778"
  },
  {
    "country": "RO",
    "name": "Berevoeşti",
    "lat": "45.23333",
    "lng": "24.91667"
  },
  {
    "country": "RO",
    "name": "Berești",
    "lat": "46.1",
    "lng": "27.88333"
  },
  {
    "country": "RO",
    "name": "Bereşti-Tazlău",
    "lat": "46.46667",
    "lng": "26.66667"
  },
  {
    "country": "RO",
    "name": "Bereşti-Sat",
    "lat": "46.1",
    "lng": "27.88333"
  },
  {
    "country": "RO",
    "name": "Bereşti-Bistriţa",
    "lat": "46.71667",
    "lng": "26.83333"
  },
  {
    "country": "RO",
    "name": "Berești",
    "lat": "46.20329",
    "lng": "27.14476"
  },
  {
    "country": "RO",
    "name": "Bereni",
    "lat": "46.55733",
    "lng": "24.86821"
  },
  {
    "country": "RO",
    "name": "Beregsău Mare",
    "lat": "45.75921",
    "lng": "21.02666"
  },
  {
    "country": "RO",
    "name": "Berchișești",
    "lat": "47.52306",
    "lng": "26.03207"
  },
  {
    "country": "RO",
    "name": "Berceni",
    "lat": "44.93333",
    "lng": "26.11667"
  },
  {
    "country": "RO",
    "name": "Berceni",
    "lat": "44.31417",
    "lng": "26.18556"
  },
  {
    "country": "RO",
    "name": "Berca",
    "lat": "45.28333",
    "lng": "26.68333"
  },
  {
    "country": "RO",
    "name": "Berbești",
    "lat": "47.84865",
    "lng": "23.93448"
  },
  {
    "country": "RO",
    "name": "Berbeşti",
    "lat": "44.98333",
    "lng": "23.88333"
  },
  {
    "country": "RO",
    "name": "Bengești",
    "lat": "45.06667",
    "lng": "23.6"
  },
  {
    "country": "RO",
    "name": "Benesat",
    "lat": "47.41049",
    "lng": "23.28904"
  },
  {
    "country": "RO",
    "name": "Beltiug",
    "lat": "47.55",
    "lng": "22.85"
  },
  {
    "country": "RO",
    "name": "Beliu",
    "lat": "46.48333",
    "lng": "21.98333"
  },
  {
    "country": "RO",
    "name": "Beliş",
    "lat": "46.65",
    "lng": "23.03333"
  },
  {
    "country": "RO",
    "name": "Belin-Vale",
    "lat": "45.93237",
    "lng": "25.60878"
  },
  {
    "country": "RO",
    "name": "Belinţ",
    "lat": "45.755",
    "lng": "21.76028"
  },
  {
    "country": "RO",
    "name": "Belin",
    "lat": "45.93333",
    "lng": "25.56667"
  },
  {
    "country": "RO",
    "name": "Beleţi",
    "lat": "44.9",
    "lng": "25.08333"
  },
  {
    "country": "RO",
    "name": "Belciugatele",
    "lat": "44.48333",
    "lng": "26.43333"
  },
  {
    "country": "RO",
    "name": "Belceşti",
    "lat": "47.3",
    "lng": "27.08333"
  },
  {
    "country": "RO",
    "name": "Beiuş",
    "lat": "46.66667",
    "lng": "22.35"
  },
  {
    "country": "RO",
    "name": "Beiu",
    "lat": "43.87352",
    "lng": "25.45548"
  },
  {
    "country": "RO",
    "name": "Beidaud",
    "lat": "44.71667",
    "lng": "28.56667"
  },
  {
    "country": "RO",
    "name": "Beica de Jos",
    "lat": "46.73333",
    "lng": "24.8"
  },
  {
    "country": "RO",
    "name": "Beclean",
    "lat": "47.18333",
    "lng": "24.18333"
  },
  {
    "country": "RO",
    "name": "Beclean",
    "lat": "45.83119",
    "lng": "24.9218"
  },
  {
    "country": "RO",
    "name": "Beciu",
    "lat": "44.00429",
    "lng": "24.66571"
  },
  {
    "country": "RO",
    "name": "Becicherecu Mic",
    "lat": "45.82917",
    "lng": "21.05139"
  },
  {
    "country": "RO",
    "name": "Bechet",
    "lat": "43.78188",
    "lng": "23.95706"
  },
  {
    "country": "RO",
    "name": "Beceni",
    "lat": "45.38333",
    "lng": "26.78333"
  },
  {
    "country": "RO",
    "name": "Beba Veche",
    "lat": "46.13333",
    "lng": "20.31667"
  },
  {
    "country": "RO",
    "name": "Bazna",
    "lat": "46.2",
    "lng": "24.28333"
  },
  {
    "country": "RO",
    "name": "Băuţar",
    "lat": "45.51667",
    "lng": "22.56667"
  },
  {
    "country": "RO",
    "name": "Bătrâni",
    "lat": "45.31425",
    "lng": "26.15091"
  },
  {
    "country": "RO",
    "name": "Bătrâna",
    "lat": "45.78333",
    "lng": "22.58333"
  },
  {
    "country": "RO",
    "name": "Batoş",
    "lat": "46.88333",
    "lng": "24.66667"
  },
  {
    "country": "RO",
    "name": "Batârăşti",
    "lat": "44.81667",
    "lng": "24.15"
  },
  {
    "country": "RO",
    "name": "Bătești",
    "lat": "44.8483",
    "lng": "26.04031"
  },
  {
    "country": "RO",
    "name": "Bătarci",
    "lat": "48.03333",
    "lng": "23.16667"
  },
  {
    "country": "RO",
    "name": "Batăr",
    "lat": "46.7",
    "lng": "21.81667"
  },
  {
    "country": "RO",
    "name": "Băţanii Mari",
    "lat": "46.08333",
    "lng": "25.68333"
  },
  {
    "country": "RO",
    "name": "Bata",
    "lat": "46.01667",
    "lng": "22.03333"
  },
  {
    "country": "RO",
    "name": "Băseşti",
    "lat": "47.48333",
    "lng": "23.15"
  },
  {
    "country": "RO",
    "name": "Başcov",
    "lat": "44.9",
    "lng": "24.81667"
  },
  {
    "country": "RO",
    "name": "Basarabi",
    "lat": "47.4537",
    "lng": "26.43972"
  },
  {
    "country": "RO",
    "name": "Basarabi",
    "lat": "44.00561",
    "lng": "23.00915"
  },
  {
    "country": "RO",
    "name": "Barza",
    "lat": "46.1199",
    "lng": "22.85695"
  },
  {
    "country": "RO",
    "name": "Barza",
    "lat": "44.33333",
    "lng": "24.78333"
  },
  {
    "country": "RO",
    "name": "Baru Mic",
    "lat": "45.46667",
    "lng": "23.15"
  },
  {
    "country": "RO",
    "name": "Baru",
    "lat": "45.47218",
    "lng": "23.16271"
  },
  {
    "country": "RO",
    "name": "Barticești",
    "lat": "47.06324",
    "lng": "26.79254"
  },
  {
    "country": "RO",
    "name": "Bârgăuani",
    "lat": "46.98333",
    "lng": "26.63333"
  },
  {
    "country": "RO",
    "name": "Barcea",
    "lat": "45.75",
    "lng": "27.46667"
  },
  {
    "country": "RO",
    "name": "Barcani",
    "lat": "45.7",
    "lng": "26.08333"
  },
  {
    "country": "RO",
    "name": "Bărcăneşti",
    "lat": "46.71667",
    "lng": "26.58333"
  },
  {
    "country": "RO",
    "name": "Bărcăneşti",
    "lat": "44.88333",
    "lng": "26.05"
  },
  {
    "country": "RO",
    "name": "Bărcăneşti",
    "lat": "44.63333",
    "lng": "26.65"
  },
  {
    "country": "RO",
    "name": "Bărbuleţu",
    "lat": "45.13333",
    "lng": "25.3"
  },
  {
    "country": "RO",
    "name": "Bărbulești",
    "lat": "44.72629",
    "lng": "26.59929"
  },
  {
    "country": "RO",
    "name": "Bărbăteşti",
    "lat": "45.18333",
    "lng": "24.11667"
  },
  {
    "country": "RO",
    "name": "Bărbăteşti",
    "lat": "44.86667",
    "lng": "23.5"
  },
  {
    "country": "RO",
    "name": "Barați",
    "lat": "46.57569",
    "lng": "26.87118"
  },
  {
    "country": "RO",
    "name": "Bărăștii de Vede",
    "lat": "44.71601",
    "lng": "24.65919"
  },
  {
    "country": "RO",
    "name": "Bărăști",
    "lat": "45.25369",
    "lng": "24.59651"
  },
  {
    "country": "RO",
    "name": "Baraolt",
    "lat": "46.07514",
    "lng": "25.60029"
  },
  {
    "country": "RO",
    "name": "Bărăganul",
    "lat": "44.8",
    "lng": "27.51667"
  },
  {
    "country": "RO",
    "name": "Bărăganu",
    "lat": "44.08939",
    "lng": "28.4198"
  },
  {
    "country": "RO",
    "name": "Bărăbanț",
    "lat": "46.0993",
    "lng": "23.58487"
  },
  {
    "country": "RO",
    "name": "Bara",
    "lat": "45.89472",
    "lng": "21.87194"
  },
  {
    "country": "RO",
    "name": "Banloc",
    "lat": "45.38742",
    "lng": "21.13581"
  },
  {
    "country": "RO",
    "name": "Băniţa",
    "lat": "45.45",
    "lng": "23.26667"
  },
  {
    "country": "RO",
    "name": "Bănişor",
    "lat": "47.10431",
    "lng": "22.83731"
  },
  {
    "country": "RO",
    "name": "Bănia",
    "lat": "44.89583",
    "lng": "22.04472"
  },
  {
    "country": "RO",
    "name": "Bănești",
    "lat": "47.58946",
    "lng": "26.52335"
  },
  {
    "country": "RO",
    "name": "Băneşti",
    "lat": "45.1",
    "lng": "25.76667"
  },
  {
    "country": "RO",
    "name": "Băneasa",
    "lat": "45.93333",
    "lng": "27.93333"
  },
  {
    "country": "RO",
    "name": "Băneasa",
    "lat": "44.06667",
    "lng": "27.7"
  },
  {
    "country": "RO",
    "name": "Băneasa",
    "lat": "44.04611",
    "lng": "26.06417"
  },
  {
    "country": "RO",
    "name": "Băneasa",
    "lat": "43.93975",
    "lng": "24.94997"
  },
  {
    "country": "RO",
    "name": "Band",
    "lat": "46.58333",
    "lng": "24.38333"
  },
  {
    "country": "RO",
    "name": "Bancu",
    "lat": "46.30291",
    "lng": "25.94422"
  },
  {
    "country": "RO",
    "name": "Banca",
    "lat": "46.3",
    "lng": "27.8"
  },
  {
    "country": "RO",
    "name": "Bălușești",
    "lat": "46.81591",
    "lng": "26.99885"
  },
  {
    "country": "RO",
    "name": "Băluşeni",
    "lat": "47.66667",
    "lng": "26.8"
  },
  {
    "country": "RO",
    "name": "Bălțești",
    "lat": "45.10965",
    "lng": "26.12937"
  },
  {
    "country": "RO",
    "name": "Bădeana",
    "lat": "46.15",
    "lng": "27.58333"
  },
  {
    "country": "RO",
    "name": "Bălteni",
    "lat": "46.66667",
    "lng": "27.61667"
  },
  {
    "country": "RO",
    "name": "Bălteni",
    "lat": "44.66488",
    "lng": "25.69339"
  },
  {
    "country": "RO",
    "name": "Bălteni",
    "lat": "44.44883",
    "lng": "24.53247"
  },
  {
    "country": "RO",
    "name": "Balta Verde",
    "lat": "44.34411",
    "lng": "22.59878"
  },
  {
    "country": "RO",
    "name": "Bălţaţi",
    "lat": "47.21667",
    "lng": "27.15"
  },
  {
    "country": "RO",
    "name": "Bălţăteşti",
    "lat": "47.11667",
    "lng": "26.3"
  },
  {
    "country": "RO",
    "name": "Balta Doamnei",
    "lat": "44.75",
    "lng": "26.16667"
  },
  {
    "country": "RO",
    "name": "Balta Albă",
    "lat": "45.30423",
    "lng": "27.28557"
  },
  {
    "country": "RO",
    "name": "Balta",
    "lat": "44.88694",
    "lng": "22.63694"
  },
  {
    "country": "RO",
    "name": "Balşa",
    "lat": "46.03333",
    "lng": "23.11667"
  },
  {
    "country": "RO",
    "name": "Balș",
    "lat": "47.29628",
    "lng": "26.97856"
  },
  {
    "country": "RO",
    "name": "Balş",
    "lat": "44.35",
    "lng": "24.1"
  },
  {
    "country": "RO",
    "name": "Baloteşti",
    "lat": "44.61667",
    "lng": "26.11667"
  },
  {
    "country": "RO",
    "name": "Bălnaca",
    "lat": "46.94384",
    "lng": "22.57206"
  },
  {
    "country": "RO",
    "name": "Balintești",
    "lat": "46.02937",
    "lng": "27.92201"
  },
  {
    "country": "RO",
    "name": "Balinţ",
    "lat": "45.8125",
    "lng": "21.85361"
  },
  {
    "country": "RO",
    "name": "Bălileşti",
    "lat": "45.06667",
    "lng": "24.93333"
  },
  {
    "country": "RO",
    "name": "Băleşti",
    "lat": "45.43333",
    "lng": "27.23333"
  },
  {
    "country": "RO",
    "name": "Băleşti",
    "lat": "45.01667",
    "lng": "23.21667"
  },
  {
    "country": "RO",
    "name": "Băleni Sârbi",
    "lat": "44.81667",
    "lng": "25.63333"
  },
  {
    "country": "RO",
    "name": "Băleni",
    "lat": "45.81667",
    "lng": "27.83333"
  },
  {
    "country": "RO",
    "name": "Baldovinești",
    "lat": "45.32182",
    "lng": "27.91107"
  },
  {
    "country": "RO",
    "name": "Baldovineşti",
    "lat": "44.38333",
    "lng": "24.05"
  },
  {
    "country": "RO",
    "name": "Balda",
    "lat": "46.73353",
    "lng": "24.14362"
  },
  {
    "country": "RO",
    "name": "Bălcești",
    "lat": "45.10516",
    "lng": "23.6329"
  },
  {
    "country": "RO",
    "name": "Bălceşti",
    "lat": "44.61667",
    "lng": "23.95"
  },
  {
    "country": "RO",
    "name": "Bălcăuţi",
    "lat": "47.89149",
    "lng": "26.07279"
  },
  {
    "country": "RO",
    "name": "Balcani",
    "lat": "46.63333",
    "lng": "26.55"
  },
  {
    "country": "RO",
    "name": "Balc",
    "lat": "47.28333",
    "lng": "22.53333"
  },
  {
    "country": "RO",
    "name": "Bălăuşeri",
    "lat": "46.4",
    "lng": "24.68333"
  },
  {
    "country": "RO",
    "name": "Bălăşeşti",
    "lat": "46.1",
    "lng": "27.66667"
  },
  {
    "country": "RO",
    "name": "Bălănești",
    "lat": "44.2497",
    "lng": "24.48216"
  },
  {
    "country": "RO",
    "name": "Bălan",
    "lat": "47.15599",
    "lng": "23.31213"
  },
  {
    "country": "RO",
    "name": "Bălan",
    "lat": "46.6505",
    "lng": "25.80834"
  },
  {
    "country": "RO",
    "name": "Balaciu",
    "lat": "44.63333",
    "lng": "26.88333"
  },
  {
    "country": "RO",
    "name": "Bălăciţa",
    "lat": "44.38333",
    "lng": "23.13333"
  },
  {
    "country": "RO",
    "name": "Balaci",
    "lat": "44.35",
    "lng": "24.91667"
  },
  {
    "country": "RO",
    "name": "Bălăceanu",
    "lat": "45.26667",
    "lng": "27.15"
  },
  {
    "country": "RO",
    "name": "Bălăceanca",
    "lat": "44.39249",
    "lng": "26.29009"
  },
  {
    "country": "RO",
    "name": "Bălăceana",
    "lat": "47.64338",
    "lng": "26.04764"
  },
  {
    "country": "RO",
    "name": "Bălăbănești",
    "lat": "46.09546",
    "lng": "27.72206"
  },
  {
    "country": "RO",
    "name": "Băla",
    "lat": "46.71667",
    "lng": "24.5"
  },
  {
    "country": "RO",
    "name": "Bala",
    "lat": "44.88389",
    "lng": "22.83333"
  },
  {
    "country": "RO",
    "name": "Bajura",
    "lat": "48.20119",
    "lng": "26.53987"
  },
  {
    "country": "RO",
    "name": "Băjești",
    "lat": "45.02615",
    "lng": "24.94006"
  },
  {
    "country": "RO",
    "name": "Băiuţ",
    "lat": "47.61667",
    "lng": "24"
  },
  {
    "country": "RO",
    "name": "Băiţa de sub Codru",
    "lat": "47.53333",
    "lng": "23.15"
  },
  {
    "country": "RO",
    "name": "Băița",
    "lat": "47.70614",
    "lng": "23.49326"
  },
  {
    "country": "RO",
    "name": "Băiţa",
    "lat": "46.03333",
    "lng": "22.9"
  },
  {
    "country": "RO",
    "name": "Băişoara",
    "lat": "46.58333",
    "lng": "23.46667"
  },
  {
    "country": "RO",
    "name": "Băișești",
    "lat": "47.48024",
    "lng": "26.11115"
  },
  {
    "country": "RO",
    "name": "Băile Tuşnad",
    "lat": "46.15",
    "lng": "25.85"
  },
  {
    "country": "RO",
    "name": "Băileşti",
    "lat": "44.01667",
    "lng": "23.35"
  },
  {
    "country": "RO",
    "name": "Băile Olăneşti",
    "lat": "45.2",
    "lng": "24.23333"
  },
  {
    "country": "RO",
    "name": "Băile Herculane",
    "lat": "44.87972",
    "lng": "22.4125"
  },
  {
    "country": "RO",
    "name": "Băile Govora",
    "lat": "45.08333",
    "lng": "24.18333"
  },
  {
    "country": "RO",
    "name": "Băile Borșa",
    "lat": "47.68416",
    "lng": "24.71391"
  },
  {
    "country": "RO",
    "name": "Băiculeşti",
    "lat": "45.06667",
    "lng": "24.7"
  },
  {
    "country": "RO",
    "name": "Băicoi",
    "lat": "45.03333",
    "lng": "25.85"
  },
  {
    "country": "RO",
    "name": "Baia Sprie",
    "lat": "47.66189",
    "lng": "23.69215"
  },
  {
    "country": "RO",
    "name": "Baia Mare",
    "lat": "47.65729",
    "lng": "23.56808"
  },
  {
    "country": "RO",
    "name": "Baia de Fier",
    "lat": "45.16667",
    "lng": "23.76667"
  },
  {
    "country": "RO",
    "name": "Baia de Criş",
    "lat": "46.16667",
    "lng": "22.71667"
  },
  {
    "country": "RO",
    "name": "Baia de Arieş",
    "lat": "46.38045",
    "lng": "23.28115"
  },
  {
    "country": "RO",
    "name": "Baia de Aramă",
    "lat": "44.99929",
    "lng": "22.80784"
  },
  {
    "country": "RO",
    "name": "Baia",
    "lat": "47.41667",
    "lng": "26.21667"
  },
  {
    "country": "RO",
    "name": "Baia",
    "lat": "44.71667",
    "lng": "28.66667"
  },
  {
    "country": "RO",
    "name": "Bahnea",
    "lat": "46.36667",
    "lng": "24.48333"
  },
  {
    "country": "RO",
    "name": "Bahna",
    "lat": "46.78333",
    "lng": "26.78333"
  },
  {
    "country": "RO",
    "name": "Băgaciu",
    "lat": "46.26667",
    "lng": "24.36667"
  },
  {
    "country": "RO",
    "name": "Băduleasa",
    "lat": "43.92286",
    "lng": "24.98274"
  },
  {
    "country": "RO",
    "name": "Bădoși",
    "lat": "44.14723",
    "lng": "23.88974"
  },
  {
    "country": "RO",
    "name": "Bădeuți",
    "lat": "47.80277",
    "lng": "25.98387"
  },
  {
    "country": "RO",
    "name": "Bădești",
    "lat": "45.17157",
    "lng": "24.86064"
  },
  {
    "country": "RO",
    "name": "Bădeni",
    "lat": "47.40581",
    "lng": "26.94898"
  },
  {
    "country": "RO",
    "name": "Bădeni",
    "lat": "45.15272",
    "lng": "25.40263"
  },
  {
    "country": "RO",
    "name": "Bacova",
    "lat": "45.6641",
    "lng": "21.55238"
  },
  {
    "country": "RO",
    "name": "Baciu",
    "lat": "46.8",
    "lng": "23.51667"
  },
  {
    "country": "RO",
    "name": "Baciu",
    "lat": "44.33152",
    "lng": "25.44429"
  },
  {
    "country": "RO",
    "name": "Băcioiu",
    "lat": "46.31431",
    "lng": "27.15745"
  },
  {
    "country": "RO",
    "name": "Băcia",
    "lat": "45.8",
    "lng": "23.01667"
  },
  {
    "country": "RO",
    "name": "Băceşti",
    "lat": "46.85",
    "lng": "27.23333"
  },
  {
    "country": "RO",
    "name": "Bacea",
    "lat": "44.39824",
    "lng": "24.63759"
  },
  {
    "country": "RO",
    "name": "Bacău",
    "lat": "46.56718",
    "lng": "26.91384"
  },
  {
    "country": "RO",
    "name": "Băcani",
    "lat": "46.33333",
    "lng": "27.66667"
  },
  {
    "country": "RO",
    "name": "Băcălești",
    "lat": "44.05997",
    "lng": "24.81636"
  },
  {
    "country": "RO",
    "name": "Babța",
    "lat": "47.45778",
    "lng": "22.94283"
  },
  {
    "country": "RO",
    "name": "Băbiciu",
    "lat": "44.03333",
    "lng": "24.56667"
  },
  {
    "country": "RO",
    "name": "Babeţi",
    "lat": "45.31667",
    "lng": "26.38333"
  },
  {
    "country": "RO",
    "name": "Băbeni-Oltețu",
    "lat": "44.61404",
    "lng": "23.97798"
  },
  {
    "country": "RO",
    "name": "Băbeni",
    "lat": "47.3",
    "lng": "23.4"
  },
  {
    "country": "RO",
    "name": "Băbeni",
    "lat": "45.44635",
    "lng": "26.97875"
  },
  {
    "country": "RO",
    "name": "Băbeni",
    "lat": "44.96667",
    "lng": "24.23333"
  },
  {
    "country": "RO",
    "name": "Băbana",
    "lat": "44.9",
    "lng": "24.7"
  },
  {
    "country": "RO",
    "name": "Băbăiţa",
    "lat": "44.16667",
    "lng": "25.38333"
  },
  {
    "country": "RO",
    "name": "Babadag",
    "lat": "44.9",
    "lng": "28.71667"
  },
  {
    "country": "RO",
    "name": "Baba Ana",
    "lat": "44.96667",
    "lng": "26.45"
  },
  {
    "country": "RO",
    "name": "Azuga",
    "lat": "45.45",
    "lng": "25.55"
  },
  {
    "country": "RO",
    "name": "Axintele",
    "lat": "44.6",
    "lng": "26.78333"
  },
  {
    "country": "RO",
    "name": "Axente Sever",
    "lat": "46.1",
    "lng": "24.21667"
  },
  {
    "country": "RO",
    "name": "Avrig",
    "lat": "45.71667",
    "lng": "24.38333"
  },
  {
    "country": "RO",
    "name": "Avram Iancu",
    "lat": "46.38333",
    "lng": "22.78333"
  },
  {
    "country": "RO",
    "name": "Avram Iancu",
    "lat": "46.66944",
    "lng": "21.52417"
  },
  {
    "country": "RO",
    "name": "Avrămeşti",
    "lat": "46.33333",
    "lng": "25.01667"
  },
  {
    "country": "RO",
    "name": "Avrămeni",
    "lat": "48.01667",
    "lng": "26.95"
  },
  {
    "country": "RO",
    "name": "Auşeu",
    "lat": "47.03333",
    "lng": "22.5"
  },
  {
    "country": "RO",
    "name": "Augustin",
    "lat": "46.04613",
    "lng": "25.55333"
  },
  {
    "country": "RO",
    "name": "Aţintiş",
    "lat": "46.43333",
    "lng": "24.1"
  },
  {
    "country": "RO",
    "name": "Atid",
    "lat": "46.45",
    "lng": "25.05"
  },
  {
    "country": "RO",
    "name": "Aţel",
    "lat": "46.15",
    "lng": "24.46667"
  },
  {
    "country": "RO",
    "name": "Asuaju de Sus",
    "lat": "47.56667",
    "lng": "23.18333"
  },
  {
    "country": "RO",
    "name": "Aştileu",
    "lat": "47.03333",
    "lng": "22.38333"
  },
  {
    "country": "RO",
    "name": "Aşchileu Dorna",
    "lat": "46.98333",
    "lng": "23.48333"
  },
  {
    "country": "RO",
    "name": "Asău",
    "lat": "46.43333",
    "lng": "26.4"
  },
  {
    "country": "RO",
    "name": "Bujoreni",
    "lat": "44.11667",
    "lng": "25.63333"
  },
  {
    "country": "RO",
    "name": "Arsura",
    "lat": "46.81333",
    "lng": "28.02222"
  },
  {
    "country": "RO",
    "name": "Arpașu de Sus",
    "lat": "45.73436",
    "lng": "24.61906"
  },
  {
    "country": "RO",
    "name": "Arpaşu de Jos",
    "lat": "45.78333",
    "lng": "24.61667"
  },
  {
    "country": "RO",
    "name": "Aroneanu",
    "lat": "47.2",
    "lng": "27.6"
  },
  {
    "country": "RO",
    "name": "Armeniş",
    "lat": "45.2",
    "lng": "22.31667"
  },
  {
    "country": "RO",
    "name": "Armăşeşti",
    "lat": "44.75",
    "lng": "26.58333"
  },
  {
    "country": "RO",
    "name": "Ariniş",
    "lat": "47.5",
    "lng": "23.23333"
  },
  {
    "country": "RO",
    "name": "Arieşeni",
    "lat": "46.47641",
    "lng": "22.75741"
  },
  {
    "country": "RO",
    "name": "Ariceștii Zeletin",
    "lat": "45.22221",
    "lng": "26.17957"
  },
  {
    "country": "RO",
    "name": "Ariceştii-Rahtivani",
    "lat": "44.95",
    "lng": "25.83333"
  },
  {
    "country": "RO",
    "name": "Arghira",
    "lat": "47.45412",
    "lng": "26.4725"
  },
  {
    "country": "RO",
    "name": "Teslui",
    "lat": "44.20559",
    "lng": "24.15482"
  },
  {
    "country": "RO",
    "name": "Argetoaia",
    "lat": "44.51667",
    "lng": "23.36667"
  },
  {
    "country": "RO",
    "name": "Argeșelu",
    "lat": "44.9274",
    "lng": "24.87115"
  },
  {
    "country": "RO",
    "name": "Argel",
    "lat": "47.76136",
    "lng": "25.47049"
  },
  {
    "country": "RO",
    "name": "Arefu",
    "lat": "45.33333",
    "lng": "24.6"
  },
  {
    "country": "RO",
    "name": "Ardusat",
    "lat": "47.65",
    "lng": "23.36667"
  },
  {
    "country": "RO",
    "name": "Ardud",
    "lat": "47.63333",
    "lng": "22.88333"
  },
  {
    "country": "RO",
    "name": "Ardeoani",
    "lat": "46.53333",
    "lng": "26.6"
  },
  {
    "country": "RO",
    "name": "Arcuș",
    "lat": "45.90077",
    "lng": "25.77673"
  },
  {
    "country": "RO",
    "name": "Archiş",
    "lat": "46.48333",
    "lng": "22.05"
  },
  {
    "country": "RO",
    "name": "Arcani",
    "lat": "45.08333",
    "lng": "23.13333"
  },
  {
    "country": "RO",
    "name": "Arbore",
    "lat": "47.73333",
    "lng": "25.93333"
  },
  {
    "country": "RO",
    "name": "Arad",
    "lat": "46.18333",
    "lng": "21.31667"
  },
  {
    "country": "RO",
    "name": "Araci",
    "lat": "45.81187",
    "lng": "25.65482"
  },
  {
    "country": "RO",
    "name": "Aprozi",
    "lat": "44.26616",
    "lng": "26.50213"
  },
  {
    "country": "RO",
    "name": "Apostolache",
    "lat": "45.13333",
    "lng": "26.26667"
  },
  {
    "country": "RO",
    "name": "Apoldu de Jos",
    "lat": "45.86667",
    "lng": "23.85"
  },
  {
    "country": "RO",
    "name": "Apold",
    "lat": "46.11667",
    "lng": "24.81667"
  },
  {
    "country": "RO",
    "name": "Apele Vii",
    "lat": "44.06667",
    "lng": "24.06667"
  },
  {
    "country": "RO",
    "name": "Apateu",
    "lat": "46.61667",
    "lng": "21.78333"
  },
  {
    "country": "RO",
    "name": "Apaţa",
    "lat": "45.95",
    "lng": "25.51667"
  },
  {
    "country": "RO",
    "name": "Apalina",
    "lat": "46.75212",
    "lng": "24.69447"
  },
  {
    "country": "RO",
    "name": "Apahida",
    "lat": "46.81667",
    "lng": "23.75"
  },
  {
    "country": "RO",
    "name": "Apa Asău",
    "lat": "46.48747",
    "lng": "26.37888"
  },
  {
    "country": "RO",
    "name": "Apa",
    "lat": "47.76667",
    "lng": "23.2"
  },
  {
    "country": "RO",
    "name": "Aninoasa",
    "lat": "45.40924",
    "lng": "23.31505"
  },
  {
    "country": "RO",
    "name": "Aninoasa",
    "lat": "45.18333",
    "lng": "24.93333"
  },
  {
    "country": "RO",
    "name": "Aninoasa",
    "lat": "44.96667",
    "lng": "25.43333"
  },
  {
    "country": "RO",
    "name": "Aninoasa",
    "lat": "44.75",
    "lng": "23.48333"
  },
  {
    "country": "RO",
    "name": "Anina",
    "lat": "45.07944",
    "lng": "21.85694"
  },
  {
    "country": "RO",
    "name": "Anieș",
    "lat": "47.41347",
    "lng": "24.76853"
  },
  {
    "country": "RO",
    "name": "Anghelești",
    "lat": "46.07875",
    "lng": "27.06459"
  },
  {
    "country": "RO",
    "name": "Andrieşeni",
    "lat": "47.53333",
    "lng": "27.28333"
  },
  {
    "country": "RO",
    "name": "Andrid",
    "lat": "47.51667",
    "lng": "22.35"
  },
  {
    "country": "RO",
    "name": "Andrei Șaguna",
    "lat": "46.2881",
    "lng": "21.39175"
  },
  {
    "country": "RO",
    "name": "Andreiaşu de Jos",
    "lat": "45.75",
    "lng": "26.83333"
  },
  {
    "country": "RO",
    "name": "Andreești",
    "lat": "44.78948",
    "lng": "23.55099"
  },
  {
    "country": "RO",
    "name": "Andrăşeşti",
    "lat": "44.56667",
    "lng": "27.13333"
  },
  {
    "country": "RO",
    "name": "Amzacea",
    "lat": "43.95",
    "lng": "28.4"
  },
  {
    "country": "RO",
    "name": "Amaru",
    "lat": "44.93333",
    "lng": "26.58333"
  },
  {
    "country": "RO",
    "name": "Amărăştii de Sus",
    "lat": "43.98333",
    "lng": "24.15"
  },
  {
    "country": "RO",
    "name": "Amărăştii de Jos",
    "lat": "43.95",
    "lng": "24.16667"
  },
  {
    "country": "RO",
    "name": "Amărăşti",
    "lat": "44.76667",
    "lng": "24.15"
  },
  {
    "country": "RO",
    "name": "Amara",
    "lat": "45.24866",
    "lng": "27.29244"
  },
  {
    "country": "RO",
    "name": "Amara",
    "lat": "44.61667",
    "lng": "27.31667"
  },
  {
    "country": "RO",
    "name": "Alunu",
    "lat": "45.01667",
    "lng": "23.81667"
  },
  {
    "country": "RO",
    "name": "Alunișu",
    "lat": "44.71667",
    "lng": "24.55"
  },
  {
    "country": "RO",
    "name": "Alunișu",
    "lat": "44.33883",
    "lng": "26.05837"
  },
  {
    "country": "RO",
    "name": "Aluniş",
    "lat": "47.03333",
    "lng": "23.75"
  },
  {
    "country": "RO",
    "name": "Aluniş",
    "lat": "46.89287",
    "lng": "24.79855"
  },
  {
    "country": "RO",
    "name": "Aluniş",
    "lat": "45.2",
    "lng": "25.86667"
  },
  {
    "country": "RO",
    "name": "Alțâna",
    "lat": "45.93333",
    "lng": "24.46667"
  },
  {
    "country": "RO",
    "name": "Alparea",
    "lat": "47.03054",
    "lng": "22.04812"
  },
  {
    "country": "RO",
    "name": "Almaşu Mare",
    "lat": "46.11014",
    "lng": "23.11721"
  },
  {
    "country": "RO",
    "name": "Almaşu",
    "lat": "46.94546",
    "lng": "23.12965"
  },
  {
    "country": "RO",
    "name": "Almaş",
    "lat": "46.28333",
    "lng": "22.23333"
  },
  {
    "country": "RO",
    "name": "Almăj",
    "lat": "44.45",
    "lng": "23.71667"
  },
  {
    "country": "RO",
    "name": "Alma",
    "lat": "46.21359",
    "lng": "24.48037"
  },
  {
    "country": "RO",
    "name": "Alimpeşti",
    "lat": "45.08333",
    "lng": "23.8"
  },
  {
    "country": "RO",
    "name": "Alimănești",
    "lat": "44.25693",
    "lng": "24.53895"
  },
  {
    "country": "RO",
    "name": "Aliman",
    "lat": "44.18333",
    "lng": "27.85"
  },
  {
    "country": "RO",
    "name": "Alexeni",
    "lat": "44.68333",
    "lng": "26.7"
  },
  {
    "country": "RO",
    "name": "Alexandru Vlăhuţă",
    "lat": "46.41667",
    "lng": "27.63333"
  },
  {
    "country": "RO",
    "name": "Alexandru Odobescu",
    "lat": "44.26667",
    "lng": "27.08333"
  },
  {
    "country": "RO",
    "name": "Alexandru I. Cuza",
    "lat": "47.13333",
    "lng": "26.85"
  },
  {
    "country": "RO",
    "name": "Alexandria",
    "lat": "43.98333",
    "lng": "25.33333"
  },
  {
    "country": "RO",
    "name": "Aleşd",
    "lat": "47.06667",
    "lng": "22.41667"
  },
  {
    "country": "RO",
    "name": "Albota",
    "lat": "44.78333",
    "lng": "24.85"
  },
  {
    "country": "RO",
    "name": "Albota de Jos",
    "lat": "44.76667",
    "lng": "24.83333"
  },
  {
    "country": "RO",
    "name": "Albiș",
    "lat": "47.39024",
    "lng": "22.24528"
  },
  {
    "country": "RO",
    "name": "Albeștii Ungureni",
    "lat": "45.22529",
    "lng": "24.67254"
  },
  {
    "country": "RO",
    "name": "Albeşti-Paleologu",
    "lat": "44.95",
    "lng": "26.21667"
  },
  {
    "country": "RO",
    "name": "Albești-Muru",
    "lat": "44.9444",
    "lng": "26.20899"
  },
  {
    "country": "RO",
    "name": "Albeştii Pământeni",
    "lat": "45.21667",
    "lng": "24.66667"
  },
  {
    "country": "RO",
    "name": "Albeşti",
    "lat": "47.7",
    "lng": "27.06667"
  },
  {
    "country": "RO",
    "name": "Albeşti",
    "lat": "46.5",
    "lng": "27.86667"
  },
  {
    "country": "RO",
    "name": "Albeşti",
    "lat": "46.23333",
    "lng": "24.85"
  },
  {
    "country": "RO",
    "name": "Albeşti",
    "lat": "45.30955",
    "lng": "25.0078"
  },
  {
    "country": "RO",
    "name": "Albeşti",
    "lat": "44.53333",
    "lng": "27.13333"
  },
  {
    "country": "RO",
    "name": "Albeşti",
    "lat": "43.8",
    "lng": "28.41667"
  },
  {
    "country": "RO",
    "name": "Albeni",
    "lat": "45.03333",
    "lng": "23.6"
  },
  {
    "country": "RO",
    "name": "Alba Iulia",
    "lat": "46.06667",
    "lng": "23.58333"
  },
  {
    "country": "RO",
    "name": "Albac",
    "lat": "46.45246",
    "lng": "22.95164"
  },
  {
    "country": "RO",
    "name": "Alba",
    "lat": "48.15859",
    "lng": "26.47736"
  },
  {
    "country": "RO",
    "name": "Alămor",
    "lat": "45.93003",
    "lng": "23.9937"
  },
  {
    "country": "RO",
    "name": "Aiudul de Sus",
    "lat": "46.31653",
    "lng": "23.69053"
  },
  {
    "country": "RO",
    "name": "Aiud",
    "lat": "46.31006",
    "lng": "23.72128"
  },
  {
    "country": "RO",
    "name": "Aiton",
    "lat": "46.68333",
    "lng": "23.73333"
  },
  {
    "country": "RO",
    "name": "Aita Mare",
    "lat": "45.96667",
    "lng": "25.55"
  },
  {
    "country": "RO",
    "name": "Agrișu Mare",
    "lat": "46.27243",
    "lng": "21.75558"
  },
  {
    "country": "RO",
    "name": "Agriș",
    "lat": "47.88075",
    "lng": "23.0034"
  },
  {
    "country": "RO",
    "name": "Agrij",
    "lat": "47.06685",
    "lng": "23.09918"
  },
  {
    "country": "RO",
    "name": "Agrieș",
    "lat": "47.40022",
    "lng": "24.13491"
  },
  {
    "country": "RO",
    "name": "Agnita",
    "lat": "45.96667",
    "lng": "24.61667"
  },
  {
    "country": "RO",
    "name": "Agârbiciu",
    "lat": "46.06764",
    "lng": "24.19386"
  },
  {
    "country": "RO",
    "name": "Agighiol",
    "lat": "45.03362",
    "lng": "28.87628"
  },
  {
    "country": "RO",
    "name": "Agigea",
    "lat": "44.08333",
    "lng": "28.61667"
  },
  {
    "country": "RO",
    "name": "Aghireșu-Fabrici",
    "lat": "46.8669",
    "lng": "23.27129"
  },
  {
    "country": "RO",
    "name": "Aghireșu",
    "lat": "46.87209",
    "lng": "23.23773"
  },
  {
    "country": "RO",
    "name": "Aghireș",
    "lat": "47.16164",
    "lng": "23.01764"
  },
  {
    "country": "RO",
    "name": "Agăş",
    "lat": "46.48333",
    "lng": "26.21667"
  },
  {
    "country": "RO",
    "name": "Agapia",
    "lat": "47.16667",
    "lng": "26.28333"
  },
  {
    "country": "RO",
    "name": "Afumaţi",
    "lat": "44.51667",
    "lng": "26.26667"
  },
  {
    "country": "RO",
    "name": "Afumaţi",
    "lat": "44",
    "lng": "23.46667"
  },
  {
    "country": "RO",
    "name": "Adunații-Copăceni",
    "lat": "44.25413",
    "lng": "26.04929"
  },
  {
    "country": "RO",
    "name": "Adunaţi",
    "lat": "45.13333",
    "lng": "25.61667"
  },
  {
    "country": "RO",
    "name": "Adjudu Vechi",
    "lat": "46.13485",
    "lng": "27.18891"
  },
  {
    "country": "RO",
    "name": "Adjudeni",
    "lat": "47.01408",
    "lng": "26.94903"
  },
  {
    "country": "RO",
    "name": "Adjud",
    "lat": "46.1",
    "lng": "27.16667"
  },
  {
    "country": "RO",
    "name": "Adâncata",
    "lat": "47.73333",
    "lng": "26.3"
  },
  {
    "country": "RO",
    "name": "Adâncata",
    "lat": "44.76667",
    "lng": "26.43333"
  },
  {
    "country": "RO",
    "name": "Adânca",
    "lat": "44.9225",
    "lng": "25.61005"
  },
  {
    "country": "RO",
    "name": "Adea",
    "lat": "46.55511",
    "lng": "21.58433"
  },
  {
    "country": "RO",
    "name": "Adășeni",
    "lat": "48.0692",
    "lng": "26.93789"
  },
  {
    "country": "RO",
    "name": "Adămuş",
    "lat": "46.3",
    "lng": "24.23333"
  },
  {
    "country": "RO",
    "name": "Adamclisi",
    "lat": "44.08333",
    "lng": "27.95"
  },
  {
    "country": "RO",
    "name": "Acriș",
    "lat": "45.63673",
    "lng": "25.99247"
  },
  {
    "country": "RO",
    "name": "Acâş",
    "lat": "47.53333",
    "lng": "22.78333"
  },
  {
    "country": "RO",
    "name": "Acăţari",
    "lat": "46.47975",
    "lng": "24.63324"
  },
  {
    "country": "RO",
    "name": "Abrud-Sat",
    "lat": "46.28166",
    "lng": "23.06098"
  },
  {
    "country": "RO",
    "name": "Abrud",
    "lat": "46.27406",
    "lng": "23.06339"
  },
  {
    "country": "RO",
    "name": "Abrămuţ",
    "lat": "47.31667",
    "lng": "22.25"
  },
  {
    "country": "RO",
    "name": "Abram",
    "lat": "47.31667",
    "lng": "22.38333"
  },
  {
    "country": "RO",
    "name": "1 Decembrie",
    "lat": "44.29083",
    "lng": "26.05806"
  },
  {
    "country": "RO",
    "name": "Vrani",
    "lat": "45.03833",
    "lng": "21.4925"
  },
  {
    "country": "RO",
    "name": "Vetrişoaia",
    "lat": "46.43",
    "lng": "28.20833"
  },
  {
    "country": "RO",
    "name": "Moieciu de Jos",
    "lat": "45.50313",
    "lng": "25.33719"
  },
  {
    "country": "RO",
    "name": "Bucuresti",
    "lat": "44.42802",
    "lng": "26.09665"
  },
  {
    "country": "RO",
    "name": "Mârșa",
    "lat": "45.70002",
    "lng": "24.37046"
  },
  {
    "country": "RO",
    "name": "Paşcani",
    "lat": "47.2469",
    "lng": "26.72291"
  },
  {
    "country": "RO",
    "name": "Dorna-Arini",
    "lat": "47.33832",
    "lng": "25.4074"
  },
  {
    "country": "RO",
    "name": "Mioveni",
    "lat": "44.95905",
    "lng": "24.94198"
  },
  {
    "country": "RO",
    "name": "Uileacu de Beiuș",
    "lat": "46.68532",
    "lng": "22.22148"
  },
  {
    "country": "RO",
    "name": "Albeştii de Argeş",
    "lat": "45.21667",
    "lng": "24.66667"
  },
  {
    "country": "RO",
    "name": "Crișan",
    "lat": "45.17462",
    "lng": "29.38598"
  },
  {
    "country": "RO",
    "name": "Horea",
    "lat": "46.50246",
    "lng": "22.95034"
  },
  {
    "country": "RO",
    "name": "Frumușeni",
    "lat": "46.10252",
    "lng": "21.46167"
  },
  {
    "country": "RO",
    "name": "Dragoslavele",
    "lat": "45.34801",
    "lng": "25.16925"
  },
  {
    "country": "RO",
    "name": "Sighișoara",
    "lat": "46.22141",
    "lng": "24.79279"
  },
  {
    "country": "RO",
    "name": "Slobozia",
    "lat": "44.5647",
    "lng": "27.3633"
  },
  {
    "country": "RO",
    "name": "Vințu de Jos",
    "lat": "45.99462",
    "lng": "23.48612"
  },
  {
    "country": "RO",
    "name": "Făgetu",
    "lat": "44.90616",
    "lng": "24.91159"
  },
  {
    "country": "RO",
    "name": "Poienari",
    "lat": "45.07034",
    "lng": "24.53056"
  },
  {
    "country": "RO",
    "name": "Oarja",
    "lat": "44.76053",
    "lng": "24.97596"
  },
  {
    "country": "RO",
    "name": "Bijghir",
    "lat": "46.60185",
    "lng": "27.01859"
  },
  {
    "country": "RO",
    "name": "Izvoarele",
    "lat": "45.28376",
    "lng": "26.00119"
  },
  {
    "country": "RO",
    "name": "Sâniob",
    "lat": "47.26461",
    "lng": "22.12778"
  },
  {
    "country": "RO",
    "name": "Baranca",
    "lat": "48.19651",
    "lng": "26.47893"
  },
  {
    "country": "RO",
    "name": "Ungureni",
    "lat": "47.88176",
    "lng": "26.79899"
  },
  {
    "country": "RO",
    "name": "Racoș",
    "lat": "46.02524",
    "lng": "25.41075"
  },
  {
    "country": "RO",
    "name": "Gropeni",
    "lat": "45.07547",
    "lng": "27.87969"
  },
  {
    "country": "RO",
    "name": "Smârdan",
    "lat": "45.2867",
    "lng": "28.00368"
  },
  {
    "country": "RO",
    "name": "Constantin Brâncoveanu",
    "lat": "44.47842",
    "lng": "27.41274"
  },
  {
    "country": "RO",
    "name": "Bonțida",
    "lat": "46.9155",
    "lng": "23.81475"
  },
  {
    "country": "RO",
    "name": "Luna",
    "lat": "46.50659",
    "lng": "23.91959"
  },
  {
    "country": "RO",
    "name": "Culmea",
    "lat": "44.25759",
    "lng": "28.46643"
  },
  {
    "country": "RO",
    "name": "Valea Voievozilor",
    "lat": "44.93805",
    "lng": "25.48518"
  },
  {
    "country": "RO",
    "name": "Ocolna",
    "lat": "43.87917",
    "lng": "24.13405"
  },
  {
    "country": "RO",
    "name": "Hulubești",
    "lat": "44.16748",
    "lng": "25.94146"
  },
  {
    "country": "RO",
    "name": "Gurasada",
    "lat": "45.95483",
    "lng": "22.59491"
  },
  {
    "country": "RO",
    "name": "Gheorghe Doja",
    "lat": "44.61622",
    "lng": "27.1874"
  },
  {
    "country": "RO",
    "name": "Toaca",
    "lat": "46.79975",
    "lng": "24.9641"
  },
  {
    "country": "RO",
    "name": "Horia",
    "lat": "46.90698",
    "lng": "26.91919"
  },
  {
    "country": "RO",
    "name": "Ion Creangă",
    "lat": "46.87029",
    "lng": "26.98023"
  },
  {
    "country": "RO",
    "name": "Urzica",
    "lat": "43.8567",
    "lng": "24.28952"
  },
  {
    "country": "RO",
    "name": "Plopeni",
    "lat": "45.06552",
    "lng": "25.98114"
  },
  {
    "country": "RO",
    "name": "Tarna Mare",
    "lat": "48.09175",
    "lng": "23.19369"
  },
  {
    "country": "RO",
    "name": "Călmățuiu de Sus",
    "lat": "44.02632",
    "lng": "24.8123"
  },
  {
    "country": "RO",
    "name": "Drăcșenei",
    "lat": "44.22676",
    "lng": "24.98542"
  },
  {
    "country": "RO",
    "name": "I. C. Brătianu",
    "lat": "45.40581",
    "lng": "28.05381"
  },
  {
    "country": "RO",
    "name": "Maliuc",
    "lat": "45.17678",
    "lng": "29.11334"
  },
  {
    "country": "RO",
    "name": "Sector 1",
    "lat": "44.49239",
    "lng": "26.04831"
  },
  {
    "country": "RO",
    "name": "Sector 2",
    "lat": "44.4528",
    "lng": "26.13321"
  },
  {
    "country": "RO",
    "name": "Sector 3",
    "lat": "44.4234",
    "lng": "26.16874"
  },
  {
    "country": "RO",
    "name": "Sector 4",
    "lat": "44.37571",
    "lng": "26.12085"
  },
  {
    "country": "RO",
    "name": "Sector 5",
    "lat": "44.38808",
    "lng": "26.07144"
  },
  {
    "country": "RO",
    "name": "Sector 6",
    "lat": "44.43579",
    "lng": "26.01649"
  },
  {
    "country": "RS",
    "name": "Zvečka",
    "lat": "44.64025",
    "lng": "20.16432"
  },
  {
    "country": "RS",
    "name": "Žujince",
    "lat": "42.31568",
    "lng": "21.70212"
  },
  {
    "country": "RS",
    "name": "Zrenjanin",
    "lat": "45.38361",
    "lng": "20.38194"
  },
  {
    "country": "RS",
    "name": "Žitorađa",
    "lat": "43.19",
    "lng": "21.71306"
  },
  {
    "country": "RS",
    "name": "Žitište",
    "lat": "45.485",
    "lng": "20.54972"
  },
  {
    "country": "RS",
    "name": "Zemun",
    "lat": "44.84306",
    "lng": "20.40111"
  },
  {
    "country": "RS",
    "name": "Zaječar",
    "lat": "43.90358",
    "lng": "22.26405"
  },
  {
    "country": "RS",
    "name": "Žagubica",
    "lat": "44.19685",
    "lng": "21.78838"
  },
  {
    "country": "RS",
    "name": "Žabari",
    "lat": "44.35611",
    "lng": "21.215"
  },
  {
    "country": "RS",
    "name": "Žabalj",
    "lat": "45.37222",
    "lng": "20.06389"
  },
  {
    "country": "RS",
    "name": "Vršac",
    "lat": "45.11667",
    "lng": "21.30361"
  },
  {
    "country": "RS",
    "name": "Vrnjačka Banja",
    "lat": "43.62725",
    "lng": "20.89634"
  },
  {
    "country": "RS",
    "name": "Vranjska Banja",
    "lat": "42.555",
    "lng": "21.99222"
  },
  {
    "country": "RS",
    "name": "Vranje",
    "lat": "42.55139",
    "lng": "21.90028"
  },
  {
    "country": "RS",
    "name": "Vranić",
    "lat": "44.60237",
    "lng": "20.32872"
  },
  {
    "country": "RS",
    "name": "Vračar",
    "lat": "44.79256",
    "lng": "20.47491"
  },
  {
    "country": "RS",
    "name": "Vojvoda Stepa",
    "lat": "45.68537",
    "lng": "20.65536"
  },
  {
    "country": "RS",
    "name": "Vojka",
    "lat": "44.93713",
    "lng": "20.15236"
  },
  {
    "country": "RS",
    "name": "Vlasotince",
    "lat": "42.96697",
    "lng": "22.13402"
  },
  {
    "country": "RS",
    "name": "Vlajkovac",
    "lat": "45.07207",
    "lng": "21.19945"
  },
  {
    "country": "RS",
    "name": "Vladimirovac",
    "lat": "45.03122",
    "lng": "20.86566"
  },
  {
    "country": "RS",
    "name": "Vladičin Han",
    "lat": "42.70778",
    "lng": "22.06333"
  },
  {
    "country": "RS",
    "name": "Vilovo",
    "lat": "45.24859",
    "lng": "20.15521"
  },
  {
    "country": "RS",
    "name": "Veliko Središte",
    "lat": "45.17919",
    "lng": "21.40353"
  },
  {
    "country": "RS",
    "name": "Veliko Gradište",
    "lat": "44.76203",
    "lng": "21.51578"
  },
  {
    "country": "RS",
    "name": "Veliki Gaj",
    "lat": "45.28849",
    "lng": "21.17057"
  },
  {
    "country": "RS",
    "name": "Aleksandrovo",
    "lat": "45.63755",
    "lng": "20.59288"
  },
  {
    "country": "RS",
    "name": "Velika Plana",
    "lat": "44.33389",
    "lng": "21.07676"
  },
  {
    "country": "RS",
    "name": "Velika Moštanica",
    "lat": "44.66486",
    "lng": "20.35395"
  },
  {
    "country": "RS",
    "name": "Velika Greda",
    "lat": "45.24376",
    "lng": "21.03498"
  },
  {
    "country": "RS",
    "name": "Varvarin",
    "lat": "43.72397",
    "lng": "21.3624"
  },
  {
    "country": "RS",
    "name": "Uzdin",
    "lat": "45.20512",
    "lng": "20.62342"
  },
  {
    "country": "RS",
    "name": "Umka",
    "lat": "44.67806",
    "lng": "20.30472"
  },
  {
    "country": "RS",
    "name": "Uljma",
    "lat": "45.04213",
    "lng": "21.15393"
  },
  {
    "country": "RS",
    "name": "Ugrinovci",
    "lat": "44.87635",
    "lng": "20.18763"
  },
  {
    "country": "RS",
    "name": "Ub",
    "lat": "44.45611",
    "lng": "20.07389"
  },
  {
    "country": "RS",
    "name": "Tutin",
    "lat": "42.99028",
    "lng": "20.33139"
  },
  {
    "country": "RS",
    "name": "Turija",
    "lat": "44.52273",
    "lng": "21.63945"
  },
  {
    "country": "RS",
    "name": "Trstenik",
    "lat": "43.61694",
    "lng": "21.0025"
  },
  {
    "country": "RS",
    "name": "Trgovište",
    "lat": "42.36417",
    "lng": "22.0825"
  },
  {
    "country": "RS",
    "name": "Torda",
    "lat": "45.58423",
    "lng": "20.459"
  },
  {
    "country": "RS",
    "name": "Topola",
    "lat": "44.25417",
    "lng": "20.6825"
  },
  {
    "country": "RS",
    "name": "Tomaševac",
    "lat": "45.26855",
    "lng": "20.62272"
  },
  {
    "country": "RS",
    "name": "Toba",
    "lat": "45.68943",
    "lng": "20.55714"
  },
  {
    "country": "RS",
    "name": "Titel",
    "lat": "45.20611",
    "lng": "20.29444"
  },
  {
    "country": "RS",
    "name": "Taraš",
    "lat": "45.46737",
    "lng": "20.19867"
  },
  {
    "country": "RS",
    "name": "Svrljig",
    "lat": "43.41333",
    "lng": "22.12111"
  },
  {
    "country": "RS",
    "name": "Svilajnac",
    "lat": "44.2337",
    "lng": "21.1967"
  },
  {
    "country": "RS",
    "name": "Sutjeska",
    "lat": "45.38312",
    "lng": "20.6962"
  },
  {
    "country": "RS",
    "name": "Surdulica",
    "lat": "42.69056",
    "lng": "22.17083"
  },
  {
    "country": "RS",
    "name": "Surduk",
    "lat": "45.07474",
    "lng": "20.31898"
  },
  {
    "country": "RS",
    "name": "Surčin",
    "lat": "44.79306",
    "lng": "20.28028"
  },
  {
    "country": "RS",
    "name": "Stubline",
    "lat": "44.57476",
    "lng": "20.13477"
  },
  {
    "country": "RS",
    "name": "Stepojevac",
    "lat": "44.51278",
    "lng": "20.295"
  },
  {
    "country": "RS",
    "name": "Stari Lec",
    "lat": "45.28401",
    "lng": "20.96433"
  },
  {
    "country": "RS",
    "name": "Stari Banovci",
    "lat": "44.9842",
    "lng": "20.28382"
  },
  {
    "country": "RS",
    "name": "Stara Pazova",
    "lat": "44.985",
    "lng": "20.16083"
  },
  {
    "country": "RS",
    "name": "Stajićevo",
    "lat": "45.29489",
    "lng": "20.45845"
  },
  {
    "country": "RS",
    "name": "Srpski Itebej",
    "lat": "45.56715",
    "lng": "20.7135"
  },
  {
    "country": "RS",
    "name": "Srpska Crnja",
    "lat": "45.72538",
    "lng": "20.69008"
  },
  {
    "country": "RS",
    "name": "Sremčica",
    "lat": "44.67653",
    "lng": "20.39232"
  },
  {
    "country": "RS",
    "name": "Sopot",
    "lat": "44.51972",
    "lng": "20.57361"
  },
  {
    "country": "RS",
    "name": "Soko Banja",
    "lat": "43.64333",
    "lng": "21.87111"
  },
  {
    "country": "RS",
    "name": "Smederevska Palanka",
    "lat": "44.36548",
    "lng": "20.95885"
  },
  {
    "country": "RS",
    "name": "Smederevo",
    "lat": "44.66278",
    "lng": "20.93"
  },
  {
    "country": "RS",
    "name": "Šimanovci",
    "lat": "44.87393",
    "lng": "20.09175"
  },
  {
    "country": "RS",
    "name": "Ševica",
    "lat": "44.50883",
    "lng": "21.72296"
  },
  {
    "country": "RS",
    "name": "Senta",
    "lat": "45.9275",
    "lng": "20.07722"
  },
  {
    "country": "RS",
    "name": "Seleuš",
    "lat": "45.1277",
    "lng": "20.91461"
  },
  {
    "country": "RS",
    "name": "Sefkerin",
    "lat": "45.00501",
    "lng": "20.48256"
  },
  {
    "country": "RS",
    "name": "Sečanj",
    "lat": "45.36667",
    "lng": "20.77222"
  },
  {
    "country": "RS",
    "name": "Sanad",
    "lat": "45.97596",
    "lng": "20.10816"
  },
  {
    "country": "RS",
    "name": "Samoš",
    "lat": "45.20255",
    "lng": "20.77392"
  },
  {
    "country": "RS",
    "name": "Samoljica",
    "lat": "42.38445",
    "lng": "21.73708"
  },
  {
    "country": "RS",
    "name": "Sakule",
    "lat": "45.14667",
    "lng": "20.48619"
  },
  {
    "country": "RS",
    "name": "Šajkaš",
    "lat": "45.27315",
    "lng": "20.09051"
  },
  {
    "country": "RS",
    "name": "Sajan",
    "lat": "45.84227",
    "lng": "20.27815"
  },
  {
    "country": "RS",
    "name": "Rušanj",
    "lat": "44.68477",
    "lng": "20.44993"
  },
  {
    "country": "RS",
    "name": "Rekovac",
    "lat": "43.863",
    "lng": "21.09345"
  },
  {
    "country": "RS",
    "name": "Ražanj",
    "lat": "43.67222",
    "lng": "21.54944"
  },
  {
    "country": "RS",
    "name": "Ravni Topolovac",
    "lat": "45.46082",
    "lng": "20.56939"
  },
  {
    "country": "RS",
    "name": "Rakovica",
    "lat": "44.74194",
    "lng": "20.44139"
  },
  {
    "country": "RS",
    "name": "Rajince",
    "lat": "42.3787",
    "lng": "21.69591"
  },
  {
    "country": "RS",
    "name": "Radovnica",
    "lat": "42.43364",
    "lng": "22.22861"
  },
  {
    "country": "RS",
    "name": "Radojevo",
    "lat": "45.74617",
    "lng": "20.78917"
  },
  {
    "country": "RS",
    "name": "Radenka",
    "lat": "44.58345",
    "lng": "21.76469"
  },
  {
    "country": "RS",
    "name": "Rača",
    "lat": "44.22712",
    "lng": "20.97754"
  },
  {
    "country": "RS",
    "name": "Prokuplje",
    "lat": "43.23417",
    "lng": "21.58806"
  },
  {
    "country": "RS",
    "name": "Preševo",
    "lat": "42.30917",
    "lng": "21.64917"
  },
  {
    "country": "RS",
    "name": "Požega",
    "lat": "43.84889",
    "lng": "20.03632"
  },
  {
    "country": "RS",
    "name": "Požarevac",
    "lat": "44.62133",
    "lng": "21.18782"
  },
  {
    "country": "RS",
    "name": "Plandište",
    "lat": "45.22722",
    "lng": "21.12167"
  },
  {
    "country": "RS",
    "name": "Pirot",
    "lat": "43.15306",
    "lng": "22.58611"
  },
  {
    "country": "RS",
    "name": "Petrovac",
    "lat": "44.37694",
    "lng": "21.41917"
  },
  {
    "country": "RS",
    "name": "Perlez",
    "lat": "45.20813",
    "lng": "20.38197"
  },
  {
    "country": "RS",
    "name": "Pavliš",
    "lat": "45.10569",
    "lng": "21.23952"
  },
  {
    "country": "RS",
    "name": "Paraćin",
    "lat": "43.86083",
    "lng": "21.40778"
  },
  {
    "country": "RS",
    "name": "Pančevo",
    "lat": "44.87083",
    "lng": "20.64028"
  },
  {
    "country": "RS",
    "name": "Padina",
    "lat": "45.11988",
    "lng": "20.7286"
  },
  {
    "country": "RS",
    "name": "Padej",
    "lat": "45.82756",
    "lng": "20.16279"
  },
  {
    "country": "RS",
    "name": "Ovča",
    "lat": "44.88349",
    "lng": "20.53336"
  },
  {
    "country": "RS",
    "name": "Ostružnica",
    "lat": "44.72769",
    "lng": "20.31845"
  },
  {
    "country": "RS",
    "name": "Ostojićevo",
    "lat": "45.88863",
    "lng": "20.16642"
  },
  {
    "country": "RS",
    "name": "Orlovat",
    "lat": "45.24171",
    "lng": "20.58089"
  },
  {
    "country": "RS",
    "name": "Opovo",
    "lat": "45.05222",
    "lng": "20.43028"
  },
  {
    "country": "RS",
    "name": "Obrenovac",
    "lat": "44.65486",
    "lng": "20.20017"
  },
  {
    "country": "RS",
    "name": "Novo Miloševo",
    "lat": "45.71916",
    "lng": "20.30364"
  },
  {
    "country": "RS",
    "name": "Novi Slankamen",
    "lat": "45.12554",
    "lng": "20.23914"
  },
  {
    "country": "RS",
    "name": "Novi Pazar",
    "lat": "43.13667",
    "lng": "20.51222"
  },
  {
    "country": "RS",
    "name": "Kozjak",
    "lat": "45.18264",
    "lng": "20.86381"
  },
  {
    "country": "RS",
    "name": "Novi Kozarci",
    "lat": "45.78241",
    "lng": "20.62289"
  },
  {
    "country": "RS",
    "name": "Novi Kneževac",
    "lat": "46.05",
    "lng": "20.1"
  },
  {
    "country": "RS",
    "name": "Novi Karlovci",
    "lat": "45.07636",
    "lng": "20.17948"
  },
  {
    "country": "RS",
    "name": "Novi Itebej",
    "lat": "45.55918",
    "lng": "20.7003"
  },
  {
    "country": "RS",
    "name": "Novi Beograd",
    "lat": "44.80556",
    "lng": "20.42417"
  },
  {
    "country": "RS",
    "name": "Novi Bečej",
    "lat": "45.59861",
    "lng": "20.13556"
  },
  {
    "country": "RS",
    "name": "Novi Banovci",
    "lat": "44.95561",
    "lng": "20.28025"
  },
  {
    "country": "RS",
    "name": "Nova Pazova",
    "lat": "44.94366",
    "lng": "20.21931"
  },
  {
    "country": "RS",
    "name": "Nova Crnja",
    "lat": "45.66833",
    "lng": "20.605"
  },
  {
    "country": "RS",
    "name": "Niš",
    "lat": "43.32472",
    "lng": "21.90333"
  },
  {
    "country": "RS",
    "name": "Nikolinci",
    "lat": "45.05245",
    "lng": "21.06695"
  },
  {
    "country": "RS",
    "name": "Neuzina",
    "lat": "45.3446",
    "lng": "20.71418"
  },
  {
    "country": "RS",
    "name": "Negotin",
    "lat": "44.22639",
    "lng": "22.53083"
  },
  {
    "country": "RS",
    "name": "Nakovo",
    "lat": "45.87503",
    "lng": "20.56709"
  },
  {
    "country": "RS",
    "name": "Adorjan",
    "lat": "46.00333",
    "lng": "20.04007"
  },
  {
    "country": "RS",
    "name": "Mošorin",
    "lat": "45.30196",
    "lng": "20.16919"
  },
  {
    "country": "RS",
    "name": "Mol",
    "lat": "45.76457",
    "lng": "20.13286"
  },
  {
    "country": "RS",
    "name": "Mokrin",
    "lat": "45.93362",
    "lng": "20.41215"
  },
  {
    "country": "RS",
    "name": "Mladenovac",
    "lat": "44.43861",
    "lng": "20.69917"
  },
  {
    "country": "RS",
    "name": "Miratovac",
    "lat": "42.25846",
    "lng": "21.66456"
  },
  {
    "country": "RS",
    "name": "Mionica",
    "lat": "44.25194",
    "lng": "20.08167"
  },
  {
    "country": "RS",
    "name": "Mihajlovo",
    "lat": "45.47085",
    "lng": "20.41508"
  },
  {
    "country": "RS",
    "name": "Merošina",
    "lat": "43.28358",
    "lng": "21.7204"
  },
  {
    "country": "RS",
    "name": "Melenci",
    "lat": "45.5168",
    "lng": "20.31961"
  },
  {
    "country": "RS",
    "name": "Medveđa",
    "lat": "42.84306",
    "lng": "21.58333"
  },
  {
    "country": "RS",
    "name": "Međa",
    "lat": "45.53815",
    "lng": "20.80677"
  },
  {
    "country": "RS",
    "name": "Margita",
    "lat": "45.21598",
    "lng": "21.17527"
  },
  {
    "country": "RS",
    "name": "Malo Crniće",
    "lat": "44.55611",
    "lng": "21.28556"
  },
  {
    "country": "RS",
    "name": "Mala Moštanica",
    "lat": "44.63834",
    "lng": "20.306"
  },
  {
    "country": "RS",
    "name": "Majdanpek",
    "lat": "44.42771",
    "lng": "21.94596"
  },
  {
    "country": "RS",
    "name": "Lukićevo",
    "lat": "45.33815",
    "lng": "20.49895"
  },
  {
    "country": "RS",
    "name": "Lugavčina",
    "lat": "44.52314",
    "lng": "21.07083"
  },
  {
    "country": "RS",
    "name": "Lučani",
    "lat": "43.86083",
    "lng": "20.13806"
  },
  {
    "country": "RS",
    "name": "Lokve",
    "lat": "45.15198",
    "lng": "21.03073"
  },
  {
    "country": "RS",
    "name": "Lok",
    "lat": "45.21583",
    "lng": "20.21222"
  },
  {
    "country": "RS",
    "name": "Ljukovo",
    "lat": "45.02604",
    "lng": "20.02737"
  },
  {
    "country": "RS",
    "name": "Ljig",
    "lat": "44.23007",
    "lng": "20.23819"
  },
  {
    "country": "RS",
    "name": "Leskovac",
    "lat": "42.99806",
    "lng": "21.94611"
  },
  {
    "country": "RS",
    "name": "Lebane",
    "lat": "42.92389",
    "lng": "21.7375"
  },
  {
    "country": "RS",
    "name": "Lazarevo",
    "lat": "45.38893",
    "lng": "20.53999"
  },
  {
    "country": "RS",
    "name": "Lazarevac",
    "lat": "44.38534",
    "lng": "20.2557"
  },
  {
    "country": "RS",
    "name": "Lapovo",
    "lat": "44.18424",
    "lng": "21.09727"
  },
  {
    "country": "RS",
    "name": "Lajkovac",
    "lat": "44.36944",
    "lng": "20.16528"
  },
  {
    "country": "RS",
    "name": "Kuštilj",
    "lat": "45.03487",
    "lng": "21.37989"
  },
  {
    "country": "RS",
    "name": "Kuršumlija",
    "lat": "43.13826",
    "lng": "21.27339"
  },
  {
    "country": "RS",
    "name": "Kupinovo",
    "lat": "44.70708",
    "lng": "20.04959"
  },
  {
    "country": "RS",
    "name": "Kumane",
    "lat": "45.53946",
    "lng": "20.22902"
  },
  {
    "country": "RS",
    "name": "Kučevo",
    "lat": "44.4775",
    "lng": "21.67"
  },
  {
    "country": "RS",
    "name": "Kruševac",
    "lat": "43.58",
    "lng": "21.33389"
  },
  {
    "country": "RS",
    "name": "Krčedin",
    "lat": "45.13871",
    "lng": "20.13308"
  },
  {
    "country": "RS",
    "name": "Kraljevo",
    "lat": "43.72583",
    "lng": "20.68944"
  },
  {
    "country": "RS",
    "name": "Krajišnik",
    "lat": "45.45283",
    "lng": "20.72976"
  },
  {
    "country": "RS",
    "name": "Kragujevac",
    "lat": "44.01667",
    "lng": "20.91667"
  },
  {
    "country": "RS",
    "name": "Kovin",
    "lat": "44.7475",
    "lng": "20.97611"
  },
  {
    "country": "RS",
    "name": "Kovilj",
    "lat": "45.23422",
    "lng": "20.02327"
  },
  {
    "country": "RS",
    "name": "Kovačica",
    "lat": "45.11167",
    "lng": "20.62139"
  },
  {
    "country": "RS",
    "name": "Konak",
    "lat": "45.31575",
    "lng": "20.91468"
  },
  {
    "country": "RS",
    "name": "Knićanin",
    "lat": "45.18675",
    "lng": "20.319"
  },
  {
    "country": "RS",
    "name": "Klek",
    "lat": "45.42254",
    "lng": "20.48049"
  },
  {
    "country": "RS",
    "name": "Kladovo",
    "lat": "44.60667",
    "lng": "22.61194"
  },
  {
    "country": "RS",
    "name": "Kikinda",
    "lat": "45.82972",
    "lng": "20.46528"
  },
  {
    "country": "RS",
    "name": "Kanjiža",
    "lat": "46.06667",
    "lng": "20.05"
  },
  {
    "country": "RS",
    "name": "Jermenovci",
    "lat": "45.18635",
    "lng": "21.0455"
  },
  {
    "country": "RS",
    "name": "Jazovo",
    "lat": "45.89876",
    "lng": "20.2213"
  },
  {
    "country": "RS",
    "name": "Jaša Tomić",
    "lat": "45.44725",
    "lng": "20.85546"
  },
  {
    "country": "RS",
    "name": "Jarkovac",
    "lat": "45.26985",
    "lng": "20.76078"
  },
  {
    "country": "RS",
    "name": "Janošik",
    "lat": "45.17141",
    "lng": "21.00658"
  },
  {
    "country": "RS",
    "name": "Jagodina",
    "lat": "43.97713",
    "lng": "21.26121"
  },
  {
    "country": "RS",
    "name": "Izbište",
    "lat": "45.02253",
    "lng": "21.18388"
  },
  {
    "country": "RS",
    "name": "Ivanjica",
    "lat": "43.58028",
    "lng": "20.23111"
  },
  {
    "country": "RS",
    "name": "Inđija",
    "lat": "45.04816",
    "lng": "20.08165"
  },
  {
    "country": "RS",
    "name": "Ilandža",
    "lat": "45.16897",
    "lng": "20.92008"
  },
  {
    "country": "RS",
    "name": "Idvor",
    "lat": "45.18895",
    "lng": "20.51442"
  },
  {
    "country": "RS",
    "name": "Tiszahegyes",
    "lat": "45.82648",
    "lng": "20.31791"
  },
  {
    "country": "RS",
    "name": "Hetin",
    "lat": "45.66202",
    "lng": "20.79138"
  },
  {
    "country": "RS",
    "name": "Hajdučica",
    "lat": "45.2501",
    "lng": "20.96016"
  },
  {
    "country": "RS",
    "name": "Gudurica",
    "lat": "45.16816",
    "lng": "21.44264"
  },
  {
    "country": "RS",
    "name": "Grocka",
    "lat": "44.67222",
    "lng": "20.7175"
  },
  {
    "country": "RS",
    "name": "Grabovac",
    "lat": "44.60049",
    "lng": "20.08539"
  },
  {
    "country": "RS",
    "name": "Gornji Milanovac",
    "lat": "44.02603",
    "lng": "20.46152"
  },
  {
    "country": "RS",
    "name": "Gornji Breg",
    "lat": "45.91995",
    "lng": "20.01766"
  },
  {
    "country": "RS",
    "name": "Golubinci",
    "lat": "44.98533",
    "lng": "20.06339"
  },
  {
    "country": "RS",
    "name": "Golubac",
    "lat": "44.65296",
    "lng": "21.63199"
  },
  {
    "country": "RS",
    "name": "Gardinovci",
    "lat": "45.20359",
    "lng": "20.13558"
  },
  {
    "country": "RS",
    "name": "Gadžin Han",
    "lat": "43.22278",
    "lng": "22.03194"
  },
  {
    "country": "RS",
    "name": "Farkaždin",
    "lat": "45.19172",
    "lng": "20.47239"
  },
  {
    "country": "RS",
    "name": "Elemir",
    "lat": "45.44263",
    "lng": "20.30003"
  },
  {
    "country": "RS",
    "name": "Ečka",
    "lat": "45.32328",
    "lng": "20.44294"
  },
  {
    "country": "RS",
    "name": "Ðurđevo",
    "lat": "45.32591",
    "lng": "20.06532"
  },
  {
    "country": "RS",
    "name": "Duboka",
    "lat": "44.52223",
    "lng": "21.7603"
  },
  {
    "country": "RS",
    "name": "Donji Milanovac",
    "lat": "44.46417",
    "lng": "22.15217"
  },
  {
    "country": "RS",
    "name": "Doljevac",
    "lat": "43.19817",
    "lng": "21.83258"
  },
  {
    "country": "RS",
    "name": "Dobrica",
    "lat": "45.21339",
    "lng": "20.84995"
  },
  {
    "country": "RS",
    "name": "Dobanovci",
    "lat": "44.82631",
    "lng": "20.22487"
  },
  {
    "country": "RS",
    "name": "Dimitrovgrad",
    "lat": "43.01417",
    "lng": "22.77556"
  },
  {
    "country": "RS",
    "name": "Despotovac",
    "lat": "44.0925",
    "lng": "21.44694"
  },
  {
    "country": "RS",
    "name": "Debeljača",
    "lat": "45.0707",
    "lng": "20.60153"
  },
  {
    "country": "RS",
    "name": "Čurug",
    "lat": "45.47221",
    "lng": "20.06861"
  },
  {
    "country": "RS",
    "name": "Ćuprija",
    "lat": "43.9275",
    "lng": "21.37"
  },
  {
    "country": "RS",
    "name": "Čukarica",
    "lat": "44.7825",
    "lng": "20.42028"
  },
  {
    "country": "RS",
    "name": "Crna Trava",
    "lat": "42.80988",
    "lng": "22.29881"
  },
  {
    "country": "RS",
    "name": "Crepaja",
    "lat": "45.00984",
    "lng": "20.63702"
  },
  {
    "country": "RS",
    "name": "Čortanovci",
    "lat": "45.1546",
    "lng": "20.01851"
  },
  {
    "country": "RS",
    "name": "Čoka",
    "lat": "45.9425",
    "lng": "20.14333"
  },
  {
    "country": "RS",
    "name": "Ćićevac",
    "lat": "43.71882",
    "lng": "21.44085"
  },
  {
    "country": "RS",
    "name": "Čestereg",
    "lat": "45.56361",
    "lng": "20.53194"
  },
  {
    "country": "RS",
    "name": "Čenta",
    "lat": "45.10814",
    "lng": "20.38947"
  },
  {
    "country": "RS",
    "name": "Čačak",
    "lat": "43.89139",
    "lng": "20.34972"
  },
  {
    "country": "RS",
    "name": "Bujanovac",
    "lat": "42.45917",
    "lng": "21.76667"
  },
  {
    "country": "RS",
    "name": "Botoš",
    "lat": "45.30837",
    "lng": "20.63514"
  },
  {
    "country": "RS",
    "name": "Bosilegrad",
    "lat": "42.5011",
    "lng": "22.47238"
  },
  {
    "country": "RS",
    "name": "Bor",
    "lat": "44.07488",
    "lng": "22.09591"
  },
  {
    "country": "RS",
    "name": "Boljevci",
    "lat": "44.72355",
    "lng": "20.22348"
  },
  {
    "country": "RS",
    "name": "Boljevac",
    "lat": "43.83028",
    "lng": "21.95306"
  },
  {
    "country": "RS",
    "name": "Boka",
    "lat": "45.3554",
    "lng": "20.82987"
  },
  {
    "country": "RS",
    "name": "Bojnik",
    "lat": "43.01224",
    "lng": "21.721"
  },
  {
    "country": "RS",
    "name": "Bočar",
    "lat": "45.76994",
    "lng": "20.2839"
  },
  {
    "country": "RS",
    "name": "Blace",
    "lat": "43.29528",
    "lng": "21.28583"
  },
  {
    "country": "RS",
    "name": "Biljača",
    "lat": "42.35518",
    "lng": "21.74781"
  },
  {
    "country": "RS",
    "name": "Beška",
    "lat": "45.13092",
    "lng": "20.06698"
  },
  {
    "country": "RS",
    "name": "Belgrade",
    "lat": "44.80401",
    "lng": "20.46513"
  },
  {
    "country": "RS",
    "name": "Belo Blato",
    "lat": "45.27278",
    "lng": "20.375"
  },
  {
    "country": "RS",
    "name": "Belegiš",
    "lat": "45.01873",
    "lng": "20.33212"
  },
  {
    "country": "RS",
    "name": "Bela Palanka",
    "lat": "43.21833",
    "lng": "22.31111"
  },
  {
    "country": "RS",
    "name": "Bela Crkva",
    "lat": "44.8975",
    "lng": "21.41722"
  },
  {
    "country": "RS",
    "name": "Torak",
    "lat": "45.50928",
    "lng": "20.609"
  },
  {
    "country": "RS",
    "name": "Bečmen",
    "lat": "44.77983",
    "lng": "20.20577"
  },
  {
    "country": "RS",
    "name": "Bečej",
    "lat": "45.61632",
    "lng": "20.03331"
  },
  {
    "country": "RS",
    "name": "Batočina",
    "lat": "44.15361",
    "lng": "21.08167"
  },
  {
    "country": "RS",
    "name": "Bašaid",
    "lat": "45.64102",
    "lng": "20.41434"
  },
  {
    "country": "RS",
    "name": "Barice",
    "lat": "45.18189",
    "lng": "21.08279"
  },
  {
    "country": "RS",
    "name": "Barič",
    "lat": "44.6507",
    "lng": "20.25941"
  },
  {
    "country": "RS",
    "name": "Baranda",
    "lat": "45.08459",
    "lng": "20.44264"
  },
  {
    "country": "RS",
    "name": "Barajevo",
    "lat": "44.57889",
    "lng": "20.41583"
  },
  {
    "country": "RS",
    "name": "Banatsko Veliko Selo",
    "lat": "45.81961",
    "lng": "20.60772"
  },
  {
    "country": "RS",
    "name": "Banatsko Karađorđevo",
    "lat": "45.58693",
    "lng": "20.56421"
  },
  {
    "country": "RS",
    "name": "Banatski Karlovac",
    "lat": "45.04987",
    "lng": "21.018"
  },
  {
    "country": "RS",
    "name": "Banatski Dvor",
    "lat": "45.51866",
    "lng": "20.51146"
  },
  {
    "country": "RS",
    "name": "Banatski Despotovac",
    "lat": "45.36606",
    "lng": "20.66407"
  },
  {
    "country": "RS",
    "name": "Banatska Topola",
    "lat": "45.67248",
    "lng": "20.4653"
  },
  {
    "country": "RS",
    "name": "Bačko Petrovo Selo",
    "lat": "45.70681",
    "lng": "20.07928"
  },
  {
    "country": "RS",
    "name": "Bačko Gradište",
    "lat": "45.53271",
    "lng": "20.03082"
  },
  {
    "country": "RS",
    "name": "Arilje",
    "lat": "43.75306",
    "lng": "20.09556"
  },
  {
    "country": "RS",
    "name": "Aranđelovac",
    "lat": "44.30694",
    "lng": "20.56"
  },
  {
    "country": "RS",
    "name": "Aradac",
    "lat": "45.38346",
    "lng": "20.30137"
  },
  {
    "country": "RS",
    "name": "Alibunar",
    "lat": "45.08083",
    "lng": "20.96583"
  },
  {
    "country": "RS",
    "name": "Aleksinac",
    "lat": "43.54167",
    "lng": "21.70778"
  },
  {
    "country": "RS",
    "name": "Aleksandrovac",
    "lat": "43.45861",
    "lng": "21.0525"
  },
  {
    "country": "RS",
    "name": "Ada",
    "lat": "45.8025",
    "lng": "20.12583"
  },
  {
    "country": "RS",
    "name": "Raška",
    "lat": "43.28722",
    "lng": "20.61528"
  },
  {
    "country": "RS",
    "name": "Niška Banja",
    "lat": "43.29507",
    "lng": "22.0057"
  },
  {
    "country": "RS",
    "name": "Sokolovica",
    "lat": "43.21528",
    "lng": "20.31556"
  },
  {
    "country": "RS",
    "name": "Rusko Selo",
    "lat": "45.76291",
    "lng": "20.57117"
  },
  {
    "country": "RS",
    "name": "Voždovac",
    "lat": "44.77833",
    "lng": "20.47583"
  },
  {
    "country": "RS",
    "name": "Zvezdara",
    "lat": "44.77465",
    "lng": "20.53207"
  },
  {
    "country": "RS",
    "name": "Prislonica",
    "lat": "43.95223",
    "lng": "20.43521"
  },
  {
    "country": "RS",
    "name": "Knić",
    "lat": "43.92694",
    "lng": "20.71889"
  },
  {
    "country": "RS",
    "name": "Savski Venac",
    "lat": "44.77917",
    "lng": "20.45389"
  },
  {
    "country": "RS",
    "name": "Palilula",
    "lat": "44.81167",
    "lng": "20.51611"
  },
  {
    "country": "RS",
    "name": "Stari Grad",
    "lat": "44.81789",
    "lng": "20.46186"
  },
  {
    "country": "RS",
    "name": "Zminjak",
    "lat": "44.75711",
    "lng": "19.4707"
  },
  {
    "country": "RS",
    "name": "Zmajevo",
    "lat": "45.45408",
    "lng": "19.6905"
  },
  {
    "country": "RS",
    "name": "Vrdnik",
    "lat": "45.12174",
    "lng": "19.79227"
  },
  {
    "country": "RS",
    "name": "Vrbas",
    "lat": "45.57139",
    "lng": "19.64083"
  },
  {
    "country": "RS",
    "name": "Vladimirci",
    "lat": "44.61472",
    "lng": "19.78528"
  },
  {
    "country": "RS",
    "name": "Višnjićevo",
    "lat": "44.96731",
    "lng": "19.28993"
  },
  {
    "country": "RS",
    "name": "Veternik",
    "lat": "45.25446",
    "lng": "19.7588"
  },
  {
    "country": "RS",
    "name": "Varna",
    "lat": "44.67914",
    "lng": "19.6515"
  },
  {
    "country": "RS",
    "name": "Valjevo",
    "lat": "44.27513",
    "lng": "19.89821"
  },
  {
    "country": "RS",
    "name": "Uzveće",
    "lat": "44.87861",
    "lng": "19.60356"
  },
  {
    "country": "RS",
    "name": "Užice",
    "lat": "43.85861",
    "lng": "19.84878"
  },
  {
    "country": "RS",
    "name": "Tršić",
    "lat": "44.49502",
    "lng": "19.2649"
  },
  {
    "country": "RS",
    "name": "Temerin",
    "lat": "45.40861",
    "lng": "19.88917"
  },
  {
    "country": "RS",
    "name": "Tabanović",
    "lat": "44.82018",
    "lng": "19.64128"
  },
  {
    "country": "RS",
    "name": "Subotica",
    "lat": "46.1",
    "lng": "19.66667"
  },
  {
    "country": "RS",
    "name": "Štitar",
    "lat": "44.79415",
    "lng": "19.59529"
  },
  {
    "country": "RS",
    "name": "Stepanovićevo",
    "lat": "45.41369",
    "lng": "19.7"
  },
  {
    "country": "RS",
    "name": "Stanišić",
    "lat": "45.93895",
    "lng": "19.16709"
  },
  {
    "country": "RS",
    "name": "Sremski Karlovci",
    "lat": "45.2025",
    "lng": "19.93444"
  },
  {
    "country": "RS",
    "name": "Sremska Mitrovica",
    "lat": "44.97639",
    "lng": "19.61222"
  },
  {
    "country": "RS",
    "name": "Srbobran",
    "lat": "45.55389",
    "lng": "19.80278"
  },
  {
    "country": "RS",
    "name": "Sonta",
    "lat": "45.59427",
    "lng": "19.09719"
  },
  {
    "country": "RS",
    "name": "Sombor",
    "lat": "45.77417",
    "lng": "19.11222"
  },
  {
    "country": "RS",
    "name": "Sjenica",
    "lat": "43.27306",
    "lng": "19.99944"
  },
  {
    "country": "RS",
    "name": "Sinošević",
    "lat": "44.61503",
    "lng": "19.63601"
  },
  {
    "country": "RS",
    "name": "Šid",
    "lat": "45.12833",
    "lng": "19.22639"
  },
  {
    "country": "RS",
    "name": "Ševarice",
    "lat": "44.86704",
    "lng": "19.66006"
  },
  {
    "country": "RS",
    "name": "Šašinci",
    "lat": "44.96514",
    "lng": "19.74151"
  },
  {
    "country": "RS",
    "name": "Salaš Noćajski",
    "lat": "44.94722",
    "lng": "19.58611"
  },
  {
    "country": "RS",
    "name": "Salaš Crnobarski",
    "lat": "44.82843",
    "lng": "19.39437"
  },
  {
    "country": "RS",
    "name": "Šabac",
    "lat": "44.74667",
    "lng": "19.69"
  },
  {
    "country": "RS",
    "name": "Rumenka",
    "lat": "45.294",
    "lng": "19.74306"
  },
  {
    "country": "RS",
    "name": "Ruma",
    "lat": "45.00806",
    "lng": "19.82222"
  },
  {
    "country": "RS",
    "name": "Riđica",
    "lat": "45.99088",
    "lng": "19.10635"
  },
  {
    "country": "RS",
    "name": "Ribari",
    "lat": "44.70961",
    "lng": "19.42472"
  },
  {
    "country": "RS",
    "name": "Ravno Selo",
    "lat": "45.44967",
    "lng": "19.62097"
  },
  {
    "country": "RS",
    "name": "Ravnje",
    "lat": "44.94326",
    "lng": "19.4228"
  },
  {
    "country": "RS",
    "name": "Radenković",
    "lat": "44.92191",
    "lng": "19.49543"
  },
  {
    "country": "RS",
    "name": "Putinci",
    "lat": "44.99259",
    "lng": "19.97102"
  },
  {
    "country": "RS",
    "name": "Prnjavor",
    "lat": "44.70061",
    "lng": "19.38695"
  },
  {
    "country": "RS",
    "name": "Prijepolje",
    "lat": "43.38996",
    "lng": "19.6487"
  },
  {
    "country": "RS",
    "name": "Prigrevica",
    "lat": "45.67636",
    "lng": "19.08809"
  },
  {
    "country": "RS",
    "name": "Priboj",
    "lat": "43.58306",
    "lng": "19.52519"
  },
  {
    "country": "RS",
    "name": "Platičevo",
    "lat": "44.82213",
    "lng": "19.79487"
  },
  {
    "country": "RS",
    "name": "Petrovaradin",
    "lat": "45.24667",
    "lng": "19.87944"
  },
  {
    "country": "RS",
    "name": "Petkovica",
    "lat": "44.66627",
    "lng": "19.43923"
  },
  {
    "country": "RS",
    "name": "Pećinci",
    "lat": "44.90889",
    "lng": "19.96639"
  },
  {
    "country": "RS",
    "name": "Osečina",
    "lat": "44.37306",
    "lng": "19.60139"
  },
  {
    "country": "RS",
    "name": "Odžaci",
    "lat": "45.50667",
    "lng": "19.26111"
  },
  {
    "country": "RS",
    "name": "Obrovac",
    "lat": "45.32106",
    "lng": "19.35048"
  },
  {
    "country": "RS",
    "name": "Novo Selo",
    "lat": "44.67041",
    "lng": "19.34495"
  },
  {
    "country": "RS",
    "name": "Novi Sad",
    "lat": "45.25167",
    "lng": "19.83694"
  },
  {
    "country": "RS",
    "name": "Nova Varoš",
    "lat": "43.46056",
    "lng": "19.81139"
  },
  {
    "country": "RS",
    "name": "Nikinci",
    "lat": "44.85017",
    "lng": "19.82321"
  },
  {
    "country": "RS",
    "name": "Metković",
    "lat": "44.85617",
    "lng": "19.54654"
  },
  {
    "country": "RS",
    "name": "Mali Zvornik",
    "lat": "44.37344",
    "lng": "19.10651"
  },
  {
    "country": "RS",
    "name": "Mali Iđoš",
    "lat": "45.70833",
    "lng": "19.66528"
  },
  {
    "country": "RS",
    "name": "Majur",
    "lat": "44.77105",
    "lng": "19.65512"
  },
  {
    "country": "RS",
    "name": "Maglić",
    "lat": "45.36248",
    "lng": "19.53211"
  },
  {
    "country": "RS",
    "name": "Mačvanska Mitrovica",
    "lat": "44.96739",
    "lng": "19.59314"
  },
  {
    "country": "RS",
    "name": "Ljubovija",
    "lat": "44.18944",
    "lng": "19.37667"
  },
  {
    "country": "RS",
    "name": "Lipolist",
    "lat": "44.69783",
    "lng": "19.50101"
  },
  {
    "country": "RS",
    "name": "Lipnički Šor",
    "lat": "44.58058",
    "lng": "19.26572"
  },
  {
    "country": "RS",
    "name": "Lešnica",
    "lat": "44.6525",
    "lng": "19.31"
  },
  {
    "country": "RS",
    "name": "Kupusina",
    "lat": "45.73759",
    "lng": "19.01082"
  },
  {
    "country": "RS",
    "name": "Kulpin",
    "lat": "45.4024",
    "lng": "19.58814"
  },
  {
    "country": "RS",
    "name": "Kula",
    "lat": "45.60889",
    "lng": "19.52639"
  },
  {
    "country": "RS",
    "name": "Krupanj",
    "lat": "44.36556",
    "lng": "19.36194"
  },
  {
    "country": "RS",
    "name": "Krivaja",
    "lat": "44.55021",
    "lng": "19.59153"
  },
  {
    "country": "RS",
    "name": "Kozjak",
    "lat": "44.58727",
    "lng": "19.28412"
  },
  {
    "country": "RS",
    "name": "Kosjerić",
    "lat": "43.99611",
    "lng": "19.90694"
  },
  {
    "country": "RS",
    "name": "Kolut",
    "lat": "45.89292",
    "lng": "18.9276"
  },
  {
    "country": "RS",
    "name": "Koceljeva",
    "lat": "44.47361",
    "lng": "19.81167"
  },
  {
    "country": "RS",
    "name": "Klenje",
    "lat": "44.80794",
    "lng": "19.43508"
  },
  {
    "country": "RS",
    "name": "Klenak",
    "lat": "44.78846",
    "lng": "19.71004"
  },
  {
    "country": "RS",
    "name": "Kisač",
    "lat": "45.35421",
    "lng": "19.72975"
  },
  {
    "country": "RS",
    "name": "Kamenica",
    "lat": "44.343",
    "lng": "19.72333"
  },
  {
    "country": "RS",
    "name": "Joševa",
    "lat": "44.58772",
    "lng": "19.40967"
  },
  {
    "country": "RS",
    "name": "Jevremovac",
    "lat": "44.72172",
    "lng": "19.66364"
  },
  {
    "country": "RS",
    "name": "Jelenča",
    "lat": "44.727",
    "lng": "19.735"
  },
  {
    "country": "RS",
    "name": "Jarebice",
    "lat": "44.53995",
    "lng": "19.42418"
  },
  {
    "country": "RS",
    "name": "Jarak",
    "lat": "44.91843",
    "lng": "19.75477"
  },
  {
    "country": "RS",
    "name": "Jadranska Lešnica",
    "lat": "44.5973",
    "lng": "19.35209"
  },
  {
    "country": "RS",
    "name": "Irig",
    "lat": "45.10111",
    "lng": "19.85833"
  },
  {
    "country": "RS",
    "name": "Hrtkovci",
    "lat": "44.88155",
    "lng": "19.76374"
  },
  {
    "country": "RS",
    "name": "Grabovci",
    "lat": "44.76496",
    "lng": "19.84489"
  },
  {
    "country": "RS",
    "name": "Gornja Bukovica",
    "lat": "44.33987",
    "lng": "19.81368"
  },
  {
    "country": "RS",
    "name": "Glušci",
    "lat": "44.89021",
    "lng": "19.54913"
  },
  {
    "country": "RS",
    "name": "Gložan",
    "lat": "45.27954",
    "lng": "19.56838"
  },
  {
    "country": "RS",
    "name": "Gakovo",
    "lat": "45.90078",
    "lng": "19.06138"
  },
  {
    "country": "RS",
    "name": "Dublje",
    "lat": "44.80117",
    "lng": "19.50902"
  },
  {
    "country": "RS",
    "name": "Drenovac",
    "lat": "44.86649",
    "lng": "19.70943"
  },
  {
    "country": "RS",
    "name": "Draginje",
    "lat": "44.53302",
    "lng": "19.7625"
  },
  {
    "country": "RS",
    "name": "Doroslovo",
    "lat": "45.60699",
    "lng": "19.18868"
  },
  {
    "country": "RS",
    "name": "Donji Dobrić",
    "lat": "44.61183",
    "lng": "19.33109"
  },
  {
    "country": "RS",
    "name": "Dobrić",
    "lat": "44.70224",
    "lng": "19.57931"
  },
  {
    "country": "RS",
    "name": "Despotovo",
    "lat": "45.45983",
    "lng": "19.52653"
  },
  {
    "country": "RS",
    "name": "Crna Bara",
    "lat": "44.87374",
    "lng": "19.3948"
  },
  {
    "country": "RS",
    "name": "Čokešina",
    "lat": "44.65319",
    "lng": "19.39016"
  },
  {
    "country": "RS",
    "name": "Čelarevo",
    "lat": "45.26999",
    "lng": "19.52484"
  },
  {
    "country": "RS",
    "name": "Čajetina",
    "lat": "43.74977",
    "lng": "19.71273"
  },
  {
    "country": "RS",
    "name": "Bukor",
    "lat": "44.49523",
    "lng": "19.57116"
  },
  {
    "country": "RS",
    "name": "Buđanovci",
    "lat": "44.89388",
    "lng": "19.86344"
  },
  {
    "country": "RS",
    "name": "Brdarica",
    "lat": "44.55376",
    "lng": "19.7715"
  },
  {
    "country": "RS",
    "name": "Bosut",
    "lat": "44.92977",
    "lng": "19.36086"
  },
  {
    "country": "RS",
    "name": "Bogosavac",
    "lat": "44.71799",
    "lng": "19.59533"
  },
  {
    "country": "RS",
    "name": "Bogojevo",
    "lat": "45.53106",
    "lng": "19.13205"
  },
  {
    "country": "RS",
    "name": "Bogatić",
    "lat": "44.8375",
    "lng": "19.48056"
  },
  {
    "country": "RS",
    "name": "Beočin",
    "lat": "45.20829",
    "lng": "19.72063"
  },
  {
    "country": "RS",
    "name": "Belotić",
    "lat": "44.81782",
    "lng": "19.54801"
  },
  {
    "country": "RS",
    "name": "Banovo Polje",
    "lat": "44.9104",
    "lng": "19.44916"
  },
  {
    "country": "RS",
    "name": "Bajina Bašta",
    "lat": "43.97083",
    "lng": "19.5675"
  },
  {
    "country": "RS",
    "name": "Badovinci",
    "lat": "44.78534",
    "lng": "19.37146"
  },
  {
    "country": "RS",
    "name": "Bački Petrovac",
    "lat": "45.36056",
    "lng": "19.59167"
  },
  {
    "country": "RS",
    "name": "Bački Breg",
    "lat": "45.92034",
    "lng": "18.92944"
  },
  {
    "country": "RS",
    "name": "Bačka Topola",
    "lat": "45.81516",
    "lng": "19.6318"
  },
  {
    "country": "RS",
    "name": "Bačka Palanka",
    "lat": "45.25083",
    "lng": "19.39194"
  },
  {
    "country": "RS",
    "name": "Bač",
    "lat": "45.39194",
    "lng": "19.23667"
  },
  {
    "country": "RS",
    "name": "Apatin",
    "lat": "45.67111",
    "lng": "18.98472"
  },
  {
    "country": "RS",
    "name": "Pocerski Pričinović",
    "lat": "44.72222",
    "lng": "19.70722"
  },
  {
    "country": "RS",
    "name": "Ðurići",
    "lat": "43.82533",
    "lng": "19.41233"
  },
  {
    "country": "RS",
    "name": "Zlatibor",
    "lat": "43.729",
    "lng": "19.70029"
  },
  {
    "country": "RS",
    "name": "Sokolovo Brdo",
    "lat": "43.13694",
    "lng": "19.80556"
  },
  {
    "country": "RS",
    "name": "Osječenik",
    "lat": "43.14528",
    "lng": "19.85889"
  },
  {
    "country": "RS",
    "name": "Rumska",
    "lat": "44.57261",
    "lng": "19.58988"
  },
  {
    "country": "RS",
    "name": "Knjazevac",
    "lat": "43.56634",
    "lng": "22.25701"
  },
  {
    "country": "RS",
    "name": "Sumulicë",
    "lat": "42.38682",
    "lng": "21.734"
  },
  {
    "country": "RS",
    "name": "Lagja e Poshtme",
    "lat": "42.38853",
    "lng": "21.72971"
  },
  {
    "country": "RS",
    "name": "Irig",
    "lat": "45.0523",
    "lng": "19.84448"
  },
  {
    "country": "RU",
    "name": "Udomlya",
    "lat": "57.87944",
    "lng": "34.9925"
  },
  {
    "country": "RU",
    "name": "Sosnovka",
    "lat": "60.01667",
    "lng": "30.35"
  },
  {
    "country": "RU",
    "name": "Sasovo",
    "lat": "54.35369",
    "lng": "41.91986"
  },
  {
    "country": "RU",
    "name": "Novozavidovskiy",
    "lat": "56.55",
    "lng": "36.43333"
  },
  {
    "country": "RU",
    "name": "Krasnolesnyy",
    "lat": "51.88072",
    "lng": "39.58772"
  },
  {
    "country": "RU",
    "name": "Kosterevo",
    "lat": "55.9299",
    "lng": "39.61438"
  },
  {
    "country": "RU",
    "name": "Zyuzino",
    "lat": "55.65608",
    "lng": "37.56846"
  },
  {
    "country": "RU",
    "name": "Zyukayka",
    "lat": "58.20416",
    "lng": "54.70784"
  },
  {
    "country": "RU",
    "name": "Zykovo",
    "lat": "54.06853",
    "lng": "45.08633"
  },
  {
    "country": "RU",
    "name": "Zyablikovo",
    "lat": "55.61667",
    "lng": "37.76667"
  },
  {
    "country": "RU",
    "name": "Zvony",
    "lat": "56.62409",
    "lng": "28.81604"
  },
  {
    "country": "RU",
    "name": "Zverevo",
    "lat": "48.02108",
    "lng": "40.12282"
  },
  {
    "country": "RU",
    "name": "Zvenigovo",
    "lat": "55.97539",
    "lng": "48.01304"
  },
  {
    "country": "RU",
    "name": "Zvenigorod",
    "lat": "55.73401",
    "lng": "36.85918"
  },
  {
    "country": "RU",
    "name": "Zuyevka",
    "lat": "58.40503",
    "lng": "51.13355"
  },
  {
    "country": "RU",
    "name": "Zubtsov",
    "lat": "56.17533",
    "lng": "34.58935"
  },
  {
    "country": "RU",
    "name": "Zubovo",
    "lat": "60.3181",
    "lng": "36.9709"
  },
  {
    "country": "RU",
    "name": "Zubova Polyana",
    "lat": "54.0771",
    "lng": "42.8372"
  },
  {
    "country": "RU",
    "name": "Zolotukhino",
    "lat": "52.0842",
    "lng": "36.37777"
  },
  {
    "country": "RU",
    "name": "Zolotkovo",
    "lat": "55.5281",
    "lng": "41.1053"
  },
  {
    "country": "RU",
    "name": "Zol’noye",
    "lat": "53.4421",
    "lng": "49.7978"
  },
  {
    "country": "RU",
    "name": "Znamenskoye",
    "lat": "53.27869",
    "lng": "35.69055"
  },
  {
    "country": "RU",
    "name": "Znamenskoye",
    "lat": "43.67898",
    "lng": "45.12867"
  },
  {
    "country": "RU",
    "name": "Znamensk",
    "lat": "54.61403",
    "lng": "21.22722"
  },
  {
    "country": "RU",
    "name": "Znamenka",
    "lat": "52.89789",
    "lng": "35.97703"
  },
  {
    "country": "RU",
    "name": "Znamenka",
    "lat": "52.4167",
    "lng": "41.43108"
  },
  {
    "country": "RU",
    "name": "Zmiyëvka",
    "lat": "52.66697",
    "lng": "36.37426"
  },
  {
    "country": "RU",
    "name": "Zmeyskaya",
    "lat": "43.33617",
    "lng": "44.15733"
  },
  {
    "country": "RU",
    "name": "Zlynka",
    "lat": "52.4267",
    "lng": "31.7378"
  },
  {
    "country": "RU",
    "name": "Zlatoust",
    "lat": "55.17111",
    "lng": "59.65083"
  },
  {
    "country": "RU",
    "name": "Zirgan",
    "lat": "53.2222",
    "lng": "55.9185"
  },
  {
    "country": "RU",
    "name": "Zimovniki",
    "lat": "47.1474",
    "lng": "42.4721"
  },
  {
    "country": "RU",
    "name": "Zilair",
    "lat": "52.2332",
    "lng": "57.4392"
  },
  {
    "country": "RU",
    "name": "Zhulebino",
    "lat": "55.7",
    "lng": "37.85"
  },
  {
    "country": "RU",
    "name": "Zhukovskiy",
    "lat": "55.59528",
    "lng": "38.12028"
  },
  {
    "country": "RU",
    "name": "Zhukovo",
    "lat": "55.03178",
    "lng": "36.74402"
  },
  {
    "country": "RU",
    "name": "Zhukovka",
    "lat": "56.48333",
    "lng": "37.51667"
  },
  {
    "country": "RU",
    "name": "Zhukovka",
    "lat": "53.53395",
    "lng": "33.72798"
  },
  {
    "country": "RU",
    "name": "Zhizdra",
    "lat": "53.74596",
    "lng": "34.73951"
  },
  {
    "country": "RU",
    "name": "Zhiryatino",
    "lat": "53.2228",
    "lng": "33.7306"
  },
  {
    "country": "RU",
    "name": "Zhirnovsk",
    "lat": "50.98448",
    "lng": "44.77347"
  },
  {
    "country": "RU",
    "name": "Zhirnov",
    "lat": "48.17089",
    "lng": "41.12608"
  },
  {
    "country": "RU",
    "name": "Zhilëvo",
    "lat": "55.01408",
    "lng": "38.01106"
  },
  {
    "country": "RU",
    "name": "Zhiletovo",
    "lat": "54.69216",
    "lng": "36.02225"
  },
  {
    "country": "RU",
    "name": "Zhiguli",
    "lat": "53.3579",
    "lng": "49.301"
  },
  {
    "country": "RU",
    "name": "Zhigulevsk",
    "lat": "53.39972",
    "lng": "49.49528"
  },
  {
    "country": "RU",
    "name": "Zheshart",
    "lat": "62.07314",
    "lng": "49.57335"
  },
  {
    "country": "RU",
    "name": "Zherdevka",
    "lat": "51.84861",
    "lng": "41.46056"
  },
  {
    "country": "RU",
    "name": "Zhemtala",
    "lat": "43.28408",
    "lng": "43.65586"
  },
  {
    "country": "RU",
    "name": "Zheleznovodsk",
    "lat": "44.13944",
    "lng": "43.01972"
  },
  {
    "country": "RU",
    "name": "Zheleznogorsk",
    "lat": "52.331",
    "lng": "35.3711"
  },
  {
    "country": "RU",
    "name": "Zheleznodorozhnyy",
    "lat": "55.744",
    "lng": "38.01684"
  },
  {
    "country": "RU",
    "name": "Zheleznodorozhnyy",
    "lat": "54.36013",
    "lng": "21.30597"
  },
  {
    "country": "RU",
    "name": "Zhdankovskiy",
    "lat": "53.75321",
    "lng": "38.17951"
  },
  {
    "country": "RU",
    "name": "Zhavoronki",
    "lat": "55.64943",
    "lng": "37.10101"
  },
  {
    "country": "RU",
    "name": "Zharkovskiy",
    "lat": "55.849",
    "lng": "32.2697"
  },
  {
    "country": "RU",
    "name": "Zhankhoteko",
    "lat": "43.56417",
    "lng": "43.21056"
  },
  {
    "country": "RU",
    "name": "Zhadovka",
    "lat": "53.57464",
    "lng": "46.94985"
  },
  {
    "country": "RU",
    "name": "Zernograd",
    "lat": "46.84518",
    "lng": "40.30834"
  },
  {
    "country": "RU",
    "name": "Zenzeli",
    "lat": "45.92407",
    "lng": "47.04739"
  },
  {
    "country": "RU",
    "name": "Zemlyansk",
    "lat": "51.9041",
    "lng": "38.7334"
  },
  {
    "country": "RU",
    "name": "Zemetchino",
    "lat": "53.4973",
    "lng": "42.61632"
  },
  {
    "country": "RU",
    "name": "Zelyony Gorod",
    "lat": "56.17833",
    "lng": "44.0744"
  },
  {
    "country": "RU",
    "name": "Zelenokumsk",
    "lat": "44.40694",
    "lng": "43.88056"
  },
  {
    "country": "RU",
    "name": "Zelenogradskiy",
    "lat": "56.1",
    "lng": "37.91667"
  },
  {
    "country": "RU",
    "name": "Zelenogradsk",
    "lat": "54.95893",
    "lng": "20.47668"
  },
  {
    "country": "RU",
    "name": "Zelenograd",
    "lat": "55.9825",
    "lng": "37.18139"
  },
  {
    "country": "RU",
    "name": "Zelenogorsk",
    "lat": "60.19968",
    "lng": "29.70183"
  },
  {
    "country": "RU",
    "name": "Zelenodolsk",
    "lat": "55.84376",
    "lng": "48.51784"
  },
  {
    "country": "RU",
    "name": "Zelenoborskiy",
    "lat": "66.845",
    "lng": "32.36222"
  },
  {
    "country": "RU",
    "name": "Zelenets",
    "lat": "61.88485",
    "lng": "50.74892"
  },
  {
    "country": "RU",
    "name": "Zelenchukskaya",
    "lat": "43.85804",
    "lng": "41.5894"
  },
  {
    "country": "RU",
    "name": "Zayukovo",
    "lat": "43.61611",
    "lng": "43.33389"
  },
  {
    "country": "RU",
    "name": "Zaymishche",
    "lat": "52.7264",
    "lng": "32.2334"
  },
  {
    "country": "RU",
    "name": "Zavoronezhskoye",
    "lat": "52.8801",
    "lng": "40.5526"
  },
  {
    "country": "RU",
    "name": "Zavolzh’ye",
    "lat": "56.64051",
    "lng": "43.39446"
  },
  {
    "country": "RU",
    "name": "Zavolzhsk",
    "lat": "57.4823",
    "lng": "42.13779"
  },
  {
    "country": "RU",
    "name": "Masalovka",
    "lat": "48.40372",
    "lng": "40.26064"
  },
  {
    "country": "RU",
    "name": "Zavidovo",
    "lat": "56.53333",
    "lng": "36.53333"
  },
  {
    "country": "RU",
    "name": "Zavetnoye",
    "lat": "47.11944",
    "lng": "43.89028"
  },
  {
    "country": "RU",
    "name": "Zavetnoye",
    "lat": "44.7492",
    "lng": "41.5995"
  },
  {
    "country": "RU",
    "name": "Zaterechnyy",
    "lat": "44.79306",
    "lng": "45.20972"
  },
  {
    "country": "RU",
    "name": "Zasosna",
    "lat": "50.6307",
    "lng": "38.3965"
  },
  {
    "country": "RU",
    "name": "Zasechnoye",
    "lat": "53.1092",
    "lng": "45.07936"
  },
  {
    "country": "RU",
    "name": "Zarubino",
    "lat": "58.735",
    "lng": "33.47556"
  },
  {
    "country": "RU",
    "name": "Zarechnyy",
    "lat": "57.46931",
    "lng": "42.28431"
  },
  {
    "country": "RU",
    "name": "Zarechnyy",
    "lat": "53.7306",
    "lng": "39.59437"
  },
  {
    "country": "RU",
    "name": "Zarechnyy",
    "lat": "53.20356",
    "lng": "45.19227"
  },
  {
    "country": "RU",
    "name": "Zaraysk",
    "lat": "54.7605",
    "lng": "38.87841"
  },
  {
    "country": "RU",
    "name": "Zaprudnya",
    "lat": "56.56667",
    "lng": "37.43333"
  },
  {
    "country": "RU",
    "name": "Zapolyarnyy",
    "lat": "69.41541",
    "lng": "30.81355"
  },
  {
    "country": "RU",
    "name": "Zaplavnoye",
    "lat": "48.7048",
    "lng": "45.0229"
  },
  {
    "country": "RU",
    "name": "Zapadnaya Dvina",
    "lat": "56.25901",
    "lng": "32.07454"
  },
  {
    "country": "RU",
    "name": "Zaokskiy",
    "lat": "54.73227",
    "lng": "37.40539"
  },
  {
    "country": "RU",
    "name": "Zandak",
    "lat": "43.0571",
    "lng": "46.45566"
  },
  {
    "country": "RU",
    "name": "Zamoskvorech’ye",
    "lat": "55.73333",
    "lng": "37.63333"
  },
  {
    "country": "RU",
    "name": "Zamishevo",
    "lat": "52.5395",
    "lng": "32.0129"
  },
  {
    "country": "RU",
    "name": "Zalukokoazhe",
    "lat": "43.90389",
    "lng": "43.21556"
  },
  {
    "country": "RU",
    "name": "Zalegoshch’",
    "lat": "52.8989",
    "lng": "36.89093"
  },
  {
    "country": "RU",
    "name": "Zakharovo",
    "lat": "54.366",
    "lng": "39.2792"
  },
  {
    "country": "RU",
    "name": "Zakan-Yurt",
    "lat": "43.25972",
    "lng": "45.42056"
  },
  {
    "country": "RU",
    "name": "Zainsk",
    "lat": "55.3195",
    "lng": "52.06942"
  },
  {
    "country": "RU",
    "name": "Zagoryanskiy",
    "lat": "55.9325",
    "lng": "37.95806"
  },
  {
    "country": "RU",
    "name": "Zadonsk",
    "lat": "52.3904",
    "lng": "38.9261"
  },
  {
    "country": "RU",
    "name": "Zabolotovka",
    "lat": "50.27799",
    "lng": "39.31439"
  },
  {
    "country": "RU",
    "name": "Yuzhnyy-Kospashskiy",
    "lat": "58.9725",
    "lng": "57.759"
  },
  {
    "country": "RU",
    "name": "Yuzhno-Sukhokumsk",
    "lat": "44.65811",
    "lng": "45.6436"
  },
  {
    "country": "RU",
    "name": "Yuzha",
    "lat": "56.58306",
    "lng": "42.01222"
  },
  {
    "country": "RU",
    "name": "Yushkozero",
    "lat": "64.75162",
    "lng": "32.10255"
  },
  {
    "country": "RU",
    "name": "Yuryuzan’",
    "lat": "54.86333",
    "lng": "58.42194"
  },
  {
    "country": "RU",
    "name": "Yur’yev-Pol’skiy",
    "lat": "56.50339",
    "lng": "39.67911"
  },
  {
    "country": "RU",
    "name": "Yur’yevets",
    "lat": "57.32007",
    "lng": "43.1041"
  },
  {
    "country": "RU",
    "name": "Yurovka",
    "lat": "45.1147",
    "lng": "37.41882"
  },
  {
    "country": "RU",
    "name": "Yurla",
    "lat": "59.3251",
    "lng": "54.3278"
  },
  {
    "country": "RU",
    "name": "Yurino",
    "lat": "56.29417",
    "lng": "46.30392"
  },
  {
    "country": "RU",
    "name": "Yumaguzino",
    "lat": "52.90412",
    "lng": "56.39329"
  },
  {
    "country": "RU",
    "name": "Yukhnov",
    "lat": "54.74444",
    "lng": "35.22972"
  },
  {
    "country": "RU",
    "name": "Yukamenskoye",
    "lat": "57.8878",
    "lng": "52.245"
  },
  {
    "country": "RU",
    "name": "Yugo-Kamskiy",
    "lat": "57.7026",
    "lng": "55.5904"
  },
  {
    "country": "RU",
    "name": "Yuganets",
    "lat": "56.2508",
    "lng": "43.23069"
  },
  {
    "country": "RU",
    "name": "Yug",
    "lat": "57.7293",
    "lng": "56.172"
  },
  {
    "country": "RU",
    "name": "Yubileynyy",
    "lat": "58.7794",
    "lng": "57.7822"
  },
  {
    "country": "RU",
    "name": "Yoshkar-Ola",
    "lat": "56.63877",
    "lng": "47.89078"
  },
  {
    "country": "RU",
    "name": "Yeyskoye Ukrepleniye",
    "lat": "46.7063",
    "lng": "38.6121"
  },
  {
    "country": "RU",
    "name": "Yeysk",
    "lat": "46.7055",
    "lng": "38.2739"
  },
  {
    "country": "RU",
    "name": "Yessentukskaya",
    "lat": "44.0328",
    "lng": "42.8813"
  },
  {
    "country": "RU",
    "name": "Yessentuki",
    "lat": "44.04444",
    "lng": "42.86056"
  },
  {
    "country": "RU",
    "name": "Yertsevo",
    "lat": "60.7966",
    "lng": "40.086"
  },
  {
    "country": "RU",
    "name": "Yershovo",
    "lat": "55.76911",
    "lng": "36.85929"
  },
  {
    "country": "RU",
    "name": "Yershov",
    "lat": "51.3513",
    "lng": "48.2766"
  },
  {
    "country": "RU",
    "name": "Yershichi",
    "lat": "53.6725",
    "lng": "32.75417"
  },
  {
    "country": "RU",
    "name": "Yermolino",
    "lat": "56.14887",
    "lng": "37.49112"
  },
  {
    "country": "RU",
    "name": "Yermolino",
    "lat": "55.19489",
    "lng": "36.59513"
  },
  {
    "country": "RU",
    "name": "Yermolayevo",
    "lat": "52.71667",
    "lng": "55.8"
  },
  {
    "country": "RU",
    "name": "Yermish’",
    "lat": "54.76778",
    "lng": "42.27111"
  },
  {
    "country": "RU",
    "name": "Yermekeyevo",
    "lat": "54.07614",
    "lng": "53.67125"
  },
  {
    "country": "RU",
    "name": "Yepifan’",
    "lat": "53.82526",
    "lng": "38.55181"
  },
  {
    "country": "RU",
    "name": "Yenotayevka",
    "lat": "47.24559",
    "lng": "47.02814"
  },
  {
    "country": "RU",
    "name": "Yemva",
    "lat": "62.58999",
    "lng": "50.85939"
  },
  {
    "country": "RU",
    "name": "Yemtsa",
    "lat": "63.07337",
    "lng": "40.33285"
  },
  {
    "country": "RU",
    "name": "Yemetsk",
    "lat": "63.47191",
    "lng": "41.78023"
  },
  {
    "country": "RU",
    "name": "Yelshanka",
    "lat": "51.81389",
    "lng": "46.39972"
  },
  {
    "country": "RU",
    "name": "Yelovo",
    "lat": "57.05381",
    "lng": "54.9207"
  },
  {
    "country": "RU",
    "name": "Yel’nya",
    "lat": "54.57864",
    "lng": "33.18373"
  },
  {
    "country": "RU",
    "name": "Yëlkino",
    "lat": "58.6922",
    "lng": "59.832"
  },
  {
    "country": "RU",
    "name": "Yelkhovka",
    "lat": "53.86668",
    "lng": "50.28319"
  },
  {
    "country": "RU",
    "name": "Yelizavetinskoye",
    "lat": "45.00722",
    "lng": "43.34944"
  },
  {
    "country": "RU",
    "name": "Yelizavetinskaya",
    "lat": "45.04616",
    "lng": "38.79491"
  },
  {
    "country": "RU",
    "name": "Yelizavetino",
    "lat": "59.49173",
    "lng": "29.78153"
  },
  {
    "country": "RU",
    "name": "Yelizavetinka",
    "lat": "51.76732",
    "lng": "59.74245"
  },
  {
    "country": "RU",
    "name": "Yelets",
    "lat": "52.62366",
    "lng": "38.50169"
  },
  {
    "country": "RU",
    "name": "Yel’digino",
    "lat": "56.11667",
    "lng": "37.81667"
  },
  {
    "country": "RU",
    "name": "Yelat’ma",
    "lat": "54.9675",
    "lng": "41.75083"
  },
  {
    "country": "RU",
    "name": "Yelan’-Kolenovskiy",
    "lat": "51.1632",
    "lng": "41.151"
  },
  {
    "country": "RU",
    "name": "Yelan’-Koleno",
    "lat": "51.1523",
    "lng": "41.2306"
  },
  {
    "country": "RU",
    "name": "Yelan’",
    "lat": "50.949",
    "lng": "43.73781"
  },
  {
    "country": "RU",
    "name": "Yelabuga",
    "lat": "55.76127",
    "lng": "52.06493"
  },
  {
    "country": "RU",
    "name": "Yekimovichi",
    "lat": "54.11285",
    "lng": "33.29648"
  },
  {
    "country": "RU",
    "name": "Yekaterinovka",
    "lat": "52.05083",
    "lng": "44.34515"
  },
  {
    "country": "RU",
    "name": "Yegor’yevsk",
    "lat": "55.38283",
    "lng": "39.03233"
  },
  {
    "country": "RU",
    "name": "Yegorlykskaya",
    "lat": "46.56564",
    "lng": "40.65621"
  },
  {
    "country": "RU",
    "name": "Yefremov",
    "lat": "53.14806",
    "lng": "38.09924"
  },
  {
    "country": "RU",
    "name": "Yefimovskiy",
    "lat": "59.49639",
    "lng": "34.67222"
  },
  {
    "country": "RU",
    "name": "Yedrovo",
    "lat": "57.91306",
    "lng": "33.62028"
  },
  {
    "country": "RU",
    "name": "Yazykovo",
    "lat": "55.21988",
    "lng": "56.13532"
  },
  {
    "country": "RU",
    "name": "Yazykovo",
    "lat": "54.2922",
    "lng": "47.3891"
  },
  {
    "country": "RU",
    "name": "Yayva",
    "lat": "59.3347",
    "lng": "57.2592"
  },
  {
    "country": "RU",
    "name": "Yavas",
    "lat": "54.4159",
    "lng": "42.8491"
  },
  {
    "country": "RU",
    "name": "Yasnyy",
    "lat": "51.0333",
    "lng": "59.8742"
  },
  {
    "country": "RU",
    "name": "Yasnogorsk",
    "lat": "54.48082",
    "lng": "37.69854"
  },
  {
    "country": "RU",
    "name": "Yashkul’",
    "lat": "46.1711",
    "lng": "45.3435"
  },
  {
    "country": "RU",
    "name": "Yashalta",
    "lat": "46.3395",
    "lng": "42.2762"
  },
  {
    "country": "RU",
    "name": "Yasenskaya",
    "lat": "46.3592",
    "lng": "38.269"
  },
  {
    "country": "RU",
    "name": "Yasenevo",
    "lat": "55.60686",
    "lng": "37.51991"
  },
  {
    "country": "RU",
    "name": "Yartsevo",
    "lat": "55.06667",
    "lng": "32.69639"
  },
  {
    "country": "RU",
    "name": "Yaroslavskaya",
    "lat": "44.61056",
    "lng": "40.46417"
  },
  {
    "country": "RU",
    "name": "Yaroslavl",
    "lat": "57.62987",
    "lng": "39.87368"
  },
  {
    "country": "RU",
    "name": "Yaroslavichi",
    "lat": "60.49275",
    "lng": "34.50806"
  },
  {
    "country": "RU",
    "name": "Yaropolets",
    "lat": "56.13333",
    "lng": "35.83317"
  },
  {
    "country": "RU",
    "name": "Yarensk",
    "lat": "62.16755",
    "lng": "49.09162"
  },
  {
    "country": "RU",
    "name": "Yarega",
    "lat": "63.43543",
    "lng": "53.5765"
  },
  {
    "country": "RU",
    "name": "Yaransk",
    "lat": "57.30331",
    "lng": "47.88611"
  },
  {
    "country": "RU",
    "name": "Yar",
    "lat": "58.2458",
    "lng": "52.1054"
  },
  {
    "country": "RU",
    "name": "Yantikovo",
    "lat": "55.82158",
    "lng": "47.91036"
  },
  {
    "country": "RU",
    "name": "Yanis’yarvi",
    "lat": "61.89127",
    "lng": "30.94849"
  },
  {
    "country": "RU",
    "name": "Yanishpole",
    "lat": "62.11095",
    "lng": "34.27013"
  },
  {
    "country": "RU",
    "name": "Yandyki",
    "lat": "45.76913",
    "lng": "47.12577"
  },
  {
    "country": "RU",
    "name": "Yanaul",
    "lat": "56.2751",
    "lng": "54.9338"
  },
  {
    "country": "RU",
    "name": "Novaya Maka",
    "lat": "41.77173",
    "lng": "48.36149"
  },
  {
    "country": "RU",
    "name": "Yamkino",
    "lat": "55.92088",
    "lng": "38.40417"
  },
  {
    "country": "RU",
    "name": "Yambirno",
    "lat": "54.1231",
    "lng": "42.0911"
  },
  {
    "country": "RU",
    "name": "Yam",
    "lat": "55.48785",
    "lng": "37.74458"
  },
  {
    "country": "RU",
    "name": "Yalkhoy-Mokhk",
    "lat": "43.10528",
    "lng": "46.19045"
  },
  {
    "country": "RU",
    "name": "Yaksatovo",
    "lat": "46.24343",
    "lng": "48.01514"
  },
  {
    "country": "RU",
    "name": "Yakovlevskoye",
    "lat": "55.44194",
    "lng": "37.94806"
  },
  {
    "country": "RU",
    "name": "Yakovlevo",
    "lat": "60.29409",
    "lng": "29.488"
  },
  {
    "country": "RU",
    "name": "Yakovlevo",
    "lat": "50.86033",
    "lng": "36.44784"
  },
  {
    "country": "RU",
    "name": "Yakhroma",
    "lat": "56.3",
    "lng": "37.48333"
  },
  {
    "country": "RU",
    "name": "Yagry",
    "lat": "64.59417",
    "lng": "39.81028"
  },
  {
    "country": "RU",
    "name": "Yadrin",
    "lat": "55.94052",
    "lng": "46.20622"
  },
  {
    "country": "RU",
    "name": "Yablonovskiy",
    "lat": "44.98901",
    "lng": "38.94324"
  },
  {
    "country": "RU",
    "name": "Vyyezdnoye",
    "lat": "55.38154",
    "lng": "43.78638"
  },
  {
    "country": "RU",
    "name": "Vytegra",
    "lat": "61.00636",
    "lng": "36.44811"
  },
  {
    "country": "RU",
    "name": "Vysotskoye",
    "lat": "45.025",
    "lng": "42.90639"
  },
  {
    "country": "RU",
    "name": "Vysotsk",
    "lat": "60.62879",
    "lng": "28.57048"
  },
  {
    "country": "RU",
    "name": "Vysokovsk",
    "lat": "56.31667",
    "lng": "36.55"
  },
  {
    "country": "RU",
    "name": "Vysokinichi",
    "lat": "54.90928",
    "lng": "36.93148"
  },
  {
    "country": "RU",
    "name": "Vysokaya Gora",
    "lat": "55.91278",
    "lng": "49.30167"
  },
  {
    "country": "RU",
    "name": "Vyshniy Volochëk",
    "lat": "57.59125",
    "lng": "34.56453"
  },
  {
    "country": "RU",
    "name": "Vyshneye Dolgoye",
    "lat": "52.06302",
    "lng": "37.40518"
  },
  {
    "country": "RU",
    "name": "Vyshkov",
    "lat": "52.4764",
    "lng": "31.6873"
  },
  {
    "country": "RU",
    "name": "Vysha",
    "lat": "53.84768",
    "lng": "42.37766"
  },
  {
    "country": "RU",
    "name": "Vyselki",
    "lat": "45.58128",
    "lng": "39.66409"
  },
  {
    "country": "RU",
    "name": "Vyritsa",
    "lat": "59.40778",
    "lng": "30.34806"
  },
  {
    "country": "RU",
    "name": "Vypolzovo",
    "lat": "57.87667",
    "lng": "33.69861"
  },
  {
    "country": "RU",
    "name": "Vyksa",
    "lat": "55.3175",
    "lng": "42.17444"
  },
  {
    "country": "RU",
    "name": "Vykhino-Zhulebino",
    "lat": "55.70196",
    "lng": "37.81178"
  },
  {
    "country": "RU",
    "name": "Vygonichi",
    "lat": "53.09855",
    "lng": "34.06728"
  },
  {
    "country": "RU",
    "name": "Vydropuzhsk",
    "lat": "57.3647",
    "lng": "34.84287"
  },
  {
    "country": "RU",
    "name": "Vychegodskiy",
    "lat": "61.24702",
    "lng": "46.89842"
  },
  {
    "country": "RU",
    "name": "Vyborg",
    "lat": "60.70763",
    "lng": "28.75283"
  },
  {
    "country": "RU",
    "name": "Vybor",
    "lat": "57.22716",
    "lng": "29.1663"
  },
  {
    "country": "RU",
    "name": "Vyazovaya",
    "lat": "54.905",
    "lng": "58.35611"
  },
  {
    "country": "RU",
    "name": "Vyazniki",
    "lat": "56.24057",
    "lng": "42.15563"
  },
  {
    "country": "RU",
    "name": "Vyaz’ma",
    "lat": "55.21039",
    "lng": "34.29508"
  },
  {
    "country": "RU",
    "name": "Vyatskiye Polyany",
    "lat": "56.22602",
    "lng": "51.06557"
  },
  {
    "country": "RU",
    "name": "Vyartsilya",
    "lat": "62.17645",
    "lng": "30.69296"
  },
  {
    "country": "RU",
    "name": "Vurnary",
    "lat": "55.49044",
    "lng": "46.96479"
  },
  {
    "country": "RU",
    "name": "Vuktyl",
    "lat": "63.85667",
    "lng": "57.30944"
  },
  {
    "country": "RU",
    "name": "Vsevolozhsk",
    "lat": "60.01512",
    "lng": "30.67314"
  },
  {
    "country": "RU",
    "name": "Voznesen’ye",
    "lat": "61.0106",
    "lng": "35.47813"
  },
  {
    "country": "RU",
    "name": "Voznesenskoye",
    "lat": "54.89",
    "lng": "42.75694"
  },
  {
    "country": "RU",
    "name": "Voznesenskaya",
    "lat": "44.5527",
    "lng": "41.0318"
  },
  {
    "country": "RU",
    "name": "Voznesenskaya",
    "lat": "43.54379",
    "lng": "44.74614"
  },
  {
    "country": "RU",
    "name": "Vozhega",
    "lat": "60.47246",
    "lng": "40.22134"
  },
  {
    "country": "RU",
    "name": "Voyvozh",
    "lat": "62.89198",
    "lng": "54.96346"
  },
  {
    "country": "RU",
    "name": "Voyskovitsy",
    "lat": "59.53266",
    "lng": "29.9362"
  },
  {
    "country": "RU",
    "name": "Votkinsk",
    "lat": "57.04865",
    "lng": "53.98717"
  },
  {
    "country": "RU",
    "name": "Vostryakovo",
    "lat": "55.66667",
    "lng": "37.45"
  },
  {
    "country": "RU",
    "name": "Vostryakovo",
    "lat": "55.39934",
    "lng": "37.80829"
  },
  {
    "country": "RU",
    "name": "Vostochnyy",
    "lat": "58.78811",
    "lng": "52.24513"
  },
  {
    "country": "RU",
    "name": "Vostochnyy",
    "lat": "55.81667",
    "lng": "37.86667"
  },
  {
    "country": "RU",
    "name": "Voskresenskoye",
    "lat": "56.83806",
    "lng": "45.43167"
  },
  {
    "country": "RU",
    "name": "Voskresenskoye",
    "lat": "53.12336",
    "lng": "56.14664"
  },
  {
    "country": "RU",
    "name": "Voskresenskoye",
    "lat": "51.82478",
    "lng": "46.93508"
  },
  {
    "country": "RU",
    "name": "Voskresensk",
    "lat": "55.31733",
    "lng": "38.65264"
  },
  {
    "country": "RU",
    "name": "Vorsma",
    "lat": "55.99062",
    "lng": "43.27249"
  },
  {
    "country": "RU",
    "name": "Vorsha",
    "lat": "56.0491",
    "lng": "40.07966"
  },
  {
    "country": "RU",
    "name": "Vorotynets",
    "lat": "56.06028",
    "lng": "45.8633"
  },
  {
    "country": "RU",
    "name": "Voroshnëvo",
    "lat": "51.65278",
    "lng": "36.01722"
  },
  {
    "country": "RU",
    "name": "Vorontsovka",
    "lat": "50.6132",
    "lng": "40.3549"
  },
  {
    "country": "RU",
    "name": "Vorontsovka",
    "lat": "46.6529",
    "lng": "38.0787"
  },
  {
    "country": "RU",
    "name": "Voronezh",
    "lat": "51.67204",
    "lng": "39.1843"
  },
  {
    "country": "RU",
    "name": "Altuf’yevskiy",
    "lat": "55.88333",
    "lng": "37.58333"
  },
  {
    "country": "RU",
    "name": "Vorob’yovo",
    "lat": "55.71667",
    "lng": "37.53333"
  },
  {
    "country": "RU",
    "name": "Vorob’yëvka",
    "lat": "50.6481",
    "lng": "40.95028"
  },
  {
    "country": "RU",
    "name": "Volzhskiy",
    "lat": "53.43058",
    "lng": "50.119"
  },
  {
    "country": "RU",
    "name": "Volzhskiy",
    "lat": "48.78583",
    "lng": "44.77973"
  },
  {
    "country": "RU",
    "name": "Volzhsk",
    "lat": "55.86638",
    "lng": "48.3594"
  },
  {
    "country": "RU",
    "name": "Volya",
    "lat": "51.7651",
    "lng": "39.5404"
  },
  {
    "country": "RU",
    "name": "Vol’sk",
    "lat": "52.04541",
    "lng": "47.37993"
  },
  {
    "country": "RU",
    "name": "Volovo",
    "lat": "52.02659",
    "lng": "37.8854"
  },
  {
    "country": "RU",
    "name": "Volot",
    "lat": "57.92778",
    "lng": "30.7025"
  },
  {
    "country": "RU",
    "name": "Volosovo",
    "lat": "59.44525",
    "lng": "29.48911"
  },
  {
    "country": "RU",
    "name": "Voloshka",
    "lat": "61.33139",
    "lng": "40.08583"
  },
  {
    "country": "RU",
    "name": "Volokonovka",
    "lat": "50.4827",
    "lng": "37.8563"
  },
  {
    "country": "RU",
    "name": "Volokolamsk",
    "lat": "56.03361",
    "lng": "35.96944"
  },
  {
    "country": "RU",
    "name": "Vologda",
    "lat": "59.2239",
    "lng": "39.88398"
  },
  {
    "country": "RU",
    "name": "Volodarskogo",
    "lat": "55.50349",
    "lng": "37.94174"
  },
  {
    "country": "RU",
    "name": "Volodarskiy",
    "lat": "46.40134",
    "lng": "48.54093"
  },
  {
    "country": "RU",
    "name": "Volodarsk",
    "lat": "56.23105",
    "lng": "43.18767"
  },
  {
    "country": "RU",
    "name": "Volochayevskoye",
    "lat": "54.70034",
    "lng": "20.21966"
  },
  {
    "country": "RU",
    "name": "Vol’nyy Aul",
    "lat": "43.47861",
    "lng": "43.6275"
  },
  {
    "country": "RU",
    "name": "Volkhovskiy",
    "lat": "58.58",
    "lng": "31.31641"
  },
  {
    "country": "RU",
    "name": "Volkhov",
    "lat": "59.9258",
    "lng": "32.33819"
  },
  {
    "country": "RU",
    "name": "Nagornyy",
    "lat": "55.65",
    "lng": "37.61667"
  },
  {
    "country": "RU",
    "name": "Volgorechensk",
    "lat": "57.43931",
    "lng": "41.15553"
  },
  {
    "country": "RU",
    "name": "Volgo-Kaspiyskiy",
    "lat": "46.20306",
    "lng": "47.91869"
  },
  {
    "country": "RU",
    "name": "Volgograd",
    "lat": "48.71939",
    "lng": "44.50183"
  },
  {
    "country": "RU",
    "name": "Volgodonsk",
    "lat": "47.51361",
    "lng": "42.15139"
  },
  {
    "country": "RU",
    "name": "Volga",
    "lat": "57.95157",
    "lng": "38.38785"
  },
  {
    "country": "RU",
    "name": "Vokhtoga",
    "lat": "58.80949",
    "lng": "41.06245"
  },
  {
    "country": "RU",
    "name": "Vokhma",
    "lat": "58.9303",
    "lng": "46.75859"
  },
  {
    "country": "RU",
    "name": "Vodstroy",
    "lat": "48.84165",
    "lng": "44.55793"
  },
  {
    "country": "RU",
    "name": "Yutsa",
    "lat": "43.95639",
    "lng": "43.01278"
  },
  {
    "country": "RU",
    "name": "Vodnyy",
    "lat": "63.50464",
    "lng": "53.40947"
  },
  {
    "country": "RU",
    "name": "Novovladykino",
    "lat": "55.85",
    "lng": "37.58333"
  },
  {
    "country": "RU",
    "name": "Vladimirskoye",
    "lat": "56.82002",
    "lng": "45.11843"
  },
  {
    "country": "RU",
    "name": "Vladimirskaya",
    "lat": "44.5455",
    "lng": "40.7933"
  },
  {
    "country": "RU",
    "name": "Vladimir",
    "lat": "56.13655",
    "lng": "40.39658"
  },
  {
    "country": "RU",
    "name": "Vladikavkaz",
    "lat": "43.03667",
    "lng": "44.66778"
  },
  {
    "country": "RU",
    "name": "Vizinga",
    "lat": "61.07493",
    "lng": "50.10311"
  },
  {
    "country": "RU",
    "name": "Vityazevo",
    "lat": "45.0013",
    "lng": "37.28211"
  },
  {
    "country": "RU",
    "name": "Vistino",
    "lat": "59.77558",
    "lng": "28.47708"
  },
  {
    "country": "RU",
    "name": "Visim",
    "lat": "57.6488",
    "lng": "59.5014"
  },
  {
    "country": "RU",
    "name": "Vishnyakovskiye Dachi",
    "lat": "55.7647",
    "lng": "38.13334"
  },
  {
    "country": "RU",
    "name": "Vinsady",
    "lat": "44.08083",
    "lng": "42.96528"
  },
  {
    "country": "RU",
    "name": "Vinogradovo",
    "lat": "56.93333",
    "lng": "37.55"
  },
  {
    "country": "RU",
    "name": "Vinogradnyy",
    "lat": "45.0561",
    "lng": "37.32125"
  },
  {
    "country": "RU",
    "name": "Vinnitsy",
    "lat": "60.62867",
    "lng": "34.77302"
  },
  {
    "country": "RU",
    "name": "Vilya",
    "lat": "55.24556",
    "lng": "42.20889"
  },
  {
    "country": "RU",
    "name": "Vilovatovo",
    "lat": "56.1724",
    "lng": "46.60134"
  },
  {
    "country": "RU",
    "name": "Vilenka",
    "lat": "54.2693",
    "lng": "38.91663"
  },
  {
    "country": "RU",
    "name": "Vidyayevo",
    "lat": "68.88333",
    "lng": "33.01667"
  },
  {
    "country": "RU",
    "name": "Vidnoye",
    "lat": "55.55239",
    "lng": "37.70967"
  },
  {
    "country": "RU",
    "name": "Vichuga",
    "lat": "57.21276",
    "lng": "41.93012"
  },
  {
    "country": "RU",
    "name": "Veydelevka",
    "lat": "50.1521",
    "lng": "38.4492"
  },
  {
    "country": "RU",
    "name": "Vetluzhskiy",
    "lat": "58.39016",
    "lng": "45.46543"
  },
  {
    "country": "RU",
    "name": "Vetluzhskiy",
    "lat": "57.17355",
    "lng": "45.12272"
  },
  {
    "country": "RU",
    "name": "Vetluga",
    "lat": "57.85574",
    "lng": "45.78102"
  },
  {
    "country": "RU",
    "name": "Ves’yegonsk",
    "lat": "58.66398",
    "lng": "37.2604"
  },
  {
    "country": "RU",
    "name": "Veshnyaki",
    "lat": "55.72393",
    "lng": "37.81952"
  },
  {
    "country": "RU",
    "name": "Veshkayma",
    "lat": "54.0472",
    "lng": "47.13"
  },
  {
    "country": "RU",
    "name": "Veshenskaya",
    "lat": "49.63033",
    "lng": "41.7334"
  },
  {
    "country": "RU",
    "name": "Veshchevo",
    "lat": "60.73107",
    "lng": "29.18305"
  },
  {
    "country": "RU",
    "name": "Vesëlyy",
    "lat": "47.09338",
    "lng": "40.7422"
  },
  {
    "country": "RU",
    "name": "Verkhozim",
    "lat": "52.71221",
    "lng": "45.41803"
  },
  {
    "country": "RU",
    "name": "Verkhov’ye",
    "lat": "52.81165",
    "lng": "37.24215"
  },
  {
    "country": "RU",
    "name": "Verkhovazh’ye",
    "lat": "60.74717",
    "lng": "42.04652"
  },
  {
    "country": "RU",
    "name": "Verkhoshizhem’ye",
    "lat": "58.01097",
    "lng": "49.10384"
  },
  {
    "country": "RU",
    "name": "Verkhnyaya Tura",
    "lat": "58.36083",
    "lng": "59.80667"
  },
  {
    "country": "RU",
    "name": "Verkhnyaya Toyma",
    "lat": "62.2347",
    "lng": "45.0009"
  },
  {
    "country": "RU",
    "name": "Verkhnyaya Tishanka",
    "lat": "51.32389",
    "lng": "40.53278"
  },
  {
    "country": "RU",
    "name": "Verkhnyaya Maksakovka",
    "lat": "61.63504",
    "lng": "50.9674"
  },
  {
    "country": "RU",
    "name": "Kishcha",
    "lat": "42.17677",
    "lng": "47.58117"
  },
  {
    "country": "RU",
    "name": "Verkhnyaya Khava",
    "lat": "51.84045",
    "lng": "39.94134"
  },
  {
    "country": "RU",
    "name": "Verkhnyaya Balkariya",
    "lat": "43.12785",
    "lng": "43.45732"
  },
  {
    "country": "RU",
    "name": "Verkhniy Uslon",
    "lat": "55.7701",
    "lng": "48.9823"
  },
  {
    "country": "RU",
    "name": "Verkhniy Tagil",
    "lat": "57.3733",
    "lng": "59.9556"
  },
  {
    "country": "RU",
    "name": "Lakkha Nëvre",
    "lat": "43.61033",
    "lng": "45.24542"
  },
  {
    "country": "RU",
    "name": "Verkhniy Mamon",
    "lat": "50.1635",
    "lng": "40.3832"
  },
  {
    "country": "RU",
    "name": "Verkhniy Lomov",
    "lat": "53.46778",
    "lng": "43.55111"
  },
  {
    "country": "RU",
    "name": "Verkhniy Landekh",
    "lat": "56.83971",
    "lng": "42.5973"
  },
  {
    "country": "RU",
    "name": "Verkhniy Kurkuzhin",
    "lat": "43.69556",
    "lng": "43.27472"
  },
  {
    "country": "RU",
    "name": "Verkhniy Fiagdon",
    "lat": "42.83323",
    "lng": "44.30657"
  },
  {
    "country": "RU",
    "name": "Verkhniye Tatyshly",
    "lat": "56.29117",
    "lng": "55.8575"
  },
  {
    "country": "RU",
    "name": "Verkhniye Sergi",
    "lat": "56.64694",
    "lng": "59.55556"
  },
  {
    "country": "RU",
    "name": "Verkhniye Osel’ki",
    "lat": "60.24948",
    "lng": "30.44938"
  },
  {
    "country": "RU",
    "name": "Verkhniye Kigi",
    "lat": "55.40833",
    "lng": "58.60444"
  },
  {
    "country": "RU",
    "name": "Verkhniye Achaluki",
    "lat": "43.34694",
    "lng": "44.6975"
  },
  {
    "country": "RU",
    "name": "Verkhniy Baskunchak",
    "lat": "48.22564",
    "lng": "46.72169"
  },
  {
    "country": "RU",
    "name": "Verkhniy Avzyan",
    "lat": "53.52889",
    "lng": "57.53722"
  },
  {
    "country": "RU",
    "name": "Verkhneye Kazanishche",
    "lat": "42.73547",
    "lng": "47.1378"
  },
  {
    "country": "RU",
    "name": "Verkhneyarkeyevo",
    "lat": "55.45046",
    "lng": "54.31455"
  },
  {
    "country": "RU",
    "name": "Verkhneural’sk",
    "lat": "53.87694",
    "lng": "59.21056"
  },
  {
    "country": "RU",
    "name": "Verkhnetulomskiy",
    "lat": "68.60727",
    "lng": "31.79621"
  },
  {
    "country": "RU",
    "name": "Verkhnedneprovskiy",
    "lat": "54.98131",
    "lng": "33.34573"
  },
  {
    "country": "RU",
    "name": "Verkhnechusovskiye Gorodki",
    "lat": "58.1671",
    "lng": "57.1086"
  },
  {
    "country": "RU",
    "name": "Vereya",
    "lat": "55.77373",
    "lng": "39.09766"
  },
  {
    "country": "RU",
    "name": "Vereya",
    "lat": "55.61472",
    "lng": "38.03917"
  },
  {
    "country": "RU",
    "name": "Vereya",
    "lat": "55.34472",
    "lng": "36.17194"
  },
  {
    "country": "RU",
    "name": "Vereshchagino",
    "lat": "58.07894",
    "lng": "54.6557"
  },
  {
    "country": "RU",
    "name": "Verbilki",
    "lat": "56.53333",
    "lng": "37.6"
  },
  {
    "country": "RU",
    "name": "Ventsy",
    "lat": "45.37639",
    "lng": "40.83583"
  },
  {
    "country": "RU",
    "name": "Venëv",
    "lat": "54.35533",
    "lng": "38.26843"
  },
  {
    "country": "RU",
    "name": "Vel’ye",
    "lat": "56.97005",
    "lng": "28.57883"
  },
  {
    "country": "RU",
    "name": "Vel’sk",
    "lat": "61.07006",
    "lng": "42.0983"
  },
  {
    "country": "RU",
    "name": "Velizh",
    "lat": "55.60564",
    "lng": "31.19673"
  },
  {
    "country": "RU",
    "name": "Velikovechnoye",
    "lat": "44.93402",
    "lng": "39.75499"
  },
  {
    "country": "RU",
    "name": "Velikooktyabr’skiy",
    "lat": "57.43333",
    "lng": "33.81595"
  },
  {
    "country": "RU",
    "name": "Velikodvorskiy",
    "lat": "55.24996",
    "lng": "40.6678"
  },
  {
    "country": "RU",
    "name": "Velikiy Ustyug",
    "lat": "60.76186",
    "lng": "46.31352"
  },
  {
    "country": "RU",
    "name": "Velikiye Luki",
    "lat": "56.34",
    "lng": "30.54517"
  },
  {
    "country": "RU",
    "name": "Velikent",
    "lat": "42.18626",
    "lng": "48.06285"
  },
  {
    "country": "RU",
    "name": "Vedeno",
    "lat": "42.96892",
    "lng": "46.09611"
  },
  {
    "country": "RU",
    "name": "Vazhiny",
    "lat": "60.96444",
    "lng": "34.02222"
  },
  {
    "country": "RU",
    "name": "Vavozh",
    "lat": "56.77513",
    "lng": "51.93098"
  },
  {
    "country": "RU",
    "name": "Vatutino",
    "lat": "55.88441",
    "lng": "37.69055"
  },
  {
    "country": "RU",
    "name": "Vatutinki",
    "lat": "55.4965",
    "lng": "37.32988"
  },
  {
    "country": "RU",
    "name": "Vasyurinskaya",
    "lat": "45.11809",
    "lng": "39.42399"
  },
  {
    "country": "RU",
    "name": "Vaskelovo",
    "lat": "60.39571",
    "lng": "30.35419"
  },
  {
    "country": "RU",
    "name": "Vasil’yevskiy Mokh",
    "lat": "57.01316",
    "lng": "35.91897"
  },
  {
    "country": "RU",
    "name": "Varygino",
    "lat": "56.76268",
    "lng": "28.53495"
  },
  {
    "country": "RU",
    "name": "Varnavino",
    "lat": "57.40351",
    "lng": "45.09164"
  },
  {
    "country": "RU",
    "name": "Varlamovo",
    "lat": "53.1897",
    "lng": "48.4226"
  },
  {
    "country": "RU",
    "name": "Varenikovskaya",
    "lat": "45.12085",
    "lng": "37.64171"
  },
  {
    "country": "RU",
    "name": "Vardane",
    "lat": "43.73179",
    "lng": "39.55428"
  },
  {
    "country": "RU",
    "name": "Valuyki",
    "lat": "50.2035",
    "lng": "38.1067"
  },
  {
    "country": "RU",
    "name": "Valerik",
    "lat": "43.17972",
    "lng": "45.40806"
  },
  {
    "country": "RU",
    "name": "Valerianovsk",
    "lat": "58.7608",
    "lng": "59.5596"
  },
  {
    "country": "RU",
    "name": "Valday",
    "lat": "57.97472",
    "lng": "33.2525"
  },
  {
    "country": "RU",
    "name": "Vakhtan",
    "lat": "57.96592",
    "lng": "46.68886"
  },
  {
    "country": "RU",
    "name": "Vakhrushi",
    "lat": "58.68472",
    "lng": "50.02611"
  },
  {
    "country": "RU",
    "name": "Vagonoremont",
    "lat": "55.9",
    "lng": "37.55"
  },
  {
    "country": "RU",
    "name": "Vadinsk",
    "lat": "53.69157",
    "lng": "43.05744"
  },
  {
    "country": "RU",
    "name": "Vad",
    "lat": "55.53009",
    "lng": "44.21137"
  },
  {
    "country": "RU",
    "name": "Vacha",
    "lat": "55.8035",
    "lng": "42.7709"
  },
  {
    "country": "RU",
    "name": "Uzunovo",
    "lat": "54.53858",
    "lng": "38.61734"
  },
  {
    "country": "RU",
    "name": "Uzlovaya",
    "lat": "53.98179",
    "lng": "38.17118"
  },
  {
    "country": "RU",
    "name": "Uyemskiy",
    "lat": "64.4743",
    "lng": "40.8524"
  },
  {
    "country": "RU",
    "name": "Uvary",
    "lat": "46.04575",
    "lng": "48.03558"
  },
  {
    "country": "RU",
    "name": "Uvarovo",
    "lat": "51.98486",
    "lng": "42.26147"
  },
  {
    "country": "RU",
    "name": "Uvarovka",
    "lat": "55.52778",
    "lng": "35.60611"
  },
  {
    "country": "RU",
    "name": "Uva",
    "lat": "56.99081",
    "lng": "52.18517"
  },
  {
    "country": "RU",
    "name": "Utsmiyurt",
    "lat": "43.53481",
    "lng": "46.46952"
  },
  {
    "country": "RU",
    "name": "Utorgosh",
    "lat": "58.28127",
    "lng": "30.25344"
  },
  {
    "country": "RU",
    "name": "Utevka",
    "lat": "52.9035",
    "lng": "50.9495"
  },
  {
    "country": "RU",
    "name": "Utamysh",
    "lat": "42.40718",
    "lng": "47.75109"
  },
  {
    "country": "RU",
    "name": "Usvyaty",
    "lat": "55.74556",
    "lng": "30.75333"
  },
  {
    "country": "RU",
    "name": "Usukhchay",
    "lat": "41.42245",
    "lng": "47.91318"
  },
  {
    "country": "RU",
    "name": "Ustyuzhna",
    "lat": "58.8394",
    "lng": "36.4321"
  },
  {
    "country": "RU",
    "name": "Ust’ye",
    "lat": "59.63043",
    "lng": "39.73596"
  },
  {
    "country": "RU",
    "name": "Ust-Tsilma",
    "lat": "65.44104",
    "lng": "52.14978"
  },
  {
    "country": "RU",
    "name": "Ust’-Shonosha",
    "lat": "61.1531",
    "lng": "41.343"
  },
  {
    "country": "RU",
    "name": "Ust’-Luga",
    "lat": "59.66755",
    "lng": "28.28713"
  },
  {
    "country": "RU",
    "name": "Ust’-Labinsk",
    "lat": "45.21077",
    "lng": "39.68914"
  },
  {
    "country": "RU",
    "name": "Ust’-Kulom",
    "lat": "61.68636",
    "lng": "53.6902"
  },
  {
    "country": "RU",
    "name": "Ust’-Kishert’",
    "lat": "57.3654",
    "lng": "57.2495"
  },
  {
    "country": "RU",
    "name": "Ust’-Katav",
    "lat": "54.9366",
    "lng": "58.1757"
  },
  {
    "country": "RU",
    "name": "Ust’-Kachka",
    "lat": "58.0038",
    "lng": "55.6721"
  },
  {
    "country": "RU",
    "name": "Ust’-Izhora",
    "lat": "59.81194",
    "lng": "30.58139"
  },
  {
    "country": "RU",
    "name": "Ust’-Dzheguta",
    "lat": "44.0834",
    "lng": "41.9763"
  },
  {
    "country": "RU",
    "name": "Ust’-Donetskiy",
    "lat": "47.64189",
    "lng": "40.87182"
  },
  {
    "country": "RU",
    "name": "Uspenskoye",
    "lat": "44.8311",
    "lng": "41.3927"
  },
  {
    "country": "RU",
    "name": "Uspenskaya",
    "lat": "45.76448",
    "lng": "41.06696"
  },
  {
    "country": "RU",
    "name": "Usol’ye",
    "lat": "59.4219",
    "lng": "56.6862"
  },
  {
    "country": "RU",
    "name": "Usogorsk",
    "lat": "63.41064",
    "lng": "48.68722"
  },
  {
    "country": "RU",
    "name": "Usman’",
    "lat": "52.04662",
    "lng": "39.7288"
  },
  {
    "country": "RU",
    "name": "Usisha",
    "lat": "42.25111",
    "lng": "47.39278"
  },
  {
    "country": "RU",
    "name": "Urzhum",
    "lat": "57.11412",
    "lng": "49.99956"
  },
  {
    "country": "RU",
    "name": "Uryv-Pokrovka",
    "lat": "51.1159",
    "lng": "39.16394"
  },
  {
    "country": "RU",
    "name": "Uryupinsk",
    "lat": "50.8047",
    "lng": "42.0138"
  },
  {
    "country": "RU",
    "name": "Urvan’",
    "lat": "43.49222",
    "lng": "43.76056"
  },
  {
    "country": "RU",
    "name": "Urussu",
    "lat": "54.59812",
    "lng": "53.46313"
  },
  {
    "country": "RU",
    "name": "Urus-Martan",
    "lat": "43.13053",
    "lng": "45.53791"
  },
  {
    "country": "RU",
    "name": "Urukh",
    "lat": "43.29335",
    "lng": "44.02647"
  },
  {
    "country": "RU",
    "name": "Urshel’skiy",
    "lat": "55.67833",
    "lng": "40.21692"
  },
  {
    "country": "RU",
    "name": "Urozhaynoye",
    "lat": "44.78833",
    "lng": "44.92278"
  },
  {
    "country": "RU",
    "name": "Urmary",
    "lat": "55.67894",
    "lng": "47.94396"
  },
  {
    "country": "RU",
    "name": "Urman",
    "lat": "54.88314",
    "lng": "56.87417"
  },
  {
    "country": "RU",
    "name": "Urma",
    "lat": "42.53894",
    "lng": "47.28639"
  },
  {
    "country": "RU",
    "name": "Urkarakh",
    "lat": "42.16297",
    "lng": "47.63068"
  },
  {
    "country": "RU",
    "name": "Uritsk",
    "lat": "59.83889",
    "lng": "30.17528"
  },
  {
    "country": "RU",
    "name": "Uren’",
    "lat": "57.45516",
    "lng": "45.78522"
  },
  {
    "country": "RU",
    "name": "Urdoma",
    "lat": "61.75335",
    "lng": "48.5442"
  },
  {
    "country": "RU",
    "name": "Urazovo",
    "lat": "50.0836",
    "lng": "38.0395"
  },
  {
    "country": "RU",
    "name": "Urazovka",
    "lat": "55.40126",
    "lng": "45.6186"
  },
  {
    "country": "RU",
    "name": "Uralets",
    "lat": "57.6614",
    "lng": "59.6497"
  },
  {
    "country": "RU",
    "name": "Upornaya",
    "lat": "44.3914",
    "lng": "41.0196"
  },
  {
    "country": "RU",
    "name": "Untsukul’",
    "lat": "42.71149",
    "lng": "46.78663"
  },
  {
    "country": "RU",
    "name": "Uni",
    "lat": "57.751",
    "lng": "51.4913"
  },
  {
    "country": "RU",
    "name": "Undory",
    "lat": "54.60849",
    "lng": "48.39276"
  },
  {
    "country": "RU",
    "name": "Unecha",
    "lat": "52.84591",
    "lng": "32.67394"
  },
  {
    "country": "RU",
    "name": "Umet",
    "lat": "54.11611",
    "lng": "42.6975"
  },
  {
    "country": "RU",
    "name": "Umba",
    "lat": "66.68706",
    "lng": "34.34291"
  },
  {
    "country": "RU",
    "name": "Ulyanovsk",
    "lat": "54.32824",
    "lng": "48.38657"
  },
  {
    "country": "RU",
    "name": "Ul’yanovka",
    "lat": "59.63944",
    "lng": "30.76472"
  },
  {
    "country": "RU",
    "name": "Ulu-Telyak",
    "lat": "54.9157",
    "lng": "56.9827"
  },
  {
    "country": "RU",
    "name": "Ulukulevo",
    "lat": "54.4355",
    "lng": "56.3221"
  },
  {
    "country": "RU",
    "name": "Ullubiyaul",
    "lat": "42.59689",
    "lng": "47.71825"
  },
  {
    "country": "RU",
    "name": "Ulluaya",
    "lat": "42.37377",
    "lng": "47.37451"
  },
  {
    "country": "RU",
    "name": "Ukhta",
    "lat": "63.56705",
    "lng": "53.68348"
  },
  {
    "country": "RU",
    "name": "Ukholovo",
    "lat": "53.7929",
    "lng": "40.4892"
  },
  {
    "country": "RU",
    "name": "Uinskoye",
    "lat": "56.88174",
    "lng": "56.58135"
  },
  {
    "country": "RU",
    "name": "Ugra",
    "lat": "54.77775",
    "lng": "34.32674"
  },
  {
    "country": "RU",
    "name": "Uglyanets",
    "lat": "51.81908",
    "lng": "39.59606"
  },
  {
    "country": "RU",
    "name": "Uglovka",
    "lat": "58.23917",
    "lng": "33.51083"
  },
  {
    "country": "RU",
    "name": "Uglich",
    "lat": "57.5275",
    "lng": "38.33167"
  },
  {
    "country": "RU",
    "name": "Ugleural’skiy",
    "lat": "58.9443",
    "lng": "57.5937"
  },
  {
    "country": "RU",
    "name": "Uglerodovskiy",
    "lat": "48.14558",
    "lng": "40.06352"
  },
  {
    "country": "RU",
    "name": "Uglegorskiy",
    "lat": "48.24274",
    "lng": "41.2531"
  },
  {
    "country": "RU",
    "name": "Ufimskiy",
    "lat": "56.7084",
    "lng": "58.0517"
  },
  {
    "country": "RU",
    "name": "Ufa",
    "lat": "54.74306",
    "lng": "55.96779"
  },
  {
    "country": "RU",
    "name": "Udobnaya",
    "lat": "44.1932",
    "lng": "41.5529"
  },
  {
    "country": "RU",
    "name": "Udimskiy",
    "lat": "61.14171",
    "lng": "45.91443"
  },
  {
    "country": "RU",
    "name": "Udel’naya",
    "lat": "60.01636",
    "lng": "30.31815"
  },
  {
    "country": "RU",
    "name": "Udel’naya",
    "lat": "55.62536",
    "lng": "38.00285"
  },
  {
    "country": "RU",
    "name": "Uchkulan",
    "lat": "43.45705",
    "lng": "42.09643"
  },
  {
    "country": "RU",
    "name": "Uchkeken",
    "lat": "43.93778",
    "lng": "42.51167"
  },
  {
    "country": "RU",
    "name": "Uchaly",
    "lat": "54.35806",
    "lng": "59.43611"
  },
  {
    "country": "RU",
    "name": "Tyulyachi",
    "lat": "55.89125",
    "lng": "50.23992"
  },
  {
    "country": "RU",
    "name": "Tyul’gan",
    "lat": "52.34049",
    "lng": "56.16604"
  },
  {
    "country": "RU",
    "name": "Tyrnyauz",
    "lat": "43.38278",
    "lng": "42.91833"
  },
  {
    "country": "RU",
    "name": "Tyarlevo",
    "lat": "59.70777",
    "lng": "30.44543"
  },
  {
    "country": "RU",
    "name": "Tver",
    "lat": "56.85836",
    "lng": "35.90057"
  },
  {
    "country": "RU",
    "name": "Tuzha",
    "lat": "57.60615",
    "lng": "47.93597"
  },
  {
    "country": "RU",
    "name": "Tuymazy",
    "lat": "54.60666",
    "lng": "53.7097"
  },
  {
    "country": "RU",
    "name": "Tutayev",
    "lat": "57.88529",
    "lng": "39.5406"
  },
  {
    "country": "RU",
    "name": "Turki",
    "lat": "51.98703",
    "lng": "43.2731"
  },
  {
    "country": "RU",
    "name": "Turgenevo",
    "lat": "54.84555",
    "lng": "46.32968"
  },
  {
    "country": "RU",
    "name": "Tunoshna",
    "lat": "57.54589",
    "lng": "40.12543"
  },
  {
    "country": "RU",
    "name": "Tumak",
    "lat": "46.23436",
    "lng": "48.50627"
  },
  {
    "country": "RU",
    "name": "Tuma",
    "lat": "55.14798",
    "lng": "40.55374"
  },
  {
    "country": "RU",
    "name": "Tul’skiy",
    "lat": "44.51361",
    "lng": "40.17889"
  },
  {
    "country": "RU",
    "name": "Tula",
    "lat": "54.19609",
    "lng": "37.61822"
  },
  {
    "country": "RU",
    "name": "Tukan",
    "lat": "53.8409",
    "lng": "57.4552"
  },
  {
    "country": "RU",
    "name": "Tugolesskiy Bor",
    "lat": "55.55051",
    "lng": "39.82422"
  },
  {
    "country": "RU",
    "name": "Tuchkovo",
    "lat": "55.60111",
    "lng": "36.46806"
  },
  {
    "country": "RU",
    "name": "Tubinskiy",
    "lat": "52.88917",
    "lng": "58.2225"
  },
  {
    "country": "RU",
    "name": "Tuapse",
    "lat": "44.1053",
    "lng": "39.0802"
  },
  {
    "country": "RU",
    "name": "Tsurib",
    "lat": "42.2368",
    "lng": "46.83073"
  },
  {
    "country": "RU",
    "name": "Tsivil’sk",
    "lat": "55.86974",
    "lng": "47.47874"
  },
  {
    "country": "RU",
    "name": "Tsimlyansk",
    "lat": "47.64611",
    "lng": "42.10194"
  },
  {
    "country": "RU",
    "name": "Tsil’na",
    "lat": "54.59533",
    "lng": "48.1414"
  },
  {
    "country": "RU",
    "name": "Tsentoroy",
    "lat": "43.00658",
    "lng": "46.22235"
  },
  {
    "country": "RU",
    "name": "Tselina",
    "lat": "46.53381",
    "lng": "41.03284"
  },
  {
    "country": "RU",
    "name": "Tsagan Aman",
    "lat": "47.5639",
    "lng": "46.7218"
  },
  {
    "country": "RU",
    "name": "Trunovskoye",
    "lat": "45.48778",
    "lng": "42.13583"
  },
  {
    "country": "RU",
    "name": "Trudobelikovskiy",
    "lat": "45.26853",
    "lng": "38.15376"
  },
  {
    "country": "RU",
    "name": "Trudfront",
    "lat": "45.9346",
    "lng": "47.66929"
  },
  {
    "country": "RU",
    "name": "Trubchevsk",
    "lat": "52.5798",
    "lng": "33.7644"
  },
  {
    "country": "RU",
    "name": "Trosna",
    "lat": "52.4446",
    "lng": "35.7791"
  },
  {
    "country": "RU",
    "name": "Troparëvo",
    "lat": "55.65625",
    "lng": "37.48496"
  },
  {
    "country": "RU",
    "name": "Troitskoye",
    "lat": "55.3",
    "lng": "38.53333"
  },
  {
    "country": "RU",
    "name": "Troitskoye",
    "lat": "46.4206",
    "lng": "44.2591"
  },
  {
    "country": "RU",
    "name": "Troitskoye",
    "lat": "43.76219",
    "lng": "44.68415"
  },
  {
    "country": "RU",
    "name": "Troitsko-Pechorsk",
    "lat": "62.70836",
    "lng": "56.19643"
  },
  {
    "country": "RU",
    "name": "Troitskiy",
    "lat": "51.3588",
    "lng": "37.5253"
  },
  {
    "country": "RU",
    "name": "Troitskaya",
    "lat": "45.13493",
    "lng": "38.12544"
  },
  {
    "country": "RU",
    "name": "Troitskaya",
    "lat": "43.30664",
    "lng": "44.98395"
  },
  {
    "country": "RU",
    "name": "Troitsk",
    "lat": "55.48498",
    "lng": "37.30736"
  },
  {
    "country": "RU",
    "name": "Tpig",
    "lat": "41.78007",
    "lng": "47.58896"
  },
  {
    "country": "RU",
    "name": "Tovarkovskiy",
    "lat": "53.68217",
    "lng": "38.2092"
  },
  {
    "country": "RU",
    "name": "Tovarkovo",
    "lat": "54.67617",
    "lng": "35.9386"
  },
  {
    "country": "RU",
    "name": "Totskoye",
    "lat": "52.52478",
    "lng": "52.76228"
  },
  {
    "country": "RU",
    "name": "Tot’ma",
    "lat": "59.97375",
    "lng": "42.76487"
  },
  {
    "country": "RU",
    "name": "Tosno",
    "lat": "59.54",
    "lng": "30.8775"
  },
  {
    "country": "RU",
    "name": "Torzhok",
    "lat": "57.0436",
    "lng": "34.96221"
  },
  {
    "country": "RU",
    "name": "Toropets",
    "lat": "56.49779",
    "lng": "31.63528"
  },
  {
    "country": "RU",
    "name": "Torfyanoy",
    "lat": "58.4916",
    "lng": "49.19786"
  },
  {
    "country": "RU",
    "name": "Torbeyevo",
    "lat": "54.07972",
    "lng": "43.24732"
  },
  {
    "country": "RU",
    "name": "Tonshayevo",
    "lat": "57.73598",
    "lng": "47.01265"
  },
  {
    "country": "RU",
    "name": "Tonkino",
    "lat": "57.37257",
    "lng": "46.46294"
  },
  {
    "country": "RU",
    "name": "Tomsino",
    "lat": "56.45202",
    "lng": "28.53917"
  },
  {
    "country": "RU",
    "name": "Tomilino",
    "lat": "55.65619",
    "lng": "37.94713"
  },
  {
    "country": "RU",
    "name": "Tomarovka",
    "lat": "50.68338",
    "lng": "36.23309"
  },
  {
    "country": "RU",
    "name": "Tol’yatti",
    "lat": "53.5303",
    "lng": "49.3461"
  },
  {
    "country": "RU",
    "name": "Tolstoy-Yurt",
    "lat": "43.44548",
    "lng": "45.77901"
  },
  {
    "country": "RU",
    "name": "Tolstopal’tsevo",
    "lat": "55.61026",
    "lng": "37.21834"
  },
  {
    "country": "RU",
    "name": "Tolmachevo",
    "lat": "58.85973",
    "lng": "29.91091"
  },
  {
    "country": "RU",
    "name": "Tolbazy",
    "lat": "54.02408",
    "lng": "55.88248"
  },
  {
    "country": "RU",
    "name": "Toksovo",
    "lat": "60.15323",
    "lng": "30.51646"
  },
  {
    "country": "RU",
    "name": "Tlyustenkhabl’",
    "lat": "44.982",
    "lng": "39.09773"
  },
  {
    "country": "RU",
    "name": "Tlyarata",
    "lat": "42.10408",
    "lng": "46.3559"
  },
  {
    "country": "RU",
    "name": "Tishchenskoye",
    "lat": "45.46056",
    "lng": "41.67382"
  },
  {
    "country": "RU",
    "name": "Tirlyanskiy",
    "lat": "54.2109",
    "lng": "58.5806"
  },
  {
    "country": "RU",
    "name": "Timashëvsk",
    "lat": "45.61694",
    "lng": "38.94528"
  },
  {
    "country": "RU",
    "name": "Tim",
    "lat": "51.62222",
    "lng": "37.12444"
  },
  {
    "country": "RU",
    "name": "Tikhvin",
    "lat": "59.64511",
    "lng": "33.52937"
  },
  {
    "country": "RU",
    "name": "Tikhoretsk",
    "lat": "45.85472",
    "lng": "40.12528"
  },
  {
    "country": "RU",
    "name": "Teykovo",
    "lat": "56.85796",
    "lng": "40.53692"
  },
  {
    "country": "RU",
    "name": "Adygeysk",
    "lat": "44.88414",
    "lng": "39.19071"
  },
  {
    "country": "RU",
    "name": "Tetyushi",
    "lat": "54.93821",
    "lng": "48.83656"
  },
  {
    "country": "RU",
    "name": "Teryayevo",
    "lat": "56.16974",
    "lng": "36.12545"
  },
  {
    "country": "RU",
    "name": "Terskol",
    "lat": "43.25528",
    "lng": "42.51528"
  },
  {
    "country": "RU",
    "name": "Terskaya",
    "lat": "43.72376",
    "lng": "44.72442"
  },
  {
    "country": "RU",
    "name": "Tersa",
    "lat": "52.08671",
    "lng": "47.53936"
  },
  {
    "country": "RU",
    "name": "Ternevskaya",
    "lat": "45.8513",
    "lng": "40.4125"
  },
  {
    "country": "RU",
    "name": "Ternovka",
    "lat": "51.67803",
    "lng": "41.6375"
  },
  {
    "country": "RU",
    "name": "Teribërka",
    "lat": "69.16088",
    "lng": "35.14527"
  },
  {
    "country": "RU",
    "name": "Tereze",
    "lat": "43.93608",
    "lng": "42.4434"
  },
  {
    "country": "RU",
    "name": "Terekli-Mekteb",
    "lat": "44.1671",
    "lng": "45.86975"
  },
  {
    "country": "RU",
    "name": "Terek",
    "lat": "43.48333",
    "lng": "44.13611"
  },
  {
    "country": "RU",
    "name": "Terbuny",
    "lat": "52.1493",
    "lng": "38.2834"
  },
  {
    "country": "RU",
    "name": "Tyoply Stan",
    "lat": "55.62047",
    "lng": "37.49338"
  },
  {
    "country": "RU",
    "name": "Tëploye",
    "lat": "53.62022",
    "lng": "37.59026"
  },
  {
    "country": "RU",
    "name": "Tëplaya Gora",
    "lat": "58.52444",
    "lng": "59.07278"
  },
  {
    "country": "RU",
    "name": "Ten’gushevo",
    "lat": "54.76861",
    "lng": "42.71889"
  },
  {
    "country": "RU",
    "name": "Temyasovo",
    "lat": "52.99333",
    "lng": "58.10139"
  },
  {
    "country": "RU",
    "name": "Temryuk",
    "lat": "45.27055",
    "lng": "37.38716"
  },
  {
    "country": "RU",
    "name": "Temnikov",
    "lat": "54.63023",
    "lng": "43.21483"
  },
  {
    "country": "RU",
    "name": "Tëmkino",
    "lat": "55.10917",
    "lng": "35.01389"
  },
  {
    "country": "RU",
    "name": "Temizhbekskaya",
    "lat": "45.45078",
    "lng": "41.03866"
  },
  {
    "country": "RU",
    "name": "Temizhbekskaya",
    "lat": "45.44556",
    "lng": "40.845"
  },
  {
    "country": "RU",
    "name": "Temirgoyevskaya",
    "lat": "45.11414",
    "lng": "40.28027"
  },
  {
    "country": "RU",
    "name": "Temiraul",
    "lat": "43.25322",
    "lng": "46.8254"
  },
  {
    "country": "RU",
    "name": "Tekstil’shchiki",
    "lat": "55.70033",
    "lng": "37.74271"
  },
  {
    "country": "RU",
    "name": "Teberda",
    "lat": "43.44565",
    "lng": "41.7448"
  },
  {
    "country": "RU",
    "name": "Tbilisskaya",
    "lat": "45.36333",
    "lng": "40.19"
  },
  {
    "country": "RU",
    "name": "Taytsy",
    "lat": "59.66444",
    "lng": "30.11472"
  },
  {
    "country": "RU",
    "name": "Tatsinskiy",
    "lat": "48.19677",
    "lng": "41.27558"
  },
  {
    "country": "RU",
    "name": "Tatishchevo",
    "lat": "51.67028",
    "lng": "45.59528"
  },
  {
    "country": "RU",
    "name": "Tatarskaya Pishlya",
    "lat": "54.06085",
    "lng": "44.89978"
  },
  {
    "country": "RU",
    "name": "Tatarskaya Kargala",
    "lat": "51.94952",
    "lng": "55.17314"
  },
  {
    "country": "RU",
    "name": "Tatarka",
    "lat": "44.95889",
    "lng": "41.95171"
  },
  {
    "country": "RU",
    "name": "Tashla",
    "lat": "51.77157",
    "lng": "52.7427"
  },
  {
    "country": "RU",
    "name": "Tarusa",
    "lat": "54.72436",
    "lng": "37.17272"
  },
  {
    "country": "RU",
    "name": "Tarumovka",
    "lat": "44.07606",
    "lng": "46.53613"
  },
  {
    "country": "RU",
    "name": "Tarskoye",
    "lat": "42.96699",
    "lng": "44.77114"
  },
  {
    "country": "RU",
    "name": "Tarnogskiy Gorodok",
    "lat": "60.49972",
    "lng": "43.57611"
  },
  {
    "country": "RU",
    "name": "Tarki",
    "lat": "42.94423",
    "lng": "47.49527"
  },
  {
    "country": "RU",
    "name": "Tarkhovka",
    "lat": "60.06687",
    "lng": "29.97435"
  },
  {
    "country": "RU",
    "name": "Taremskoye",
    "lat": "55.92889",
    "lng": "43.04433"
  },
  {
    "country": "RU",
    "name": "Tarasovskiy",
    "lat": "48.72727",
    "lng": "40.36267"
  },
  {
    "country": "RU",
    "name": "Tarasovka",
    "lat": "55.95722",
    "lng": "37.84333"
  },
  {
    "country": "RU",
    "name": "Tambovka",
    "lat": "47.31528",
    "lng": "47.37773"
  },
  {
    "country": "RU",
    "name": "Tambov",
    "lat": "52.73169",
    "lng": "41.44326"
  },
  {
    "country": "RU",
    "name": "Taman’",
    "lat": "45.2117",
    "lng": "36.71609"
  },
  {
    "country": "RU",
    "name": "Tamala",
    "lat": "52.54097",
    "lng": "43.25145"
  },
  {
    "country": "RU",
    "name": "Talovyy",
    "lat": "47.80765",
    "lng": "40.10943"
  },
  {
    "country": "RU",
    "name": "Talovaya",
    "lat": "51.11444",
    "lng": "40.73"
  },
  {
    "country": "RU",
    "name": "Talitsy",
    "lat": "56.52801",
    "lng": "42.3323"
  },
  {
    "country": "RU",
    "name": "Taldom",
    "lat": "56.73333",
    "lng": "37.53333"
  },
  {
    "country": "RU",
    "name": "Talashkino",
    "lat": "54.65471",
    "lng": "32.18325"
  },
  {
    "country": "RU",
    "name": "Agidel’",
    "lat": "55.9077",
    "lng": "53.9355"
  },
  {
    "country": "RU",
    "name": "Taganrog",
    "lat": "47.23617",
    "lng": "38.89688"
  },
  {
    "country": "RU",
    "name": "Taganskiy",
    "lat": "55.73333",
    "lng": "37.66667"
  },
  {
    "country": "RU",
    "name": "Syzran’",
    "lat": "53.1585",
    "lng": "48.4681"
  },
  {
    "country": "RU",
    "name": "Syumsi",
    "lat": "57.11108",
    "lng": "51.61494"
  },
  {
    "country": "RU",
    "name": "Syrtych",
    "lat": "41.83388",
    "lng": "48.22901"
  },
  {
    "country": "RU",
    "name": "Syrskoye",
    "lat": "52.57437",
    "lng": "39.4966"
  },
  {
    "country": "RU",
    "name": "Syrostan",
    "lat": "55.0634",
    "lng": "59.9002"
  },
  {
    "country": "RU",
    "name": "Syntul",
    "lat": "55.00327",
    "lng": "41.29711"
  },
  {
    "country": "RU",
    "name": "Synya",
    "lat": "65.37185",
    "lng": "58.03874"
  },
  {
    "country": "RU",
    "name": "Sylva",
    "lat": "58.0327",
    "lng": "56.7713"
  },
  {
    "country": "RU",
    "name": "Sylva",
    "lat": "57.3092",
    "lng": "58.7734"
  },
  {
    "country": "RU",
    "name": "Syktyvkar",
    "lat": "61.67642",
    "lng": "50.80994"
  },
  {
    "country": "RU",
    "name": "Sychëvo",
    "lat": "55.95771",
    "lng": "36.22785"
  },
  {
    "country": "RU",
    "name": "Sychëvo",
    "lat": "55.06196",
    "lng": "38.71384"
  },
  {
    "country": "RU",
    "name": "Sychëvka",
    "lat": "55.82515",
    "lng": "34.27361"
  },
  {
    "country": "RU",
    "name": "Syava",
    "lat": "58.01457",
    "lng": "46.32216"
  },
  {
    "country": "RU",
    "name": "Syas’stroy",
    "lat": "60.13669",
    "lng": "32.56906"
  },
  {
    "country": "RU",
    "name": "Syamzha",
    "lat": "60.01577",
    "lng": "41.06139"
  },
  {
    "country": "RU",
    "name": "Svobody",
    "lat": "44.02556",
    "lng": "43.05028"
  },
  {
    "country": "RU",
    "name": "Svobodnyy",
    "lat": "52.33039",
    "lng": "46.37122"
  },
  {
    "country": "RU",
    "name": "Sviyazhsk",
    "lat": "55.77329",
    "lng": "48.66051"
  },
  {
    "country": "RU",
    "name": "Sviblovo",
    "lat": "55.85",
    "lng": "37.63333"
  },
  {
    "country": "RU",
    "name": "Svetogorsk",
    "lat": "61.11213",
    "lng": "28.86321"
  },
  {
    "country": "RU",
    "name": "Svetlyy Yar",
    "lat": "48.4748",
    "lng": "44.78096"
  },
  {
    "country": "RU",
    "name": "Svetlyy",
    "lat": "54.67501",
    "lng": "20.13473"
  },
  {
    "country": "RU",
    "name": "Svetlograd",
    "lat": "45.33528",
    "lng": "42.85472"
  },
  {
    "country": "RU",
    "name": "Svetlogorsk",
    "lat": "54.93987",
    "lng": "20.15479"
  },
  {
    "country": "RU",
    "name": "Sverdlovskiy",
    "lat": "55.90968",
    "lng": "38.14978"
  },
  {
    "country": "RU",
    "name": "Sven’",
    "lat": "53.18222",
    "lng": "34.55111"
  },
  {
    "country": "RU",
    "name": "Svecha",
    "lat": "58.27849",
    "lng": "47.51636"
  },
  {
    "country": "RU",
    "name": "Svatkovo",
    "lat": "56.38333",
    "lng": "38.21667"
  },
  {
    "country": "RU",
    "name": "Suzëmka",
    "lat": "52.31834",
    "lng": "34.07899"
  },
  {
    "country": "RU",
    "name": "Suzdal’",
    "lat": "56.42274",
    "lng": "40.44668"
  },
  {
    "country": "RU",
    "name": "Suvorovskaya",
    "lat": "44.1901",
    "lng": "42.6595"
  },
  {
    "country": "RU",
    "name": "Suvorov",
    "lat": "54.1223",
    "lng": "36.49657"
  },
  {
    "country": "RU",
    "name": "Suslonger",
    "lat": "56.31556",
    "lng": "48.25306"
  },
  {
    "country": "RU",
    "name": "Susanino",
    "lat": "58.14881",
    "lng": "41.59483"
  },
  {
    "country": "RU",
    "name": "Surskoye",
    "lat": "54.4821",
    "lng": "46.7214"
  },
  {
    "country": "RU",
    "name": "Sursk",
    "lat": "53.07542",
    "lng": "45.68461"
  },
  {
    "country": "RU",
    "name": "Surovikino",
    "lat": "48.60734",
    "lng": "42.84621"
  },
  {
    "country": "RU",
    "name": "Surovatikha",
    "lat": "55.76516",
    "lng": "43.89845"
  },
  {
    "country": "RU",
    "name": "Surkhakhi",
    "lat": "43.1875",
    "lng": "44.90194"
  },
  {
    "country": "RU",
    "name": "Surgut",
    "lat": "53.92498",
    "lng": "51.20348"
  },
  {
    "country": "RU",
    "name": "Surazh",
    "lat": "53.01747",
    "lng": "32.39178"
  },
  {
    "country": "RU",
    "name": "Sura",
    "lat": "53.88786",
    "lng": "45.74192"
  },
  {
    "country": "RU",
    "name": "Suponevo",
    "lat": "53.20492",
    "lng": "34.29597"
  },
  {
    "country": "RU",
    "name": "Suoyarvi",
    "lat": "62.08333",
    "lng": "32.35"
  },
  {
    "country": "RU",
    "name": "Sunzha",
    "lat": "43.05862",
    "lng": "44.82281"
  },
  {
    "country": "RU",
    "name": "Suna",
    "lat": "57.83379",
    "lng": "50.05884"
  },
  {
    "country": "RU",
    "name": "Sulak",
    "lat": "43.27342",
    "lng": "47.51463"
  },
  {
    "country": "RU",
    "name": "Suksun",
    "lat": "57.1431",
    "lng": "57.3949"
  },
  {
    "country": "RU",
    "name": "Sukkozero",
    "lat": "63.17018",
    "lng": "32.34436"
  },
  {
    "country": "RU",
    "name": "Sukko",
    "lat": "44.79945",
    "lng": "37.42145"
  },
  {
    "country": "RU",
    "name": "Sukhodol",
    "lat": "53.90063",
    "lng": "51.2117"
  },
  {
    "country": "RU",
    "name": "Sukhobezvodnoye",
    "lat": "57.04913",
    "lng": "44.88909"
  },
  {
    "country": "RU",
    "name": "Sukhinichi",
    "lat": "54.09989",
    "lng": "35.34254"
  },
  {
    "country": "RU",
    "name": "Sukhaya Buyvola",
    "lat": "45.15333",
    "lng": "42.99556"
  },
  {
    "country": "RU",
    "name": "Sudzha",
    "lat": "51.1976",
    "lng": "35.2726"
  },
  {
    "country": "RU",
    "name": "Sudogda",
    "lat": "55.95394",
    "lng": "40.86291"
  },
  {
    "country": "RU",
    "name": "Sudislavl’",
    "lat": "57.88175",
    "lng": "41.70829"
  },
  {
    "country": "RU",
    "name": "Suda",
    "lat": "59.15254",
    "lng": "37.5582"
  },
  {
    "country": "RU",
    "name": "Subkhankulovo",
    "lat": "54.55741",
    "lng": "53.81153"
  },
  {
    "country": "RU",
    "name": "Stupino",
    "lat": "54.90083",
    "lng": "38.07083"
  },
  {
    "country": "RU",
    "name": "Stulovo",
    "lat": "58.7225",
    "lng": "50.14389"
  },
  {
    "country": "RU",
    "name": "Strunino",
    "lat": "56.37328",
    "lng": "38.58321"
  },
  {
    "country": "RU",
    "name": "Strugi-Krasnyye",
    "lat": "58.26754",
    "lng": "29.11137"
  },
  {
    "country": "RU",
    "name": "Stromyn’",
    "lat": "56.04347",
    "lng": "38.48318"
  },
  {
    "country": "RU",
    "name": "Stroitel’",
    "lat": "50.78543",
    "lng": "36.4831"
  },
  {
    "country": "RU",
    "name": "Strogino",
    "lat": "55.81838",
    "lng": "37.41224"
  },
  {
    "country": "RU",
    "name": "Strizhi",
    "lat": "58.45758",
    "lng": "49.28667"
  },
  {
    "country": "RU",
    "name": "Strel'na",
    "lat": "59.85189",
    "lng": "30.03611"
  },
  {
    "country": "RU",
    "name": "Strelka",
    "lat": "45.20633",
    "lng": "37.2865"
  },
  {
    "country": "RU",
    "name": "Strelitsa",
    "lat": "51.6083",
    "lng": "38.9102"
  },
  {
    "country": "RU",
    "name": "Storozhevaya",
    "lat": "43.87886",
    "lng": "41.45143"
  },
  {
    "country": "RU",
    "name": "Stolbovaya",
    "lat": "55.25021",
    "lng": "37.49249"
  },
  {
    "country": "RU",
    "name": "Stolbishchi",
    "lat": "55.64679",
    "lng": "49.21595"
  },
  {
    "country": "RU",
    "name": "Stodolishche",
    "lat": "54.18594",
    "lng": "32.64925"
  },
  {
    "country": "RU",
    "name": "Sterlitamak",
    "lat": "53.62462",
    "lng": "55.95015"
  },
  {
    "country": "RU",
    "name": "Sterlibashevo",
    "lat": "53.43755",
    "lng": "55.2578"
  },
  {
    "country": "RU",
    "name": "Stepnoye",
    "lat": "51.37972",
    "lng": "46.84917"
  },
  {
    "country": "RU",
    "name": "Stepantsevo",
    "lat": "56.13143",
    "lng": "41.7032"
  },
  {
    "country": "RU",
    "name": "Stavrovo",
    "lat": "56.13311",
    "lng": "40.01295"
  },
  {
    "country": "RU",
    "name": "Stavropol’",
    "lat": "45.0428",
    "lng": "41.9734"
  },
  {
    "country": "RU",
    "name": "Staryy Urukh",
    "lat": "43.34041",
    "lng": "44.01868"
  },
  {
    "country": "RU",
    "name": "Staryy Oskol",
    "lat": "51.29667",
    "lng": "37.84167"
  },
  {
    "country": "RU",
    "name": "Staryye Atagi",
    "lat": "43.12028",
    "lng": "45.74056"
  },
  {
    "country": "RU",
    "name": "Staryy Cherek",
    "lat": "43.47139",
    "lng": "43.84694"
  },
  {
    "country": "RU",
    "name": "Starozhilovo",
    "lat": "54.2254",
    "lng": "39.916"
  },
  {
    "country": "RU",
    "name": "Staroyur’yevo",
    "lat": "53.31611",
    "lng": "40.70806"
  },
  {
    "country": "RU",
    "name": "Staroye Drozhzhanoye",
    "lat": "54.72657",
    "lng": "47.56766"
  },
  {
    "country": "RU",
    "name": "Starovelichkovskaya",
    "lat": "45.42884",
    "lng": "38.73261"
  },
  {
    "country": "RU",
    "name": "Staroutkinsk",
    "lat": "57.23017",
    "lng": "59.33483"
  },
  {
    "country": "RU",
    "name": "Starotitarovskaya",
    "lat": "45.21938",
    "lng": "37.15476"
  },
  {
    "country": "RU",
    "name": "Starotimoshkino",
    "lat": "53.71908",
    "lng": "47.53116"
  },
  {
    "country": "RU",
    "name": "Starosubkhangulovo",
    "lat": "53.1031",
    "lng": "57.4423"
  },
  {
    "country": "RU",
    "name": "Staroshcherbinovskaya",
    "lat": "46.6311",
    "lng": "38.6742"
  },
  {
    "country": "RU",
    "name": "Staropavlovskaya",
    "lat": "43.84889",
    "lng": "43.63278"
  },
  {
    "country": "RU",
    "name": "Staronizhestebliyevskaya",
    "lat": "45.38315",
    "lng": "38.44304"
  },
  {
    "country": "RU",
    "name": "Staromyshastovskaya",
    "lat": "45.34329",
    "lng": "39.07608"
  },
  {
    "country": "RU",
    "name": "Starominskaya",
    "lat": "46.53",
    "lng": "39.04972"
  },
  {
    "country": "RU",
    "name": "Staroleushkovskaya",
    "lat": "45.98666",
    "lng": "39.75987"
  },
  {
    "country": "RU",
    "name": "Starokucherganovka",
    "lat": "46.32476",
    "lng": "47.9555"
  },
  {
    "country": "RU",
    "name": "Starokorsunskaya",
    "lat": "45.05727",
    "lng": "39.31611"
  },
  {
    "country": "RU",
    "name": "Starodzhereliyevskaya",
    "lat": "45.47599",
    "lng": "38.2968"
  },
  {
    "country": "RU",
    "name": "Starodubskoye",
    "lat": "44.56306",
    "lng": "44.01528"
  },
  {
    "country": "RU",
    "name": "Starodub",
    "lat": "52.58444",
    "lng": "32.76333"
  },
  {
    "country": "RU",
    "name": "Staroderevyankovskaya",
    "lat": "46.1276",
    "lng": "38.9674"
  },
  {
    "country": "RU",
    "name": "Starocherkasskaya",
    "lat": "47.24077",
    "lng": "40.04186"
  },
  {
    "country": "RU",
    "name": "Starobaltachevo",
    "lat": "56.0017",
    "lng": "55.928"
  },
  {
    "country": "RU",
    "name": "Staritsa",
    "lat": "56.50752",
    "lng": "34.93544"
  },
  {
    "country": "RU",
    "name": "Staraya Vichuga",
    "lat": "57.26833",
    "lng": "41.87873"
  },
  {
    "country": "RU",
    "name": "Staraya Toropa",
    "lat": "56.28012",
    "lng": "31.67018"
  },
  {
    "country": "RU",
    "name": "Staraya Sunzha",
    "lat": "43.33542",
    "lng": "45.74377"
  },
  {
    "country": "RU",
    "name": "Staraya Stanitsa",
    "lat": "48.34579",
    "lng": "40.29376"
  },
  {
    "country": "RU",
    "name": "Staraya Stanitsa",
    "lat": "45.0098",
    "lng": "41.1512"
  },
  {
    "country": "RU",
    "name": "Staraya Russa",
    "lat": "57.99439",
    "lng": "31.36081"
  },
  {
    "country": "RU",
    "name": "Staraya Poltavka",
    "lat": "50.47715",
    "lng": "46.48144"
  },
  {
    "country": "RU",
    "name": "Staraya Mayna",
    "lat": "54.60417",
    "lng": "48.93056"
  },
  {
    "country": "RU",
    "name": "Staraya Ladoga",
    "lat": "59.99872",
    "lng": "32.29413"
  },
  {
    "country": "RU",
    "name": "Staraya Kupavna",
    "lat": "55.80799",
    "lng": "38.1805"
  },
  {
    "country": "RU",
    "name": "Staraya Kulatka",
    "lat": "52.72778",
    "lng": "47.61788"
  },
  {
    "country": "RU",
    "name": "Staraya Derevnya",
    "lat": "59.98834",
    "lng": "30.24296"
  },
  {
    "country": "RU",
    "name": "Staraya",
    "lat": "59.92749",
    "lng": "30.62765"
  },
  {
    "country": "RU",
    "name": "Star’",
    "lat": "53.62362",
    "lng": "34.15183"
  },
  {
    "country": "RU",
    "name": "Stanovoye",
    "lat": "52.76384",
    "lng": "38.35818"
  },
  {
    "country": "RU",
    "name": "Srednyaya Yelyuzan’",
    "lat": "53.0241",
    "lng": "45.9529"
  },
  {
    "country": "RU",
    "name": "Srednyaya Akhtuba",
    "lat": "48.70998",
    "lng": "44.86724"
  },
  {
    "country": "RU",
    "name": "Sredniy Ikorets",
    "lat": "51.06749",
    "lng": "39.75838"
  },
  {
    "country": "RU",
    "name": "Spokoynaya",
    "lat": "44.2468",
    "lng": "41.4015"
  },
  {
    "country": "RU",
    "name": "Spitsevka",
    "lat": "45.12306",
    "lng": "42.5125"
  },
  {
    "country": "RU",
    "name": "Spirovo",
    "lat": "57.41905",
    "lng": "34.97658"
  },
  {
    "country": "RU",
    "name": "Spiridonovka",
    "lat": "53.09248",
    "lng": "50.64621"
  },
  {
    "country": "RU",
    "name": "Spas-Zaulok",
    "lat": "56.48333",
    "lng": "36.56667"
  },
  {
    "country": "RU",
    "name": "Spassk-Ryazanskiy",
    "lat": "54.404",
    "lng": "40.3762"
  },
  {
    "country": "RU",
    "name": "Spasskoye-Lutovinovo",
    "lat": "53.37012",
    "lng": "36.62297"
  },
  {
    "country": "RU",
    "name": "Spasskoye",
    "lat": "55.86048",
    "lng": "45.69695"
  },
  {
    "country": "RU",
    "name": "Spas-Klepiki",
    "lat": "55.13472",
    "lng": "40.17673"
  },
  {
    "country": "RU",
    "name": "Spas-Demensk",
    "lat": "54.41222",
    "lng": "34.02257"
  },
  {
    "country": "RU",
    "name": "Sozimskiy",
    "lat": "59.74178",
    "lng": "52.24821"
  },
  {
    "country": "RU",
    "name": "Sovetskoye",
    "lat": "51.44255",
    "lng": "46.7424"
  },
  {
    "country": "RU",
    "name": "Sovetskoye",
    "lat": "47.30868",
    "lng": "44.52162"
  },
  {
    "country": "RU",
    "name": "Kashkhatau",
    "lat": "43.31848",
    "lng": "43.60804"
  },
  {
    "country": "RU",
    "name": "Shatoy",
    "lat": "42.87143",
    "lng": "45.68865"
  },
  {
    "country": "RU",
    "name": "Khebda",
    "lat": "42.44423",
    "lng": "46.55172"
  },
  {
    "country": "RU",
    "name": "Sovetskiy",
    "lat": "60.53945",
    "lng": "28.67756"
  },
  {
    "country": "RU",
    "name": "Sovetskiy",
    "lat": "56.75833",
    "lng": "48.47611"
  },
  {
    "country": "RU",
    "name": "Sovetskaya",
    "lat": "49.00912",
    "lng": "42.12178"
  },
  {
    "country": "RU",
    "name": "Sovetskaya",
    "lat": "44.77694",
    "lng": "41.17222"
  },
  {
    "country": "RU",
    "name": "Sovetskaya",
    "lat": "44.02667",
    "lng": "44.05"
  },
  {
    "country": "RU",
    "name": "Sovetsk",
    "lat": "57.58475",
    "lng": "48.95844"
  },
  {
    "country": "RU",
    "name": "Sovetsk",
    "lat": "55.08392",
    "lng": "21.87851"
  },
  {
    "country": "RU",
    "name": "Sotnikovskoye",
    "lat": "45.00389",
    "lng": "43.77722"
  },
  {
    "country": "RU",
    "name": "Sosnovyy Bor",
    "lat": "59.8996",
    "lng": "29.08574"
  },
  {
    "country": "RU",
    "name": "Sosnovoborsk",
    "lat": "53.29066",
    "lng": "46.24849"
  },
  {
    "country": "RU",
    "name": "Sosnovo",
    "lat": "60.55145",
    "lng": "30.21441"
  },
  {
    "country": "RU",
    "name": "Sosnovka",
    "lat": "56.25496",
    "lng": "51.28419"
  },
  {
    "country": "RU",
    "name": "Sosnovka",
    "lat": "54.71161",
    "lng": "43.29774"
  },
  {
    "country": "RU",
    "name": "Sosnovka",
    "lat": "53.23593",
    "lng": "41.36859"
  },
  {
    "country": "RU",
    "name": "Sosnovaya Polyana",
    "lat": "59.83528",
    "lng": "30.14667"
  },
  {
    "country": "RU",
    "name": "Sosnogorsk",
    "lat": "63.60229",
    "lng": "53.88175"
  },
  {
    "country": "RU",
    "name": "Soskovo",
    "lat": "52.74752",
    "lng": "35.38277"
  },
  {
    "country": "RU",
    "name": "Sosenskiy",
    "lat": "54.05899",
    "lng": "35.96228"
  },
  {
    "country": "RU",
    "name": "Sortavala",
    "lat": "61.71233",
    "lng": "30.70953"
  },
  {
    "country": "RU",
    "name": "Sorochinsk",
    "lat": "52.4338",
    "lng": "53.1583"
  },
  {
    "country": "RU",
    "name": "Sonkovo",
    "lat": "57.77816",
    "lng": "37.15707"
  },
  {
    "country": "RU",
    "name": "Somovo",
    "lat": "51.74098",
    "lng": "39.36655"
  },
  {
    "country": "RU",
    "name": "Solyanka",
    "lat": "46.3889",
    "lng": "48.01755"
  },
  {
    "country": "RU",
    "name": "Sol’vychegodsk",
    "lat": "61.33046",
    "lng": "46.91559"
  },
  {
    "country": "RU",
    "name": "Soluno-Dmitriyevskoye",
    "lat": "44.4074",
    "lng": "42.724"
  },
  {
    "country": "RU",
    "name": "Sol’tsy",
    "lat": "58.12387",
    "lng": "30.32377"
  },
  {
    "country": "RU",
    "name": "Solotcha",
    "lat": "54.7897",
    "lng": "39.83336"
  },
  {
    "country": "RU",
    "name": "Solomenskoye",
    "lat": "44.21667",
    "lng": "44.35278"
  },
  {
    "country": "RU",
    "name": "Solntsevo",
    "lat": "55.63711",
    "lng": "37.38115"
  },
  {
    "country": "RU",
    "name": "Solntsevo",
    "lat": "51.41853",
    "lng": "36.7499"
  },
  {
    "country": "RU",
    "name": "Solnechnoye",
    "lat": "60.15612",
    "lng": "29.94753"
  },
  {
    "country": "RU",
    "name": "Solnechnogorsk",
    "lat": "56.18333",
    "lng": "36.98333"
  },
  {
    "country": "RU",
    "name": "Sol’-Iletsk",
    "lat": "51.1631",
    "lng": "54.99176"
  },
  {
    "country": "RU",
    "name": "Solikamsk",
    "lat": "59.6316",
    "lng": "56.7685"
  },
  {
    "country": "RU",
    "name": "Soligalich",
    "lat": "59.0796",
    "lng": "42.28526"
  },
  {
    "country": "RU",
    "name": "Solginskiy",
    "lat": "61.05",
    "lng": "41.34278"
  },
  {
    "country": "RU",
    "name": "Soldatskaya",
    "lat": "43.81806",
    "lng": "43.81583"
  },
  {
    "country": "RU",
    "name": "Soldato-Aleksandrovskoye",
    "lat": "44.26528",
    "lng": "43.75611"
  },
  {
    "country": "RU",
    "name": "Sokol’skoye",
    "lat": "57.14122",
    "lng": "43.15895"
  },
  {
    "country": "RU",
    "name": "Sokolovyy",
    "lat": "51.56857",
    "lng": "45.83312"
  },
  {
    "country": "RU",
    "name": "Sokolovskoye",
    "lat": "45.25833",
    "lng": "40.67972"
  },
  {
    "country": "RU",
    "name": "Sokolovo-Kundryuchenskiy",
    "lat": "47.83536",
    "lng": "39.94711"
  },
  {
    "country": "RU",
    "name": "Sokol’niki",
    "lat": "55.80202",
    "lng": "37.67159"
  },
  {
    "country": "RU",
    "name": "Sokol",
    "lat": "55.8",
    "lng": "37.51667"
  },
  {
    "country": "RU",
    "name": "Sokol",
    "lat": "59.46167",
    "lng": "40.12056"
  },
  {
    "country": "RU",
    "name": "Sofrino",
    "lat": "56.15",
    "lng": "37.93333"
  },
  {
    "country": "RU",
    "name": "Sochi",
    "lat": "43.59917",
    "lng": "39.72569"
  },
  {
    "country": "RU",
    "name": "Sobinka",
    "lat": "55.98553",
    "lng": "40.01111"
  },
  {
    "country": "RU",
    "name": "Snegiri",
    "lat": "55.88867",
    "lng": "37.02421"
  },
  {
    "country": "RU",
    "name": "Smyshlyayevka",
    "lat": "53.23913",
    "lng": "50.39072"
  },
  {
    "country": "RU",
    "name": "Smolino",
    "lat": "56.27526",
    "lng": "43.09109"
  },
  {
    "country": "RU",
    "name": "Smolenskaya",
    "lat": "44.78636",
    "lng": "38.80333"
  },
  {
    "country": "RU",
    "name": "Smolensk",
    "lat": "54.7818",
    "lng": "32.0401"
  },
  {
    "country": "RU",
    "name": "Slobodskoy",
    "lat": "58.73222",
    "lng": "50.17722"
  },
  {
    "country": "RU",
    "name": "Slobodka",
    "lat": "55.86667",
    "lng": "37.58333"
  },
  {
    "country": "RU",
    "name": "Sloboda",
    "lat": "51.1421",
    "lng": "40.3021"
  },
  {
    "country": "RU",
    "name": "Slavyansk-na-Kubani",
    "lat": "45.2558",
    "lng": "38.1256"
  },
  {
    "country": "RU",
    "name": "Slavsk",
    "lat": "55.0425",
    "lng": "21.67704"
  },
  {
    "country": "RU",
    "name": "Slashchevskaya",
    "lat": "49.8599",
    "lng": "42.3362"
  },
  {
    "country": "RU",
    "name": "Slantsy",
    "lat": "59.11817",
    "lng": "28.09137"
  },
  {
    "country": "RU",
    "name": "Skuratovskiy",
    "lat": "54.10152",
    "lng": "37.60384"
  },
  {
    "country": "RU",
    "name": "Skoropuskovskiy",
    "lat": "56.36667",
    "lng": "38.16667"
  },
  {
    "country": "RU",
    "name": "Skorodnoye",
    "lat": "51.07101",
    "lng": "37.22756"
  },
  {
    "country": "RU",
    "name": "Skopin",
    "lat": "53.82486",
    "lng": "39.55053"
  },
  {
    "country": "RU",
    "name": "Skolkovo",
    "lat": "55.68784",
    "lng": "37.36836"
  },
  {
    "country": "RU",
    "name": "Skhodnya",
    "lat": "55.94806",
    "lng": "37.29778"
  },
  {
    "country": "RU",
    "name": "Sizyy Bugor",
    "lat": "46.21343",
    "lng": "48.50462"
  },
  {
    "country": "RU",
    "name": "Siverskiy",
    "lat": "59.35444",
    "lng": "30.07833"
  },
  {
    "country": "RU",
    "name": "Siva",
    "lat": "58.38204",
    "lng": "54.38037"
  },
  {
    "country": "RU",
    "name": "Siukh",
    "lat": "42.5999",
    "lng": "46.54462"
  },
  {
    "country": "RU",
    "name": "Sitniki",
    "lat": "56.45529",
    "lng": "44.06658"
  },
  {
    "country": "RU",
    "name": "Sista-Palkino",
    "lat": "59.80042",
    "lng": "28.91049"
  },
  {
    "country": "RU",
    "name": "Sinyavskoye",
    "lat": "47.27703",
    "lng": "39.27888"
  },
  {
    "country": "RU",
    "name": "Sinyavino",
    "lat": "59.90781",
    "lng": "31.0711"
  },
  {
    "country": "RU",
    "name": "Sinodskoye",
    "lat": "51.9918",
    "lng": "46.67009"
  },
  {
    "country": "RU",
    "name": "Novosin’kovo",
    "lat": "56.37737",
    "lng": "37.32871"
  },
  {
    "country": "RU",
    "name": "Sinegorskiy",
    "lat": "48.01389",
    "lng": "40.84468"
  },
  {
    "country": "RU",
    "name": "Sindor",
    "lat": "62.86286",
    "lng": "51.89051"
  },
  {
    "country": "RU",
    "name": "Sim",
    "lat": "54.993",
    "lng": "57.6982"
  },
  {
    "country": "RU",
    "name": "Silikatnyy",
    "lat": "53.98957",
    "lng": "48.32749"
  },
  {
    "country": "RU",
    "name": "Sigayevo",
    "lat": "56.42163",
    "lng": "53.77566"
  },
  {
    "country": "RU",
    "name": "Sibay",
    "lat": "52.71806",
    "lng": "58.66583"
  },
  {
    "country": "RU",
    "name": "Shvartsevskiy",
    "lat": "54.09174",
    "lng": "37.99053"
  },
  {
    "country": "RU",
    "name": "Shuyskoye",
    "lat": "59.37356",
    "lng": "41.03047"
  },
  {
    "country": "RU",
    "name": "Shuya",
    "lat": "61.95251",
    "lng": "34.23271"
  },
  {
    "country": "RU",
    "name": "Shuya",
    "lat": "56.84865",
    "lng": "41.38833"
  },
  {
    "country": "RU",
    "name": "Shuvalovo",
    "lat": "60.04903",
    "lng": "30.2936"
  },
  {
    "country": "RU",
    "name": "Shushary",
    "lat": "59.80917",
    "lng": "30.38167"
  },
  {
    "country": "RU",
    "name": "Shun’ga",
    "lat": "62.60263",
    "lng": "34.9468"
  },
  {
    "country": "RU",
    "name": "Shumyachi",
    "lat": "53.85833",
    "lng": "32.42417"
  },
  {
    "country": "RU",
    "name": "Shumikhinskiy",
    "lat": "58.7448",
    "lng": "57.6926"
  },
  {
    "country": "RU",
    "name": "Shumeyka",
    "lat": "51.56361",
    "lng": "46.24833"
  },
  {
    "country": "RU",
    "name": "Shumerlya",
    "lat": "55.5005",
    "lng": "46.41288"
  },
  {
    "country": "RU",
    "name": "Shugurovo",
    "lat": "54.50828",
    "lng": "52.13265"
  },
  {
    "country": "RU",
    "name": "Shudayag",
    "lat": "63.52665",
    "lng": "53.60582"
  },
  {
    "country": "RU",
    "name": "Mikhaylovsk",
    "lat": "45.12833",
    "lng": "42.02556"
  },
  {
    "country": "RU",
    "name": "Shovgenovskiy",
    "lat": "45.01028",
    "lng": "40.225"
  },
  {
    "country": "RU",
    "name": "Shonguy",
    "lat": "68.75261",
    "lng": "33.14595"
  },
  {
    "country": "RU",
    "name": "Sholokhovskiy",
    "lat": "48.28071",
    "lng": "41.04592"
  },
  {
    "country": "RU",
    "name": "Kvartsitnyy",
    "lat": "61.49321",
    "lng": "35.02888"
  },
  {
    "country": "RU",
    "name": "Shlissel’burg",
    "lat": "59.9473",
    "lng": "31.03845"
  },
  {
    "country": "RU",
    "name": "Shkurinskaya",
    "lat": "46.5858",
    "lng": "39.3599"
  },
  {
    "country": "RU",
    "name": "Shirokovskiy",
    "lat": "58.8411",
    "lng": "57.785"
  },
  {
    "country": "RU",
    "name": "Shirochanka",
    "lat": "46.64968",
    "lng": "38.39782"
  },
  {
    "country": "RU",
    "name": "Shiringushi",
    "lat": "53.84851",
    "lng": "42.76759"
  },
  {
    "country": "RU",
    "name": "Shipitsyno",
    "lat": "61.28056",
    "lng": "46.52083"
  },
  {
    "country": "RU",
    "name": "Shimsk",
    "lat": "58.21201",
    "lng": "30.71269"
  },
  {
    "country": "RU",
    "name": "Shimorskoye",
    "lat": "55.3281",
    "lng": "42.0256"
  },
  {
    "country": "RU",
    "name": "Shilovo",
    "lat": "54.3204",
    "lng": "40.874"
  },
  {
    "country": "RU",
    "name": "Shilovo",
    "lat": "51.54583",
    "lng": "39.08917"
  },
  {
    "country": "RU",
    "name": "Shil’da",
    "lat": "51.8143",
    "lng": "59.7744"
  },
  {
    "country": "RU",
    "name": "Shikhazany",
    "lat": "55.56047",
    "lng": "47.39297"
  },
  {
    "country": "RU",
    "name": "Shikhany",
    "lat": "52.11776",
    "lng": "47.1986"
  },
  {
    "country": "RU",
    "name": "Shigony",
    "lat": "53.3875",
    "lng": "48.6777"
  },
  {
    "country": "RU",
    "name": "Sheremet’yevskiy",
    "lat": "55.97583",
    "lng": "37.49417"
  },
  {
    "country": "RU",
    "name": "Shepsi",
    "lat": "44.0355",
    "lng": "39.1474"
  },
  {
    "country": "RU",
    "name": "Shentala",
    "lat": "54.45",
    "lng": "51.48333"
  },
  {
    "country": "RU",
    "name": "Shenkursk",
    "lat": "62.1091",
    "lng": "42.89595"
  },
  {
    "country": "RU",
    "name": "Shemysheyka",
    "lat": "52.89196",
    "lng": "45.39282"
  },
  {
    "country": "RU",
    "name": "Shemursha",
    "lat": "54.88663",
    "lng": "47.51893"
  },
  {
    "country": "RU",
    "name": "Shemordan",
    "lat": "56.1856",
    "lng": "50.3972"
  },
  {
    "country": "RU",
    "name": "Shemëtovo",
    "lat": "56.52764",
    "lng": "38.07518"
  },
  {
    "country": "RU",
    "name": "Sheltozero",
    "lat": "61.36667",
    "lng": "35.36667"
  },
  {
    "country": "RU",
    "name": "Shelkovskaya",
    "lat": "43.50804",
    "lng": "46.34016"
  },
  {
    "country": "RU",
    "name": "Sheksna",
    "lat": "59.20998",
    "lng": "38.51066"
  },
  {
    "country": "RU",
    "name": "Shedok",
    "lat": "44.2179",
    "lng": "40.8487"
  },
  {
    "country": "RU",
    "name": "Shebekino",
    "lat": "50.40967",
    "lng": "36.9136"
  },
  {
    "country": "RU",
    "name": "Shchukino",
    "lat": "55.8",
    "lng": "37.45"
  },
  {
    "country": "RU",
    "name": "Shchigry",
    "lat": "51.87555",
    "lng": "36.90432"
  },
  {
    "country": "RU",
    "name": "Shcherbinka",
    "lat": "55.49972",
    "lng": "37.55972"
  },
  {
    "country": "RU",
    "name": "Shchelkovo",
    "lat": "55.92497",
    "lng": "37.97218"
  },
  {
    "country": "RU",
    "name": "Shchëkino",
    "lat": "54.00513",
    "lng": "37.52194"
  },
  {
    "country": "RU",
    "name": "Shcheglovo",
    "lat": "60.02839",
    "lng": "30.75289"
  },
  {
    "country": "RU",
    "name": "Shaygino",
    "lat": "57.76751",
    "lng": "46.86181"
  },
  {
    "country": "RU",
    "name": "Shaturtorf",
    "lat": "55.56711",
    "lng": "39.42129"
  },
  {
    "country": "RU",
    "name": "Shatura",
    "lat": "55.57253",
    "lng": "39.53682"
  },
  {
    "country": "RU",
    "name": "Shatsk",
    "lat": "54.02576",
    "lng": "41.71191"
  },
  {
    "country": "RU",
    "name": "Shatki",
    "lat": "55.18874",
    "lng": "44.12486"
  },
  {
    "country": "RU",
    "name": "Shatalovo",
    "lat": "54.334",
    "lng": "32.4465"
  },
  {
    "country": "RU",
    "name": "Shar’ya",
    "lat": "58.36909",
    "lng": "45.51558"
  },
  {
    "country": "RU",
    "name": "Sharlyk",
    "lat": "52.91667",
    "lng": "54.75"
  },
  {
    "country": "RU",
    "name": "Sharkan",
    "lat": "57.29885",
    "lng": "53.87122"
  },
  {
    "country": "RU",
    "name": "Sharanga",
    "lat": "57.17749",
    "lng": "46.53956"
  },
  {
    "country": "RU",
    "name": "Sharan",
    "lat": "54.81667",
    "lng": "54"
  },
  {
    "country": "RU",
    "name": "Shangaly",
    "lat": "61.12842",
    "lng": "43.33427"
  },
  {
    "country": "RU",
    "name": "Shamkhal-Termen",
    "lat": "43.03389",
    "lng": "47.31053"
  },
  {
    "country": "RU",
    "name": "Shamkhal",
    "lat": "43.05958",
    "lng": "47.33732"
  },
  {
    "country": "RU",
    "name": "Shamary",
    "lat": "57.3434",
    "lng": "58.21988"
  },
  {
    "country": "RU",
    "name": "Shalya",
    "lat": "57.2471",
    "lng": "58.7298"
  },
  {
    "country": "RU",
    "name": "Shalushka",
    "lat": "43.5325",
    "lng": "43.56611"
  },
  {
    "country": "RU",
    "name": "Shal’skiy",
    "lat": "61.79698",
    "lng": "36.0168"
  },
  {
    "country": "RU",
    "name": "Shali",
    "lat": "43.14806",
    "lng": "45.90194"
  },
  {
    "country": "RU",
    "name": "Shalazhi",
    "lat": "43.09476",
    "lng": "45.35898"
  },
  {
    "country": "RU",
    "name": "Shalakusha",
    "lat": "62.22472",
    "lng": "40.25389"
  },
  {
    "country": "RU",
    "name": "Shakhun’ya",
    "lat": "57.67579",
    "lng": "46.61136"
  },
  {
    "country": "RU",
    "name": "Shakhty",
    "lat": "47.70911",
    "lng": "40.21443"
  },
  {
    "country": "RU",
    "name": "Shakhta",
    "lat": "59.0905",
    "lng": "57.6575"
  },
  {
    "country": "RU",
    "name": "Shakhovskaya",
    "lat": "56.03147",
    "lng": "35.50697"
  },
  {
    "country": "RU",
    "name": "Shafranovo",
    "lat": "53.96667",
    "lng": "54.76667"
  },
  {
    "country": "RU",
    "name": "Shaburnovo",
    "lat": "56.55",
    "lng": "37.93333"
  },
  {
    "country": "RU",
    "name": "Shablykino",
    "lat": "52.85661",
    "lng": "35.19637"
  },
  {
    "country": "RU",
    "name": "Shabel’skoye",
    "lat": "46.85275",
    "lng": "38.47278"
  },
  {
    "country": "RU",
    "name": "Shaami-Yurt",
    "lat": "43.22632",
    "lng": "45.39203"
  },
  {
    "country": "RU",
    "name": "Sevsk",
    "lat": "52.1491",
    "lng": "34.4926"
  },
  {
    "country": "RU",
    "name": "Severskaya",
    "lat": "44.85407",
    "lng": "38.67686"
  },
  {
    "country": "RU",
    "name": "Severo-Zadonsk",
    "lat": "54.03481",
    "lng": "38.40172"
  },
  {
    "country": "RU",
    "name": "Severoural’sk",
    "lat": "60.15328",
    "lng": "59.95205"
  },
  {
    "country": "RU",
    "name": "Severomorsk",
    "lat": "69.06889",
    "lng": "33.41622"
  },
  {
    "country": "RU",
    "name": "Severodvinsk",
    "lat": "64.5635",
    "lng": "39.8302"
  },
  {
    "country": "RU",
    "name": "Tretiy Severnyy",
    "lat": "60.20861",
    "lng": "59.96111"
  },
  {
    "country": "RU",
    "name": "Severnyy-Kospashskiy",
    "lat": "59.0897",
    "lng": "57.8039"
  },
  {
    "country": "RU",
    "name": "Severnyy",
    "lat": "56.73333",
    "lng": "37.65"
  },
  {
    "country": "RU",
    "name": "Severnyy",
    "lat": "55.93583",
    "lng": "37.54889"
  },
  {
    "country": "RU",
    "name": "Severnyy",
    "lat": "50.67704",
    "lng": "36.55324"
  },
  {
    "country": "RU",
    "name": "Severnoye",
    "lat": "54.09347",
    "lng": "52.54393"
  },
  {
    "country": "RU",
    "name": "Severnoye",
    "lat": "44.83194",
    "lng": "42.85833"
  },
  {
    "country": "RU",
    "name": "Setun’",
    "lat": "55.71667",
    "lng": "37.41667"
  },
  {
    "country": "RU",
    "name": "Sestroretsk",
    "lat": "60.09801",
    "lng": "29.96378"
  },
  {
    "country": "RU",
    "name": "Seshcha",
    "lat": "53.7361",
    "lng": "33.3387"
  },
  {
    "country": "RU",
    "name": "Serzhen’-Yurt",
    "lat": "43.12265",
    "lng": "45.98583"
  },
  {
    "country": "RU",
    "name": "Sertolovo",
    "lat": "60.1444",
    "lng": "30.20165"
  },
  {
    "country": "RU",
    "name": "Serpukhov",
    "lat": "54.91578",
    "lng": "37.41114"
  },
  {
    "country": "RU",
    "name": "Sernur",
    "lat": "56.93333",
    "lng": "49.15361"
  },
  {
    "country": "RU",
    "name": "Sernovodsk",
    "lat": "43.31172",
    "lng": "45.15939"
  },
  {
    "country": "RU",
    "name": "Sernovodsk",
    "lat": "53.92293",
    "lng": "51.25704"
  },
  {
    "country": "RU",
    "name": "Sergokala",
    "lat": "42.45468",
    "lng": "47.66119"
  },
  {
    "country": "RU",
    "name": "Sergiyev Posad",
    "lat": "56.3",
    "lng": "38.13333"
  },
  {
    "country": "RU",
    "name": "Sergach",
    "lat": "55.53079",
    "lng": "45.46611"
  },
  {
    "country": "RU",
    "name": "Serëdka",
    "lat": "58.15838",
    "lng": "28.18576"
  },
  {
    "country": "RU",
    "name": "Seredeyskiy",
    "lat": "54.05071",
    "lng": "35.23183"
  },
  {
    "country": "RU",
    "name": "Serebryanyye Prudy",
    "lat": "54.46923",
    "lng": "38.72095"
  },
  {
    "country": "RU",
    "name": "Serdobsk",
    "lat": "52.45861",
    "lng": "44.21689"
  },
  {
    "country": "RU",
    "name": "Serafimovskiy",
    "lat": "54.42408",
    "lng": "53.7964"
  },
  {
    "country": "RU",
    "name": "Serafimovich",
    "lat": "49.5786",
    "lng": "42.736"
  },
  {
    "country": "RU",
    "name": "Sennoy",
    "lat": "52.1509",
    "lng": "46.96309"
  },
  {
    "country": "RU",
    "name": "Sengiley",
    "lat": "53.96222",
    "lng": "48.79444"
  },
  {
    "country": "RU",
    "name": "Semkhoz",
    "lat": "56.28333",
    "lng": "38.06667"
  },
  {
    "country": "RU",
    "name": "Semiluki",
    "lat": "51.68525",
    "lng": "39.02787"
  },
  {
    "country": "RU",
    "name": "Semiletka",
    "lat": "55.36028",
    "lng": "54.61528"
  },
  {
    "country": "RU",
    "name": "Semikarakorsk",
    "lat": "47.51943",
    "lng": "40.8112"
  },
  {
    "country": "RU",
    "name": "Semibratovo",
    "lat": "57.30461",
    "lng": "39.53688"
  },
  {
    "country": "RU",
    "name": "Semënovskoye",
    "lat": "55.68333",
    "lng": "37.55"
  },
  {
    "country": "RU",
    "name": "Semënov",
    "lat": "56.78749",
    "lng": "44.49297"
  },
  {
    "country": "RU",
    "name": "Selyatino",
    "lat": "55.51514",
    "lng": "36.97746"
  },
  {
    "country": "RU",
    "name": "Selty",
    "lat": "57.3132",
    "lng": "52.1345"
  },
  {
    "country": "RU",
    "name": "Sel’tso",
    "lat": "53.36831",
    "lng": "34.10328"
  },
  {
    "country": "RU",
    "name": "Selizharovo",
    "lat": "56.85188",
    "lng": "33.44869"
  },
  {
    "country": "RU",
    "name": "Selishche",
    "lat": "56.88794",
    "lng": "33.26914"
  },
  {
    "country": "RU",
    "name": "Selezni",
    "lat": "52.80415",
    "lng": "41.23961"
  },
  {
    "country": "RU",
    "name": "Segezha",
    "lat": "63.74147",
    "lng": "34.32218"
  },
  {
    "country": "RU",
    "name": "Sedkyrkeshch",
    "lat": "61.75",
    "lng": "50.91667"
  },
  {
    "country": "RU",
    "name": "Sechenovo",
    "lat": "55.22444",
    "lng": "45.89056"
  },
  {
    "country": "RU",
    "name": "Sebrovo",
    "lat": "50.0981",
    "lng": "43.2976"
  },
  {
    "country": "RU",
    "name": "Sebezh",
    "lat": "56.28511",
    "lng": "28.48187"
  },
  {
    "country": "RU",
    "name": "Sazonovo",
    "lat": "59.0919",
    "lng": "35.2268"
  },
  {
    "country": "RU",
    "name": "Savino",
    "lat": "56.59285",
    "lng": "41.21814"
  },
  {
    "country": "RU",
    "name": "Savinka",
    "lat": "50.07848",
    "lng": "47.09936"
  },
  {
    "country": "RU",
    "name": "Savasleyka",
    "lat": "55.4606",
    "lng": "42.3207"
  },
  {
    "country": "RU",
    "name": "Satka",
    "lat": "55.0425",
    "lng": "59.04"
  },
  {
    "country": "RU",
    "name": "Satis",
    "lat": "54.9229",
    "lng": "43.22977"
  },
  {
    "country": "RU",
    "name": "Satinka",
    "lat": "52.37923",
    "lng": "41.68192"
  },
  {
    "country": "RU",
    "name": "Sasykoli",
    "lat": "47.55153",
    "lng": "46.99679"
  },
  {
    "country": "RU",
    "name": "Sary-Tyuz",
    "lat": "43.90181",
    "lng": "41.89523"
  },
  {
    "country": "RU",
    "name": "Sars",
    "lat": "56.55017",
    "lng": "57.13658"
  },
  {
    "country": "RU",
    "name": "Sarov",
    "lat": "54.93583",
    "lng": "43.32352"
  },
  {
    "country": "RU",
    "name": "Sarmanovo",
    "lat": "55.25529",
    "lng": "52.58907"
  },
  {
    "country": "RU",
    "name": "Sarmakovo",
    "lat": "43.74556",
    "lng": "43.20028"
  },
  {
    "country": "RU",
    "name": "Saratovskaya",
    "lat": "44.70752",
    "lng": "39.22156"
  },
  {
    "country": "RU",
    "name": "Saratov",
    "lat": "51.54056",
    "lng": "46.00861"
  },
  {
    "country": "RU",
    "name": "Sarapul",
    "lat": "56.47633",
    "lng": "53.79782"
  },
  {
    "country": "RU",
    "name": "Sarany",
    "lat": "58.5",
    "lng": "58.88333"
  },
  {
    "country": "RU",
    "name": "Saransk",
    "lat": "54.1838",
    "lng": "45.1749"
  },
  {
    "country": "RU",
    "name": "Sarana",
    "lat": "56.47728",
    "lng": "57.72586"
  },
  {
    "country": "RU",
    "name": "Saraktash",
    "lat": "51.78771",
    "lng": "56.36091"
  },
  {
    "country": "RU",
    "name": "Sarai",
    "lat": "53.74577",
    "lng": "41.02126"
  },
  {
    "country": "RU",
    "name": "Sapozhok",
    "lat": "53.94194",
    "lng": "40.68056"
  },
  {
    "country": "RU",
    "name": "Sapërnyy",
    "lat": "59.77611",
    "lng": "30.66139"
  },
  {
    "country": "RU",
    "name": "Sapernoye",
    "lat": "60.71418",
    "lng": "29.95525"
  },
  {
    "country": "RU",
    "name": "Saint Petersburg",
    "lat": "59.93863",
    "lng": "30.31413"
  },
  {
    "country": "RU",
    "name": "Sandovo",
    "lat": "58.46022",
    "lng": "36.41277"
  },
  {
    "country": "RU",
    "name": "Sandata",
    "lat": "46.27081",
    "lng": "41.75834"
  },
  {
    "country": "RU",
    "name": "Sanchursk",
    "lat": "56.94125",
    "lng": "47.24987"
  },
  {
    "country": "RU",
    "name": "Samur",
    "lat": "41.82527",
    "lng": "48.48597"
  },
  {
    "country": "RU",
    "name": "Samoylovka",
    "lat": "51.184",
    "lng": "43.7081"
  },
  {
    "country": "RU",
    "name": "Samoded",
    "lat": "63.6083",
    "lng": "40.5111"
  },
  {
    "country": "RU",
    "name": "Sambek",
    "lat": "47.74306",
    "lng": "39.83083"
  },
  {
    "country": "RU",
    "name": "Samashki",
    "lat": "43.29056",
    "lng": "45.30139"
  },
  {
    "country": "RU",
    "name": "Samarskoye",
    "lat": "46.937",
    "lng": "39.6881"
  },
  {
    "country": "RU",
    "name": "Samara",
    "lat": "53.20007",
    "lng": "50.15"
  },
  {
    "country": "RU",
    "name": "Saltykovka",
    "lat": "55.76679",
    "lng": "37.93533"
  },
  {
    "country": "RU",
    "name": "Sal’sk",
    "lat": "46.4747",
    "lng": "41.54114"
  },
  {
    "country": "RU",
    "name": "Salmi",
    "lat": "61.36971",
    "lng": "31.85185"
  },
  {
    "country": "RU",
    "name": "Salavat",
    "lat": "53.38365",
    "lng": "55.90773"
  },
  {
    "country": "RU",
    "name": "Sakmara",
    "lat": "51.98438",
    "lng": "55.3338"
  },
  {
    "country": "RU",
    "name": "Sakharovo",
    "lat": "56.89949",
    "lng": "36.05015"
  },
  {
    "country": "RU",
    "name": "Sagopshi",
    "lat": "43.48515",
    "lng": "44.59063"
  },
  {
    "country": "RU",
    "name": "Safonovo",
    "lat": "69.06043",
    "lng": "33.29523"
  },
  {
    "country": "RU",
    "name": "Safonovo",
    "lat": "55.15",
    "lng": "33.21667"
  },
  {
    "country": "RU",
    "name": "Sadovoye",
    "lat": "51.53111",
    "lng": "40.50194"
  },
  {
    "country": "RU",
    "name": "Sadovoye",
    "lat": "47.7772",
    "lng": "44.5208"
  },
  {
    "country": "RU",
    "name": "Sachkovichi",
    "lat": "52.3459",
    "lng": "32.2246"
  },
  {
    "country": "RU",
    "name": "Sabnova",
    "lat": "42.07617",
    "lng": "48.24796"
  },
  {
    "country": "RU",
    "name": "Rzhev",
    "lat": "56.26241",
    "lng": "34.32817"
  },
  {
    "country": "RU",
    "name": "Rzhavki",
    "lat": "56",
    "lng": "37.25"
  },
  {
    "country": "RU",
    "name": "Rzhanitsa",
    "lat": "53.42844",
    "lng": "33.92297"
  },
  {
    "country": "RU",
    "name": "Rzhaksa",
    "lat": "52.13384",
    "lng": "42.0264"
  },
  {
    "country": "RU",
    "name": "Ryzdvyanyy",
    "lat": "45.2656",
    "lng": "41.8389"
  },
  {
    "country": "RU",
    "name": "Rybnoye",
    "lat": "54.72774",
    "lng": "39.51731"
  },
  {
    "country": "RU",
    "name": "Rybnaya Sloboda",
    "lat": "55.46129",
    "lng": "50.1409"
  },
  {
    "country": "RU",
    "name": "Rybinsk",
    "lat": "58.0446",
    "lng": "38.84259"
  },
  {
    "country": "RU",
    "name": "Rybatskoye",
    "lat": "59.8393",
    "lng": "30.49873"
  },
  {
    "country": "RU",
    "name": "Ryazhsk",
    "lat": "53.7038",
    "lng": "40.1109"
  },
  {
    "country": "RU",
    "name": "Ryazanskaya",
    "lat": "44.95528",
    "lng": "39.58894"
  },
  {
    "country": "RU",
    "name": "Ryazan’",
    "lat": "54.6269",
    "lng": "39.6916"
  },
  {
    "country": "RU",
    "name": "Ryabovo",
    "lat": "59.4",
    "lng": "31.13333"
  },
  {
    "country": "RU",
    "name": "Ruzayevka",
    "lat": "54.06387",
    "lng": "44.9509"
  },
  {
    "country": "RU",
    "name": "Ruza",
    "lat": "55.69898",
    "lng": "36.19522"
  },
  {
    "country": "RU",
    "name": "Rutul",
    "lat": "41.53566",
    "lng": "47.42391"
  },
  {
    "country": "RU",
    "name": "Russko-Vysotskoye",
    "lat": "59.69963",
    "lng": "29.94404"
  },
  {
    "country": "RU",
    "name": "Russkiy Kameshkir",
    "lat": "52.85955",
    "lng": "46.08861"
  },
  {
    "country": "RU",
    "name": "Ruskeala",
    "lat": "61.93333",
    "lng": "30.58333"
  },
  {
    "country": "RU",
    "name": "Rumyantsevo",
    "lat": "55.97278",
    "lng": "36.53417"
  },
  {
    "country": "RU",
    "name": "Rudnya",
    "lat": "54.94698",
    "lng": "31.0934"
  },
  {
    "country": "RU",
    "name": "Rudnya",
    "lat": "50.79898",
    "lng": "44.55856"
  },
  {
    "country": "RU",
    "name": "Rudnichnyy",
    "lat": "59.61702",
    "lng": "52.47033"
  },
  {
    "country": "RU",
    "name": "Rublëvo",
    "lat": "55.78514",
    "lng": "37.35481"
  },
  {
    "country": "RU",
    "name": "Rtishchevo",
    "lat": "52.26041",
    "lng": "43.78745"
  },
  {
    "country": "RU",
    "name": "Rozhdestveno",
    "lat": "59.31812",
    "lng": "29.94594"
  },
  {
    "country": "RU",
    "name": "Rozhdestveno",
    "lat": "55.85444",
    "lng": "37.04935"
  },
  {
    "country": "RU",
    "name": "Rozhdestveno",
    "lat": "53.23745",
    "lng": "50.05971"
  },
  {
    "country": "RU",
    "name": "Rovnoye",
    "lat": "50.7765",
    "lng": "46.05085"
  },
  {
    "country": "RU",
    "name": "Rostov-na-Donu",
    "lat": "47.23135",
    "lng": "39.72328"
  },
  {
    "country": "RU",
    "name": "Rostov",
    "lat": "57.1914",
    "lng": "39.41394"
  },
  {
    "country": "RU",
    "name": "Rostokino",
    "lat": "55.83333",
    "lng": "37.66667"
  },
  {
    "country": "RU",
    "name": "Rossosh’",
    "lat": "51.1209",
    "lng": "38.5116"
  },
  {
    "country": "RU",
    "name": "Rossosh’",
    "lat": "50.19828",
    "lng": "39.56726"
  },
  {
    "country": "RU",
    "name": "Roslyakovo",
    "lat": "69.04303",
    "lng": "33.19906"
  },
  {
    "country": "RU",
    "name": "Roslavl’",
    "lat": "53.95278",
    "lng": "32.86389"
  },
  {
    "country": "RU",
    "name": "Roshni-Chu",
    "lat": "43.08954",
    "lng": "45.45435"
  },
  {
    "country": "RU",
    "name": "Roshchino",
    "lat": "60.25191",
    "lng": "29.6085"
  },
  {
    "country": "RU",
    "name": "Mariyenburg",
    "lat": "59.57139",
    "lng": "30.06472"
  },
  {
    "country": "RU",
    "name": "Roshal’",
    "lat": "55.66853",
    "lng": "39.87488"
  },
  {
    "country": "RU",
    "name": "Romodanovo",
    "lat": "54.42753",
    "lng": "45.32962"
  },
  {
    "country": "RU",
    "name": "Romanovskaya",
    "lat": "47.5426",
    "lng": "42.0285"
  },
  {
    "country": "RU",
    "name": "Romanovka",
    "lat": "60.0443",
    "lng": "30.714"
  },
  {
    "country": "RU",
    "name": "Romanovka",
    "lat": "51.74427",
    "lng": "42.7527"
  },
  {
    "country": "RU",
    "name": "Rogovskaya",
    "lat": "45.73117",
    "lng": "38.7396"
  },
  {
    "country": "RU",
    "name": "Rogovatoye",
    "lat": "51.23",
    "lng": "38.3818"
  },
  {
    "country": "RU",
    "name": "Rognedino",
    "lat": "53.80147",
    "lng": "33.5576"
  },
  {
    "country": "RU",
    "name": "Rogachëvo",
    "lat": "56.43333",
    "lng": "37.16667"
  },
  {
    "country": "RU",
    "name": "Rodnikovskaya",
    "lat": "44.76444",
    "lng": "40.66556"
  },
  {
    "country": "RU",
    "name": "Rodniki",
    "lat": "57.10513",
    "lng": "41.73048"
  },
  {
    "country": "RU",
    "name": "Rodniki",
    "lat": "55.65204",
    "lng": "38.06685"
  },
  {
    "country": "RU",
    "name": "Rodionovo-Nesvetayskaya",
    "lat": "47.61033",
    "lng": "39.71212"
  },
  {
    "country": "RU",
    "name": "Rodionovo-Nesvetaiskoye",
    "lat": "47.6",
    "lng": "39.7"
  },
  {
    "country": "RU",
    "name": "Rochegda",
    "lat": "62.6678",
    "lng": "43.4133"
  },
  {
    "country": "RU",
    "name": "Revyakino",
    "lat": "54.36517",
    "lng": "37.66249"
  },
  {
    "country": "RU",
    "name": "Revda",
    "lat": "67.9371",
    "lng": "34.56149"
  },
  {
    "country": "RU",
    "name": "Revda",
    "lat": "56.80097",
    "lng": "59.93028"
  },
  {
    "country": "RU",
    "name": "Reutov",
    "lat": "55.76111",
    "lng": "37.8575"
  },
  {
    "country": "RU",
    "name": "Reshetnikovo",
    "lat": "56.45",
    "lng": "36.56667"
  },
  {
    "country": "RU",
    "name": "Reshetikha",
    "lat": "56.21566",
    "lng": "43.28802"
  },
  {
    "country": "RU",
    "name": "Repnoye",
    "lat": "51.5921",
    "lng": "43.1861"
  },
  {
    "country": "RU",
    "name": "Repino",
    "lat": "60.17217",
    "lng": "29.86908"
  },
  {
    "country": "RU",
    "name": "Remontnoye",
    "lat": "46.5614",
    "lng": "43.6501"
  },
  {
    "country": "RU",
    "name": "Redkino",
    "lat": "56.64754",
    "lng": "36.29674"
  },
  {
    "country": "RU",
    "name": "Rechitsy",
    "lat": "55.59754",
    "lng": "38.47134"
  },
  {
    "country": "RU",
    "name": "Razumnoye",
    "lat": "50.53439",
    "lng": "36.68462"
  },
  {
    "country": "RU",
    "name": "Razliv",
    "lat": "60.07919",
    "lng": "29.97206"
  },
  {
    "country": "RU",
    "name": "Rayevskiy",
    "lat": "54.0658",
    "lng": "54.9468"
  },
  {
    "country": "RU",
    "name": "Rayevskaya",
    "lat": "44.83571",
    "lng": "37.55577"
  },
  {
    "country": "RU",
    "name": "Rassvet",
    "lat": "46.83333",
    "lng": "40.75"
  },
  {
    "country": "RU",
    "name": "Rasskazovo",
    "lat": "52.65599",
    "lng": "41.88461"
  },
  {
    "country": "RU",
    "name": "Rasshevatskaya",
    "lat": "45.5748",
    "lng": "41.03496"
  },
  {
    "country": "RU",
    "name": "Ramon’",
    "lat": "51.91569",
    "lng": "39.33609"
  },
  {
    "country": "RU",
    "name": "Rameshki",
    "lat": "57.3439",
    "lng": "36.04535"
  },
  {
    "country": "RU",
    "name": "Ramenskoye",
    "lat": "55.56694",
    "lng": "38.23028"
  },
  {
    "country": "RU",
    "name": "Ramenki",
    "lat": "55.7",
    "lng": "37.5"
  },
  {
    "country": "RU",
    "name": "Rakitnoye",
    "lat": "50.8389",
    "lng": "35.8515"
  },
  {
    "country": "RU",
    "name": "Rakhmanovo",
    "lat": "55.74401",
    "lng": "38.61124"
  },
  {
    "country": "RU",
    "name": "Radovitskiy",
    "lat": "55.1282",
    "lng": "39.7956"
  },
  {
    "country": "RU",
    "name": "Radumlya",
    "lat": "56.06901",
    "lng": "37.14979"
  },
  {
    "country": "RU",
    "name": "Raditsa-Krylovka",
    "lat": "53.31712",
    "lng": "34.35742"
  },
  {
    "country": "RU",
    "name": "Radishchevo",
    "lat": "52.85459",
    "lng": "47.87644"
  },
  {
    "country": "RU",
    "name": "Radchenko",
    "lat": "56.68027",
    "lng": "36.37178"
  },
  {
    "country": "RU",
    "name": "Rabotki",
    "lat": "56.04147",
    "lng": "44.60265"
  },
  {
    "country": "RU",
    "name": "Pytalovo",
    "lat": "57.06791",
    "lng": "27.91384"
  },
  {
    "country": "RU",
    "name": "Pyshchug",
    "lat": "58.88726",
    "lng": "45.71341"
  },
  {
    "country": "RU",
    "name": "Pyra",
    "lat": "56.29527",
    "lng": "43.35274"
  },
  {
    "country": "RU",
    "name": "Pychas",
    "lat": "56.50332",
    "lng": "52.44088"
  },
  {
    "country": "RU",
    "name": "Pyatovskiy",
    "lat": "54.68908",
    "lng": "36.05634"
  },
  {
    "country": "RU",
    "name": "Pyatnitskoye",
    "lat": "50.4233",
    "lng": "37.8273"
  },
  {
    "country": "RU",
    "name": "Pyatigorskiy",
    "lat": "43.97417",
    "lng": "43.25833"
  },
  {
    "country": "RU",
    "name": "Pyatigorsk",
    "lat": "44.04861",
    "lng": "43.05944"
  },
  {
    "country": "RU",
    "name": "Pyaozerskiy",
    "lat": "65.7687",
    "lng": "31.08925"
  },
  {
    "country": "RU",
    "name": "Putyatino",
    "lat": "54.15998",
    "lng": "41.1169"
  },
  {
    "country": "RU",
    "name": "Puteyets",
    "lat": "65.17157",
    "lng": "57.09101"
  },
  {
    "country": "RU",
    "name": "Pustoshka",
    "lat": "56.33547",
    "lng": "29.36901"
  },
  {
    "country": "RU",
    "name": "Pushkinskiye Gory",
    "lat": "57.02085",
    "lng": "28.9103"
  },
  {
    "country": "RU",
    "name": "Pushkino",
    "lat": "56.01722",
    "lng": "37.86667"
  },
  {
    "country": "RU",
    "name": "Pushkino",
    "lat": "51.235",
    "lng": "46.97417"
  },
  {
    "country": "RU",
    "name": "Pushkin",
    "lat": "59.71417",
    "lng": "30.39642"
  },
  {
    "country": "RU",
    "name": "Pushchino",
    "lat": "54.83373",
    "lng": "37.61138"
  },
  {
    "country": "RU",
    "name": "Purshevo",
    "lat": "55.72124",
    "lng": "38.03277"
  },
  {
    "country": "RU",
    "name": "Purekh",
    "lat": "56.64684",
    "lng": "43.06772"
  },
  {
    "country": "RU",
    "name": "Puksoozero",
    "lat": "62.5903",
    "lng": "40.6066"
  },
  {
    "country": "RU",
    "name": "Pugachev",
    "lat": "52.01333",
    "lng": "48.8025"
  },
  {
    "country": "RU",
    "name": "Pudozh",
    "lat": "61.80415",
    "lng": "36.5277"
  },
  {
    "country": "RU",
    "name": "Pudem",
    "lat": "58.3047",
    "lng": "52.1673"
  },
  {
    "country": "RU",
    "name": "Puchezh",
    "lat": "56.97878",
    "lng": "43.16761"
  },
  {
    "country": "RU",
    "name": "Psyzh",
    "lat": "44.23306",
    "lng": "42.01833"
  },
  {
    "country": "RU",
    "name": "Psygansu",
    "lat": "43.41944",
    "lng": "43.79361"
  },
  {
    "country": "RU",
    "name": "Pskov",
    "lat": "57.8136",
    "lng": "28.3496"
  },
  {
    "country": "RU",
    "name": "Pshekhskaya",
    "lat": "44.69597",
    "lng": "39.79665"
  },
  {
    "country": "RU",
    "name": "Pshada",
    "lat": "44.47",
    "lng": "38.3996"
  },
  {
    "country": "RU",
    "name": "Psedakh",
    "lat": "43.46722",
    "lng": "44.56917"
  },
  {
    "country": "RU",
    "name": "Psebay",
    "lat": "44.1234",
    "lng": "40.8107"
  },
  {
    "country": "RU",
    "name": "Pryazha",
    "lat": "61.69258",
    "lng": "33.62159"
  },
  {
    "country": "RU",
    "name": "Pryamitsyno",
    "lat": "51.6561",
    "lng": "35.9314"
  },
  {
    "country": "RU",
    "name": "Prudy",
    "lat": "57.5738",
    "lng": "46.27176"
  },
  {
    "country": "RU",
    "name": "Protvino",
    "lat": "54.86821",
    "lng": "37.21583"
  },
  {
    "country": "RU",
    "name": "Pronsk",
    "lat": "54.1048",
    "lng": "39.6092"
  },
  {
    "country": "RU",
    "name": "Proletarskiy",
    "lat": "55.02219",
    "lng": "37.39019"
  },
  {
    "country": "RU",
    "name": "Proletarskiy",
    "lat": "50.79139",
    "lng": "35.77306"
  },
  {
    "country": "RU",
    "name": "Proletarsk",
    "lat": "46.70289",
    "lng": "41.72717"
  },
  {
    "country": "RU",
    "name": "Proletariy",
    "lat": "58.43423",
    "lng": "31.70462"
  },
  {
    "country": "RU",
    "name": "Kipen’",
    "lat": "59.67407",
    "lng": "29.84977"
  },
  {
    "country": "RU",
    "name": "Prokhorovka",
    "lat": "51.03741",
    "lng": "36.73252"
  },
  {
    "country": "RU",
    "name": "Prokhladnyy",
    "lat": "43.75741",
    "lng": "44.0297"
  },
  {
    "country": "RU",
    "name": "Prochnookopskaya",
    "lat": "45.0666",
    "lng": "41.1175"
  },
  {
    "country": "RU",
    "name": "Priyutovo",
    "lat": "53.9",
    "lng": "53.93333"
  },
  {
    "country": "RU",
    "name": "Priyutnoye",
    "lat": "46.10111",
    "lng": "43.50722"
  },
  {
    "country": "RU",
    "name": "Privolzhskoye",
    "lat": "51.69194",
    "lng": "46.72361"
  },
  {
    "country": "RU",
    "name": "Privolzhskiy",
    "lat": "51.40944",
    "lng": "46.04833"
  },
  {
    "country": "RU",
    "name": "Privolzhsk",
    "lat": "57.38698",
    "lng": "41.28666"
  },
  {
    "country": "RU",
    "name": "Privodino",
    "lat": "61.07599",
    "lng": "46.50238"
  },
  {
    "country": "RU",
    "name": "Priupskiy",
    "lat": "53.9096",
    "lng": "37.736"
  },
  {
    "country": "RU",
    "name": "Pristen’",
    "lat": "51.23551",
    "lng": "36.69594"
  },
  {
    "country": "RU",
    "name": "Priozërsk",
    "lat": "61.03928",
    "lng": "30.12907"
  },
  {
    "country": "RU",
    "name": "Primorka",
    "lat": "47.28395",
    "lng": "39.06408"
  },
  {
    "country": "RU",
    "name": "Primorsko-Akhtarsk",
    "lat": "46.0497",
    "lng": "38.1747"
  },
  {
    "country": "RU",
    "name": "Primorsk",
    "lat": "60.36593",
    "lng": "28.60737"
  },
  {
    "country": "RU",
    "name": "Primorsk",
    "lat": "54.73905",
    "lng": "20.00553"
  },
  {
    "country": "RU",
    "name": "Primorsk",
    "lat": "49.26532",
    "lng": "45.02889"
  },
  {
    "country": "RU",
    "name": "Primalkinskoye",
    "lat": "43.74667",
    "lng": "44.00833"
  },
  {
    "country": "RU",
    "name": "Prikubanskiy",
    "lat": "45.0015",
    "lng": "41.1795"
  },
  {
    "country": "RU",
    "name": "Prigorodnyy",
    "lat": "51.76608",
    "lng": "55.26648"
  },
  {
    "country": "RU",
    "name": "Prigorodnoye",
    "lat": "43.25303",
    "lng": "45.75808"
  },
  {
    "country": "RU",
    "name": "Prigorodka",
    "lat": "52.04472",
    "lng": "39.71238"
  },
  {
    "country": "RU",
    "name": "Pridonskoy",
    "lat": "51.68406",
    "lng": "39.0727"
  },
  {
    "country": "RU",
    "name": "Pregradnoye",
    "lat": "45.82183",
    "lng": "41.74692"
  },
  {
    "country": "RU",
    "name": "Pregradnaya",
    "lat": "43.95395",
    "lng": "41.1891"
  },
  {
    "country": "RU",
    "name": "Prechistoye",
    "lat": "58.42068",
    "lng": "40.34017"
  },
  {
    "country": "RU",
    "name": "Pravokumskoye",
    "lat": "44.76944",
    "lng": "44.64722"
  },
  {
    "country": "RU",
    "name": "Pravdinskiy",
    "lat": "56.06034",
    "lng": "37.86266"
  },
  {
    "country": "RU",
    "name": "Pravdinsk",
    "lat": "54.44289",
    "lng": "21.01785"
  },
  {
    "country": "RU",
    "name": "Praskoveya",
    "lat": "44.74444",
    "lng": "44.20306"
  },
  {
    "country": "RU",
    "name": "Pozhva",
    "lat": "59.0912",
    "lng": "56.0901"
  },
  {
    "country": "RU",
    "name": "Poyakonda",
    "lat": "66.59428",
    "lng": "32.82088"
  },
  {
    "country": "RU",
    "name": "Povorino",
    "lat": "51.1945",
    "lng": "42.2457"
  },
  {
    "country": "RU",
    "name": "Povenets",
    "lat": "62.8487",
    "lng": "34.82621"
  },
  {
    "country": "RU",
    "name": "Povarovo",
    "lat": "56.06667",
    "lng": "37.05"
  },
  {
    "country": "RU",
    "name": "Poshekhon’ye",
    "lat": "58.49928",
    "lng": "39.13531"
  },
  {
    "country": "RU",
    "name": "Kotlovka",
    "lat": "55.65928",
    "lng": "37.60404"
  },
  {
    "country": "RU",
    "name": "Annino",
    "lat": "55.58333",
    "lng": "37.6"
  },
  {
    "country": "RU",
    "name": "Poselki",
    "lat": "53.13236",
    "lng": "46.50307"
  },
  {
    "country": "RU",
    "name": "Port-Katon",
    "lat": "46.879",
    "lng": "38.756"
  },
  {
    "country": "RU",
    "name": "Porosozero",
    "lat": "62.71912",
    "lng": "32.72703"
  },
  {
    "country": "RU",
    "name": "Porkhov",
    "lat": "57.76502",
    "lng": "29.55612"
  },
  {
    "country": "RU",
    "name": "Poretskoye",
    "lat": "55.19742",
    "lng": "46.32908"
  },
  {
    "country": "RU",
    "name": "Porech’ye-Rybnoye",
    "lat": "57.09805",
    "lng": "39.38354"
  },
  {
    "country": "RU",
    "name": "Poputnaya",
    "lat": "44.5125",
    "lng": "41.4392"
  },
  {
    "country": "RU",
    "name": "Popovo",
    "lat": "55.07523",
    "lng": "37.66727"
  },
  {
    "country": "RU",
    "name": "Ponyri Vtoryye",
    "lat": "52.27994",
    "lng": "36.22461"
  },
  {
    "country": "RU",
    "name": "Pontonnyy",
    "lat": "59.78667",
    "lng": "30.61528"
  },
  {
    "country": "RU",
    "name": "Ponezhukay",
    "lat": "44.88761",
    "lng": "39.38551"
  },
  {
    "country": "RU",
    "name": "Ponazyrevo",
    "lat": "58.35784",
    "lng": "46.31421"
  },
  {
    "country": "RU",
    "name": "Pomary",
    "lat": "55.96815",
    "lng": "48.35072"
  },
  {
    "country": "RU",
    "name": "Polyarnyye Zori",
    "lat": "67.36611",
    "lng": "32.49806"
  },
  {
    "country": "RU",
    "name": "Polyarnyy",
    "lat": "69.19889",
    "lng": "33.44778"
  },
  {
    "country": "RU",
    "name": "Polyane",
    "lat": "56.88089",
    "lng": "28.88485"
  },
  {
    "country": "RU",
    "name": "Polyany",
    "lat": "54.71801",
    "lng": "39.82932"
  },
  {
    "country": "RU",
    "name": "Polotnyanyy Zavod",
    "lat": "54.72139",
    "lng": "35.96611"
  },
  {
    "country": "RU",
    "name": "Polessk",
    "lat": "54.86205",
    "lng": "21.10279"
  },
  {
    "country": "RU",
    "name": "Poldnëvoye",
    "lat": "45.85568",
    "lng": "47.95241"
  },
  {
    "country": "RU",
    "name": "Polazna",
    "lat": "58.2922",
    "lng": "56.4156"
  },
  {
    "country": "RU",
    "name": "Pokrovskoye-Streshnëvo",
    "lat": "55.80797",
    "lng": "37.45814"
  },
  {
    "country": "RU",
    "name": "Pokrovskoye",
    "lat": "56.68972",
    "lng": "28.25483"
  },
  {
    "country": "RU",
    "name": "Pokrovskoye",
    "lat": "52.60968",
    "lng": "36.87124"
  },
  {
    "country": "RU",
    "name": "Pokrovskoye",
    "lat": "47.4157",
    "lng": "38.89706"
  },
  {
    "country": "RU",
    "name": "Pokrovskoye",
    "lat": "43.28872",
    "lng": "46.66527"
  },
  {
    "country": "RU",
    "name": "Pokrovo-Prigorodnoye",
    "lat": "52.68405",
    "lng": "41.41752"
  },
  {
    "country": "RU",
    "name": "Pokrov",
    "lat": "55.91797",
    "lng": "39.17242"
  },
  {
    "country": "RU",
    "name": "Pokoynoye",
    "lat": "44.80972",
    "lng": "44.25167"
  },
  {
    "country": "RU",
    "name": "Pokhvistnevo",
    "lat": "53.65237",
    "lng": "52.12738"
  },
  {
    "country": "RU",
    "name": "Poim",
    "lat": "53.02639",
    "lng": "43.18721"
  },
  {
    "country": "RU",
    "name": "Pogar",
    "lat": "52.55399",
    "lng": "33.25907"
  },
  {
    "country": "RU",
    "name": "Podyuga",
    "lat": "61.095",
    "lng": "40.86472"
  },
  {
    "country": "RU",
    "name": "Podstepki",
    "lat": "53.5151",
    "lng": "49.1355"
  },
  {
    "country": "RU",
    "name": "Podsolnechnoye",
    "lat": "53.15",
    "lng": "52.0191"
  },
  {
    "country": "RU",
    "name": "Podporozh’ye",
    "lat": "60.91124",
    "lng": "34.17064"
  },
  {
    "country": "RU",
    "name": "Podosinovets",
    "lat": "60.27758",
    "lng": "47.06587"
  },
  {
    "country": "RU",
    "name": "Podolsk",
    "lat": "55.42419",
    "lng": "37.55472"
  },
  {
    "country": "RU",
    "name": "Podlesnyy",
    "lat": "53.94003",
    "lng": "38.26872"
  },
  {
    "country": "RU",
    "name": "Podlesnoye",
    "lat": "51.8161",
    "lng": "47.009"
  },
  {
    "country": "RU",
    "name": "Podkumskiy",
    "lat": "44.07556",
    "lng": "43.21028"
  },
  {
    "country": "RU",
    "name": "Podkletnoye",
    "lat": "51.58993",
    "lng": "39.4623"
  },
  {
    "country": "RU",
    "name": "Podgorodnyaya Pokrovka",
    "lat": "51.82808",
    "lng": "54.9874"
  },
  {
    "country": "RU",
    "name": "Podgornoye",
    "lat": "51.73504",
    "lng": "39.14961"
  },
  {
    "country": "RU",
    "name": "Podgornoye",
    "lat": "50.4143",
    "lng": "39.61639"
  },
  {
    "country": "RU",
    "name": "Podgornaya",
    "lat": "44.20306",
    "lng": "43.42972"
  },
  {
    "country": "RU",
    "name": "Podgorenskiy",
    "lat": "50.40498",
    "lng": "39.64295"
  },
  {
    "country": "RU",
    "name": "Poddor’ye",
    "lat": "57.46947",
    "lng": "31.11561"
  },
  {
    "country": "RU",
    "name": "Pochinok",
    "lat": "54.40685",
    "lng": "32.44067"
  },
  {
    "country": "RU",
    "name": "Pochinki",
    "lat": "54.69875",
    "lng": "44.86678"
  },
  {
    "country": "RU",
    "name": "Pochep",
    "lat": "52.9336",
    "lng": "33.4464"
  },
  {
    "country": "RU",
    "name": "Plyussa",
    "lat": "58.43078",
    "lng": "29.36537"
  },
  {
    "country": "RU",
    "name": "Ryazanskiy",
    "lat": "55.73333",
    "lng": "37.76667"
  },
  {
    "country": "RU",
    "name": "Pleshanovo",
    "lat": "52.83333",
    "lng": "53.48333"
  },
  {
    "country": "RU",
    "name": "Plesetsk",
    "lat": "62.70804",
    "lng": "40.29159"
  },
  {
    "country": "RU",
    "name": "Plës",
    "lat": "57.45862",
    "lng": "41.51579"
  },
  {
    "country": "RU",
    "name": "Plekhanovo",
    "lat": "52.63822",
    "lng": "39.84729"
  },
  {
    "country": "RU",
    "name": "Plavsk",
    "lat": "53.70944",
    "lng": "37.29194"
  },
  {
    "country": "RU",
    "name": "Platonovka",
    "lat": "52.71058",
    "lng": "41.95199"
  },
  {
    "country": "RU",
    "name": "Platnirovskaya",
    "lat": "45.39531",
    "lng": "39.3842"
  },
  {
    "country": "RU",
    "name": "Plastunovskaya",
    "lat": "45.29432",
    "lng": "39.26505"
  },
  {
    "country": "RU",
    "name": "Planovskoye",
    "lat": "43.39846",
    "lng": "44.1949"
  },
  {
    "country": "RU",
    "name": "Pizhma",
    "lat": "57.86418",
    "lng": "47.11714"
  },
  {
    "country": "RU",
    "name": "Pizhanka",
    "lat": "57.46042",
    "lng": "48.542"
  },
  {
    "country": "RU",
    "name": "Pitkyaranta",
    "lat": "61.5734",
    "lng": "31.47915"
  },
  {
    "country": "RU",
    "name": "Piterka",
    "lat": "50.6803",
    "lng": "47.44539"
  },
  {
    "country": "RU",
    "name": "Pitelino",
    "lat": "54.57768",
    "lng": "41.81448"
  },
  {
    "country": "RU",
    "name": "Pistsovo",
    "lat": "57.17904",
    "lng": "40.52983"
  },
  {
    "country": "RU",
    "name": "Pirogovskiy",
    "lat": "55.97806",
    "lng": "37.73361"
  },
  {
    "country": "RU",
    "name": "Pirogovo",
    "lat": "56.77959",
    "lng": "53.14954"
  },
  {
    "country": "RU",
    "name": "Pionerskiy",
    "lat": "54.95083",
    "lng": "20.22748"
  },
  {
    "country": "RU",
    "name": "Pinyug",
    "lat": "60.25095",
    "lng": "47.78425"
  },
  {
    "country": "RU",
    "name": "Pinerovka",
    "lat": "51.562",
    "lng": "43.0689"
  },
  {
    "country": "RU",
    "name": "Pinega",
    "lat": "64.69969",
    "lng": "43.39016"
  },
  {
    "country": "RU",
    "name": "Pindushi",
    "lat": "62.91519",
    "lng": "34.57996"
  },
  {
    "country": "RU",
    "name": "Pil’na",
    "lat": "55.55394",
    "lng": "45.92194"
  },
  {
    "country": "RU",
    "name": "Pikalëvo",
    "lat": "59.51833",
    "lng": "34.16639"
  },
  {
    "country": "RU",
    "name": "Pichayevo",
    "lat": "53.23627",
    "lng": "42.20323"
  },
  {
    "country": "RU",
    "name": "Petushki",
    "lat": "55.92639",
    "lng": "39.46104"
  },
  {
    "country": "RU",
    "name": "Petrozavodsk",
    "lat": "61.78491",
    "lng": "34.34691"
  },
  {
    "country": "RU",
    "name": "Petrov Val",
    "lat": "50.14337",
    "lng": "45.20958"
  },
  {
    "country": "RU",
    "name": "Petrovsk",
    "lat": "57.01039",
    "lng": "39.26928"
  },
  {
    "country": "RU",
    "name": "Petrovskiy",
    "lat": "56.6421",
    "lng": "40.32026"
  },
  {
    "country": "RU",
    "name": "Petrovskaya",
    "lat": "55.55",
    "lng": "37.78333"
  },
  {
    "country": "RU",
    "name": "Petrovskaya",
    "lat": "45.43139",
    "lng": "37.955"
  },
  {
    "country": "RU",
    "name": "Petrovsk",
    "lat": "52.30639",
    "lng": "45.39167"
  },
  {
    "country": "RU",
    "name": "Petrovo-Dal’neye",
    "lat": "55.74679",
    "lng": "37.17347"
  },
  {
    "country": "RU",
    "name": "Petro-Slavyanka",
    "lat": "59.80222",
    "lng": "30.50694"
  },
  {
    "country": "RU",
    "name": "Petropavlovskaya",
    "lat": "45.08189",
    "lng": "40.45125"
  },
  {
    "country": "RU",
    "name": "Petropavlovskaya",
    "lat": "43.37944",
    "lng": "45.82611"
  },
  {
    "country": "RU",
    "name": "Petrodvorets",
    "lat": "59.89565",
    "lng": "29.80145"
  },
  {
    "country": "RU",
    "name": "Peterhof",
    "lat": "59.88333",
    "lng": "29.9"
  },
  {
    "country": "RU",
    "name": "Pestyaki",
    "lat": "56.7086",
    "lng": "42.66954"
  },
  {
    "country": "RU",
    "name": "Pestretsy",
    "lat": "55.75313",
    "lng": "49.65454"
  },
  {
    "country": "RU",
    "name": "Pestravka",
    "lat": "52.3982",
    "lng": "49.961"
  },
  {
    "country": "RU",
    "name": "Pestovo",
    "lat": "58.59382",
    "lng": "35.80244"
  },
  {
    "country": "RU",
    "name": "Pesochnyy",
    "lat": "60.12295",
    "lng": "30.16404"
  },
  {
    "country": "RU",
    "name": "Pesochnoye",
    "lat": "58.00597",
    "lng": "39.17717"
  },
  {
    "country": "RU",
    "name": "Peskovka",
    "lat": "59.04478",
    "lng": "52.36057"
  },
  {
    "country": "RU",
    "name": "Peski",
    "lat": "55.21626",
    "lng": "38.76262"
  },
  {
    "country": "RU",
    "name": "Peshkovo",
    "lat": "47.01867",
    "lng": "39.38845"
  },
  {
    "country": "RU",
    "name": "Peshki",
    "lat": "56.13333",
    "lng": "37.06667"
  },
  {
    "country": "RU",
    "name": "Peschanokopskoye",
    "lat": "46.19517",
    "lng": "41.08143"
  },
  {
    "country": "RU",
    "name": "Pervoural’sk",
    "lat": "56.90528",
    "lng": "59.94361"
  },
  {
    "country": "RU",
    "name": "Pervomayskoye",
    "lat": "60.35922",
    "lng": "29.7424"
  },
  {
    "country": "RU",
    "name": "Pervomayskoye",
    "lat": "43.93847",
    "lng": "42.476"
  },
  {
    "country": "RU",
    "name": "Pervomayskiy",
    "lat": "56.61474",
    "lng": "43.35825"
  },
  {
    "country": "RU",
    "name": "Pervomayskiy",
    "lat": "54.04482",
    "lng": "37.50875"
  },
  {
    "country": "RU",
    "name": "Pervomayskiy",
    "lat": "53.2485",
    "lng": "40.2871"
  },
  {
    "country": "RU",
    "name": "Bakhchivandzhi",
    "lat": "55.88333",
    "lng": "38.08333"
  },
  {
    "country": "RU",
    "name": "Pervomayskaya",
    "lat": "43.40331",
    "lng": "45.52343"
  },
  {
    "country": "RU",
    "name": "Pervomaysk",
    "lat": "54.8689",
    "lng": "43.80272"
  },
  {
    "country": "RU",
    "name": "Pervoavgustovskiy",
    "lat": "52.2264",
    "lng": "35.0552"
  },
  {
    "country": "RU",
    "name": "Perm",
    "lat": "58.01046",
    "lng": "56.25017"
  },
  {
    "country": "RU",
    "name": "Pereyaslovskaya",
    "lat": "45.84121",
    "lng": "39.02379"
  },
  {
    "country": "RU",
    "name": "Perevoz",
    "lat": "55.59613",
    "lng": "44.54461"
  },
  {
    "country": "RU",
    "name": "Perevolotskiy",
    "lat": "51.87633",
    "lng": "54.19378"
  },
  {
    "country": "RU",
    "name": "Perevoloki",
    "lat": "53.2458",
    "lng": "49.1793"
  },
  {
    "country": "RU",
    "name": "Pereslavl’-Zalesskiy",
    "lat": "56.73934",
    "lng": "38.85626"
  },
  {
    "country": "RU",
    "name": "Perepravnaya",
    "lat": "44.3366",
    "lng": "40.7849"
  },
  {
    "country": "RU",
    "name": "Peremyshl’",
    "lat": "54.26313",
    "lng": "36.16063"
  },
  {
    "country": "RU",
    "name": "Perelyub",
    "lat": "51.86292",
    "lng": "50.35412"
  },
  {
    "country": "RU",
    "name": "Pereleshinskiy",
    "lat": "51.7148",
    "lng": "40.1953"
  },
  {
    "country": "RU",
    "name": "Pereleshino",
    "lat": "51.7376",
    "lng": "40.1388"
  },
  {
    "country": "RU",
    "name": "Peredovaya",
    "lat": "44.11722",
    "lng": "41.47556"
  },
  {
    "country": "RU",
    "name": "Novo-Peredelkino",
    "lat": "55.64528",
    "lng": "37.33583"
  },
  {
    "country": "RU",
    "name": "Penza",
    "lat": "53.20066",
    "lng": "45.00464"
  },
  {
    "country": "RU",
    "name": "Peno",
    "lat": "56.92624",
    "lng": "32.74262"
  },
  {
    "country": "RU",
    "name": "Pelagiada",
    "lat": "45.20639",
    "lng": "42.02361"
  },
  {
    "country": "RU",
    "name": "Pechory",
    "lat": "57.81642",
    "lng": "27.6119"
  },
  {
    "country": "RU",
    "name": "Pechora",
    "lat": "65.14717",
    "lng": "57.22439"
  },
  {
    "country": "RU",
    "name": "Pechersk",
    "lat": "54.85355",
    "lng": "32.03154"
  },
  {
    "country": "RU",
    "name": "Pechenga",
    "lat": "69.52587",
    "lng": "31.17027"
  },
  {
    "country": "RU",
    "name": "Pavshino",
    "lat": "55.81667",
    "lng": "37.35"
  },
  {
    "country": "RU",
    "name": "Pavlovskiy Posad",
    "lat": "55.78187",
    "lng": "38.65025"
  },
  {
    "country": "RU",
    "name": "Pavlovskiy",
    "lat": "57.8424",
    "lng": "54.84357"
  },
  {
    "country": "RU",
    "name": "Pavlovskaya Sloboda",
    "lat": "55.81517",
    "lng": "37.08246"
  },
  {
    "country": "RU",
    "name": "Pavlovskaya",
    "lat": "46.1377",
    "lng": "39.7832"
  },
  {
    "country": "RU",
    "name": "Pavlovsk",
    "lat": "59.68333",
    "lng": "30.43472"
  },
  {
    "country": "RU",
    "name": "Pavlovsk",
    "lat": "50.45778",
    "lng": "40.10806"
  },
  {
    "country": "RU",
    "name": "Pavlovo",
    "lat": "59.80861",
    "lng": "30.89667"
  },
  {
    "country": "RU",
    "name": "Pavlovka",
    "lat": "55.42094",
    "lng": "56.55426"
  },
  {
    "country": "RU",
    "name": "Pavlovka",
    "lat": "53.59569",
    "lng": "46.76631"
  },
  {
    "country": "RU",
    "name": "Pavlovka",
    "lat": "52.68966",
    "lng": "47.14046"
  },
  {
    "country": "RU",
    "name": "Pavlodol’skaya",
    "lat": "43.71923",
    "lng": "44.47815"
  },
  {
    "country": "RU",
    "name": "Pavino",
    "lat": "59.1139",
    "lng": "46.14142"
  },
  {
    "country": "RU",
    "name": "Pavelets",
    "lat": "53.78833",
    "lng": "39.24601"
  },
  {
    "country": "RU",
    "name": "Pashkovskiy",
    "lat": "45.02366",
    "lng": "39.10436"
  },
  {
    "country": "RU",
    "name": "Pashiya",
    "lat": "58.4324",
    "lng": "58.2562"
  },
  {
    "country": "RU",
    "name": "Pasegovo",
    "lat": "58.50602",
    "lng": "49.51383"
  },
  {
    "country": "RU",
    "name": "Partizan",
    "lat": "53.95017",
    "lng": "38.09801"
  },
  {
    "country": "RU",
    "name": "Parma",
    "lat": "66",
    "lng": "57.7"
  },
  {
    "country": "RU",
    "name": "Parkovyy",
    "lat": "45.83306",
    "lng": "40.14556"
  },
  {
    "country": "RU",
    "name": "Pargolovo",
    "lat": "60.0812",
    "lng": "30.27626"
  },
  {
    "country": "RU",
    "name": "Parfino",
    "lat": "57.97306",
    "lng": "31.64806"
  },
  {
    "country": "RU",
    "name": "Parfen’yevo",
    "lat": "58.48396",
    "lng": "43.40876"
  },
  {
    "country": "RU",
    "name": "Paraul",
    "lat": "42.74193",
    "lng": "47.35531"
  },
  {
    "country": "RU",
    "name": "Paran’ga",
    "lat": "56.70389",
    "lng": "49.40472"
  },
  {
    "country": "RU",
    "name": "Pankovka",
    "lat": "58.50004",
    "lng": "31.1999"
  },
  {
    "country": "RU",
    "name": "Panino",
    "lat": "51.6467",
    "lng": "40.1346"
  },
  {
    "country": "RU",
    "name": "Pamyat’ Parizhskoy Kommuny",
    "lat": "56.1048",
    "lng": "44.4952"
  },
  {
    "country": "RU",
    "name": "Pallasovka",
    "lat": "50.05",
    "lng": "46.88333"
  },
  {
    "country": "RU",
    "name": "Palkino",
    "lat": "57.54089",
    "lng": "28.01257"
  },
  {
    "country": "RU",
    "name": "Palekh",
    "lat": "56.80256",
    "lng": "41.85508"
  },
  {
    "country": "RU",
    "name": "Pachelma",
    "lat": "53.24426",
    "lng": "43.35205"
  },
  {
    "country": "RU",
    "name": "Staryye Ozinki",
    "lat": "51.1786",
    "lng": "49.6769"
  },
  {
    "country": "RU",
    "name": "Ozherel’ye",
    "lat": "54.79197",
    "lng": "38.26559"
  },
  {
    "country": "RU",
    "name": "Ozëry",
    "lat": "54.85998",
    "lng": "38.55062"
  },
  {
    "country": "RU",
    "name": "Ozërsk",
    "lat": "54.41056",
    "lng": "22.01167"
  },
  {
    "country": "RU",
    "name": "Ozërnyy",
    "lat": "55.5802",
    "lng": "32.4127"
  },
  {
    "country": "RU",
    "name": "Ozerki",
    "lat": "60.03947",
    "lng": "30.31128"
  },
  {
    "country": "RU",
    "name": "Ovoshchi",
    "lat": "45.36639",
    "lng": "43.32333"
  },
  {
    "country": "RU",
    "name": "Overyata",
    "lat": "58.08417",
    "lng": "55.86694"
  },
  {
    "country": "RU",
    "name": "Otrado-Kubanskoye",
    "lat": "45.24417",
    "lng": "40.84083"
  },
  {
    "country": "RU",
    "name": "Otradnyy",
    "lat": "53.37596",
    "lng": "51.3452"
  },
  {
    "country": "RU",
    "name": "Otradnoye",
    "lat": "55.86667",
    "lng": "37.6"
  },
  {
    "country": "RU",
    "name": "Otradnoye",
    "lat": "59.7775",
    "lng": "30.81806"
  },
  {
    "country": "RU",
    "name": "Otradnaya",
    "lat": "44.39333",
    "lng": "41.52056"
  },
  {
    "country": "RU",
    "name": "Otkaznoye",
    "lat": "44.32639",
    "lng": "43.86083"
  },
  {
    "country": "RU",
    "name": "Osyno",
    "lat": "56.15053",
    "lng": "28.6758"
  },
  {
    "country": "RU",
    "name": "Ostrovtsy",
    "lat": "55.5875",
    "lng": "38.00556"
  },
  {
    "country": "RU",
    "name": "Ostrovskoye",
    "lat": "57.80574",
    "lng": "42.24332"
  },
  {
    "country": "RU",
    "name": "Ostrov",
    "lat": "57.34395",
    "lng": "28.35368"
  },
  {
    "country": "RU",
    "name": "Ostrogozhsk",
    "lat": "50.8664",
    "lng": "39.07561"
  },
  {
    "country": "RU",
    "name": "Oster",
    "lat": "54.017",
    "lng": "32.8019"
  },
  {
    "country": "RU",
    "name": "Ostashkov",
    "lat": "57.14667",
    "lng": "33.10753"
  },
  {
    "country": "RU",
    "name": "Ostashëvo",
    "lat": "55.85896",
    "lng": "35.86948"
  },
  {
    "country": "RU",
    "name": "Ostankinskiy",
    "lat": "55.82957",
    "lng": "37.61604"
  },
  {
    "country": "RU",
    "name": "Osinovo",
    "lat": "55.8809",
    "lng": "48.881"
  },
  {
    "country": "RU",
    "name": "Osinki",
    "lat": "52.8432",
    "lng": "49.5132"
  },
  {
    "country": "RU",
    "name": "Osel’ki",
    "lat": "60.20503",
    "lng": "30.49667"
  },
  {
    "country": "RU",
    "name": "Osa",
    "lat": "57.283",
    "lng": "55.4589"
  },
  {
    "country": "RU",
    "name": "Orud’yevo",
    "lat": "56.43333",
    "lng": "37.53333"
  },
  {
    "country": "RU",
    "name": "Orsk",
    "lat": "51.20487",
    "lng": "58.56685"
  },
  {
    "country": "RU",
    "name": "Orshanka",
    "lat": "56.91607",
    "lng": "47.89335"
  },
  {
    "country": "RU",
    "name": "Orsha",
    "lat": "56.91196",
    "lng": "36.22862"
  },
  {
    "country": "RU",
    "name": "Orlovskiy",
    "lat": "46.87139",
    "lng": "42.05917"
  },
  {
    "country": "RU",
    "name": "Orlovo",
    "lat": "51.75397",
    "lng": "39.58731"
  },
  {
    "country": "RU",
    "name": "Orlovka",
    "lat": "44.69139",
    "lng": "44.17444"
  },
  {
    "country": "RU",
    "name": "Orichi",
    "lat": "58.40356",
    "lng": "49.05719"
  },
  {
    "country": "RU",
    "name": "Orgtrud",
    "lat": "56.1832",
    "lng": "40.6149"
  },
  {
    "country": "RU",
    "name": "Orenburg",
    "lat": "51.7727",
    "lng": "55.0988"
  },
  {
    "country": "RU",
    "name": "Orël",
    "lat": "52.96508",
    "lng": "36.07849"
  },
  {
    "country": "RU",
    "name": "Orekhovo-Zuyevo",
    "lat": "55.80672",
    "lng": "38.96178"
  },
  {
    "country": "RU",
    "name": "Orekhovo-Borisovo Severnoye",
    "lat": "55.61667",
    "lng": "37.68333"
  },
  {
    "country": "RU",
    "name": "Ordzhonikidzevskiy",
    "lat": "43.84233",
    "lng": "41.89636"
  },
  {
    "country": "RU",
    "name": "Sunzha",
    "lat": "43.3195",
    "lng": "45.04911"
  },
  {
    "country": "RU",
    "name": "Orda",
    "lat": "57.19509",
    "lng": "56.90908"
  },
  {
    "country": "RU",
    "name": "Oranzherei",
    "lat": "45.84756",
    "lng": "47.56635"
  },
  {
    "country": "RU",
    "name": "Opochka",
    "lat": "56.71357",
    "lng": "28.66388"
  },
  {
    "country": "RU",
    "name": "Opechenskiy Posad",
    "lat": "58.2751",
    "lng": "34.11731"
  },
  {
    "country": "RU",
    "name": "Oparino",
    "lat": "59.85179",
    "lng": "48.27826"
  },
  {
    "country": "RU",
    "name": "Opalikha",
    "lat": "55.82593",
    "lng": "37.25278"
  },
  {
    "country": "RU",
    "name": "Onega",
    "lat": "63.90692",
    "lng": "38.11112"
  },
  {
    "country": "RU",
    "name": "Omutninsk",
    "lat": "58.67001",
    "lng": "52.1932"
  },
  {
    "country": "RU",
    "name": "Olym",
    "lat": "51.6798",
    "lng": "38.1758"
  },
  {
    "country": "RU",
    "name": "Olonets",
    "lat": "60.98475",
    "lng": "32.96976"
  },
  {
    "country": "RU",
    "name": "Ol’khovatka",
    "lat": "50.28308",
    "lng": "39.28715"
  },
  {
    "country": "RU",
    "name": "Ol’gino",
    "lat": "59.83702",
    "lng": "29.92266"
  },
  {
    "country": "RU",
    "name": "Ol’ginskaya",
    "lat": "47.18794",
    "lng": "39.94925"
  },
  {
    "country": "RU",
    "name": "Ol’ginskaya",
    "lat": "45.9461",
    "lng": "38.54864"
  },
  {
    "country": "RU",
    "name": "Ol’gino",
    "lat": "60.00928",
    "lng": "30.11559"
  },
  {
    "country": "RU",
    "name": "Ol’ginka",
    "lat": "44.2075",
    "lng": "38.89111"
  },
  {
    "country": "RU",
    "name": "Olenino",
    "lat": "56.20917",
    "lng": "33.48888"
  },
  {
    "country": "RU",
    "name": "Olenegorsk",
    "lat": "68.1432",
    "lng": "33.25287"
  },
  {
    "country": "RU",
    "name": "Okulovka",
    "lat": "58.40083",
    "lng": "33.29083"
  },
  {
    "country": "RU",
    "name": "Tsotsin-Yurt",
    "lat": "43.24206",
    "lng": "46.00013"
  },
  {
    "country": "RU",
    "name": "Oktyabr’skiy",
    "lat": "56.21887",
    "lng": "42.04069"
  },
  {
    "country": "RU",
    "name": "Oktyabr’skiy",
    "lat": "55.60806",
    "lng": "37.97738"
  },
  {
    "country": "RU",
    "name": "Oktyabr’skiy",
    "lat": "54.48147",
    "lng": "53.47103"
  },
  {
    "country": "RU",
    "name": "Oktyabr’skiy",
    "lat": "54.22675",
    "lng": "38.89402"
  },
  {
    "country": "RU",
    "name": "Takhtamukay",
    "lat": "44.9215",
    "lng": "38.99583"
  },
  {
    "country": "RU",
    "name": "Oksovskiy",
    "lat": "62.60623",
    "lng": "39.89845"
  },
  {
    "country": "RU",
    "name": "Okhansk",
    "lat": "57.7203",
    "lng": "55.3882"
  },
  {
    "country": "RU",
    "name": "Odoyev",
    "lat": "53.93933",
    "lng": "36.68639"
  },
  {
    "country": "RU",
    "name": "Odintsovo",
    "lat": "55.67798",
    "lng": "37.27773"
  },
  {
    "country": "RU",
    "name": "Ochër",
    "lat": "57.89035",
    "lng": "54.72019"
  },
  {
    "country": "RU",
    "name": "Ochakovo-Matveyevskoye",
    "lat": "55.68432",
    "lng": "37.44654"
  },
  {
    "country": "RU",
    "name": "Obukhovo",
    "lat": "55.83278",
    "lng": "38.2725"
  },
  {
    "country": "RU",
    "name": "Obsharovka",
    "lat": "53.125",
    "lng": "48.85306"
  },
  {
    "country": "RU",
    "name": "Oboyan’",
    "lat": "51.20981",
    "lng": "36.27919"
  },
  {
    "country": "RU",
    "name": "Obninsk",
    "lat": "55.09681",
    "lng": "36.61006"
  },
  {
    "country": "RU",
    "name": "Oblivskaya",
    "lat": "48.53616",
    "lng": "42.50138"
  },
  {
    "country": "RU",
    "name": "Nyuksenitsa",
    "lat": "60.41159",
    "lng": "44.23309"
  },
  {
    "country": "RU",
    "name": "Nytva",
    "lat": "57.9437",
    "lng": "55.3396"
  },
  {
    "country": "RU",
    "name": "Nyrob",
    "lat": "60.733",
    "lng": "56.72024"
  },
  {
    "country": "RU",
    "name": "Nyazepetrovsk",
    "lat": "56.05306",
    "lng": "59.60278"
  },
  {
    "country": "RU",
    "name": "Nyandoma",
    "lat": "61.6656",
    "lng": "40.2013"
  },
  {
    "country": "RU",
    "name": "Nurma",
    "lat": "59.55",
    "lng": "31.01667"
  },
  {
    "country": "RU",
    "name": "Nurlat",
    "lat": "54.42766",
    "lng": "50.80511"
  },
  {
    "country": "RU",
    "name": "Nuradilovo",
    "lat": "43.28447",
    "lng": "46.45763"
  },
  {
    "country": "RU",
    "name": "Nudol’",
    "lat": "56.1",
    "lng": "36.51667"
  },
  {
    "country": "RU",
    "name": "Nozhay-Yurt",
    "lat": "43.0929",
    "lng": "46.37868"
  },
  {
    "country": "RU",
    "name": "Novyy Yegorlyk",
    "lat": "46.3927",
    "lng": "41.87162"
  },
  {
    "country": "RU",
    "name": "Novyy Ropsk",
    "lat": "52.29781",
    "lng": "32.31206"
  },
  {
    "country": "RU",
    "name": "Novyy Rogachik",
    "lat": "48.67685",
    "lng": "44.06081"
  },
  {
    "country": "RU",
    "name": "Novyy Oskol",
    "lat": "50.7633",
    "lng": "37.86402"
  },
  {
    "country": "RU",
    "name": "Novyy Nekouz",
    "lat": "57.90286",
    "lng": "38.07004"
  },
  {
    "country": "RU",
    "name": "Novyy Karachay",
    "lat": "43.82076",
    "lng": "41.90322"
  },
  {
    "country": "RU",
    "name": "Novyye Lyady",
    "lat": "58.0552",
    "lng": "56.6104"
  },
  {
    "country": "RU",
    "name": "Novyye Kuz’minki",
    "lat": "55.7",
    "lng": "37.75"
  },
  {
    "country": "RU",
    "name": "Novyye Gorki",
    "lat": "56.72535",
    "lng": "41.06014"
  },
  {
    "country": "RU",
    "name": "Novyye Cherëmushki",
    "lat": "55.7",
    "lng": "37.58333"
  },
  {
    "country": "RU",
    "name": "Novyye Burasy",
    "lat": "52.13236",
    "lng": "46.07144"
  },
  {
    "country": "RU",
    "name": "Novyye Atagi",
    "lat": "43.13528",
    "lng": "45.77306"
  },
  {
    "country": "RU",
    "name": "Novyy Byt",
    "lat": "55.05857",
    "lng": "37.61348"
  },
  {
    "country": "RU",
    "name": "Novyy Buyan",
    "lat": "53.68611",
    "lng": "50.04691"
  },
  {
    "country": "RU",
    "name": "Novozybkov",
    "lat": "52.5396",
    "lng": "31.9275"
  },
  {
    "country": "RU",
    "name": "Novozhivotinnoye",
    "lat": "51.8877",
    "lng": "39.16894"
  },
  {
    "country": "RU",
    "name": "Novozavedennoye",
    "lat": "44.26278",
    "lng": "43.63806"
  },
  {
    "country": "RU",
    "name": "Novoye Leushino",
    "lat": "56.80732",
    "lng": "40.51443"
  },
  {
    "country": "RU",
    "name": "Novoye Devyatkino",
    "lat": "60.06364",
    "lng": "30.48328"
  },
  {
    "country": "RU",
    "name": "Novoye",
    "lat": "55.63104",
    "lng": "38.92001"
  },
  {
    "country": "RU",
    "name": "Novovyazniki",
    "lat": "56.1975",
    "lng": "42.17111"
  },
  {
    "country": "RU",
    "name": "Novovoronezh",
    "lat": "51.30719",
    "lng": "39.21732"
  },
  {
    "country": "RU",
    "name": "Novovelichkovskaya",
    "lat": "45.27638",
    "lng": "38.84165"
  },
  {
    "country": "RU",
    "name": "Novouzensk",
    "lat": "50.45917",
    "lng": "48.14306"
  },
  {
    "country": "RU",
    "name": "Novoutkinsk",
    "lat": "56.99295",
    "lng": "59.55714"
  },
  {
    "country": "RU",
    "name": "Novoul’yanovsk",
    "lat": "54.14961",
    "lng": "48.38907"
  },
  {
    "country": "RU",
    "name": "Novoukrainskoye",
    "lat": "45.37833",
    "lng": "40.52972"
  },
  {
    "country": "RU",
    "name": "Novoukrainskiy",
    "lat": "44.8942",
    "lng": "38.04886"
  },
  {
    "country": "RU",
    "name": "Novotroitskaya",
    "lat": "45.32667",
    "lng": "41.52528"
  },
  {
    "country": "RU",
    "name": "Novotroitsk",
    "lat": "51.20301",
    "lng": "58.32665"
  },
  {
    "country": "RU",
    "name": "Novotitarovskaya",
    "lat": "45.23756",
    "lng": "38.98059"
  },
  {
    "country": "RU",
    "name": "Novo-Talitsy",
    "lat": "57.00392",
    "lng": "40.85936"
  },
  {
    "country": "RU",
    "name": "Novospasskoye",
    "lat": "53.14683",
    "lng": "47.75138"
  },
  {
    "country": "RU",
    "name": "Novosokol’niki",
    "lat": "56.34634",
    "lng": "30.15778"
  },
  {
    "country": "RU",
    "name": "Novosmolinskiy",
    "lat": "56.2841",
    "lng": "43.05071"
  },
  {
    "country": "RU",
    "name": "Novosil’",
    "lat": "52.97387",
    "lng": "37.04048"
  },
  {
    "country": "RU",
    "name": "Novosheshminsk",
    "lat": "55.06513",
    "lng": "51.23376"
  },
  {
    "country": "RU",
    "name": "Novoshcherbinovskaya",
    "lat": "46.47669",
    "lng": "38.64757"
  },
  {
    "country": "RU",
    "name": "Novoshakhtinsk",
    "lat": "47.76037",
    "lng": "39.93335"
  },
  {
    "country": "RU",
    "name": "Novosergiyevka",
    "lat": "52.0934",
    "lng": "53.6528"
  },
  {
    "country": "RU",
    "name": "Novosemeykino",
    "lat": "53.37056",
    "lng": "50.35428"
  },
  {
    "country": "RU",
    "name": "Novoselitskoye",
    "lat": "44.75083",
    "lng": "43.43694"
  },
  {
    "country": "RU",
    "name": "Novorzhev",
    "lat": "57.02942",
    "lng": "29.33378"
  },
  {
    "country": "RU",
    "name": "Novorudnyy",
    "lat": "51.5026",
    "lng": "58.1873"
  },
  {
    "country": "RU",
    "name": "Novorozhdestvenskaya",
    "lat": "45.86057",
    "lng": "39.94968"
  },
  {
    "country": "RU",
    "name": "Novorossiysk",
    "lat": "44.72439",
    "lng": "37.76752"
  },
  {
    "country": "RU",
    "name": "Novopokrovskaya",
    "lat": "45.95139",
    "lng": "40.70056"
  },
  {
    "country": "RU",
    "name": "Novopokrovka",
    "lat": "52.1331",
    "lng": "40.8783"
  },
  {
    "country": "RU",
    "name": "Novopodrezkovo",
    "lat": "55.93972",
    "lng": "37.34417"
  },
  {
    "country": "RU",
    "name": "Novoplatnirovskaya",
    "lat": "46.1065",
    "lng": "39.4191"
  },
  {
    "country": "RU",
    "name": "Novopistsovo",
    "lat": "57.32177",
    "lng": "41.8531"
  },
  {
    "country": "RU",
    "name": "Novopetrovskoye",
    "lat": "55.99278",
    "lng": "36.47194"
  },
  {
    "country": "RU",
    "name": "Novopavlovsk",
    "lat": "43.96222",
    "lng": "43.63417"
  },
  {
    "country": "RU",
    "name": "Novoorsk",
    "lat": "51.381",
    "lng": "58.9813"
  },
  {
    "country": "RU",
    "name": "Novo-Nikol’skoye",
    "lat": "56.56667",
    "lng": "37.53333"
  },
  {
    "country": "RU",
    "name": "Novonikolayevskiy",
    "lat": "50.9738",
    "lng": "42.3649"
  },
  {
    "country": "RU",
    "name": "Novomyshastovskaya",
    "lat": "45.19909",
    "lng": "38.58272"
  },
  {
    "country": "RU",
    "name": "Novomoskovsk",
    "lat": "54.0105",
    "lng": "38.2846"
  },
  {
    "country": "RU",
    "name": "Novominskaya",
    "lat": "46.3163",
    "lng": "38.9586"
  },
  {
    "country": "RU",
    "name": "Novomikhaylovskiy",
    "lat": "44.2626",
    "lng": "38.8585"
  },
  {
    "country": "RU",
    "name": "Novomichurinsk",
    "lat": "54.0384",
    "lng": "39.7479"
  },
  {
    "country": "RU",
    "name": "Novaya Malykla",
    "lat": "54.2",
    "lng": "49.95"
  },
  {
    "country": "RU",
    "name": "Novomalorossiyskaya",
    "lat": "45.63483",
    "lng": "39.89481"
  },
  {
    "country": "RU",
    "name": "Novoleushkovskaya",
    "lat": "45.9956",
    "lng": "39.9921"
  },
  {
    "country": "RU",
    "name": "Novolakskoye",
    "lat": "43.11952",
    "lng": "46.48281"
  },
  {
    "country": "RU",
    "name": "Novolabinskaya",
    "lat": "45.10956",
    "lng": "39.89399"
  },
  {
    "country": "RU",
    "name": "Novokuz’minki",
    "lat": "55.71667",
    "lng": "37.78333"
  },
  {
    "country": "RU",
    "name": "Novokuybyshevsk",
    "lat": "53.0959",
    "lng": "49.9462"
  },
  {
    "country": "RU",
    "name": "Novokubansk",
    "lat": "45.117",
    "lng": "41.0267"
  },
  {
    "country": "RU",
    "name": "Novokorsunskaya",
    "lat": "45.6408",
    "lng": "39.14641"
  },
  {
    "country": "RU",
    "name": "Novokhovrino",
    "lat": "55.86667",
    "lng": "37.5"
  },
  {
    "country": "RU",
    "name": "Novokhopërsk",
    "lat": "51.0969",
    "lng": "41.6252"
  },
  {
    "country": "RU",
    "name": "Novokayakent",
    "lat": "42.39368",
    "lng": "47.98608"
  },
  {
    "country": "RU",
    "name": "Novyy Izborsk",
    "lat": "57.77079",
    "lng": "27.97306"
  },
  {
    "country": "RU",
    "name": "Novoivanovskoye",
    "lat": "55.70381",
    "lng": "37.3651"
  },
  {
    "country": "RU",
    "name": "Novogurovskiy",
    "lat": "54.46782",
    "lng": "37.33709"
  },
  {
    "country": "RU",
    "name": "Oyskhara",
    "lat": "43.26402",
    "lng": "46.24803"
  },
  {
    "country": "RU",
    "name": "Grebnevo",
    "lat": "55.95074",
    "lng": "38.07973"
  },
  {
    "country": "RU",
    "name": "Novogireyevo",
    "lat": "55.75378",
    "lng": "37.81885"
  },
  {
    "country": "RU",
    "name": "Novogagatli",
    "lat": "43.45677",
    "lng": "46.48175"
  },
  {
    "country": "RU",
    "name": "Novodzhereliyevskaya",
    "lat": "45.77373",
    "lng": "38.67227"
  },
  {
    "country": "RU",
    "name": "Novodvinsk",
    "lat": "64.4165",
    "lng": "40.8122"
  },
  {
    "country": "RU",
    "name": "Novodugino",
    "lat": "55.63052",
    "lng": "34.28423"
  },
  {
    "country": "RU",
    "name": "Novodmitriyevskaya",
    "lat": "44.83276",
    "lng": "38.87847"
  },
  {
    "country": "RU",
    "name": "Novoderevyankovskaya",
    "lat": "46.32312",
    "lng": "38.74724"
  },
  {
    "country": "RU",
    "name": "Novocherkassk",
    "lat": "47.42096",
    "lng": "40.09185"
  },
  {
    "country": "RU",
    "name": "Novocheremshansk",
    "lat": "54.35714",
    "lng": "50.16662"
  },
  {
    "country": "RU",
    "name": "Novocheboksarsk",
    "lat": "56.11095",
    "lng": "47.47755"
  },
  {
    "country": "RU",
    "name": "Novoblagodarnoye",
    "lat": "44.14333",
    "lng": "42.875"
  },
  {
    "country": "RU",
    "name": "Novobeysugskaya",
    "lat": "45.47195",
    "lng": "39.88614"
  },
  {
    "country": "RU",
    "name": "Novobessergenovka",
    "lat": "47.18465",
    "lng": "38.84625"
  },
  {
    "country": "RU",
    "name": "Novobelokatay",
    "lat": "55.7062",
    "lng": "58.9549"
  },
  {
    "country": "RU",
    "name": "Novobataysk",
    "lat": "46.89806",
    "lng": "39.78194"
  },
  {
    "country": "RU",
    "name": "Novoanninskiy",
    "lat": "50.5287",
    "lng": "42.6747"
  },
  {
    "country": "RU",
    "name": "Novoalekseyevskaya",
    "lat": "44.81889",
    "lng": "40.93389"
  },
  {
    "country": "RU",
    "name": "Novoaleksandrovsk",
    "lat": "45.4948",
    "lng": "41.22075"
  },
  {
    "country": "RU",
    "name": "Novki",
    "lat": "56.36386",
    "lng": "41.08655"
  },
  {
    "country": "RU",
    "name": "Velikiy Novgorod",
    "lat": "58.52131",
    "lng": "31.27104"
  },
  {
    "country": "RU",
    "name": "Novaya Usman’",
    "lat": "51.64177",
    "lng": "39.40863"
  },
  {
    "country": "RU",
    "name": "Novaya Tavolzhanka",
    "lat": "50.35123",
    "lng": "36.8298"
  },
  {
    "country": "RU",
    "name": "Novaya Mayna",
    "lat": "54.15",
    "lng": "49.75"
  },
  {
    "country": "RU",
    "name": "Novaya Lyada",
    "lat": "52.71309",
    "lng": "41.63872"
  },
  {
    "country": "RU",
    "name": "Novaya Ladoga",
    "lat": "60.10246",
    "lng": "32.30191"
  },
  {
    "country": "RU",
    "name": "Novaya Derevnya",
    "lat": "59.98748",
    "lng": "30.28682"
  },
  {
    "country": "RU",
    "name": "Novaya Chigla",
    "lat": "51.22333",
    "lng": "40.47806"
  },
  {
    "country": "RU",
    "name": "Nolinsk",
    "lat": "57.55962",
    "lng": "49.93629"
  },
  {
    "country": "RU",
    "name": "Nogir",
    "lat": "43.08162",
    "lng": "44.6365"
  },
  {
    "country": "RU",
    "name": "Noginsk",
    "lat": "55.86647",
    "lng": "38.4438"
  },
  {
    "country": "RU",
    "name": "Nizhnyaya Tura",
    "lat": "58.6293",
    "lng": "59.8118"
  },
  {
    "country": "RU",
    "name": "Nizhnepavlovka",
    "lat": "51.71324",
    "lng": "54.80146"
  },
  {
    "country": "RU",
    "name": "Nizhnyaya Maktama",
    "lat": "54.86356",
    "lng": "52.4281"
  },
  {
    "country": "RU",
    "name": "Nizhnyaya Irga",
    "lat": "56.8669",
    "lng": "57.422"
  },
  {
    "country": "RU",
    "name": "Nizhniy Ufaley",
    "lat": "55.91528",
    "lng": "59.98417"
  },
  {
    "country": "RU",
    "name": "Nizhny Tagil",
    "lat": "57.91944",
    "lng": "59.965"
  },
  {
    "country": "RU",
    "name": "Nizhniy Odes",
    "lat": "63.64451",
    "lng": "54.85598"
  },
  {
    "country": "RU",
    "name": "Nizhniy Novgorod",
    "lat": "56.32867",
    "lng": "44.00205"
  },
  {
    "country": "RU",
    "name": "Nizhniy Mamon",
    "lat": "50.1937",
    "lng": "40.5083"
  },
  {
    "country": "RU",
    "name": "Nizhniy Lomov",
    "lat": "53.53041",
    "lng": "43.67663"
  },
  {
    "country": "RU",
    "name": "Nizhniy Kislyay",
    "lat": "50.8497",
    "lng": "40.1719"
  },
  {
    "country": "RU",
    "name": "Nizhniye Vyazovyye",
    "lat": "55.79877",
    "lng": "48.52476"
  },
  {
    "country": "RU",
    "name": "Nizhniye Sergi",
    "lat": "56.66139",
    "lng": "59.30333"
  },
  {
    "country": "RU",
    "name": "Nizhniye Achaluki",
    "lat": "43.4028",
    "lng": "44.75908"
  },
  {
    "country": "RU",
    "name": "Nizhniy Dzhengutay",
    "lat": "42.70008",
    "lng": "47.24488"
  },
  {
    "country": "RU",
    "name": "Nizhniy Chir",
    "lat": "48.35973",
    "lng": "43.0865"
  },
  {
    "country": "RU",
    "name": "Nizhniy Cherek",
    "lat": "43.51306",
    "lng": "43.91389"
  },
  {
    "country": "RU",
    "name": "Nizhniy Baskunchak",
    "lat": "48.21978",
    "lng": "46.83105"
  },
  {
    "country": "RU",
    "name": "Nizhniy Arkhyz",
    "lat": "43.67633",
    "lng": "41.45556"
  },
  {
    "country": "RU",
    "name": "Nizhneye Kazanishche",
    "lat": "42.76369",
    "lng": "47.16027"
  },
  {
    "country": "RU",
    "name": "Nizhnetroitskiy",
    "lat": "54.33852",
    "lng": "53.68329"
  },
  {
    "country": "RU",
    "name": "Nizhnekamsk",
    "lat": "55.63657",
    "lng": "51.82447"
  },
  {
    "country": "RU",
    "name": "Nizhneivkino",
    "lat": "58.19398",
    "lng": "49.52137"
  },
  {
    "country": "RU",
    "name": "Nizhnedevitsk",
    "lat": "51.5419",
    "lng": "38.3657"
  },
  {
    "country": "RU",
    "name": "Niny",
    "lat": "44.48778",
    "lng": "43.94889"
  },
  {
    "country": "RU",
    "name": "Nikulino",
    "lat": "55.66943",
    "lng": "37.46598"
  },
  {
    "country": "RU",
    "name": "Nikol’skoye",
    "lat": "55.68333",
    "lng": "37.48333"
  },
  {
    "country": "RU",
    "name": "Nikol’skoye",
    "lat": "59.70056",
    "lng": "30.78472"
  },
  {
    "country": "RU",
    "name": "Nikol’sk",
    "lat": "59.53531",
    "lng": "45.45743"
  },
  {
    "country": "RU",
    "name": "Nikol’sk",
    "lat": "53.71886",
    "lng": "46.07118"
  },
  {
    "country": "RU",
    "name": "Nikologory",
    "lat": "56.1413",
    "lng": "41.99218"
  },
  {
    "country": "RU",
    "name": "Nikolo-Berëzovka",
    "lat": "56.12422",
    "lng": "54.15573"
  },
  {
    "country": "RU",
    "name": "Nikolina Gora",
    "lat": "55.73433",
    "lng": "37.04364"
  },
  {
    "country": "RU",
    "name": "Nikolayevskaya",
    "lat": "47.61391",
    "lng": "41.5023"
  },
  {
    "country": "RU",
    "name": "Nikolayevsk",
    "lat": "50.02824",
    "lng": "45.45953"
  },
  {
    "country": "RU",
    "name": "Nikolayevka",
    "lat": "54.1451",
    "lng": "45.1444"
  },
  {
    "country": "RU",
    "name": "Nikolayevka",
    "lat": "53.1257",
    "lng": "47.2041"
  },
  {
    "country": "RU",
    "name": "Nikola-Lenivets",
    "lat": "54.74943",
    "lng": "35.60133"
  },
  {
    "country": "RU",
    "name": "Nikel",
    "lat": "69.41285",
    "lng": "30.22198"
  },
  {
    "country": "RU",
    "name": "Nezlobnaya",
    "lat": "44.11806",
    "lng": "43.40278"
  },
  {
    "country": "RU",
    "name": "Nezhinka",
    "lat": "51.7676",
    "lng": "55.3694"
  },
  {
    "country": "RU",
    "name": "Neya",
    "lat": "58.29719",
    "lng": "43.86808"
  },
  {
    "country": "RU",
    "name": "Nevinnomyssk",
    "lat": "44.6333",
    "lng": "41.9444"
  },
  {
    "country": "RU",
    "name": "Neverkino",
    "lat": "52.78541",
    "lng": "46.74174"
  },
  {
    "country": "RU",
    "name": "Nevel’",
    "lat": "56.02094",
    "lng": "29.92844"
  },
  {
    "country": "RU",
    "name": "Nesterovskaya",
    "lat": "43.23861",
    "lng": "45.05028"
  },
  {
    "country": "RU",
    "name": "Nesterov",
    "lat": "54.63056",
    "lng": "22.57139"
  },
  {
    "country": "RU",
    "name": "Nerl’",
    "lat": "56.66285",
    "lng": "40.38931"
  },
  {
    "country": "RU",
    "name": "Nerekhta",
    "lat": "57.45881",
    "lng": "40.57471"
  },
  {
    "country": "RU",
    "name": "Nemchinovka",
    "lat": "55.72288",
    "lng": "37.36086"
  },
  {
    "country": "RU",
    "name": "Neman",
    "lat": "55.03111",
    "lng": "22.02639"
  },
  {
    "country": "RU",
    "name": "Nema",
    "lat": "57.50675",
    "lng": "50.50115"
  },
  {
    "country": "RU",
    "name": "Nelidovo",
    "lat": "56.22107",
    "lng": "32.77738"
  },
  {
    "country": "RU",
    "name": "Nelazskoye",
    "lat": "59.18919",
    "lng": "37.63963"
  },
  {
    "country": "RU",
    "name": "Nekrasovskoye",
    "lat": "57.67663",
    "lng": "40.36567"
  },
  {
    "country": "RU",
    "name": "Nekrasovskiy",
    "lat": "56.09349",
    "lng": "37.49934"
  },
  {
    "country": "RU",
    "name": "Nekrasovskaya",
    "lat": "45.14468",
    "lng": "39.74868"
  },
  {
    "country": "RU",
    "name": "Nekrasovka",
    "lat": "55.69328",
    "lng": "37.91148"
  },
  {
    "country": "RU",
    "name": "Neklyudovo",
    "lat": "56.41421",
    "lng": "43.97721"
  },
  {
    "country": "RU",
    "name": "Nekhayevskiy",
    "lat": "50.4106",
    "lng": "41.7561"
  },
  {
    "country": "RU",
    "name": "Neftekamsk",
    "lat": "56.092",
    "lng": "54.2661"
  },
  {
    "country": "RU",
    "name": "Neftegorsk",
    "lat": "52.802",
    "lng": "51.166"
  },
  {
    "country": "RU",
    "name": "Neftegorsk",
    "lat": "44.3658",
    "lng": "39.7078"
  },
  {
    "country": "RU",
    "name": "Nedvigovka",
    "lat": "47.26873",
    "lng": "39.3488"
  },
  {
    "country": "RU",
    "name": "Nebug",
    "lat": "44.1717",
    "lng": "39.0026"
  },
  {
    "country": "RU",
    "name": "Nebolchi",
    "lat": "59.12393",
    "lng": "33.34537"
  },
  {
    "country": "RU",
    "name": "Nazran’",
    "lat": "43.22597",
    "lng": "44.77323"
  },
  {
    "country": "RU",
    "name": "Nazar'yevo",
    "lat": "55.67417",
    "lng": "37.04028"
  },
  {
    "country": "RU",
    "name": "Navoloki",
    "lat": "57.46572",
    "lng": "41.96344"
  },
  {
    "country": "RU",
    "name": "Navlya",
    "lat": "52.82544",
    "lng": "34.4996"
  },
  {
    "country": "RU",
    "name": "Navashino",
    "lat": "55.5441",
    "lng": "42.1968"
  },
  {
    "country": "RU",
    "name": "Naurskaya",
    "lat": "43.65075",
    "lng": "45.31173"
  },
  {
    "country": "RU",
    "name": "Alpatovo",
    "lat": "43.7028",
    "lng": "45.24154"
  },
  {
    "country": "RU",
    "name": "Natyrbovo",
    "lat": "44.73",
    "lng": "40.62639"
  },
  {
    "country": "RU",
    "name": "Naryshkino",
    "lat": "52.96778",
    "lng": "35.72677"
  },
  {
    "country": "RU",
    "name": "Nar'yan-Mar",
    "lat": "67.63869",
    "lng": "53.00371"
  },
  {
    "country": "RU",
    "name": "Nartkala",
    "lat": "43.5575",
    "lng": "43.85083"
  },
  {
    "country": "RU",
    "name": "Nartan",
    "lat": "43.51083",
    "lng": "43.69944"
  },
  {
    "country": "RU",
    "name": "Narovchat",
    "lat": "53.87654",
    "lng": "43.69458"
  },
  {
    "country": "RU",
    "name": "Naro-Fominsk",
    "lat": "55.38752",
    "lng": "36.73307"
  },
  {
    "country": "RU",
    "name": "Narimanov",
    "lat": "46.6927",
    "lng": "47.8498"
  },
  {
    "country": "RU",
    "name": "Nal’chik",
    "lat": "43.49806",
    "lng": "43.61889"
  },
  {
    "country": "RU",
    "name": "Nakhabino",
    "lat": "55.84854",
    "lng": "37.17789"
  },
  {
    "country": "RU",
    "name": "Nagutskoye",
    "lat": "44.4415",
    "lng": "42.8762"
  },
  {
    "country": "RU",
    "name": "Nagorsk",
    "lat": "59.31722",
    "lng": "50.80778"
  },
  {
    "country": "RU",
    "name": "Lakha Nëvre",
    "lat": "43.62271",
    "lng": "45.33969"
  },
  {
    "country": "RU",
    "name": "Nadvoitsy",
    "lat": "63.86667",
    "lng": "34.31667"
  },
  {
    "country": "RU",
    "name": "Nadezhda",
    "lat": "44.1",
    "lng": "44.6"
  },
  {
    "country": "RU",
    "name": "Nachalovo",
    "lat": "46.338",
    "lng": "48.20128"
  },
  {
    "country": "RU",
    "name": "Naberezhnyye Chelny",
    "lat": "55.72545",
    "lng": "52.41122"
  },
  {
    "country": "RU",
    "name": "Myurego",
    "lat": "42.41087",
    "lng": "47.69304"
  },
  {
    "country": "RU",
    "name": "Mytishchi",
    "lat": "55.91163",
    "lng": "37.73076"
  },
  {
    "country": "RU",
    "name": "Myshkin",
    "lat": "57.78973",
    "lng": "38.45448"
  },
  {
    "country": "RU",
    "name": "Myatlevo",
    "lat": "54.89693",
    "lng": "35.67619"
  },
  {
    "country": "RU",
    "name": "Myaksa",
    "lat": "58.8889",
    "lng": "38.1938"
  },
  {
    "country": "RU",
    "name": "Muyezerskiy",
    "lat": "63.95758",
    "lng": "31.98738"
  },
  {
    "country": "RU",
    "name": "Mutsalaul",
    "lat": "43.27548",
    "lng": "46.73078"
  },
  {
    "country": "RU",
    "name": "Muslyumovo",
    "lat": "55.30333",
    "lng": "53.19472"
  },
  {
    "country": "RU",
    "name": "Murygino",
    "lat": "58.73831",
    "lng": "49.45822"
  },
  {
    "country": "RU",
    "name": "Murom",
    "lat": "55.575",
    "lng": "42.0426"
  },
  {
    "country": "RU",
    "name": "Murmino",
    "lat": "54.6043",
    "lng": "40.0549"
  },
  {
    "country": "RU",
    "name": "Murmashi",
    "lat": "68.81542",
    "lng": "32.81147"
  },
  {
    "country": "RU",
    "name": "Murmansk",
    "lat": "68.97917",
    "lng": "33.09251"
  },
  {
    "country": "RU",
    "name": "Murino",
    "lat": "60.04796",
    "lng": "30.45204"
  },
  {
    "country": "RU",
    "name": "Murashi",
    "lat": "59.3999",
    "lng": "48.9615"
  },
  {
    "country": "RU",
    "name": "Muranovo",
    "lat": "56.18333",
    "lng": "37.9"
  },
  {
    "country": "RU",
    "name": "Mumra",
    "lat": "45.77251",
    "lng": "47.65398"
  },
  {
    "country": "RU",
    "name": "Mullovka",
    "lat": "54.2",
    "lng": "49.4"
  },
  {
    "country": "RU",
    "name": "Mulino",
    "lat": "56.28923",
    "lng": "42.92005"
  },
  {
    "country": "RU",
    "name": "Mukhtolovo",
    "lat": "55.46751",
    "lng": "43.19973"
  },
  {
    "country": "RU",
    "name": "Mugi",
    "lat": "42.29944",
    "lng": "47.42077"
  },
  {
    "country": "RU",
    "name": "Muchkapskiy",
    "lat": "51.85133",
    "lng": "42.47175"
  },
  {
    "country": "RU",
    "name": "Mtsensk",
    "lat": "53.27657",
    "lng": "36.57334"
  },
  {
    "country": "RU",
    "name": "Mstikhino",
    "lat": "54.55947",
    "lng": "36.12777"
  },
  {
    "country": "RU",
    "name": "Mstera",
    "lat": "56.37889",
    "lng": "41.92"
  },
  {
    "country": "RU",
    "name": "Mrakovo",
    "lat": "52.71611",
    "lng": "56.62444"
  },
  {
    "country": "RU",
    "name": "Mozhga",
    "lat": "56.44469",
    "lng": "52.22763"
  },
  {
    "country": "RU",
    "name": "Mozhaysk",
    "lat": "55.50194",
    "lng": "36.02722"
  },
  {
    "country": "RU",
    "name": "Mozdok",
    "lat": "43.74359",
    "lng": "44.65177"
  },
  {
    "country": "RU",
    "name": "Mostovskoy",
    "lat": "44.41222",
    "lng": "40.79361"
  },
  {
    "country": "RU",
    "name": "Mostishche",
    "lat": "56.29123",
    "lng": "28.7642"
  },
  {
    "country": "RU",
    "name": "Moscow",
    "lat": "55.75222",
    "lng": "37.61556"
  },
  {
    "country": "RU",
    "name": "Moskovskoye",
    "lat": "45.2842",
    "lng": "41.9103"
  },
  {
    "country": "RU",
    "name": "Moshenskoye",
    "lat": "58.51016",
    "lng": "34.59108"
  },
  {
    "country": "RU",
    "name": "Mosal’sk",
    "lat": "54.48806",
    "lng": "34.98167"
  },
  {
    "country": "RU",
    "name": "Morshansk",
    "lat": "53.44354",
    "lng": "41.81065"
  },
  {
    "country": "RU",
    "name": "Morozovsk",
    "lat": "48.35502",
    "lng": "41.82627"
  },
  {
    "country": "RU",
    "name": "Morki",
    "lat": "56.43028",
    "lng": "48.99472"
  },
  {
    "country": "RU",
    "name": "Morgaushi",
    "lat": "55.9643",
    "lng": "46.7743"
  },
  {
    "country": "RU",
    "name": "Mordovo",
    "lat": "52.0834",
    "lng": "40.77"
  },
  {
    "country": "RU",
    "name": "Mordino",
    "lat": "61.35327",
    "lng": "51.89574"
  },
  {
    "country": "RU",
    "name": "Monino",
    "lat": "55.84244",
    "lng": "38.19362"
  },
  {
    "country": "RU",
    "name": "Monchegorsk",
    "lat": "67.93972",
    "lng": "32.87389"
  },
  {
    "country": "RU",
    "name": "Monastyrshchina",
    "lat": "54.34961",
    "lng": "31.83795"
  },
  {
    "country": "RU",
    "name": "Molokovo",
    "lat": "58.16611",
    "lng": "36.76278"
  },
  {
    "country": "RU",
    "name": "Molokovo",
    "lat": "55.56186",
    "lng": "37.86492"
  },
  {
    "country": "RU",
    "name": "Molodezhnoye",
    "lat": "60.19803",
    "lng": "29.51597"
  },
  {
    "country": "RU",
    "name": "Molochnoye",
    "lat": "59.29166",
    "lng": "39.67868"
  },
  {
    "country": "RU",
    "name": "Mokshan",
    "lat": "53.4365",
    "lng": "44.61322"
  },
  {
    "country": "RU",
    "name": "Mokrous",
    "lat": "51.2373",
    "lng": "47.5137"
  },
  {
    "country": "RU",
    "name": "Mochalishche",
    "lat": "56.3306",
    "lng": "48.3547"
  },
  {
    "country": "RU",
    "name": "Mshinskaya",
    "lat": "59.015",
    "lng": "29.94333"
  },
  {
    "country": "RU",
    "name": "Mizur",
    "lat": "42.85376",
    "lng": "44.06393"
  },
  {
    "country": "RU",
    "name": "Mitrofanovka",
    "lat": "49.97083",
    "lng": "39.69389"
  },
  {
    "country": "RU",
    "name": "Miskindzha",
    "lat": "41.42402",
    "lng": "47.84669"
  },
  {
    "country": "RU",
    "name": "Mishkino",
    "lat": "53.9997",
    "lng": "59.1064"
  },
  {
    "country": "RU",
    "name": "Misheronskiy",
    "lat": "55.71927",
    "lng": "39.73835"
  },
  {
    "country": "RU",
    "name": "Mirskoy",
    "lat": "45.5439",
    "lng": "40.3998"
  },
  {
    "country": "RU",
    "name": "Mirnyy",
    "lat": "61.33289",
    "lng": "44.53598"
  },
  {
    "country": "RU",
    "name": "Mirnyy",
    "lat": "58.49333",
    "lng": "47.65389"
  },
  {
    "country": "RU",
    "name": "Mirnyy",
    "lat": "54.36607",
    "lng": "48.72939"
  },
  {
    "country": "RU",
    "name": "Mirnyy",
    "lat": "53.50642",
    "lng": "50.27658"
  },
  {
    "country": "RU",
    "name": "Mineralnye Vody",
    "lat": "44.21028",
    "lng": "43.13528"
  },
  {
    "country": "RU",
    "name": "Mindyak",
    "lat": "54.0231",
    "lng": "58.7891"
  },
  {
    "country": "RU",
    "name": "Milyutinskaya",
    "lat": "48.62788",
    "lng": "41.66788"
  },
  {
    "country": "RU",
    "name": "Miloslavskoye",
    "lat": "53.58152",
    "lng": "39.43992"
  },
  {
    "country": "RU",
    "name": "Millerovo",
    "lat": "48.92265",
    "lng": "40.39673"
  },
  {
    "country": "RU",
    "name": "Mikun’",
    "lat": "62.35472",
    "lng": "50.07714"
  },
  {
    "country": "RU",
    "name": "Mikulino",
    "lat": "56.45188",
    "lng": "35.60685"
  },
  {
    "country": "RU",
    "name": "Mikhnëvo",
    "lat": "55.12747",
    "lng": "37.95451"
  },
  {
    "country": "RU",
    "name": "Mikhaylovskoye",
    "lat": "43.09972",
    "lng": "44.63164"
  },
  {
    "country": "RU",
    "name": "Mikhaylovskaya",
    "lat": "44.99472",
    "lng": "40.59639"
  },
  {
    "country": "RU",
    "name": "Mikhaylovsk",
    "lat": "56.43583",
    "lng": "59.12"
  },
  {
    "country": "RU",
    "name": "Mikhaylovka",
    "lat": "54.805",
    "lng": "55.89193"
  },
  {
    "country": "RU",
    "name": "Mikhaylovka",
    "lat": "52.2317",
    "lng": "35.3767"
  },
  {
    "country": "RU",
    "name": "Mikhaylovka",
    "lat": "50.06",
    "lng": "43.2379"
  },
  {
    "country": "RU",
    "name": "Mikhaylov",
    "lat": "54.2298",
    "lng": "39.0269"
  },
  {
    "country": "RU",
    "name": "Mikhalkovo",
    "lat": "55.68333",
    "lng": "37.43333"
  },
  {
    "country": "RU",
    "name": "Michurinskoye",
    "lat": "60.5642",
    "lng": "29.86232"
  },
  {
    "country": "RU",
    "name": "Michurinsk",
    "lat": "52.8978",
    "lng": "40.4907"
  },
  {
    "country": "RU",
    "name": "Miatli",
    "lat": "43.08173",
    "lng": "46.8286"
  },
  {
    "country": "RU",
    "name": "Mglin",
    "lat": "53.05907",
    "lng": "32.84753"
  },
  {
    "country": "RU",
    "name": "Mga",
    "lat": "59.75",
    "lng": "31.06667"
  },
  {
    "country": "RU",
    "name": "Mezinovskiy",
    "lat": "55.5042",
    "lng": "40.35932"
  },
  {
    "country": "RU",
    "name": "Mezhevoy",
    "lat": "55.17111",
    "lng": "58.78139"
  },
  {
    "country": "RU",
    "name": "Mezhdurechensk",
    "lat": "63.24556",
    "lng": "48.55333"
  },
  {
    "country": "RU",
    "name": "Mezhdurechensk",
    "lat": "53.2665",
    "lng": "49.1116"
  },
  {
    "country": "RU",
    "name": "Mezen’",
    "lat": "65.8401",
    "lng": "44.2542"
  },
  {
    "country": "RU",
    "name": "Metallostroy",
    "lat": "59.80083",
    "lng": "30.54778"
  },
  {
    "country": "RU",
    "name": "Mesyagutovo",
    "lat": "55.53028",
    "lng": "58.25278"
  },
  {
    "country": "RU",
    "name": "Mesker-Yurt",
    "lat": "43.25147",
    "lng": "45.90716"
  },
  {
    "country": "RU",
    "name": "Meshchovsk",
    "lat": "54.32444",
    "lng": "35.28083"
  },
  {
    "country": "RU",
    "name": "Meshcherino",
    "lat": "55.19567",
    "lng": "38.36002"
  },
  {
    "country": "RU",
    "name": "Menzelinsk",
    "lat": "55.72706",
    "lng": "53.10258"
  },
  {
    "country": "RU",
    "name": "Mendeleyevskiy",
    "lat": "54.13745",
    "lng": "37.58742"
  },
  {
    "country": "RU",
    "name": "Mendeleyevsk",
    "lat": "55.90819",
    "lng": "52.29047"
  },
  {
    "country": "RU",
    "name": "Mendeleyevo",
    "lat": "58.16976",
    "lng": "54.99634"
  },
  {
    "country": "RU",
    "name": "Mendeleyevo",
    "lat": "56.03333",
    "lng": "37.21667"
  },
  {
    "country": "RU",
    "name": "Melikhovo",
    "lat": "55.1144",
    "lng": "37.64827"
  },
  {
    "country": "RU",
    "name": "Meleuz",
    "lat": "52.96467",
    "lng": "55.93277"
  },
  {
    "country": "RU",
    "name": "Melenki",
    "lat": "55.3343",
    "lng": "41.6295"
  },
  {
    "country": "RU",
    "name": "Melikhovskaya",
    "lat": "47.48106",
    "lng": "40.48669"
  },
  {
    "country": "RU",
    "name": "Melekhovo",
    "lat": "56.2773",
    "lng": "41.29346"
  },
  {
    "country": "RU",
    "name": "Medyn’",
    "lat": "54.96917",
    "lng": "35.85861"
  },
  {
    "country": "RU",
    "name": "Medvezh’yegorsk",
    "lat": "62.91713",
    "lng": "34.45689"
  },
  {
    "country": "RU",
    "name": "Medvezh’i Ozëra",
    "lat": "55.86935",
    "lng": "37.98613"
  },
  {
    "country": "RU",
    "name": "Medvedovskaya",
    "lat": "45.45151",
    "lng": "39.02485"
  },
  {
    "country": "RU",
    "name": "Medvedok",
    "lat": "57.38913",
    "lng": "50.0351"
  },
  {
    "country": "RU",
    "name": "Medveditskiy",
    "lat": "50.78521",
    "lng": "44.71287"
  },
  {
    "country": "RU",
    "name": "Medvedevo",
    "lat": "56.63388",
    "lng": "47.80405"
  },
  {
    "country": "RU",
    "name": "Mednogorsk",
    "lat": "51.4128",
    "lng": "57.595"
  },
  {
    "country": "RU",
    "name": "Mechetinskaya",
    "lat": "46.7713",
    "lng": "40.45597"
  },
  {
    "country": "RU",
    "name": "Mayskoye",
    "lat": "52.27244",
    "lng": "50.03383"
  },
  {
    "country": "RU",
    "name": "Mayskiy",
    "lat": "53.96216",
    "lng": "38.21165"
  },
  {
    "country": "RU",
    "name": "Mayskiy",
    "lat": "50.51988",
    "lng": "36.45878"
  },
  {
    "country": "RU",
    "name": "Mayskiy",
    "lat": "47.696",
    "lng": "40.10259"
  },
  {
    "country": "RU",
    "name": "Mayskiy",
    "lat": "43.6414",
    "lng": "44.03851"
  },
  {
    "country": "RU",
    "name": "Mayrtup",
    "lat": "43.20348",
    "lng": "46.13215"
  },
  {
    "country": "RU",
    "name": "Mayna",
    "lat": "54.1135",
    "lng": "47.6231"
  },
  {
    "country": "RU",
    "name": "Maykor",
    "lat": "59.0047",
    "lng": "55.8784"
  },
  {
    "country": "RU",
    "name": "Maykopskoye",
    "lat": "45.39361",
    "lng": "40.76583"
  },
  {
    "country": "RU",
    "name": "Maykop",
    "lat": "44.60778",
    "lng": "40.10583"
  },
  {
    "country": "RU",
    "name": "Mayachnyy",
    "lat": "52.6839",
    "lng": "55.685"
  },
  {
    "country": "RU",
    "name": "Matyushkino",
    "lat": "56.86325",
    "lng": "28.62508"
  },
  {
    "country": "RU",
    "name": "Matveyevskoye",
    "lat": "55.71112",
    "lng": "37.47502"
  },
  {
    "country": "RU",
    "name": "Matveyev Kurgan",
    "lat": "47.5645",
    "lng": "38.86947"
  },
  {
    "country": "RU",
    "name": "Matveyevka",
    "lat": "52.15",
    "lng": "56.18333"
  },
  {
    "country": "RU",
    "name": "Matrosy",
    "lat": "61.78042",
    "lng": "33.81283"
  },
  {
    "country": "RU",
    "name": "Maslovka",
    "lat": "51.55346",
    "lng": "39.23573"
  },
  {
    "country": "RU",
    "name": "Maslova Pristan’",
    "lat": "50.45874",
    "lng": "36.74081"
  },
  {
    "country": "RU",
    "name": "Maromitsa",
    "lat": "59.86828",
    "lng": "48.01227"
  },
  {
    "country": "RU",
    "name": "Marks",
    "lat": "51.71111",
    "lng": "46.74861"
  },
  {
    "country": "RU",
    "name": "Markovo",
    "lat": "57.0185",
    "lng": "40.49465"
  },
  {
    "country": "RU",
    "name": "Mari-Turek",
    "lat": "56.78946",
    "lng": "49.62349"
  },
  {
    "country": "RU",
    "name": "Mar’ino",
    "lat": "55.65",
    "lng": "37.71667"
  },
  {
    "country": "RU",
    "name": "Mariinskiy Posad",
    "lat": "56.11497",
    "lng": "47.71805"
  },
  {
    "country": "RU",
    "name": "Marfino",
    "lat": "56.07237",
    "lng": "37.55899"
  },
  {
    "country": "RU",
    "name": "Marfino",
    "lat": "55.70267",
    "lng": "37.38322"
  },
  {
    "country": "RU",
    "name": "Marfino",
    "lat": "46.40852",
    "lng": "48.71398"
  },
  {
    "country": "RU",
    "name": "Marevo",
    "lat": "57.31461",
    "lng": "32.08045"
  },
  {
    "country": "RU",
    "name": "Manturovo",
    "lat": "58.32889",
    "lng": "44.76406"
  },
  {
    "country": "RU",
    "name": "Manturovo",
    "lat": "51.4547",
    "lng": "37.1282"
  },
  {
    "country": "RU",
    "name": "Manaskent",
    "lat": "42.7402",
    "lng": "47.6914"
  },
  {
    "country": "RU",
    "name": "Manas",
    "lat": "42.72749",
    "lng": "47.67846"
  },
  {
    "country": "RU",
    "name": "Mamontovka",
    "lat": "55.98083",
    "lng": "37.81972"
  },
  {
    "country": "RU",
    "name": "Mamedkala",
    "lat": "42.16773",
    "lng": "48.11988"
  },
  {
    "country": "RU",
    "name": "Mamadysh",
    "lat": "55.71525",
    "lng": "51.40797"
  },
  {
    "country": "RU",
    "name": "Yaroslavskiy",
    "lat": "55.88333",
    "lng": "37.71667"
  },
  {
    "country": "RU",
    "name": "Malyye Derbety",
    "lat": "47.95472",
    "lng": "44.68083"
  },
  {
    "country": "RU",
    "name": "Malyshevo",
    "lat": "55.4945",
    "lng": "38.35356"
  },
  {
    "country": "RU",
    "name": "Maloye Verevo",
    "lat": "59.61361",
    "lng": "30.17278"
  },
  {
    "country": "RU",
    "name": "Maloyaroslavets",
    "lat": "55.01457",
    "lng": "36.47185"
  },
  {
    "country": "RU",
    "name": "Maloarkhangel’sk",
    "lat": "52.40024",
    "lng": "36.50332"
  },
  {
    "country": "RU",
    "name": "Malmyzh",
    "lat": "56.5205",
    "lng": "50.6818"
  },
  {
    "country": "RU",
    "name": "Malka",
    "lat": "43.80389",
    "lng": "43.32417"
  },
  {
    "country": "RU",
    "name": "Malino",
    "lat": "55.11195",
    "lng": "38.17384"
  },
  {
    "country": "RU",
    "name": "Malgobek",
    "lat": "43.51118",
    "lng": "44.58821"
  },
  {
    "country": "RU",
    "name": "Malaya Vishera",
    "lat": "58.84538",
    "lng": "32.22218"
  },
  {
    "country": "RU",
    "name": "Malaya Serdoba",
    "lat": "52.4661",
    "lng": "44.9512"
  },
  {
    "country": "RU",
    "name": "Malaya Purga",
    "lat": "56.55666",
    "lng": "53.00434"
  },
  {
    "country": "RU",
    "name": "Malaya Dubna",
    "lat": "55.87783",
    "lng": "38.95423"
  },
  {
    "country": "RU",
    "name": "Malakhovka",
    "lat": "55.64776",
    "lng": "38.02486"
  },
  {
    "country": "RU",
    "name": "Makushino",
    "lat": "56.68802",
    "lng": "28.47207"
  },
  {
    "country": "RU",
    "name": "Maksatikha",
    "lat": "57.79695",
    "lng": "35.88254"
  },
  {
    "country": "RU",
    "name": "Makhalino",
    "lat": "53.08543",
    "lng": "46.22108"
  },
  {
    "country": "RU",
    "name": "Makhachkala",
    "lat": "42.97638",
    "lng": "47.50236"
  },
  {
    "country": "RU",
    "name": "Makar’yev",
    "lat": "57.88501",
    "lng": "43.8049"
  },
  {
    "country": "RU",
    "name": "Magnitogorsk",
    "lat": "53.41861",
    "lng": "59.04722"
  },
  {
    "country": "RU",
    "name": "Magnitka",
    "lat": "55.3475",
    "lng": "59.69611"
  },
  {
    "country": "RU",
    "name": "Maginsk",
    "lat": "55.76338",
    "lng": "56.96583"
  },
  {
    "country": "RU",
    "name": "Magaramkent",
    "lat": "41.61586",
    "lng": "48.34797"
  },
  {
    "country": "RU",
    "name": "Madzhalis",
    "lat": "42.12167",
    "lng": "47.83333"
  },
  {
    "country": "RU",
    "name": "Lyudinovo",
    "lat": "53.86639",
    "lng": "34.44778"
  },
  {
    "country": "RU",
    "name": "Lyubytino",
    "lat": "58.81222",
    "lng": "33.39222"
  },
  {
    "country": "RU",
    "name": "Lyubuchany",
    "lat": "55.25088",
    "lng": "37.54988"
  },
  {
    "country": "RU",
    "name": "Lyubovsho",
    "lat": "52.9851",
    "lng": "31.5422"
  },
  {
    "country": "RU",
    "name": "Lyubokhna",
    "lat": "53.50332",
    "lng": "34.38847"
  },
  {
    "country": "RU",
    "name": "Lyublino",
    "lat": "55.67738",
    "lng": "37.76005"
  },
  {
    "country": "RU",
    "name": "Lyubim",
    "lat": "58.3625",
    "lng": "40.68433"
  },
  {
    "country": "RU",
    "name": "Lyubertsy",
    "lat": "55.67719",
    "lng": "37.89322"
  },
  {
    "country": "RU",
    "name": "Lyuban’",
    "lat": "59.35",
    "lng": "31.21667"
  },
  {
    "country": "RU",
    "name": "Lytkarino",
    "lat": "55.58271",
    "lng": "37.90516"
  },
  {
    "country": "RU",
    "name": "Lysyye Gory",
    "lat": "51.55063",
    "lng": "44.84144"
  },
  {
    "country": "RU",
    "name": "Lys’va",
    "lat": "58.10861",
    "lng": "57.80528"
  },
  {
    "country": "RU",
    "name": "Lysogorskaya",
    "lat": "44.10639",
    "lng": "43.27556"
  },
  {
    "country": "RU",
    "name": "Lyskovo",
    "lat": "56.03282",
    "lng": "45.0422"
  },
  {
    "country": "RU",
    "name": "Lyaskelya",
    "lat": "61.76322",
    "lng": "31.00616"
  },
  {
    "country": "RU",
    "name": "Lyangasovo",
    "lat": "58.51759",
    "lng": "49.44718"
  },
  {
    "country": "RU",
    "name": "Lyamino",
    "lat": "58.2839",
    "lng": "57.725"
  },
  {
    "country": "RU",
    "name": "Lyambir’",
    "lat": "54.28172",
    "lng": "45.12494"
  },
  {
    "country": "RU",
    "name": "L’vovskiy",
    "lat": "55.31872",
    "lng": "37.52337"
  },
  {
    "country": "RU",
    "name": "Luzhniki",
    "lat": "55.71599",
    "lng": "37.55376"
  },
  {
    "country": "RU",
    "name": "Luza",
    "lat": "60.63081",
    "lng": "47.25118"
  },
  {
    "country": "RU",
    "name": "Luppolovo",
    "lat": "60.15402",
    "lng": "30.28034"
  },
  {
    "country": "RU",
    "name": "Lunino",
    "lat": "53.59176",
    "lng": "45.22709"
  },
  {
    "country": "RU",
    "name": "Lukoyanov",
    "lat": "55.02772",
    "lng": "44.47865"
  },
  {
    "country": "RU",
    "name": "Lukovetskiy",
    "lat": "64.2956",
    "lng": "41.9211"
  },
  {
    "country": "RU",
    "name": "Luknovo",
    "lat": "56.18045",
    "lng": "42.03987"
  },
  {
    "country": "RU",
    "name": "Lukino",
    "lat": "56.85933",
    "lng": "28.46426"
  },
  {
    "country": "RU",
    "name": "Lukino",
    "lat": "56.44183",
    "lng": "43.62932"
  },
  {
    "country": "RU",
    "name": "Lukhovka",
    "lat": "54.14844",
    "lng": "45.25728"
  },
  {
    "country": "RU",
    "name": "Lukhovitsy",
    "lat": "54.97661",
    "lng": "39.0444"
  },
  {
    "country": "RU",
    "name": "Lukh",
    "lat": "57.01242",
    "lng": "42.25838"
  },
  {
    "country": "RU",
    "name": "Lugovaya",
    "lat": "56.05",
    "lng": "37.48333"
  },
  {
    "country": "RU",
    "name": "Luga",
    "lat": "58.73722",
    "lng": "29.84528"
  },
  {
    "country": "RU",
    "name": "Lubyany",
    "lat": "56.0378",
    "lng": "51.40001"
  },
  {
    "country": "RU",
    "name": "Lozhki",
    "lat": "56.09387",
    "lng": "37.10873"
  },
  {
    "country": "RU",
    "name": "Loyga",
    "lat": "61.07845",
    "lng": "44.6075"
  },
  {
    "country": "RU",
    "name": "Lovozero",
    "lat": "68.00638",
    "lng": "35.01589"
  },
  {
    "country": "RU",
    "name": "Lovlinskaya",
    "lat": "45.51611",
    "lng": "40.24"
  },
  {
    "country": "RU",
    "name": "Loukhi",
    "lat": "66.07616",
    "lng": "33.04745"
  },
  {
    "country": "RU",
    "name": "Lotoshino",
    "lat": "56.23489",
    "lng": "35.64273"
  },
  {
    "country": "RU",
    "name": "Losino-Petrovskiy",
    "lat": "55.86959",
    "lng": "38.20065"
  },
  {
    "country": "RU",
    "name": "Losevo",
    "lat": "50.67667",
    "lng": "40.045"
  },
  {
    "country": "RU",
    "name": "Lopatinskiy",
    "lat": "55.34101",
    "lng": "38.72366"
  },
  {
    "country": "RU",
    "name": "Lopatino",
    "lat": "52.61949",
    "lng": "45.81184"
  },
  {
    "country": "RU",
    "name": "Lopandino",
    "lat": "52.4666",
    "lng": "34.8163"
  },
  {
    "country": "RU",
    "name": "Lomovka",
    "lat": "53.91944",
    "lng": "58.36722"
  },
  {
    "country": "RU",
    "name": "Lomonosov",
    "lat": "59.90612",
    "lng": "29.77253"
  },
  {
    "country": "RU",
    "name": "Lomintsevskiy",
    "lat": "53.98548",
    "lng": "37.66471"
  },
  {
    "country": "RU",
    "name": "Lokot’",
    "lat": "52.565",
    "lng": "34.5776"
  },
  {
    "country": "RU",
    "name": "Loknya",
    "lat": "56.82998",
    "lng": "30.14665"
  },
  {
    "country": "RU",
    "name": "Log",
    "lat": "49.48437",
    "lng": "43.86125"
  },
  {
    "country": "RU",
    "name": "Lodeynoye Pole",
    "lat": "60.726",
    "lng": "33.55306"
  },
  {
    "country": "RU",
    "name": "Lobnya",
    "lat": "56.00972",
    "lng": "37.48194"
  },
  {
    "country": "RU",
    "name": "Lobanovo",
    "lat": "57.8595",
    "lng": "56.3026"
  },
  {
    "country": "RU",
    "name": "Livny",
    "lat": "52.42534",
    "lng": "37.60689"
  },
  {
    "country": "RU",
    "name": "Livenka",
    "lat": "50.4491",
    "lng": "38.2959"
  },
  {
    "country": "RU",
    "name": "Liski",
    "lat": "50.98405",
    "lng": "39.51545"
  },
  {
    "country": "RU",
    "name": "Lisiy Nos",
    "lat": "60.01686",
    "lng": "30.02008"
  },
  {
    "country": "RU",
    "name": "Lipin Bor",
    "lat": "60.263",
    "lng": "37.9785"
  },
  {
    "country": "RU",
    "name": "Lipetsk",
    "lat": "52.60311",
    "lng": "39.57076"
  },
  {
    "country": "RU",
    "name": "Linda",
    "lat": "56.61571",
    "lng": "44.09544"
  },
  {
    "country": "RU",
    "name": "Liman",
    "lat": "45.78457",
    "lng": "47.22405"
  },
  {
    "country": "RU",
    "name": "Likino-Dulevo",
    "lat": "55.7083",
    "lng": "38.9542"
  },
  {
    "country": "RU",
    "name": "Likhoy",
    "lat": "48.12662",
    "lng": "40.20556"
  },
  {
    "country": "RU",
    "name": "Likhovskoy",
    "lat": "48.15188",
    "lng": "40.17925"
  },
  {
    "country": "RU",
    "name": "Likhoslavl’",
    "lat": "57.12747",
    "lng": "35.46404"
  },
  {
    "country": "RU",
    "name": "Likhobory",
    "lat": "55.85",
    "lng": "37.56667"
  },
  {
    "country": "RU",
    "name": "Lianozovo",
    "lat": "55.89783",
    "lng": "37.5868"
  },
  {
    "country": "RU",
    "name": "L’govskiy",
    "lat": "51.63069",
    "lng": "35.2775"
  },
  {
    "country": "RU",
    "name": "Lezhnevo",
    "lat": "56.77508",
    "lng": "40.89174"
  },
  {
    "country": "RU",
    "name": "Lev Tolstoy",
    "lat": "53.21344",
    "lng": "39.44604"
  },
  {
    "country": "RU",
    "name": "Levokumskoye",
    "lat": "44.82194",
    "lng": "44.66056"
  },
  {
    "country": "RU",
    "name": "Levokumka",
    "lat": "44.23167",
    "lng": "43.15"
  },
  {
    "country": "RU",
    "name": "Levikha",
    "lat": "57.58361",
    "lng": "59.90028"
  },
  {
    "country": "RU",
    "name": "Levashevo",
    "lat": "57.64451",
    "lng": "40.52401"
  },
  {
    "country": "RU",
    "name": "Levashi",
    "lat": "42.43036",
    "lng": "47.32148"
  },
  {
    "country": "RU",
    "name": "Levashovo",
    "lat": "60.10369",
    "lng": "30.20683"
  },
  {
    "country": "RU",
    "name": "Letnyaya Stavka",
    "lat": "45.43056",
    "lng": "43.44722"
  },
  {
    "country": "RU",
    "name": "Letnik",
    "lat": "46.011",
    "lng": "41.2657"
  },
  {
    "country": "RU",
    "name": "Letka",
    "lat": "59.60111",
    "lng": "49.42321"
  },
  {
    "country": "RU",
    "name": "Lesogorskiy",
    "lat": "61.04549",
    "lng": "28.92938"
  },
  {
    "country": "RU",
    "name": "Lesogorsk",
    "lat": "55.0979",
    "lng": "43.93552"
  },
  {
    "country": "RU",
    "name": "Lesnyye Polyany",
    "lat": "59.00314",
    "lng": "52.41802"
  },
  {
    "country": "RU",
    "name": "Lesnyye Polyany",
    "lat": "55.96667",
    "lng": "37.86667"
  },
  {
    "country": "RU",
    "name": "Lesnoy Gorodok",
    "lat": "55.63893",
    "lng": "37.20829"
  },
  {
    "country": "RU",
    "name": "Lesnoye",
    "lat": "58.28406",
    "lng": "35.51584"
  },
  {
    "country": "RU",
    "name": "Komendantsky aerodrom",
    "lat": "60.00448",
    "lng": "30.27523"
  },
  {
    "country": "RU",
    "name": "Lesnoy",
    "lat": "59.781",
    "lng": "52.12838"
  },
  {
    "country": "RU",
    "name": "Lesnoy",
    "lat": "56.06667",
    "lng": "37.91667"
  },
  {
    "country": "RU",
    "name": "Lesnoy",
    "lat": "54.2125",
    "lng": "40.4713"
  },
  {
    "country": "RU",
    "name": "Leskolovo",
    "lat": "60.26341",
    "lng": "30.45462"
  },
  {
    "country": "RU",
    "name": "Leshukonskoye",
    "lat": "64.8977",
    "lng": "45.7655"
  },
  {
    "country": "RU",
    "name": "Lermontovo",
    "lat": "52.99277",
    "lng": "43.66141"
  },
  {
    "country": "RU",
    "name": "Lermontov",
    "lat": "44.10667",
    "lng": "42.97333"
  },
  {
    "country": "RU",
    "name": "Leonovo",
    "lat": "55.85",
    "lng": "37.65"
  },
  {
    "country": "RU",
    "name": "Leninskoye",
    "lat": "60.22021",
    "lng": "29.84711"
  },
  {
    "country": "RU",
    "name": "Leninskoye",
    "lat": "58.31637",
    "lng": "47.08856"
  },
  {
    "country": "RU",
    "name": "Leninskiye Gory",
    "lat": "55.7",
    "lng": "37.56667"
  },
  {
    "country": "RU",
    "name": "Leninskiy",
    "lat": "54.28768",
    "lng": "37.45926"
  },
  {
    "country": "RU",
    "name": "Leninsk",
    "lat": "54.90306",
    "lng": "59.8675"
  },
  {
    "country": "RU",
    "name": "Leninsk",
    "lat": "48.70233",
    "lng": "45.19798"
  },
  {
    "country": "RU",
    "name": "Leninogorsk",
    "lat": "54.60256",
    "lng": "52.46087"
  },
  {
    "country": "RU",
    "name": "Tsaritsyno",
    "lat": "55.6254",
    "lng": "37.65032"
  },
  {
    "country": "RU",
    "name": "Leninkent",
    "lat": "42.96895",
    "lng": "47.35202"
  },
  {
    "country": "RU",
    "name": "Leningradskaya",
    "lat": "46.3214",
    "lng": "39.3877"
  },
  {
    "country": "RU",
    "name": "Yubileyny",
    "lat": "55.93333",
    "lng": "37.83333"
  },
  {
    "country": "RU",
    "name": "Leninaul",
    "lat": "43.09138",
    "lng": "46.57434"
  },
  {
    "country": "RU",
    "name": "Lenina",
    "lat": "46.06667",
    "lng": "39.78333"
  },
  {
    "country": "RU",
    "name": "Lefortovo",
    "lat": "55.76667",
    "lng": "37.7"
  },
  {
    "country": "RU",
    "name": "Ledmozero",
    "lat": "64.25444",
    "lng": "32.02789"
  },
  {
    "country": "RU",
    "name": "Lechinkay",
    "lat": "43.56472",
    "lng": "43.43278"
  },
  {
    "country": "RU",
    "name": "Lebyazh’ye",
    "lat": "59.96124",
    "lng": "29.41487"
  },
  {
    "country": "RU",
    "name": "Lebedyan’",
    "lat": "53.01942",
    "lng": "39.16639"
  },
  {
    "country": "RU",
    "name": "Lazarevskoye",
    "lat": "43.90886",
    "lng": "39.33137"
  },
  {
    "country": "RU",
    "name": "Latnaya",
    "lat": "51.6586",
    "lng": "38.9011"
  },
  {
    "country": "RU",
    "name": "Lashma",
    "lat": "54.9321",
    "lng": "41.14379"
  },
  {
    "country": "RU",
    "name": "Laptëvo",
    "lat": "56.7426",
    "lng": "28.83444"
  },
  {
    "country": "RU",
    "name": "Lal’sk",
    "lat": "60.74146",
    "lng": "47.58617"
  },
  {
    "country": "RU",
    "name": "Lakinsk",
    "lat": "56.01931",
    "lng": "39.94848"
  },
  {
    "country": "RU",
    "name": "Lakhtinskiy",
    "lat": "59.99521",
    "lng": "30.14717"
  },
  {
    "country": "RU",
    "name": "Lakhdenpokh’ya",
    "lat": "61.51981",
    "lng": "30.19917"
  },
  {
    "country": "RU",
    "name": "Laishevo",
    "lat": "55.40464",
    "lng": "49.55037"
  },
  {
    "country": "RU",
    "name": "Ladushkin",
    "lat": "54.57025",
    "lng": "20.17099"
  },
  {
    "country": "RU",
    "name": "Ladozhskaya",
    "lat": "45.30902",
    "lng": "39.93803"
  },
  {
    "country": "RU",
    "name": "Ladovskaya Balka",
    "lat": "45.62965",
    "lng": "41.40231"
  },
  {
    "country": "RU",
    "name": "Labinsk",
    "lat": "44.63417",
    "lng": "40.73556"
  },
  {
    "country": "RU",
    "name": "Kyzyl-Oktyabr’skiy",
    "lat": "43.8257",
    "lng": "41.78605"
  },
  {
    "country": "RU",
    "name": "Islamey",
    "lat": "43.67556",
    "lng": "43.455"
  },
  {
    "country": "RU",
    "name": "Dugulubgey",
    "lat": "43.6625",
    "lng": "43.53694"
  },
  {
    "country": "RU",
    "name": "Kyzburun Pervyy",
    "lat": "43.65167",
    "lng": "43.395"
  },
  {
    "country": "RU",
    "name": "Kyakhulay",
    "lat": "42.96839",
    "lng": "47.48301"
  },
  {
    "country": "RU",
    "name": "Kvarkeno",
    "lat": "52.08333",
    "lng": "59.725"
  },
  {
    "country": "RU",
    "name": "Kuzovatovo",
    "lat": "53.54681",
    "lng": "47.68659"
  },
  {
    "country": "RU",
    "name": "Kuznetsk",
    "lat": "53.11675",
    "lng": "46.60037"
  },
  {
    "country": "RU",
    "name": "Kuznechnoye",
    "lat": "61.1153",
    "lng": "29.87535"
  },
  {
    "country": "RU",
    "name": "Kuznechikha",
    "lat": "57.21607",
    "lng": "42.33477"
  },
  {
    "country": "RU",
    "name": "Kuz’minskiye Otverzhki",
    "lat": "52.69574",
    "lng": "39.47036"
  },
  {
    "country": "RU",
    "name": "Kuz’minki",
    "lat": "55.7",
    "lng": "37.8"
  },
  {
    "country": "RU",
    "name": "Kuzino",
    "lat": "59.77665",
    "lng": "38.3104"
  },
  {
    "country": "RU",
    "name": "Kuzino",
    "lat": "57.0224",
    "lng": "59.4412"
  },
  {
    "country": "RU",
    "name": "Kuzhorskaya",
    "lat": "44.67512",
    "lng": "40.31032"
  },
  {
    "country": "RU",
    "name": "Kuzhenkino",
    "lat": "57.76111",
    "lng": "33.95083"
  },
  {
    "country": "RU",
    "name": "Kuzhener",
    "lat": "56.81111",
    "lng": "48.91278"
  },
  {
    "country": "RU",
    "name": "Kuyvozi",
    "lat": "60.31931",
    "lng": "30.43631"
  },
  {
    "country": "RU",
    "name": "Kuyeda",
    "lat": "56.4311",
    "lng": "55.58861"
  },
  {
    "country": "RU",
    "name": "Kuybyshevskiy Zaton",
    "lat": "55.1593",
    "lng": "49.1701"
  },
  {
    "country": "RU",
    "name": "Kuybyshevo",
    "lat": "47.81228",
    "lng": "38.90731"
  },
  {
    "country": "RU",
    "name": "Kuvshinovo",
    "lat": "57.02953",
    "lng": "34.17252"
  },
  {
    "country": "RU",
    "name": "Kuvandyk",
    "lat": "51.4781",
    "lng": "57.3552"
  },
  {
    "country": "RU",
    "name": "Kuskovo",
    "lat": "55.73423",
    "lng": "37.82616"
  },
  {
    "country": "RU",
    "name": "Kushva",
    "lat": "58.29056",
    "lng": "59.75917"
  },
  {
    "country": "RU",
    "name": "Kushnarënkovo",
    "lat": "55.105",
    "lng": "55.35083"
  },
  {
    "country": "RU",
    "name": "Kushelevka",
    "lat": "59.99333",
    "lng": "30.36389"
  },
  {
    "country": "RU",
    "name": "Kushchëvskaya",
    "lat": "46.5599",
    "lng": "39.6321"
  },
  {
    "country": "RU",
    "name": "Kusa",
    "lat": "55.33833",
    "lng": "59.44056"
  },
  {
    "country": "RU",
    "name": "Kur’yanovo",
    "lat": "55.65",
    "lng": "37.7"
  },
  {
    "country": "RU",
    "name": "Kurush",
    "lat": "41.28413",
    "lng": "47.83454"
  },
  {
    "country": "RU",
    "name": "Kurumoch",
    "lat": "53.48963",
    "lng": "50.03748"
  },
  {
    "country": "RU",
    "name": "Kurskaya",
    "lat": "44.05",
    "lng": "44.45"
  },
  {
    "country": "RU",
    "name": "Kursk",
    "lat": "51.73733",
    "lng": "36.18735"
  },
  {
    "country": "RU",
    "name": "Kursavka",
    "lat": "44.4564",
    "lng": "42.5093"
  },
  {
    "country": "RU",
    "name": "Kurovskoye",
    "lat": "55.58183",
    "lng": "38.91994"
  },
  {
    "country": "RU",
    "name": "Kurmanayevka",
    "lat": "52.5093",
    "lng": "52.0675"
  },
  {
    "country": "RU",
    "name": "Kurlovo",
    "lat": "55.43252",
    "lng": "40.48539"
  },
  {
    "country": "RU",
    "name": "Nizhniy Kurkuzhin",
    "lat": "43.74833",
    "lng": "43.34972"
  },
  {
    "country": "RU",
    "name": "Kurkino",
    "lat": "53.42567",
    "lng": "38.65824"
  },
  {
    "country": "RU",
    "name": "Kurkent",
    "lat": "41.71199",
    "lng": "48.11531"
  },
  {
    "country": "RU",
    "name": "Kurganinsk",
    "lat": "44.88",
    "lng": "40.59861"
  },
  {
    "country": "RU",
    "name": "Kurdzhinovo",
    "lat": "43.98838",
    "lng": "40.95519"
  },
  {
    "country": "RU",
    "name": "Kurchatov",
    "lat": "51.6601",
    "lng": "35.6521"
  },
  {
    "country": "RU",
    "name": "Kurchaloy",
    "lat": "43.20184",
    "lng": "46.0881"
  },
  {
    "country": "RU",
    "name": "Kurba",
    "lat": "57.56097",
    "lng": "39.4981"
  },
  {
    "country": "RU",
    "name": "Kurakh",
    "lat": "41.58491",
    "lng": "47.78306"
  },
  {
    "country": "RU",
    "name": "Kupchino",
    "lat": "59.85278",
    "lng": "30.35667"
  },
  {
    "country": "RU",
    "name": "Kupavna",
    "lat": "55.74576",
    "lng": "38.13136"
  },
  {
    "country": "RU",
    "name": "Kungur",
    "lat": "57.4368",
    "lng": "56.9593"
  },
  {
    "country": "RU",
    "name": "Kumysh",
    "lat": "43.88334",
    "lng": "41.89323"
  },
  {
    "country": "RU",
    "name": "Kumylzhenskaya",
    "lat": "49.8809",
    "lng": "42.5898"
  },
  {
    "country": "RU",
    "name": "Kumukh",
    "lat": "42.17036",
    "lng": "47.11606"
  },
  {
    "country": "RU",
    "name": "Kumertau",
    "lat": "52.76667",
    "lng": "55.78333"
  },
  {
    "country": "RU",
    "name": "Kumëny",
    "lat": "58.10887",
    "lng": "49.91614"
  },
  {
    "country": "RU",
    "name": "Kultayevo",
    "lat": "57.8948",
    "lng": "55.9378"
  },
  {
    "country": "RU",
    "name": "Kuloy",
    "lat": "61.03049",
    "lng": "42.49252"
  },
  {
    "country": "RU",
    "name": "Kulotino",
    "lat": "58.45",
    "lng": "33.38333"
  },
  {
    "country": "RU",
    "name": "Kuli",
    "lat": "42.01845",
    "lng": "47.24342"
  },
  {
    "country": "RU",
    "name": "Kuleshovka",
    "lat": "47.07802",
    "lng": "39.55794"
  },
  {
    "country": "RU",
    "name": "Kulebaki",
    "lat": "55.41333",
    "lng": "42.5325"
  },
  {
    "country": "RU",
    "name": "Kulary",
    "lat": "43.23972",
    "lng": "45.50417"
  },
  {
    "country": "RU",
    "name": "Kukushtan",
    "lat": "57.6464",
    "lng": "56.4952"
  },
  {
    "country": "RU",
    "name": "Kukoboy",
    "lat": "58.70089",
    "lng": "39.91427"
  },
  {
    "country": "RU",
    "name": "Kukmor",
    "lat": "56.1855",
    "lng": "50.8944"
  },
  {
    "country": "RU",
    "name": "Kugesi",
    "lat": "56.02895",
    "lng": "47.29255"
  },
  {
    "country": "RU",
    "name": "Kudymkar",
    "lat": "59.01306",
    "lng": "54.65556"
  },
  {
    "country": "RU",
    "name": "Kudinovo",
    "lat": "54.99939",
    "lng": "36.25331"
  },
  {
    "country": "RU",
    "name": "Kudeyevskiy",
    "lat": "54.87583",
    "lng": "56.75667"
  },
  {
    "country": "RU",
    "name": "Kudepsta",
    "lat": "43.49547",
    "lng": "39.89294"
  },
  {
    "country": "RU",
    "name": "Kuchugury",
    "lat": "45.40702",
    "lng": "36.95586"
  },
  {
    "country": "RU",
    "name": "Kubinka",
    "lat": "55.57957",
    "lng": "36.70392"
  },
  {
    "country": "RU",
    "name": "Kuba-Taba",
    "lat": "43.77611",
    "lng": "43.44278"
  },
  {
    "country": "RU",
    "name": "Kubanskiy",
    "lat": "45.92917",
    "lng": "40.58056"
  },
  {
    "country": "RU",
    "name": "Kubachi",
    "lat": "42.08598",
    "lng": "47.60338"
  },
  {
    "country": "RU",
    "name": "Kstovo",
    "lat": "56.14733",
    "lng": "44.19787"
  },
  {
    "country": "RU",
    "name": "Kshenskiy",
    "lat": "51.84083",
    "lng": "37.71361"
  },
  {
    "country": "RU",
    "name": "Krymsk",
    "lat": "44.92934",
    "lng": "37.99117"
  },
  {
    "country": "RU",
    "name": "Krym",
    "lat": "47.30025",
    "lng": "39.51637"
  },
  {
    "country": "RU",
    "name": "Krylovskaya",
    "lat": "46.31944",
    "lng": "39.97111"
  },
  {
    "country": "RU",
    "name": "Krylovskaya",
    "lat": "46.1097",
    "lng": "39.3035"
  },
  {
    "country": "RU",
    "name": "Kruglolesskoye",
    "lat": "44.65889",
    "lng": "42.81417"
  },
  {
    "country": "RU",
    "name": "Krotovka",
    "lat": "53.2858",
    "lng": "51.1686"
  },
  {
    "country": "RU",
    "name": "Kropotkin",
    "lat": "45.4375",
    "lng": "40.57556"
  },
  {
    "country": "RU",
    "name": "Kropachëvo",
    "lat": "55.0112",
    "lng": "57.9896"
  },
  {
    "country": "RU",
    "name": "Kronshtadt",
    "lat": "59.99541",
    "lng": "29.76668"
  },
  {
    "country": "RU",
    "name": "Kromy",
    "lat": "52.68762",
    "lng": "35.76665"
  },
  {
    "country": "RU",
    "name": "Krivyanskaya",
    "lat": "47.39689",
    "lng": "40.1668"
  },
  {
    "country": "RU",
    "name": "Krivtsovo",
    "lat": "56.15",
    "lng": "36.88333"
  },
  {
    "country": "RU",
    "name": "Kresty",
    "lat": "56.77595",
    "lng": "28.09083"
  },
  {
    "country": "RU",
    "name": "Kresttsy",
    "lat": "58.2452",
    "lng": "32.51647"
  },
  {
    "country": "RU",
    "name": "Kremenki",
    "lat": "54.88626",
    "lng": "37.11955"
  },
  {
    "country": "RU",
    "name": "Krechevitsy",
    "lat": "58.61703",
    "lng": "31.40101"
  },
  {
    "country": "RU",
    "name": "Kratovo",
    "lat": "55.59728",
    "lng": "38.17743"
  },
  {
    "country": "RU",
    "name": "Krasyukovskaya",
    "lat": "47.55222",
    "lng": "40.10885"
  },
  {
    "country": "RU",
    "name": "Krasnyy Yar",
    "lat": "53.49988",
    "lng": "50.39312"
  },
  {
    "country": "RU",
    "name": "Krasnyy Yar",
    "lat": "51.62917",
    "lng": "46.42167"
  },
  {
    "country": "RU",
    "name": "Krasnyy Yar",
    "lat": "50.69652",
    "lng": "44.72792"
  },
  {
    "country": "RU",
    "name": "Krasnyy Yar",
    "lat": "46.53314",
    "lng": "48.34559"
  },
  {
    "country": "RU",
    "name": "Krasnyy Tkach",
    "lat": "55.4721",
    "lng": "39.08017"
  },
  {
    "country": "RU",
    "name": "Krasnyy Sulin",
    "lat": "47.89221",
    "lng": "40.07037"
  },
  {
    "country": "RU",
    "name": "Biryulëvo Zapadnoye",
    "lat": "55.58766",
    "lng": "37.64282"
  },
  {
    "country": "RU",
    "name": "Krasnyy Profintern",
    "lat": "57.74459",
    "lng": "40.43501"
  },
  {
    "country": "RU",
    "name": "Krasnyy Oktyabr’",
    "lat": "56.11667",
    "lng": "38.88333"
  },
  {
    "country": "RU",
    "name": "Krasnyy Oktyabr’",
    "lat": "56.10347",
    "lng": "41.38395"
  },
  {
    "country": "RU",
    "name": "Krasnyy Oktyabr’",
    "lat": "51.54018",
    "lng": "45.70382"
  },
  {
    "country": "RU",
    "name": "Krasnyy Luch",
    "lat": "57.06676",
    "lng": "30.09032"
  },
  {
    "country": "RU",
    "name": "Krasnyy Kut",
    "lat": "50.95",
    "lng": "46.96667"
  },
  {
    "country": "RU",
    "name": "Krasnyy Kurgan",
    "lat": "43.94222",
    "lng": "42.61083"
  },
  {
    "country": "RU",
    "name": "Krasnyy Klyuch",
    "lat": "55.38625",
    "lng": "56.65287"
  },
  {
    "country": "RU",
    "name": "Krasnyy Kholm",
    "lat": "58.0607",
    "lng": "37.12032"
  },
  {
    "country": "RU",
    "name": "Krasnyy Gulyay",
    "lat": "54.02821",
    "lng": "48.33327"
  },
  {
    "country": "RU",
    "name": "Krasnyye Tkachi",
    "lat": "57.49259",
    "lng": "39.75629"
  },
  {
    "country": "RU",
    "name": "Krasnyye Chetai",
    "lat": "55.68871",
    "lng": "46.13865"
  },
  {
    "country": "RU",
    "name": "Krasnyye Barrikady",
    "lat": "46.2045",
    "lng": "47.8535"
  },
  {
    "country": "RU",
    "name": "Krasnyye Baki",
    "lat": "57.131",
    "lng": "45.15992"
  },
  {
    "country": "RU",
    "name": "Krasnyy Bor",
    "lat": "59.68194",
    "lng": "30.66806"
  },
  {
    "country": "RU",
    "name": "Krasnyy Bogatyr’",
    "lat": "56.01453",
    "lng": "41.12958"
  },
  {
    "country": "RU",
    "name": "Krasnoznamensk",
    "lat": "54.94222",
    "lng": "22.48972"
  },
  {
    "country": "RU",
    "name": "Krasnozavodsk",
    "lat": "56.45",
    "lng": "38.21667"
  },
  {
    "country": "RU",
    "name": "Krasnoye Selo",
    "lat": "59.73833",
    "lng": "30.08944"
  },
  {
    "country": "RU",
    "name": "Krasnoye-na-Volge",
    "lat": "57.51483",
    "lng": "41.239"
  },
  {
    "country": "RU",
    "name": "Krasnoye",
    "lat": "52.86449",
    "lng": "38.79353"
  },
  {
    "country": "RU",
    "name": "Krasnoye",
    "lat": "50.9297",
    "lng": "38.6817"
  },
  {
    "country": "RU",
    "name": "Krasnoye",
    "lat": "46.7373",
    "lng": "39.5645"
  },
  {
    "country": "RU",
    "name": "Krasnoyarskiy",
    "lat": "51.965",
    "lng": "59.89667"
  },
  {
    "country": "RU",
    "name": "Krasnoyarskaya",
    "lat": "47.6501",
    "lng": "42.0443"
  },
  {
    "country": "RU",
    "name": "Krasnovka",
    "lat": "48.81769",
    "lng": "40.09226"
  },
  {
    "country": "RU",
    "name": "Krasnovishersk",
    "lat": "60.40783",
    "lng": "57.08199"
  },
  {
    "country": "RU",
    "name": "Krasnoufimsk",
    "lat": "56.60585",
    "lng": "57.76686"
  },
  {
    "country": "RU",
    "name": "Krasnoslobodsk",
    "lat": "54.4253",
    "lng": "43.78963"
  },
  {
    "country": "RU",
    "name": "Krasnoslobodsk",
    "lat": "48.70708",
    "lng": "44.57702"
  },
  {
    "country": "RU",
    "name": "Golovinskiy",
    "lat": "55.85381",
    "lng": "37.49604"
  },
  {
    "country": "RU",
    "name": "Krasnomayskiy",
    "lat": "57.61941",
    "lng": "34.40987"
  },
  {
    "country": "RU",
    "name": "Krasnokumskoye",
    "lat": "44.17806",
    "lng": "43.50194"
  },
  {
    "country": "RU",
    "name": "Krasnokholm",
    "lat": "51.59787",
    "lng": "54.1567"
  },
  {
    "country": "RU",
    "name": "Krasnokamsk",
    "lat": "58.0796",
    "lng": "55.7552"
  },
  {
    "country": "RU",
    "name": "Krasnogvardeyskoye",
    "lat": "50.6492",
    "lng": "38.4036"
  },
  {
    "country": "RU",
    "name": "Krasnogvardeyskoye",
    "lat": "45.84604",
    "lng": "41.51885"
  },
  {
    "country": "RU",
    "name": "Krasnogvardeyskoye",
    "lat": "45.1278",
    "lng": "39.57246"
  },
  {
    "country": "RU",
    "name": "Krasnogvardeyets",
    "lat": "52.6804",
    "lng": "52.3635"
  },
  {
    "country": "RU",
    "name": "Krasnogorskoye",
    "lat": "57.7047",
    "lng": "52.4999"
  },
  {
    "country": "RU",
    "name": "Krasnogorskiy",
    "lat": "56.1525",
    "lng": "48.32583"
  },
  {
    "country": "RU",
    "name": "Krasnogorsk",
    "lat": "55.82036",
    "lng": "37.33017"
  },
  {
    "country": "RU",
    "name": "Krasnogorodsk",
    "lat": "56.83568",
    "lng": "28.28224"
  },
  {
    "country": "RU",
    "name": "Krasnofarfornyy",
    "lat": "59.1364",
    "lng": "31.85023"
  },
  {
    "country": "RU",
    "name": "Krasnodar",
    "lat": "45.04484",
    "lng": "38.97603"
  },
  {
    "country": "RU",
    "name": "Krasnoborsk",
    "lat": "61.55978",
    "lng": "45.93396"
  },
  {
    "country": "RU",
    "name": "Krasnoarmeyskoye",
    "lat": "55.76813",
    "lng": "47.17244"
  },
  {
    "country": "RU",
    "name": "Krasnoarmeyskoye",
    "lat": "52.71994",
    "lng": "50.03122"
  },
  {
    "country": "RU",
    "name": "Krasnoarmeyskiy",
    "lat": "47.0114",
    "lng": "42.2072"
  },
  {
    "country": "RU",
    "name": "Krasnoarmeyskaya",
    "lat": "45.36614",
    "lng": "38.21171"
  },
  {
    "country": "RU",
    "name": "Krasnoarmeysk",
    "lat": "56.1",
    "lng": "38.13333"
  },
  {
    "country": "RU",
    "name": "Krasnoarmeysk",
    "lat": "51.02389",
    "lng": "45.69694"
  },
  {
    "country": "RU",
    "name": "Krasnaya Zarya",
    "lat": "52.7825",
    "lng": "37.68056"
  },
  {
    "country": "RU",
    "name": "Krasnaya Yaruga",
    "lat": "50.80083",
    "lng": "35.65833"
  },
  {
    "country": "RU",
    "name": "Presnenskiy",
    "lat": "55.75",
    "lng": "37.55"
  },
  {
    "country": "RU",
    "name": "Krasnaya Poyma",
    "lat": "55.00138",
    "lng": "39.07997"
  },
  {
    "country": "RU",
    "name": "Krasnaya Polyana",
    "lat": "56.24204",
    "lng": "51.14425"
  },
  {
    "country": "RU",
    "name": "Krasnaya Polyana",
    "lat": "46.11293",
    "lng": "41.50157"
  },
  {
    "country": "RU",
    "name": "Krasnaya Polyana",
    "lat": "45.0548",
    "lng": "41.1031"
  },
  {
    "country": "RU",
    "name": "Krasnaya Polyana",
    "lat": "43.67952",
    "lng": "40.20403"
  },
  {
    "country": "RU",
    "name": "Krasnaya Gorka",
    "lat": "55.38666",
    "lng": "46.10925"
  },
  {
    "country": "RU",
    "name": "Krasnaya Gorka",
    "lat": "55.19617",
    "lng": "56.66727"
  },
  {
    "country": "RU",
    "name": "Krasnaya Gorbatka",
    "lat": "55.8703",
    "lng": "41.7641"
  },
  {
    "country": "RU",
    "name": "Krasnaya Gora",
    "lat": "52.9995",
    "lng": "31.6023"
  },
  {
    "country": "RU",
    "name": "Kraskovo",
    "lat": "55.64972",
    "lng": "37.98778"
  },
  {
    "country": "RU",
    "name": "Krasavino",
    "lat": "60.96225",
    "lng": "46.48321"
  },
  {
    "country": "RU",
    "name": "Krapivna",
    "lat": "53.94235",
    "lng": "37.15744"
  },
  {
    "country": "RU",
    "name": "Krasnokholmskiy",
    "lat": "55.98729",
    "lng": "55.04659"
  },
  {
    "country": "RU",
    "name": "Koz’modem’yansk",
    "lat": "56.3419",
    "lng": "46.56353"
  },
  {
    "country": "RU",
    "name": "Kozlovo",
    "lat": "56.50977",
    "lng": "36.27326"
  },
  {
    "country": "RU",
    "name": "Kozlovka",
    "lat": "55.84284",
    "lng": "48.2492"
  },
  {
    "country": "RU",
    "name": "Kozlovka",
    "lat": "50.86222",
    "lng": "40.45556"
  },
  {
    "country": "RU",
    "name": "Kozhva",
    "lat": "65.10727",
    "lng": "57.0459"
  },
  {
    "country": "RU",
    "name": "Kozhukhovo",
    "lat": "55.7",
    "lng": "37.66667"
  },
  {
    "country": "RU",
    "name": "Kozeyevo",
    "lat": "55.86667",
    "lng": "37.61667"
  },
  {
    "country": "RU",
    "name": "Kozel’sk",
    "lat": "54.03746",
    "lng": "35.77159"
  },
  {
    "country": "RU",
    "name": "Koygorodok",
    "lat": "60.44498",
    "lng": "50.9968"
  },
  {
    "country": "RU",
    "name": "Kovylkino",
    "lat": "54.03876",
    "lng": "43.91385"
  },
  {
    "country": "RU",
    "name": "Kovrov",
    "lat": "56.35722",
    "lng": "41.31917"
  },
  {
    "country": "RU",
    "name": "Kovernino",
    "lat": "57.12818",
    "lng": "43.8135"
  },
  {
    "country": "RU",
    "name": "Kovdor",
    "lat": "67.56616",
    "lng": "30.47576"
  },
  {
    "country": "RU",
    "name": "Kotovsk",
    "lat": "52.58666",
    "lng": "41.5021"
  },
  {
    "country": "RU",
    "name": "Kotovo",
    "lat": "50.32113",
    "lng": "44.80119"
  },
  {
    "country": "RU",
    "name": "Kotlyarevskaya",
    "lat": "43.57344",
    "lng": "44.06134"
  },
  {
    "country": "RU",
    "name": "Kotlas",
    "lat": "61.25745",
    "lng": "46.64963"
  },
  {
    "country": "RU",
    "name": "Kotel’nikovo",
    "lat": "47.63009",
    "lng": "43.14068"
  },
  {
    "country": "RU",
    "name": "Kotel’niki",
    "lat": "55.63546",
    "lng": "37.8445"
  },
  {
    "country": "RU",
    "name": "Kotel’nich",
    "lat": "58.3089",
    "lng": "48.348"
  },
  {
    "country": "RU",
    "name": "Kostrovo",
    "lat": "55.89429",
    "lng": "36.69491"
  },
  {
    "country": "RU",
    "name": "Kostroma",
    "lat": "57.76647",
    "lng": "40.92686"
  },
  {
    "country": "RU",
    "name": "Kostomuksha",
    "lat": "64.571",
    "lng": "30.57667"
  },
  {
    "country": "RU",
    "name": "Kostino",
    "lat": "58.90966",
    "lng": "53.26907"
  },
  {
    "country": "RU",
    "name": "Kostino",
    "lat": "56.03333",
    "lng": "37.91667"
  },
  {
    "country": "RU",
    "name": "Kostek",
    "lat": "43.34387",
    "lng": "46.85411"
  },
  {
    "country": "RU",
    "name": "Kosmynino",
    "lat": "57.58183",
    "lng": "40.76434"
  },
  {
    "country": "RU",
    "name": "Koslan",
    "lat": "63.45641",
    "lng": "48.89891"
  },
  {
    "country": "RU",
    "name": "Kosino",
    "lat": "58.41272",
    "lng": "51.27819"
  },
  {
    "country": "RU",
    "name": "Koshki",
    "lat": "54.20914",
    "lng": "50.46767"
  },
  {
    "country": "RU",
    "name": "Koshekhabl’",
    "lat": "44.89722",
    "lng": "40.51194"
  },
  {
    "country": "RU",
    "name": "Kosaya Gora",
    "lat": "54.11896",
    "lng": "37.54459"
  },
  {
    "country": "RU",
    "name": "Kosa",
    "lat": "59.9449",
    "lng": "54.9895"
  },
  {
    "country": "RU",
    "name": "Korzhovka-Golubovka",
    "lat": "52.76742",
    "lng": "32.35362"
  },
  {
    "country": "RU",
    "name": "Korzhevskiy",
    "lat": "45.19414",
    "lng": "37.71949"
  },
  {
    "country": "RU",
    "name": "Koryazhma",
    "lat": "61.31433",
    "lng": "47.16914"
  },
  {
    "country": "RU",
    "name": "Kortkeros",
    "lat": "61.81056",
    "lng": "51.58056"
  },
  {
    "country": "RU",
    "name": "Korsakovo",
    "lat": "53.26767",
    "lng": "37.35689"
  },
  {
    "country": "RU",
    "name": "Korotoyak",
    "lat": "50.98665",
    "lng": "39.17677"
  },
  {
    "country": "RU",
    "name": "Korocha",
    "lat": "50.8132",
    "lng": "37.18598"
  },
  {
    "country": "RU",
    "name": "Korobitsyno",
    "lat": "60.51523",
    "lng": "29.72437"
  },
  {
    "country": "RU",
    "name": "Kormëzhka",
    "lat": "51.9005",
    "lng": "48.0163"
  },
  {
    "country": "RU",
    "name": "Korenovsk",
    "lat": "45.46899",
    "lng": "39.45136"
  },
  {
    "country": "RU",
    "name": "Korenëvo",
    "lat": "55.67194",
    "lng": "38.00778"
  },
  {
    "country": "RU",
    "name": "Korenëvo",
    "lat": "51.4119",
    "lng": "34.908"
  },
  {
    "country": "RU",
    "name": "Korablino",
    "lat": "53.91639",
    "lng": "40.01333"
  },
  {
    "country": "RU",
    "name": "Koptëvo",
    "lat": "55.81667",
    "lng": "37.51667"
  },
  {
    "country": "RU",
    "name": "Kopor’ye",
    "lat": "59.71067",
    "lng": "29.03488"
  },
  {
    "country": "RU",
    "name": "Kopanskaya",
    "lat": "46.27785",
    "lng": "38.47955"
  },
  {
    "country": "RU",
    "name": "Konyshevka",
    "lat": "51.8418",
    "lng": "35.2941"
  },
  {
    "country": "RU",
    "name": "Konstantinovskoye",
    "lat": "45.29917",
    "lng": "42.63667"
  },
  {
    "country": "RU",
    "name": "Konstantinovskiy",
    "lat": "57.83005",
    "lng": "39.58989"
  },
  {
    "country": "RU",
    "name": "Konstantinovskaya",
    "lat": "44.83528",
    "lng": "40.72694"
  },
  {
    "country": "RU",
    "name": "Konstantinovskaya",
    "lat": "44.04556",
    "lng": "43.15833"
  },
  {
    "country": "RU",
    "name": "Konstantinovsk",
    "lat": "47.58278",
    "lng": "41.09222"
  },
  {
    "country": "RU",
    "name": "Konstantinovo",
    "lat": "56.55",
    "lng": "38.03333"
  },
  {
    "country": "RU",
    "name": "Konosha",
    "lat": "60.9736",
    "lng": "40.257"
  },
  {
    "country": "RU",
    "name": "Konokovo",
    "lat": "44.8616",
    "lng": "41.3266"
  },
  {
    "country": "RU",
    "name": "Konobeyevo",
    "lat": "55.40776",
    "lng": "38.66261"
  },
  {
    "country": "RU",
    "name": "Konëvo",
    "lat": "62.11745",
    "lng": "39.33131"
  },
  {
    "country": "RU",
    "name": "Kondrovo",
    "lat": "54.80639",
    "lng": "35.92778"
  },
  {
    "country": "RU",
    "name": "Kondopoga",
    "lat": "62.20565",
    "lng": "34.26138"
  },
  {
    "country": "RU",
    "name": "Kondol’",
    "lat": "52.81889",
    "lng": "45.05798"
  },
  {
    "country": "RU",
    "name": "Konakovo",
    "lat": "56.7",
    "lng": "36.76667"
  },
  {
    "country": "RU",
    "name": "Komsomol'skoye",
    "lat": "55.25667",
    "lng": "47.54608"
  },
  {
    "country": "RU",
    "name": "Komsomol’skiy",
    "lat": "45.33",
    "lng": "46.0428"
  },
  {
    "country": "RU",
    "name": "Komsomol’skiy",
    "lat": "43.97833",
    "lng": "46.69852"
  },
  {
    "country": "RU",
    "name": "Komsomol’sk",
    "lat": "57.02913",
    "lng": "40.37266"
  },
  {
    "country": "RU",
    "name": "Komsomolets",
    "lat": "52.7686",
    "lng": "41.28683"
  },
  {
    "country": "RU",
    "name": "Komsomolets",
    "lat": "44.01972",
    "lng": "43.56972"
  },
  {
    "country": "RU",
    "name": "Kommunarka",
    "lat": "55.56952",
    "lng": "37.48932"
  },
  {
    "country": "RU",
    "name": "Kommunar",
    "lat": "59.62056",
    "lng": "30.39"
  },
  {
    "country": "RU",
    "name": "Kommunar",
    "lat": "56.11222",
    "lng": "40.44666"
  },
  {
    "country": "RU",
    "name": "Komarovo",
    "lat": "60.1866",
    "lng": "29.80865"
  },
  {
    "country": "RU",
    "name": "Komarikhinskiy",
    "lat": "58.0979",
    "lng": "57.1163"
  },
  {
    "country": "RU",
    "name": "Komarichi",
    "lat": "52.4151",
    "lng": "34.7905"
  },
  {
    "country": "RU",
    "name": "Kolyubakino",
    "lat": "55.668",
    "lng": "36.53234"
  },
  {
    "country": "RU",
    "name": "Kolyshley",
    "lat": "52.7005",
    "lng": "44.5367"
  },
  {
    "country": "RU",
    "name": "Koltushi",
    "lat": "59.92969",
    "lng": "30.64465"
  },
  {
    "country": "RU",
    "name": "Koltubanovskiy",
    "lat": "52.9407",
    "lng": "52.0269"
  },
  {
    "country": "RU",
    "name": "Kolpny",
    "lat": "52.22823",
    "lng": "37.03683"
  },
  {
    "country": "RU",
    "name": "Kolpino",
    "lat": "59.75069",
    "lng": "30.58856"
  },
  {
    "country": "RU",
    "name": "Yanino-1",
    "lat": "59.94808",
    "lng": "30.55914"
  },
  {
    "country": "RU",
    "name": "Kolomyagi",
    "lat": "60.02427",
    "lng": "30.28491"
  },
  {
    "country": "RU",
    "name": "Kolomna",
    "lat": "55.07944",
    "lng": "38.77833"
  },
  {
    "country": "RU",
    "name": "Kolomenskoye",
    "lat": "55.66667",
    "lng": "37.68333"
  },
  {
    "country": "RU",
    "name": "Kologriv",
    "lat": "58.82748",
    "lng": "44.31777"
  },
  {
    "country": "RU",
    "name": "Kolodeznyy",
    "lat": "51.33333",
    "lng": "39.18333"
  },
  {
    "country": "RU",
    "name": "Kolobovo",
    "lat": "56.70199",
    "lng": "41.34173"
  },
  {
    "country": "RU",
    "name": "Kol’chugino",
    "lat": "56.29929",
    "lng": "39.38304"
  },
  {
    "country": "RU",
    "name": "Kolchanovo",
    "lat": "60.01647",
    "lng": "32.58837"
  },
  {
    "country": "RU",
    "name": "Kola",
    "lat": "68.88062",
    "lng": "33.01842"
  },
  {
    "country": "RU",
    "name": "Koksovyy",
    "lat": "48.20058",
    "lng": "40.65089"
  },
  {
    "country": "RU",
    "name": "Kokoshkino",
    "lat": "55.59769",
    "lng": "37.1695"
  },
  {
    "country": "RU",
    "name": "Kokorevka",
    "lat": "52.5874",
    "lng": "34.2692"
  },
  {
    "country": "RU",
    "name": "Kokino",
    "lat": "52.4964",
    "lng": "34.7808"
  },
  {
    "country": "RU",
    "name": "Kokhma",
    "lat": "56.93487",
    "lng": "41.0915"
  },
  {
    "country": "RU",
    "name": "Kodino",
    "lat": "63.71976",
    "lng": "39.64465"
  },
  {
    "country": "RU",
    "name": "Kochkurovo",
    "lat": "54.03576",
    "lng": "45.41845"
  },
  {
    "country": "RU",
    "name": "Kochevo",
    "lat": "59.5974",
    "lng": "54.3147"
  },
  {
    "country": "RU",
    "name": "Kobrinskoye",
    "lat": "59.4225",
    "lng": "30.12389"
  },
  {
    "country": "RU",
    "name": "Knyaginino",
    "lat": "55.82278",
    "lng": "45.03489"
  },
  {
    "country": "RU",
    "name": "Klyavlino",
    "lat": "54.26491",
    "lng": "52.02674"
  },
  {
    "country": "RU",
    "name": "Klintsy",
    "lat": "52.76019",
    "lng": "32.23935"
  },
  {
    "country": "RU",
    "name": "Klin",
    "lat": "56.33333",
    "lng": "36.73333"
  },
  {
    "country": "RU",
    "name": "Klimovsk",
    "lat": "55.36352",
    "lng": "37.52984"
  },
  {
    "country": "RU",
    "name": "Klimovo",
    "lat": "52.38053",
    "lng": "32.19233"
  },
  {
    "country": "RU",
    "name": "Kletskaya",
    "lat": "49.31455",
    "lng": "43.05844"
  },
  {
    "country": "RU",
    "name": "Kletnya",
    "lat": "53.38967",
    "lng": "33.21714"
  },
  {
    "country": "RU",
    "name": "Kizner",
    "lat": "56.27489",
    "lng": "51.508"
  },
  {
    "country": "RU",
    "name": "Kizlyar",
    "lat": "43.84712",
    "lng": "46.71445"
  },
  {
    "country": "RU",
    "name": "Kizlyar",
    "lat": "43.70379",
    "lng": "44.5944"
  },
  {
    "country": "RU",
    "name": "Kizilyurt",
    "lat": "43.20697",
    "lng": "46.8679"
  },
  {
    "country": "RU",
    "name": "Kizema",
    "lat": "61.11304",
    "lng": "44.83017"
  },
  {
    "country": "RU",
    "name": "Kizel",
    "lat": "59.04709",
    "lng": "57.64767"
  },
  {
    "country": "RU",
    "name": "Kiyevskoye",
    "lat": "45.03829",
    "lng": "37.88829"
  },
  {
    "country": "RU",
    "name": "Kiyasovo",
    "lat": "56.34907",
    "lng": "53.12439"
  },
  {
    "country": "RU",
    "name": "Kitovo",
    "lat": "56.86586",
    "lng": "41.28246"
  },
  {
    "country": "RU",
    "name": "Kislyakovskaya",
    "lat": "46.4417",
    "lng": "39.675"
  },
  {
    "country": "RU",
    "name": "Kislovodsk",
    "lat": "43.91333",
    "lng": "42.72083"
  },
  {
    "country": "RU",
    "name": "Kishpek",
    "lat": "43.655",
    "lng": "43.64083"
  },
  {
    "country": "RU",
    "name": "Kirzhach",
    "lat": "56.15273",
    "lng": "38.85509"
  },
  {
    "country": "RU",
    "name": "Kirya",
    "lat": "55.08102",
    "lng": "46.86091"
  },
  {
    "country": "RU",
    "name": "Kirsanov",
    "lat": "52.65494",
    "lng": "42.72236"
  },
  {
    "country": "RU",
    "name": "Kirs",
    "lat": "59.33882",
    "lng": "52.24467"
  },
  {
    "country": "RU",
    "name": "Kirovskiy",
    "lat": "51.41667",
    "lng": "36.66667"
  },
  {
    "country": "RU",
    "name": "Kirovskiy",
    "lat": "45.84639",
    "lng": "48.12472"
  },
  {
    "country": "RU",
    "name": "Kirovskaya",
    "lat": "46.9748",
    "lng": "40.0402"
  },
  {
    "country": "RU",
    "name": "Kirovsk",
    "lat": "67.61475",
    "lng": "33.67274"
  },
  {
    "country": "RU",
    "name": "Kirovsk",
    "lat": "59.88101",
    "lng": "30.99507"
  },
  {
    "country": "RU",
    "name": "Kirovo-Chepetsk",
    "lat": "58.55386",
    "lng": "50.03986"
  },
  {
    "country": "RU",
    "name": "Kirov",
    "lat": "58.59665",
    "lng": "49.66007"
  },
  {
    "country": "RU",
    "name": "Kirov",
    "lat": "54.06686",
    "lng": "34.29955"
  },
  {
    "country": "RU",
    "name": "Kiritsy",
    "lat": "54.2862",
    "lng": "40.3572"
  },
  {
    "country": "RU",
    "name": "Kirishi",
    "lat": "59.44712",
    "lng": "32.02049"
  },
  {
    "country": "RU",
    "name": "Kirillov",
    "lat": "59.86299",
    "lng": "38.38128"
  },
  {
    "country": "RU",
    "name": "Kirgiz-Miyaki",
    "lat": "53.6324",
    "lng": "54.7979"
  },
  {
    "country": "RU",
    "name": "Kireyevsk",
    "lat": "53.93361",
    "lng": "37.92792"
  },
  {
    "country": "RU",
    "name": "Kingisepp",
    "lat": "59.37331",
    "lng": "28.61343"
  },
  {
    "country": "RU",
    "name": "Kineshma",
    "lat": "57.43914",
    "lng": "42.12894"
  },
  {
    "country": "RU",
    "name": "Kinel’-Cherkassy",
    "lat": "53.4706",
    "lng": "51.47431"
  },
  {
    "country": "RU",
    "name": "Kinel’",
    "lat": "53.22571",
    "lng": "50.62907"
  },
  {
    "country": "RU",
    "name": "Kimry",
    "lat": "56.86667",
    "lng": "37.35"
  },
  {
    "country": "RU",
    "name": "Kimovsk",
    "lat": "53.97164",
    "lng": "38.53186"
  },
  {
    "country": "RU",
    "name": "Kil’mez’",
    "lat": "56.94389",
    "lng": "51.065"
  },
  {
    "country": "RU",
    "name": "Kilemary",
    "lat": "56.77825",
    "lng": "46.86594"
  },
  {
    "country": "RU",
    "name": "Kikvidze",
    "lat": "50.74161",
    "lng": "43.0518"
  },
  {
    "country": "RU",
    "name": "Kiknur",
    "lat": "57.30341",
    "lng": "47.20105"
  },
  {
    "country": "RU",
    "name": "Kikerino",
    "lat": "59.46466",
    "lng": "29.62729"
  },
  {
    "country": "RU",
    "name": "Kideksha",
    "lat": "56.42381",
    "lng": "40.52146"
  },
  {
    "country": "RU",
    "name": "Kichmengskiy Gorodok",
    "lat": "59.98164",
    "lng": "45.78543"
  },
  {
    "country": "RU",
    "name": "Khvoynaya",
    "lat": "58.9",
    "lng": "34.53333"
  },
  {
    "country": "RU",
    "name": "Khvorostyanka",
    "lat": "52.6096",
    "lng": "48.9597"
  },
  {
    "country": "RU",
    "name": "Khvatovka",
    "lat": "52.35236",
    "lng": "46.56282"
  },
  {
    "country": "RU",
    "name": "Khvastovichi",
    "lat": "53.46942",
    "lng": "35.09409"
  },
  {
    "country": "RU",
    "name": "Khvalynsk",
    "lat": "52.4906",
    "lng": "48.1058"
  },
  {
    "country": "RU",
    "name": "Khvalovo",
    "lat": "59.94774",
    "lng": "32.73723"
  },
  {
    "country": "RU",
    "name": "Khunzakh",
    "lat": "42.5424",
    "lng": "46.70689"
  },
  {
    "country": "RU",
    "name": "Khumalag",
    "lat": "43.24031",
    "lng": "44.47521"
  },
  {
    "country": "RU",
    "name": "Khuchni",
    "lat": "41.94986",
    "lng": "47.94854"
  },
  {
    "country": "RU",
    "name": "Khryashchevka",
    "lat": "53.8119",
    "lng": "49.0916"
  },
  {
    "country": "RU",
    "name": "Khrenovoye",
    "lat": "51.12",
    "lng": "40.28889"
  },
  {
    "country": "RU",
    "name": "Khrabrovo",
    "lat": "54.89709",
    "lng": "20.58035"
  },
  {
    "country": "RU",
    "name": "Khotynets",
    "lat": "53.1286",
    "lng": "35.3966"
  },
  {
    "country": "RU",
    "name": "Khot'kovo",
    "lat": "56.25699",
    "lng": "37.99544"
  },
  {
    "country": "RU",
    "name": "Khosta",
    "lat": "43.51484",
    "lng": "39.86825"
  },
  {
    "country": "RU",
    "name": "Khoroshëvo-Mnevniki",
    "lat": "55.78363",
    "lng": "37.47137"
  },
  {
    "country": "RU",
    "name": "Khorlovo",
    "lat": "55.3327",
    "lng": "38.81365"
  },
  {
    "country": "RU",
    "name": "Khomutovo",
    "lat": "52.85386",
    "lng": "37.4388"
  },
  {
    "country": "RU",
    "name": "Khomutovka",
    "lat": "51.9207",
    "lng": "34.5619"
  },
  {
    "country": "RU",
    "name": "Kholm-Zhirkovskiy",
    "lat": "55.51889",
    "lng": "33.47306"
  },
  {
    "country": "RU",
    "name": "Kholmskiy",
    "lat": "44.84694",
    "lng": "38.385"
  },
  {
    "country": "RU",
    "name": "Kholmogory",
    "lat": "64.2229",
    "lng": "41.656"
  },
  {
    "country": "RU",
    "name": "Kholm",
    "lat": "59.26667",
    "lng": "32.85"
  },
  {
    "country": "RU",
    "name": "Kholm",
    "lat": "57.14543",
    "lng": "31.1778"
  },
  {
    "country": "RU",
    "name": "Khokhryaki",
    "lat": "56.91561",
    "lng": "53.3221"
  },
  {
    "country": "RU",
    "name": "Khokhlovo",
    "lat": "59.14923",
    "lng": "37.39978"
  },
  {
    "country": "RU",
    "name": "Khodz’",
    "lat": "44.5102",
    "lng": "40.7142"
  },
  {
    "country": "RU",
    "name": "Khlevnoye",
    "lat": "52.19512",
    "lng": "39.09316"
  },
  {
    "country": "RU",
    "name": "Khiv",
    "lat": "41.75428",
    "lng": "47.93063"
  },
  {
    "country": "RU",
    "name": "Khislavichi",
    "lat": "54.18714",
    "lng": "32.15817"
  },
  {
    "country": "RU",
    "name": "Khimki",
    "lat": "55.89704",
    "lng": "37.42969"
  },
  {
    "country": "RU",
    "name": "Khelyulya",
    "lat": "61.749",
    "lng": "30.66473"
  },
  {
    "country": "RU",
    "name": "Khatukay",
    "lat": "45.19074",
    "lng": "39.6632"
  },
  {
    "country": "RU",
    "name": "Khasavyurt",
    "lat": "43.2509",
    "lng": "46.58766"
  },
  {
    "country": "RU",
    "name": "Kharovsk",
    "lat": "59.96425",
    "lng": "40.19121"
  },
  {
    "country": "RU",
    "name": "Kharlu",
    "lat": "61.8",
    "lng": "30.95"
  },
  {
    "country": "RU",
    "name": "Kharitonovo",
    "lat": "61.40092",
    "lng": "47.49779"
  },
  {
    "country": "RU",
    "name": "Kharabali",
    "lat": "47.41958",
    "lng": "47.25678"
  },
  {
    "country": "RU",
    "name": "Khanskaya",
    "lat": "44.67702",
    "lng": "39.9616"
  },
  {
    "country": "RU",
    "name": "Khanino",
    "lat": "54.211",
    "lng": "36.62292"
  },
  {
    "country": "RU",
    "name": "Khamamatyurt",
    "lat": "43.60809",
    "lng": "46.5006"
  },
  {
    "country": "RU",
    "name": "Orlov",
    "lat": "58.53946",
    "lng": "48.89173"
  },
  {
    "country": "RU",
    "name": "Khadzhalmakhi",
    "lat": "42.42",
    "lng": "47.18206"
  },
  {
    "country": "RU",
    "name": "Khadyzhensk",
    "lat": "44.4258",
    "lng": "39.5362"
  },
  {
    "country": "RU",
    "name": "Khabez",
    "lat": "44.0434",
    "lng": "41.772"
  },
  {
    "country": "RU",
    "name": "Kez",
    "lat": "57.8957",
    "lng": "53.7132"
  },
  {
    "country": "RU",
    "name": "Kevsala",
    "lat": "45.79833",
    "lng": "42.69028"
  },
  {
    "country": "RU",
    "name": "Kesova Gora",
    "lat": "57.58361",
    "lng": "37.29222"
  },
  {
    "country": "RU",
    "name": "Kerva",
    "lat": "55.61167",
    "lng": "39.57665"
  },
  {
    "country": "RU",
    "name": "Kerchevskiy",
    "lat": "59.9456",
    "lng": "56.2959"
  },
  {
    "country": "RU",
    "name": "Kenzhe",
    "lat": "43.50167",
    "lng": "43.55722"
  },
  {
    "country": "RU",
    "name": "Kemlya",
    "lat": "54.6963",
    "lng": "45.2424"
  },
  {
    "country": "RU",
    "name": "Kem’",
    "lat": "64.95546",
    "lng": "34.57929"
  },
  {
    "country": "RU",
    "name": "Kazinka",
    "lat": "52.53817",
    "lng": "39.82164"
  },
  {
    "country": "RU",
    "name": "Kazanskaya",
    "lat": "49.79333",
    "lng": "41.14667"
  },
  {
    "country": "RU",
    "name": "Kazanskaya",
    "lat": "45.4106",
    "lng": "40.4361"
  },
  {
    "country": "RU",
    "name": "Kazan",
    "lat": "55.78874",
    "lng": "49.12214"
  },
  {
    "country": "RU",
    "name": "Kazaki",
    "lat": "52.62484",
    "lng": "38.26488"
  },
  {
    "country": "RU",
    "name": "Kayasula",
    "lat": "44.325",
    "lng": "45"
  },
  {
    "country": "RU",
    "name": "Kayakent",
    "lat": "42.38736",
    "lng": "47.90301"
  },
  {
    "country": "RU",
    "name": "Kavkazskiy",
    "lat": "44.2672",
    "lng": "42.2347"
  },
  {
    "country": "RU",
    "name": "Kavkazskaya",
    "lat": "45.4453",
    "lng": "40.6765"
  },
  {
    "country": "RU",
    "name": "Katyr-Yurt",
    "lat": "43.17007",
    "lng": "45.37114"
  },
  {
    "country": "RU",
    "name": "Katyn'",
    "lat": "54.77455",
    "lng": "31.69041"
  },
  {
    "country": "RU",
    "name": "Katunino",
    "lat": "64.3862",
    "lng": "40.6298"
  },
  {
    "country": "RU",
    "name": "Katav-Ivanovsk",
    "lat": "54.75306",
    "lng": "58.19556"
  },
  {
    "country": "RU",
    "name": "Kasumkent",
    "lat": "41.67725",
    "lng": "48.14601"
  },
  {
    "country": "RU",
    "name": "Kastornoye",
    "lat": "51.8334",
    "lng": "38.1302"
  },
  {
    "country": "RU",
    "name": "Kastanayevo",
    "lat": "55.71667",
    "lng": "37.5"
  },
  {
    "country": "RU",
    "name": "Kaspiyskiy",
    "lat": "45.39288",
    "lng": "47.37073"
  },
  {
    "country": "RU",
    "name": "Kaspiysk",
    "lat": "42.88165",
    "lng": "47.63919"
  },
  {
    "country": "RU",
    "name": "Kasimov",
    "lat": "54.94111",
    "lng": "41.39528"
  },
  {
    "country": "RU",
    "name": "Kashirskoye",
    "lat": "51.41945",
    "lng": "39.61248"
  },
  {
    "country": "RU",
    "name": "Kashira",
    "lat": "54.84444",
    "lng": "38.16694"
  },
  {
    "country": "RU",
    "name": "Kashin",
    "lat": "57.35917",
    "lng": "37.60806"
  },
  {
    "country": "RU",
    "name": "Kashary",
    "lat": "49.04001",
    "lng": "41.00557"
  },
  {
    "country": "RU",
    "name": "Karsun",
    "lat": "54.19941",
    "lng": "46.9827"
  },
  {
    "country": "RU",
    "name": "Karpushikha",
    "lat": "57.50167",
    "lng": "59.89556"
  },
  {
    "country": "RU",
    "name": "Karpogory",
    "lat": "64.00189",
    "lng": "44.44513"
  },
  {
    "country": "RU",
    "name": "Karmaskaly",
    "lat": "54.3709",
    "lng": "56.1837"
  },
  {
    "country": "RU",
    "name": "Karinskoye",
    "lat": "55.70969",
    "lng": "36.68903"
  },
  {
    "country": "RU",
    "name": "Kargopol’",
    "lat": "61.50359",
    "lng": "38.9486"
  },
  {
    "country": "RU",
    "name": "Kargalinskaya",
    "lat": "43.74381",
    "lng": "46.47821"
  },
  {
    "country": "RU",
    "name": "Kardzhin",
    "lat": "43.27368",
    "lng": "44.29075"
  },
  {
    "country": "RU",
    "name": "Kardymovo",
    "lat": "54.89016",
    "lng": "32.43111"
  },
  {
    "country": "RU",
    "name": "Kardonikskaya",
    "lat": "43.86577",
    "lng": "41.71432"
  },
  {
    "country": "RU",
    "name": "Kardailovo",
    "lat": "51.53861",
    "lng": "53.90417"
  },
  {
    "country": "RU",
    "name": "Karata",
    "lat": "42.59486",
    "lng": "46.3393"
  },
  {
    "country": "RU",
    "name": "Karalat",
    "lat": "45.91555",
    "lng": "48.30683"
  },
  {
    "country": "RU",
    "name": "Karakulino",
    "lat": "56.012",
    "lng": "53.70669"
  },
  {
    "country": "RU",
    "name": "Karaidel’",
    "lat": "55.83373",
    "lng": "56.90692"
  },
  {
    "country": "RU",
    "name": "Karagay",
    "lat": "58.26669",
    "lng": "54.93678"
  },
  {
    "country": "RU",
    "name": "Karagach",
    "lat": "43.80528",
    "lng": "43.775"
  },
  {
    "country": "RU",
    "name": "Karachev",
    "lat": "53.12292",
    "lng": "34.98517"
  },
  {
    "country": "RU",
    "name": "Karachayevsk",
    "lat": "43.77399",
    "lng": "41.91419"
  },
  {
    "country": "RU",
    "name": "Karabulak",
    "lat": "43.30513",
    "lng": "44.89949"
  },
  {
    "country": "RU",
    "name": "Karabudakhkent",
    "lat": "42.7087",
    "lng": "47.56735"
  },
  {
    "country": "RU",
    "name": "Karabash",
    "lat": "54.693",
    "lng": "52.58359"
  },
  {
    "country": "RU",
    "name": "Karabanovo",
    "lat": "56.31667",
    "lng": "38.7"
  },
  {
    "country": "RU",
    "name": "Kapustin Yar",
    "lat": "48.58175",
    "lng": "45.74481"
  },
  {
    "country": "RU",
    "name": "Kapotnya",
    "lat": "55.63806",
    "lng": "37.79306"
  },
  {
    "country": "RU",
    "name": "Kantyshevo",
    "lat": "43.22824",
    "lng": "44.63322"
  },
  {
    "country": "RU",
    "name": "Kantemirovka",
    "lat": "49.70887",
    "lng": "39.85922"
  },
  {
    "country": "RU",
    "name": "Kangly",
    "lat": "44.25444",
    "lng": "43.03083"
  },
  {
    "country": "RU",
    "name": "Kanevskaya",
    "lat": "46.0849",
    "lng": "38.9596"
  },
  {
    "country": "RU",
    "name": "Kanelovskaya",
    "lat": "46.5896",
    "lng": "39.1944"
  },
  {
    "country": "RU",
    "name": "Kandry",
    "lat": "54.56667",
    "lng": "54.11667"
  },
  {
    "country": "RU",
    "name": "Kandalaksha",
    "lat": "67.162",
    "lng": "32.41229"
  },
  {
    "country": "RU",
    "name": "Kanayevka",
    "lat": "53.10783",
    "lng": "45.56144"
  },
  {
    "country": "RU",
    "name": "Kanash",
    "lat": "55.50962",
    "lng": "47.49127"
  },
  {
    "country": "RU",
    "name": "Kanadey",
    "lat": "53.16786",
    "lng": "47.52644"
  },
  {
    "country": "RU",
    "name": "Kamyzyak",
    "lat": "46.10995",
    "lng": "48.07364"
  },
  {
    "country": "RU",
    "name": "Kamyshla",
    "lat": "54.11693",
    "lng": "52.14262"
  },
  {
    "country": "RU",
    "name": "Kamyshin",
    "lat": "50.09833",
    "lng": "45.41601"
  },
  {
    "country": "RU",
    "name": "Kamyshevatskaya",
    "lat": "46.41316",
    "lng": "37.95632"
  },
  {
    "country": "RU",
    "name": "Kaminskiy",
    "lat": "57.15159",
    "lng": "41.47318"
  },
  {
    "country": "RU",
    "name": "Kameshkovo",
    "lat": "56.35305",
    "lng": "41.00941"
  },
  {
    "country": "RU",
    "name": "Kamensk-Shakhtinskiy",
    "lat": "48.31779",
    "lng": "40.25948"
  },
  {
    "country": "RU",
    "name": "Kamenskiy",
    "lat": "50.88547",
    "lng": "45.48801"
  },
  {
    "country": "RU",
    "name": "Kamenolomni",
    "lat": "47.66853",
    "lng": "40.2051"
  },
  {
    "country": "RU",
    "name": "Kamennomostskoye",
    "lat": "43.73722",
    "lng": "43.05139"
  },
  {
    "country": "RU",
    "name": "Kamennomostskiy",
    "lat": "44.2891",
    "lng": "40.188"
  },
  {
    "country": "RU",
    "name": "Kamennogorsk",
    "lat": "60.95451",
    "lng": "29.13391"
  },
  {
    "country": "RU",
    "name": "Kamenka",
    "lat": "65.8835",
    "lng": "44.1272"
  },
  {
    "country": "RU",
    "name": "Kamenka",
    "lat": "60.44639",
    "lng": "29.0829"
  },
  {
    "country": "RU",
    "name": "Kamenka",
    "lat": "57.39214",
    "lng": "41.79383"
  },
  {
    "country": "RU",
    "name": "Kamenka",
    "lat": "51.3223",
    "lng": "42.7678"
  },
  {
    "country": "RU",
    "name": "Kamenka",
    "lat": "50.71499",
    "lng": "39.42189"
  },
  {
    "country": "RU",
    "name": "Kamenka",
    "lat": "43.53333",
    "lng": "43.51667"
  },
  {
    "country": "RU",
    "name": "Kamenetskiy",
    "lat": "54.01353",
    "lng": "38.22115"
  },
  {
    "country": "RU",
    "name": "Kambileyevskoye",
    "lat": "43.07858",
    "lng": "44.75216"
  },
  {
    "country": "RU",
    "name": "Kambarka",
    "lat": "56.2666",
    "lng": "54.2056"
  },
  {
    "country": "RU",
    "name": "Kama",
    "lat": "56.30512",
    "lng": "54.09361"
  },
  {
    "country": "RU",
    "name": "Kalyazin",
    "lat": "57.24028",
    "lng": "37.84333"
  },
  {
    "country": "RU",
    "name": "Kaluga",
    "lat": "54.5293",
    "lng": "36.27542"
  },
  {
    "country": "RU",
    "name": "Kaltasy",
    "lat": "55.96926",
    "lng": "54.80321"
  },
  {
    "country": "RU",
    "name": "Kalnibolotskaya",
    "lat": "46.00583",
    "lng": "40.45682"
  },
  {
    "country": "RU",
    "name": "Kalinovskoye",
    "lat": "44.8635",
    "lng": "42.9622"
  },
  {
    "country": "RU",
    "name": "Kalinovskaya",
    "lat": "43.57383",
    "lng": "45.5209"
  },
  {
    "country": "RU",
    "name": "Kalino",
    "lat": "58.2504",
    "lng": "57.6085"
  },
  {
    "country": "RU",
    "name": "Kalininskaya",
    "lat": "45.4844",
    "lng": "38.66221"
  },
  {
    "country": "RU",
    "name": "Kalininsk",
    "lat": "51.5",
    "lng": "44.4758"
  },
  {
    "country": "RU",
    "name": "Korolev",
    "lat": "55.91417",
    "lng": "37.82556"
  },
  {
    "country": "RU",
    "name": "Kaliningrad",
    "lat": "54.70649",
    "lng": "20.51095"
  },
  {
    "country": "RU",
    "name": "Kalininaul",
    "lat": "43.07121",
    "lng": "46.56679"
  },
  {
    "country": "RU",
    "name": "Kalinin",
    "lat": "47.24678",
    "lng": "39.51088"
  },
  {
    "country": "RU",
    "name": "Kalikino",
    "lat": "52.9493",
    "lng": "39.8269"
  },
  {
    "country": "RU",
    "name": "Kalevala",
    "lat": "65.19873",
    "lng": "31.18999"
  },
  {
    "country": "RU",
    "name": "Kalashnikovo",
    "lat": "57.28237",
    "lng": "35.22617"
  },
  {
    "country": "RU",
    "name": "Kalach-na-Donu",
    "lat": "48.69099",
    "lng": "43.52638"
  },
  {
    "country": "RU",
    "name": "Kalach",
    "lat": "50.4258",
    "lng": "41.0261"
  },
  {
    "country": "RU",
    "name": "Kakhun",
    "lat": "43.54306",
    "lng": "43.87639"
  },
  {
    "country": "RU",
    "name": "Kagal’nitskaya",
    "lat": "46.88056",
    "lng": "40.14657"
  },
  {
    "country": "RU",
    "name": "Kafyr-Kumukh",
    "lat": "42.83754",
    "lng": "47.15412"
  },
  {
    "country": "RU",
    "name": "Kadyy",
    "lat": "57.78704",
    "lng": "43.19029"
  },
  {
    "country": "RU",
    "name": "Kaduy",
    "lat": "59.2",
    "lng": "37.15"
  },
  {
    "country": "RU",
    "name": "Kadoshkino",
    "lat": "54.0257",
    "lng": "44.4191"
  },
  {
    "country": "RU",
    "name": "Kadom",
    "lat": "54.55917",
    "lng": "42.4675"
  },
  {
    "country": "RU",
    "name": "Kadnikov",
    "lat": "59.50218",
    "lng": "40.33803"
  },
  {
    "country": "RU",
    "name": "Kachkanar",
    "lat": "58.7002",
    "lng": "59.4839"
  },
  {
    "country": "RU",
    "name": "Kabardinka",
    "lat": "44.65139",
    "lng": "37.94278"
  },
  {
    "country": "RU",
    "name": "Kabanovo",
    "lat": "55.74815",
    "lng": "38.93511"
  },
  {
    "country": "RU",
    "name": "Kabakovo",
    "lat": "54.5369",
    "lng": "56.1517"
  },
  {
    "country": "RU",
    "name": "Izoplit",
    "lat": "56.62558",
    "lng": "36.22198"
  },
  {
    "country": "RU",
    "name": "Izobil’nyy",
    "lat": "45.37092",
    "lng": "41.70839"
  },
  {
    "country": "RU",
    "name": "Iznoski",
    "lat": "54.98806",
    "lng": "35.31083"
  },
  {
    "country": "RU",
    "name": "Izmaylovo",
    "lat": "55.78677",
    "lng": "37.80165"
  },
  {
    "country": "RU",
    "name": "Izmaylovo",
    "lat": "53.72114",
    "lng": "47.24581"
  },
  {
    "country": "RU",
    "name": "Izmalkovo",
    "lat": "52.6887",
    "lng": "37.96398"
  },
  {
    "country": "RU",
    "name": "Izhma",
    "lat": "65.00833",
    "lng": "53.91128"
  },
  {
    "country": "RU",
    "name": "Izhevskoye",
    "lat": "54.557",
    "lng": "40.8753"
  },
  {
    "country": "RU",
    "name": "Izhevsk",
    "lat": "56.84976",
    "lng": "53.20448"
  },
  {
    "country": "RU",
    "name": "Izborsk",
    "lat": "57.70757",
    "lng": "27.86291"
  },
  {
    "country": "RU",
    "name": "Izberbash",
    "lat": "42.56955",
    "lng": "47.86447"
  },
  {
    "country": "RU",
    "name": "Ivot",
    "lat": "53.67556",
    "lng": "34.18722"
  },
  {
    "country": "RU",
    "name": "Ivnya",
    "lat": "51.06294",
    "lng": "36.13426"
  },
  {
    "country": "RU",
    "name": "Ivanteyevka",
    "lat": "55.97111",
    "lng": "37.92083"
  },
  {
    "country": "RU",
    "name": "Ivanteyevka",
    "lat": "52.2667",
    "lng": "49.1055"
  },
  {
    "country": "RU",
    "name": "Ivanovskoye",
    "lat": "55.76667",
    "lng": "37.83333"
  },
  {
    "country": "RU",
    "name": "Ivanovskoye",
    "lat": "44.5795",
    "lng": "41.8764"
  },
  {
    "country": "RU",
    "name": "Ivanovo",
    "lat": "56.99719",
    "lng": "40.97139"
  },
  {
    "country": "RU",
    "name": "Ivanishchi",
    "lat": "55.77417",
    "lng": "40.42731"
  },
  {
    "country": "RU",
    "name": "Ivanino",
    "lat": "51.6434",
    "lng": "35.5769"
  },
  {
    "country": "RU",
    "name": "Ivangorod",
    "lat": "59.37155",
    "lng": "28.21625"
  },
  {
    "country": "RU",
    "name": "Itum-Kali",
    "lat": "42.73557",
    "lng": "45.57576"
  },
  {
    "country": "RU",
    "name": "Isyangulovo",
    "lat": "52.18584",
    "lng": "56.58043"
  },
  {
    "country": "RU",
    "name": "Istra",
    "lat": "55.91997",
    "lng": "36.86867"
  },
  {
    "country": "RU",
    "name": "Issad",
    "lat": "60.06743",
    "lng": "32.34331"
  },
  {
    "country": "RU",
    "name": "Issa",
    "lat": "53.87049",
    "lng": "44.85781"
  },
  {
    "country": "RU",
    "name": "Ispravnaya",
    "lat": "44.0682",
    "lng": "41.6102"
  },
  {
    "country": "RU",
    "name": "Ishnya",
    "lat": "57.1907",
    "lng": "39.36004"
  },
  {
    "country": "RU",
    "name": "Ishley",
    "lat": "56.02317",
    "lng": "47.05054"
  },
  {
    "country": "RU",
    "name": "Ishkhoy-Yurt",
    "lat": "43.21278",
    "lng": "46.38936"
  },
  {
    "country": "RU",
    "name": "Ishimbay",
    "lat": "53.45446",
    "lng": "56.04149"
  },
  {
    "country": "RU",
    "name": "Isheyevka",
    "lat": "54.42789",
    "lng": "48.26675"
  },
  {
    "country": "RU",
    "name": "Ishcherskaya",
    "lat": "43.71359",
    "lng": "45.13371"
  },
  {
    "country": "RU",
    "name": "Isakly",
    "lat": "54.13333",
    "lng": "51.53333"
  },
  {
    "country": "RU",
    "name": "Is",
    "lat": "58.7909",
    "lng": "59.7179"
  },
  {
    "country": "RU",
    "name": "Irkliyevskaya",
    "lat": "45.85635",
    "lng": "39.65381"
  },
  {
    "country": "RU",
    "name": "Irganay",
    "lat": "42.6465",
    "lng": "46.91154"
  },
  {
    "country": "RU",
    "name": "Irgakly",
    "lat": "44.36111",
    "lng": "44.75556"
  },
  {
    "country": "RU",
    "name": "Ipatovo",
    "lat": "45.71806",
    "lng": "42.90361"
  },
  {
    "country": "RU",
    "name": "Ostrovnoy",
    "lat": "68.05306",
    "lng": "39.51306"
  },
  {
    "country": "RU",
    "name": "Inzhavino",
    "lat": "52.31847",
    "lng": "42.49369"
  },
  {
    "country": "RU",
    "name": "Inzer",
    "lat": "54.2167",
    "lng": "57.5556"
  },
  {
    "country": "RU",
    "name": "Inza",
    "lat": "53.85672",
    "lng": "46.35622"
  },
  {
    "country": "RU",
    "name": "Insar",
    "lat": "53.86531",
    "lng": "44.37382"
  },
  {
    "country": "RU",
    "name": "Inozemtsevo",
    "lat": "44.09264",
    "lng": "43.09113"
  },
  {
    "country": "RU",
    "name": "Inderka",
    "lat": "53.24846",
    "lng": "46.25823"
  },
  {
    "country": "RU",
    "name": "Imeni Zhelyabova",
    "lat": "58.9544",
    "lng": "36.5956"
  },
  {
    "country": "RU",
    "name": "Imeni Vorovskogo",
    "lat": "55.7237",
    "lng": "41.119"
  },
  {
    "country": "RU",
    "name": "Imeni Vorovskogo",
    "lat": "55.7319",
    "lng": "38.32368"
  },
  {
    "country": "RU",
    "name": "Imeni Vladimira Il’icha Lenina",
    "lat": "53.56422",
    "lng": "46.9801"
  },
  {
    "country": "RU",
    "name": "Imeni Tsyurupy",
    "lat": "55.49567",
    "lng": "38.65064"
  },
  {
    "country": "RU",
    "name": "Imeni Sverdlova",
    "lat": "59.79611",
    "lng": "30.66583"
  },
  {
    "country": "RU",
    "name": "Imeni Stepana Razina",
    "lat": "54.8932",
    "lng": "44.29627"
  },
  {
    "country": "RU",
    "name": "Imeni Morozova",
    "lat": "59.97572",
    "lng": "31.03762"
  },
  {
    "country": "RU",
    "name": "Gereykhanovskoye",
    "lat": "41.7011",
    "lng": "48.28113"
  },
  {
    "country": "RU",
    "name": "Imeni Babushkina",
    "lat": "59.75727",
    "lng": "43.12847"
  },
  {
    "country": "RU",
    "name": "Il’skiy",
    "lat": "44.84222",
    "lng": "38.56686"
  },
  {
    "country": "RU",
    "name": "Ilovlya",
    "lat": "49.30334",
    "lng": "43.97965"
  },
  {
    "country": "RU",
    "name": "Ilovka",
    "lat": "50.7053",
    "lng": "38.637"
  },
  {
    "country": "RU",
    "name": "Il’inskoye-Khovanskoye",
    "lat": "56.9718",
    "lng": "39.7684"
  },
  {
    "country": "RU",
    "name": "Il’inskoye",
    "lat": "56.96667",
    "lng": "37.18333"
  },
  {
    "country": "RU",
    "name": "Il’inskoye",
    "lat": "56.92362",
    "lng": "28.52499"
  },
  {
    "country": "RU",
    "name": "Il’insko-Podomskoye",
    "lat": "61.11444",
    "lng": "47.97861"
  },
  {
    "country": "RU",
    "name": "Il’inskiy Pogost",
    "lat": "55.47785",
    "lng": "38.90906"
  },
  {
    "country": "RU",
    "name": "Il’inskiy",
    "lat": "55.61902",
    "lng": "38.11818"
  },
  {
    "country": "RU",
    "name": "Il’ichëvo",
    "lat": "60.26808",
    "lng": "29.7523"
  },
  {
    "country": "RU",
    "name": "Il’ich",
    "lat": "45.42488",
    "lng": "36.77402"
  },
  {
    "country": "RU",
    "name": "Ilek",
    "lat": "51.52709",
    "lng": "53.38306"
  },
  {
    "country": "RU",
    "name": "Iksha",
    "lat": "56.17204",
    "lng": "37.49842"
  },
  {
    "country": "RU",
    "name": "Ikryanoye",
    "lat": "46.09323",
    "lng": "47.73078"
  },
  {
    "country": "RU",
    "name": "Ikon-Khalk",
    "lat": "44.3051",
    "lng": "41.9142"
  },
  {
    "country": "RU",
    "name": "Iki-Burul",
    "lat": "45.82083",
    "lng": "44.64722"
  },
  {
    "country": "RU",
    "name": "Igra",
    "lat": "57.5549",
    "lng": "53.0544"
  },
  {
    "country": "RU",
    "name": "Ignatovka",
    "lat": "53.94787",
    "lng": "47.6536"
  },
  {
    "country": "RU",
    "name": "Iglino",
    "lat": "54.83244",
    "lng": "56.41264"
  },
  {
    "country": "RU",
    "name": "Idritsa",
    "lat": "56.33157",
    "lng": "28.89884"
  },
  {
    "country": "RU",
    "name": "Ibresi",
    "lat": "55.3011",
    "lng": "47.038"
  },
  {
    "country": "RU",
    "name": "Gzhel’",
    "lat": "55.61008",
    "lng": "38.39399"
  },
  {
    "country": "RU",
    "name": "Elin-Yurt",
    "lat": "43.67306",
    "lng": "44.95889"
  },
  {
    "country": "RU",
    "name": "Gvardeysk",
    "lat": "54.64772",
    "lng": "21.06513"
  },
  {
    "country": "RU",
    "name": "Gus’-Zheleznyy",
    "lat": "55.05811",
    "lng": "41.16556"
  },
  {
    "country": "RU",
    "name": "Gus’-Khrustal’nyy",
    "lat": "55.61113",
    "lng": "40.65186"
  },
  {
    "country": "RU",
    "name": "Gusevskiy",
    "lat": "55.66199",
    "lng": "40.56267"
  },
  {
    "country": "RU",
    "name": "Gusev",
    "lat": "54.59222",
    "lng": "22.19972"
  },
  {
    "country": "RU",
    "name": "Gur’yevsk",
    "lat": "54.77323",
    "lng": "20.60521"
  },
  {
    "country": "RU",
    "name": "Gurbuki",
    "lat": "42.61128",
    "lng": "47.60067"
  },
  {
    "country": "RU",
    "name": "Gunib",
    "lat": "42.38758",
    "lng": "46.96509"
  },
  {
    "country": "RU",
    "name": "Gundorovskiy",
    "lat": "46.78047",
    "lng": "41.8968"
  },
  {
    "country": "RU",
    "name": "Gundelen",
    "lat": "43.5975",
    "lng": "43.17194"
  },
  {
    "country": "RU",
    "name": "Gumrak",
    "lat": "48.78255",
    "lng": "44.3824"
  },
  {
    "country": "RU",
    "name": "Gul’kevichi",
    "lat": "45.35383",
    "lng": "40.69465"
  },
  {
    "country": "RU",
    "name": "Gukovo",
    "lat": "48.06212",
    "lng": "39.9355"
  },
  {
    "country": "RU",
    "name": "Gudermes",
    "lat": "43.35071",
    "lng": "46.10925"
  },
  {
    "country": "RU",
    "name": "Gubskaya",
    "lat": "44.31639",
    "lng": "40.63583"
  },
  {
    "country": "RU",
    "name": "Gubkin",
    "lat": "51.28167",
    "lng": "37.54583"
  },
  {
    "country": "RU",
    "name": "Gubden",
    "lat": "42.56808",
    "lng": "47.56579"
  },
  {
    "country": "RU",
    "name": "Gubakha",
    "lat": "58.83862",
    "lng": "57.55325"
  },
  {
    "country": "RU",
    "name": "Gryazovets",
    "lat": "58.88",
    "lng": "40.2525"
  },
  {
    "country": "RU",
    "name": "Gryazi",
    "lat": "52.49657",
    "lng": "39.93593"
  },
  {
    "country": "RU",
    "name": "Grushevskaya",
    "lat": "47.44056",
    "lng": "39.95111"
  },
  {
    "country": "RU",
    "name": "Martan-Chu",
    "lat": "43.06366",
    "lng": "45.56217"
  },
  {
    "country": "RU",
    "name": "Groznyy",
    "lat": "43.31195",
    "lng": "45.68895"
  },
  {
    "country": "RU",
    "name": "Grivenskaya",
    "lat": "45.6473",
    "lng": "38.17597"
  },
  {
    "country": "RU",
    "name": "Gritsovskiy",
    "lat": "54.13761",
    "lng": "38.16043"
  },
  {
    "country": "RU",
    "name": "Grigoropolisskaya",
    "lat": "45.29722",
    "lng": "41.05667"
  },
  {
    "country": "RU",
    "name": "Gribanovskiy",
    "lat": "51.45792",
    "lng": "41.97637"
  },
  {
    "country": "RU",
    "name": "Gremyachinsk",
    "lat": "58.5603",
    "lng": "57.851"
  },
  {
    "country": "RU",
    "name": "Grecheskoye",
    "lat": "44.43053",
    "lng": "43.0083"
  },
  {
    "country": "RU",
    "name": "Grebenskaya",
    "lat": "43.53086",
    "lng": "46.37174"
  },
  {
    "country": "RU",
    "name": "Grazhdanskoye",
    "lat": "44.23",
    "lng": "42.7698"
  },
  {
    "country": "RU",
    "name": "Grazhdanka",
    "lat": "60.03587",
    "lng": "30.40518"
  },
  {
    "country": "RU",
    "name": "Grayvoron",
    "lat": "50.4767",
    "lng": "35.6773"
  },
  {
    "country": "RU",
    "name": "Grakhovo",
    "lat": "56.05017",
    "lng": "51.96758"
  },
  {
    "country": "RU",
    "name": "Grabovo",
    "lat": "53.38751",
    "lng": "45.06395"
  },
  {
    "country": "RU",
    "name": "Goyty",
    "lat": "43.16417",
    "lng": "45.62278"
  },
  {
    "country": "RU",
    "name": "Gostilitsy",
    "lat": "59.74832",
    "lng": "29.62205"
  },
  {
    "country": "RU",
    "name": "Gostagayevskaya",
    "lat": "45.02284",
    "lng": "37.50511"
  },
  {
    "country": "RU",
    "name": "Goryachiy Klyuch",
    "lat": "44.63083",
    "lng": "39.13"
  },
  {
    "country": "RU",
    "name": "Goryachevodskiy",
    "lat": "44.02361",
    "lng": "43.09222"
  },
  {
    "country": "RU",
    "name": "Abram Mys",
    "lat": "68.97839",
    "lng": "33.01926"
  },
  {
    "country": "RU",
    "name": "Gorskaya",
    "lat": "60.0464",
    "lng": "29.97137"
  },
  {
    "country": "RU",
    "name": "Gorshechnoye",
    "lat": "51.5244",
    "lng": "38.0365"
  },
  {
    "country": "RU",
    "name": "Gorokhovets",
    "lat": "56.20152",
    "lng": "42.69351"
  },
  {
    "country": "RU",
    "name": "Gorodovikovsk",
    "lat": "46.08785",
    "lng": "41.93353"
  },
  {
    "country": "RU",
    "name": "Gorodoviki",
    "lat": "46.13528",
    "lng": "41.96556"
  },
  {
    "country": "RU",
    "name": "Gorodnya",
    "lat": "56.7055",
    "lng": "36.31793"
  },
  {
    "country": "RU",
    "name": "Gorodishche",
    "lat": "53.2775",
    "lng": "45.7017"
  },
  {
    "country": "RU",
    "name": "Gorodishche",
    "lat": "48.80454",
    "lng": "44.47439"
  },
  {
    "country": "RU",
    "name": "Gorodets",
    "lat": "56.65493",
    "lng": "43.47273"
  },
  {
    "country": "RU",
    "name": "Gornyy",
    "lat": "51.7578",
    "lng": "48.5413"
  },
  {
    "country": "RU",
    "name": "Gornyy",
    "lat": "47.81592",
    "lng": "40.20363"
  },
  {
    "country": "RU",
    "name": "Gornyatskiy",
    "lat": "48.29147",
    "lng": "40.9575"
  },
  {
    "country": "RU",
    "name": "Gornozavodsk",
    "lat": "58.37583",
    "lng": "58.32111"
  },
  {
    "country": "RU",
    "name": "Gorki Vtoryye",
    "lat": "55.72565",
    "lng": "37.1635"
  },
  {
    "country": "RU",
    "name": "Gorki-Leninskiye",
    "lat": "55.50855",
    "lng": "37.77618"
  },
  {
    "country": "RU",
    "name": "Goritsy",
    "lat": "59.86949",
    "lng": "38.26016"
  },
  {
    "country": "RU",
    "name": "Goreloye",
    "lat": "52.93697",
    "lng": "41.50435"
  },
  {
    "country": "RU",
    "name": "Gorelovo",
    "lat": "59.77234",
    "lng": "30.13455"
  },
  {
    "country": "RU",
    "name": "Gorelki",
    "lat": "54.25617",
    "lng": "37.6108"
  },
  {
    "country": "RU",
    "name": "Gordeyevka",
    "lat": "52.9569",
    "lng": "31.9703"
  },
  {
    "country": "RU",
    "name": "Gorbunki",
    "lat": "59.81307",
    "lng": "29.98478"
  },
  {
    "country": "RU",
    "name": "Gorbatovka",
    "lat": "56.25716",
    "lng": "43.74577"
  },
  {
    "country": "RU",
    "name": "Gorbatov",
    "lat": "56.1311",
    "lng": "43.06363"
  },
  {
    "country": "RU",
    "name": "Goragorskiy",
    "lat": "43.5002",
    "lng": "45.08574"
  },
  {
    "country": "RU",
    "name": "Golynki",
    "lat": "54.86964",
    "lng": "31.38609"
  },
  {
    "country": "RU",
    "name": "Gol’yanovo",
    "lat": "55.82299",
    "lng": "37.81306"
  },
  {
    "country": "RU",
    "name": "Golubitskaya",
    "lat": "45.32566",
    "lng": "37.2702"
  },
  {
    "country": "RU",
    "name": "Golovino",
    "lat": "55.96128",
    "lng": "40.42511"
  },
  {
    "country": "RU",
    "name": "Golovchino",
    "lat": "50.5341",
    "lng": "35.797"
  },
  {
    "country": "RU",
    "name": "Golitsyno",
    "lat": "55.60928",
    "lng": "36.98212"
  },
  {
    "country": "RU",
    "name": "Gagatli",
    "lat": "42.8013",
    "lng": "46.29162"
  },
  {
    "country": "RU",
    "name": "Gofitskoye",
    "lat": "45.07917",
    "lng": "43.04639"
  },
  {
    "country": "RU",
    "name": "Glushkovo",
    "lat": "51.33917",
    "lng": "34.63278"
  },
  {
    "country": "RU",
    "name": "Glubokoye",
    "lat": "56.6089",
    "lng": "29.02066"
  },
  {
    "country": "RU",
    "name": "Glubokiy",
    "lat": "48.52716",
    "lng": "40.33144"
  },
  {
    "country": "RU",
    "name": "Glubokiy",
    "lat": "44.94673",
    "lng": "41.01845"
  },
  {
    "country": "RU",
    "name": "Glotovka",
    "lat": "53.94906",
    "lng": "46.70422"
  },
  {
    "country": "RU",
    "name": "Glinka",
    "lat": "54.64043",
    "lng": "32.87811"
  },
  {
    "country": "RU",
    "name": "Glinishchevo",
    "lat": "53.30416",
    "lng": "34.06523"
  },
  {
    "country": "RU",
    "name": "Glembochino",
    "lat": "56.18758",
    "lng": "28.3785"
  },
  {
    "country": "RU",
    "name": "Glebychevo",
    "lat": "60.43868",
    "lng": "28.71826"
  },
  {
    "country": "RU",
    "name": "Glazunovka",
    "lat": "52.50057",
    "lng": "36.31997"
  },
  {
    "country": "RU",
    "name": "Glazov",
    "lat": "58.1393",
    "lng": "52.658"
  },
  {
    "country": "RU",
    "name": "Glafirovka",
    "lat": "46.76378",
    "lng": "38.40785"
  },
  {
    "country": "RU",
    "name": "Gizel’",
    "lat": "43.04",
    "lng": "44.57083"
  },
  {
    "country": "RU",
    "name": "Girvas",
    "lat": "62.47962",
    "lng": "33.68482"
  },
  {
    "country": "RU",
    "name": "Girey",
    "lat": "45.4012",
    "lng": "40.6587"
  },
  {
    "country": "RU",
    "name": "Gimry",
    "lat": "42.75974",
    "lng": "46.83959"
  },
  {
    "country": "RU",
    "name": "Gigant",
    "lat": "46.50665",
    "lng": "41.34185"
  },
  {
    "country": "RU",
    "name": "Gidrotorf",
    "lat": "56.47562",
    "lng": "43.53813"
  },
  {
    "country": "RU",
    "name": "Giaginskaya",
    "lat": "44.86208",
    "lng": "40.07195"
  },
  {
    "country": "RU",
    "name": "Gerzel’-Aul",
    "lat": "43.24728",
    "lng": "46.40249"
  },
  {
    "country": "RU",
    "name": "Germenchuk",
    "lat": "43.1857",
    "lng": "45.921"
  },
  {
    "country": "RU",
    "name": "Germenchik",
    "lat": "43.59389",
    "lng": "43.76611"
  },
  {
    "country": "RU",
    "name": "Gergebil’",
    "lat": "42.50472",
    "lng": "47.06611"
  },
  {
    "country": "RU",
    "name": "Georgiyevskoye",
    "lat": "58.73101",
    "lng": "45.02404"
  },
  {
    "country": "RU",
    "name": "Georgiyevskaya",
    "lat": "44.11139",
    "lng": "43.49222"
  },
  {
    "country": "RU",
    "name": "Georgiyevsk",
    "lat": "44.15194",
    "lng": "43.46972"
  },
  {
    "country": "RU",
    "name": "Georgiyevka",
    "lat": "53.27438",
    "lng": "50.99848"
  },
  {
    "country": "RU",
    "name": "Gelendzhik",
    "lat": "44.5622",
    "lng": "38.0848"
  },
  {
    "country": "RU",
    "name": "Gekhi",
    "lat": "43.16354",
    "lng": "45.47238"
  },
  {
    "country": "RU",
    "name": "Gdov",
    "lat": "58.74424",
    "lng": "27.81977"
  },
  {
    "country": "RU",
    "name": "Gayny",
    "lat": "60.30707",
    "lng": "54.32412"
  },
  {
    "country": "RU",
    "name": "Gayduk",
    "lat": "44.78489",
    "lng": "37.7005"
  },
  {
    "country": "RU",
    "name": "Gay",
    "lat": "51.4666",
    "lng": "58.4552"
  },
  {
    "country": "RU",
    "name": "Gavrilov-Yam",
    "lat": "57.30185",
    "lng": "39.85331"
  },
  {
    "country": "RU",
    "name": "Gavrilov Posad",
    "lat": "56.5593",
    "lng": "40.121"
  },
  {
    "country": "RU",
    "name": "Gavrilovka Vtoraya",
    "lat": "52.87697",
    "lng": "42.76633"
  },
  {
    "country": "RU",
    "name": "Gatchina",
    "lat": "59.57639",
    "lng": "30.12833"
  },
  {
    "country": "RU",
    "name": "Garbolovo",
    "lat": "60.34127",
    "lng": "30.49551"
  },
  {
    "country": "RU",
    "name": "Gaptsakh",
    "lat": "41.45174",
    "lng": "47.93027"
  },
  {
    "country": "RU",
    "name": "Gamovo",
    "lat": "57.8652",
    "lng": "56.1056"
  },
  {
    "country": "RU",
    "name": "Galyugayevskaya",
    "lat": "43.69694",
    "lng": "44.93444"
  },
  {
    "country": "RU",
    "name": "Galitsy",
    "lat": "56.17759",
    "lng": "42.84588"
  },
  {
    "country": "RU",
    "name": "Galich",
    "lat": "58.37884",
    "lng": "42.34633"
  },
  {
    "country": "RU",
    "name": "Gagino",
    "lat": "55.23142",
    "lng": "45.03386"
  },
  {
    "country": "RU",
    "name": "Gagarin",
    "lat": "55.55291",
    "lng": "34.99537"
  },
  {
    "country": "RU",
    "name": "Gadzhiyevo",
    "lat": "69.25506",
    "lng": "33.33616"
  },
  {
    "country": "RU",
    "name": "Furmanov",
    "lat": "57.25363",
    "lng": "41.10849"
  },
  {
    "country": "RU",
    "name": "Fryazino",
    "lat": "55.96056",
    "lng": "38.04556"
  },
  {
    "country": "RU",
    "name": "Fryazevo",
    "lat": "55.73321",
    "lng": "38.46458"
  },
  {
    "country": "RU",
    "name": "Fryanovo",
    "lat": "56.13333",
    "lng": "38.45"
  },
  {
    "country": "RU",
    "name": "Froly",
    "lat": "57.9214",
    "lng": "56.2728"
  },
  {
    "country": "RU",
    "name": "Frolovo",
    "lat": "49.77133",
    "lng": "43.66222"
  },
  {
    "country": "RU",
    "name": "Frolishchi",
    "lat": "56.42177",
    "lng": "42.65187"
  },
  {
    "country": "RU",
    "name": "Fosforitnyy",
    "lat": "55.32892",
    "lng": "38.89509"
  },
  {
    "country": "RU",
    "name": "Fornosovo",
    "lat": "59.56889",
    "lng": "30.55444"
  },
  {
    "country": "RU",
    "name": "Foki",
    "lat": "56.693",
    "lng": "54.34985"
  },
  {
    "country": "RU",
    "name": "Firsanovka",
    "lat": "55.95361",
    "lng": "37.24083"
  },
  {
    "country": "RU",
    "name": "Firovo",
    "lat": "57.48135",
    "lng": "33.70211"
  },
  {
    "country": "RU",
    "name": "Filimonki",
    "lat": "55.55794",
    "lng": "37.34719"
  },
  {
    "country": "RU",
    "name": "Fili",
    "lat": "55.74819",
    "lng": "37.47969"
  },
  {
    "country": "RU",
    "name": "Ferzikovo",
    "lat": "54.51913",
    "lng": "36.75671"
  },
  {
    "country": "RU",
    "name": "Fershampenuaz",
    "lat": "53.5202",
    "lng": "59.8117"
  },
  {
    "country": "RU",
    "name": "Ferapontovo",
    "lat": "59.95425",
    "lng": "38.56745"
  },
  {
    "country": "RU",
    "name": "Fedurnovo",
    "lat": "55.75488",
    "lng": "38.04696"
  },
  {
    "country": "RU",
    "name": "Fëdorovskoye",
    "lat": "59.66306",
    "lng": "30.53222"
  },
  {
    "country": "RU",
    "name": "Fatezh",
    "lat": "52.0891",
    "lng": "35.8632"
  },
  {
    "country": "RU",
    "name": "Fastovetskaya",
    "lat": "45.91889",
    "lng": "40.15889"
  },
  {
    "country": "RU",
    "name": "Falënki",
    "lat": "58.36127",
    "lng": "51.59461"
  },
  {
    "country": "RU",
    "name": "Fakel",
    "lat": "57.631",
    "lng": "53.0251"
  },
  {
    "country": "RU",
    "name": "Ezhva",
    "lat": "61.81281",
    "lng": "50.72834"
  },
  {
    "country": "RU",
    "name": "Etoka",
    "lat": "43.91944",
    "lng": "43.04833"
  },
  {
    "country": "RU",
    "name": "Essoyla",
    "lat": "61.86983",
    "lng": "33.14901"
  },
  {
    "country": "RU",
    "name": "Ertil’",
    "lat": "51.84056",
    "lng": "40.80556"
  },
  {
    "country": "RU",
    "name": "Erpeli",
    "lat": "42.80584",
    "lng": "46.97732"
  },
  {
    "country": "RU",
    "name": "Engel’-Yurt",
    "lat": "43.32633",
    "lng": "46.36048"
  },
  {
    "country": "RU",
    "name": "Engel’s",
    "lat": "51.48389",
    "lng": "46.10528"
  },
  {
    "country": "RU",
    "name": "Energetik",
    "lat": "51.7445",
    "lng": "58.7934"
  },
  {
    "country": "RU",
    "name": "Enem",
    "lat": "44.9264",
    "lng": "38.90584"
  },
  {
    "country": "RU",
    "name": "Emmaus",
    "lat": "56.78055",
    "lng": "36.115"
  },
  {
    "country": "RU",
    "name": "El’ton",
    "lat": "49.1273",
    "lng": "46.84703"
  },
  {
    "country": "RU",
    "name": "Elista",
    "lat": "46.30778",
    "lng": "44.25583"
  },
  {
    "country": "RU",
    "name": "Elektrougli",
    "lat": "55.72445",
    "lng": "38.20908"
  },
  {
    "country": "RU",
    "name": "Elektrostal’",
    "lat": "55.78959",
    "lng": "38.44671"
  },
  {
    "country": "RU",
    "name": "Elektrogorsk",
    "lat": "55.88431",
    "lng": "38.7864"
  },
  {
    "country": "RU",
    "name": "El’brus",
    "lat": "43.25771",
    "lng": "42.64435"
  },
  {
    "country": "RU",
    "name": "Ekazhevo",
    "lat": "43.21222",
    "lng": "44.82306"
  },
  {
    "country": "RU",
    "name": "Edissiya",
    "lat": "44.05111",
    "lng": "44.54083"
  },
  {
    "country": "RU",
    "name": "Dzhubga",
    "lat": "44.3211",
    "lng": "38.7073"
  },
  {
    "country": "RU",
    "name": "Dzhiginka",
    "lat": "45.133",
    "lng": "37.33825"
  },
  {
    "country": "RU",
    "name": "Dzhayrakh",
    "lat": "42.82043",
    "lng": "44.68139"
  },
  {
    "country": "RU",
    "name": "Dzhalka",
    "lat": "43.3186",
    "lng": "45.98787"
  },
  {
    "country": "RU",
    "name": "Dzhalil’",
    "lat": "55.0239",
    "lng": "52.7358"
  },
  {
    "country": "RU",
    "name": "Dzerzhinskiy",
    "lat": "55.62945",
    "lng": "37.85654"
  },
  {
    "country": "RU",
    "name": "Dzerzhinsk",
    "lat": "56.24143",
    "lng": "43.45539"
  },
  {
    "country": "RU",
    "name": "Dyurtyuli",
    "lat": "55.49106",
    "lng": "54.86883"
  },
  {
    "country": "RU",
    "name": "Dyshne-Vedeno",
    "lat": "42.96435",
    "lng": "46.11578"
  },
  {
    "country": "RU",
    "name": "Dylym",
    "lat": "43.07099",
    "lng": "46.63454"
  },
  {
    "country": "RU",
    "name": "Dyat’kovo",
    "lat": "53.59782",
    "lng": "34.33825"
  },
  {
    "country": "RU",
    "name": "Dvortsy",
    "lat": "54.61677",
    "lng": "35.9974"
  },
  {
    "country": "RU",
    "name": "Dvinskoy",
    "lat": "62.1519",
    "lng": "45.1184"
  },
  {
    "country": "RU",
    "name": "Duvan",
    "lat": "55.69497",
    "lng": "57.90237"
  },
  {
    "country": "RU",
    "name": "Dorgeli",
    "lat": "42.667",
    "lng": "47.29435"
  },
  {
    "country": "RU",
    "name": "Duminichi",
    "lat": "53.93446",
    "lng": "35.10993"
  },
  {
    "country": "RU",
    "name": "Dulyapino",
    "lat": "57.25783",
    "lng": "40.81471"
  },
  {
    "country": "RU",
    "name": "Dukhovshchina",
    "lat": "55.1919",
    "lng": "32.4111"
  },
  {
    "country": "RU",
    "name": "Dukhovnitskoye",
    "lat": "52.4828",
    "lng": "48.2137"
  },
  {
    "country": "RU",
    "name": "Dubrovka",
    "lat": "59.22866",
    "lng": "51.15578"
  },
  {
    "country": "RU",
    "name": "Dubrovka",
    "lat": "56.39101",
    "lng": "28.6385"
  },
  {
    "country": "RU",
    "name": "Dubrovka",
    "lat": "53.6907",
    "lng": "33.5071"
  },
  {
    "country": "RU",
    "name": "Dubrovitsy",
    "lat": "55.43969",
    "lng": "37.4867"
  },
  {
    "country": "RU",
    "name": "Dubovyy Umët",
    "lat": "52.97629",
    "lng": "50.28569"
  },
  {
    "country": "RU",
    "name": "Dubovskoye",
    "lat": "47.4142",
    "lng": "42.7697"
  },
  {
    "country": "RU",
    "name": "Dubovka",
    "lat": "49.05825",
    "lng": "44.829"
  },
  {
    "country": "RU",
    "name": "Dubna",
    "lat": "56.73333",
    "lng": "37.16667"
  },
  {
    "country": "RU",
    "name": "Dubna",
    "lat": "54.15416",
    "lng": "36.96173"
  },
  {
    "country": "RU",
    "name": "Dubki",
    "lat": "57.3",
    "lng": "40.25"
  },
  {
    "country": "RU",
    "name": "Dubki",
    "lat": "43.02116",
    "lng": "46.83746"
  },
  {
    "country": "RU",
    "name": "Duba-Yurt",
    "lat": "43.03534",
    "lng": "45.73046"
  },
  {
    "country": "RU",
    "name": "Druzhnaya Gorka",
    "lat": "59.28018",
    "lng": "30.12709"
  },
  {
    "country": "RU",
    "name": "Druzhinino",
    "lat": "56.78945",
    "lng": "59.51428"
  },
  {
    "country": "RU",
    "name": "Druzhba",
    "lat": "55.88603",
    "lng": "37.74267"
  },
  {
    "country": "RU",
    "name": "Druzhba",
    "lat": "44.1953",
    "lng": "42.017"
  },
  {
    "country": "RU",
    "name": "Drezna",
    "lat": "55.74208",
    "lng": "38.84753"
  },
  {
    "country": "RU",
    "name": "Drakino",
    "lat": "51.13898",
    "lng": "39.40215"
  },
  {
    "country": "RU",
    "name": "Doschatoye",
    "lat": "55.3886",
    "lng": "42.1032"
  },
  {
    "country": "RU",
    "name": "Dorokhovo",
    "lat": "55.55056",
    "lng": "36.37444"
  },
  {
    "country": "RU",
    "name": "Dorogomilovo",
    "lat": "55.75",
    "lng": "37.56667"
  },
  {
    "country": "RU",
    "name": "Dorogobuzh",
    "lat": "54.915",
    "lng": "33.29722"
  },
  {
    "country": "RU",
    "name": "Donskoye",
    "lat": "52.77495",
    "lng": "41.47759"
  },
  {
    "country": "RU",
    "name": "Donskoye",
    "lat": "52.6174",
    "lng": "38.9738"
  },
  {
    "country": "RU",
    "name": "Donskoye",
    "lat": "45.45518",
    "lng": "41.97411"
  },
  {
    "country": "RU",
    "name": "Donskoy",
    "lat": "53.97106",
    "lng": "38.33627"
  },
  {
    "country": "RU",
    "name": "Donskoy",
    "lat": "47.41404",
    "lng": "40.25742"
  },
  {
    "country": "RU",
    "name": "Donetsk",
    "lat": "48.33962",
    "lng": "39.95948"
  },
  {
    "country": "RU",
    "name": "Dondukovskaya",
    "lat": "44.8819",
    "lng": "40.36271"
  },
  {
    "country": "RU",
    "name": "Domodedovo",
    "lat": "55.4413",
    "lng": "37.75367"
  },
  {
    "country": "RU",
    "name": "Dombarovskiy",
    "lat": "50.7587",
    "lng": "59.5386"
  },
  {
    "country": "RU",
    "name": "Dolzhanskaya",
    "lat": "46.63369",
    "lng": "37.80246"
  },
  {
    "country": "RU",
    "name": "Dolgorukovo",
    "lat": "52.31945",
    "lng": "38.34527"
  },
  {
    "country": "RU",
    "name": "Dolgoprudnyy",
    "lat": "55.94958",
    "lng": "37.50183"
  },
  {
    "country": "RU",
    "name": "Dobryatino",
    "lat": "55.5055",
    "lng": "41.3195"
  },
  {
    "country": "RU",
    "name": "Dobryanka",
    "lat": "58.4644",
    "lng": "56.4127"
  },
  {
    "country": "RU",
    "name": "Dobrun’",
    "lat": "53.18512",
    "lng": "34.24625"
  },
  {
    "country": "RU",
    "name": "Dobroye",
    "lat": "52.8678",
    "lng": "39.8109"
  },
  {
    "country": "RU",
    "name": "Dobrinka",
    "lat": "52.16528",
    "lng": "40.47306"
  },
  {
    "country": "RU",
    "name": "Dno",
    "lat": "57.82772",
    "lng": "29.96368"
  },
  {
    "country": "RU",
    "name": "Dneprovskaya",
    "lat": "45.62359",
    "lng": "38.80807"
  },
  {
    "country": "RU",
    "name": "Dmitrovsk-Orlovskiy",
    "lat": "52.505",
    "lng": "35.1464"
  },
  {
    "country": "RU",
    "name": "Dmitrovskiy Pogost",
    "lat": "55.31333",
    "lng": "39.83358"
  },
  {
    "country": "RU",
    "name": "Dmitrov",
    "lat": "56.34485",
    "lng": "37.52041"
  },
  {
    "country": "RU",
    "name": "Dmitriyevskoye",
    "lat": "45.80529",
    "lng": "41.89667"
  },
  {
    "country": "RU",
    "name": "Dmitriyevskaya",
    "lat": "45.65639",
    "lng": "40.76528"
  },
  {
    "country": "RU",
    "name": "Dmitriyevka",
    "lat": "54.75",
    "lng": "55.33333"
  },
  {
    "country": "RU",
    "name": "Divnoye",
    "lat": "45.90889",
    "lng": "43.35472"
  },
  {
    "country": "RU",
    "name": "Divnomorskoye",
    "lat": "44.5017",
    "lng": "38.1342"
  },
  {
    "country": "RU",
    "name": "Diveyevo",
    "lat": "55.04329",
    "lng": "43.24178"
  },
  {
    "country": "RU",
    "name": "Dinskaya",
    "lat": "45.21516",
    "lng": "39.2265"
  },
  {
    "country": "RU",
    "name": "Dimitrovgrad",
    "lat": "54.21386",
    "lng": "49.61838"
  },
  {
    "country": "RU",
    "name": "Digora",
    "lat": "43.15806",
    "lng": "44.15694"
  },
  {
    "country": "RU",
    "name": "Deyskoye",
    "lat": "43.47546",
    "lng": "44.16182"
  },
  {
    "country": "RU",
    "name": "Devitsa",
    "lat": "51.6352",
    "lng": "38.945"
  },
  {
    "country": "RU",
    "name": "Detchino",
    "lat": "54.80923",
    "lng": "36.3075"
  },
  {
    "country": "RU",
    "name": "Desnogorsk",
    "lat": "54.15077",
    "lng": "33.28151"
  },
  {
    "country": "RU",
    "name": "Deshovki",
    "lat": "54.00333",
    "lng": "35.78771"
  },
  {
    "country": "RU",
    "name": "Dergachi",
    "lat": "51.2328",
    "lng": "48.7659"
  },
  {
    "country": "RU",
    "name": "Derbent",
    "lat": "42.06779",
    "lng": "48.28987"
  },
  {
    "country": "RU",
    "name": "Demyansk",
    "lat": "57.64301",
    "lng": "32.466"
  },
  {
    "country": "RU",
    "name": "Dem’yanovo",
    "lat": "60.35111",
    "lng": "47.08417"
  },
  {
    "country": "RU",
    "name": "Demikhovo",
    "lat": "55.79685",
    "lng": "38.88404"
  },
  {
    "country": "RU",
    "name": "Demidov",
    "lat": "55.27063",
    "lng": "31.51497"
  },
  {
    "country": "RU",
    "name": "Dedovsk",
    "lat": "55.86861",
    "lng": "37.12222"
  },
  {
    "country": "RU",
    "name": "Dedovichi",
    "lat": "57.55166",
    "lng": "29.95018"
  },
  {
    "country": "RU",
    "name": "Dedino",
    "lat": "56.24461",
    "lng": "28.25059"
  },
  {
    "country": "RU",
    "name": "Dedenëvo",
    "lat": "56.24283",
    "lng": "37.51769"
  },
  {
    "country": "RU",
    "name": "Debesy",
    "lat": "57.6515",
    "lng": "53.8089"
  },
  {
    "country": "RU",
    "name": "Davydovo",
    "lat": "55.60859",
    "lng": "38.86109"
  },
  {
    "country": "RU",
    "name": "Davydovka",
    "lat": "51.15781",
    "lng": "39.42915"
  },
  {
    "country": "RU",
    "name": "Davydkovo",
    "lat": "55.71815",
    "lng": "37.47271"
  },
  {
    "country": "RU",
    "name": "Davlekanovo",
    "lat": "54.22145",
    "lng": "55.03434"
  },
  {
    "country": "RU",
    "name": "Darovskoy",
    "lat": "58.76999",
    "lng": "47.95642"
  },
  {
    "country": "RU",
    "name": "Dankov",
    "lat": "53.25155",
    "lng": "39.15553"
  },
  {
    "country": "RU",
    "name": "Danki",
    "lat": "54.91806",
    "lng": "37.57009"
  },
  {
    "country": "RU",
    "name": "Danilovka",
    "lat": "50.35573",
    "lng": "44.11681"
  },
  {
    "country": "RU",
    "name": "Danilov",
    "lat": "58.1908",
    "lng": "40.17171"
  },
  {
    "country": "RU",
    "name": "Dal’neye Konstantinovo",
    "lat": "55.81025",
    "lng": "44.09595"
  },
  {
    "country": "RU",
    "name": "Dalakovo",
    "lat": "43.23759",
    "lng": "44.58964"
  },
  {
    "country": "RU",
    "name": "Dagestanskiye Ogni",
    "lat": "42.11589",
    "lng": "48.19204"
  },
  {
    "country": "RU",
    "name": "Dachnoye",
    "lat": "59.84167",
    "lng": "30.25583"
  },
  {
    "country": "RU",
    "name": "Dachnoye",
    "lat": "43.08468",
    "lng": "44.7358"
  },
  {
    "country": "RU",
    "name": "Chusovoy",
    "lat": "58.3013",
    "lng": "57.8131"
  },
  {
    "country": "RU",
    "name": "Churovichi",
    "lat": "52.1693",
    "lng": "31.9926"
  },
  {
    "country": "RU",
    "name": "Chupa",
    "lat": "66.27001",
    "lng": "33.05486"
  },
  {
    "country": "RU",
    "name": "Chukhloma",
    "lat": "58.75375",
    "lng": "42.68318"
  },
  {
    "country": "RU",
    "name": "Chufarovo",
    "lat": "54.0963",
    "lng": "47.3367"
  },
  {
    "country": "RU",
    "name": "Chudovo",
    "lat": "59.11667",
    "lng": "31.68333"
  },
  {
    "country": "RU",
    "name": "Chuchkovo",
    "lat": "54.26931",
    "lng": "41.44648"
  },
  {
    "country": "RU",
    "name": "Chontaul",
    "lat": "43.30481",
    "lng": "46.85967"
  },
  {
    "country": "RU",
    "name": "Chkalovskiy",
    "lat": "55.89534",
    "lng": "38.07763"
  },
  {
    "country": "RU",
    "name": "Chkalovsk",
    "lat": "56.76776",
    "lng": "43.25135"
  },
  {
    "country": "RU",
    "name": "Chistoye",
    "lat": "56.53753",
    "lng": "43.00445"
  },
  {
    "country": "RU",
    "name": "Chistopol’",
    "lat": "55.36311",
    "lng": "50.64244"
  },
  {
    "country": "RU",
    "name": "Chishmy",
    "lat": "54.57648",
    "lng": "55.37642"
  },
  {
    "country": "RU",
    "name": "Chirkey",
    "lat": "42.96131",
    "lng": "46.97866"
  },
  {
    "country": "RU",
    "name": "Chiri-Yurt",
    "lat": "43.08869",
    "lng": "45.74323"
  },
  {
    "country": "RU",
    "name": "Chikola",
    "lat": "43.19055",
    "lng": "43.92093"
  },
  {
    "country": "RU",
    "name": "Chesnokovka",
    "lat": "54.61242",
    "lng": "55.94575"
  },
  {
    "country": "RU",
    "name": "Cherusti",
    "lat": "55.54976",
    "lng": "40.01071"
  },
  {
    "country": "RU",
    "name": "Chertkovo",
    "lat": "49.38451",
    "lng": "40.14723"
  },
  {
    "country": "RU",
    "name": "Chyorny Yar",
    "lat": "48.06242",
    "lng": "46.10911"
  },
  {
    "country": "RU",
    "name": "Chernyshkovskiy",
    "lat": "48.42188",
    "lng": "42.23083"
  },
  {
    "country": "RU",
    "name": "Chernyanka",
    "lat": "50.94095",
    "lng": "37.80693"
  },
  {
    "country": "RU",
    "name": "Chernyakhovsk",
    "lat": "54.63345",
    "lng": "21.81557"
  },
  {
    "country": "RU",
    "name": "Chernushka",
    "lat": "56.50722",
    "lng": "56.07661"
  },
  {
    "country": "RU",
    "name": "Chernukha",
    "lat": "55.59739",
    "lng": "43.7556"
  },
  {
    "country": "RU",
    "name": "Chernoyerkovskaya",
    "lat": "45.43306",
    "lng": "37.76861"
  },
  {
    "country": "RU",
    "name": "Chernomorskiy",
    "lat": "44.85056",
    "lng": "38.49361"
  },
  {
    "country": "RU",
    "name": "Chernolesskoye",
    "lat": "44.71556",
    "lng": "43.71333"
  },
  {
    "country": "RU",
    "name": "Chernoistochinsk",
    "lat": "57.73639",
    "lng": "59.87194"
  },
  {
    "country": "RU",
    "name": "Chernogolovka",
    "lat": "56",
    "lng": "38.36667"
  },
  {
    "country": "RU",
    "name": "Chernitsyno",
    "lat": "51.50739",
    "lng": "36.05101"
  },
  {
    "country": "RU",
    "name": "Cherneya",
    "lat": "56.24975",
    "lng": "28.54256"
  },
  {
    "country": "RU",
    "name": "Chërnaya Kholunitsa",
    "lat": "58.85115",
    "lng": "51.71545"
  },
  {
    "country": "RU",
    "name": "Chornoye",
    "lat": "55.74611",
    "lng": "38.06889"
  },
  {
    "country": "RU",
    "name": "Chern’",
    "lat": "53.45232",
    "lng": "36.9145"
  },
  {
    "country": "RU",
    "name": "Chermoz",
    "lat": "58.7813",
    "lng": "56.1577"
  },
  {
    "country": "RU",
    "name": "Chermen",
    "lat": "43.14861",
    "lng": "44.70694"
  },
  {
    "country": "RU",
    "name": "Cherkizovo",
    "lat": "55.97583",
    "lng": "37.7875"
  },
  {
    "country": "RU",
    "name": "Cherkessk",
    "lat": "44.22333",
    "lng": "42.05778"
  },
  {
    "country": "RU",
    "name": "Cherkasskoye",
    "lat": "52.42895",
    "lng": "47.21048"
  },
  {
    "country": "RU",
    "name": "Cherepovets",
    "lat": "59.13333",
    "lng": "37.9"
  },
  {
    "country": "RU",
    "name": "Cherepet’",
    "lat": "54.11784",
    "lng": "36.37877"
  },
  {
    "country": "RU",
    "name": "Cheremushskiy",
    "lat": "61.27306",
    "lng": "47.26361"
  },
  {
    "country": "RU",
    "name": "Cherëmushki",
    "lat": "55.66473",
    "lng": "37.56135"
  },
  {
    "country": "RU",
    "name": "Cherëmukhovo",
    "lat": "60.34842",
    "lng": "59.98507"
  },
  {
    "country": "RU",
    "name": "Cheremshan",
    "lat": "54.66667",
    "lng": "51.5"
  },
  {
    "country": "RU",
    "name": "Cheremisinovo",
    "lat": "51.8855",
    "lng": "37.2646"
  },
  {
    "country": "RU",
    "name": "Cherdyn’",
    "lat": "60.40295",
    "lng": "56.47868"
  },
  {
    "country": "RU",
    "name": "Cherdakly",
    "lat": "54.3594",
    "lng": "48.84497"
  },
  {
    "country": "RU",
    "name": "Chemodanovka",
    "lat": "53.23162",
    "lng": "45.24738"
  },
  {
    "country": "RU",
    "name": "Chelno-Vershiny",
    "lat": "54.4148",
    "lng": "51.08594"
  },
  {
    "country": "RU",
    "name": "Chelbasskaya",
    "lat": "45.97924",
    "lng": "39.37186"
  },
  {
    "country": "RU",
    "name": "Chekmagush",
    "lat": "55.13194",
    "lng": "54.65556"
  },
  {
    "country": "RU",
    "name": "Chekhov",
    "lat": "55.1477",
    "lng": "37.47728"
  },
  {
    "country": "RU",
    "name": "Chekalin",
    "lat": "54.09685",
    "lng": "36.24499"
  },
  {
    "country": "RU",
    "name": "Chegem Vtoroy",
    "lat": "43.59583",
    "lng": "43.59944"
  },
  {
    "country": "RU",
    "name": "Chegem",
    "lat": "43.28333",
    "lng": "43.13333"
  },
  {
    "country": "RU",
    "name": "Chechen-Aul",
    "lat": "43.2",
    "lng": "45.78889"
  },
  {
    "country": "RU",
    "name": "Chebsara",
    "lat": "59.20016",
    "lng": "38.83556"
  },
  {
    "country": "RU",
    "name": "Cheboksary",
    "lat": "56.13222",
    "lng": "47.25194"
  },
  {
    "country": "RU",
    "name": "Chaykovskiy",
    "lat": "56.76864",
    "lng": "54.11484"
  },
  {
    "country": "RU",
    "name": "Chaykovskaya",
    "lat": "58.1288",
    "lng": "55.5352"
  },
  {
    "country": "RU",
    "name": "Chastyye",
    "lat": "57.28876",
    "lng": "54.97278"
  },
  {
    "country": "RU",
    "name": "Chashnikovo",
    "lat": "56.03333",
    "lng": "37.16667"
  },
  {
    "country": "RU",
    "name": "Chaplygin",
    "lat": "53.24319",
    "lng": "39.96288"
  },
  {
    "country": "RU",
    "name": "Chapayevsk",
    "lat": "52.9771",
    "lng": "49.7086"
  },
  {
    "country": "RU",
    "name": "Chamzinka",
    "lat": "54.40188",
    "lng": "45.78387"
  },
  {
    "country": "RU",
    "name": "Chamlykskaya",
    "lat": "44.71583",
    "lng": "40.87861"
  },
  {
    "country": "RU",
    "name": "Chaltyr",
    "lat": "47.28477",
    "lng": "39.48232"
  },
  {
    "country": "RU",
    "name": "Chagoda",
    "lat": "59.164",
    "lng": "35.3285"
  },
  {
    "country": "RU",
    "name": "Chaadayevka",
    "lat": "53.1427",
    "lng": "45.9122"
  },
  {
    "country": "RU",
    "name": "Bytosh’",
    "lat": "53.81861",
    "lng": "34.09116"
  },
  {
    "country": "RU",
    "name": "Bystrogorskiy",
    "lat": "48.20813",
    "lng": "41.14097"
  },
  {
    "country": "RU",
    "name": "Bylym",
    "lat": "43.465",
    "lng": "43.03889"
  },
  {
    "country": "RU",
    "name": "Bykovo",
    "lat": "55.63614",
    "lng": "38.08027"
  },
  {
    "country": "RU",
    "name": "Bykovo",
    "lat": "55.62075",
    "lng": "38.0797"
  },
  {
    "country": "RU",
    "name": "Bykovo",
    "lat": "49.76618",
    "lng": "45.38866"
  },
  {
    "country": "RU",
    "name": "Buzuluk",
    "lat": "52.7807",
    "lng": "52.2635"
  },
  {
    "country": "RU",
    "name": "Buzdyak",
    "lat": "54.58333",
    "lng": "54.55"
  },
  {
    "country": "RU",
    "name": "Buynaksk",
    "lat": "42.819",
    "lng": "47.1192"
  },
  {
    "country": "RU",
    "name": "Buy",
    "lat": "58.48067",
    "lng": "41.53699"
  },
  {
    "country": "RU",
    "name": "Buturlinovka",
    "lat": "50.82389",
    "lng": "40.60917"
  },
  {
    "country": "RU",
    "name": "Buturlino",
    "lat": "55.56673",
    "lng": "44.89738"
  },
  {
    "country": "RU",
    "name": "Burtunay",
    "lat": "42.9886",
    "lng": "46.63034"
  },
  {
    "country": "RU",
    "name": "Burmakino",
    "lat": "57.41663",
    "lng": "40.23687"
  },
  {
    "country": "RU",
    "name": "Burlatskoye",
    "lat": "45.05639",
    "lng": "43.635"
  },
  {
    "country": "RU",
    "name": "Buribay",
    "lat": "51.96167",
    "lng": "58.15917"
  },
  {
    "country": "RU",
    "name": "Burevestnik",
    "lat": "56.14403",
    "lng": "43.78832"
  },
  {
    "country": "RU",
    "name": "Burayevo",
    "lat": "55.84069",
    "lng": "55.40834"
  },
  {
    "country": "RU",
    "name": "Bolgar",
    "lat": "54.95",
    "lng": "49.06667"
  },
  {
    "country": "RU",
    "name": "Bulgakovo",
    "lat": "54.4968",
    "lng": "55.8843"
  },
  {
    "country": "RU",
    "name": "Buinsk",
    "lat": "55.195",
    "lng": "47.0608"
  },
  {
    "country": "RU",
    "name": "Buinsk",
    "lat": "54.97119",
    "lng": "48.29184"
  },
  {
    "country": "RU",
    "name": "Buguruslan",
    "lat": "53.6554",
    "lng": "52.442"
  },
  {
    "country": "RU",
    "name": "Bugul’ma",
    "lat": "54.5378",
    "lng": "52.7985"
  },
  {
    "country": "RU",
    "name": "Budogoshch’",
    "lat": "59.28158",
    "lng": "32.47074"
  },
  {
    "country": "RU",
    "name": "Budënnovsk",
    "lat": "44.78389",
    "lng": "44.16583"
  },
  {
    "country": "RU",
    "name": "Bryukhovetskaya",
    "lat": "45.80603",
    "lng": "38.99959"
  },
  {
    "country": "RU",
    "name": "Bryansk",
    "lat": "53.25209",
    "lng": "34.37167"
  },
  {
    "country": "RU",
    "name": "Brusyanka",
    "lat": "53.98492",
    "lng": "38.03593"
  },
  {
    "country": "RU",
    "name": "Bronnitsy",
    "lat": "55.42112",
    "lng": "38.26188"
  },
  {
    "country": "RU",
    "name": "Breytovo",
    "lat": "58.29925",
    "lng": "37.86172"
  },
  {
    "country": "RU",
    "name": "Nogamerzin-Yurt",
    "lat": "43.65361",
    "lng": "44.88889"
  },
  {
    "country": "RU",
    "name": "Bratovshchina",
    "lat": "56.05",
    "lng": "37.88333"
  },
  {
    "country": "RU",
    "name": "Brateyevo",
    "lat": "55.63755",
    "lng": "37.76438"
  },
  {
    "country": "RU",
    "name": "Borzoy",
    "lat": "42.84147",
    "lng": "45.62746"
  },
  {
    "country": "RU",
    "name": "Borskoye",
    "lat": "53.03333",
    "lng": "51.71667"
  },
  {
    "country": "RU",
    "name": "Borovsk",
    "lat": "55.20639",
    "lng": "36.48611"
  },
  {
    "country": "RU",
    "name": "Borovoy",
    "lat": "64.6121",
    "lng": "32.24968"
  },
  {
    "country": "RU",
    "name": "Borovoy",
    "lat": "63.23005",
    "lng": "52.89031"
  },
  {
    "country": "RU",
    "name": "Borovichi",
    "lat": "58.38778",
    "lng": "33.91546"
  },
  {
    "country": "RU",
    "name": "Borok",
    "lat": "58.06532",
    "lng": "38.2362"
  },
  {
    "country": "RU",
    "name": "Borodinskiy",
    "lat": "53.99859",
    "lng": "37.81792"
  },
  {
    "country": "RU",
    "name": "Orekhovo-Borisovo Yuzhnoye",
    "lat": "55.63333",
    "lng": "37.73333"
  },
  {
    "country": "RU",
    "name": "Borisovka",
    "lat": "50.60155",
    "lng": "36.01549"
  },
  {
    "country": "RU",
    "name": "Borisova Griva",
    "lat": "60.08936",
    "lng": "30.97727"
  },
  {
    "country": "RU",
    "name": "Borisoglebskiy",
    "lat": "57.2586",
    "lng": "39.1508"
  },
  {
    "country": "RU",
    "name": "Borisoglebsk",
    "lat": "51.36713",
    "lng": "42.08494"
  },
  {
    "country": "RU",
    "name": "Borinskoye",
    "lat": "52.4569",
    "lng": "39.3713"
  },
  {
    "country": "RU",
    "name": "Borgustanskaya",
    "lat": "44.0547",
    "lng": "42.5288"
  },
  {
    "country": "RU",
    "name": "Bor",
    "lat": "56.35808",
    "lng": "44.07477"
  },
  {
    "country": "RU",
    "name": "Bamut",
    "lat": "43.15986",
    "lng": "45.19734"
  },
  {
    "country": "RU",
    "name": "Bol’shoy Khomutets",
    "lat": "52.78285",
    "lng": "39.87214"
  },
  {
    "country": "RU",
    "name": "Bol’shoy Karay",
    "lat": "51.60542",
    "lng": "42.69006"
  },
  {
    "country": "RU",
    "name": "Bol’shoye Skuratovo",
    "lat": "53.43852",
    "lng": "36.84085"
  },
  {
    "country": "RU",
    "name": "Bol’shoye Selo",
    "lat": "57.71774",
    "lng": "38.93341"
  },
  {
    "country": "RU",
    "name": "Bol’shoye Murashkino",
    "lat": "55.78261",
    "lng": "44.77541"
  },
  {
    "country": "RU",
    "name": "Bol’shoye Gryzlovo",
    "lat": "54.80033",
    "lng": "37.63939"
  },
  {
    "country": "RU",
    "name": "Bol’shoye Boldino",
    "lat": "55.00588",
    "lng": "45.31419"
  },
  {
    "country": "RU",
    "name": "Bol'shiye Vyazëmy",
    "lat": "55.62058",
    "lng": "36.9762"
  },
  {
    "country": "RU",
    "name": "Bolshevo",
    "lat": "55.93486",
    "lng": "37.83002"
  },
  {
    "country": "RU",
    "name": "Bol’shaya Setun’",
    "lat": "55.71667",
    "lng": "37.41667"
  },
  {
    "country": "RU",
    "name": "Bol’shaya Martynovka",
    "lat": "47.27421",
    "lng": "41.66681"
  },
  {
    "country": "RU",
    "name": "Bol’shaya Izhora",
    "lat": "59.93796",
    "lng": "29.57721"
  },
  {
    "country": "RU",
    "name": "Bolokhovo",
    "lat": "54.08378",
    "lng": "37.82895"
  },
  {
    "country": "RU",
    "name": "Bologoye",
    "lat": "57.8799",
    "lng": "34.10681"
  },
  {
    "country": "RU",
    "name": "Bolkhov",
    "lat": "53.44295",
    "lng": "36.00546"
  },
  {
    "country": "RU",
    "name": "Bolgatovo",
    "lat": "56.80306",
    "lng": "28.94876"
  },
  {
    "country": "RU",
    "name": "Boksitogorsk",
    "lat": "59.47405",
    "lng": "33.84853"
  },
  {
    "country": "RU",
    "name": "Bokovskaya",
    "lat": "49.22899",
    "lng": "41.8306"
  },
  {
    "country": "RU",
    "name": "Bokino",
    "lat": "52.63744",
    "lng": "41.45968"
  },
  {
    "country": "RU",
    "name": "Boguchar",
    "lat": "49.93577",
    "lng": "40.545"
  },
  {
    "country": "RU",
    "name": "Bogovarovo",
    "lat": "58.97849",
    "lng": "47.02462"
  },
  {
    "country": "RU",
    "name": "Bogoslovka",
    "lat": "53.20837",
    "lng": "44.80133"
  },
  {
    "country": "RU",
    "name": "Bogorodskoye",
    "lat": "55.81353",
    "lng": "37.71617"
  },
  {
    "country": "RU",
    "name": "Bogorodskoye",
    "lat": "57.82849",
    "lng": "50.74856"
  },
  {
    "country": "RU",
    "name": "Bogorodskoye",
    "lat": "57.04695",
    "lng": "41.01354"
  },
  {
    "country": "RU",
    "name": "Bogorodskoye",
    "lat": "56.55",
    "lng": "37.88333"
  },
  {
    "country": "RU",
    "name": "Bogorodskoye",
    "lat": "56.5",
    "lng": "38.18333"
  },
  {
    "country": "RU",
    "name": "Bogorodsk",
    "lat": "56.10513",
    "lng": "43.51294"
  },
  {
    "country": "RU",
    "name": "Bogoroditsk",
    "lat": "53.77166",
    "lng": "38.12408"
  },
  {
    "country": "RU",
    "name": "Bogolyubovo",
    "lat": "56.19052",
    "lng": "40.52313"
  },
  {
    "country": "RU",
    "name": "Bogatyye Saby",
    "lat": "56.0102",
    "lng": "50.4483"
  },
  {
    "country": "RU",
    "name": "Bogatyr’",
    "lat": "53.4298",
    "lng": "49.9455"
  },
  {
    "country": "RU",
    "name": "Bogatoye",
    "lat": "53.0601",
    "lng": "51.3325"
  },
  {
    "country": "RU",
    "name": "Bobrov",
    "lat": "51.09611",
    "lng": "40.03333"
  },
  {
    "country": "RU",
    "name": "Blizhne-Pesochnoye",
    "lat": "55.3456",
    "lng": "42.1015"
  },
  {
    "country": "RU",
    "name": "Blechepsin",
    "lat": "44.82028",
    "lng": "40.50028"
  },
  {
    "country": "RU",
    "name": "Blagoyevo",
    "lat": "63.4231",
    "lng": "47.9646"
  },
  {
    "country": "RU",
    "name": "Blagoveshchensk",
    "lat": "55.035",
    "lng": "55.97806"
  },
  {
    "country": "RU",
    "name": "Blagodatnoye",
    "lat": "45.39972",
    "lng": "42.58667"
  },
  {
    "country": "RU",
    "name": "Blagodarnyy",
    "lat": "45.09778",
    "lng": "43.43639"
  },
  {
    "country": "RU",
    "name": "Bizhbulyak",
    "lat": "53.6967",
    "lng": "54.2642"
  },
  {
    "country": "RU",
    "name": "Bisert’",
    "lat": "56.86174",
    "lng": "59.05231"
  },
  {
    "country": "RU",
    "name": "Biryulëvo",
    "lat": "55.58635",
    "lng": "37.67781"
  },
  {
    "country": "RU",
    "name": "Birsk",
    "lat": "55.42111",
    "lng": "55.54278"
  },
  {
    "country": "RU",
    "name": "Bilyarsk",
    "lat": "54.98358",
    "lng": "50.38671"
  },
  {
    "country": "RU",
    "name": "Bilimbay",
    "lat": "56.96889",
    "lng": "59.8149"
  },
  {
    "country": "RU",
    "name": "Bibirevo",
    "lat": "55.88333",
    "lng": "37.6"
  },
  {
    "country": "RU",
    "name": "Bezopasnoye",
    "lat": "45.64833",
    "lng": "41.93603"
  },
  {
    "country": "RU",
    "name": "Bezhta",
    "lat": "42.1338",
    "lng": "46.12828"
  },
  {
    "country": "RU",
    "name": "Bezhetsk",
    "lat": "57.78506",
    "lng": "36.69651"
  },
  {
    "country": "RU",
    "name": "Bezhanitsy",
    "lat": "56.97669",
    "lng": "29.89065"
  },
  {
    "country": "RU",
    "name": "Bezenchuk",
    "lat": "52.982",
    "lng": "49.4333"
  },
  {
    "country": "RU",
    "name": "Betlitsa",
    "lat": "54.00946",
    "lng": "33.95875"
  },
  {
    "country": "RU",
    "name": "Bessonovka",
    "lat": "53.30968",
    "lng": "45.04069"
  },
  {
    "country": "RU",
    "name": "Bessonovka",
    "lat": "50.52644",
    "lng": "36.30107"
  },
  {
    "country": "RU",
    "name": "Besskorbnaya",
    "lat": "44.6447",
    "lng": "41.311"
  },
  {
    "country": "RU",
    "name": "Besleneyevskaya",
    "lat": "44.231",
    "lng": "40.725"
  },
  {
    "country": "RU",
    "name": "Besleney",
    "lat": "44.2405",
    "lng": "41.7387"
  },
  {
    "country": "RU",
    "name": "Beslan",
    "lat": "43.19217",
    "lng": "44.54313"
  },
  {
    "country": "RU",
    "name": "Beshpagir",
    "lat": "45.02167",
    "lng": "42.38083"
  },
  {
    "country": "RU",
    "name": "Bershet’",
    "lat": "57.7309",
    "lng": "56.3783"
  },
  {
    "country": "RU",
    "name": "Bernovo",
    "lat": "56.68633",
    "lng": "34.70357"
  },
  {
    "country": "RU",
    "name": "Berezniki",
    "lat": "59.4091",
    "lng": "56.8204"
  },
  {
    "country": "RU",
    "name": "Berëznik",
    "lat": "62.852",
    "lng": "42.7071"
  },
  {
    "country": "RU",
    "name": "Berezayka",
    "lat": "57.98833",
    "lng": "33.90361"
  },
  {
    "country": "RU",
    "name": "Berezanskaya",
    "lat": "45.70562",
    "lng": "39.59324"
  },
  {
    "country": "RU",
    "name": "Berëza",
    "lat": "53.51833",
    "lng": "50.13967"
  },
  {
    "country": "RU",
    "name": "Bereslavka",
    "lat": "48.62541",
    "lng": "44.04491"
  },
  {
    "country": "RU",
    "name": "Berendeyevo",
    "lat": "56.60078",
    "lng": "39.02173"
  },
  {
    "country": "RU",
    "name": "Berdyaush",
    "lat": "55.1619",
    "lng": "59.1464"
  },
  {
    "country": "RU",
    "name": "Benoy-Yurt",
    "lat": "43.69305",
    "lng": "45.05025"
  },
  {
    "country": "RU",
    "name": "Belyy Gorodok",
    "lat": "56.965",
    "lng": "37.5125"
  },
  {
    "country": "RU",
    "name": "Belyye Stolby",
    "lat": "55.33136",
    "lng": "37.854"
  },
  {
    "country": "RU",
    "name": "Belyye Berega",
    "lat": "53.20851",
    "lng": "34.66405"
  },
  {
    "country": "RU",
    "name": "Belyy",
    "lat": "55.8402",
    "lng": "32.9419"
  },
  {
    "country": "RU",
    "name": "Belyayevka",
    "lat": "51.39742",
    "lng": "56.41667"
  },
  {
    "country": "RU",
    "name": "Belozërsk",
    "lat": "60.0288",
    "lng": "37.8084"
  },
  {
    "country": "RU",
    "name": "Beloye",
    "lat": "45.04832",
    "lng": "39.65143"
  },
  {
    "country": "RU",
    "name": "Belousovo",
    "lat": "55.09499",
    "lng": "36.6732"
  },
  {
    "country": "RU",
    "name": "Beloretsk",
    "lat": "53.96306",
    "lng": "58.39806"
  },
  {
    "country": "RU",
    "name": "Ilaskhan-Yurt",
    "lat": "43.2791",
    "lng": "46.10229"
  },
  {
    "country": "RU",
    "name": "Belorechensk",
    "lat": "58.77251",
    "lng": "52.29357"
  },
  {
    "country": "RU",
    "name": "Belorechensk",
    "lat": "44.77127",
    "lng": "39.87879"
  },
  {
    "country": "RU",
    "name": "Beloozërskiy",
    "lat": "55.45978",
    "lng": "38.44358"
  },
  {
    "country": "RU",
    "name": "Beloostrov",
    "lat": "60.15118",
    "lng": "30.00151"
  },
  {
    "country": "RU",
    "name": "Beloomut",
    "lat": "54.94478",
    "lng": "39.33941"
  },
  {
    "country": "RU",
    "name": "Belomorsk",
    "lat": "64.52322",
    "lng": "34.7668"
  },
  {
    "country": "RU",
    "name": "Belogor’ye",
    "lat": "50.4904",
    "lng": "40.0095"
  },
  {
    "country": "RU",
    "name": "Belinskiy",
    "lat": "52.96474",
    "lng": "43.41647"
  },
  {
    "country": "RU",
    "name": "Belgorod",
    "lat": "50.61074",
    "lng": "36.58015"
  },
  {
    "country": "RU",
    "name": "Belgatoy",
    "lat": "43.18995",
    "lng": "45.83082"
  },
  {
    "country": "RU",
    "name": "Belëv",
    "lat": "53.81194",
    "lng": "36.13194"
  },
  {
    "country": "RU",
    "name": "Belebey",
    "lat": "54.11667",
    "lng": "54.11667"
  },
  {
    "country": "RU",
    "name": "Belaya Rechka",
    "lat": "56.28491",
    "lng": "39.40665"
  },
  {
    "country": "RU",
    "name": "Belaya Rechka",
    "lat": "43.43806",
    "lng": "43.535"
  },
  {
    "country": "RU",
    "name": "Belaya Kholunitsa",
    "lat": "58.84",
    "lng": "50.85278"
  },
  {
    "country": "RU",
    "name": "Belaya Kalitva",
    "lat": "48.18585",
    "lng": "40.77424"
  },
  {
    "country": "RU",
    "name": "Belaya Glina",
    "lat": "46.07802",
    "lng": "40.86651"
  },
  {
    "country": "RU",
    "name": "Belaya",
    "lat": "51.05444",
    "lng": "35.71611"
  },
  {
    "country": "RU",
    "name": "Bekovo",
    "lat": "52.46632",
    "lng": "43.71199"
  },
  {
    "country": "RU",
    "name": "Bekhteyevka",
    "lat": "50.80721",
    "lng": "37.20853"
  },
  {
    "country": "RU",
    "name": "Bekeshevskaya",
    "lat": "44.11389",
    "lng": "42.42694"
  },
  {
    "country": "RU",
    "name": "Begunitsy",
    "lat": "59.58552",
    "lng": "29.31757"
  },
  {
    "country": "RU",
    "name": "Begichevskiy",
    "lat": "53.79605",
    "lng": "38.25498"
  },
  {
    "country": "RU",
    "name": "Spassk",
    "lat": "53.92559",
    "lng": "43.18394"
  },
  {
    "country": "RU",
    "name": "Bedeyeva Polyana",
    "lat": "55.32345",
    "lng": "56.38882"
  },
  {
    "country": "RU",
    "name": "Bazarnyy Syzgan",
    "lat": "53.75117",
    "lng": "46.75354"
  },
  {
    "country": "RU",
    "name": "Bazarnyy Karabulak",
    "lat": "52.26833",
    "lng": "46.41444"
  },
  {
    "country": "RU",
    "name": "Bazarnyye Mataki",
    "lat": "54.88333",
    "lng": "49.93333"
  },
  {
    "country": "RU",
    "name": "Baymak",
    "lat": "52.59333",
    "lng": "58.3225"
  },
  {
    "country": "RU",
    "name": "Bavtugay",
    "lat": "43.16808",
    "lng": "46.83415"
  },
  {
    "country": "RU",
    "name": "Bavly",
    "lat": "54.39304",
    "lng": "53.26023"
  },
  {
    "country": "RU",
    "name": "Bavleny",
    "lat": "56.39448",
    "lng": "39.56504"
  },
  {
    "country": "RU",
    "name": "Batyrevo",
    "lat": "55.0675",
    "lng": "47.61111"
  },
  {
    "country": "RU",
    "name": "Baturinskaya",
    "lat": "45.79267",
    "lng": "39.37065"
  },
  {
    "country": "RU",
    "name": "Batetskiy",
    "lat": "58.6461",
    "lng": "30.30268"
  },
  {
    "country": "RU",
    "name": "Botayurt",
    "lat": "43.31865",
    "lng": "46.68371"
  },
  {
    "country": "RU",
    "name": "Bataysk",
    "lat": "47.13975",
    "lng": "39.75181"
  },
  {
    "country": "RU",
    "name": "Botashyurt",
    "lat": "43.30801",
    "lng": "46.50991"
  },
  {
    "country": "RU",
    "name": "Bashmakovo",
    "lat": "53.21329",
    "lng": "43.0342"
  },
  {
    "country": "RU",
    "name": "Barysh",
    "lat": "53.65533",
    "lng": "47.11229"
  },
  {
    "country": "RU",
    "name": "Barybino",
    "lat": "55.26768",
    "lng": "37.89333"
  },
  {
    "country": "RU",
    "name": "Baryatino",
    "lat": "54.31206",
    "lng": "34.52096"
  },
  {
    "country": "RU",
    "name": "Barvikha",
    "lat": "55.74212",
    "lng": "37.27926"
  },
  {
    "country": "RU",
    "name": "Barsukovskaya",
    "lat": "44.7632",
    "lng": "41.8191"
  },
  {
    "country": "RU",
    "name": "Barsuki",
    "lat": "54.26548",
    "lng": "37.48746"
  },
  {
    "country": "RU",
    "name": "Barda",
    "lat": "56.9287",
    "lng": "55.5962"
  },
  {
    "country": "RU",
    "name": "Barashevo",
    "lat": "54.5325",
    "lng": "42.87917"
  },
  {
    "country": "RU",
    "name": "Baranchinskiy",
    "lat": "58.1617",
    "lng": "59.6991"
  },
  {
    "country": "RU",
    "name": "Bammatyurt",
    "lat": "43.34315",
    "lng": "46.60853"
  },
  {
    "country": "RU",
    "name": "Baltay",
    "lat": "52.46525",
    "lng": "46.63081"
  },
  {
    "country": "RU",
    "name": "Baltasi",
    "lat": "56.3462",
    "lng": "50.2062"
  },
  {
    "country": "RU",
    "name": "Balezino",
    "lat": "57.9787",
    "lng": "53.0138"
  },
  {
    "country": "RU",
    "name": "Balashov",
    "lat": "51.5502",
    "lng": "43.1667"
  },
  {
    "country": "RU",
    "name": "Balashikha",
    "lat": "55.80945",
    "lng": "37.95806"
  },
  {
    "country": "RU",
    "name": "Balasheyka",
    "lat": "53.2841",
    "lng": "48.0851"
  },
  {
    "country": "RU",
    "name": "Balakovo",
    "lat": "52.02782",
    "lng": "47.8007"
  },
  {
    "country": "RU",
    "name": "Balakirevo",
    "lat": "56.50588",
    "lng": "38.84324"
  },
  {
    "country": "RU",
    "name": "Balakhonovskoye",
    "lat": "44.7767",
    "lng": "41.7842"
  },
  {
    "country": "RU",
    "name": "Novaya Balakhna",
    "lat": "56.48989",
    "lng": "43.60114"
  },
  {
    "country": "RU",
    "name": "Balabanovo",
    "lat": "55.18161",
    "lng": "36.6606"
  },
  {
    "country": "RU",
    "name": "Baksheyevo",
    "lat": "55.7086",
    "lng": "39.87666"
  },
  {
    "country": "RU",
    "name": "Baksanenok",
    "lat": "43.68972",
    "lng": "43.65472"
  },
  {
    "country": "RU",
    "name": "Baksan",
    "lat": "43.68806",
    "lng": "43.53694"
  },
  {
    "country": "RU",
    "name": "Bakhilovo",
    "lat": "53.4011",
    "lng": "49.636"
  },
  {
    "country": "RU",
    "name": "Bakaly",
    "lat": "55.17889",
    "lng": "53.80278"
  },
  {
    "country": "RU",
    "name": "Bakal",
    "lat": "54.9417",
    "lng": "58.8083"
  },
  {
    "country": "RU",
    "name": "Bagrationovsk",
    "lat": "54.38714",
    "lng": "20.64372"
  },
  {
    "country": "RU",
    "name": "Bagramovo",
    "lat": "54.72337",
    "lng": "39.45186"
  },
  {
    "country": "RU",
    "name": "Bagayevskaya",
    "lat": "47.32411",
    "lng": "40.38791"
  },
  {
    "country": "RU",
    "name": "Bachi-Yurt",
    "lat": "43.22417",
    "lng": "46.19423"
  },
  {
    "country": "RU",
    "name": "Babynino",
    "lat": "54.39385",
    "lng": "35.77013"
  },
  {
    "country": "RU",
    "name": "Babushkin",
    "lat": "55.86931",
    "lng": "37.72966"
  },
  {
    "country": "RU",
    "name": "Babugent",
    "lat": "43.27942",
    "lng": "43.5502"
  },
  {
    "country": "RU",
    "name": "Babino",
    "lat": "56.22564",
    "lng": "43.6238"
  },
  {
    "country": "RU",
    "name": "Babayurt",
    "lat": "43.6002",
    "lng": "46.77888"
  },
  {
    "country": "RU",
    "name": "Babayevo",
    "lat": "59.3936",
    "lng": "35.9371"
  },
  {
    "country": "RU",
    "name": "Azovskaya",
    "lat": "44.79083",
    "lng": "38.62639"
  },
  {
    "country": "RU",
    "name": "Azov",
    "lat": "47.10779",
    "lng": "39.41648"
  },
  {
    "country": "RU",
    "name": "Ayutinskiy",
    "lat": "47.78228",
    "lng": "40.14763"
  },
  {
    "country": "RU",
    "name": "Aysha",
    "lat": "55.87035",
    "lng": "48.63187"
  },
  {
    "country": "RU",
    "name": "Aykino",
    "lat": "62.22481",
    "lng": "49.99222"
  },
  {
    "country": "RU",
    "name": "Avtury",
    "lat": "43.16354",
    "lng": "46.0012"
  },
  {
    "country": "RU",
    "name": "Avtovo",
    "lat": "59.87167",
    "lng": "30.26583"
  },
  {
    "country": "RU",
    "name": "Avsyunino",
    "lat": "55.56516",
    "lng": "39.12324"
  },
  {
    "country": "RU",
    "name": "Avdon",
    "lat": "54.66667",
    "lng": "55.71667"
  },
  {
    "country": "RU",
    "name": "Aushiger",
    "lat": "43.39611",
    "lng": "43.73167"
  },
  {
    "country": "RU",
    "name": "Atyashevo",
    "lat": "54.56443",
    "lng": "46.06905"
  },
  {
    "country": "RU",
    "name": "Atkarsk",
    "lat": "51.87185",
    "lng": "45.00775"
  },
  {
    "country": "RU",
    "name": "Atig",
    "lat": "56.69307",
    "lng": "59.42271"
  },
  {
    "country": "RU",
    "name": "Ateptsevo",
    "lat": "55.32364",
    "lng": "36.75002"
  },
  {
    "country": "RU",
    "name": "Atemar",
    "lat": "54.18097",
    "lng": "45.40909"
  },
  {
    "country": "RU",
    "name": "Atamanskaya",
    "lat": "46.1773",
    "lng": "39.6358"
  },
  {
    "country": "RU",
    "name": "Astrakhan",
    "lat": "46.34968",
    "lng": "48.04076"
  },
  {
    "country": "RU",
    "name": "Assinovskaya",
    "lat": "43.24167",
    "lng": "45.18194"
  },
  {
    "country": "RU",
    "name": "Askino",
    "lat": "56.09013",
    "lng": "56.57831"
  },
  {
    "country": "RU",
    "name": "Ashukino",
    "lat": "56.16667",
    "lng": "37.95"
  },
  {
    "country": "RU",
    "name": "Ashitkovo",
    "lat": "55.45173",
    "lng": "38.59518"
  },
  {
    "country": "RU",
    "name": "Ashil’ta",
    "lat": "42.77042",
    "lng": "46.72992"
  },
  {
    "country": "RU",
    "name": "Asha",
    "lat": "54.9973",
    "lng": "57.2722"
  },
  {
    "country": "RU",
    "name": "Asekeyevo",
    "lat": "53.57425",
    "lng": "52.79724"
  },
  {
    "country": "RU",
    "name": "Asanovo",
    "lat": "54.89418",
    "lng": "55.49083"
  },
  {
    "country": "RU",
    "name": "Arzgir",
    "lat": "45.37278",
    "lng": "44.22056"
  },
  {
    "country": "RU",
    "name": "Arzamas",
    "lat": "55.39485",
    "lng": "43.83992"
  },
  {
    "country": "RU",
    "name": "Arti",
    "lat": "56.42344",
    "lng": "58.53276"
  },
  {
    "country": "RU",
    "name": "Arsk",
    "lat": "56.09151",
    "lng": "49.87783"
  },
  {
    "country": "RU",
    "name": "Arshan’",
    "lat": "46.2732",
    "lng": "44.22"
  },
  {
    "country": "RU",
    "name": "Arsen’yevo",
    "lat": "53.73893",
    "lng": "36.66429"
  },
  {
    "country": "RU",
    "name": "Arsaki",
    "lat": "56.38333",
    "lng": "38.48333"
  },
  {
    "country": "RU",
    "name": "Armavir",
    "lat": "44.9892",
    "lng": "41.1234"
  },
  {
    "country": "RU",
    "name": "Arkul’",
    "lat": "57.28085",
    "lng": "50.044"
  },
  {
    "country": "RU",
    "name": "Arkhonskaya",
    "lat": "43.11",
    "lng": "44.5125"
  },
  {
    "country": "RU",
    "name": "Arkhipovka",
    "lat": "56.66292",
    "lng": "41.25434"
  },
  {
    "country": "RU",
    "name": "Arkhipo-Osipovka",
    "lat": "44.37194",
    "lng": "38.52972"
  },
  {
    "country": "RU",
    "name": "Arkhangel’skoye",
    "lat": "55.85486",
    "lng": "35.32873"
  },
  {
    "country": "RU",
    "name": "Arkhangel’skoye",
    "lat": "55.78791",
    "lng": "37.29984"
  },
  {
    "country": "RU",
    "name": "Arkhangel’sk",
    "lat": "64.5401",
    "lng": "40.5433"
  },
  {
    "country": "RU",
    "name": "Arkadak",
    "lat": "51.93261",
    "lng": "43.49779"
  },
  {
    "country": "RU",
    "name": "Argun",
    "lat": "43.29713",
    "lng": "45.87454"
  },
  {
    "country": "RU",
    "name": "Argudan",
    "lat": "43.42139",
    "lng": "43.91583"
  },
  {
    "country": "RU",
    "name": "Ardon’",
    "lat": "52.73524",
    "lng": "32.30857"
  },
  {
    "country": "RU",
    "name": "Ardon",
    "lat": "43.1772",
    "lng": "44.29702"
  },
  {
    "country": "RU",
    "name": "Ardatov",
    "lat": "55.24205",
    "lng": "43.09699"
  },
  {
    "country": "RU",
    "name": "Ardatov",
    "lat": "54.84767",
    "lng": "46.23878"
  },
  {
    "country": "RU",
    "name": "Arbazh",
    "lat": "57.68041",
    "lng": "48.30647"
  },
  {
    "country": "RU",
    "name": "Apsheronsk",
    "lat": "44.46472",
    "lng": "39.73417"
  },
  {
    "country": "RU",
    "name": "Aprelevka",
    "lat": "55.55194",
    "lng": "37.0801"
  },
  {
    "country": "RU",
    "name": "Apatity",
    "lat": "67.56414",
    "lng": "33.4031"
  },
  {
    "country": "RU",
    "name": "Apastovo",
    "lat": "55.20293",
    "lng": "48.51091"
  },
  {
    "country": "RU",
    "name": "Antropovo",
    "lat": "58.39876",
    "lng": "43.00659"
  },
  {
    "country": "RU",
    "name": "Antipovka",
    "lat": "49.82994",
    "lng": "45.31216"
  },
  {
    "country": "RU",
    "name": "Ansalta",
    "lat": "42.68941",
    "lng": "46.11782"
  },
  {
    "country": "RU",
    "name": "Anopino",
    "lat": "55.69809",
    "lng": "40.66707"
  },
  {
    "country": "RU",
    "name": "Annino",
    "lat": "59.77056",
    "lng": "30.05611"
  },
  {
    "country": "RU",
    "name": "Anna",
    "lat": "51.4842",
    "lng": "40.4299"
  },
  {
    "country": "RU",
    "name": "Andzhiyevskiy",
    "lat": "44.23889",
    "lng": "43.08556"
  },
  {
    "country": "RU",
    "name": "Andreyevskoye",
    "lat": "55.55487",
    "lng": "37.92566"
  },
  {
    "country": "RU",
    "name": "Andreyevo",
    "lat": "55.9465",
    "lng": "41.1505"
  },
  {
    "country": "RU",
    "name": "Andreyevka",
    "lat": "55.98028",
    "lng": "37.135"
  },
  {
    "country": "RU",
    "name": "Endirey",
    "lat": "43.16316",
    "lng": "46.65401"
  },
  {
    "country": "RU",
    "name": "Andreapol’",
    "lat": "56.65134",
    "lng": "32.2664"
  },
  {
    "country": "RU",
    "name": "Andi",
    "lat": "42.78359",
    "lng": "46.26171"
  },
  {
    "country": "RU",
    "name": "Anastasiyevskaya",
    "lat": "45.21576",
    "lng": "37.89258"
  },
  {
    "country": "RU",
    "name": "Anastasiyevka",
    "lat": "47.56072",
    "lng": "38.52837"
  },
  {
    "country": "RU",
    "name": "Anapskaya",
    "lat": "44.89671",
    "lng": "37.386"
  },
  {
    "country": "RU",
    "name": "Anapa",
    "lat": "44.89084",
    "lng": "37.3239"
  },
  {
    "country": "RU",
    "name": "Amzya",
    "lat": "56.2346",
    "lng": "54.385"
  },
  {
    "country": "RU",
    "name": "Amin’yevo",
    "lat": "55.7",
    "lng": "37.46667"
  },
  {
    "country": "RU",
    "name": "Altukhovo",
    "lat": "52.67559",
    "lng": "34.36703"
  },
  {
    "country": "RU",
    "name": "Altud",
    "lat": "43.72194",
    "lng": "43.86583"
  },
  {
    "country": "RU",
    "name": "Alnashi",
    "lat": "56.18738",
    "lng": "52.47919"
  },
  {
    "country": "RU",
    "name": "Al’met’yevsk",
    "lat": "54.90442",
    "lng": "52.3154"
  },
  {
    "country": "RU",
    "name": "Almaznyy",
    "lat": "48.04476",
    "lng": "40.04501"
  },
  {
    "country": "RU",
    "name": "Alleroy",
    "lat": "43.21711",
    "lng": "46.28209"
  },
  {
    "country": "RU",
    "name": "Alkhazurovo",
    "lat": "43.0639",
    "lng": "45.65134"
  },
  {
    "country": "RU",
    "name": "Alkhan-Yurt",
    "lat": "43.23179",
    "lng": "45.57228"
  },
  {
    "country": "RU",
    "name": "Alkhan-Kala",
    "lat": "43.25861",
    "lng": "45.53917"
  },
  {
    "country": "RU",
    "name": "Ali-Yurt",
    "lat": "43.1425",
    "lng": "44.8525"
  },
  {
    "country": "RU",
    "name": "Alikovo",
    "lat": "55.73827",
    "lng": "46.75493"
  },
  {
    "country": "RU",
    "name": "Ali-Berdukovskiy",
    "lat": "43.98952",
    "lng": "41.74212"
  },
  {
    "country": "RU",
    "name": "Aleksin",
    "lat": "54.50503",
    "lng": "37.0674"
  },
  {
    "country": "RU",
    "name": "Alekseyevskoye",
    "lat": "55.30706",
    "lng": "50.11353"
  },
  {
    "country": "RU",
    "name": "Alekseyevskaya",
    "lat": "50.2896",
    "lng": "42.1845"
  },
  {
    "country": "RU",
    "name": "Alekseyevskaya",
    "lat": "45.77167",
    "lng": "40.15528"
  },
  {
    "country": "RU",
    "name": "Alekseyevka",
    "lat": "55.63",
    "lng": "37.8"
  },
  {
    "country": "RU",
    "name": "Alekseyevka",
    "lat": "54.85",
    "lng": "55.23333"
  },
  {
    "country": "RU",
    "name": "Alekseyevka",
    "lat": "52.30583",
    "lng": "48.02611"
  },
  {
    "country": "RU",
    "name": "Alekseyevka",
    "lat": "50.6309",
    "lng": "38.6903"
  },
  {
    "country": "RU",
    "name": "Aleksandrovskoye",
    "lat": "44.71417",
    "lng": "43.00083"
  },
  {
    "country": "RU",
    "name": "Aleksandrovskaya",
    "lat": "60.05168",
    "lng": "29.97935"
  },
  {
    "country": "RU",
    "name": "Aleksandrovskaya",
    "lat": "59.73083",
    "lng": "30.33222"
  },
  {
    "country": "RU",
    "name": "Aleksandrovskaya",
    "lat": "43.48333",
    "lng": "43.65"
  },
  {
    "country": "RU",
    "name": "Aleksandrovsk",
    "lat": "59.1581",
    "lng": "57.5695"
  },
  {
    "country": "RU",
    "name": "Aleksandrov Gay",
    "lat": "50.14704",
    "lng": "48.57037"
  },
  {
    "country": "RU",
    "name": "Aleksandrov",
    "lat": "56.39516",
    "lng": "38.71216"
  },
  {
    "country": "RU",
    "name": "Aleksandro-Nevskiy",
    "lat": "53.4751",
    "lng": "40.2095"
  },
  {
    "country": "RU",
    "name": "Aleksandriyskaya",
    "lat": "44.22722",
    "lng": "43.34528"
  },
  {
    "country": "RU",
    "name": "Aleksandriya",
    "lat": "45.09472",
    "lng": "43.24556"
  },
  {
    "country": "RU",
    "name": "Alatyr’",
    "lat": "54.8421",
    "lng": "46.5813"
  },
  {
    "country": "RU",
    "name": "Alandskoye",
    "lat": "52.22611",
    "lng": "59.79389"
  },
  {
    "country": "RU",
    "name": "Alakurtti",
    "lat": "66.9672",
    "lng": "30.34905"
  },
  {
    "country": "RU",
    "name": "Alabushevo",
    "lat": "56.01667",
    "lng": "37.15"
  },
  {
    "country": "RU",
    "name": "Ak”yar",
    "lat": "51.85905",
    "lng": "58.22136"
  },
  {
    "country": "RU",
    "name": "Akusha",
    "lat": "42.26885",
    "lng": "47.34114"
  },
  {
    "country": "RU",
    "name": "Aktyubinskiy",
    "lat": "54.81372",
    "lng": "52.80559"
  },
  {
    "country": "RU",
    "name": "Russkiy Aktash",
    "lat": "55.0384",
    "lng": "52.1214"
  },
  {
    "country": "RU",
    "name": "Aktanysh",
    "lat": "55.72156",
    "lng": "54.08293"
  },
  {
    "country": "RU",
    "name": "Levoberezhnyy",
    "lat": "55.85",
    "lng": "37.48333"
  },
  {
    "country": "RU",
    "name": "Aksay",
    "lat": "47.25838",
    "lng": "39.86675"
  },
  {
    "country": "RU",
    "name": "Aksay",
    "lat": "43.37254",
    "lng": "46.44497"
  },
  {
    "country": "RU",
    "name": "Aksarayskiy",
    "lat": "46.79244",
    "lng": "48.01188"
  },
  {
    "country": "RU",
    "name": "Aksakovo",
    "lat": "54.03333",
    "lng": "54.15"
  },
  {
    "country": "RU",
    "name": "Aknada",
    "lat": "42.40155",
    "lng": "46.17228"
  },
  {
    "country": "RU",
    "name": "Staraya Akkermanovka",
    "lat": "51.24669",
    "lng": "58.23908"
  },
  {
    "country": "RU",
    "name": "Akhunovo",
    "lat": "54.2079",
    "lng": "59.6017"
  },
  {
    "country": "RU",
    "name": "Akhtyrskiy",
    "lat": "44.8546",
    "lng": "38.3031"
  },
  {
    "country": "RU",
    "name": "Akhty",
    "lat": "41.45968",
    "lng": "47.73123"
  },
  {
    "country": "RU",
    "name": "Akhtubinsk",
    "lat": "48.27955",
    "lng": "46.17217"
  },
  {
    "country": "RU",
    "name": "Akhtanizovskaya",
    "lat": "45.32128",
    "lng": "37.10071"
  },
  {
    "country": "RU",
    "name": "Agvali",
    "lat": "42.53853",
    "lng": "46.11967"
  },
  {
    "country": "RU",
    "name": "Agryz",
    "lat": "56.52034",
    "lng": "52.99422"
  },
  {
    "country": "RU",
    "name": "Agronom",
    "lat": "45.14021",
    "lng": "39.19484"
  },
  {
    "country": "RU",
    "name": "Agoy",
    "lat": "44.1466",
    "lng": "39.0373"
  },
  {
    "country": "RU",
    "name": "Ageyevo",
    "lat": "54.15883",
    "lng": "36.46927"
  },
  {
    "country": "RU",
    "name": "Agapovka",
    "lat": "53.2973",
    "lng": "59.1348"
  },
  {
    "country": "RU",
    "name": "Agalatovo",
    "lat": "60.2195",
    "lng": "30.27388"
  },
  {
    "country": "RU",
    "name": "Afrikanda",
    "lat": "67.44289",
    "lng": "32.78279"
  },
  {
    "country": "RU",
    "name": "Afonino",
    "lat": "56.26201",
    "lng": "44.09503"
  },
  {
    "country": "RU",
    "name": "Afipskiy",
    "lat": "44.90005",
    "lng": "38.84265"
  },
  {
    "country": "RU",
    "name": "Adyge-Khabl’",
    "lat": "44.33434",
    "lng": "41.93922"
  },
  {
    "country": "RU",
    "name": "Adler",
    "lat": "43.42896",
    "lng": "39.92391"
  },
  {
    "country": "RU",
    "name": "Adil’-Yangiyurt",
    "lat": "43.56328",
    "lng": "46.58462"
  },
  {
    "country": "RU",
    "name": "Adamovka",
    "lat": "51.5223",
    "lng": "59.9396"
  },
  {
    "country": "RU",
    "name": "Achkhoy-Martan",
    "lat": "43.18997",
    "lng": "45.28373"
  },
  {
    "country": "RU",
    "name": "Achit",
    "lat": "56.7985",
    "lng": "57.8994"
  },
  {
    "country": "RU",
    "name": "Achisu",
    "lat": "42.65197",
    "lng": "47.68282"
  },
  {
    "country": "RU",
    "name": "Achikulak",
    "lat": "44.55167",
    "lng": "44.83778"
  },
  {
    "country": "RU",
    "name": "Abzakovo",
    "lat": "53.82861",
    "lng": "58.59333"
  },
  {
    "country": "RU",
    "name": "Abrau-Dyurso",
    "lat": "44.69973",
    "lng": "37.60098"
  },
  {
    "country": "RU",
    "name": "Abramovka",
    "lat": "51.1886",
    "lng": "41.0202"
  },
  {
    "country": "RU",
    "name": "Abinsk",
    "lat": "44.86803",
    "lng": "38.15728"
  },
  {
    "country": "RU",
    "name": "Abdulino",
    "lat": "53.7",
    "lng": "53.66667"
  },
  {
    "country": "RU",
    "name": "Abadzekhskaya",
    "lat": "44.39389",
    "lng": "40.22139"
  },
  {
    "country": "RU",
    "name": "Vasil’yevo",
    "lat": "55.83595",
    "lng": "48.6582"
  },
  {
    "country": "RU",
    "name": "Ryl’sk",
    "lat": "51.5655",
    "lng": "34.6822"
  },
  {
    "country": "RU",
    "name": "Gedzhukh",
    "lat": "42.12786",
    "lng": "48.06474"
  },
  {
    "country": "RU",
    "name": "Krasnoyarskaya",
    "lat": "47.4955",
    "lng": "42.1856"
  },
  {
    "country": "RU",
    "name": "Vidyayevo",
    "lat": "69.31914",
    "lng": "32.80488"
  },
  {
    "country": "RU",
    "name": "Snezhnogorsk",
    "lat": "69.19333",
    "lng": "33.25314"
  },
  {
    "country": "RU",
    "name": "Kokrek",
    "lat": "43.23639",
    "lng": "46.72665"
  },
  {
    "country": "RU",
    "name": "Kontenko",
    "lat": "45.35806",
    "lng": "36.83222"
  },
  {
    "country": "RU",
    "name": "Vyshestebliyevskaya",
    "lat": "45.19611",
    "lng": "37.01806"
  },
  {
    "country": "RU",
    "name": "Pervomayskoye",
    "lat": "43.91904",
    "lng": "46.71019"
  },
  {
    "country": "RU",
    "name": "Vostochny",
    "lat": "44.31494",
    "lng": "44.19637"
  },
  {
    "country": "RU",
    "name": "Stepnoye",
    "lat": "44.27083",
    "lng": "44.585"
  },
  {
    "country": "RU",
    "name": "Kara-Tyube",
    "lat": "44.63361",
    "lng": "45.43694"
  },
  {
    "country": "RU",
    "name": "Neftekumsk",
    "lat": "44.75583",
    "lng": "44.9925"
  },
  {
    "country": "RU",
    "name": "Imeni Pervogo Maya",
    "lat": "50.88997",
    "lng": "39.5919"
  },
  {
    "country": "RU",
    "name": "Rabocheostrovsk",
    "lat": "64.98547",
    "lng": "34.76611"
  },
  {
    "country": "RU",
    "name": "Lutkun",
    "lat": "41.48084",
    "lng": "47.68578"
  },
  {
    "country": "RU",
    "name": "Druzhba",
    "lat": "42.24108",
    "lng": "47.99798"
  },
  {
    "country": "RU",
    "name": "Gerga",
    "lat": "42.34645",
    "lng": "47.96333"
  },
  {
    "country": "RU",
    "name": "Alagir",
    "lat": "43.04222",
    "lng": "44.22222"
  },
  {
    "country": "RU",
    "name": "Yuzhnyy",
    "lat": "45.0025",
    "lng": "40.47472"
  },
  {
    "country": "RU",
    "name": "Kovalevskoye",
    "lat": "45.19417",
    "lng": "40.97611"
  },
  {
    "country": "RU",
    "name": "Persianovka",
    "lat": "47.52972",
    "lng": "39.41833"
  },
  {
    "country": "RU",
    "name": "Karamakhi",
    "lat": "42.61934",
    "lng": "47.26017"
  },
  {
    "country": "RU",
    "name": "Alkhan-Churt",
    "lat": "43.35194",
    "lng": "44.78694"
  },
  {
    "country": "RU",
    "name": "Novyy Khushet",
    "lat": "42.89941",
    "lng": "47.5604"
  },
  {
    "country": "RU",
    "name": "Khambi-Irze",
    "lat": "43.23502",
    "lng": "45.45302"
  },
  {
    "country": "RU",
    "name": "Orël-Izumrud",
    "lat": "43.46005",
    "lng": "39.92377"
  },
  {
    "country": "RU",
    "name": "Vysokoye",
    "lat": "43.46304",
    "lng": "39.96701"
  },
  {
    "country": "RU",
    "name": "Sovetskoye",
    "lat": "46.72194",
    "lng": "42.14639"
  },
  {
    "country": "RU",
    "name": "Zavetnyy",
    "lat": "44.9316",
    "lng": "41.1373"
  },
  {
    "country": "RU",
    "name": "Yasnaya Polyana",
    "lat": "44.0225",
    "lng": "42.7539"
  },
  {
    "country": "RU",
    "name": "Ivanovka",
    "lat": "53.34694",
    "lng": "34.21917"
  },
  {
    "country": "RU",
    "name": "Kurovskoye",
    "lat": "54.54299",
    "lng": "36.00262"
  },
  {
    "country": "RU",
    "name": "Il’inskoye",
    "lat": "55.24917",
    "lng": "37.95805"
  },
  {
    "country": "RU",
    "name": "Rozhdestvenskiy",
    "lat": "54.2957",
    "lng": "37.57019"
  },
  {
    "country": "RU",
    "name": "Vorotynsk",
    "lat": "54.42828",
    "lng": "36.04646"
  },
  {
    "country": "RU",
    "name": "Chupryakovo",
    "lat": "55.55282",
    "lng": "36.62721"
  },
  {
    "country": "RU",
    "name": "Annino",
    "lat": "55.58316",
    "lng": "37.26019"
  },
  {
    "country": "RU",
    "name": "Razvilka",
    "lat": "55.59209",
    "lng": "37.74085"
  },
  {
    "country": "RU",
    "name": "Dubovka",
    "lat": "53.95223",
    "lng": "38.06276"
  },
  {
    "country": "RU",
    "name": "Dagomys",
    "lat": "43.66974",
    "lng": "39.66863"
  },
  {
    "country": "RU",
    "name": "Gornoye Loo",
    "lat": "43.71294",
    "lng": "39.60492"
  },
  {
    "country": "RU",
    "name": "Bugry",
    "lat": "60.07121",
    "lng": "30.39225"
  },
  {
    "country": "RU",
    "name": "Ferma",
    "lat": "57.9016",
    "lng": "56.3064"
  },
  {
    "country": "RU",
    "name": "Gorod Shebekino",
    "lat": "50.41667",
    "lng": "36.91667"
  },
  {
    "country": "RU",
    "name": "Korkmaskala",
    "lat": "43.02379",
    "lng": "47.29436"
  },
  {
    "country": "RU",
    "name": "Bol'shoe Isakovo",
    "lat": "54.71774",
    "lng": "20.60284"
  },
  {
    "country": "RU",
    "name": "Maloye Isakovo",
    "lat": "54.73269",
    "lng": "20.58413"
  },
  {
    "country": "RU",
    "name": "Otradnoye",
    "lat": "54.94114",
    "lng": "20.11397"
  },
  {
    "country": "RU",
    "name": "Yuzhnyy",
    "lat": "54.54837",
    "lng": "20.59843"
  },
  {
    "country": "RU",
    "name": "Surok",
    "lat": "56.44694",
    "lng": "48.12139"
  },
  {
    "country": "RU",
    "name": "Partsa",
    "lat": "54.3653",
    "lng": "42.8617"
  },
  {
    "country": "RU",
    "name": "Udarnyy",
    "lat": "54.3409",
    "lng": "42.8611"
  },
  {
    "country": "RU",
    "name": "Lepley",
    "lat": "54.3092",
    "lng": "42.8599"
  },
  {
    "country": "RU",
    "name": "Pavlovo",
    "lat": "55.9686",
    "lng": "43.0912"
  },
  {
    "country": "RU",
    "name": "Atlashevo",
    "lat": "56.01235",
    "lng": "47.55615"
  },
  {
    "country": "RU",
    "name": "Privolzhskiy",
    "lat": "55.96135",
    "lng": "48.41512"
  },
  {
    "country": "RU",
    "name": "Belidzhi",
    "lat": "41.89184",
    "lng": "48.41247"
  },
  {
    "country": "RU",
    "name": "Khazar",
    "lat": "41.9974",
    "lng": "48.33325"
  },
  {
    "country": "RU",
    "name": "Zaozërsk",
    "lat": "69.40052",
    "lng": "32.44761"
  },
  {
    "country": "RU",
    "name": "Pervoye Maya",
    "lat": "56.16403",
    "lng": "44.71955"
  },
  {
    "country": "RU",
    "name": "Pasha",
    "lat": "60.39546",
    "lng": "33.04308"
  },
  {
    "country": "RU",
    "name": "Lesnoy",
    "lat": "58.63667",
    "lng": "59.80222"
  },
  {
    "country": "RU",
    "name": "Kondratovo",
    "lat": "57.9804",
    "lng": "56.1066"
  },
  {
    "country": "RU",
    "name": "Ileza",
    "lat": "61.05328",
    "lng": "43.90021"
  },
  {
    "country": "RU",
    "name": "Trëkhgornyy",
    "lat": "54.815",
    "lng": "58.45917"
  },
  {
    "country": "RU",
    "name": "Mirnyy",
    "lat": "62.76409",
    "lng": "40.33746"
  },
  {
    "country": "RU",
    "name": "Znamensk",
    "lat": "48.5842",
    "lng": "45.7338"
  },
  {
    "country": "RU",
    "name": "Svetlyy",
    "lat": "51.6737",
    "lng": "45.63054"
  },
  {
    "country": "RU",
    "name": "Zvëzdnyy",
    "lat": "57.7325",
    "lng": "56.31472"
  },
  {
    "country": "RU",
    "name": "Zarechnyy",
    "lat": "53.13333",
    "lng": "46.58333"
  },
  {
    "country": "RU",
    "name": "Ozërnyy",
    "lat": "57.9",
    "lng": "33.65"
  },
  {
    "country": "RU",
    "name": "Dvubratskiy",
    "lat": "45.23888",
    "lng": "39.80499"
  },
  {
    "country": "RU",
    "name": "Yuzhnyy",
    "lat": "44.72111",
    "lng": "39.87918"
  },
  {
    "country": "RU",
    "name": "Kochubeyevskoye",
    "lat": "44.64417",
    "lng": "41.84528"
  },
  {
    "country": "RU",
    "name": "Udarnyy",
    "lat": "44.34917",
    "lng": "42.50528"
  },
  {
    "country": "RU",
    "name": "Novoterskiy",
    "lat": "44.14861",
    "lng": "43.0925"
  },
  {
    "country": "RU",
    "name": "Zmeyka",
    "lat": "44.14278",
    "lng": "43.12083"
  },
  {
    "country": "RU",
    "name": "Svetlopolyansk",
    "lat": "59.41836",
    "lng": "52.36045"
  },
  {
    "country": "RU",
    "name": "Net’inka",
    "lat": "53.34778",
    "lng": "34.19111"
  },
  {
    "country": "RU",
    "name": "Putëvka",
    "lat": "53.25833",
    "lng": "34.28778"
  },
  {
    "country": "RU",
    "name": "Kazachka",
    "lat": "53.3644",
    "lng": "38.0694"
  },
  {
    "country": "RU",
    "name": "Vnukovo",
    "lat": "55.61194",
    "lng": "37.29611"
  },
  {
    "country": "RU",
    "name": "Moskovskiy",
    "lat": "55.59911",
    "lng": "37.35495"
  },
  {
    "country": "RU",
    "name": "Zhitnevo",
    "lat": "55.34233",
    "lng": "37.91464"
  },
  {
    "country": "RU",
    "name": "Zubutli-Miatli",
    "lat": "43.19886",
    "lng": "46.81241"
  },
  {
    "country": "RU",
    "name": "Solnechnoye",
    "lat": "43.276",
    "lng": "46.50697"
  },
  {
    "country": "RU",
    "name": "Shamil’kala",
    "lat": "42.68581",
    "lng": "46.86393"
  },
  {
    "country": "RU",
    "name": "Novyy Sulak",
    "lat": "43.21239",
    "lng": "46.81426"
  },
  {
    "country": "RU",
    "name": "Novyy Kostek",
    "lat": "43.3353",
    "lng": "46.82466"
  },
  {
    "country": "RU",
    "name": "Usinsk",
    "lat": "65.99389",
    "lng": "57.52806"
  },
  {
    "country": "RU",
    "name": "Krasnyy Kommunar",
    "lat": "51.96436",
    "lng": "55.3668"
  },
  {
    "country": "RU",
    "name": "Volovo",
    "lat": "53.55831",
    "lng": "38.00285"
  },
  {
    "country": "RU",
    "name": "Mednogorskiy",
    "lat": "43.9178",
    "lng": "41.18255"
  },
  {
    "country": "RU",
    "name": "Khankala",
    "lat": "43.30212",
    "lng": "45.75564"
  },
  {
    "country": "RU",
    "name": "Pravokubanskiy",
    "lat": "43.91721",
    "lng": "41.88413"
  },
  {
    "country": "RU",
    "name": "Novyye Lapsary",
    "lat": "56.0685",
    "lng": "47.2142"
  },
  {
    "country": "RU",
    "name": "Raduzhnyy",
    "lat": "59.48333",
    "lng": "49.65"
  },
  {
    "country": "RU",
    "name": "Priladozhskiy",
    "lat": "59.85",
    "lng": "31.48333"
  },
  {
    "country": "RU",
    "name": "Molochnyy",
    "lat": "68.85389",
    "lng": "33.02046"
  },
  {
    "country": "RU",
    "name": "Iskateley",
    "lat": "67.68026",
    "lng": "53.15117"
  },
  {
    "country": "RU",
    "name": "Tsibanobalka",
    "lat": "44.98034",
    "lng": "37.34384"
  },
  {
    "country": "RU",
    "name": "Myskhako",
    "lat": "44.67139",
    "lng": "37.74333"
  },
  {
    "country": "RU",
    "name": "Lermontovo",
    "lat": "44.3038",
    "lng": "38.7572"
  },
  {
    "country": "RU",
    "name": "Chinar",
    "lat": "42.10798",
    "lng": "48.14321"
  },
  {
    "country": "RU",
    "name": "Petra-Dubrava",
    "lat": "53.29613",
    "lng": "50.36554"
  },
  {
    "country": "RU",
    "name": "Povolzhskiy",
    "lat": "53.5854",
    "lng": "49.7629"
  },
  {
    "country": "RU",
    "name": "Verkhnebakanskiy",
    "lat": "44.84917",
    "lng": "37.65722"
  },
  {
    "country": "RU",
    "name": "Kochubey",
    "lat": "44.38611",
    "lng": "46.5825"
  },
  {
    "country": "RU",
    "name": "Nezhinskiy",
    "lat": "43.92833",
    "lng": "42.68556"
  },
  {
    "country": "RU",
    "name": "Tyube",
    "lat": "43.04926",
    "lng": "47.30742"
  },
  {
    "country": "RU",
    "name": "Novyy Chirkey",
    "lat": "43.16205",
    "lng": "47.05585"
  },
  {
    "country": "RU",
    "name": "Uchkent",
    "lat": "43.11427",
    "lng": "47.08255"
  },
  {
    "country": "RU",
    "name": "Mursalimkino",
    "lat": "55.0379",
    "lng": "58.5585"
  },
  {
    "country": "RU",
    "name": "Belozërnyy",
    "lat": "45.06433",
    "lng": "38.67901"
  },
  {
    "country": "RU",
    "name": "Sovkhoznyy",
    "lat": "45.29462",
    "lng": "38.11384"
  },
  {
    "country": "RU",
    "name": "Raduzhnyy",
    "lat": "55.1368",
    "lng": "38.72803"
  },
  {
    "country": "RU",
    "name": "Biorki",
    "lat": "55.0528",
    "lng": "38.60873"
  },
  {
    "country": "RU",
    "name": "Pervomayskiy",
    "lat": "55.06696",
    "lng": "38.66489"
  },
  {
    "country": "RU",
    "name": "Obukhovo",
    "lat": "59.84389",
    "lng": "30.45111"
  },
  {
    "country": "RU",
    "name": "Galashki",
    "lat": "43.1174",
    "lng": "44.99055"
  },
  {
    "country": "RU",
    "name": "Staryy Malgobek",
    "lat": "43.54437",
    "lng": "44.59592"
  },
  {
    "country": "RU",
    "name": "Sokol",
    "lat": "57.9146",
    "lng": "56.0456"
  },
  {
    "country": "RU",
    "name": "Krasnobrodskiy",
    "lat": "54.1581",
    "lng": "86.4486"
  },
  {
    "country": "RU",
    "name": "Zyuzel’skiy",
    "lat": "56.4856",
    "lng": "60.1331"
  },
  {
    "country": "RU",
    "name": "Zyryanskoye",
    "lat": "56.83058",
    "lng": "86.62734"
  },
  {
    "country": "RU",
    "name": "Zykovo",
    "lat": "55.95503",
    "lng": "93.16093"
  },
  {
    "country": "RU",
    "name": "Zverinogolovskoye",
    "lat": "54.45397",
    "lng": "64.85242"
  },
  {
    "country": "RU",
    "name": "Zudilovo",
    "lat": "53.4927",
    "lng": "83.8937"
  },
  {
    "country": "RU",
    "name": "Zonal’noye",
    "lat": "52.6665",
    "lng": "84.9331"
  },
  {
    "country": "RU",
    "name": "Znamenskoye",
    "lat": "57.12806",
    "lng": "73.82821"
  },
  {
    "country": "RU",
    "name": "Zmeinogorsk",
    "lat": "51.15776",
    "lng": "82.19534"
  },
  {
    "country": "RU",
    "name": "Zheleznodorozhnyy",
    "lat": "55.10183",
    "lng": "61.54926"
  },
  {
    "country": "RU",
    "name": "Zelënyy Bor",
    "lat": "53.62178",
    "lng": "91.61528"
  },
  {
    "country": "RU",
    "name": "Zelenogorskiy",
    "lat": "55.03333",
    "lng": "87"
  },
  {
    "country": "RU",
    "name": "Zelenoborsk",
    "lat": "61.47088",
    "lng": "64.04344"
  },
  {
    "country": "RU",
    "name": "Zdvinsk",
    "lat": "54.70206",
    "lng": "78.66105"
  },
  {
    "country": "RU",
    "name": "Zaykovo",
    "lat": "57.5613",
    "lng": "62.75681"
  },
  {
    "country": "RU",
    "name": "Zav’yalovo",
    "lat": "52.83805",
    "lng": "80.9197"
  },
  {
    "country": "RU",
    "name": "Zavodouspenskoye",
    "lat": "56.86256",
    "lng": "65.01553"
  },
  {
    "country": "RU",
    "name": "Zavodoukovsk",
    "lat": "56.5042",
    "lng": "66.55153"
  },
  {
    "country": "RU",
    "name": "Zaton",
    "lat": "53.29361",
    "lng": "83.80722"
  },
  {
    "country": "RU",
    "name": "Zarinsk",
    "lat": "53.7074",
    "lng": "84.9493"
  },
  {
    "country": "RU",
    "name": "Zarechnyy",
    "lat": "56.811",
    "lng": "61.3254"
  },
  {
    "country": "RU",
    "name": "Zapolyarnyy",
    "lat": "67.49552",
    "lng": "63.73275"
  },
  {
    "country": "RU",
    "name": "Zalesovo",
    "lat": "53.99389",
    "lng": "84.74306"
  },
  {
    "country": "RU",
    "name": "Yuzhnyy",
    "lat": "53.25417",
    "lng": "83.69361"
  },
  {
    "country": "RU",
    "name": "Yuzhnoural’sk",
    "lat": "54.4418",
    "lng": "61.2536"
  },
  {
    "country": "RU",
    "name": "Yushala",
    "lat": "57.07611",
    "lng": "64.26011"
  },
  {
    "country": "RU",
    "name": "Yurty",
    "lat": "56.0498",
    "lng": "97.6348"
  },
  {
    "country": "RU",
    "name": "Yurginskoye",
    "lat": "56.81888",
    "lng": "67.39211"
  },
  {
    "country": "RU",
    "name": "Yurgamysh",
    "lat": "55.37454",
    "lng": "64.46222"
  },
  {
    "country": "RU",
    "name": "Yurga",
    "lat": "55.72306",
    "lng": "84.88611"
  },
  {
    "country": "RU",
    "name": "Yetkul’",
    "lat": "54.8221",
    "lng": "61.588"
  },
  {
    "country": "RU",
    "name": "Yertarskiy",
    "lat": "56.79016",
    "lng": "64.29952"
  },
  {
    "country": "RU",
    "name": "Yermakovskoye",
    "lat": "53.27545",
    "lng": "92.40021"
  },
  {
    "country": "RU",
    "name": "Yeniseysk",
    "lat": "58.44937",
    "lng": "92.17968"
  },
  {
    "country": "RU",
    "name": "Yemel’yanovo",
    "lat": "56.16776",
    "lng": "92.67539"
  },
  {
    "country": "RU",
    "name": "Yemanzhelinsk",
    "lat": "54.75472",
    "lng": "61.32083"
  },
  {
    "country": "RU",
    "name": "Yemanzhelinka",
    "lat": "54.801",
    "lng": "61.2989"
  },
  {
    "country": "RU",
    "name": "Yelanskiy",
    "lat": "56.8419",
    "lng": "62.5014"
  },
  {
    "country": "RU",
    "name": "Yekaterinburg",
    "lat": "56.8519",
    "lng": "60.6122"
  },
  {
    "country": "RU",
    "name": "Yaya",
    "lat": "56.206",
    "lng": "86.44"
  },
  {
    "country": "RU",
    "name": "Yashkino",
    "lat": "55.8736",
    "lng": "85.4265"
  },
  {
    "country": "RU",
    "name": "Yar-Sale",
    "lat": "66.8654",
    "lng": "70.83784"
  },
  {
    "country": "RU",
    "name": "Yarovoye",
    "lat": "52.9273",
    "lng": "78.58"
  },
  {
    "country": "RU",
    "name": "Yarkovo",
    "lat": "57.40386",
    "lng": "67.0639"
  },
  {
    "country": "RU",
    "name": "Yarkovo",
    "lat": "54.8056",
    "lng": "82.5989"
  },
  {
    "country": "RU",
    "name": "Yalutorovsk",
    "lat": "56.65358",
    "lng": "66.30057"
  },
  {
    "country": "RU",
    "name": "Yagunovskiy",
    "lat": "55.2828",
    "lng": "85.978"
  },
  {
    "country": "RU",
    "name": "Yagunovo",
    "lat": "55.24645",
    "lng": "86.01097"
  },
  {
    "country": "RU",
    "name": "Vvedenskoye",
    "lat": "55.47426",
    "lng": "65.08449"
  },
  {
    "country": "RU",
    "name": "Vostochnyy",
    "lat": "58.79991",
    "lng": "61.81391"
  },
  {
    "country": "RU",
    "name": "Vorkuta",
    "lat": "67.49884",
    "lng": "64.05253"
  },
  {
    "country": "RU",
    "name": "Vorgashor",
    "lat": "67.58355",
    "lng": "63.79399"
  },
  {
    "country": "RU",
    "name": "Volchikha",
    "lat": "52.01356",
    "lng": "80.35715"
  },
  {
    "country": "RU",
    "name": "Volchansk",
    "lat": "59.9378",
    "lng": "60.081"
  },
  {
    "country": "RU",
    "name": "Vlasikha",
    "lat": "53.29722",
    "lng": "83.57417"
  },
  {
    "country": "RU",
    "name": "Vkhodnoy",
    "lat": "54.95181",
    "lng": "73.17108"
  },
  {
    "country": "RU",
    "name": "Vishnëvogorsk",
    "lat": "55.9913",
    "lng": "60.6579"
  },
  {
    "country": "RU",
    "name": "Vinzili",
    "lat": "56.95938",
    "lng": "65.7708"
  },
  {
    "country": "RU",
    "name": "Vikulovo",
    "lat": "56.81667",
    "lng": "70.61069"
  },
  {
    "country": "RU",
    "name": "Veseloyarsk",
    "lat": "51.28737",
    "lng": "81.10703"
  },
  {
    "country": "RU",
    "name": "Vershina Tei",
    "lat": "53.26858",
    "lng": "89.56008"
  },
  {
    "country": "RU",
    "name": "Verkh-Suetka",
    "lat": "53.30401",
    "lng": "80.04675"
  },
  {
    "country": "RU",
    "name": "Verkhotur’ye",
    "lat": "58.86271",
    "lng": "60.80536"
  },
  {
    "country": "RU",
    "name": "Verkh-Tula",
    "lat": "54.8839",
    "lng": "82.7762"
  },
  {
    "country": "RU",
    "name": "Verkhnyaya Sysert’",
    "lat": "56.44012",
    "lng": "60.75563"
  },
  {
    "country": "RU",
    "name": "Verkhnyaya Sinyachikha",
    "lat": "57.97604",
    "lng": "61.66733"
  },
  {
    "country": "RU",
    "name": "Verkhnyaya Salda",
    "lat": "58.04874",
    "lng": "60.55949"
  },
  {
    "country": "RU",
    "name": "Verkhnyaya Pyshma",
    "lat": "56.97047",
    "lng": "60.58219"
  },
  {
    "country": "RU",
    "name": "Verkhnyaya Inta",
    "lat": "65.98115",
    "lng": "60.30945"
  },
  {
    "country": "RU",
    "name": "Verkhniy Ufaley",
    "lat": "56.0556",
    "lng": "60.2397"
  },
  {
    "country": "RU",
    "name": "Verkh-Bekhtemir",
    "lat": "52.76596",
    "lng": "85.90508"
  },
  {
    "country": "RU",
    "name": "Verkh-Neyvinskiy",
    "lat": "57.27013",
    "lng": "60.13762"
  },
  {
    "country": "RU",
    "name": "Verkhneye Dubrovo",
    "lat": "56.7528",
    "lng": "61.0468"
  },
  {
    "country": "RU",
    "name": "Verkh-Katunskoye",
    "lat": "52.45",
    "lng": "85.43162"
  },
  {
    "country": "RU",
    "name": "Verkh-Chebula",
    "lat": "56.03062",
    "lng": "87.62215"
  },
  {
    "country": "RU",
    "name": "Vengerovo",
    "lat": "55.68485",
    "lng": "76.74707"
  },
  {
    "country": "RU",
    "name": "Velikopetrovka",
    "lat": "53.25042",
    "lng": "60.48606"
  },
  {
    "country": "RU",
    "name": "Varna",
    "lat": "53.38194",
    "lng": "60.97472"
  },
  {
    "country": "RU",
    "name": "Vargashi",
    "lat": "55.35556",
    "lng": "65.84667"
  },
  {
    "country": "RU",
    "name": "Vakhrushevo",
    "lat": "55.2317",
    "lng": "61.7173"
  },
  {
    "country": "RU",
    "name": "Vagay",
    "lat": "57.93566",
    "lng": "69.01953"
  },
  {
    "country": "RU",
    "name": "Uzhur",
    "lat": "55.31246",
    "lng": "89.83301"
  },
  {
    "country": "RU",
    "name": "Uyar",
    "lat": "55.8118",
    "lng": "94.3247"
  },
  {
    "country": "RU",
    "name": "Uvel’skiy",
    "lat": "54.4446",
    "lng": "61.3574"
  },
  {
    "country": "RU",
    "name": "Uvat",
    "lat": "59.14227",
    "lng": "68.88881"
  },
  {
    "country": "RU",
    "name": "Usyatskoye",
    "lat": "52.56806",
    "lng": "85.76085"
  },
  {
    "country": "RU",
    "name": "Ust’yanka",
    "lat": "53.4527",
    "lng": "78.7425"
  },
  {
    "country": "RU",
    "name": "Ust’-Ulagan",
    "lat": "50.63258",
    "lng": "87.96046"
  },
  {
    "country": "RU",
    "name": "Ust’-Tarka",
    "lat": "55.56715",
    "lng": "75.705"
  },
  {
    "country": "RU",
    "name": "Ust’-Koksa",
    "lat": "50.2696",
    "lng": "85.6108"
  },
  {
    "country": "RU",
    "name": "Ust’-Kan",
    "lat": "50.9276",
    "lng": "84.761"
  },
  {
    "country": "RU",
    "name": "Ust’-Kalmanka",
    "lat": "52.1207",
    "lng": "83.305"
  },
  {
    "country": "RU",
    "name": "Ust’-Ishim",
    "lat": "57.6935",
    "lng": "71.1665"
  },
  {
    "country": "RU",
    "name": "Ust’-Isha",
    "lat": "52.18201",
    "lng": "85.96757"
  },
  {
    "country": "RU",
    "name": "Ust’-Charyshskaya Pristan’",
    "lat": "52.3934",
    "lng": "83.6635"
  },
  {
    "country": "RU",
    "name": "Zelenogorsk",
    "lat": "56.1124",
    "lng": "94.5985"
  },
  {
    "country": "RU",
    "name": "Ust’-Bagaryak",
    "lat": "56.13278",
    "lng": "61.84722"
  },
  {
    "country": "RU",
    "name": "Ust’-Abakan",
    "lat": "53.83651",
    "lng": "91.39077"
  },
  {
    "country": "RU",
    "name": "Uspenka",
    "lat": "56.80158",
    "lng": "69.22702"
  },
  {
    "country": "RU",
    "name": "Urengoy",
    "lat": "65.9655",
    "lng": "78.36929"
  },
  {
    "country": "RU",
    "name": "Uray",
    "lat": "60.13044",
    "lng": "64.78896"
  },
  {
    "country": "RU",
    "name": "Ural",
    "lat": "55.9052",
    "lng": "94.7537"
  },
  {
    "country": "RU",
    "name": "Uporovo",
    "lat": "56.31093",
    "lng": "66.26926"
  },
  {
    "country": "RU",
    "name": "Uk",
    "lat": "55.079",
    "lng": "98.8586"
  },
  {
    "country": "RU",
    "name": "Uglovskoye",
    "lat": "51.3557",
    "lng": "80.1942"
  },
  {
    "country": "RU",
    "name": "Ubinskoye",
    "lat": "55.30675",
    "lng": "79.68016"
  },
  {
    "country": "RU",
    "name": "Tyumentsevo",
    "lat": "53.3224",
    "lng": "81.498"
  },
  {
    "country": "RU",
    "name": "Tyumen",
    "lat": "57.15222",
    "lng": "65.52722"
  },
  {
    "country": "RU",
    "name": "Tyukhtet",
    "lat": "56.53939",
    "lng": "89.31221"
  },
  {
    "country": "RU",
    "name": "Tyukalinsk",
    "lat": "55.87321",
    "lng": "72.19673"
  },
  {
    "country": "RU",
    "name": "Tyubuk",
    "lat": "56.05521",
    "lng": "60.9405"
  },
  {
    "country": "RU",
    "name": "Tyazhinskiy",
    "lat": "56.11607",
    "lng": "88.52279"
  },
  {
    "country": "RU",
    "name": "Turukhansk",
    "lat": "65.79479",
    "lng": "87.95006"
  },
  {
    "country": "RU",
    "name": "Turochak",
    "lat": "52.2576",
    "lng": "87.1224"
  },
  {
    "country": "RU",
    "name": "Turinskaya Sloboda",
    "lat": "57.6232",
    "lng": "64.38575"
  },
  {
    "country": "RU",
    "name": "Turinsk",
    "lat": "58.04575",
    "lng": "63.69605"
  },
  {
    "country": "RU",
    "name": "Turgoyak",
    "lat": "55.15",
    "lng": "60.11833"
  },
  {
    "country": "RU",
    "name": "Turan",
    "lat": "52.1449",
    "lng": "93.91887"
  },
  {
    "country": "RU",
    "name": "Tuim",
    "lat": "54.33949",
    "lng": "89.94586"
  },
  {
    "country": "RU",
    "name": "Tugulym",
    "lat": "57.05906",
    "lng": "64.64251"
  },
  {
    "country": "RU",
    "name": "Tsementnyy",
    "lat": "57.4693",
    "lng": "60.1536"
  },
  {
    "country": "RU",
    "name": "Tsementnozavodskiy",
    "lat": "67.62834",
    "lng": "64.08965"
  },
  {
    "country": "RU",
    "name": "Tselinnoye",
    "lat": "54.50111",
    "lng": "63.67361"
  },
  {
    "country": "RU",
    "name": "Tselinnoye",
    "lat": "53.07822",
    "lng": "85.65363"
  },
  {
    "country": "RU",
    "name": "Trudarmeyskiy",
    "lat": "54.132",
    "lng": "86.4098"
  },
  {
    "country": "RU",
    "name": "Troitsk",
    "lat": "55.70128",
    "lng": "72.23369"
  },
  {
    "country": "RU",
    "name": "Troitskoye",
    "lat": "52.9821",
    "lng": "84.6757"
  },
  {
    "country": "RU",
    "name": "Troitskiy",
    "lat": "57.06028",
    "lng": "63.74811"
  },
  {
    "country": "RU",
    "name": "Troitsk",
    "lat": "54.0979",
    "lng": "61.5773"
  },
  {
    "country": "RU",
    "name": "Topol’noye",
    "lat": "51.5105",
    "lng": "84.4813"
  },
  {
    "country": "RU",
    "name": "Topki",
    "lat": "55.2769",
    "lng": "85.6163"
  },
  {
    "country": "RU",
    "name": "Topchikha",
    "lat": "52.8192",
    "lng": "83.1185"
  },
  {
    "country": "RU",
    "name": "Toora-Khem",
    "lat": "52.46556",
    "lng": "96.11796"
  },
  {
    "country": "RU",
    "name": "Tomsk",
    "lat": "56.49771",
    "lng": "84.97437"
  },
  {
    "country": "RU",
    "name": "Tolmachëvo",
    "lat": "54.9824",
    "lng": "82.7363"
  },
  {
    "country": "RU",
    "name": "Togur",
    "lat": "58.3631",
    "lng": "82.8265"
  },
  {
    "country": "RU",
    "name": "Togul",
    "lat": "53.467",
    "lng": "85.9128"
  },
  {
    "country": "RU",
    "name": "Toguchin",
    "lat": "55.23528",
    "lng": "84.38583"
  },
  {
    "country": "RU",
    "name": "Tobol’sk",
    "lat": "58.19807",
    "lng": "68.25457"
  },
  {
    "country": "RU",
    "name": "Tisul’",
    "lat": "55.76173",
    "lng": "88.31228"
  },
  {
    "country": "RU",
    "name": "Tinskoy",
    "lat": "56.1513",
    "lng": "96.9173"
  },
  {
    "country": "RU",
    "name": "Timiryazevskoye",
    "lat": "56.48988",
    "lng": "84.87795"
  },
  {
    "country": "RU",
    "name": "Teya",
    "lat": "60.37202",
    "lng": "92.62956"
  },
  {
    "country": "RU",
    "name": "Tevriz",
    "lat": "57.509",
    "lng": "72.4042"
  },
  {
    "country": "RU",
    "name": "Temirtau",
    "lat": "53.1377",
    "lng": "87.4538"
  },
  {
    "country": "RU",
    "name": "Tegul’det",
    "lat": "57.30679",
    "lng": "88.16004"
  },
  {
    "country": "RU",
    "name": "Teeli",
    "lat": "51.01398",
    "lng": "90.20535"
  },
  {
    "country": "RU",
    "name": "Tazovskiy",
    "lat": "67.4715",
    "lng": "78.7162"
  },
  {
    "country": "RU",
    "name": "Tayzhina",
    "lat": "53.6679",
    "lng": "87.4362"
  },
  {
    "country": "RU",
    "name": "Tayshet",
    "lat": "55.9342",
    "lng": "98.0044"
  },
  {
    "country": "RU",
    "name": "Tayginka",
    "lat": "55.6244",
    "lng": "60.5076"
  },
  {
    "country": "RU",
    "name": "Tayga",
    "lat": "56.06402",
    "lng": "85.62238"
  },
  {
    "country": "RU",
    "name": "Tavricheskoye",
    "lat": "54.58508",
    "lng": "73.6395"
  },
  {
    "country": "RU",
    "name": "Tavda",
    "lat": "58.04254",
    "lng": "65.27258"
  },
  {
    "country": "RU",
    "name": "Tatarsk",
    "lat": "55.21903",
    "lng": "75.98283"
  },
  {
    "country": "RU",
    "name": "Tashtyp",
    "lat": "52.79542",
    "lng": "89.89477"
  },
  {
    "country": "RU",
    "name": "Tashtagol",
    "lat": "52.7657",
    "lng": "87.8894"
  },
  {
    "country": "RU",
    "name": "Tashara",
    "lat": "55.5195",
    "lng": "83.5094"
  },
  {
    "country": "RU",
    "name": "Tashanta",
    "lat": "49.71573",
    "lng": "89.19425"
  },
  {
    "country": "RU",
    "name": "Taseyevo",
    "lat": "57.21457",
    "lng": "94.89393"
  },
  {
    "country": "RU",
    "name": "Tarko-Sale",
    "lat": "64.91611",
    "lng": "77.77457"
  },
  {
    "country": "RU",
    "name": "Tara",
    "lat": "56.89436",
    "lng": "74.37096"
  },
  {
    "country": "RU",
    "name": "Talnakh",
    "lat": "69.4865",
    "lng": "88.3972"
  },
  {
    "country": "RU",
    "name": "Tal’menka",
    "lat": "53.8183",
    "lng": "83.5677"
  },
  {
    "country": "RU",
    "name": "Talitsa",
    "lat": "56.8804",
    "lng": "60.0213"
  },
  {
    "country": "RU",
    "name": "Talitsa",
    "lat": "57.01095",
    "lng": "63.73254"
  },
  {
    "country": "RU",
    "name": "Tabuny",
    "lat": "52.7773",
    "lng": "78.7896"
  },
  {
    "country": "RU",
    "name": "Tabory",
    "lat": "58.51982",
    "lng": "64.54947"
  },
  {
    "country": "RU",
    "name": "Sysert’",
    "lat": "56.50243",
    "lng": "60.81917"
  },
  {
    "country": "RU",
    "name": "Sychëvka",
    "lat": "52.0512",
    "lng": "84.7788"
  },
  {
    "country": "RU",
    "name": "Svetlyy",
    "lat": "56.91667",
    "lng": "85.96667"
  },
  {
    "country": "RU",
    "name": "Svetlyy",
    "lat": "50.81833",
    "lng": "60.85194"
  },
  {
    "country": "RU",
    "name": "Svetlogorsk",
    "lat": "66.93762",
    "lng": "88.35265"
  },
  {
    "country": "RU",
    "name": "Suzun",
    "lat": "53.7841",
    "lng": "82.3116"
  },
  {
    "country": "RU",
    "name": "Sut-Khol’",
    "lat": "51.40698",
    "lng": "91.29244"
  },
  {
    "country": "RU",
    "name": "Suslovo",
    "lat": "56.21667",
    "lng": "88.11667"
  },
  {
    "country": "RU",
    "name": "Surgut",
    "lat": "61.25",
    "lng": "73.41667"
  },
  {
    "country": "RU",
    "name": "Sumkino",
    "lat": "58.11083",
    "lng": "68.32444"
  },
  {
    "country": "RU",
    "name": "Sukpak",
    "lat": "51.66667",
    "lng": "94.63333"
  },
  {
    "country": "RU",
    "name": "Sukhoy Log",
    "lat": "56.9094",
    "lng": "62.0296"
  },
  {
    "country": "RU",
    "name": "Sukhobuzimskoye",
    "lat": "56.5",
    "lng": "93.27278"
  },
  {
    "country": "RU",
    "name": "Stukovo",
    "lat": "53.21278",
    "lng": "83.33778"
  },
  {
    "country": "RU",
    "name": "Strezhevoy",
    "lat": "60.7333",
    "lng": "77.5889"
  },
  {
    "country": "RU",
    "name": "Strelka",
    "lat": "58.07278",
    "lng": "93.03444"
  },
  {
    "country": "RU",
    "name": "Staryy Togul",
    "lat": "53.4291",
    "lng": "85.9006"
  },
  {
    "country": "RU",
    "name": "Staryy Nadym",
    "lat": "65.61182",
    "lng": "72.68417"
  },
  {
    "country": "RU",
    "name": "Staropyshminsk",
    "lat": "56.93867",
    "lng": "60.90295"
  },
  {
    "country": "RU",
    "name": "Staropesterevo",
    "lat": "54.5001",
    "lng": "86.4094"
  },
  {
    "country": "RU",
    "name": "Starobachaty",
    "lat": "54.2425",
    "lng": "86.2072"
  },
  {
    "country": "RU",
    "name": "Staroaleyskoye",
    "lat": "51.00611",
    "lng": "82"
  },
  {
    "country": "RU",
    "name": "Starobelokurikha",
    "lat": "52.05206",
    "lng": "85.08765"
  },
  {
    "country": "RU",
    "name": "Stantsionno-Oyashinskiy",
    "lat": "55.4664",
    "lng": "83.8245"
  },
  {
    "country": "RU",
    "name": "Srostki",
    "lat": "52.4209",
    "lng": "85.69923"
  },
  {
    "country": "RU",
    "name": "Sredneuralsk",
    "lat": "56.98921",
    "lng": "60.46662"
  },
  {
    "country": "RU",
    "name": "Spassk",
    "lat": "52.747",
    "lng": "87.7545"
  },
  {
    "country": "RU",
    "name": "Sovkhoznyy",
    "lat": "56.5599",
    "lng": "61.426"
  },
  {
    "country": "RU",
    "name": "Sovetskoye",
    "lat": "52.28556",
    "lng": "85.41424"
  },
  {
    "country": "RU",
    "name": "Sovetskiy",
    "lat": "67.48333",
    "lng": "64.41667"
  },
  {
    "country": "RU",
    "name": "Sovetskiy",
    "lat": "61.36139",
    "lng": "63.58417"
  },
  {
    "country": "RU",
    "name": "Sos’va",
    "lat": "59.17662",
    "lng": "61.85579"
  },
  {
    "country": "RU",
    "name": "Sosnovoborsk",
    "lat": "56.1217",
    "lng": "93.3385"
  },
  {
    "country": "RU",
    "name": "Sosnovka",
    "lat": "53.6676",
    "lng": "87.1527"
  },
  {
    "country": "RU",
    "name": "Sorsk",
    "lat": "54.00333",
    "lng": "90.24667"
  },
  {
    "country": "RU",
    "name": "Sorokino",
    "lat": "53.75",
    "lng": "84.91667"
  },
  {
    "country": "RU",
    "name": "Solton",
    "lat": "52.8429",
    "lng": "86.4787"
  },
  {
    "country": "RU",
    "name": "Soloneshnoye",
    "lat": "51.6544",
    "lng": "84.3197"
  },
  {
    "country": "RU",
    "name": "Sokur",
    "lat": "55.2093",
    "lng": "83.319"
  },
  {
    "country": "RU",
    "name": "Sokolovo",
    "lat": "52.5318",
    "lng": "84.7896"
  },
  {
    "country": "RU",
    "name": "Snezhnogorsk",
    "lat": "68.09306",
    "lng": "87.74"
  },
  {
    "country": "RU",
    "name": "Smolenskoye",
    "lat": "52.30447",
    "lng": "85.0785"
  },
  {
    "country": "RU",
    "name": "Slavgorodskoye",
    "lat": "53.0214",
    "lng": "78.6435"
  },
  {
    "country": "RU",
    "name": "Slavgorod",
    "lat": "52.9978",
    "lng": "78.6449"
  },
  {
    "country": "RU",
    "name": "Sladkovo",
    "lat": "55.52835",
    "lng": "70.33854"
  },
  {
    "country": "RU",
    "name": "Shushenskoye",
    "lat": "53.325",
    "lng": "91.93556"
  },
  {
    "country": "RU",
    "name": "Shumskiy",
    "lat": "54.8318",
    "lng": "99.1328"
  },
  {
    "country": "RU",
    "name": "Shumikha",
    "lat": "55.22611",
    "lng": "63.29611"
  },
  {
    "country": "RU",
    "name": "Shul’gin Log",
    "lat": "52.16985",
    "lng": "85.85573"
  },
  {
    "country": "RU",
    "name": "Shubenka",
    "lat": "52.6551",
    "lng": "85.09858"
  },
  {
    "country": "RU",
    "name": "Shitkino",
    "lat": "56.3703",
    "lng": "98.3543"
  },
  {
    "country": "RU",
    "name": "Shirokaya Rechka",
    "lat": "56.79858",
    "lng": "60.48522"
  },
  {
    "country": "RU",
    "name": "Shira",
    "lat": "54.49111",
    "lng": "89.95306"
  },
  {
    "country": "RU",
    "name": "Shipunovo",
    "lat": "52.1582",
    "lng": "82.2173"
  },
  {
    "country": "RU",
    "name": "Sherkaly",
    "lat": "62.75806",
    "lng": "65.47528"
  },
  {
    "country": "RU",
    "name": "Sheregesh",
    "lat": "52.9209",
    "lng": "87.9869"
  },
  {
    "country": "RU",
    "name": "Sherbakul’",
    "lat": "54.63159",
    "lng": "72.39635"
  },
  {
    "country": "RU",
    "name": "Shelabolikha",
    "lat": "53.4131",
    "lng": "82.6167"
  },
  {
    "country": "RU",
    "name": "Sheberta",
    "lat": "54.64178",
    "lng": "99.89209"
  },
  {
    "country": "RU",
    "name": "Shebalino",
    "lat": "51.29167",
    "lng": "85.67722"
  },
  {
    "country": "RU",
    "name": "Shchelkun",
    "lat": "56.30338",
    "lng": "60.94831"
  },
  {
    "country": "RU",
    "name": "Shatrovo",
    "lat": "56.5197",
    "lng": "64.632"
  },
  {
    "country": "RU",
    "name": "Sharypovo",
    "lat": "55.54028",
    "lng": "89.20083"
  },
  {
    "country": "RU",
    "name": "Shalinskoye",
    "lat": "55.7194",
    "lng": "93.7589"
  },
  {
    "country": "RU",
    "name": "Shakhi",
    "lat": "53.3361",
    "lng": "83.3624"
  },
  {
    "country": "RU",
    "name": "Shagonar",
    "lat": "51.534",
    "lng": "92.93164"
  },
  {
    "country": "RU",
    "name": "Shadrinsk",
    "lat": "56.0852",
    "lng": "63.6335"
  },
  {
    "country": "RU",
    "name": "Shabrovskiy",
    "lat": "56.63597",
    "lng": "60.58065"
  },
  {
    "country": "RU",
    "name": "Severo-Yeniseyskiy",
    "lat": "60.37552",
    "lng": "93.03017"
  },
  {
    "country": "RU",
    "name": "Severnoye",
    "lat": "56.34912",
    "lng": "78.36189"
  },
  {
    "country": "RU",
    "name": "Severka",
    "lat": "56.8688",
    "lng": "60.3015"
  },
  {
    "country": "RU",
    "name": "Severka",
    "lat": "52.13333",
    "lng": "79.28333"
  },
  {
    "country": "RU",
    "name": "Serov",
    "lat": "59.60334",
    "lng": "60.5787"
  },
  {
    "country": "RU",
    "name": "Novoseleznëvo",
    "lat": "55.68207",
    "lng": "69.20562"
  },
  {
    "country": "RU",
    "name": "Sayansk",
    "lat": "54.15",
    "lng": "91.885"
  },
  {
    "country": "RU",
    "name": "Sayanogorsk",
    "lat": "53.0875",
    "lng": "91.39972"
  },
  {
    "country": "RU",
    "name": "Saryg-Sep",
    "lat": "51.49074",
    "lng": "95.56081"
  },
  {
    "country": "RU",
    "name": "Sargazy",
    "lat": "55.02064",
    "lng": "61.24985"
  },
  {
    "country": "RU",
    "name": "Sargatskoye",
    "lat": "55.61006",
    "lng": "73.49716"
  },
  {
    "country": "RU",
    "name": "Saranpaul’",
    "lat": "64.26102",
    "lng": "60.90233"
  },
  {
    "country": "RU",
    "name": "Sannikovo",
    "lat": "53.3448",
    "lng": "83.9749"
  },
  {
    "country": "RU",
    "name": "Samus’",
    "lat": "56.74482",
    "lng": "84.70422"
  },
  {
    "country": "RU",
    "name": "Samagaltay",
    "lat": "50.6022",
    "lng": "95.0047"
  },
  {
    "country": "RU",
    "name": "Salym",
    "lat": "60.0625",
    "lng": "71.47889"
  },
  {
    "country": "RU",
    "name": "Salekhard",
    "lat": "66.53",
    "lng": "66.60194"
  },
  {
    "country": "RU",
    "name": "Salair",
    "lat": "54.2312",
    "lng": "85.7972"
  },
  {
    "country": "RU",
    "name": "Safakulevo",
    "lat": "54.9901",
    "lng": "62.5442"
  },
  {
    "country": "RU",
    "name": "Sovkhoznyy",
    "lat": "56.76374",
    "lng": "60.54938"
  },
  {
    "country": "RU",
    "name": "Russkinskiye",
    "lat": "62.1538",
    "lng": "73.60102"
  },
  {
    "country": "RU",
    "name": "Russkaya Polyana",
    "lat": "53.77944",
    "lng": "73.88056"
  },
  {
    "country": "RU",
    "name": "Rudnichnyy",
    "lat": "59.70118",
    "lng": "60.28817"
  },
  {
    "country": "RU",
    "name": "Rudnichnyy",
    "lat": "56.08469",
    "lng": "86.24988"
  },
  {
    "country": "RU",
    "name": "Rubtsovsk",
    "lat": "51.51473",
    "lng": "81.20613"
  },
  {
    "country": "RU",
    "name": "Roza",
    "lat": "54.9163",
    "lng": "61.4586"
  },
  {
    "country": "RU",
    "name": "Rostovka",
    "lat": "55.3842",
    "lng": "71.88913"
  },
  {
    "country": "RU",
    "name": "Romanovo",
    "lat": "52.6182",
    "lng": "81.2271"
  },
  {
    "country": "RU",
    "name": "Rodino",
    "lat": "52.49783",
    "lng": "80.20294"
  },
  {
    "country": "RU",
    "name": "Rezh",
    "lat": "57.37005",
    "lng": "61.40428"
  },
  {
    "country": "RU",
    "name": "Reftinskiy",
    "lat": "57.09013",
    "lng": "61.67692"
  },
  {
    "country": "RU",
    "name": "Rebrikha",
    "lat": "53.07333",
    "lng": "82.34083"
  },
  {
    "country": "RU",
    "name": "Razdolinsk",
    "lat": "58.42111",
    "lng": "94.66583"
  },
  {
    "country": "RU",
    "name": "Rassvet",
    "lat": "56.999",
    "lng": "91.4724"
  },
  {
    "country": "RU",
    "name": "Pyshma",
    "lat": "56.95226",
    "lng": "63.25129"
  },
  {
    "country": "RU",
    "name": "Prosvet",
    "lat": "55.57028",
    "lng": "65.0825"
  },
  {
    "country": "RU",
    "name": "Promyshlennyy",
    "lat": "67.58333",
    "lng": "63.91667"
  },
  {
    "country": "RU",
    "name": "Promyshlennovskiy",
    "lat": "55.48333",
    "lng": "86.2"
  },
  {
    "country": "RU",
    "name": "Promyshlennaya",
    "lat": "54.9159",
    "lng": "85.6385"
  },
  {
    "country": "RU",
    "name": "Prokudskoye",
    "lat": "55.0089",
    "lng": "82.4574"
  },
  {
    "country": "RU",
    "name": "Prokop’yevsk",
    "lat": "53.9059",
    "lng": "86.719"
  },
  {
    "country": "RU",
    "name": "Pritomskiy",
    "lat": "53.7724",
    "lng": "87.6082"
  },
  {
    "country": "RU",
    "name": "Predivinsk",
    "lat": "57.0631",
    "lng": "93.4374"
  },
  {
    "country": "RU",
    "name": "Poykovskiy",
    "lat": "61.23333",
    "lng": "73.33333"
  },
  {
    "country": "RU",
    "name": "Potanino",
    "lat": "55.1786",
    "lng": "61.6222"
  },
  {
    "country": "RU",
    "name": "Pospelikha",
    "lat": "51.95",
    "lng": "81.76667"
  },
  {
    "country": "RU",
    "name": "Polysayevo",
    "lat": "54.6012",
    "lng": "86.2459"
  },
  {
    "country": "RU",
    "name": "Polunochnoye",
    "lat": "60.86972",
    "lng": "60.41528"
  },
  {
    "country": "RU",
    "name": "Poltavka",
    "lat": "54.36629",
    "lng": "71.76319"
  },
  {
    "country": "RU",
    "name": "Polovinnoye",
    "lat": "54.79139",
    "lng": "65.98639"
  },
  {
    "country": "RU",
    "name": "Polovinnoye",
    "lat": "53.75671",
    "lng": "79.24327"
  },
  {
    "country": "RU",
    "name": "Polevskoy",
    "lat": "56.44222",
    "lng": "60.18778"
  },
  {
    "country": "RU",
    "name": "Poletayevo",
    "lat": "55.0336",
    "lng": "61.1138"
  },
  {
    "country": "RU",
    "name": "Pokrovskoye",
    "lat": "56.4704",
    "lng": "61.6092"
  },
  {
    "country": "RU",
    "name": "Podsosnovo",
    "lat": "53.3721",
    "lng": "78.9184"
  },
  {
    "country": "RU",
    "name": "Podsineye",
    "lat": "53.66583",
    "lng": "91.53639"
  },
  {
    "country": "RU",
    "name": "Podgornoye",
    "lat": "57.78861",
    "lng": "82.65194"
  },
  {
    "country": "RU",
    "name": "Plast",
    "lat": "54.36914",
    "lng": "60.81361"
  },
  {
    "country": "RU",
    "name": "Pirovskoye",
    "lat": "57.63012",
    "lng": "92.26373"
  },
  {
    "country": "RU",
    "name": "Pionerskiy",
    "lat": "61.19472",
    "lng": "62.86889"
  },
  {
    "country": "RU",
    "name": "Pioner",
    "lat": "55.3166",
    "lng": "85.9508"
  },
  {
    "country": "RU",
    "name": "Petukhovo",
    "lat": "55.06917",
    "lng": "67.90194"
  },
  {
    "country": "RU",
    "name": "Petropavlovskoye",
    "lat": "52.0712",
    "lng": "84.107"
  },
  {
    "country": "RU",
    "name": "Petrokamenskoye",
    "lat": "57.716",
    "lng": "60.6484"
  },
  {
    "country": "RU",
    "name": "Pervomayskoye",
    "lat": "57.0761",
    "lng": "86.2313"
  },
  {
    "country": "RU",
    "name": "Pervomayskoye",
    "lat": "53.72111",
    "lng": "84.01833"
  },
  {
    "country": "RU",
    "name": "Pervomayskiy",
    "lat": "52.9173",
    "lng": "81.6624"
  },
  {
    "country": "RU",
    "name": "Pelym",
    "lat": "61.01083",
    "lng": "61.99778"
  },
  {
    "country": "RU",
    "name": "Pavlovsk",
    "lat": "53.31861",
    "lng": "82.98222"
  },
  {
    "country": "RU",
    "name": "Pavlogradka",
    "lat": "54.2024",
    "lng": "73.5592"
  },
  {
    "country": "RU",
    "name": "Partizanskoye",
    "lat": "55.4972",
    "lng": "94.3922"
  },
  {
    "country": "RU",
    "name": "Parizh",
    "lat": "53.2974",
    "lng": "60.1005"
  },
  {
    "country": "RU",
    "name": "Parabel’",
    "lat": "58.69778",
    "lng": "81.4825"
  },
  {
    "country": "RU",
    "name": "Pankrushikha",
    "lat": "53.83194",
    "lng": "80.34056"
  },
  {
    "country": "RU",
    "name": "Pangody",
    "lat": "65.85002",
    "lng": "74.48593"
  },
  {
    "country": "RU",
    "name": "Ovsyanka",
    "lat": "55.9583",
    "lng": "92.572"
  },
  {
    "country": "RU",
    "name": "Ous",
    "lat": "60.90583",
    "lng": "61.51861"
  },
  {
    "country": "RU",
    "name": "Osinniki",
    "lat": "53.6239",
    "lng": "87.3598"
  },
  {
    "country": "RU",
    "name": "Orlik",
    "lat": "52.5178",
    "lng": "99.825"
  },
  {
    "country": "RU",
    "name": "Ordynskoye",
    "lat": "54.3656",
    "lng": "81.8994"
  },
  {
    "country": "RU",
    "name": "Onokhino",
    "lat": "56.92501",
    "lng": "65.5394"
  },
  {
    "country": "RU",
    "name": "Onguday",
    "lat": "50.75",
    "lng": "86.15"
  },
  {
    "country": "RU",
    "name": "Omutinskiy",
    "lat": "56.47453",
    "lng": "67.67087"
  },
  {
    "country": "RU",
    "name": "Omsk",
    "lat": "54.99244",
    "lng": "73.36859"
  },
  {
    "country": "RU",
    "name": "Okoneshnikovo",
    "lat": "54.83767",
    "lng": "75.08343"
  },
  {
    "country": "RU",
    "name": "Odesskoye",
    "lat": "54.215",
    "lng": "72.9651"
  },
  {
    "country": "RU",
    "name": "Obukhovskoye",
    "lat": "56.8345",
    "lng": "62.612"
  },
  {
    "country": "RU",
    "name": "Ob’",
    "lat": "54.9872",
    "lng": "82.7166"
  },
  {
    "country": "RU",
    "name": "Nyda",
    "lat": "66.62472",
    "lng": "72.92278"
  },
  {
    "country": "RU",
    "name": "Nyagan",
    "lat": "62.14056",
    "lng": "65.39361"
  },
  {
    "country": "RU",
    "name": "Noyabrsk",
    "lat": "63.19309",
    "lng": "75.43728"
  },
  {
    "country": "RU",
    "name": "Novyy Urengoy",
    "lat": "66.08333",
    "lng": "76.63333"
  },
  {
    "country": "RU",
    "name": "Novaya Zaimka",
    "lat": "56.48571",
    "lng": "66.92413"
  },
  {
    "country": "RU",
    "name": "Novovarshavka",
    "lat": "54.1721",
    "lng": "74.6946"
  },
  {
    "country": "RU",
    "name": "Novotyryshkino",
    "lat": "52.0833",
    "lng": "84.9089"
  },
  {
    "country": "RU",
    "name": "Novosineglazovskiy",
    "lat": "55.03928",
    "lng": "61.3768"
  },
  {
    "country": "RU",
    "name": "Novosilikatnyy",
    "lat": "53.30972",
    "lng": "83.62389"
  },
  {
    "country": "RU",
    "name": "Novosibirsk",
    "lat": "55.0415",
    "lng": "82.9346"
  },
  {
    "country": "RU",
    "name": "Novopesterevo",
    "lat": "54.4429",
    "lng": "85.7401"
  },
  {
    "country": "RU",
    "name": "Novoomskiy",
    "lat": "54.84152",
    "lng": "73.30174"
  },
  {
    "country": "RU",
    "name": "Novolugovoye",
    "lat": "54.9792",
    "lng": "83.1138"
  },
  {
    "country": "RU",
    "name": "Novokuznetsk",
    "lat": "53.7557",
    "lng": "87.1099"
  },
  {
    "country": "RU",
    "name": "Novogornyy",
    "lat": "55.63",
    "lng": "60.7919"
  },
  {
    "country": "RU",
    "name": "Novochernorechenskiy",
    "lat": "56.26658",
    "lng": "91.09234"
  },
  {
    "country": "RU",
    "name": "Novobiryusinskiy",
    "lat": "56.9578",
    "lng": "97.7076"
  },
  {
    "country": "RU",
    "name": "Novoasbest",
    "lat": "57.74225",
    "lng": "60.28773"
  },
  {
    "country": "RU",
    "name": "Novoaltaysk",
    "lat": "53.3917",
    "lng": "83.9363"
  },
  {
    "country": "RU",
    "name": "Novoagansk",
    "lat": "61.9449",
    "lng": "76.6625"
  },
  {
    "country": "RU",
    "name": "Novikovo",
    "lat": "52.62231",
    "lng": "85.96392"
  },
  {
    "country": "RU",
    "name": "Novichikha",
    "lat": "52.204",
    "lng": "81.3877"
  },
  {
    "country": "RU",
    "name": "Novaya Lyalya",
    "lat": "59.05503",
    "lng": "60.59899"
  },
  {
    "country": "RU",
    "name": "Norilsk",
    "lat": "69.3535",
    "lng": "88.2027"
  },
  {
    "country": "RU",
    "name": "Nizhnyaya Tavda",
    "lat": "57.67306",
    "lng": "66.1725"
  },
  {
    "country": "RU",
    "name": "Souzga",
    "lat": "51.88722",
    "lng": "85.84944"
  },
  {
    "country": "RU",
    "name": "Nizhnyaya Salda",
    "lat": "58.07756",
    "lng": "60.7202"
  },
  {
    "country": "RU",
    "name": "Nizhnyaya Poyma",
    "lat": "56.1643",
    "lng": "97.2065"
  },
  {
    "country": "RU",
    "name": "Nizhnyaya Omka",
    "lat": "55.43375",
    "lng": "74.94256"
  },
  {
    "country": "RU",
    "name": "Nizhniy Ingash",
    "lat": "56.2003",
    "lng": "96.5373"
  },
  {
    "country": "RU",
    "name": "Nizhnevartovsk",
    "lat": "60.9344",
    "lng": "76.5531"
  },
  {
    "country": "RU",
    "name": "Nizhneudinsk",
    "lat": "54.9076",
    "lng": "99.0276"
  },
  {
    "country": "RU",
    "name": "Nikolo-Pavlovskoye",
    "lat": "57.78306",
    "lng": "60.05778"
  },
  {
    "country": "RU",
    "name": "Nikolayevka",
    "lat": "51.92556",
    "lng": "79.41583"
  },
  {
    "country": "RU",
    "name": "Nikitinskiy",
    "lat": "54.5845",
    "lng": "86.0115"
  },
  {
    "country": "RU",
    "name": "Neyvo-Shaytanskiy",
    "lat": "57.7286",
    "lng": "61.24956"
  },
  {
    "country": "RU",
    "name": "Neyvo-Rudyanka",
    "lat": "57.3444",
    "lng": "60.1343"
  },
  {
    "country": "RU",
    "name": "Nev’yansk",
    "lat": "57.4953",
    "lng": "60.2112"
  },
  {
    "country": "RU",
    "name": "Gal’bshtadt",
    "lat": "53.2264",
    "lng": "78.9845"
  },
  {
    "country": "RU",
    "name": "Nefteyugansk",
    "lat": "61.09979",
    "lng": "72.60349"
  },
  {
    "country": "RU",
    "name": "Nazyvayevsk",
    "lat": "55.56975",
    "lng": "71.35294"
  },
  {
    "country": "RU",
    "name": "Nazarovo",
    "lat": "56.0104",
    "lng": "90.4011"
  },
  {
    "country": "RU",
    "name": "Nauchnyy Gorodok",
    "lat": "53.4203",
    "lng": "83.521"
  },
  {
    "country": "RU",
    "name": "Nalobikha",
    "lat": "53.20056",
    "lng": "84.60389"
  },
  {
    "country": "RU",
    "name": "Nagornyy",
    "lat": "52.7959",
    "lng": "83.5498"
  },
  {
    "country": "RU",
    "name": "Nadym",
    "lat": "65.53333",
    "lng": "72.51667"
  },
  {
    "country": "RU",
    "name": "Myski",
    "lat": "53.709",
    "lng": "87.8014"
  },
  {
    "country": "RU",
    "name": "Muzhi",
    "lat": "65.4003",
    "lng": "64.70278"
  },
  {
    "country": "RU",
    "name": "Muslyumovo",
    "lat": "55.6133",
    "lng": "61.626"
  },
  {
    "country": "RU",
    "name": "Muromtsevo",
    "lat": "56.37238",
    "lng": "75.24175"
  },
  {
    "country": "RU",
    "name": "Mundybash",
    "lat": "53.211",
    "lng": "87.2983"
  },
  {
    "country": "RU",
    "name": "Mugur-Aksy",
    "lat": "50.38072",
    "lng": "90.43739"
  },
  {
    "country": "RU",
    "name": "Motygino",
    "lat": "58.18401",
    "lng": "94.69339"
  },
  {
    "country": "RU",
    "name": "Moskovskiy",
    "lat": "57.11108",
    "lng": "65.42298"
  },
  {
    "country": "RU",
    "name": "Moshkovo",
    "lat": "55.3053",
    "lng": "83.6104"
  },
  {
    "country": "RU",
    "name": "Moryakovskiy Zaton",
    "lat": "56.69448",
    "lng": "84.65145"
  },
  {
    "country": "RU",
    "name": "Mortka",
    "lat": "59.33222",
    "lng": "66.02139"
  },
  {
    "country": "RU",
    "name": "Monetnyy",
    "lat": "57.0472",
    "lng": "60.8794"
  },
  {
    "country": "RU",
    "name": "Molchanovo",
    "lat": "57.58167",
    "lng": "83.76917"
  },
  {
    "country": "RU",
    "name": "Mokrousovo",
    "lat": "55.81028",
    "lng": "66.76528"
  },
  {
    "country": "RU",
    "name": "Mochishche",
    "lat": "55.1586",
    "lng": "83.1229"
  },
  {
    "country": "RU",
    "name": "Mishkino",
    "lat": "55.33889",
    "lng": "63.9175"
  },
  {
    "country": "RU",
    "name": "Minusinsk",
    "lat": "53.71028",
    "lng": "91.6875"
  },
  {
    "country": "RU",
    "name": "Mikhaylovskoye",
    "lat": "51.82389",
    "lng": "79.71722"
  },
  {
    "country": "RU",
    "name": "Miasskoye",
    "lat": "55.2784",
    "lng": "61.8905"
  },
  {
    "country": "RU",
    "name": "Miass",
    "lat": "55.045",
    "lng": "60.10833"
  },
  {
    "country": "RU",
    "name": "Mezhdurechenskiy",
    "lat": "59.6",
    "lng": "65.93333"
  },
  {
    "country": "RU",
    "name": "Mezhdurechensk",
    "lat": "53.69417",
    "lng": "88.06028"
  },
  {
    "country": "RU",
    "name": "Mendeleyevo",
    "lat": "58.16667",
    "lng": "68.3"
  },
  {
    "country": "RU",
    "name": "Mel’nikovo",
    "lat": "56.55738",
    "lng": "84.0835"
  },
  {
    "country": "RU",
    "name": "Melioratorov",
    "lat": "57.21065",
    "lng": "65.60774"
  },
  {
    "country": "RU",
    "name": "Megion",
    "lat": "61.0296",
    "lng": "76.1136"
  },
  {
    "country": "RU",
    "name": "Mayna",
    "lat": "53.00639",
    "lng": "91.48361"
  },
  {
    "country": "RU",
    "name": "Mayma",
    "lat": "52.01577",
    "lng": "85.90963"
  },
  {
    "country": "RU",
    "name": "Maslyanino",
    "lat": "54.34361",
    "lng": "84.21111"
  },
  {
    "country": "RU",
    "name": "Martyush",
    "lat": "56.4",
    "lng": "61.88194"
  },
  {
    "country": "RU",
    "name": "Martynovo",
    "lat": "53.26667",
    "lng": "85.88333"
  },
  {
    "country": "RU",
    "name": "Mariinsk",
    "lat": "56.21389",
    "lng": "87.74722"
  },
  {
    "country": "RU",
    "name": "Manzya",
    "lat": "58.49222",
    "lng": "96.26167"
  },
  {
    "country": "RU",
    "name": "Manzherok",
    "lat": "51.82861",
    "lng": "85.76722"
  },
  {
    "country": "RU",
    "name": "Mamontovo",
    "lat": "52.7055",
    "lng": "81.6244"
  },
  {
    "country": "RU",
    "name": "Malysheva",
    "lat": "57.11851",
    "lng": "61.40345"
  },
  {
    "country": "RU",
    "name": "Malougrenevo",
    "lat": "52.5568",
    "lng": "85.33908"
  },
  {
    "country": "RU",
    "name": "Malinovoye Ozero",
    "lat": "51.67528",
    "lng": "79.7825"
  },
  {
    "country": "RU",
    "name": "Makushino",
    "lat": "55.21028",
    "lng": "67.24417"
  },
  {
    "country": "RU",
    "name": "Lyubinskiy",
    "lat": "55.15421",
    "lng": "72.69247"
  },
  {
    "country": "RU",
    "name": "Luzino",
    "lat": "54.94811",
    "lng": "73.03531"
  },
  {
    "country": "RU",
    "name": "Lugovskoy",
    "lat": "56.95849",
    "lng": "64.52897"
  },
  {
    "country": "RU",
    "name": "Losinyy",
    "lat": "57.13862",
    "lng": "61.06663"
  },
  {
    "country": "RU",
    "name": "Lokosovo",
    "lat": "61.13333",
    "lng": "74.81667"
  },
  {
    "country": "RU",
    "name": "Lobva",
    "lat": "59.18538",
    "lng": "60.51846"
  },
  {
    "country": "RU",
    "name": "Listvyanskiy",
    "lat": "54.4399",
    "lng": "83.4984"
  },
  {
    "country": "RU",
    "name": "Listvyagi",
    "lat": "53.6772",
    "lng": "86.951"
  },
  {
    "country": "RU",
    "name": "Linëvo",
    "lat": "54.4589",
    "lng": "83.3764"
  },
  {
    "country": "RU",
    "name": "Lesosibirsk",
    "lat": "58.23583",
    "lng": "92.48278"
  },
  {
    "country": "RU",
    "name": "Lesogorsk",
    "lat": "56.0458",
    "lng": "99.5136"
  },
  {
    "country": "RU",
    "name": "Lesnoye",
    "lat": "52.46926",
    "lng": "85.25547"
  },
  {
    "country": "RU",
    "name": "Lesnikovo",
    "lat": "55.28222",
    "lng": "65.3175"
  },
  {
    "country": "RU",
    "name": "Leninsk-Kuznetsky",
    "lat": "54.6567",
    "lng": "86.1737"
  },
  {
    "country": "RU",
    "name": "Lebyazh’ye",
    "lat": "55.26889",
    "lng": "66.49472"
  },
  {
    "country": "RU",
    "name": "Lebyazh’ye",
    "lat": "53.24361",
    "lng": "83.65333"
  },
  {
    "country": "RU",
    "name": "Labytnangi",
    "lat": "66.65722",
    "lng": "66.41833"
  },
  {
    "country": "RU",
    "name": "Kyzyl-Mazhalyk",
    "lat": "51.14594",
    "lng": "90.5808"
  },
  {
    "country": "RU",
    "name": "Kyzyl-Khaya",
    "lat": "50.04986",
    "lng": "89.87821"
  },
  {
    "country": "RU",
    "name": "Kyzyl",
    "lat": "51.71472",
    "lng": "94.45338"
  },
  {
    "country": "RU",
    "name": "Kytmanovo",
    "lat": "53.4593",
    "lng": "85.4479"
  },
  {
    "country": "RU",
    "name": "Kyshtym",
    "lat": "55.714",
    "lng": "60.5528"
  },
  {
    "country": "RU",
    "name": "Kyshtovka",
    "lat": "56.55498",
    "lng": "76.62713"
  },
  {
    "country": "RU",
    "name": "Kvitok",
    "lat": "56.0724",
    "lng": "98.4813"
  },
  {
    "country": "RU",
    "name": "Kuzedeyevo",
    "lat": "53.3308",
    "lng": "87.2019"
  },
  {
    "country": "RU",
    "name": "Kuybyshev",
    "lat": "55.44753",
    "lng": "78.32181"
  },
  {
    "country": "RU",
    "name": "Kurtamysh",
    "lat": "54.91028",
    "lng": "64.43194"
  },
  {
    "country": "RU",
    "name": "Kurgan",
    "lat": "55.45",
    "lng": "65.33333"
  },
  {
    "country": "RU",
    "name": "Kuragino",
    "lat": "53.88785",
    "lng": "92.68152"
  },
  {
    "country": "RU",
    "name": "Kupino",
    "lat": "54.36635",
    "lng": "77.29805"
  },
  {
    "country": "RU",
    "name": "Kungurtug",
    "lat": "50.59944",
    "lng": "97.52278"
  },
  {
    "country": "RU",
    "name": "Kunashak",
    "lat": "55.7032",
    "lng": "61.5498"
  },
  {
    "country": "RU",
    "name": "Kuminskiy",
    "lat": "58.66667",
    "lng": "66.56667"
  },
  {
    "country": "RU",
    "name": "Kulunda",
    "lat": "52.566",
    "lng": "78.9385"
  },
  {
    "country": "RU",
    "name": "Kudryashovskiy",
    "lat": "55.0974",
    "lng": "82.7742"
  },
  {
    "country": "RU",
    "name": "Krutinka",
    "lat": "56.0055",
    "lng": "71.51131"
  },
  {
    "country": "RU",
    "name": "Krutikha",
    "lat": "53.9599",
    "lng": "81.2093"
  },
  {
    "country": "RU",
    "name": "Krutaya Gorka",
    "lat": "55.36493",
    "lng": "73.2231"
  },
  {
    "country": "RU",
    "name": "Krivosheino",
    "lat": "57.34306",
    "lng": "83.92611"
  },
  {
    "country": "RU",
    "name": "Krivodanovka",
    "lat": "55.0881",
    "lng": "82.6551"
  },
  {
    "country": "RU",
    "name": "Krasnyy Yar",
    "lat": "57.1275",
    "lng": "84.53028"
  },
  {
    "country": "RU",
    "name": "Krasnyy Yar",
    "lat": "55.24242",
    "lng": "72.92635"
  },
  {
    "country": "RU",
    "name": "Krasnyy Yar",
    "lat": "52.3575",
    "lng": "85.33806"
  },
  {
    "country": "RU",
    "name": "Krasnyy Oktyabr’",
    "lat": "55.65667",
    "lng": "64.81333"
  },
  {
    "country": "RU",
    "name": "Krasnozërskoye",
    "lat": "53.98277",
    "lng": "79.23735"
  },
  {
    "country": "RU",
    "name": "Krasnoye",
    "lat": "54.6068",
    "lng": "85.3899"
  },
  {
    "country": "RU",
    "name": "Krasnoyarsk",
    "lat": "56.01839",
    "lng": "92.86717"
  },
  {
    "country": "RU",
    "name": "Krasnoyarka",
    "lat": "55.33333",
    "lng": "73.11667"
  },
  {
    "country": "RU",
    "name": "Krasnoural’sk",
    "lat": "58.3638",
    "lng": "60.0407"
  },
  {
    "country": "RU",
    "name": "Krasnotur’insk",
    "lat": "59.7666",
    "lng": "60.2086"
  },
  {
    "country": "RU",
    "name": "Krasnoturansk",
    "lat": "54.31861",
    "lng": "91.56389"
  },
  {
    "country": "RU",
    "name": "Krasnoshchekovo",
    "lat": "51.67083",
    "lng": "82.72889"
  },
  {
    "country": "RU",
    "name": "Krasnoobsk",
    "lat": "54.9198",
    "lng": "82.9909"
  },
  {
    "country": "RU",
    "name": "Krasnokamensk",
    "lat": "54.33389",
    "lng": "93.25944"
  },
  {
    "country": "RU",
    "name": "Krasnogvardeyskiy",
    "lat": "57.37928",
    "lng": "62.31952"
  },
  {
    "country": "RU",
    "name": "Krasnogorskoye",
    "lat": "52.2953",
    "lng": "86.1979"
  },
  {
    "country": "RU",
    "name": "Krasnogorskiy",
    "lat": "54.6025",
    "lng": "61.231"
  },
  {
    "country": "RU",
    "name": "Krasnogorskiy",
    "lat": "54.5471",
    "lng": "86.281"
  },
  {
    "country": "RU",
    "name": "Krapivinskiy",
    "lat": "54.9992",
    "lng": "86.8133"
  },
  {
    "country": "RU",
    "name": "Kozhevnikovo",
    "lat": "56.25889",
    "lng": "83.97139"
  },
  {
    "country": "RU",
    "name": "Koyelga",
    "lat": "54.65224",
    "lng": "60.9049"
  },
  {
    "country": "RU",
    "name": "Kosikha",
    "lat": "53.36167",
    "lng": "84.58222"
  },
  {
    "country": "RU",
    "name": "Koshurnikovo",
    "lat": "54.16667",
    "lng": "93.3"
  },
  {
    "country": "RU",
    "name": "Kosh-Agach",
    "lat": "49.99273",
    "lng": "88.67598"
  },
  {
    "country": "RU",
    "name": "Kormilovka",
    "lat": "55.00264",
    "lng": "74.10281"
  },
  {
    "country": "RU",
    "name": "Korkino",
    "lat": "54.8913",
    "lng": "61.3969"
  },
  {
    "country": "RU",
    "name": "Kopeysk",
    "lat": "55.11722",
    "lng": "61.62823"
  },
  {
    "country": "RU",
    "name": "Kondinskoye",
    "lat": "59.64806",
    "lng": "67.41"
  },
  {
    "country": "RU",
    "name": "Yugorsk",
    "lat": "61.31226",
    "lng": "63.33067"
  },
  {
    "country": "RU",
    "name": "Kommunisticheskiy",
    "lat": "61.67889",
    "lng": "64.48194"
  },
  {
    "country": "RU",
    "name": "Kommunar",
    "lat": "54.34835",
    "lng": "89.28297"
  },
  {
    "country": "RU",
    "name": "Kolyvan’",
    "lat": "55.3053",
    "lng": "82.7391"
  },
  {
    "country": "RU",
    "name": "Kol’tsovo",
    "lat": "54.9376",
    "lng": "83.1825"
  },
  {
    "country": "RU",
    "name": "Kolpashevo",
    "lat": "58.31306",
    "lng": "82.90889"
  },
  {
    "country": "RU",
    "name": "Kolosovka",
    "lat": "56.46779",
    "lng": "73.61096"
  },
  {
    "country": "RU",
    "name": "Kodinsk",
    "lat": "58.60629",
    "lng": "99.17398"
  },
  {
    "country": "RU",
    "name": "Kochki",
    "lat": "54.33583",
    "lng": "80.48056"
  },
  {
    "country": "RU",
    "name": "Kochenëvo",
    "lat": "55.0218",
    "lng": "82.202"
  },
  {
    "country": "RU",
    "name": "Klyuchi",
    "lat": "52.25303",
    "lng": "79.16868"
  },
  {
    "country": "RU",
    "name": "Klyuchevsk",
    "lat": "57.1216",
    "lng": "60.9414"
  },
  {
    "country": "RU",
    "name": "Kiselëvsk",
    "lat": "53.99",
    "lng": "86.6621"
  },
  {
    "country": "RU",
    "name": "Kirovgrad",
    "lat": "57.42972",
    "lng": "60.05972"
  },
  {
    "country": "RU",
    "name": "Khulimsunt",
    "lat": "62.86333",
    "lng": "61.64361"
  },
  {
    "country": "RU",
    "name": "Khudoyelanskoye",
    "lat": "54.70375",
    "lng": "99.63042"
  },
  {
    "country": "RU",
    "name": "Khovu-Aksy",
    "lat": "51.13294",
    "lng": "93.71286"
  },
  {
    "country": "RU",
    "name": "Kharp",
    "lat": "66.80139",
    "lng": "65.80806"
  },
  {
    "country": "RU",
    "name": "Khanty-Mansiysk",
    "lat": "61.00417",
    "lng": "69.00194"
  },
  {
    "country": "RU",
    "name": "Khandagayty",
    "lat": "50.73333",
    "lng": "92.05"
  },
  {
    "country": "RU",
    "name": "Khabary",
    "lat": "53.62588",
    "lng": "79.5345"
  },
  {
    "country": "RU",
    "name": "Ketovo",
    "lat": "55.355",
    "lng": "65.32583"
  },
  {
    "country": "RU",
    "name": "Kemerovo",
    "lat": "55.33333",
    "lng": "86.08333"
  },
  {
    "country": "RU",
    "name": "Kedrovoye",
    "lat": "57.1576",
    "lng": "60.5698"
  },
  {
    "country": "RU",
    "name": "Kedrovka",
    "lat": "55.53333",
    "lng": "86.05"
  },
  {
    "country": "RU",
    "name": "Kazanskoye",
    "lat": "55.64477",
    "lng": "69.235"
  },
  {
    "country": "RU",
    "name": "Kazachinskoye",
    "lat": "57.7004",
    "lng": "93.2809"
  },
  {
    "country": "RU",
    "name": "Kaz",
    "lat": "52.9113",
    "lng": "87.3105"
  },
  {
    "country": "RU",
    "name": "Kayyerkan",
    "lat": "69.37861",
    "lng": "87.74389"
  },
  {
    "country": "RU",
    "name": "Kataysk",
    "lat": "56.289",
    "lng": "62.5841"
  },
  {
    "country": "RU",
    "name": "Kasli",
    "lat": "55.8909",
    "lng": "60.7616"
  },
  {
    "country": "RU",
    "name": "Kartaly",
    "lat": "53.05285",
    "lng": "60.64903"
  },
  {
    "country": "RU",
    "name": "Karpinsk",
    "lat": "59.7703",
    "lng": "59.9964"
  },
  {
    "country": "RU",
    "name": "Kargat",
    "lat": "55.19556",
    "lng": "80.28111"
  },
  {
    "country": "RU",
    "name": "Kargasok",
    "lat": "59.05556",
    "lng": "80.85722"
  },
  {
    "country": "RU",
    "name": "Karatuzskoye",
    "lat": "53.60722",
    "lng": "92.86667"
  },
  {
    "country": "RU",
    "name": "Karasuk",
    "lat": "53.73772",
    "lng": "78.04026"
  },
  {
    "country": "RU",
    "name": "Karagayla",
    "lat": "54.172",
    "lng": "86.5521"
  },
  {
    "country": "RU",
    "name": "Karabash",
    "lat": "55.4808",
    "lng": "60.2157"
  },
  {
    "country": "RU",
    "name": "Kansk",
    "lat": "56.20167",
    "lng": "95.7175"
  },
  {
    "country": "RU",
    "name": "Kanashevo",
    "lat": "55.2169",
    "lng": "62.0634"
  },
  {
    "country": "RU",
    "name": "Kamyshlov",
    "lat": "56.84278",
    "lng": "62.71111"
  },
  {
    "country": "RU",
    "name": "Kamensk-Ural’skiy",
    "lat": "56.4185",
    "lng": "61.9329"
  },
  {
    "country": "RU",
    "name": "Mys-Kamennyy",
    "lat": "68.45972",
    "lng": "73.59028"
  },
  {
    "country": "RU",
    "name": "Kamen’-na-Obi",
    "lat": "53.7884",
    "lng": "81.3423"
  },
  {
    "country": "RU",
    "name": "Kaltay",
    "lat": "56.27917",
    "lng": "84.87861"
  },
  {
    "country": "RU",
    "name": "Kaltan",
    "lat": "53.5347",
    "lng": "87.2457"
  },
  {
    "country": "RU",
    "name": "Kalmanka",
    "lat": "52.89917",
    "lng": "83.54333"
  },
  {
    "country": "RU",
    "name": "Kalinovo",
    "lat": "57.1317",
    "lng": "60.1464"
  },
  {
    "country": "RU",
    "name": "Kalachinsk",
    "lat": "55.05286",
    "lng": "74.57511"
  },
  {
    "country": "RU",
    "name": "Kaa-Khem",
    "lat": "51.68333",
    "lng": "94.73333"
  },
  {
    "country": "RU",
    "name": "Izumrud",
    "lat": "57.07881",
    "lng": "61.39932"
  },
  {
    "country": "RU",
    "name": "Izhmorskiy",
    "lat": "56.19239",
    "lng": "86.64161"
  },
  {
    "country": "RU",
    "name": "Ivdel’",
    "lat": "60.69111",
    "lng": "60.42056"
  },
  {
    "country": "RU",
    "name": "Itatskiy",
    "lat": "56.07",
    "lng": "89.03694"
  },
  {
    "country": "RU",
    "name": "Iskitim",
    "lat": "54.6366",
    "lng": "83.3045"
  },
  {
    "country": "RU",
    "name": "Ishim",
    "lat": "56.11281",
    "lng": "69.49015"
  },
  {
    "country": "RU",
    "name": "Isetskoye",
    "lat": "56.4858",
    "lng": "65.3226"
  },
  {
    "country": "RU",
    "name": "Iset’",
    "lat": "56.9779",
    "lng": "60.3718"
  },
  {
    "country": "RU",
    "name": "Irtyshskiy",
    "lat": "58.33333",
    "lng": "68.13333"
  },
  {
    "country": "RU",
    "name": "Irtyshskiy",
    "lat": "54.81426",
    "lng": "73.58722"
  },
  {
    "country": "RU",
    "name": "Irsha",
    "lat": "55.9273",
    "lng": "94.7999"
  },
  {
    "country": "RU",
    "name": "Irbit",
    "lat": "57.67052",
    "lng": "63.071"
  },
  {
    "country": "RU",
    "name": "Irbeyskoye",
    "lat": "55.6396",
    "lng": "95.4515"
  },
  {
    "country": "RU",
    "name": "Inya",
    "lat": "53.5044",
    "lng": "82.6712"
  },
  {
    "country": "RU",
    "name": "Inya",
    "lat": "50.46667",
    "lng": "86.61667"
  },
  {
    "country": "RU",
    "name": "Inta",
    "lat": "66.03169",
    "lng": "60.16594"
  },
  {
    "country": "RU",
    "name": "Inskoy",
    "lat": "54.4297",
    "lng": "86.44"
  },
  {
    "country": "RU",
    "name": "Ilanskiy",
    "lat": "56.2325",
    "lng": "96.0652"
  },
  {
    "country": "RU",
    "name": "Ikovka",
    "lat": "55.60889",
    "lng": "64.9375"
  },
  {
    "country": "RU",
    "name": "Igrim",
    "lat": "63.1906",
    "lng": "64.4162"
  },
  {
    "country": "RU",
    "name": "Igarka",
    "lat": "67.4655",
    "lng": "86.6027"
  },
  {
    "country": "RU",
    "name": "Idrinskoye",
    "lat": "54.37083",
    "lng": "92.13583"
  },
  {
    "country": "RU",
    "name": "Gur’yevsk",
    "lat": "54.28333",
    "lng": "85.93333"
  },
  {
    "country": "RU",
    "name": "Gryaznovskoye",
    "lat": "56.7825",
    "lng": "61.7053"
  },
  {
    "country": "RU",
    "name": "Grishkovka",
    "lat": "53.1487",
    "lng": "78.751"
  },
  {
    "country": "RU",
    "name": "Gramoteino",
    "lat": "54.5368",
    "lng": "86.3839"
  },
  {
    "country": "RU",
    "name": "Gornyy Shchit",
    "lat": "56.68815",
    "lng": "60.51947"
  },
  {
    "country": "RU",
    "name": "Gornyy",
    "lat": "55.1153",
    "lng": "83.9059"
  },
  {
    "country": "RU",
    "name": "Gornyak",
    "lat": "55.13446",
    "lng": "61.68268"
  },
  {
    "country": "RU",
    "name": "Gornyak",
    "lat": "50.99417",
    "lng": "81.46611"
  },
  {
    "country": "RU",
    "name": "Gornopravdinsk",
    "lat": "60.05",
    "lng": "69.9"
  },
  {
    "country": "RU",
    "name": "Gorno-Altaysk",
    "lat": "51.96056",
    "lng": "85.91892"
  },
  {
    "country": "RU",
    "name": "Plotnikovo",
    "lat": "55.02472",
    "lng": "85.94361"
  },
  {
    "country": "RU",
    "name": "Gon’ba",
    "lat": "53.4172",
    "lng": "83.5747"
  },
  {
    "country": "RU",
    "name": "Golyshmanovo",
    "lat": "56.3979",
    "lng": "68.37279"
  },
  {
    "country": "RU",
    "name": "Glyadyanskoye",
    "lat": "54.9075",
    "lng": "65.08833"
  },
  {
    "country": "RU",
    "name": "Gari",
    "lat": "59.43075",
    "lng": "62.34967"
  },
  {
    "country": "RU",
    "name": "Filimonovo",
    "lat": "56.20111",
    "lng": "95.46111"
  },
  {
    "country": "RU",
    "name": "Erzin",
    "lat": "50.26",
    "lng": "95.1623"
  },
  {
    "country": "RU",
    "name": "Elekmonar",
    "lat": "51.46083",
    "lng": "86.02194"
  },
  {
    "country": "RU",
    "name": "Dzerzhinskoye",
    "lat": "56.83444",
    "lng": "95.22833"
  },
  {
    "country": "RU",
    "name": "Dvurechensk",
    "lat": "56.5982",
    "lng": "61.0953"
  },
  {
    "country": "RU",
    "name": "Dudinka",
    "lat": "69.40583",
    "lng": "86.17778"
  },
  {
    "country": "RU",
    "name": "Dubrovino",
    "lat": "55.4718",
    "lng": "83.2907"
  },
  {
    "country": "RU",
    "name": "Dubinino",
    "lat": "55.61917",
    "lng": "89.09111"
  },
  {
    "country": "RU",
    "name": "Dorogino",
    "lat": "54.3598",
    "lng": "83.3198"
  },
  {
    "country": "RU",
    "name": "Dolgoderevenskoye",
    "lat": "55.34444",
    "lng": "61.34444"
  },
  {
    "country": "RU",
    "name": "Divnogorsk",
    "lat": "55.9581",
    "lng": "92.3726"
  },
  {
    "country": "RU",
    "name": "Dikson",
    "lat": "73.50819",
    "lng": "80.52918"
  },
  {
    "country": "RU",
    "name": "Degtyarsk",
    "lat": "56.704",
    "lng": "60.0879"
  },
  {
    "country": "RU",
    "name": "Dalmatovo",
    "lat": "56.26",
    "lng": "62.9362"
  },
  {
    "country": "RU",
    "name": "Chunskiy",
    "lat": "56.0815",
    "lng": "99.6342"
  },
  {
    "country": "RU",
    "name": "Chunoyar",
    "lat": "57.4483",
    "lng": "97.3286"
  },
  {
    "country": "RU",
    "name": "Chulym",
    "lat": "55.09972",
    "lng": "80.95722"
  },
  {
    "country": "RU",
    "name": "Choya",
    "lat": "52.0108",
    "lng": "86.5467"
  },
  {
    "country": "RU",
    "name": "Chistogorskiy",
    "lat": "53.9835",
    "lng": "87.3843"
  },
  {
    "country": "RU",
    "name": "Chesma",
    "lat": "53.81111",
    "lng": "60.65333"
  },
  {
    "country": "RU",
    "name": "Chervishevo",
    "lat": "56.94635",
    "lng": "65.42782"
  },
  {
    "country": "RU",
    "name": "Chernogorsk",
    "lat": "53.82361",
    "lng": "91.28417"
  },
  {
    "country": "RU",
    "name": "Cherlak",
    "lat": "54.155",
    "lng": "74.8055"
  },
  {
    "country": "RU",
    "name": "Cherga",
    "lat": "51.56889",
    "lng": "85.5625"
  },
  {
    "country": "RU",
    "name": "Cherepanovo",
    "lat": "54.2222",
    "lng": "83.381"
  },
  {
    "country": "RU",
    "name": "Cherëmushki",
    "lat": "52.85576",
    "lng": "91.41672"
  },
  {
    "country": "RU",
    "name": "Cheremshanka",
    "lat": "56.1192",
    "lng": "60.26804"
  },
  {
    "country": "RU",
    "name": "Cheremnoye",
    "lat": "53.16972",
    "lng": "83.21333"
  },
  {
    "country": "RU",
    "name": "Novobirilyussy",
    "lat": "56.9526",
    "lng": "90.6807"
  },
  {
    "country": "RU",
    "name": "Chemal",
    "lat": "51.41111",
    "lng": "86.005"
  },
  {
    "country": "RU",
    "name": "Chelyabinsk",
    "lat": "55.15402",
    "lng": "61.42915"
  },
  {
    "country": "RU",
    "name": "Chebarkul’",
    "lat": "54.9749",
    "lng": "60.3633"
  },
  {
    "country": "RU",
    "name": "Charyshskoye",
    "lat": "51.3978",
    "lng": "83.5598"
  },
  {
    "country": "RU",
    "name": "Chany",
    "lat": "55.31205",
    "lng": "76.76468"
  },
  {
    "country": "RU",
    "name": "Chadan",
    "lat": "51.28333",
    "lng": "91.58333"
  },
  {
    "country": "RU",
    "name": "Bystryy Istok",
    "lat": "52.371",
    "lng": "84.3873"
  },
  {
    "country": "RU",
    "name": "Bystryanka",
    "lat": "52.28611",
    "lng": "85.82833"
  },
  {
    "country": "RU",
    "name": "Butka",
    "lat": "56.71788",
    "lng": "63.78661"
  },
  {
    "country": "RU",
    "name": "Burla",
    "lat": "53.3362",
    "lng": "78.3301"
  },
  {
    "country": "RU",
    "name": "Bulanash",
    "lat": "57.27825",
    "lng": "61.9965"
  },
  {
    "country": "RU",
    "name": "Brodokalmak",
    "lat": "55.5748",
    "lng": "62.082"
  },
  {
    "country": "RU",
    "name": "Bredy",
    "lat": "52.41528",
    "lng": "60.34111"
  },
  {
    "country": "RU",
    "name": "Borovskiy",
    "lat": "57.04096",
    "lng": "65.72018"
  },
  {
    "country": "RU",
    "name": "Borovoy",
    "lat": "55.43333",
    "lng": "86.08333"
  },
  {
    "country": "RU",
    "name": "Borovikha",
    "lat": "53.5072",
    "lng": "83.8379"
  },
  {
    "country": "RU",
    "name": "Borodino",
    "lat": "55.9061",
    "lng": "94.9079"
  },
  {
    "country": "RU",
    "name": "Bor",
    "lat": "61.60111",
    "lng": "90.01806"
  },
  {
    "country": "RU",
    "name": "Bol’sherech’ye",
    "lat": "56.09252",
    "lng": "74.62716"
  },
  {
    "country": "RU",
    "name": "Bolotnoye",
    "lat": "55.67167",
    "lng": "84.39806"
  },
  {
    "country": "RU",
    "name": "Boguchany",
    "lat": "58.38139",
    "lng": "97.45306"
  },
  {
    "country": "RU",
    "name": "Bograd",
    "lat": "54.23444",
    "lng": "90.83278"
  },
  {
    "country": "RU",
    "name": "Bogotol",
    "lat": "56.20778",
    "lng": "89.53417"
  },
  {
    "country": "RU",
    "name": "Bogdanovich",
    "lat": "56.78028",
    "lng": "62.04944"
  },
  {
    "country": "RU",
    "name": "Bogashevo",
    "lat": "56.36798",
    "lng": "85.14414"
  },
  {
    "country": "RU",
    "name": "Bogandinskiy",
    "lat": "56.89375",
    "lng": "65.89378"
  },
  {
    "country": "RU",
    "name": "Bobrovskiy",
    "lat": "56.6732",
    "lng": "60.9807"
  },
  {
    "country": "RU",
    "name": "Bobrovka",
    "lat": "54.047",
    "lng": "61.7455"
  },
  {
    "country": "RU",
    "name": "Bobrovka",
    "lat": "53.18361",
    "lng": "83.87639"
  },
  {
    "country": "RU",
    "name": "Blagoveshchenka",
    "lat": "52.83333",
    "lng": "79.86667"
  },
  {
    "country": "RU",
    "name": "Biysk",
    "lat": "52.53639",
    "lng": "85.20722"
  },
  {
    "country": "RU",
    "name": "Biskamzha",
    "lat": "53.44972",
    "lng": "89.52722"
  },
  {
    "country": "RU",
    "name": "Biryusinsk",
    "lat": "55.9634",
    "lng": "97.8235"
  },
  {
    "country": "RU",
    "name": "Beya",
    "lat": "53.05333",
    "lng": "90.91389"
  },
  {
    "country": "RU",
    "name": "Beryozovsky",
    "lat": "56.9083",
    "lng": "60.8019"
  },
  {
    "country": "RU",
    "name": "Berëzovskiy",
    "lat": "55.6",
    "lng": "86.2"
  },
  {
    "country": "RU",
    "name": "Berëzovo",
    "lat": "63.93806",
    "lng": "65.04194"
  },
  {
    "country": "RU",
    "name": "Berëzovka",
    "lat": "56.03044",
    "lng": "93.11164"
  },
  {
    "country": "RU",
    "name": "Berëzovka",
    "lat": "52.35111",
    "lng": "85.82722"
  },
  {
    "country": "RU",
    "name": "Beregovoy",
    "lat": "55.17301",
    "lng": "73.21984"
  },
  {
    "country": "RU",
    "name": "Berdsk",
    "lat": "54.7551",
    "lng": "83.0967"
  },
  {
    "country": "RU",
    "name": "Belyy Yar",
    "lat": "58.44472",
    "lng": "85.0425"
  },
  {
    "country": "RU",
    "name": "Belyy Yar",
    "lat": "53.60389",
    "lng": "91.39028"
  },
  {
    "country": "RU",
    "name": "Belyashi",
    "lat": "49.73333",
    "lng": "87.41667"
  },
  {
    "country": "RU",
    "name": "Belozërskoye",
    "lat": "55.82139",
    "lng": "65.58417"
  },
  {
    "country": "RU",
    "name": "Beloyarskiy",
    "lat": "63.71194",
    "lng": "66.67222"
  },
  {
    "country": "RU",
    "name": "Beloyarskiy",
    "lat": "56.7584",
    "lng": "61.4143"
  },
  {
    "country": "RU",
    "name": "Beloyarsk",
    "lat": "53.4461",
    "lng": "83.9048"
  },
  {
    "country": "RU",
    "name": "Belovo",
    "lat": "54.4165",
    "lng": "86.2976"
  },
  {
    "country": "RU",
    "name": "Belokurikha",
    "lat": "51.9959",
    "lng": "84.9896"
  },
  {
    "country": "RU",
    "name": "Belogorsk",
    "lat": "55.01778",
    "lng": "88.48972"
  },
  {
    "country": "RU",
    "name": "Bayunovskiye Klyuchi",
    "lat": "53.32806",
    "lng": "84.18222"
  },
  {
    "country": "RU",
    "name": "Baykit",
    "lat": "61.67694",
    "lng": "96.37917"
  },
  {
    "country": "RU",
    "name": "Bay-Khaak",
    "lat": "51.16105",
    "lng": "94.46371"
  },
  {
    "country": "RU",
    "name": "Baykalovo",
    "lat": "57.39811",
    "lng": "63.76841"
  },
  {
    "country": "RU",
    "name": "Bayevo",
    "lat": "53.27065",
    "lng": "80.77921"
  },
  {
    "country": "RU",
    "name": "Bastan",
    "lat": "51.85889",
    "lng": "79.47444"
  },
  {
    "country": "RU",
    "name": "Barzas",
    "lat": "55.72912",
    "lng": "86.32233"
  },
  {
    "country": "RU",
    "name": "Baryshevo",
    "lat": "54.9564",
    "lng": "83.1822"
  },
  {
    "country": "RU",
    "name": "Barsovo",
    "lat": "61.16667",
    "lng": "73.16667"
  },
  {
    "country": "RU",
    "name": "Barnaul",
    "lat": "53.36056",
    "lng": "83.76361"
  },
  {
    "country": "RU",
    "name": "Barabinsk",
    "lat": "55.35709",
    "lng": "78.35697"
  },
  {
    "country": "RU",
    "name": "Baraba",
    "lat": "56.75",
    "lng": "61.76667"
  },
  {
    "country": "RU",
    "name": "Balgazyn",
    "lat": "51",
    "lng": "95.2"
  },
  {
    "country": "RU",
    "name": "Balakhta",
    "lat": "55.38425",
    "lng": "91.61872"
  },
  {
    "country": "RU",
    "name": "Bakchar",
    "lat": "57.01861",
    "lng": "82.07111"
  },
  {
    "country": "RU",
    "name": "Bagan",
    "lat": "54.10014",
    "lng": "77.66462"
  },
  {
    "country": "RU",
    "name": "Bachatskiy",
    "lat": "54.2927",
    "lng": "86.1285"
  },
  {
    "country": "RU",
    "name": "Azovo",
    "lat": "54.69972",
    "lng": "73.02367"
  },
  {
    "country": "RU",
    "name": "Azanka",
    "lat": "58.04012",
    "lng": "64.78927"
  },
  {
    "country": "RU",
    "name": "Aya",
    "lat": "51.94532",
    "lng": "85.80168"
  },
  {
    "country": "RU",
    "name": "Atagay",
    "lat": "55.1033",
    "lng": "99.3875"
  },
  {
    "country": "RU",
    "name": "Askiz",
    "lat": "53.13722",
    "lng": "90.42833"
  },
  {
    "country": "RU",
    "name": "Askiz",
    "lat": "53.13194",
    "lng": "90.52639"
  },
  {
    "country": "RU",
    "name": "Asino",
    "lat": "56.99987",
    "lng": "86.14393"
  },
  {
    "country": "RU",
    "name": "Asbestovskiy",
    "lat": "57.75574",
    "lng": "61.39672"
  },
  {
    "country": "RU",
    "name": "Asbest",
    "lat": "57.00993",
    "lng": "61.45776"
  },
  {
    "country": "RU",
    "name": "Artyshta",
    "lat": "54.1222",
    "lng": "86.2909"
  },
  {
    "country": "RU",
    "name": "Artybash",
    "lat": "51.79278",
    "lng": "87.27611"
  },
  {
    "country": "RU",
    "name": "Artëmovskiy",
    "lat": "57.3555",
    "lng": "61.86865"
  },
  {
    "country": "RU",
    "name": "Aromashevo",
    "lat": "56.86018",
    "lng": "68.63754"
  },
  {
    "country": "RU",
    "name": "Armizonskoye",
    "lat": "55.94611",
    "lng": "67.67361"
  },
  {
    "country": "RU",
    "name": "Argayash",
    "lat": "55.4888",
    "lng": "60.8767"
  },
  {
    "country": "RU",
    "name": "Aramil",
    "lat": "56.6977",
    "lng": "60.8369"
  },
  {
    "country": "RU",
    "name": "Anzhero-Sudzhensk",
    "lat": "56.081",
    "lng": "86.0285"
  },
  {
    "country": "RU",
    "name": "Anton’yevka",
    "lat": "51.9961",
    "lng": "83.974"
  },
  {
    "country": "RU",
    "name": "Antipino",
    "lat": "57.10679",
    "lng": "65.75755"
  },
  {
    "country": "RU",
    "name": "Andra",
    "lat": "62.51472",
    "lng": "65.88778"
  },
  {
    "country": "RU",
    "name": "Alzamay",
    "lat": "55.5562",
    "lng": "98.6644"
  },
  {
    "country": "RU",
    "name": "Altayskoye",
    "lat": "51.95333",
    "lng": "85.3325"
  },
  {
    "country": "RU",
    "name": "Aleysk",
    "lat": "52.4926",
    "lng": "82.7822"
  },
  {
    "country": "RU",
    "name": "Aleksandrovskoye",
    "lat": "56.74083",
    "lng": "85.39056"
  },
  {
    "country": "RU",
    "name": "Alapayevsk",
    "lat": "57.85158",
    "lng": "61.69627"
  },
  {
    "country": "RU",
    "name": "Aktash",
    "lat": "50.3",
    "lng": "87.73333"
  },
  {
    "country": "RU",
    "name": "Aksarka",
    "lat": "66.56056",
    "lng": "67.7975"
  },
  {
    "country": "RU",
    "name": "Ak-Dovurak",
    "lat": "51.18333",
    "lng": "90.6"
  },
  {
    "country": "RU",
    "name": "Akademgorodok",
    "lat": "54.8523",
    "lng": "83.106"
  },
  {
    "country": "RU",
    "name": "Agirish",
    "lat": "61.92472",
    "lng": "63.02306"
  },
  {
    "country": "RU",
    "name": "Aginskoye",
    "lat": "55.2586",
    "lng": "94.9079"
  },
  {
    "country": "RU",
    "name": "Achinsk",
    "lat": "56.2694",
    "lng": "90.4993"
  },
  {
    "country": "RU",
    "name": "Abaza",
    "lat": "52.655",
    "lng": "90.09278"
  },
  {
    "country": "RU",
    "name": "Abatskoye",
    "lat": "56.28748",
    "lng": "70.45553"
  },
  {
    "country": "RU",
    "name": "Aban",
    "lat": "56.6787",
    "lng": "96.0658"
  },
  {
    "country": "RU",
    "name": "Abalak",
    "lat": "58.12861",
    "lng": "68.59444"
  },
  {
    "country": "RU",
    "name": "Abakan",
    "lat": "53.71556",
    "lng": "91.42917"
  },
  {
    "country": "RU",
    "name": "Abagur",
    "lat": "53.7308",
    "lng": "87.2526"
  },
  {
    "country": "RU",
    "name": "Ursk",
    "lat": "54.45417",
    "lng": "85.40028"
  },
  {
    "country": "RU",
    "name": "Snezhinsk",
    "lat": "56.085",
    "lng": "60.73139"
  },
  {
    "country": "RU",
    "name": "Shuvakish",
    "lat": "56.9187",
    "lng": "60.47727"
  },
  {
    "country": "RU",
    "name": "Istok",
    "lat": "56.79086",
    "lng": "60.77889"
  },
  {
    "country": "RU",
    "name": "Priob’ye",
    "lat": "62.52056",
    "lng": "65.59639"
  },
  {
    "country": "RU",
    "name": "Il’ichevo",
    "lat": "53.27889",
    "lng": "91.84028"
  },
  {
    "country": "RU",
    "name": "Tanzybey",
    "lat": "53.13265",
    "lng": "92.94335"
  },
  {
    "country": "RU",
    "name": "Ozersk",
    "lat": "55.75556",
    "lng": "60.70278"
  },
  {
    "country": "RU",
    "name": "Zheleznogorsk",
    "lat": "56.25111",
    "lng": "93.53194"
  },
  {
    "country": "RU",
    "name": "Novoural’sk",
    "lat": "57.24389",
    "lng": "60.08389"
  },
  {
    "country": "RU",
    "name": "Seversk",
    "lat": "56.60056",
    "lng": "84.88639"
  },
  {
    "country": "RU",
    "name": "Lokomotivnyy",
    "lat": "53.0118",
    "lng": "60.5684"
  },
  {
    "country": "RU",
    "name": "Solnechnyy",
    "lat": "56.11583",
    "lng": "92.92528"
  },
  {
    "country": "RU",
    "name": "Svobodnyy",
    "lat": "58.03972",
    "lng": "60.39611"
  },
  {
    "country": "RU",
    "name": "Kedrovyy",
    "lat": "56.28232",
    "lng": "91.5376"
  },
  {
    "country": "RU",
    "name": "Sibirskiy",
    "lat": "53.5777",
    "lng": "83.7577"
  },
  {
    "country": "RU",
    "name": "Malinovskiy",
    "lat": "61.19528",
    "lng": "62.83972"
  },
  {
    "country": "RU",
    "name": "Novyye Zori",
    "lat": "53.24778",
    "lng": "83.425"
  },
  {
    "country": "RU",
    "name": "Gubkinskiy",
    "lat": "64.434",
    "lng": "76.50261"
  },
  {
    "country": "RU",
    "name": "Purpe",
    "lat": "64.48028",
    "lng": "76.68972"
  },
  {
    "country": "RU",
    "name": "Iogach",
    "lat": "51.78167",
    "lng": "87.26306"
  },
  {
    "country": "RU",
    "name": "Raduzhny",
    "lat": "62.09611",
    "lng": "77.475"
  },
  {
    "country": "RU",
    "name": "Turtas",
    "lat": "58.93867",
    "lng": "69.13393"
  },
  {
    "country": "RU",
    "name": "Kedrovyy",
    "lat": "57.51972",
    "lng": "79.51556"
  },
  {
    "country": "RU",
    "name": "Muravlenko",
    "lat": "63.78977",
    "lng": "74.52301"
  },
  {
    "country": "RU",
    "name": "Starokamyshinsk",
    "lat": "55.03912",
    "lng": "61.58778"
  },
  {
    "country": "RU",
    "name": "Timiryazevskiy",
    "lat": "54.92917",
    "lng": "60.7625"
  },
  {
    "country": "RU",
    "name": "Bazhovo",
    "lat": "55.05955",
    "lng": "61.60445"
  },
  {
    "country": "RU",
    "name": "Roshchino",
    "lat": "55.31012",
    "lng": "61.26363"
  },
  {
    "country": "RU",
    "name": "Lyantor",
    "lat": "61.61945",
    "lng": "72.15546"
  },
  {
    "country": "RU",
    "name": "Sadovyy",
    "lat": "55.1361",
    "lng": "82.9659"
  },
  {
    "country": "RU",
    "name": "Uyskoye",
    "lat": "54.3775",
    "lng": "60.00472"
  },
  {
    "country": "RU",
    "name": "Krasnyy Chikoy",
    "lat": "50.36321",
    "lng": "108.75445"
  },
  {
    "country": "RU",
    "name": "Zvëzdnyy",
    "lat": "56.7492",
    "lng": "106.4799"
  },
  {
    "country": "RU",
    "name": "Zima",
    "lat": "53.9202",
    "lng": "102.0442"
  },
  {
    "country": "RU",
    "name": "Zhireken",
    "lat": "52.82657",
    "lng": "117.30725"
  },
  {
    "country": "RU",
    "name": "Zhigansk",
    "lat": "66.76601",
    "lng": "123.37418"
  },
  {
    "country": "RU",
    "name": "Zhigalovo",
    "lat": "54.81061",
    "lng": "105.15808"
  },
  {
    "country": "RU",
    "name": "Zhemchug",
    "lat": "51.6861",
    "lng": "102.459"
  },
  {
    "country": "RU",
    "name": "Zheleznogorsk-Ilimskiy",
    "lat": "56.5768",
    "lng": "104.1217"
  },
  {
    "country": "RU",
    "name": "Zheleznodorozhnyy",
    "lat": "57.90525",
    "lng": "102.77838"
  },
  {
    "country": "RU",
    "name": "Zhatay",
    "lat": "62.15975",
    "lng": "129.82843"
  },
  {
    "country": "RU",
    "name": "Zharikovo",
    "lat": "44.588",
    "lng": "131.7277"
  },
  {
    "country": "RU",
    "name": "Zeya",
    "lat": "53.73601",
    "lng": "127.257"
  },
  {
    "country": "RU",
    "name": "Zavodskoy",
    "lat": "43.46242",
    "lng": "132.28494"
  },
  {
    "country": "RU",
    "name": "Zavitinsk",
    "lat": "50.11118",
    "lng": "129.44156"
  },
  {
    "country": "RU",
    "name": "Zarubino",
    "lat": "42.63257",
    "lng": "131.09005"
  },
  {
    "country": "RU",
    "name": "Zarechnyy",
    "lat": "51.84928",
    "lng": "107.521"
  },
  {
    "country": "RU",
    "name": "Zalari",
    "lat": "53.5584",
    "lng": "102.5065"
  },
  {
    "country": "RU",
    "name": "Zakamensk",
    "lat": "50.3741",
    "lng": "103.2863"
  },
  {
    "country": "RU",
    "name": "Zaigrayevo",
    "lat": "51.83487",
    "lng": "108.267"
  },
  {
    "country": "RU",
    "name": "Zabaykal’sk",
    "lat": "49.6513",
    "lng": "117.32557"
  },
  {
    "country": "RU",
    "name": "Ytyk-Kyuyël’",
    "lat": "62.36119",
    "lng": "133.56044"
  },
  {
    "country": "RU",
    "name": "Yerofey Pavlovich",
    "lat": "53.96305",
    "lng": "121.95805"
  },
  {
    "country": "RU",
    "name": "Yerbogachen",
    "lat": "61.28016",
    "lng": "108.01535"
  },
  {
    "country": "RU",
    "name": "Yelantsy",
    "lat": "52.80286",
    "lng": "106.40466"
  },
  {
    "country": "RU",
    "name": "Yekaterinovka",
    "lat": "42.92525",
    "lng": "133.04922"
  },
  {
    "country": "RU",
    "name": "Yekaterinoslavka",
    "lat": "50.37344",
    "lng": "129.10957"
  },
  {
    "country": "RU",
    "name": "Yedogon",
    "lat": "54.2549",
    "lng": "100.2385"
  },
  {
    "country": "RU",
    "name": "Yaroslavskiy",
    "lat": "44.18578",
    "lng": "132.22862"
  },
  {
    "country": "RU",
    "name": "Yakutsk",
    "lat": "62.03389",
    "lng": "129.73306"
  },
  {
    "country": "RU",
    "name": "Yakovlevka",
    "lat": "44.42588",
    "lng": "133.47406"
  },
  {
    "country": "RU",
    "name": "Vysokogornyy",
    "lat": "50.09885",
    "lng": "139.12284"
  },
  {
    "country": "RU",
    "name": "Rechka-Vydrino",
    "lat": "51.4892",
    "lng": "104.8429"
  },
  {
    "country": "RU",
    "name": "Vydrino",
    "lat": "51.463",
    "lng": "104.6425"
  },
  {
    "country": "RU",
    "name": "Vyazemskiy",
    "lat": "47.53757",
    "lng": "134.75556"
  },
  {
    "country": "RU",
    "name": "Vrangel’",
    "lat": "42.73021",
    "lng": "133.08322"
  },
  {
    "country": "RU",
    "name": "Vozdvizhenka",
    "lat": "43.89413",
    "lng": "131.94589"
  },
  {
    "country": "RU",
    "name": "Vostok",
    "lat": "46.45148",
    "lng": "135.82738"
  },
  {
    "country": "RU",
    "name": "Volochayevka Vtoraya",
    "lat": "48.56695",
    "lng": "134.58232"
  },
  {
    "country": "RU",
    "name": "Vol’no-Nadezhdinskoye",
    "lat": "43.37496",
    "lng": "131.99675"
  },
  {
    "country": "RU",
    "name": "Volchanets",
    "lat": "42.91388",
    "lng": "132.76222"
  },
  {
    "country": "RU",
    "name": "Vladivostok",
    "lat": "43.10562",
    "lng": "131.87353"
  },
  {
    "country": "RU",
    "name": "Vladimiro-Aleksandrovskoye",
    "lat": "42.89134",
    "lng": "133.07801"
  },
  {
    "country": "RU",
    "name": "Vitim",
    "lat": "59.44326",
    "lng": "112.56993"
  },
  {
    "country": "RU",
    "name": "Vilyuysk",
    "lat": "63.74683",
    "lng": "121.63339"
  },
  {
    "country": "RU",
    "name": "Vikhorevka",
    "lat": "56.12128",
    "lng": "101.17767"
  },
  {
    "country": "RU",
    "name": "Vidim",
    "lat": "56.4088",
    "lng": "103.1106"
  },
  {
    "country": "RU",
    "name": "Vershino-Shakhtaminskiy",
    "lat": "51.30024",
    "lng": "117.88762"
  },
  {
    "country": "RU",
    "name": "Vershino-Darasunskiy",
    "lat": "52.36604",
    "lng": "115.52661"
  },
  {
    "country": "RU",
    "name": "Verkh-Usugli",
    "lat": "52.7",
    "lng": "115.16667"
  },
  {
    "country": "RU",
    "name": "Verkhoyansk",
    "lat": "67.55387",
    "lng": "133.38976"
  },
  {
    "country": "RU",
    "name": "Verkhnevilyuysk",
    "lat": "63.44578",
    "lng": "120.30739"
  },
  {
    "country": "RU",
    "name": "Vanavara",
    "lat": "60.34679",
    "lng": "102.28434"
  },
  {
    "country": "RU",
    "name": "Ust’-Uda",
    "lat": "54.1742",
    "lng": "103.0304"
  },
  {
    "country": "RU",
    "name": "Ust’-Ordynskiy",
    "lat": "52.805",
    "lng": "104.75083"
  },
  {
    "country": "RU",
    "name": "Ust-Maya",
    "lat": "60.41553",
    "lng": "134.54405"
  },
  {
    "country": "RU",
    "name": "Ust-Kuyga",
    "lat": "70.00208",
    "lng": "135.54876"
  },
  {
    "country": "RU",
    "name": "Ust’-Kut",
    "lat": "56.7938",
    "lng": "105.7672"
  },
  {
    "country": "RU",
    "name": "Ust’-Karsk",
    "lat": "52.70206",
    "lng": "118.80163"
  },
  {
    "country": "RU",
    "name": "Ust’-Ilimsk",
    "lat": "58.00056",
    "lng": "102.66194"
  },
  {
    "country": "RU",
    "name": "Ust’-Barguzin",
    "lat": "53.41116",
    "lng": "109.03103"
  },
  {
    "country": "RU",
    "name": "Ussuriysk",
    "lat": "43.80291",
    "lng": "131.94578"
  },
  {
    "country": "RU",
    "name": "Usol’ye-Sibirskoye",
    "lat": "52.75194",
    "lng": "103.64528"
  },
  {
    "country": "RU",
    "name": "Ushumun",
    "lat": "52.78633",
    "lng": "126.53767"
  },
  {
    "country": "RU",
    "name": "Urusha",
    "lat": "54.05303",
    "lng": "122.88561"
  },
  {
    "country": "RU",
    "name": "Urik",
    "lat": "52.46051",
    "lng": "104.24016"
  },
  {
    "country": "RU",
    "name": "Ulety",
    "lat": "51.35589",
    "lng": "112.4843"
  },
  {
    "country": "RU",
    "name": "Ulan-Ude",
    "lat": "51.82721",
    "lng": "107.60627"
  },
  {
    "country": "RU",
    "name": "Uglovoye",
    "lat": "43.32807",
    "lng": "132.08832"
  },
  {
    "country": "RU",
    "name": "Uglekamensk",
    "lat": "43.21996",
    "lng": "133.23177"
  },
  {
    "country": "RU",
    "name": "Udachny",
    "lat": "66.42989",
    "lng": "112.4021"
  },
  {
    "country": "RU",
    "name": "Tyrma",
    "lat": "50.0477",
    "lng": "132.15011"
  },
  {
    "country": "RU",
    "name": "Tyret’ Pervaya",
    "lat": "53.67028",
    "lng": "102.31056"
  },
  {
    "country": "RU",
    "name": "Tynda",
    "lat": "55.156",
    "lng": "124.72479"
  },
  {
    "country": "RU",
    "name": "Tygda",
    "lat": "53.11169",
    "lng": "126.32907"
  },
  {
    "country": "RU",
    "name": "Turuntayevo",
    "lat": "52.20203",
    "lng": "107.64484"
  },
  {
    "country": "RU",
    "name": "Turka",
    "lat": "52.9492",
    "lng": "108.2217"
  },
  {
    "country": "RU",
    "name": "Tura",
    "lat": "64.27769",
    "lng": "100.21849"
  },
  {
    "country": "RU",
    "name": "Tulyushka",
    "lat": "54.45851",
    "lng": "101.17054"
  },
  {
    "country": "RU",
    "name": "Tulun",
    "lat": "54.56358",
    "lng": "100.58143"
  },
  {
    "country": "RU",
    "name": "Trudovoye",
    "lat": "43.29823",
    "lng": "132.06877"
  },
  {
    "country": "RU",
    "name": "Topolëvo",
    "lat": "48.50264",
    "lng": "135.17611"
  },
  {
    "country": "RU",
    "name": "Tommot",
    "lat": "58.95717",
    "lng": "126.29158"
  },
  {
    "country": "RU",
    "name": "Tokur",
    "lat": "53.13531",
    "lng": "132.88996"
  },
  {
    "country": "RU",
    "name": "Tiksi",
    "lat": "71.69002",
    "lng": "128.86467"
  },
  {
    "country": "RU",
    "name": "Fokino",
    "lat": "42.97429",
    "lng": "132.40574"
  },
  {
    "country": "RU",
    "name": "Terney",
    "lat": "45.05278",
    "lng": "136.60881"
  },
  {
    "country": "RU",
    "name": "Tel’ma",
    "lat": "52.6981",
    "lng": "103.7138"
  },
  {
    "country": "RU",
    "name": "Tayturka",
    "lat": "52.86917",
    "lng": "103.46083"
  },
  {
    "country": "RU",
    "name": "Tavrichanka",
    "lat": "43.32551",
    "lng": "131.86264"
  },
  {
    "country": "RU",
    "name": "Novonukutskiy",
    "lat": "53.7002",
    "lng": "102.7117"
  },
  {
    "country": "RU",
    "name": "Tataurovo",
    "lat": "52.14182",
    "lng": "107.44054"
  },
  {
    "country": "RU",
    "name": "Tarbagatay",
    "lat": "51.48195",
    "lng": "107.36158"
  },
  {
    "country": "RU",
    "name": "Tarbagatay",
    "lat": "51.17559",
    "lng": "109.09484"
  },
  {
    "country": "RU",
    "name": "Tankhoy",
    "lat": "51.55683",
    "lng": "105.1262"
  },
  {
    "country": "RU",
    "name": "Tambovka",
    "lat": "50.09968",
    "lng": "128.05724"
  },
  {
    "country": "RU",
    "name": "Taldan",
    "lat": "53.68981",
    "lng": "124.8149"
  },
  {
    "country": "RU",
    "name": "Talakan",
    "lat": "50.26378",
    "lng": "130.26755"
  },
  {
    "country": "RU",
    "name": "Taksimo",
    "lat": "56.34162",
    "lng": "114.90048"
  },
  {
    "country": "RU",
    "name": "Takhtamygda",
    "lat": "54.11031",
    "lng": "123.60802"
  },
  {
    "country": "RU",
    "name": "Tabaga",
    "lat": "61.85502",
    "lng": "129.60022"
  },
  {
    "country": "RU",
    "name": "Svobodnyy",
    "lat": "51.37525",
    "lng": "128.14097"
  },
  {
    "country": "RU",
    "name": "Svirsk",
    "lat": "53.08583",
    "lng": "103.3325"
  },
  {
    "country": "RU",
    "name": "Svetlaya",
    "lat": "46.54217",
    "lng": "138.32973"
  },
  {
    "country": "RU",
    "name": "Suntar",
    "lat": "62.14444",
    "lng": "117.63194"
  },
  {
    "country": "RU",
    "name": "Sretensk",
    "lat": "52.2478",
    "lng": "117.70835"
  },
  {
    "country": "RU",
    "name": "Srednebelaya",
    "lat": "50.65854",
    "lng": "128.00932"
  },
  {
    "country": "RU",
    "name": "Spasskoye",
    "lat": "44.61215",
    "lng": "132.80007"
  },
  {
    "country": "RU",
    "name": "Spassk-Dal’niy",
    "lat": "44.59884",
    "lng": "132.82593"
  },
  {
    "country": "RU",
    "name": "Sotnikovo",
    "lat": "51.88448",
    "lng": "107.4825"
  },
  {
    "country": "RU",
    "name": "Sosnovo-Ozerskoye",
    "lat": "52.52466",
    "lng": "111.54124"
  },
  {
    "country": "RU",
    "name": "Solovjevsk",
    "lat": "54.23333",
    "lng": "124.43333"
  },
  {
    "country": "RU",
    "name": "Solnechnyy",
    "lat": "60.30217",
    "lng": "137.55563"
  },
  {
    "country": "RU",
    "name": "Solnechnyy",
    "lat": "50.72367",
    "lng": "136.63831"
  },
  {
    "country": "RU",
    "name": "Solnechnyy",
    "lat": "50.58333",
    "lng": "137.03333"
  },
  {
    "country": "RU",
    "name": "Sokol",
    "lat": "51.80036",
    "lng": "107.44437"
  },
  {
    "country": "RU",
    "name": "Smolyaninovo",
    "lat": "43.28801",
    "lng": "132.45586"
  },
  {
    "country": "RU",
    "name": "Smolenshchina",
    "lat": "52.25528",
    "lng": "104.12806"
  },
  {
    "country": "RU",
    "name": "Smolenka",
    "lat": "52.13523",
    "lng": "113.4974"
  },
  {
    "country": "RU",
    "name": "Smidovich",
    "lat": "48.59647",
    "lng": "133.80866"
  },
  {
    "country": "RU",
    "name": "Slyudyanka",
    "lat": "51.65944",
    "lng": "103.70611"
  },
  {
    "country": "RU",
    "name": "Slavyanka",
    "lat": "42.86413",
    "lng": "131.3882"
  },
  {
    "country": "RU",
    "name": "Skovorodino",
    "lat": "53.98473",
    "lng": "123.9403"
  },
  {
    "country": "RU",
    "name": "Sivakovka",
    "lat": "44.47838",
    "lng": "132.36718"
  },
  {
    "country": "RU",
    "name": "Sivaki",
    "lat": "52.6343",
    "lng": "126.74777"
  },
  {
    "country": "RU",
    "name": "Shtykovo",
    "lat": "43.38918",
    "lng": "132.36129"
  },
  {
    "country": "RU",
    "name": "Shkotovo",
    "lat": "43.32092",
    "lng": "132.35433"
  },
  {
    "country": "RU",
    "name": "Shirokiy",
    "lat": "49.75907",
    "lng": "129.51988"
  },
  {
    "country": "RU",
    "name": "Shimanovsk",
    "lat": "52.00575",
    "lng": "127.67756"
  },
  {
    "country": "RU",
    "name": "Shilka",
    "lat": "51.85",
    "lng": "116.03333"
  },
  {
    "country": "RU",
    "name": "Shestakovo",
    "lat": "56.4915",
    "lng": "103.96"
  },
  {
    "country": "RU",
    "name": "Sheragul",
    "lat": "54.46243",
    "lng": "100.90994"
  },
  {
    "country": "RU",
    "name": "Shelopugino",
    "lat": "51.65286",
    "lng": "117.56303"
  },
  {
    "country": "RU",
    "name": "Shelekhov",
    "lat": "52.21389",
    "lng": "104.1"
  },
  {
    "country": "RU",
    "name": "Sharalday",
    "lat": "51.02528",
    "lng": "107.64487"
  },
  {
    "country": "RU",
    "name": "Shamanka",
    "lat": "52.06667",
    "lng": "103.82028"
  },
  {
    "country": "RU",
    "name": "Severomuysk",
    "lat": "56.14806",
    "lng": "113.42667"
  },
  {
    "country": "RU",
    "name": "Severobaykal’sk",
    "lat": "55.63695",
    "lng": "109.32297"
  },
  {
    "country": "RU",
    "name": "Seryshevo",
    "lat": "51.09391",
    "lng": "128.38258"
  },
  {
    "country": "RU",
    "name": "Sergeyevka",
    "lat": "43.34909",
    "lng": "133.35972"
  },
  {
    "country": "RU",
    "name": "Serebryanyy Bor",
    "lat": "56.67076",
    "lng": "124.83754"
  },
  {
    "country": "RU",
    "name": "Selikhino",
    "lat": "50.36832",
    "lng": "137.50163"
  },
  {
    "country": "RU",
    "name": "Selenduma",
    "lat": "50.91306",
    "lng": "106.24056"
  },
  {
    "country": "RU",
    "name": "Nizhniy Sayantuy",
    "lat": "51.73751",
    "lng": "107.51308"
  },
  {
    "country": "RU",
    "name": "Saskylakh",
    "lat": "71.96347",
    "lng": "114.09199"
  },
  {
    "country": "RU",
    "name": "Sangar",
    "lat": "63.92301",
    "lng": "127.47135"
  },
  {
    "country": "RU",
    "name": "Russkiy",
    "lat": "43.0224",
    "lng": "131.8601"
  },
  {
    "country": "RU",
    "name": "Rudnyy",
    "lat": "44.27759",
    "lng": "134.96106"
  },
  {
    "country": "RU",
    "name": "Rudnogorsk",
    "lat": "57.2639",
    "lng": "103.7519"
  },
  {
    "country": "RU",
    "name": "Rudnaya Pristan’",
    "lat": "44.35812",
    "lng": "135.81478"
  },
  {
    "country": "RU",
    "name": "Romny",
    "lat": "50.7207",
    "lng": "129.29122"
  },
  {
    "country": "RU",
    "name": "Romanovka",
    "lat": "43.23294",
    "lng": "132.45714"
  },
  {
    "country": "RU",
    "name": "Rettikhovka",
    "lat": "44.17038",
    "lng": "132.77083"
  },
  {
    "country": "RU",
    "name": "Razdol’noye",
    "lat": "43.53894",
    "lng": "131.89691"
  },
  {
    "country": "RU",
    "name": "Raychikhinsk",
    "lat": "49.78998",
    "lng": "129.40992"
  },
  {
    "country": "RU",
    "name": "Putyatin",
    "lat": "42.86179",
    "lng": "132.41564"
  },
  {
    "country": "RU",
    "name": "Primorskiy",
    "lat": "43.09962",
    "lng": "131.58938"
  },
  {
    "country": "RU",
    "name": "Priiskovyy",
    "lat": "51.93333",
    "lng": "116.63333"
  },
  {
    "country": "RU",
    "name": "Priargunsk",
    "lat": "50.3691",
    "lng": "119.1012"
  },
  {
    "country": "RU",
    "name": "Priamurskiy",
    "lat": "48.52716",
    "lng": "134.90359"
  },
  {
    "country": "RU",
    "name": "Preobrazheniye",
    "lat": "42.90117",
    "lng": "133.9043"
  },
  {
    "country": "RU",
    "name": "Poyarkovo",
    "lat": "49.62678",
    "lng": "128.65352"
  },
  {
    "country": "RU",
    "name": "Popova",
    "lat": "42.96096",
    "lng": "131.72494"
  },
  {
    "country": "RU",
    "name": "Pokrovsk",
    "lat": "61.47768",
    "lng": "129.13699"
  },
  {
    "country": "RU",
    "name": "Pokrovka",
    "lat": "43.95331",
    "lng": "131.63443"
  },
  {
    "country": "RU",
    "name": "Pokosnoye",
    "lat": "55.52583",
    "lng": "101.05361"
  },
  {
    "country": "RU",
    "name": "Pogranichnyy",
    "lat": "44.4097",
    "lng": "131.3778"
  },
  {
    "country": "RU",
    "name": "Plastun",
    "lat": "44.76077",
    "lng": "136.28048"
  },
  {
    "country": "RU",
    "name": "Pivovarikha",
    "lat": "52.27056",
    "lng": "104.44583"
  },
  {
    "country": "RU",
    "name": "Petrovsk-Zabaykal’skiy",
    "lat": "51.2753",
    "lng": "108.84301"
  },
  {
    "country": "RU",
    "name": "Petropavlovka",
    "lat": "50.6114",
    "lng": "105.3196"
  },
  {
    "country": "RU",
    "name": "Pervomayskiy",
    "lat": "51.67013",
    "lng": "115.62543"
  },
  {
    "country": "RU",
    "name": "Perfilovo",
    "lat": "54.41083",
    "lng": "100.48454"
  },
  {
    "country": "RU",
    "name": "Peleduy",
    "lat": "59.62889",
    "lng": "112.74056"
  },
  {
    "country": "RU",
    "name": "Partizansk",
    "lat": "43.12165",
    "lng": "133.12347"
  },
  {
    "country": "RU",
    "name": "Oyëk",
    "lat": "52.58611",
    "lng": "104.45556"
  },
  {
    "country": "RU",
    "name": "Ovsyanka",
    "lat": "53.57868",
    "lng": "126.89623"
  },
  {
    "country": "RU",
    "name": "Osa",
    "lat": "53.38722",
    "lng": "103.87694"
  },
  {
    "country": "RU",
    "name": "Orlovskiy",
    "lat": "51.03333",
    "lng": "114.83333"
  },
  {
    "country": "RU",
    "name": "Onokhoy",
    "lat": "51.92859",
    "lng": "108.06693"
  },
  {
    "country": "RU",
    "name": "Olovyannaya",
    "lat": "50.95",
    "lng": "115.56667"
  },
  {
    "country": "RU",
    "name": "Ol’ga",
    "lat": "43.74735",
    "lng": "135.2909"
  },
  {
    "country": "RU",
    "name": "Olenyok",
    "lat": "68.50472",
    "lng": "112.4485"
  },
  {
    "country": "RU",
    "name": "Olyokminsk",
    "lat": "60.3743",
    "lng": "120.4203"
  },
  {
    "country": "RU",
    "name": "Okino-Klyuchi",
    "lat": "50.59389",
    "lng": "107.10944"
  },
  {
    "country": "RU",
    "name": "Nyurba",
    "lat": "63.28417",
    "lng": "118.33194"
  },
  {
    "country": "RU",
    "name": "Novyy Zagan",
    "lat": "51.02858",
    "lng": "107.76376"
  },
  {
    "country": "RU",
    "name": "Novyy Uoyan",
    "lat": "56.15722",
    "lng": "111.70556"
  },
  {
    "country": "RU",
    "name": "Novosysoyevka",
    "lat": "44.2347",
    "lng": "133.3642"
  },
  {
    "country": "RU",
    "name": "Novoshakhtinskiy",
    "lat": "44.02576",
    "lng": "132.16583"
  },
  {
    "country": "RU",
    "name": "Novoraychikhinsk",
    "lat": "49.78423",
    "lng": "129.59051"
  },
  {
    "country": "RU",
    "name": "Novopokrovka",
    "lat": "45.85296",
    "lng": "134.50035"
  },
  {
    "country": "RU",
    "name": "Novopavlovka",
    "lat": "51.21724",
    "lng": "109.21305"
  },
  {
    "country": "RU",
    "name": "Novonikol’sk",
    "lat": "43.85518",
    "lng": "131.86257"
  },
  {
    "country": "RU",
    "name": "Novokruchininskiy",
    "lat": "51.7836",
    "lng": "113.77591"
  },
  {
    "country": "RU",
    "name": "Novokizhinginsk",
    "lat": "51.6162",
    "lng": "109.60265"
  },
  {
    "country": "RU",
    "name": "Novobureyskiy",
    "lat": "49.79695",
    "lng": "129.87443"
  },
  {
    "country": "RU",
    "name": "Novaya Igirma",
    "lat": "57.1334",
    "lng": "103.9112"
  },
  {
    "country": "RU",
    "name": "Novaya Bryan’",
    "lat": "51.71699",
    "lng": "108.27014"
  },
  {
    "country": "RU",
    "name": "Nizhniy Tsasuchey",
    "lat": "50.51667",
    "lng": "115.13333"
  },
  {
    "country": "RU",
    "name": "Nizhniy Kuranakh",
    "lat": "58.8238",
    "lng": "125.52278"
  },
  {
    "country": "RU",
    "name": "Nizhniy Bestyakh",
    "lat": "61.96202",
    "lng": "129.91245"
  },
  {
    "country": "RU",
    "name": "Nizhneangarsk",
    "lat": "55.79326",
    "lng": "109.58029"
  },
  {
    "country": "RU",
    "name": "Nikol’sk",
    "lat": "51.18867",
    "lng": "108.32187"
  },
  {
    "country": "RU",
    "name": "Nikolayevskiy",
    "lat": "51.65526",
    "lng": "107.80068"
  },
  {
    "country": "RU",
    "name": "Never",
    "lat": "53.97946",
    "lng": "124.15777"
  },
  {
    "country": "RU",
    "name": "Neryungri",
    "lat": "56.66637",
    "lng": "124.63825"
  },
  {
    "country": "RU",
    "name": "Nerchinskiy Zavod",
    "lat": "51.30829",
    "lng": "119.61597"
  },
  {
    "country": "RU",
    "name": "Nerchinsk",
    "lat": "51.98333",
    "lng": "116.58333"
  },
  {
    "country": "RU",
    "name": "Nekrasovka",
    "lat": "48.35208",
    "lng": "135.23221"
  },
  {
    "country": "RU",
    "name": "Naushki",
    "lat": "50.38278",
    "lng": "106.10556"
  },
  {
    "country": "RU",
    "name": "Namtsy",
    "lat": "62.71959",
    "lng": "129.66722"
  },
  {
    "country": "RU",
    "name": "Nakhodka",
    "lat": "42.81384",
    "lng": "132.87348"
  },
  {
    "country": "RU",
    "name": "Mukhorshibir’",
    "lat": "51.04986",
    "lng": "107.82997"
  },
  {
    "country": "RU",
    "name": "Mukhen",
    "lat": "48.19672",
    "lng": "136.12691"
  },
  {
    "country": "RU",
    "name": "Mugun",
    "lat": "54.47143",
    "lng": "100.24831"
  },
  {
    "country": "RU",
    "name": "Monastyrishche",
    "lat": "44.19641",
    "lng": "132.50223"
  },
  {
    "country": "RU",
    "name": "Mokhsogollokh",
    "lat": "61.39619",
    "lng": "128.9381"
  },
  {
    "country": "RU",
    "name": "Mogzon",
    "lat": "51.7406",
    "lng": "111.96555"
  },
  {
    "country": "RU",
    "name": "Mogoytuy",
    "lat": "51.28333",
    "lng": "114.91667"
  },
  {
    "country": "RU",
    "name": "Mogocha",
    "lat": "53.73417",
    "lng": "119.76515"
  },
  {
    "country": "RU",
    "name": "Mnogovershinnyy",
    "lat": "53.93345",
    "lng": "139.9274"
  },
  {
    "country": "RU",
    "name": "Mnogoudobnoye",
    "lat": "43.46802",
    "lng": "132.46675"
  },
  {
    "country": "RU",
    "name": "Mishelevka",
    "lat": "52.8575",
    "lng": "103.17194"
  },
  {
    "country": "RU",
    "name": "Mirny",
    "lat": "62.53528",
    "lng": "113.96111"
  },
  {
    "country": "RU",
    "name": "Mikhaylovka",
    "lat": "43.93283",
    "lng": "132.00911"
  },
  {
    "country": "RU",
    "name": "Meget",
    "lat": "52.415",
    "lng": "104.04944"
  },
  {
    "country": "RU",
    "name": "Mayya",
    "lat": "61.73824",
    "lng": "130.28161"
  },
  {
    "country": "RU",
    "name": "Markovo",
    "lat": "57.32056",
    "lng": "107.08806"
  },
  {
    "country": "RU",
    "name": "Markha",
    "lat": "62.11454",
    "lng": "129.74403"
  },
  {
    "country": "RU",
    "name": "Manzurka",
    "lat": "53.48556",
    "lng": "106.05444"
  },
  {
    "country": "RU",
    "name": "Mamakan",
    "lat": "57.81611",
    "lng": "114.00278"
  },
  {
    "country": "RU",
    "name": "Mama",
    "lat": "58.31056",
    "lng": "112.89861"
  },
  {
    "country": "RU",
    "name": "Makkaveyevo",
    "lat": "51.75325",
    "lng": "113.9454"
  },
  {
    "country": "RU",
    "name": "Magistral’nyy",
    "lat": "56.17148",
    "lng": "107.44166"
  },
  {
    "country": "RU",
    "name": "Magdagachi",
    "lat": "53.45398",
    "lng": "125.80932"
  },
  {
    "country": "RU",
    "name": "Magan",
    "lat": "62.10746",
    "lng": "129.53184"
  },
  {
    "country": "RU",
    "name": "Sergeyevka",
    "lat": "44.3381",
    "lng": "131.66129"
  },
  {
    "country": "RU",
    "name": "Lyalichi",
    "lat": "44.07352",
    "lng": "132.38991"
  },
  {
    "country": "RU",
    "name": "Luchki",
    "lat": "44.28613",
    "lng": "132.25975"
  },
  {
    "country": "RU",
    "name": "Luchegorsk",
    "lat": "46.47656",
    "lng": "134.19532"
  },
  {
    "country": "RU",
    "name": "Londoko",
    "lat": "49.01805",
    "lng": "131.99142"
  },
  {
    "country": "RU",
    "name": "Livadiya",
    "lat": "42.8682",
    "lng": "132.67367"
  },
  {
    "country": "RU",
    "name": "Litovko",
    "lat": "49.23754",
    "lng": "135.17401"
  },
  {
    "country": "RU",
    "name": "Listvyanka",
    "lat": "51.8535",
    "lng": "104.8693"
  },
  {
    "country": "RU",
    "name": "Lipovtsy",
    "lat": "44.20018",
    "lng": "131.72373"
  },
  {
    "country": "RU",
    "name": "Lesozavodsk",
    "lat": "45.47885",
    "lng": "133.42825"
  },
  {
    "country": "RU",
    "name": "Lermontovka",
    "lat": "47.14795",
    "lng": "134.33477"
  },
  {
    "country": "RU",
    "name": "Lensk",
    "lat": "60.72528",
    "lng": "114.92778"
  },
  {
    "country": "RU",
    "name": "Leninskoye",
    "lat": "47.93501",
    "lng": "132.62025"
  },
  {
    "country": "RU",
    "name": "Leninskiy",
    "lat": "58.57141",
    "lng": "125.43918"
  },
  {
    "country": "RU",
    "name": "Lebedinyy",
    "lat": "58.48844",
    "lng": "125.49415"
  },
  {
    "country": "RU",
    "name": "Lazo",
    "lat": "45.87052",
    "lng": "133.65021"
  },
  {
    "country": "RU",
    "name": "Lazo",
    "lat": "43.38563",
    "lng": "133.9061"
  },
  {
    "country": "RU",
    "name": "Kysyl-Syr",
    "lat": "63.89482",
    "lng": "122.7654"
  },
  {
    "country": "RU",
    "name": "Kyren",
    "lat": "51.6828",
    "lng": "102.1408"
  },
  {
    "country": "RU",
    "name": "Kyra",
    "lat": "49.57903",
    "lng": "111.97638"
  },
  {
    "country": "RU",
    "name": "Kyakhta",
    "lat": "50.35737",
    "lng": "106.45033"
  },
  {
    "country": "RU",
    "name": "Kuytun",
    "lat": "54.34241",
    "lng": "101.50917"
  },
  {
    "country": "RU",
    "name": "Kutulik",
    "lat": "53.35083",
    "lng": "102.78389"
  },
  {
    "country": "RU",
    "name": "Kurumkan",
    "lat": "54.32093",
    "lng": "110.30651"
  },
  {
    "country": "RU",
    "name": "Kurort-Darasun",
    "lat": "51.19905",
    "lng": "113.71599"
  },
  {
    "country": "RU",
    "name": "Kultuk",
    "lat": "51.72083",
    "lng": "103.69556"
  },
  {
    "country": "RU",
    "name": "Kul’dur",
    "lat": "49.20465",
    "lng": "131.6384"
  },
  {
    "country": "RU",
    "name": "Kudara-Somon",
    "lat": "50.15472",
    "lng": "107.40139"
  },
  {
    "country": "RU",
    "name": "Kropotkin",
    "lat": "58.50944",
    "lng": "115.32167"
  },
  {
    "country": "RU",
    "name": "Krasnorechenskiy",
    "lat": "44.62807",
    "lng": "135.35262"
  },
  {
    "country": "RU",
    "name": "Krasnokamensk",
    "lat": "50.0979",
    "lng": "118.0369"
  },
  {
    "country": "RU",
    "name": "Kraskino",
    "lat": "42.71071",
    "lng": "130.78126"
  },
  {
    "country": "RU",
    "name": "Kotik",
    "lat": "54.65057",
    "lng": "100.45395"
  },
  {
    "country": "RU",
    "name": "Korfovskiy",
    "lat": "48.22259",
    "lng": "135.05966"
  },
  {
    "country": "RU",
    "name": "Konstantinovka",
    "lat": "49.61876",
    "lng": "127.99025"
  },
  {
    "country": "RU",
    "name": "Komsomolsk-on-Amur",
    "lat": "50.55034",
    "lng": "137.00995"
  },
  {
    "country": "RU",
    "name": "Kokuy",
    "lat": "52.20634",
    "lng": "117.55412"
  },
  {
    "country": "RU",
    "name": "Knyaze-Volkonskoye",
    "lat": "48.46547",
    "lng": "135.45582"
  },
  {
    "country": "RU",
    "name": "Knevichi",
    "lat": "43.39975",
    "lng": "132.18808"
  },
  {
    "country": "RU",
    "name": "Klyuchevskiy",
    "lat": "53.5336",
    "lng": "119.45269"
  },
  {
    "country": "RU",
    "name": "Klichka",
    "lat": "50.4457",
    "lng": "117.996"
  },
  {
    "country": "RU",
    "name": "Kizhinga",
    "lat": "51.8476",
    "lng": "109.90795"
  },
  {
    "country": "RU",
    "name": "Kitoy",
    "lat": "52.6",
    "lng": "103.9"
  },
  {
    "country": "RU",
    "name": "Kirovskiy",
    "lat": "45.09272",
    "lng": "133.50084"
  },
  {
    "country": "RU",
    "name": "Kirensk",
    "lat": "57.78528",
    "lng": "108.11194"
  },
  {
    "country": "RU",
    "name": "Kimil’tey",
    "lat": "54.1337",
    "lng": "101.9811"
  },
  {
    "country": "RU",
    "name": "Kichera",
    "lat": "55.93874",
    "lng": "110.10122"
  },
  {
    "country": "RU",
    "name": "Khuzhir",
    "lat": "53.19389",
    "lng": "107.33972"
  },
  {
    "country": "RU",
    "name": "Khurba",
    "lat": "50.40657",
    "lng": "136.88276"
  },
  {
    "country": "RU",
    "name": "Khrebtovaya",
    "lat": "56.7032",
    "lng": "104.2494"
  },
  {
    "country": "RU",
    "name": "Khorol’",
    "lat": "44.42631",
    "lng": "132.07638"
  },
  {
    "country": "RU",
    "name": "Khorinsk",
    "lat": "52.16631",
    "lng": "109.77626"
  },
  {
    "country": "RU",
    "name": "Khor",
    "lat": "47.88696",
    "lng": "134.9463"
  },
  {
    "country": "RU",
    "name": "Khonkholoy",
    "lat": "51.13186",
    "lng": "108.22515"
  },
  {
    "country": "RU",
    "name": "Khomutovo",
    "lat": "52.46583",
    "lng": "104.4025"
  },
  {
    "country": "RU",
    "name": "Kholtoson",
    "lat": "50.2981",
    "lng": "103.3097"
  },
  {
    "country": "RU",
    "name": "Kholbon",
    "lat": "51.88333",
    "lng": "116.25"
  },
  {
    "country": "RU",
    "name": "Khingansk",
    "lat": "49.12821",
    "lng": "131.19322"
  },
  {
    "country": "RU",
    "name": "Khilok",
    "lat": "51.36777",
    "lng": "110.46804"
  },
  {
    "country": "RU",
    "name": "Khatassy",
    "lat": "61.90638",
    "lng": "129.63302"
  },
  {
    "country": "RU",
    "name": "Khatanga",
    "lat": "71.98002",
    "lng": "102.47111"
  },
  {
    "country": "RU",
    "name": "Khandyga",
    "lat": "62.65333",
    "lng": "135.5667"
  },
  {
    "country": "RU",
    "name": "Khabarovsk",
    "lat": "48.48271",
    "lng": "135.08379"
  },
  {
    "country": "RU",
    "name": "Kazachinskoye",
    "lat": "56.26974",
    "lng": "107.57624"
  },
  {
    "country": "RU",
    "name": "Kavalerovo",
    "lat": "44.27221",
    "lng": "135.05227"
  },
  {
    "country": "RU",
    "name": "Karymskoye",
    "lat": "51.61667",
    "lng": "114.35"
  },
  {
    "country": "RU",
    "name": "Kangalassy",
    "lat": "62.34824",
    "lng": "129.96471"
  },
  {
    "country": "RU",
    "name": "Kamen’-Rybolov",
    "lat": "44.7452",
    "lng": "132.0465"
  },
  {
    "country": "RU",
    "name": "Kamenka",
    "lat": "44.45865",
    "lng": "136.01403"
  },
  {
    "country": "RU",
    "name": "Kalga",
    "lat": "50.92538",
    "lng": "118.89958"
  },
  {
    "country": "RU",
    "name": "Kalanguy",
    "lat": "51.01667",
    "lng": "116.51667"
  },
  {
    "country": "RU",
    "name": "Kadaya",
    "lat": "50.93254",
    "lng": "119.29468"
  },
  {
    "country": "RU",
    "name": "Kachug",
    "lat": "53.96056",
    "lng": "105.88167"
  },
  {
    "country": "RU",
    "name": "Kabansk",
    "lat": "52.04861",
    "lng": "106.65278"
  },
  {
    "country": "RU",
    "name": "Izvestkovyy",
    "lat": "48.98043",
    "lng": "131.55274"
  },
  {
    "country": "RU",
    "name": "Ivolginsk",
    "lat": "51.74919",
    "lng": "107.28374"
  },
  {
    "country": "RU",
    "name": "Ivanovka",
    "lat": "43.96879",
    "lng": "132.48331"
  },
  {
    "country": "RU",
    "name": "Istok",
    "lat": "52.09528",
    "lng": "106.2475"
  },
  {
    "country": "RU",
    "name": "Irkutsk",
    "lat": "52.29778",
    "lng": "104.29639"
  },
  {
    "country": "RU",
    "name": "Imeni Poliny Osipenko",
    "lat": "52.4227",
    "lng": "136.48692"
  },
  {
    "country": "RU",
    "name": "Il’ka",
    "lat": "51.72114",
    "lng": "108.52169"
  },
  {
    "country": "RU",
    "name": "Ilir",
    "lat": "55.22473",
    "lng": "100.68498"
  },
  {
    "country": "RU",
    "name": "Il’inka",
    "lat": "52.11944",
    "lng": "107.27083"
  },
  {
    "country": "RU",
    "name": "Ikey",
    "lat": "54.19194",
    "lng": "100.08111"
  },
  {
    "country": "RU",
    "name": "Gusinoye Ozero",
    "lat": "51.11444",
    "lng": "106.26139"
  },
  {
    "country": "RU",
    "name": "Gusinoozyorsk",
    "lat": "51.28333",
    "lng": "106.5"
  },
  {
    "country": "RU",
    "name": "Guran",
    "lat": "54.76127",
    "lng": "100.64399"
  },
  {
    "country": "RU",
    "name": "Gornyye Klyuchi",
    "lat": "45.24221",
    "lng": "133.50601"
  },
  {
    "country": "RU",
    "name": "Gornyy",
    "lat": "50.76344",
    "lng": "136.44951"
  },
  {
    "country": "RU",
    "name": "Gornorechenskiy",
    "lat": "44.26555",
    "lng": "135.11465"
  },
  {
    "country": "RU",
    "name": "Gorin",
    "lat": "51.19861",
    "lng": "136.66216"
  },
  {
    "country": "RU",
    "name": "Gazimurskiy Zavod",
    "lat": "51.55352",
    "lng": "118.3446"
  },
  {
    "country": "RU",
    "name": "Gadaley",
    "lat": "54.40318",
    "lng": "100.74093"
  },
  {
    "country": "RU",
    "name": "Ekimchan",
    "lat": "53.06972",
    "lng": "132.94011"
  },
  {
    "country": "RU",
    "name": "Dzhida",
    "lat": "50.67722",
    "lng": "106.18056"
  },
  {
    "country": "RU",
    "name": "Dzhebariki-Khaya",
    "lat": "62.21084",
    "lng": "135.84876"
  },
  {
    "country": "RU",
    "name": "Dunay",
    "lat": "42.87881",
    "lng": "132.33521"
  },
  {
    "country": "RU",
    "name": "Dul’durga",
    "lat": "50.67611",
    "lng": "113.59306"
  },
  {
    "country": "RU",
    "name": "Drovyanaya",
    "lat": "51.5762",
    "lng": "113.04078"
  },
  {
    "country": "RU",
    "name": "Dostoyevka",
    "lat": "44.32554",
    "lng": "133.48134"
  },
  {
    "country": "RU",
    "name": "Domna",
    "lat": "51.89712",
    "lng": "113.1573"
  },
  {
    "country": "RU",
    "name": "Dauriya",
    "lat": "49.93333",
    "lng": "116.86667"
  },
  {
    "country": "RU",
    "name": "Darasun",
    "lat": "51.6594",
    "lng": "113.97515"
  },
  {
    "country": "RU",
    "name": "Dalnerechensk",
    "lat": "45.93149",
    "lng": "133.73906"
  },
  {
    "country": "RU",
    "name": "Churapcha",
    "lat": "61.99858",
    "lng": "132.43341"
  },
  {
    "country": "RU",
    "name": "Chumikan",
    "lat": "54.71857",
    "lng": "135.3163"
  },
  {
    "country": "RU",
    "name": "Chul’man",
    "lat": "56.84735",
    "lng": "124.90812"
  },
  {
    "country": "RU",
    "name": "Chuguyevka",
    "lat": "44.16652",
    "lng": "133.86495"
  },
  {
    "country": "RU",
    "name": "Chkalovskoye",
    "lat": "44.83808",
    "lng": "133.04332"
  },
  {
    "country": "RU",
    "name": "Chita",
    "lat": "52.03171",
    "lng": "113.50087"
  },
  {
    "country": "RU",
    "name": "Chernyshevskiy",
    "lat": "63.01601",
    "lng": "112.46901"
  },
  {
    "country": "RU",
    "name": "Chernyshevsk",
    "lat": "52.52209",
    "lng": "117.01712"
  },
  {
    "country": "RU",
    "name": "Chernyshëvka",
    "lat": "44.19971",
    "lng": "133.13193"
  },
  {
    "country": "RU",
    "name": "Chernigovka",
    "lat": "44.34216",
    "lng": "132.56937"
  },
  {
    "country": "RU",
    "name": "Cheremkhovo",
    "lat": "53.15611",
    "lng": "103.0675"
  },
  {
    "country": "RU",
    "name": "Chegdomyn",
    "lat": "51.12853",
    "lng": "133.00827"
  },
  {
    "country": "RU",
    "name": "Chara",
    "lat": "56.90639",
    "lng": "118.26306"
  },
  {
    "country": "RU",
    "name": "Bureya",
    "lat": "49.81212",
    "lng": "129.81278"
  },
  {
    "country": "RU",
    "name": "Bukachacha",
    "lat": "52.98333",
    "lng": "116.91667"
  },
  {
    "country": "RU",
    "name": "Budagovo",
    "lat": "54.6255",
    "lng": "100.13109"
  },
  {
    "country": "RU",
    "name": "Borzya",
    "lat": "50.38333",
    "lng": "116.51667"
  },
  {
    "country": "RU",
    "name": "Borogontsy",
    "lat": "62.6706",
    "lng": "131.16344"
  },
  {
    "country": "RU",
    "name": "Bol’shoy Kunaley",
    "lat": "51.43203",
    "lng": "107.6089"
  },
  {
    "country": "RU",
    "name": "Bol’shoy Kamen’",
    "lat": "43.11283",
    "lng": "132.354"
  },
  {
    "country": "RU",
    "name": "Bol’shaya Tura",
    "lat": "51.61642",
    "lng": "114.11242"
  },
  {
    "country": "RU",
    "name": "Bol’shaya Rechka",
    "lat": "51.9536",
    "lng": "104.7335"
  },
  {
    "country": "RU",
    "name": "Bokhan",
    "lat": "53.153",
    "lng": "103.7714"
  },
  {
    "country": "RU",
    "name": "Bodaybo",
    "lat": "57.85056",
    "lng": "114.19333"
  },
  {
    "country": "RU",
    "name": "Blagoveshchensk",
    "lat": "50.27961",
    "lng": "127.5405"
  },
  {
    "country": "RU",
    "name": "Blagodatnoye",
    "lat": "44.32285",
    "lng": "132.0905"
  },
  {
    "country": "RU",
    "name": "Birobidzhan",
    "lat": "48.79284",
    "lng": "132.92386"
  },
  {
    "country": "RU",
    "name": "Birakan",
    "lat": "48.99302",
    "lng": "131.72026"
  },
  {
    "country": "RU",
    "name": "Bira",
    "lat": "49.00135",
    "lng": "132.46826"
  },
  {
    "country": "RU",
    "name": "Bikin",
    "lat": "46.81293",
    "lng": "134.25012"
  },
  {
    "country": "RU",
    "name": "Bichura",
    "lat": "50.58806",
    "lng": "107.60222"
  },
  {
    "country": "RU",
    "name": "Berkakit",
    "lat": "56.57456",
    "lng": "124.77635"
  },
  {
    "country": "RU",
    "name": "Berëzovyy",
    "lat": "51.66897",
    "lng": "135.66584"
  },
  {
    "country": "RU",
    "name": "Bereznyaki",
    "lat": "56.9366",
    "lng": "103.5851"
  },
  {
    "country": "RU",
    "name": "Berdigestyakh",
    "lat": "62.09842",
    "lng": "126.69573"
  },
  {
    "country": "RU",
    "name": "Belogorsk",
    "lat": "50.91644",
    "lng": "128.47726"
  },
  {
    "country": "RU",
    "name": "Baykal’sk",
    "lat": "51.5151",
    "lng": "104.1402"
  },
  {
    "country": "RU",
    "name": "Bayangol",
    "lat": "50.6977",
    "lng": "103.4656"
  },
  {
    "country": "RU",
    "name": "Bayanday",
    "lat": "53.06611",
    "lng": "105.51389"
  },
  {
    "country": "RU",
    "name": "Batagay-Alyta",
    "lat": "67.79846",
    "lng": "130.40119"
  },
  {
    "country": "RU",
    "name": "Batagay",
    "lat": "67.65653",
    "lng": "134.63962"
  },
  {
    "country": "RU",
    "name": "Barguzin",
    "lat": "53.61875",
    "lng": "109.63904"
  },
  {
    "country": "RU",
    "name": "Barabash",
    "lat": "43.19948",
    "lng": "131.49185"
  },
  {
    "country": "RU",
    "name": "Balyaga",
    "lat": "51.15293",
    "lng": "108.92767"
  },
  {
    "country": "RU",
    "name": "Baley",
    "lat": "51.58166",
    "lng": "116.63395"
  },
  {
    "country": "RU",
    "name": "Balakhninskiy",
    "lat": "58.01056",
    "lng": "114.27694"
  },
  {
    "country": "RU",
    "name": "Balagansk",
    "lat": "54.0057",
    "lng": "103.05234"
  },
  {
    "country": "RU",
    "name": "Baklashi",
    "lat": "52.22556",
    "lng": "104.04861"
  },
  {
    "country": "RU",
    "name": "Bagdarin",
    "lat": "54.43333",
    "lng": "113.6"
  },
  {
    "country": "RU",
    "name": "Badar",
    "lat": "54.39948",
    "lng": "100.59436"
  },
  {
    "country": "RU",
    "name": "Bada",
    "lat": "51.391",
    "lng": "109.86145"
  },
  {
    "country": "RU",
    "name": "Babushkin",
    "lat": "51.71222",
    "lng": "105.86472"
  },
  {
    "country": "RU",
    "name": "Babstovo",
    "lat": "48.11853",
    "lng": "132.47913"
  },
  {
    "country": "RU",
    "name": "Aykhal",
    "lat": "65.93381",
    "lng": "111.4834"
  },
  {
    "country": "RU",
    "name": "Ayan",
    "lat": "56.46314",
    "lng": "138.17777"
  },
  {
    "country": "RU",
    "name": "Atamanovka",
    "lat": "51.93333",
    "lng": "113.63333"
  },
  {
    "country": "RU",
    "name": "Artëm",
    "lat": "43.3595",
    "lng": "132.18887"
  },
  {
    "country": "RU",
    "name": "Arsen’yev",
    "lat": "44.15254",
    "lng": "133.27791"
  },
  {
    "country": "RU",
    "name": "Arkhara",
    "lat": "49.42447",
    "lng": "130.08569"
  },
  {
    "country": "RU",
    "name": "Anuchino",
    "lat": "43.96571",
    "lng": "133.05846"
  },
  {
    "country": "RU",
    "name": "Angarsk",
    "lat": "52.53667",
    "lng": "103.88639"
  },
  {
    "country": "RU",
    "name": "Amurzet",
    "lat": "47.69541",
    "lng": "131.09493"
  },
  {
    "country": "RU",
    "name": "Amursk",
    "lat": "50.23685",
    "lng": "136.88136"
  },
  {
    "country": "RU",
    "name": "Amga",
    "lat": "60.90009",
    "lng": "131.97882"
  },
  {
    "country": "RU",
    "name": "Amazar",
    "lat": "53.86033",
    "lng": "120.87925"
  },
  {
    "country": "RU",
    "name": "Almaznyy",
    "lat": "62.44917",
    "lng": "114.32778"
  },
  {
    "country": "RU",
    "name": "Alekseyevskaya",
    "lat": "57.85",
    "lng": "108.4"
  },
  {
    "country": "RU",
    "name": "Aleksandrovskiy Zavod",
    "lat": "50.92525",
    "lng": "117.93773"
  },
  {
    "country": "RU",
    "name": "Aldan",
    "lat": "58.61021",
    "lng": "125.39613"
  },
  {
    "country": "RU",
    "name": "Aksha",
    "lat": "50.28139",
    "lng": "113.28667"
  },
  {
    "country": "RU",
    "name": "Aginskoye",
    "lat": "51.1",
    "lng": "114.53"
  },
  {
    "country": "RU",
    "name": "Afanas’yeva",
    "lat": "54.63958",
    "lng": "100.61755"
  },
  {
    "country": "RU",
    "name": "Deputatsky",
    "lat": "69.30958",
    "lng": "139.97571"
  },
  {
    "country": "RU",
    "name": "Novyy Urgal",
    "lat": "51.07089",
    "lng": "132.60075"
  },
  {
    "country": "RU",
    "name": "Dalnegorsk",
    "lat": "44.55745",
    "lng": "135.6209"
  },
  {
    "country": "RU",
    "name": "Bratsk",
    "lat": "56.1325",
    "lng": "101.61417"
  },
  {
    "country": "RU",
    "name": "Sayansk",
    "lat": "54.1088",
    "lng": "102.1648"
  },
  {
    "country": "RU",
    "name": "Kuanda",
    "lat": "56.31611",
    "lng": "116.08056"
  },
  {
    "country": "RU",
    "name": "Novaya Chara",
    "lat": "56.81639",
    "lng": "118.29861"
  },
  {
    "country": "RU",
    "name": "Yantal’",
    "lat": "56.8471",
    "lng": "105.2542"
  },
  {
    "country": "RU",
    "name": "Khabarovsk Vtoroy",
    "lat": "48.43776",
    "lng": "135.13329"
  },
  {
    "country": "RU",
    "name": "Dzerzhinsk",
    "lat": "52.28028",
    "lng": "104.38694"
  },
  {
    "country": "RU",
    "name": "Markova",
    "lat": "52.20889",
    "lng": "104.21083"
  },
  {
    "country": "RU",
    "name": "Ust’-Kamchatsk Staryy",
    "lat": "56.22778",
    "lng": "162.47778"
  },
  {
    "country": "RU",
    "name": "Vilyuchinsk",
    "lat": "52.9311",
    "lng": "158.40469"
  },
  {
    "country": "RU",
    "name": "Zyryanka",
    "lat": "65.73489",
    "lng": "150.89429"
  },
  {
    "country": "RU",
    "name": "Zavety Il’icha",
    "lat": "49.03737",
    "lng": "140.26989"
  },
  {
    "country": "RU",
    "name": "Yuzhno-Sakhalinsk",
    "lat": "46.95407",
    "lng": "142.73603"
  },
  {
    "country": "RU",
    "name": "Yuzhno-Kurilsk",
    "lat": "44.02734",
    "lng": "145.86146"
  },
  {
    "country": "RU",
    "name": "Yelizovo",
    "lat": "53.18909",
    "lng": "158.38135"
  },
  {
    "country": "RU",
    "name": "Yagodnoye",
    "lat": "62.52406",
    "lng": "149.62827"
  },
  {
    "country": "RU",
    "name": "Yablochnyy",
    "lat": "47.152",
    "lng": "142.05678"
  },
  {
    "country": "RU",
    "name": "Vostok",
    "lat": "48.97715",
    "lng": "142.91556"
  },
  {
    "country": "RU",
    "name": "Vanino",
    "lat": "49.09848",
    "lng": "140.25313"
  },
  {
    "country": "RU",
    "name": "Vakhrushev",
    "lat": "48.99035",
    "lng": "142.95303"
  },
  {
    "country": "RU",
    "name": "Ust’-Omchug",
    "lat": "61.13336",
    "lng": "149.63283"
  },
  {
    "country": "RU",
    "name": "Ust-Nera",
    "lat": "64.56968",
    "lng": "143.237"
  },
  {
    "country": "RU",
    "name": "Uptar",
    "lat": "59.89923",
    "lng": "150.87376"
  },
  {
    "country": "RU",
    "name": "Uglezavodsk",
    "lat": "47.32332",
    "lng": "142.63317"
  },
  {
    "country": "RU",
    "name": "Uglegorsk",
    "lat": "49.08047",
    "lng": "142.06449"
  },
  {
    "country": "RU",
    "name": "Tymovskoye",
    "lat": "50.84925",
    "lng": "142.6652"
  },
  {
    "country": "RU",
    "name": "Tungor",
    "lat": "53.39121",
    "lng": "142.95755"
  },
  {
    "country": "RU",
    "name": "Troitskoye",
    "lat": "46.92493",
    "lng": "142.64532"
  },
  {
    "country": "RU",
    "name": "Tomari",
    "lat": "47.76482",
    "lng": "142.07106"
  },
  {
    "country": "RU",
    "name": "Tilichiki",
    "lat": "60.42795",
    "lng": "166.05764"
  },
  {
    "country": "RU",
    "name": "Tigil’",
    "lat": "57.75979",
    "lng": "158.68161"
  },
  {
    "country": "RU",
    "name": "Talaya",
    "lat": "61.37038",
    "lng": "152.76878"
  },
  {
    "country": "RU",
    "name": "Susuman",
    "lat": "62.78075",
    "lng": "148.15396"
  },
  {
    "country": "RU",
    "name": "Srednekolymsk",
    "lat": "67.45659",
    "lng": "153.70246"
  },
  {
    "country": "RU",
    "name": "Sovetskaya Gavan’",
    "lat": "48.97215",
    "lng": "140.28919"
  },
  {
    "country": "RU",
    "name": "Sokol",
    "lat": "59.91834",
    "lng": "150.74956"
  },
  {
    "country": "RU",
    "name": "Sokol",
    "lat": "47.24464",
    "lng": "142.75167"
  },
  {
    "country": "RU",
    "name": "Smirnykh",
    "lat": "49.74596",
    "lng": "142.83716"
  },
  {
    "country": "RU",
    "name": "Sinegor'ye",
    "lat": "62.08782",
    "lng": "150.52162"
  },
  {
    "country": "RU",
    "name": "Sinegorsk",
    "lat": "47.17278",
    "lng": "142.51577"
  },
  {
    "country": "RU",
    "name": "Shebunino",
    "lat": "46.4301",
    "lng": "141.85699"
  },
  {
    "country": "RU",
    "name": "Shakhtersk",
    "lat": "49.17175",
    "lng": "142.1364"
  },
  {
    "country": "RU",
    "name": "Seymchan",
    "lat": "62.93373",
    "lng": "152.39109"
  },
  {
    "country": "RU",
    "name": "Severo-Kuril’sk",
    "lat": "50.67531",
    "lng": "156.12695"
  },
  {
    "country": "RU",
    "name": "Pravda",
    "lat": "46.93972",
    "lng": "142.00426"
  },
  {
    "country": "RU",
    "name": "Poronaysk",
    "lat": "49.22188",
    "lng": "143.09694"
  },
  {
    "country": "RU",
    "name": "Pevek",
    "lat": "69.70287",
    "lng": "170.29993"
  },
  {
    "country": "RU",
    "name": "Petropavlovsk-Kamchatsky",
    "lat": "53.04444",
    "lng": "158.65076"
  },
  {
    "country": "RU",
    "name": "Paratunka",
    "lat": "52.96202",
    "lng": "158.25723"
  },
  {
    "country": "RU",
    "name": "Palatka",
    "lat": "60.10183",
    "lng": "150.93433"
  },
  {
    "country": "RU",
    "name": "Palana",
    "lat": "59.08384",
    "lng": "159.9563"
  },
  {
    "country": "RU",
    "name": "Ozernovskiy",
    "lat": "51.49604",
    "lng": "156.50102"
  },
  {
    "country": "RU",
    "name": "Otrada",
    "lat": "44.06832",
    "lng": "145.86454"
  },
  {
    "country": "RU",
    "name": "Ossora",
    "lat": "59.24781",
    "lng": "163.07034"
  },
  {
    "country": "RU",
    "name": "Orotukan",
    "lat": "62.26423",
    "lng": "151.67153"
  },
  {
    "country": "RU",
    "name": "Omsukchan",
    "lat": "62.51575",
    "lng": "155.79038"
  },
  {
    "country": "RU",
    "name": "Ola",
    "lat": "59.57823",
    "lng": "151.29819"
  },
  {
    "country": "RU",
    "name": "Okhotsk",
    "lat": "59.362",
    "lng": "143.21468"
  },
  {
    "country": "RU",
    "name": "Okha",
    "lat": "53.58991",
    "lng": "142.95313"
  },
  {
    "country": "RU",
    "name": "Nogliki",
    "lat": "51.79917",
    "lng": "143.13871"
  },
  {
    "country": "RU",
    "name": "Nikolayevsk-on-Amure",
    "lat": "53.14657",
    "lng": "140.72287"
  },
  {
    "country": "RU",
    "name": "Nevel’sk",
    "lat": "46.67902",
    "lng": "141.85629"
  },
  {
    "country": "RU",
    "name": "Myaundzha",
    "lat": "63.04996",
    "lng": "147.18438"
  },
  {
    "country": "RU",
    "name": "Mil’kovo",
    "lat": "54.6961",
    "lng": "158.62067"
  },
  {
    "country": "RU",
    "name": "Mgachi",
    "lat": "51.04834",
    "lng": "142.26821"
  },
  {
    "country": "RU",
    "name": "Mayskiy",
    "lat": "48.99887",
    "lng": "140.20976"
  },
  {
    "country": "RU",
    "name": "Makarov",
    "lat": "48.62698",
    "lng": "142.77999"
  },
  {
    "country": "RU",
    "name": "Mago",
    "lat": "53.25851",
    "lng": "140.18269"
  },
  {
    "country": "RU",
    "name": "Magadan",
    "lat": "59.5638",
    "lng": "150.80347"
  },
  {
    "country": "RU",
    "name": "Lososina",
    "lat": "48.99652",
    "lng": "140.31462"
  },
  {
    "country": "RU",
    "name": "Leonidovo",
    "lat": "49.28619",
    "lng": "142.86975"
  },
  {
    "country": "RU",
    "name": "Lazarev",
    "lat": "52.22307",
    "lng": "141.51265"
  },
  {
    "country": "RU",
    "name": "Kuril’sk",
    "lat": "45.22686",
    "lng": "147.87767"
  },
  {
    "country": "RU",
    "name": "Krasnogorsk",
    "lat": "48.41728",
    "lng": "142.08686"
  },
  {
    "country": "RU",
    "name": "Kozyrëvsk",
    "lat": "56.0486",
    "lng": "159.8715"
  },
  {
    "country": "RU",
    "name": "Korsakov",
    "lat": "46.6342",
    "lng": "142.77722"
  },
  {
    "country": "RU",
    "name": "Klyuchi",
    "lat": "56.32035",
    "lng": "160.84541"
  },
  {
    "country": "RU",
    "name": "Kholodnyy",
    "lat": "62.71333",
    "lng": "147.91361"
  },
  {
    "country": "RU",
    "name": "Kholmsk",
    "lat": "47.04737",
    "lng": "142.05048"
  },
  {
    "country": "RU",
    "name": "Gornozavodsk",
    "lat": "46.55984",
    "lng": "141.84358"
  },
  {
    "country": "RU",
    "name": "Gastello",
    "lat": "49.10056",
    "lng": "142.95917"
  },
  {
    "country": "RU",
    "name": "Evensk",
    "lat": "61.91722",
    "lng": "159.23348"
  },
  {
    "country": "RU",
    "name": "Esso",
    "lat": "55.92738",
    "lng": "158.70708"
  },
  {
    "country": "RU",
    "name": "Dukat",
    "lat": "62.57231",
    "lng": "155.34988"
  },
  {
    "country": "RU",
    "name": "Dolinsk",
    "lat": "47.32946",
    "lng": "142.79291"
  },
  {
    "country": "RU",
    "name": "De-Kastri",
    "lat": "51.47543",
    "lng": "140.76986"
  },
  {
    "country": "RU",
    "name": "Chokurdakh",
    "lat": "70.61897",
    "lng": "147.8973"
  },
  {
    "country": "RU",
    "name": "Cherskiy",
    "lat": "68.75325",
    "lng": "161.33197"
  },
  {
    "country": "RU",
    "name": "Chekhov",
    "lat": "47.44984",
    "lng": "141.99064"
  },
  {
    "country": "RU",
    "name": "Bykov",
    "lat": "47.32099",
    "lng": "142.56226"
  },
  {
    "country": "RU",
    "name": "Boshnyakovo",
    "lat": "49.64572",
    "lng": "142.17047"
  },
  {
    "country": "RU",
    "name": "Bogorodskoye",
    "lat": "52.37397",
    "lng": "140.43579"
  },
  {
    "country": "RU",
    "name": "Bilibino",
    "lat": "68.05464",
    "lng": "166.43721"
  },
  {
    "country": "RU",
    "name": "Beringovskiy",
    "lat": "63.06101",
    "lng": "179.35046"
  },
  {
    "country": "RU",
    "name": "Belaya Gora",
    "lat": "68.53805",
    "lng": "146.18583"
  },
  {
    "country": "RU",
    "name": "Atlasovo",
    "lat": "55.6065",
    "lng": "159.64266"
  },
  {
    "country": "RU",
    "name": "Arman’",
    "lat": "59.66994",
    "lng": "150.13164"
  },
  {
    "country": "RU",
    "name": "Aniva",
    "lat": "46.71492",
    "lng": "142.52866"
  },
  {
    "country": "RU",
    "name": "Anadyr",
    "lat": "64.73424",
    "lng": "177.5103"
  },
  {
    "country": "RU",
    "name": "Aleksandrovsk-Sakhalinskiy",
    "lat": "50.89926",
    "lng": "142.16215"
  },
  {
    "country": "RU",
    "name": "Yantarnyy",
    "lat": "54.87102",
    "lng": "19.94016"
  },
  {
    "country": "RU",
    "name": "Mamonovo",
    "lat": "54.46427",
    "lng": "19.93801"
  },
  {
    "country": "RU",
    "name": "Donskoye",
    "lat": "54.93842",
    "lng": "19.96821"
  },
  {
    "country": "RU",
    "name": "Baltiysk",
    "lat": "54.65455",
    "lng": "19.90929"
  },
  {
    "country": "RU",
    "name": "Provideniya",
    "lat": "64.42289",
    "lng": "-173.22641"
  },
  {
    "country": "RU",
    "name": "Lorino",
    "lat": "65.50331",
    "lng": "-171.70396"
  },
  {
    "country": "RU",
    "name": "Lavrentiya",
    "lat": "65.58604",
    "lng": "-171.02082"
  },
  {
    "country": "RU",
    "name": "Egvekinot",
    "lat": "66.32166",
    "lng": "-179.12198"
  },
  {
    "country": "RU",
    "name": "Raduzhnyy",
    "lat": "58.49899",
    "lng": "49.64347"
  },
  {
    "country": "RU",
    "name": "Grazhdanka",
    "lat": "44.2163",
    "lng": "133.17706"
  },
  {
    "country": "RU",
    "name": "Oktyabr’skiy",
    "lat": "57.74456",
    "lng": "41.00193"
  },
  {
    "country": "RU",
    "name": "Logovskoye",
    "lat": "53.4943",
    "lng": "84.2016"
  },
  {
    "country": "RU",
    "name": "Magas",
    "lat": "43.22257",
    "lng": "44.77261"
  },
  {
    "country": "RU",
    "name": "Vas’kovo",
    "lat": "64.4122",
    "lng": "40.4639"
  },
  {
    "country": "RU",
    "name": "Isakogorka",
    "lat": "64.446",
    "lng": "40.6531"
  },
  {
    "country": "RU",
    "name": "Kurilovo",
    "lat": "55.37271",
    "lng": "37.37703"
  },
  {
    "country": "RU",
    "name": "Izmaylovo",
    "lat": "55.56428",
    "lng": "37.64254"
  },
  {
    "country": "RU",
    "name": "Krasnoznamensk",
    "lat": "55.59944",
    "lng": "37.03861"
  },
  {
    "country": "RU",
    "name": "Shishkin Les",
    "lat": "55.41057",
    "lng": "37.18853"
  },
  {
    "country": "RU",
    "name": "Posëlok Mar’ino",
    "lat": "55.55",
    "lng": "37.32"
  },
  {
    "country": "RU",
    "name": "Mosrentgen",
    "lat": "55.6197",
    "lng": "37.46402"
  },
  {
    "country": "RU",
    "name": "Zarech’ye",
    "lat": "55.68667",
    "lng": "37.3924"
  },
  {
    "country": "RU",
    "name": "Povedniki",
    "lat": "55.97",
    "lng": "37.6"
  },
  {
    "country": "RU",
    "name": "Chertanovo Yuzhnoye",
    "lat": "55.59072",
    "lng": "37.59519"
  },
  {
    "country": "RU",
    "name": "Sredniy",
    "lat": "52.8884",
    "lng": "103.4904"
  },
  {
    "country": "RU",
    "name": "Zagor’ye",
    "lat": "55.57657",
    "lng": "37.66709"
  },
  {
    "country": "RU",
    "name": "Orekhovo-Borisovo",
    "lat": "55.61252",
    "lng": "37.72639"
  },
  {
    "country": "RU",
    "name": "Pad’ Mel’nichnaya",
    "lat": "52.16",
    "lng": "104.38"
  },
  {
    "country": "RU",
    "name": "Metrogorodok",
    "lat": "55.80961",
    "lng": "37.78739"
  },
  {
    "country": "RU",
    "name": "Novyy",
    "lat": "43.36438",
    "lng": "132.02109"
  },
  {
    "country": "RU",
    "name": "Chistyye Bory",
    "lat": "58.36472",
    "lng": "41.62778"
  },
  {
    "country": "RU",
    "name": "Zarya",
    "lat": "52.59696",
    "lng": "85.1757"
  },
  {
    "country": "RU",
    "name": "Pervomayskoye",
    "lat": "52.59888",
    "lng": "85.25769"
  },
  {
    "country": "RU",
    "name": "Stan-Bekhtemir",
    "lat": "52.60665",
    "lng": "85.62619"
  },
  {
    "country": "RU",
    "name": "Kogalym",
    "lat": "62.26537",
    "lng": "74.47906"
  },
  {
    "country": "RU",
    "name": "Pyt-Yakh",
    "lat": "60.74985",
    "lng": "72.85824"
  },
  {
    "country": "RU",
    "name": "Langepas",
    "lat": "61.25439",
    "lng": "75.2124"
  },
  {
    "country": "RU",
    "name": "Severomorsk-3",
    "lat": "68.87862",
    "lng": "33.72631"
  },
  {
    "country": "RU",
    "name": "Kievskiy",
    "lat": "55.42999",
    "lng": "36.8666"
  },
  {
    "country": "RU",
    "name": "Obolensk",
    "lat": "54.97741",
    "lng": "37.22449"
  },
  {
    "country": "RU",
    "name": "Lesnoy",
    "lat": "57.6198",
    "lng": "63.0784"
  },
  {
    "country": "RU",
    "name": "Muromtsevo",
    "lat": "55.93096",
    "lng": "40.90738"
  },
  {
    "country": "RU",
    "name": "Nezhdaninskoe",
    "lat": "62.50523",
    "lng": "139.05104"
  },
  {
    "country": "RU",
    "name": "Vzmorye",
    "lat": "54.69606",
    "lng": "20.23613"
  },
  {
    "country": "RU",
    "name": "Shikotan",
    "lat": "43.79916",
    "lng": "146.72164"
  },
  {
    "country": "RU",
    "name": "Peresvet",
    "lat": "56.42302",
    "lng": "38.17612"
  },
  {
    "country": "RU",
    "name": "Blyasino",
    "lat": "56.94565",
    "lng": "28.30621"
  },
  {
    "country": "RU",
    "name": "Pribrezhnyy",
    "lat": "53.48662",
    "lng": "49.85836"
  },
  {
    "country": "RU",
    "name": "Zarya",
    "lat": "55.75533",
    "lng": "38.09578"
  },
  {
    "country": "RU",
    "name": "Raduzhnyy",
    "lat": "56.0038",
    "lng": "40.33905"
  },
  {
    "country": "RU",
    "name": "Nizhnesortymskiy",
    "lat": "62.43965",
    "lng": "71.76029"
  },
  {
    "country": "RU",
    "name": "Pokachi",
    "lat": "61.71982",
    "lng": "75.36827"
  },
  {
    "country": "RU",
    "name": "Izluchinsk",
    "lat": "60.97944",
    "lng": "76.92421"
  },
  {
    "country": "RU",
    "name": "Oktyabr’skiy",
    "lat": "48.655",
    "lng": "43.804"
  },
  {
    "country": "RU",
    "name": "Kusak",
    "lat": "53.2238",
    "lng": "78.9337"
  },
  {
    "country": "RU",
    "name": "Sudoverf’",
    "lat": "58.11696",
    "lng": "38.64175"
  },
  {
    "country": "RU",
    "name": "Singapay",
    "lat": "61.15452",
    "lng": "72.66072"
  },
  {
    "country": "RU",
    "name": "Norkino",
    "lat": "56.6682",
    "lng": "29.0286"
  },
  {
    "country": "RU",
    "name": "Shevlyakovo",
    "lat": "56.39733",
    "lng": "36.85973"
  },
  {
    "country": "RU",
    "name": "Noginsk-9",
    "lat": "56.06681",
    "lng": "38.50013"
  },
  {
    "country": "RU",
    "name": "Staroye Arakchino",
    "lat": "55.8041",
    "lng": "48.9709"
  },
  {
    "country": "RU",
    "name": "Sagan-Nur",
    "lat": "51.3436",
    "lng": "108.4449"
  },
  {
    "country": "RU",
    "name": "Voznesenskiy",
    "lat": "54.8968",
    "lng": "99.1031"
  },
  {
    "country": "RU",
    "name": "Emar",
    "lat": "43.20417",
    "lng": "132.15643"
  },
  {
    "country": "RU",
    "name": "Algatuy",
    "lat": "54.4009",
    "lng": "100.255"
  },
  {
    "country": "RU",
    "name": "Kurortnyy",
    "lat": "60.16562",
    "lng": "29.908"
  },
  {
    "country": "RU",
    "name": "Chernaya Rechka",
    "lat": "59.98594",
    "lng": "30.30338"
  },
  {
    "country": "RU",
    "name": "Untolovo",
    "lat": "60.0122",
    "lng": "30.20897"
  },
  {
    "country": "RU",
    "name": "Petrogradka",
    "lat": "59.96567",
    "lng": "30.31154"
  },
  {
    "country": "RU",
    "name": "Vasyl'evsky Ostrov",
    "lat": "59.94091",
    "lng": "30.25377"
  },
  {
    "country": "RU",
    "name": "Parnas",
    "lat": "60.06964",
    "lng": "30.3487"
  },
  {
    "country": "RU",
    "name": "Kalininskiy",
    "lat": "59.99675",
    "lng": "30.3899"
  },
  {
    "country": "RU",
    "name": "Krasnogvargeisky",
    "lat": "59.97305",
    "lng": "30.47607"
  },
  {
    "country": "RU",
    "name": "Admiralteisky",
    "lat": "59.90839",
    "lng": "30.28484"
  },
  {
    "country": "RU",
    "name": "Krestovskiy ostrov",
    "lat": "59.97091",
    "lng": "30.25789"
  },
  {
    "country": "RU",
    "name": "Akademicheskoe",
    "lat": "60.01375",
    "lng": "30.39471"
  },
  {
    "country": "RU",
    "name": "Finlyandskiy",
    "lat": "59.96824",
    "lng": "30.36415"
  },
  {
    "country": "RU",
    "name": "Centralniy",
    "lat": "59.93111",
    "lng": "30.36072"
  },
  {
    "country": "RU",
    "name": "Tonshalovo",
    "lat": "59.19483",
    "lng": "37.94746"
  },
  {
    "country": "RU",
    "name": "Svetlanovskiy",
    "lat": "60.00276",
    "lng": "30.33051"
  },
  {
    "country": "RU",
    "name": "Sampsonievskiy",
    "lat": "59.98499",
    "lng": "30.34295"
  },
  {
    "country": "RU",
    "name": "Vostochnoe Degunino",
    "lat": "55.8801",
    "lng": "37.55758"
  },
  {
    "country": "RU",
    "name": "Dzerzhinsky",
    "lat": "55.62737",
    "lng": "37.85803"
  },
  {
    "country": "RU",
    "name": "Korolyov",
    "lat": "55.91732",
    "lng": "37.81786"
  },
  {
    "country": "RU",
    "name": "Blagovetschenskaya",
    "lat": "45.0553",
    "lng": "37.13276"
  },
  {
    "country": "RU",
    "name": "Rybnoye",
    "lat": "56.41349",
    "lng": "37.6218"
  },
  {
    "country": "RU",
    "name": "Podosinki",
    "lat": "56.20837",
    "lng": "37.54741"
  },
  {
    "country": "RU",
    "name": "Petrovskiy",
    "lat": "52.24159",
    "lng": "40.64976"
  },
  {
    "country": "RU",
    "name": "Avtopoligon",
    "lat": "56.34984",
    "lng": "37.32296"
  },
  {
    "country": "RU",
    "name": "Budenovetc",
    "lat": "56.37975",
    "lng": "37.62774"
  },
  {
    "country": "RU",
    "name": "Gorshkovo",
    "lat": "56.37561",
    "lng": "37.4124"
  },
  {
    "country": "RU",
    "name": "Ol'yavidovo",
    "lat": "56.5033",
    "lng": "37.7516"
  },
  {
    "country": "RU",
    "name": "Filippovka",
    "lat": "57.4373",
    "lng": "57.01934"
  },
  {
    "country": "RU",
    "name": "LMS",
    "lat": "55.31425",
    "lng": "37.18546"
  },
  {
    "country": "RU",
    "name": "Krasnaya Pahra",
    "lat": "55.43223",
    "lng": "37.26966"
  },
  {
    "country": "RU",
    "name": "Poselok Turisticheskogo pansionata Klyazminskoe vodohranilische",
    "lat": "55.99507",
    "lng": "37.67199"
  },
  {
    "country": "RU",
    "name": "Novoorlovsk",
    "lat": "51.07549",
    "lng": "114.7261"
  },
  {
    "country": "RU",
    "name": "Petrovskoye",
    "lat": "56.69755",
    "lng": "28.645"
  },
  {
    "country": "RU",
    "name": "Tanais",
    "lat": "47.26837",
    "lng": "39.33425"
  },
  {
    "country": "RU",
    "name": "Zarech’ye",
    "lat": "53.73078",
    "lng": "35.63246"
  },
  {
    "country": "RU",
    "name": "Semiozerje",
    "lat": "60.32018",
    "lng": "29.29705"
  },
  {
    "country": "RU",
    "name": "Fedorovskiy",
    "lat": "61.6063",
    "lng": "73.71415"
  },
  {
    "country": "RU",
    "name": "Vysokiy",
    "lat": "68.13583",
    "lng": "33.41917"
  },
  {
    "country": "RU",
    "name": "Vniissok",
    "lat": "55.65639",
    "lng": "37.21194"
  },
  {
    "country": "RU",
    "name": "Solnechniy",
    "lat": "61.27944",
    "lng": "73.18139"
  },
  {
    "country": "RU",
    "name": "Roschinskiy",
    "lat": "53.05111",
    "lng": "50.49667"
  },
  {
    "country": "RU",
    "name": "Korotchaevo",
    "lat": "65.91028",
    "lng": "78.20917"
  },
  {
    "country": "RU",
    "name": "Slavniy",
    "lat": "53.54654",
    "lng": "36.47387"
  },
  {
    "country": "RW",
    "name": "Rwamagana",
    "lat": "-1.9487",
    "lng": "30.4347"
  },
  {
    "country": "RW",
    "name": "Musanze",
    "lat": "-1.49984",
    "lng": "29.63497"
  },
  {
    "country": "RW",
    "name": "Nzega",
    "lat": "-2.479",
    "lng": "29.5564"
  },
  {
    "country": "RW",
    "name": "Kigali",
    "lat": "-1.94995",
    "lng": "30.05885"
  },
  {
    "country": "RW",
    "name": "Kibuye",
    "lat": "-2.06028",
    "lng": "29.34778"
  },
  {
    "country": "RW",
    "name": "Kibungo",
    "lat": "-2.1597",
    "lng": "30.5427"
  },
  {
    "country": "RW",
    "name": "Gitarama",
    "lat": "-2.07444",
    "lng": "29.75667"
  },
  {
    "country": "RW",
    "name": "Gikongoro",
    "lat": "-2.46397",
    "lng": "29.57389"
  },
  {
    "country": "RW",
    "name": "Cyangugu",
    "lat": "-2.4846",
    "lng": "28.9075"
  },
  {
    "country": "RW",
    "name": "Gisenyi",
    "lat": "-1.70278",
    "lng": "29.25639"
  },
  {
    "country": "RW",
    "name": "Byumba",
    "lat": "-1.5763",
    "lng": "30.0675"
  },
  {
    "country": "RW",
    "name": "Butare",
    "lat": "-2.59667",
    "lng": "29.73944"
  },
  {
    "country": "RW",
    "name": "Nyanza",
    "lat": "-2.35187",
    "lng": "29.75089"
  },
  {
    "country": "RW",
    "name": "Eglise Catholique, Centrale GIKO",
    "lat": "-1.93653",
    "lng": "29.8061"
  },
  {
    "country": "SA",
    "name": "Yanbu",
    "lat": "24.08954",
    "lng": "38.0618"
  },
  {
    "country": "SA",
    "name": "Unayzah",
    "lat": "26.08793",
    "lng": "43.96368"
  },
  {
    "country": "SA",
    "name": "Umm Lajj",
    "lat": "25.02126",
    "lng": "37.2685"
  },
  {
    "country": "SA",
    "name": "Umm as Sāhik",
    "lat": "26.65361",
    "lng": "49.91639"
  },
  {
    "country": "SA",
    "name": "Turaif",
    "lat": "31.67252",
    "lng": "38.66374"
  },
  {
    "country": "SA",
    "name": "Turabah",
    "lat": "21.21406",
    "lng": "41.6331"
  },
  {
    "country": "SA",
    "name": "At Tūbī",
    "lat": "26.55778",
    "lng": "49.99167"
  },
  {
    "country": "SA",
    "name": "Tārūt",
    "lat": "26.5733",
    "lng": "50.04028"
  },
  {
    "country": "SA",
    "name": "Tanūmah",
    "lat": "27.1",
    "lng": "44.13333"
  },
  {
    "country": "SA",
    "name": "Tabuk",
    "lat": "28.3998",
    "lng": "36.57151"
  },
  {
    "country": "SA",
    "name": "Ţubarjal",
    "lat": "30.49987",
    "lng": "38.21603"
  },
  {
    "country": "SA",
    "name": "Tabālah",
    "lat": "19.95",
    "lng": "42.4"
  },
  {
    "country": "SA",
    "name": "Sulţānah",
    "lat": "24.49258",
    "lng": "39.58572"
  },
  {
    "country": "SA",
    "name": "Sayhāt",
    "lat": "26.48345",
    "lng": "50.04849"
  },
  {
    "country": "SA",
    "name": "Şāmitah",
    "lat": "16.59601",
    "lng": "42.94435"
  },
  {
    "country": "SA",
    "name": "Sakakah",
    "lat": "29.96974",
    "lng": "40.20641"
  },
  {
    "country": "SA",
    "name": "Şafwá",
    "lat": "26.6497",
    "lng": "49.95522"
  },
  {
    "country": "SA",
    "name": "Şabyā",
    "lat": "17.1495",
    "lng": "42.62537"
  },
  {
    "country": "SA",
    "name": "Raḩīmah",
    "lat": "26.70791",
    "lng": "50.06194"
  },
  {
    "country": "SA",
    "name": "Rābigh",
    "lat": "22.79856",
    "lng": "39.03493"
  },
  {
    "country": "SA",
    "name": "Qal‘at Bīshah",
    "lat": "20.00054",
    "lng": "42.6052"
  },
  {
    "country": "SA",
    "name": "Najrān",
    "lat": "17.49326",
    "lng": "44.12766"
  },
  {
    "country": "SA",
    "name": "Mulayjah",
    "lat": "27.27103",
    "lng": "48.42419"
  },
  {
    "country": "SA",
    "name": "Mislīyah",
    "lat": "17.45988",
    "lng": "42.5572"
  },
  {
    "country": "SA",
    "name": "Marāt",
    "lat": "25.07064",
    "lng": "45.45775"
  },
  {
    "country": "SA",
    "name": "Mecca",
    "lat": "21.42664",
    "lng": "39.82563"
  },
  {
    "country": "SA",
    "name": "Khamis Mushait",
    "lat": "18.3",
    "lng": "42.73333"
  },
  {
    "country": "SA",
    "name": "Julayjilah",
    "lat": "25.5",
    "lng": "49.6"
  },
  {
    "country": "SA",
    "name": "Jizan",
    "lat": "16.88917",
    "lng": "42.55111"
  },
  {
    "country": "SA",
    "name": "Jeddah",
    "lat": "21.54238",
    "lng": "39.19797"
  },
  {
    "country": "SA",
    "name": "Ha'il",
    "lat": "27.52188",
    "lng": "41.69073"
  },
  {
    "country": "SA",
    "name": "Hafar Al-Batin",
    "lat": "28.43279",
    "lng": "45.97077"
  },
  {
    "country": "SA",
    "name": "Farasān",
    "lat": "16.70222",
    "lng": "42.11833"
  },
  {
    "country": "SA",
    "name": "Duba",
    "lat": "27.35134",
    "lng": "35.69014"
  },
  {
    "country": "SA",
    "name": "Buraydah",
    "lat": "26.32599",
    "lng": "43.97497"
  },
  {
    "country": "SA",
    "name": "Abqaiq",
    "lat": "25.93402",
    "lng": "49.6688"
  },
  {
    "country": "SA",
    "name": "Badr Ḩunayn",
    "lat": "23.78292",
    "lng": "38.79047"
  },
  {
    "country": "SA",
    "name": "Az Zulfī",
    "lat": "26.29945",
    "lng": "44.81542"
  },
  {
    "country": "SA",
    "name": "Dhahran",
    "lat": "26.28864",
    "lng": "50.11396"
  },
  {
    "country": "SA",
    "name": "Aţ Ţaraf",
    "lat": "25.36232",
    "lng": "49.72757"
  },
  {
    "country": "SA",
    "name": "Ta’if",
    "lat": "21.27028",
    "lng": "40.41583"
  },
  {
    "country": "SA",
    "name": "As Sulayyil",
    "lat": "20.46067",
    "lng": "45.57792"
  },
  {
    "country": "SA",
    "name": "Sājir",
    "lat": "25.18251",
    "lng": "44.59964"
  },
  {
    "country": "SA",
    "name": "As Saffānīyah",
    "lat": "27.97083",
    "lng": "48.73"
  },
  {
    "country": "SA",
    "name": "Riyadh",
    "lat": "24.68773",
    "lng": "46.72185"
  },
  {
    "country": "SA",
    "name": "Ar Rass",
    "lat": "25.86944",
    "lng": "43.4973"
  },
  {
    "country": "SA",
    "name": "Arar",
    "lat": "30.97531",
    "lng": "41.03808"
  },
  {
    "country": "SA",
    "name": "An Nimāş",
    "lat": "19.14547",
    "lng": "42.12009"
  },
  {
    "country": "SA",
    "name": "Qurayyat",
    "lat": "31.33176",
    "lng": "37.34282"
  },
  {
    "country": "SA",
    "name": "Al Wajh",
    "lat": "26.24551",
    "lng": "36.45249"
  },
  {
    "country": "SA",
    "name": "Al-`Ula",
    "lat": "26.60853",
    "lng": "37.92316"
  },
  {
    "country": "SA",
    "name": "Al Qurayn",
    "lat": "25.48333",
    "lng": "49.6"
  },
  {
    "country": "SA",
    "name": "Qaisumah",
    "lat": "28.31117",
    "lng": "46.12729"
  },
  {
    "country": "SA",
    "name": "Al Qaţīf",
    "lat": "26.56542",
    "lng": "50.0089"
  },
  {
    "country": "SA",
    "name": "Al Qārah",
    "lat": "25.41667",
    "lng": "49.66667"
  },
  {
    "country": "SA",
    "name": "Al Muţayrifī",
    "lat": "25.47878",
    "lng": "49.55824"
  },
  {
    "country": "SA",
    "name": "Al Munayzilah",
    "lat": "25.38333",
    "lng": "49.66667"
  },
  {
    "country": "SA",
    "name": "Al Mubarraz",
    "lat": "25.40768",
    "lng": "49.59028"
  },
  {
    "country": "SA",
    "name": "Al Mindak",
    "lat": "20.1588",
    "lng": "41.28337"
  },
  {
    "country": "SA",
    "name": "Al Mithnab",
    "lat": "25.86012",
    "lng": "44.22228"
  },
  {
    "country": "SA",
    "name": "Al Markaz",
    "lat": "25.4",
    "lng": "49.73333"
  },
  {
    "country": "SA",
    "name": "Al Majma‘ah",
    "lat": "25.91097",
    "lng": "45.35665"
  },
  {
    "country": "SA",
    "name": "Medina",
    "lat": "24.46861",
    "lng": "39.61417"
  },
  {
    "country": "SA",
    "name": "Khobar",
    "lat": "26.27944",
    "lng": "50.20833"
  },
  {
    "country": "SA",
    "name": "Al Kharj",
    "lat": "24.15541",
    "lng": "47.33457"
  },
  {
    "country": "SA",
    "name": "Al Khafjī",
    "lat": "28.43905",
    "lng": "48.49132"
  },
  {
    "country": "SA",
    "name": "Al Jumūm",
    "lat": "21.61694",
    "lng": "39.69806"
  },
  {
    "country": "SA",
    "name": "Al Jubayl",
    "lat": "27.0174",
    "lng": "49.62251"
  },
  {
    "country": "SA",
    "name": "Al Jubayl",
    "lat": "25.4",
    "lng": "49.65"
  },
  {
    "country": "SA",
    "name": "Al Jarādīyah",
    "lat": "16.57946",
    "lng": "42.9124"
  },
  {
    "country": "SA",
    "name": "Al Jafr",
    "lat": "25.37736",
    "lng": "49.72154"
  },
  {
    "country": "SA",
    "name": "Al Hufūf",
    "lat": "25.36467",
    "lng": "49.58764"
  },
  {
    "country": "SA",
    "name": "Al Bukayrīyah",
    "lat": "26.13915",
    "lng": "43.65782"
  },
  {
    "country": "SA",
    "name": "Al Baţţālīyah",
    "lat": "25.43333",
    "lng": "49.63333"
  },
  {
    "country": "SA",
    "name": "Al Bahah",
    "lat": "20.01288",
    "lng": "41.46767"
  },
  {
    "country": "SA",
    "name": "Al Arţāwīyah",
    "lat": "26.50387",
    "lng": "45.34813"
  },
  {
    "country": "SA",
    "name": "Al Awjām",
    "lat": "26.56324",
    "lng": "49.94331"
  },
  {
    "country": "SA",
    "name": "‘Afīf",
    "lat": "23.9065",
    "lng": "42.91724"
  },
  {
    "country": "SA",
    "name": "Adh Dhibiyah",
    "lat": "26.027",
    "lng": "43.157"
  },
  {
    "country": "SA",
    "name": "Ad Dilam",
    "lat": "23.99104",
    "lng": "47.16181"
  },
  {
    "country": "SA",
    "name": "Ad Dawādimī",
    "lat": "24.50772",
    "lng": "44.39237"
  },
  {
    "country": "SA",
    "name": "Ad Darb",
    "lat": "17.72285",
    "lng": "42.25261"
  },
  {
    "country": "SA",
    "name": "Dammam",
    "lat": "26.43442",
    "lng": "50.10326"
  },
  {
    "country": "SA",
    "name": "Abū ‘Arīsh",
    "lat": "16.96887",
    "lng": "42.83251"
  },
  {
    "country": "SA",
    "name": "Abha",
    "lat": "18.21639",
    "lng": "42.50528"
  },
  {
    "country": "SA",
    "name": "Şuwayr",
    "lat": "30.11713",
    "lng": "40.38925"
  },
  {
    "country": "SA",
    "name": "Wed Alnkil",
    "lat": "25.4267",
    "lng": "42.8343"
  },
  {
    "country": "SA",
    "name": "Tumayr",
    "lat": "25.70347",
    "lng": "45.86835"
  },
  {
    "country": "SA",
    "name": "Al Fuwayliq",
    "lat": "26.4436",
    "lng": "43.25164"
  },
  {
    "country": "SA",
    "name": "Al Majāridah",
    "lat": "19.12361",
    "lng": "41.91111"
  },
  {
    "country": "SA",
    "name": "Ain AlBaraha",
    "lat": "24.75806",
    "lng": "43.77389"
  },
  {
    "country": "SA",
    "name": "Al Muwayh",
    "lat": "22.43333",
    "lng": "41.75829"
  },
  {
    "country": "SA",
    "name": "Al Hadā",
    "lat": "21.36753",
    "lng": "40.28694"
  },
  {
    "country": "SA",
    "name": "Ash Shafā",
    "lat": "21.0721",
    "lng": "40.31185"
  },
  {
    "country": "SA",
    "name": "Mizhirah",
    "lat": "16.82611",
    "lng": "42.73333"
  },
  {
    "country": "SA",
    "name": "shokhaibٍ",
    "lat": "24.49023",
    "lng": "46.26871"
  },
  {
    "country": "SA",
    "name": "Unaizah",
    "lat": "26.08427",
    "lng": "43.99355"
  },
  {
    "country": "SB",
    "name": "Tulagi",
    "lat": "-9.10306",
    "lng": "160.15056"
  },
  {
    "country": "SB",
    "name": "Honiara",
    "lat": "-9.43333",
    "lng": "159.95"
  },
  {
    "country": "SB",
    "name": "Gizo",
    "lat": "-8.10303",
    "lng": "156.84186"
  },
  {
    "country": "SB",
    "name": "Buala",
    "lat": "-8.14497",
    "lng": "159.59212"
  },
  {
    "country": "SB",
    "name": "Auki",
    "lat": "-8.76778",
    "lng": "160.69778"
  },
  {
    "country": "SB",
    "name": "Lata",
    "lat": "-10.725",
    "lng": "165.79722"
  },
  {
    "country": "SB",
    "name": "Kirakira",
    "lat": "-10.45442",
    "lng": "161.92045"
  },
  {
    "country": "SB",
    "name": "Taro",
    "lat": "-6.71111",
    "lng": "156.39722"
  },
  {
    "country": "SC",
    "name": "Victoria",
    "lat": "-4.62001",
    "lng": "55.45501"
  },
  {
    "country": "SC",
    "name": "Takamaka",
    "lat": "-4.76667",
    "lng": "55.5"
  },
  {
    "country": "SC",
    "name": "Port Glaud",
    "lat": "-4.66667",
    "lng": "55.41667"
  },
  {
    "country": "SC",
    "name": "Cascade",
    "lat": "-4.66667",
    "lng": "55.5"
  },
  {
    "country": "SC",
    "name": "Bel Ombre",
    "lat": "-4.61667",
    "lng": "55.41667"
  },
  {
    "country": "SC",
    "name": "Beau Vallon",
    "lat": "-4.62091",
    "lng": "55.43015"
  },
  {
    "country": "SC",
    "name": "Anse Royale",
    "lat": "-4.73333",
    "lng": "55.51667"
  },
  {
    "country": "SC",
    "name": "Anse Boileau",
    "lat": "-4.71667",
    "lng": "55.48333"
  },
  {
    "country": "SC",
    "name": "La Passe",
    "lat": "-4.34808",
    "lng": "55.83269"
  },
  {
    "country": "SD",
    "name": "Dongola",
    "lat": "19.18163",
    "lng": "30.47689"
  },
  {
    "country": "SD",
    "name": "Zalingei",
    "lat": "12.90918",
    "lng": "23.47058"
  },
  {
    "country": "SD",
    "name": "Wagar",
    "lat": "16.1525",
    "lng": "36.2032"
  },
  {
    "country": "SD",
    "name": "Wad Rāwah",
    "lat": "15.16028",
    "lng": "33.13972"
  },
  {
    "country": "SD",
    "name": "Wad Medani",
    "lat": "14.40118",
    "lng": "33.51989"
  },
  {
    "country": "SD",
    "name": "Wad az Zāki",
    "lat": "14.4619",
    "lng": "32.2065"
  },
  {
    "country": "SD",
    "name": "Umm Ruwaba",
    "lat": "12.9061",
    "lng": "31.2158"
  },
  {
    "country": "SD",
    "name": "Umm Kaddadah",
    "lat": "13.60169",
    "lng": "26.68759"
  },
  {
    "country": "SD",
    "name": "Um Jar Al Gharbiyya",
    "lat": "13.8013",
    "lng": "32.4078"
  },
  {
    "country": "SD",
    "name": "Omdurman",
    "lat": "15.64453",
    "lng": "32.47773"
  },
  {
    "country": "SD",
    "name": "Tokār",
    "lat": "18.4254",
    "lng": "37.729"
  },
  {
    "country": "SD",
    "name": "Tandaltī",
    "lat": "13.01667",
    "lng": "31.86667"
  },
  {
    "country": "SD",
    "name": "Talodi",
    "lat": "10.63246",
    "lng": "30.3797"
  },
  {
    "country": "SD",
    "name": "Singa",
    "lat": "13.1483",
    "lng": "33.93117"
  },
  {
    "country": "SD",
    "name": "Shendi",
    "lat": "16.6915",
    "lng": "33.4341"
  },
  {
    "country": "SD",
    "name": "Sawākin",
    "lat": "19.1059",
    "lng": "37.3321"
  },
  {
    "country": "SD",
    "name": "Sinnar",
    "lat": "13.56907",
    "lng": "33.56718"
  },
  {
    "country": "SD",
    "name": "Rabak",
    "lat": "13.18087",
    "lng": "32.73999"
  },
  {
    "country": "SD",
    "name": "Nyala",
    "lat": "12.04888",
    "lng": "24.88069"
  },
  {
    "country": "SD",
    "name": "Merowe",
    "lat": "18.47036",
    "lng": "31.81126"
  },
  {
    "country": "SD",
    "name": "Marabba",
    "lat": "12.35",
    "lng": "32.18333"
  },
  {
    "country": "SD",
    "name": "Maiurno",
    "lat": "13.41667",
    "lng": "33.66667"
  },
  {
    "country": "SD",
    "name": "Kutum",
    "lat": "14.2",
    "lng": "24.66667"
  },
  {
    "country": "SD",
    "name": "Kosti",
    "lat": "13.1629",
    "lng": "32.66347"
  },
  {
    "country": "SD",
    "name": "Kurmuk",
    "lat": "10.55",
    "lng": "34.28333"
  },
  {
    "country": "SD",
    "name": "Kuraymah",
    "lat": "18.55",
    "lng": "31.85"
  },
  {
    "country": "SD",
    "name": "Kināna",
    "lat": "14.0361",
    "lng": "33.1712"
  },
  {
    "country": "SD",
    "name": "Kassala",
    "lat": "15.45099",
    "lng": "36.39998"
  },
  {
    "country": "SD",
    "name": "Karmah an Nuzul",
    "lat": "19.63333",
    "lng": "30.41667"
  },
  {
    "country": "SD",
    "name": "Kadugli",
    "lat": "11.01111",
    "lng": "29.71833"
  },
  {
    "country": "SD",
    "name": "Gebeit",
    "lat": "21.06667",
    "lng": "36.31667"
  },
  {
    "country": "SD",
    "name": "Jalqani",
    "lat": "12.4486",
    "lng": "34.2186"
  },
  {
    "country": "SD",
    "name": "Doka",
    "lat": "13.51667",
    "lng": "35.76667"
  },
  {
    "country": "SD",
    "name": "Dilling",
    "lat": "12.05",
    "lng": "29.65"
  },
  {
    "country": "SD",
    "name": "Port Sudan",
    "lat": "19.61745",
    "lng": "37.21644"
  },
  {
    "country": "SD",
    "name": "Berber",
    "lat": "18.02158",
    "lng": "33.98299"
  },
  {
    "country": "SD",
    "name": "Bārah",
    "lat": "13.7",
    "lng": "30.36667"
  },
  {
    "country": "SD",
    "name": "Atbara",
    "lat": "17.70217",
    "lng": "33.98638"
  },
  {
    "country": "SD",
    "name": "As Sūkī",
    "lat": "13.31667",
    "lng": "33.88333"
  },
  {
    "country": "SD",
    "name": "Ar Ruseris",
    "lat": "11.8659",
    "lng": "34.3869"
  },
  {
    "country": "SD",
    "name": "Ar Rahad",
    "lat": "12.71667",
    "lng": "30.65"
  },
  {
    "country": "SD",
    "name": "Aroma",
    "lat": "15.81667",
    "lng": "36.13333"
  },
  {
    "country": "SD",
    "name": "Argo",
    "lat": "19.51667",
    "lng": "30.41667"
  },
  {
    "country": "SD",
    "name": "An Nuhūd",
    "lat": "12.7",
    "lng": "28.43333"
  },
  {
    "country": "SD",
    "name": "El Obeid",
    "lat": "13.18421",
    "lng": "30.21669"
  },
  {
    "country": "SD",
    "name": "Al Qiţena",
    "lat": "14.8648",
    "lng": "32.3668"
  },
  {
    "country": "SD",
    "name": "Al Qadarif",
    "lat": "14.03493",
    "lng": "35.38344"
  },
  {
    "country": "SD",
    "name": "Al Masallamiyya",
    "lat": "14.5748",
    "lng": "33.3373"
  },
  {
    "country": "SD",
    "name": "Al Mijlad",
    "lat": "11.03333",
    "lng": "27.73333"
  },
  {
    "country": "SD",
    "name": "El Matama",
    "lat": "16.7095",
    "lng": "33.3565"
  },
  {
    "country": "SD",
    "name": "Al Manāqil",
    "lat": "14.2459",
    "lng": "32.9891"
  },
  {
    "country": "SD",
    "name": "Al Lagowa",
    "lat": "11.4",
    "lng": "29.13333"
  },
  {
    "country": "SD",
    "name": "Khartoum",
    "lat": "15.55177",
    "lng": "32.53241"
  },
  {
    "country": "SD",
    "name": "Al Kiremit al ‘Arakiyyīn",
    "lat": "14.3476",
    "lng": "32.9437"
  },
  {
    "country": "SD",
    "name": "Al Kawa",
    "lat": "13.7463",
    "lng": "32.4996"
  },
  {
    "country": "SD",
    "name": "Geneina",
    "lat": "13.45262",
    "lng": "22.44725"
  },
  {
    "country": "SD",
    "name": "Al Hilāliyya",
    "lat": "14.9398",
    "lng": "33.234"
  },
  {
    "country": "SD",
    "name": "Al Ḩawātah",
    "lat": "13.41667",
    "lng": "34.63333"
  },
  {
    "country": "SD",
    "name": "Al Hasaheisa",
    "lat": "14.75264",
    "lng": "33.29836"
  },
  {
    "country": "SD",
    "name": "Al Fūlah",
    "lat": "11.73292",
    "lng": "28.35786"
  },
  {
    "country": "SD",
    "name": "El Fasher",
    "lat": "13.62793",
    "lng": "25.34936"
  },
  {
    "country": "SD",
    "name": "El Bauga",
    "lat": "18.26197",
    "lng": "33.90812"
  },
  {
    "country": "SD",
    "name": "Ad Douiem",
    "lat": "14.0012",
    "lng": "32.3116"
  },
  {
    "country": "SD",
    "name": "El Daein",
    "lat": "11.46186",
    "lng": "26.12583"
  },
  {
    "country": "SD",
    "name": "Ad Dindar",
    "lat": "13.2",
    "lng": "34.16667"
  },
  {
    "country": "SD",
    "name": "Ed Damer",
    "lat": "17.59898",
    "lng": "33.97205"
  },
  {
    "country": "SD",
    "name": "Ad-Damazin",
    "lat": "11.7891",
    "lng": "34.3592"
  },
  {
    "country": "SD",
    "name": "Ad Dabbah",
    "lat": "18.05",
    "lng": "30.95"
  },
  {
    "country": "SD",
    "name": "Abū Zabad",
    "lat": "12.35",
    "lng": "29.25"
  },
  {
    "country": "SD",
    "name": "Abu Jibeha",
    "lat": "11.4562",
    "lng": "31.2285"
  },
  {
    "country": "SD",
    "name": "Gereida",
    "lat": "11.27543",
    "lng": "25.14026"
  },
  {
    "country": "SD",
    "name": "El Fula",
    "lat": "11.71195",
    "lng": "28.3462"
  },
  {
    "country": "SE",
    "name": "Viken",
    "lat": "64.72587",
    "lng": "20.91548"
  },
  {
    "country": "SE",
    "name": "Ursviken",
    "lat": "64.71261",
    "lng": "21.1658"
  },
  {
    "country": "SE",
    "name": "Umeå",
    "lat": "63.82842",
    "lng": "20.25972"
  },
  {
    "country": "SE",
    "name": "Töre",
    "lat": "65.91243",
    "lng": "22.65128"
  },
  {
    "country": "SE",
    "name": "Täfteå",
    "lat": "63.8397",
    "lng": "20.47857"
  },
  {
    "country": "SE",
    "name": "Storvik",
    "lat": "65.15",
    "lng": "20.73333"
  },
  {
    "country": "SE",
    "name": "Södra Sunderbyn",
    "lat": "65.65983",
    "lng": "21.94004"
  },
  {
    "country": "SE",
    "name": "Skelleftehamn",
    "lat": "64.68333",
    "lng": "21.23333"
  },
  {
    "country": "SE",
    "name": "Skellefteå",
    "lat": "64.75067",
    "lng": "20.95279"
  },
  {
    "country": "SE",
    "name": "Råneå",
    "lat": "65.85482",
    "lng": "22.29126"
  },
  {
    "country": "SE",
    "name": "Sävar",
    "lat": "63.90383",
    "lng": "20.55014"
  },
  {
    "country": "SE",
    "name": "Rosvik",
    "lat": "65.43333",
    "lng": "21.7"
  },
  {
    "country": "SE",
    "name": "Rolfs",
    "lat": "65.85",
    "lng": "23.11667"
  },
  {
    "country": "SE",
    "name": "Roknäs",
    "lat": "65.35",
    "lng": "21.2"
  },
  {
    "country": "SE",
    "name": "Robertsfors",
    "lat": "64.19324",
    "lng": "20.84806"
  },
  {
    "country": "SE",
    "name": "Röbäck",
    "lat": "63.80879",
    "lng": "20.18901"
  },
  {
    "country": "SE",
    "name": "Sävast",
    "lat": "65.77002",
    "lng": "21.73113"
  },
  {
    "country": "SE",
    "name": "Piteå",
    "lat": "65.31717",
    "lng": "21.47944"
  },
  {
    "country": "SE",
    "name": "Pajala",
    "lat": "67.21284",
    "lng": "23.36607"
  },
  {
    "country": "SE",
    "name": "Övertorneå",
    "lat": "66.38778",
    "lng": "23.65425"
  },
  {
    "country": "SE",
    "name": "Överkalix",
    "lat": "66.32754",
    "lng": "22.84414"
  },
  {
    "country": "SE",
    "name": "Obbola",
    "lat": "63.7",
    "lng": "20.31667"
  },
  {
    "country": "SE",
    "name": "Norrfjärden",
    "lat": "65.41805",
    "lng": "21.50151"
  },
  {
    "country": "SE",
    "name": "Malmberget",
    "lat": "67.17529",
    "lng": "20.65495"
  },
  {
    "country": "SE",
    "name": "Luleå",
    "lat": "65.58415",
    "lng": "22.15465"
  },
  {
    "country": "SE",
    "name": "Långsele",
    "lat": "64.81667",
    "lng": "20.25"
  },
  {
    "country": "SE",
    "name": "Kiruna",
    "lat": "67.85572",
    "lng": "20.22513"
  },
  {
    "country": "SE",
    "name": "Kalix",
    "lat": "65.85298",
    "lng": "23.15645"
  },
  {
    "country": "SE",
    "name": "Kåge",
    "lat": "64.83571",
    "lng": "20.98453"
  },
  {
    "country": "SE",
    "name": "Hortlax",
    "lat": "65.28188",
    "lng": "21.40544"
  },
  {
    "country": "SE",
    "name": "Holmsund",
    "lat": "63.70602",
    "lng": "20.36409"
  },
  {
    "country": "SE",
    "name": "Haparanda",
    "lat": "65.83549",
    "lng": "24.13676"
  },
  {
    "country": "SE",
    "name": "Gammelstad",
    "lat": "65.63931",
    "lng": "22.01145"
  },
  {
    "country": "SE",
    "name": "Gällivare",
    "lat": "67.13387",
    "lng": "20.65278"
  },
  {
    "country": "SE",
    "name": "Forsbacka",
    "lat": "64.76667",
    "lng": "20.5"
  },
  {
    "country": "SE",
    "name": "Ersmark",
    "lat": "63.88333",
    "lng": "20.31667"
  },
  {
    "country": "SE",
    "name": "Byske",
    "lat": "64.95258",
    "lng": "21.2058"
  },
  {
    "country": "SE",
    "name": "Burträsk",
    "lat": "64.51667",
    "lng": "20.65"
  },
  {
    "country": "SE",
    "name": "Bureå",
    "lat": "64.61667",
    "lng": "21.2"
  },
  {
    "country": "SE",
    "name": "Boliden",
    "lat": "64.86667",
    "lng": "20.38333"
  },
  {
    "country": "SE",
    "name": "Boden",
    "lat": "65.82518",
    "lng": "21.68864"
  },
  {
    "country": "SE",
    "name": "Bergsviken",
    "lat": "65.3",
    "lng": "21.38333"
  },
  {
    "country": "SE",
    "name": "Bergnäset",
    "lat": "65.57791",
    "lng": "22.10844"
  },
  {
    "country": "SE",
    "name": "Backa",
    "lat": "64.98333",
    "lng": "21.06667"
  },
  {
    "country": "SE",
    "name": "Älvsbyn",
    "lat": "65.67624",
    "lng": "21.00162"
  },
  {
    "country": "SE",
    "name": "Alunda",
    "lat": "60.26667",
    "lng": "18.4"
  },
  {
    "country": "SE",
    "name": "Anneberg",
    "lat": "60.24167",
    "lng": "18.41667"
  },
  {
    "country": "SE",
    "name": "Björklinge",
    "lat": "60.03004",
    "lng": "17.55203"
  },
  {
    "country": "SE",
    "name": "Marieberg",
    "lat": "60.23333",
    "lng": "18.5"
  },
  {
    "country": "SE",
    "name": "Ystad",
    "lat": "55.42966",
    "lng": "13.82041"
  },
  {
    "country": "SE",
    "name": "Vrigstad",
    "lat": "57.35",
    "lng": "14.46667"
  },
  {
    "country": "SE",
    "name": "Vittsjö",
    "lat": "56.34366",
    "lng": "13.66081"
  },
  {
    "country": "SE",
    "name": "Vislanda",
    "lat": "56.78333",
    "lng": "14.45"
  },
  {
    "country": "SE",
    "name": "Viskafors",
    "lat": "57.62941",
    "lng": "12.8489"
  },
  {
    "country": "SE",
    "name": "Visby",
    "lat": "57.64089",
    "lng": "18.29602"
  },
  {
    "country": "SE",
    "name": "Virserum",
    "lat": "57.31667",
    "lng": "15.58333"
  },
  {
    "country": "SE",
    "name": "Vintrosa",
    "lat": "59.25",
    "lng": "14.95"
  },
  {
    "country": "SE",
    "name": "Vinslöv",
    "lat": "56.1",
    "lng": "13.91667"
  },
  {
    "country": "SE",
    "name": "Vinninga",
    "lat": "58.45",
    "lng": "13.26667"
  },
  {
    "country": "SE",
    "name": "Vingåker",
    "lat": "59.0433",
    "lng": "15.87374"
  },
  {
    "country": "SE",
    "name": "Vindeln",
    "lat": "64.20175",
    "lng": "19.71945"
  },
  {
    "country": "SE",
    "name": "Vimmerby",
    "lat": "57.66588",
    "lng": "15.85515"
  },
  {
    "country": "SE",
    "name": "Vilhelmina",
    "lat": "64.62417",
    "lng": "16.65596"
  },
  {
    "country": "SE",
    "name": "Vikingstad",
    "lat": "58.38304",
    "lng": "15.43201"
  },
  {
    "country": "SE",
    "name": "Viken",
    "lat": "56.15063",
    "lng": "12.57429"
  },
  {
    "country": "SE",
    "name": "Vikarbyn",
    "lat": "60.91667",
    "lng": "15.01667"
  },
  {
    "country": "SE",
    "name": "Vi",
    "lat": "62.3",
    "lng": "17.16667"
  },
  {
    "country": "SE",
    "name": "Vibble",
    "lat": "57.60452",
    "lng": "18.25601"
  },
  {
    "country": "SE",
    "name": "Vetlanda",
    "lat": "57.42887",
    "lng": "15.07762"
  },
  {
    "country": "SE",
    "name": "Vellinge",
    "lat": "55.47124",
    "lng": "13.01971"
  },
  {
    "country": "SE",
    "name": "Vejbystrand",
    "lat": "56.31778",
    "lng": "12.76722"
  },
  {
    "country": "SE",
    "name": "Veinge",
    "lat": "56.55",
    "lng": "13.06667"
  },
  {
    "country": "SE",
    "name": "Veddige",
    "lat": "57.26591",
    "lng": "12.3322"
  },
  {
    "country": "SE",
    "name": "Veberöd",
    "lat": "55.63333",
    "lng": "13.48333"
  },
  {
    "country": "SE",
    "name": "Växjö",
    "lat": "56.87767",
    "lng": "14.80906"
  },
  {
    "country": "SE",
    "name": "Vaxholm",
    "lat": "59.40225",
    "lng": "18.35317"
  },
  {
    "country": "SE",
    "name": "Vattholma",
    "lat": "60.01667",
    "lng": "17.73333"
  },
  {
    "country": "SE",
    "name": "Västervik",
    "lat": "57.7584",
    "lng": "16.63733"
  },
  {
    "country": "SE",
    "name": "Västerås",
    "lat": "59.61617",
    "lng": "16.55276"
  },
  {
    "country": "SE",
    "name": "Vasastan",
    "lat": "59.34571",
    "lng": "18.04985"
  },
  {
    "country": "SE",
    "name": "Vårsta",
    "lat": "59.16528",
    "lng": "17.79722"
  },
  {
    "country": "SE",
    "name": "Värnamo",
    "lat": "57.18604",
    "lng": "14.04001"
  },
  {
    "country": "SE",
    "name": "Vargön",
    "lat": "58.35599",
    "lng": "12.3906"
  },
  {
    "country": "SE",
    "name": "Vårgårda",
    "lat": "58.03706",
    "lng": "12.80907"
  },
  {
    "country": "SE",
    "name": "Varberg",
    "lat": "57.10557",
    "lng": "12.25078"
  },
  {
    "country": "SE",
    "name": "Vara",
    "lat": "58.26234",
    "lng": "12.95413"
  },
  {
    "country": "SE",
    "name": "Vansbro",
    "lat": "60.50893",
    "lng": "14.22458"
  },
  {
    "country": "SE",
    "name": "Vännäsby",
    "lat": "63.91564",
    "lng": "19.82438"
  },
  {
    "country": "SE",
    "name": "Vännäs",
    "lat": "63.90676",
    "lng": "19.75712"
  },
  {
    "country": "SE",
    "name": "Vänersborg",
    "lat": "58.38075",
    "lng": "12.3234"
  },
  {
    "country": "SE",
    "name": "Vallentuna",
    "lat": "59.53436",
    "lng": "18.07758"
  },
  {
    "country": "SE",
    "name": "Vallda",
    "lat": "57.4775",
    "lng": "12.00139"
  },
  {
    "country": "SE",
    "name": "Valla",
    "lat": "63.55",
    "lng": "13.8"
  },
  {
    "country": "SE",
    "name": "Valla",
    "lat": "59.01667",
    "lng": "16.38333"
  },
  {
    "country": "SE",
    "name": "Valje",
    "lat": "56.06279",
    "lng": "14.54388"
  },
  {
    "country": "SE",
    "name": "Valdemarsvik",
    "lat": "58.2031",
    "lng": "16.60225"
  },
  {
    "country": "SE",
    "name": "Valbo",
    "lat": "60.65",
    "lng": "17.03333"
  },
  {
    "country": "SE",
    "name": "Vålberg",
    "lat": "59.39145",
    "lng": "13.18633"
  },
  {
    "country": "SE",
    "name": "Vagnhärad",
    "lat": "58.94587",
    "lng": "17.48757"
  },
  {
    "country": "SE",
    "name": "Vaggeryd",
    "lat": "57.49807",
    "lng": "14.14842"
  },
  {
    "country": "SE",
    "name": "Vadstena",
    "lat": "58.44863",
    "lng": "14.88969"
  },
  {
    "country": "SE",
    "name": "Uppsala",
    "lat": "59.85882",
    "lng": "17.63889"
  },
  {
    "country": "SE",
    "name": "Upplands Väsby",
    "lat": "59.51839",
    "lng": "17.91128"
  },
  {
    "country": "SE",
    "name": "Hjärup",
    "lat": "55.6688",
    "lng": "13.13931"
  },
  {
    "country": "SE",
    "name": "Ulricehamn",
    "lat": "57.79159",
    "lng": "13.41422"
  },
  {
    "country": "SE",
    "name": "Uddevalla",
    "lat": "58.34784",
    "lng": "11.9424"
  },
  {
    "country": "SE",
    "name": "Tyringe",
    "lat": "56.16037",
    "lng": "13.59811"
  },
  {
    "country": "SE",
    "name": "Tygelsjö",
    "lat": "55.51667",
    "lng": "13"
  },
  {
    "country": "SE",
    "name": "Tvååker",
    "lat": "57.04147",
    "lng": "12.3995"
  },
  {
    "country": "SE",
    "name": "Tumba",
    "lat": "59.19858",
    "lng": "17.83317"
  },
  {
    "country": "SE",
    "name": "Tullinge",
    "lat": "59.2",
    "lng": "17.9"
  },
  {
    "country": "SE",
    "name": "Trosa",
    "lat": "58.89621",
    "lng": "17.54812"
  },
  {
    "country": "SE",
    "name": "Trönninge",
    "lat": "56.61667",
    "lng": "12.93333"
  },
  {
    "country": "SE",
    "name": "Trollhättan",
    "lat": "58.28365",
    "lng": "12.28864"
  },
  {
    "country": "SE",
    "name": "Gimo",
    "lat": "60.17304",
    "lng": "18.18507"
  },
  {
    "country": "SE",
    "name": "Trelleborg",
    "lat": "55.37514",
    "lng": "13.15691"
  },
  {
    "country": "SE",
    "name": "Trekanten",
    "lat": "56.7",
    "lng": "16.11667"
  },
  {
    "country": "SE",
    "name": "Träslövsläge",
    "lat": "57.05417",
    "lng": "12.27899"
  },
  {
    "country": "SE",
    "name": "Tranemo",
    "lat": "57.48333",
    "lng": "13.35"
  },
  {
    "country": "SE",
    "name": "Tranås",
    "lat": "58.03717",
    "lng": "14.9782"
  },
  {
    "country": "SE",
    "name": "Torup",
    "lat": "56.95663",
    "lng": "13.07725"
  },
  {
    "country": "SE",
    "name": "Torslanda",
    "lat": "57.72432",
    "lng": "11.77013"
  },
  {
    "country": "SE",
    "name": "Torshälla",
    "lat": "59.41667",
    "lng": "16.46667"
  },
  {
    "country": "SE",
    "name": "Torsby",
    "lat": "60.13527",
    "lng": "13.0082"
  },
  {
    "country": "SE",
    "name": "Torsås",
    "lat": "56.41251",
    "lng": "15.99844"
  },
  {
    "country": "SE",
    "name": "Tormestorp",
    "lat": "56.1135",
    "lng": "13.74516"
  },
  {
    "country": "SE",
    "name": "Torekov",
    "lat": "56.425",
    "lng": "12.63333"
  },
  {
    "country": "SE",
    "name": "Töreboda",
    "lat": "58.70739",
    "lng": "14.12597"
  },
  {
    "country": "SE",
    "name": "Tomelilla",
    "lat": "55.54293",
    "lng": "13.9546"
  },
  {
    "country": "SE",
    "name": "Tollarp1",
    "lat": "56.16667",
    "lng": "14.28333"
  },
  {
    "country": "SE",
    "name": "Tollarp",
    "lat": "55.93333",
    "lng": "13.98333"
  },
  {
    "country": "SE",
    "name": "Töcksfors",
    "lat": "59.50816",
    "lng": "11.84431"
  },
  {
    "country": "SE",
    "name": "Tjuvkil",
    "lat": "57.9",
    "lng": "11.73333"
  },
  {
    "country": "SE",
    "name": "Tingsryd",
    "lat": "56.5247",
    "lng": "14.97902"
  },
  {
    "country": "SE",
    "name": "Timrå",
    "lat": "62.48654",
    "lng": "17.32613"
  },
  {
    "country": "SE",
    "name": "Timmernabben",
    "lat": "56.96667",
    "lng": "16.43333"
  },
  {
    "country": "SE",
    "name": "Tillberga",
    "lat": "59.68333",
    "lng": "16.61667"
  },
  {
    "country": "SE",
    "name": "Tierp",
    "lat": "60.34269",
    "lng": "17.51812"
  },
  {
    "country": "SE",
    "name": "Tidaholm",
    "lat": "58.18035",
    "lng": "13.95824"
  },
  {
    "country": "SE",
    "name": "Tibro",
    "lat": "58.42453",
    "lng": "14.16162"
  },
  {
    "country": "SE",
    "name": "Tenhult",
    "lat": "57.70761",
    "lng": "14.32205"
  },
  {
    "country": "SE",
    "name": "Teckomatorp",
    "lat": "55.86667",
    "lng": "13.08333"
  },
  {
    "country": "SE",
    "name": "Tärnsjö",
    "lat": "60.15",
    "lng": "16.93333"
  },
  {
    "country": "SE",
    "name": "Tanumshede",
    "lat": "58.72385",
    "lng": "11.32587"
  },
  {
    "country": "SE",
    "name": "Tallboda",
    "lat": "58.42521",
    "lng": "15.68154"
  },
  {
    "country": "SE",
    "name": "Täby",
    "lat": "59.4439",
    "lng": "18.06872"
  },
  {
    "country": "SE",
    "name": "Taberg",
    "lat": "57.67722",
    "lng": "14.08876"
  },
  {
    "country": "SE",
    "name": "Svenljunga",
    "lat": "57.49551",
    "lng": "13.11078"
  },
  {
    "country": "SE",
    "name": "Sveg",
    "lat": "62.03407",
    "lng": "14.36577"
  },
  {
    "country": "SE",
    "name": "Svedala",
    "lat": "55.50788",
    "lng": "13.23515"
  },
  {
    "country": "SE",
    "name": "Svärtinge",
    "lat": "58.65507",
    "lng": "16.02823"
  },
  {
    "country": "SE",
    "name": "Svärdsjö",
    "lat": "60.74022",
    "lng": "15.90173"
  },
  {
    "country": "SE",
    "name": "Svängsta",
    "lat": "56.26667",
    "lng": "14.76667"
  },
  {
    "country": "SE",
    "name": "Svanesund",
    "lat": "58.14292",
    "lng": "11.81821"
  },
  {
    "country": "SE",
    "name": "Svalsta",
    "lat": "58.74273",
    "lng": "16.86978"
  },
  {
    "country": "SE",
    "name": "Svalöv",
    "lat": "55.9134",
    "lng": "13.10762"
  },
  {
    "country": "SE",
    "name": "Surte",
    "lat": "57.82533",
    "lng": "12.01604"
  },
  {
    "country": "SE",
    "name": "Surahammar",
    "lat": "59.70725",
    "lng": "16.22188"
  },
  {
    "country": "SE",
    "name": "Sunne",
    "lat": "59.83764",
    "lng": "13.14302"
  },
  {
    "country": "SE",
    "name": "Sundsvall",
    "lat": "62.39129",
    "lng": "17.3063"
  },
  {
    "country": "SE",
    "name": "Sundsbruk",
    "lat": "62.45806",
    "lng": "17.34889"
  },
  {
    "country": "SE",
    "name": "Sundbyberg",
    "lat": "59.36128",
    "lng": "17.97114"
  },
  {
    "country": "SE",
    "name": "Styrsö",
    "lat": "57.61639",
    "lng": "11.78556"
  },
  {
    "country": "SE",
    "name": "Sturkö",
    "lat": "56.08333",
    "lng": "15.7"
  },
  {
    "country": "SE",
    "name": "Sturefors",
    "lat": "58.33333",
    "lng": "15.73333"
  },
  {
    "country": "SE",
    "name": "Strövelstorp",
    "lat": "56.16979",
    "lng": "12.83925"
  },
  {
    "country": "SE",
    "name": "Strömsund",
    "lat": "63.85206",
    "lng": "15.55583"
  },
  {
    "country": "SE",
    "name": "Strömstad",
    "lat": "58.93945",
    "lng": "11.1712"
  },
  {
    "country": "SE",
    "name": "Strömsnäsbruk",
    "lat": "56.55",
    "lng": "13.71667"
  },
  {
    "country": "SE",
    "name": "Strömma",
    "lat": "59.28333",
    "lng": "18.53333"
  },
  {
    "country": "SE",
    "name": "Strängnäs",
    "lat": "59.37741",
    "lng": "17.03119"
  },
  {
    "country": "SE",
    "name": "Storvreta",
    "lat": "59.95933",
    "lng": "17.70588"
  },
  {
    "country": "SE",
    "name": "Storvik",
    "lat": "60.58333",
    "lng": "16.53333"
  },
  {
    "country": "SE",
    "name": "Storuman",
    "lat": "65.0959",
    "lng": "17.11731"
  },
  {
    "country": "SE",
    "name": "Storfors",
    "lat": "59.53183",
    "lng": "14.27201"
  },
  {
    "country": "SE",
    "name": "Storebro",
    "lat": "57.58333",
    "lng": "15.85"
  },
  {
    "country": "SE",
    "name": "Stora Höga",
    "lat": "58.01667",
    "lng": "11.83333"
  },
  {
    "country": "SE",
    "name": "Storå",
    "lat": "59.71409",
    "lng": "15.13169"
  },
  {
    "country": "SE",
    "name": "Stöpen",
    "lat": "58.47802",
    "lng": "13.86611"
  },
  {
    "country": "SE",
    "name": "Stockvik",
    "lat": "62.33667",
    "lng": "17.36583"
  },
  {
    "country": "SE",
    "name": "Stockholm",
    "lat": "59.33258",
    "lng": "18.0649"
  },
  {
    "country": "SE",
    "name": "Stockaryd",
    "lat": "57.31737",
    "lng": "14.59341"
  },
  {
    "country": "SE",
    "name": "Stigtomta",
    "lat": "58.8",
    "lng": "16.78333"
  },
  {
    "country": "SE",
    "name": "Stenungsund",
    "lat": "58.07046",
    "lng": "11.8181"
  },
  {
    "country": "SE",
    "name": "Stenstorp",
    "lat": "58.48333",
    "lng": "15.06667"
  },
  {
    "country": "SE",
    "name": "Stenstorp",
    "lat": "58.27254",
    "lng": "13.71454"
  },
  {
    "country": "SE",
    "name": "Stenkullen",
    "lat": "57.79476",
    "lng": "12.31688"
  },
  {
    "country": "SE",
    "name": "Steninge",
    "lat": "56.769",
    "lng": "12.63034"
  },
  {
    "country": "SE",
    "name": "Stenhamra",
    "lat": "59.3344",
    "lng": "17.68842"
  },
  {
    "country": "SE",
    "name": "Stehag",
    "lat": "55.90188",
    "lng": "13.39577"
  },
  {
    "country": "SE",
    "name": "Stavsnäs",
    "lat": "59.28333",
    "lng": "18.68333"
  },
  {
    "country": "SE",
    "name": "Stångby",
    "lat": "55.7503",
    "lng": "13.19797"
  },
  {
    "country": "SE",
    "name": "Stallarholmen",
    "lat": "59.36667",
    "lng": "17.2"
  },
  {
    "country": "SE",
    "name": "Staffanstorp",
    "lat": "55.64277",
    "lng": "13.20638"
  },
  {
    "country": "SE",
    "name": "Gamla Stan",
    "lat": "59.32627",
    "lng": "18.07251"
  },
  {
    "country": "SE",
    "name": "Sösdala",
    "lat": "56.03992",
    "lng": "13.67811"
  },
  {
    "country": "SE",
    "name": "Sorsele",
    "lat": "65.53484",
    "lng": "17.53702"
  },
  {
    "country": "SE",
    "name": "Sörforsa",
    "lat": "61.73333",
    "lng": "16.98333"
  },
  {
    "country": "SE",
    "name": "Söråker",
    "lat": "62.50561",
    "lng": "17.51032"
  },
  {
    "country": "SE",
    "name": "Sölvesborg",
    "lat": "56.05205",
    "lng": "14.57525"
  },
  {
    "country": "SE",
    "name": "Solna",
    "lat": "59.36004",
    "lng": "18.00086"
  },
  {
    "country": "SE",
    "name": "Sollentuna",
    "lat": "59.42804",
    "lng": "17.95093"
  },
  {
    "country": "SE",
    "name": "Sollefteå",
    "lat": "63.16667",
    "lng": "17.26667"
  },
  {
    "country": "SE",
    "name": "Sollebrunn",
    "lat": "58.11667",
    "lng": "12.53333"
  },
  {
    "country": "SE",
    "name": "Södra Vi",
    "lat": "57.73993",
    "lng": "15.79391"
  },
  {
    "country": "SE",
    "name": "Södra Sandby",
    "lat": "56.56667",
    "lng": "16.61667"
  },
  {
    "country": "SE",
    "name": "Södra Sandby",
    "lat": "55.71677",
    "lng": "13.34659"
  },
  {
    "country": "SE",
    "name": "Södertälje",
    "lat": "59.19554",
    "lng": "17.62525"
  },
  {
    "country": "SE",
    "name": "Södermalm",
    "lat": "59.31278",
    "lng": "18.07577"
  },
  {
    "country": "SE",
    "name": "Söderköping",
    "lat": "58.48057",
    "lng": "16.32221"
  },
  {
    "country": "SE",
    "name": "Söderhamn",
    "lat": "61.30373",
    "lng": "17.05921"
  },
  {
    "country": "SE",
    "name": "Söderfors",
    "lat": "64.81667",
    "lng": "18.05"
  },
  {
    "country": "SE",
    "name": "Söderfors",
    "lat": "60.38333",
    "lng": "17.23333"
  },
  {
    "country": "SE",
    "name": "Smygehamn",
    "lat": "55.34337",
    "lng": "13.36989"
  },
  {
    "country": "SE",
    "name": "Smögen",
    "lat": "58.35593",
    "lng": "11.22411"
  },
  {
    "country": "SE",
    "name": "Smedjebacken",
    "lat": "60.14181",
    "lng": "15.41416"
  },
  {
    "country": "SE",
    "name": "Smedby",
    "lat": "60.7",
    "lng": "15.05"
  },
  {
    "country": "SE",
    "name": "Smedby",
    "lat": "56.67413",
    "lng": "16.2432"
  },
  {
    "country": "SE",
    "name": "Smålandsstenar",
    "lat": "57.16241",
    "lng": "13.41212"
  },
  {
    "country": "SE",
    "name": "Slottsbron",
    "lat": "59.3227",
    "lng": "13.10268"
  },
  {
    "country": "SE",
    "name": "Skutskär",
    "lat": "60.62507",
    "lng": "17.41552"
  },
  {
    "country": "SE",
    "name": "Skurup",
    "lat": "55.47839",
    "lng": "13.50186"
  },
  {
    "country": "SE",
    "name": "Skultuna",
    "lat": "59.71667",
    "lng": "16.41667"
  },
  {
    "country": "SE",
    "name": "Skultorp",
    "lat": "58.35",
    "lng": "13.83333"
  },
  {
    "country": "SE",
    "name": "Skrea",
    "lat": "56.88333",
    "lng": "12.56667"
  },
  {
    "country": "SE",
    "name": "Skövde",
    "lat": "58.39118",
    "lng": "13.84506"
  },
  {
    "country": "SE",
    "name": "Skottsund",
    "lat": "62.29056",
    "lng": "17.38694"
  },
  {
    "country": "SE",
    "name": "Sköllersta",
    "lat": "59.13738",
    "lng": "15.3394"
  },
  {
    "country": "SE",
    "name": "Skogstorp",
    "lat": "59.32472",
    "lng": "16.48284"
  },
  {
    "country": "SE",
    "name": "Skoghall",
    "lat": "59.32324",
    "lng": "13.46552"
  },
  {
    "country": "SE",
    "name": "Skivarp",
    "lat": "55.41667",
    "lng": "13.56667"
  },
  {
    "country": "SE",
    "name": "Skinnskatteberg",
    "lat": "59.83028",
    "lng": "15.69337"
  },
  {
    "country": "SE",
    "name": "Skillingaryd",
    "lat": "57.43044",
    "lng": "14.09383"
  },
  {
    "country": "SE",
    "name": "Skepplanda",
    "lat": "57.98333",
    "lng": "12.2"
  },
  {
    "country": "SE",
    "name": "Skegrie",
    "lat": "55.40633",
    "lng": "13.07693"
  },
  {
    "country": "SE",
    "name": "Skattkärr",
    "lat": "59.41208",
    "lng": "13.67078"
  },
  {
    "country": "SE",
    "name": "Skärhamn",
    "lat": "57.98665",
    "lng": "11.55742"
  },
  {
    "country": "SE",
    "name": "Skåre",
    "lat": "55.38333",
    "lng": "13.05"
  },
  {
    "country": "SE",
    "name": "Skåre",
    "lat": "59.43333",
    "lng": "13.43333"
  },
  {
    "country": "SE",
    "name": "Skärblacka",
    "lat": "58.56667",
    "lng": "15.9"
  },
  {
    "country": "SE",
    "name": "Skara",
    "lat": "58.38659",
    "lng": "13.43836"
  },
  {
    "country": "SE",
    "name": "Skänninge",
    "lat": "59.93333",
    "lng": "18.48333"
  },
  {
    "country": "SE",
    "name": "Skänninge",
    "lat": "58.39427",
    "lng": "15.08659"
  },
  {
    "country": "SE",
    "name": "Sjuntorp",
    "lat": "58.2",
    "lng": "12.21667"
  },
  {
    "country": "SE",
    "name": "Sjömarken",
    "lat": "57.71533",
    "lng": "12.83495"
  },
  {
    "country": "SE",
    "name": "Sjöbo",
    "lat": "55.63135",
    "lng": "13.70622"
  },
  {
    "country": "SE",
    "name": "Simrishamn",
    "lat": "55.55653",
    "lng": "14.35037"
  },
  {
    "country": "SE",
    "name": "Siljansnäs",
    "lat": "60.78333",
    "lng": "14.85"
  },
  {
    "country": "SE",
    "name": "Sigtuna",
    "lat": "59.61731",
    "lng": "17.72361"
  },
  {
    "country": "SE",
    "name": "Sibbhult",
    "lat": "56.26667",
    "lng": "14.2"
  },
  {
    "country": "SE",
    "name": "Segeltorp",
    "lat": "59.27597",
    "lng": "17.93072"
  },
  {
    "country": "SE",
    "name": "Sävsjö",
    "lat": "57.40327",
    "lng": "14.66244"
  },
  {
    "country": "SE",
    "name": "Sävja",
    "lat": "59.81872",
    "lng": "17.69958"
  },
  {
    "country": "SE",
    "name": "Sätofta",
    "lat": "55.91667",
    "lng": "13.55"
  },
  {
    "country": "SE",
    "name": "Sätila",
    "lat": "57.54172",
    "lng": "12.43429"
  },
  {
    "country": "SE",
    "name": "Säter",
    "lat": "60.34778",
    "lng": "15.75051"
  },
  {
    "country": "SE",
    "name": "Särö",
    "lat": "57.50577",
    "lng": "11.9321"
  },
  {
    "country": "SE",
    "name": "Sandviken",
    "lat": "60.61667",
    "lng": "16.76667"
  },
  {
    "country": "SE",
    "name": "Sandarne",
    "lat": "61.25893",
    "lng": "17.15284"
  },
  {
    "country": "SE",
    "name": "Sandared",
    "lat": "57.70992",
    "lng": "12.79238"
  },
  {
    "country": "SE",
    "name": "Saltsjöbaden",
    "lat": "59.28333",
    "lng": "18.3"
  },
  {
    "country": "SE",
    "name": "Sålanda",
    "lat": "57.98333",
    "lng": "12.21667"
  },
  {
    "country": "SE",
    "name": "Sala",
    "lat": "59.91993",
    "lng": "16.60655"
  },
  {
    "country": "SE",
    "name": "Säffle",
    "lat": "59.13229",
    "lng": "12.92888"
  },
  {
    "country": "SE",
    "name": "Rydsgård",
    "lat": "55.47285",
    "lng": "13.58829"
  },
  {
    "country": "SE",
    "name": "Rydebäck",
    "lat": "55.96667",
    "lng": "12.76667"
  },
  {
    "country": "SE",
    "name": "Rydaholm",
    "lat": "56.98388",
    "lng": "14.30849"
  },
  {
    "country": "SE",
    "name": "Ryd",
    "lat": "58.66667",
    "lng": "15.08333"
  },
  {
    "country": "SE",
    "name": "Ryd",
    "lat": "56.46667",
    "lng": "14.68333"
  },
  {
    "country": "SE",
    "name": "Rottne",
    "lat": "57.01667",
    "lng": "14.9"
  },
  {
    "country": "SE",
    "name": "Rosersberg",
    "lat": "59.58333",
    "lng": "17.88333"
  },
  {
    "country": "SE",
    "name": "Rönninge",
    "lat": "59.2",
    "lng": "17.73333"
  },
  {
    "country": "SE",
    "name": "Ronneby",
    "lat": "56.20999",
    "lng": "15.27602"
  },
  {
    "country": "SE",
    "name": "Rönnäng",
    "lat": "57.93333",
    "lng": "11.58333"
  },
  {
    "country": "SE",
    "name": "Romme",
    "lat": "60.43333",
    "lng": "15.5"
  },
  {
    "country": "SE",
    "name": "Rödeby",
    "lat": "56.26078",
    "lng": "15.62143"
  },
  {
    "country": "SE",
    "name": "Rinkabyholm",
    "lat": "56.64972",
    "lng": "16.26667"
  },
  {
    "country": "SE",
    "name": "Rindö",
    "lat": "59.39688",
    "lng": "18.39434"
  },
  {
    "country": "SE",
    "name": "Rimforsa",
    "lat": "58.13624",
    "lng": "15.6865"
  },
  {
    "country": "SE",
    "name": "Rimbo",
    "lat": "59.75",
    "lng": "18.36667"
  },
  {
    "country": "SE",
    "name": "Resarö",
    "lat": "59.4291",
    "lng": "18.33386"
  },
  {
    "country": "SE",
    "name": "Reftele",
    "lat": "57.17467",
    "lng": "13.59498"
  },
  {
    "country": "SE",
    "name": "Rävlanda",
    "lat": "57.65338",
    "lng": "12.49791"
  },
  {
    "country": "SE",
    "name": "Rättvik",
    "lat": "60.88632",
    "lng": "15.11787"
  },
  {
    "country": "SE",
    "name": "Råtorp",
    "lat": "59.40197",
    "lng": "13.49144"
  },
  {
    "country": "SE",
    "name": "Råsunda",
    "lat": "59.36588",
    "lng": "17.99569"
  },
  {
    "country": "SE",
    "name": "Ramnäs",
    "lat": "59.76667",
    "lng": "16.2"
  },
  {
    "country": "SE",
    "name": "Perstorp",
    "lat": "56.13829",
    "lng": "13.39476"
  },
  {
    "country": "SE",
    "name": "Pershagen",
    "lat": "59.15494",
    "lng": "17.6534"
  },
  {
    "country": "SE",
    "name": "Påskallavik",
    "lat": "57.16667",
    "lng": "16.45"
  },
  {
    "country": "SE",
    "name": "Partille",
    "lat": "57.7395",
    "lng": "12.10642"
  },
  {
    "country": "SE",
    "name": "Pålsboda",
    "lat": "59.06565",
    "lng": "15.33747"
  },
  {
    "country": "SE",
    "name": "Påarp",
    "lat": "56.03333",
    "lng": "12.81667"
  },
  {
    "country": "SE",
    "name": "Oxie",
    "lat": "55.54014",
    "lng": "13.09605"
  },
  {
    "country": "SE",
    "name": "Oxelösund",
    "lat": "58.67057",
    "lng": "17.10152"
  },
  {
    "country": "SE",
    "name": "Överum",
    "lat": "57.98856",
    "lng": "16.3139"
  },
  {
    "country": "SE",
    "name": "Östra Ljungby",
    "lat": "56.19601",
    "lng": "13.09199"
  },
  {
    "country": "SE",
    "name": "Östhammar",
    "lat": "60.25909",
    "lng": "18.37408"
  },
  {
    "country": "SE",
    "name": "Östervåla",
    "lat": "60.18333",
    "lng": "17.18333"
  },
  {
    "country": "SE",
    "name": "Östersund",
    "lat": "63.1792",
    "lng": "14.63566"
  },
  {
    "country": "SE",
    "name": "Östermalm",
    "lat": "59.33879",
    "lng": "18.08487"
  },
  {
    "country": "SE",
    "name": "Österbymo",
    "lat": "57.82465",
    "lng": "15.27357"
  },
  {
    "country": "SE",
    "name": "Österbybruk",
    "lat": "60.2",
    "lng": "17.9"
  },
  {
    "country": "SE",
    "name": "Ösmo",
    "lat": "58.98333",
    "lng": "17.9"
  },
  {
    "country": "SE",
    "name": "Oskarström",
    "lat": "56.8",
    "lng": "12.96667"
  },
  {
    "country": "SE",
    "name": "Oskarshamn",
    "lat": "57.26455",
    "lng": "16.44837"
  },
  {
    "country": "SE",
    "name": "Osby",
    "lat": "56.38165",
    "lng": "13.99364"
  },
  {
    "country": "SE",
    "name": "Örsundsbro",
    "lat": "59.73333",
    "lng": "17.3"
  },
  {
    "country": "SE",
    "name": "Orsa",
    "lat": "61.12034",
    "lng": "14.6155"
  },
  {
    "country": "SE",
    "name": "Örnsköldsvik",
    "lat": "63.29091",
    "lng": "18.71525"
  },
  {
    "country": "SE",
    "name": "Ornäs",
    "lat": "60.50944",
    "lng": "15.54128"
  },
  {
    "country": "SE",
    "name": "Örkelljunga",
    "lat": "56.28338",
    "lng": "13.27773"
  },
  {
    "country": "SE",
    "name": "Öregrund",
    "lat": "60.33333",
    "lng": "18.43333"
  },
  {
    "country": "SE",
    "name": "Örebro",
    "lat": "59.27412",
    "lng": "15.2066"
  },
  {
    "country": "SE",
    "name": "Örbyhus",
    "lat": "60.22407",
    "lng": "17.70138"
  },
  {
    "country": "SE",
    "name": "Önnestad",
    "lat": "56.05747",
    "lng": "14.02233"
  },
  {
    "country": "SE",
    "name": "Olstorp",
    "lat": "58.81667",
    "lng": "16.63333"
  },
  {
    "country": "SE",
    "name": "Olofström",
    "lat": "56.2773",
    "lng": "14.53402"
  },
  {
    "country": "SE",
    "name": "Olofstorp",
    "lat": "58.25",
    "lng": "14"
  },
  {
    "country": "SE",
    "name": "Olofstorp",
    "lat": "57.80444",
    "lng": "12.17131"
  },
  {
    "country": "SE",
    "name": "Öjersjö",
    "lat": "57.69882",
    "lng": "12.13448"
  },
  {
    "country": "SE",
    "name": "Ödsmål",
    "lat": "58.1",
    "lng": "11.85"
  },
  {
    "country": "SE",
    "name": "Ödeshög",
    "lat": "58.22949",
    "lng": "14.65294"
  },
  {
    "country": "SE",
    "name": "Odensjö",
    "lat": "57.71667",
    "lng": "14.16667"
  },
  {
    "country": "SE",
    "name": "Odensbacken",
    "lat": "59.16667",
    "lng": "15.53333"
  },
  {
    "country": "SE",
    "name": "Ödåkra",
    "lat": "56.10412",
    "lng": "12.7477"
  },
  {
    "country": "SE",
    "name": "Öckerö",
    "lat": "57.70814",
    "lng": "11.65585"
  },
  {
    "country": "SE",
    "name": "Ockelbo",
    "lat": "60.8912",
    "lng": "16.71846"
  },
  {
    "country": "SE",
    "name": "Nynäshamn",
    "lat": "58.90337",
    "lng": "17.94793"
  },
  {
    "country": "SE",
    "name": "Nykvarn",
    "lat": "59.8",
    "lng": "18.3"
  },
  {
    "country": "SE",
    "name": "Nykvarn",
    "lat": "59.17718",
    "lng": "17.4323"
  },
  {
    "country": "SE",
    "name": "Nyköping",
    "lat": "58.753",
    "lng": "17.00788"
  },
  {
    "country": "SE",
    "name": "Nyhammar",
    "lat": "60.28333",
    "lng": "14.96667"
  },
  {
    "country": "SE",
    "name": "Nybro",
    "lat": "56.74461",
    "lng": "15.90714"
  },
  {
    "country": "SE",
    "name": "Nossebro",
    "lat": "58.18808",
    "lng": "12.71599"
  },
  {
    "country": "SE",
    "name": "Norsjö",
    "lat": "64.91206",
    "lng": "19.48153"
  },
  {
    "country": "SE",
    "name": "Norrtälje",
    "lat": "59.75799",
    "lng": "18.70496"
  },
  {
    "country": "SE",
    "name": "Norrköping",
    "lat": "58.59419",
    "lng": "16.1826"
  },
  {
    "country": "SE",
    "name": "Norra Åsum",
    "lat": "55.98333",
    "lng": "14.15"
  },
  {
    "country": "SE",
    "name": "Nordmaling",
    "lat": "63.56852",
    "lng": "19.50244"
  },
  {
    "country": "SE",
    "name": "Norberg",
    "lat": "60.06505",
    "lng": "15.92366"
  },
  {
    "country": "SE",
    "name": "Nora",
    "lat": "59.51926",
    "lng": "15.03979"
  },
  {
    "country": "SE",
    "name": "Nolby",
    "lat": "62.2875",
    "lng": "17.36917"
  },
  {
    "country": "SE",
    "name": "Njurundabommen",
    "lat": "62.26339",
    "lng": "17.38354"
  },
  {
    "country": "SE",
    "name": "Nättraby",
    "lat": "56.2",
    "lng": "15.51667"
  },
  {
    "country": "SE",
    "name": "Näsum",
    "lat": "56.17693",
    "lng": "14.49706"
  },
  {
    "country": "SE",
    "name": "Nässjö",
    "lat": "57.65307",
    "lng": "14.69676"
  },
  {
    "country": "SE",
    "name": "Nacka",
    "lat": "59.31053",
    "lng": "18.16372"
  },
  {
    "country": "SE",
    "name": "Myggenäs",
    "lat": "58.06176",
    "lng": "11.74936"
  },
  {
    "country": "SE",
    "name": "Munkfors",
    "lat": "59.83856",
    "lng": "13.54361"
  },
  {
    "country": "SE",
    "name": "Munkedal",
    "lat": "58.46634",
    "lng": "11.67345"
  },
  {
    "country": "SE",
    "name": "Munka-Ljungby",
    "lat": "56.25",
    "lng": "12.96667"
  },
  {
    "country": "SE",
    "name": "Mullsjö",
    "lat": "57.9171",
    "lng": "13.87831"
  },
  {
    "country": "SE",
    "name": "Motala",
    "lat": "58.53706",
    "lng": "15.03649"
  },
  {
    "country": "SE",
    "name": "Mörtnäs",
    "lat": "59.31862",
    "lng": "18.44312"
  },
  {
    "country": "SE",
    "name": "Mörrum",
    "lat": "56.19281",
    "lng": "14.74739"
  },
  {
    "country": "SE",
    "name": "Morgongåva",
    "lat": "59.93395",
    "lng": "16.96353"
  },
  {
    "country": "SE",
    "name": "Mörbylånga",
    "lat": "56.5248",
    "lng": "16.37877"
  },
  {
    "country": "SE",
    "name": "Mörarp",
    "lat": "56.05749",
    "lng": "12.88018"
  },
  {
    "country": "SE",
    "name": "Mora",
    "lat": "61.00704",
    "lng": "14.54316"
  },
  {
    "country": "SE",
    "name": "Mönsterås",
    "lat": "57.04134",
    "lng": "16.44463"
  },
  {
    "country": "SE",
    "name": "Mölnlycke",
    "lat": "57.65893",
    "lng": "12.11792"
  },
  {
    "country": "SE",
    "name": "Mölndal",
    "lat": "57.6554",
    "lng": "12.01378"
  },
  {
    "country": "SE",
    "name": "Mölnbo",
    "lat": "59.05",
    "lng": "17.41667"
  },
  {
    "country": "SE",
    "name": "Mölltorp",
    "lat": "58.5",
    "lng": "14.4"
  },
  {
    "country": "SE",
    "name": "Molkom",
    "lat": "59.60057",
    "lng": "13.72115"
  },
  {
    "country": "SE",
    "name": "Moheda",
    "lat": "57",
    "lng": "14.56667"
  },
  {
    "country": "SE",
    "name": "Mockfjärd",
    "lat": "60.5",
    "lng": "14.96667"
  },
  {
    "country": "SE",
    "name": "Mjölby",
    "lat": "58.32595",
    "lng": "15.12365"
  },
  {
    "country": "SE",
    "name": "Mjällby",
    "lat": "56.68333",
    "lng": "12.76667"
  },
  {
    "country": "SE",
    "name": "Mjällby",
    "lat": "56.05",
    "lng": "14.68333"
  },
  {
    "country": "SE",
    "name": "Mellerud",
    "lat": "58.69979",
    "lng": "12.45312"
  },
  {
    "country": "SE",
    "name": "Mellbystrand",
    "lat": "56.48561",
    "lng": "12.93958"
  },
  {
    "country": "SE",
    "name": "Matfors",
    "lat": "62.34864",
    "lng": "17.03173"
  },
  {
    "country": "SE",
    "name": "Märsta",
    "lat": "59.62157",
    "lng": "17.85476"
  },
  {
    "country": "SE",
    "name": "Markaryd",
    "lat": "56.46135",
    "lng": "13.59644"
  },
  {
    "country": "SE",
    "name": "Mariestad",
    "lat": "58.70971",
    "lng": "13.82367"
  },
  {
    "country": "SE",
    "name": "Marieholm",
    "lat": "57.38333",
    "lng": "13.85"
  },
  {
    "country": "SE",
    "name": "Marieholm",
    "lat": "55.86667",
    "lng": "13.15"
  },
  {
    "country": "SE",
    "name": "Mariefred",
    "lat": "59.25963",
    "lng": "17.223"
  },
  {
    "country": "SE",
    "name": "Mariannelund",
    "lat": "57.61667",
    "lng": "15.56667"
  },
  {
    "country": "SE",
    "name": "Mantorp",
    "lat": "58.35",
    "lng": "15.28333"
  },
  {
    "country": "SE",
    "name": "Malung",
    "lat": "60.68329",
    "lng": "13.71542"
  },
  {
    "country": "SE",
    "name": "Malmslätt",
    "lat": "58.41102",
    "lng": "15.51647"
  },
  {
    "country": "SE",
    "name": "Malmö",
    "lat": "55.60587",
    "lng": "13.00073"
  },
  {
    "country": "SE",
    "name": "Malmköping",
    "lat": "59.13333",
    "lng": "16.73333"
  },
  {
    "country": "SE",
    "name": "Malmbäck",
    "lat": "57.57667",
    "lng": "14.4617"
  },
  {
    "country": "SE",
    "name": "Målilla",
    "lat": "57.38773",
    "lng": "15.80675"
  },
  {
    "country": "SE",
    "name": "Malå",
    "lat": "65.18501",
    "lng": "18.74243"
  },
  {
    "country": "SE",
    "name": "Lysekil",
    "lat": "58.27429",
    "lng": "11.43576"
  },
  {
    "country": "SE",
    "name": "Lycksele",
    "lat": "64.59537",
    "lng": "18.67351"
  },
  {
    "country": "SE",
    "name": "Lund",
    "lat": "55.70584",
    "lng": "13.19321"
  },
  {
    "country": "SE",
    "name": "Ludvika",
    "lat": "60.14959",
    "lng": "15.18776"
  },
  {
    "country": "SE",
    "name": "Lövstalöt",
    "lat": "59.9574",
    "lng": "17.57826"
  },
  {
    "country": "SE",
    "name": "Lönsboda",
    "lat": "56.4",
    "lng": "14.31667"
  },
  {
    "country": "SE",
    "name": "Lomma",
    "lat": "55.67244",
    "lng": "13.06849"
  },
  {
    "country": "SE",
    "name": "Lödöse",
    "lat": "58.02994",
    "lng": "12.15934"
  },
  {
    "country": "SE",
    "name": "Löddeköpinge",
    "lat": "55.76667",
    "lng": "13.01667"
  },
  {
    "country": "SE",
    "name": "Löberöd",
    "lat": "55.7761",
    "lng": "13.52414"
  },
  {
    "country": "SE",
    "name": "Ljusne",
    "lat": "61.2117",
    "lng": "17.1279"
  },
  {
    "country": "SE",
    "name": "Ljusdal",
    "lat": "61.82883",
    "lng": "16.09126"
  },
  {
    "country": "SE",
    "name": "Ljungskile",
    "lat": "58.22452",
    "lng": "11.92014"
  },
  {
    "country": "SE",
    "name": "Ljungsbro",
    "lat": "58.51667",
    "lng": "15.5"
  },
  {
    "country": "SE",
    "name": "Ljunghusen",
    "lat": "55.39793",
    "lng": "12.92486"
  },
  {
    "country": "SE",
    "name": "Ljungbyholm",
    "lat": "56.63333",
    "lng": "16.16667"
  },
  {
    "country": "SE",
    "name": "Ljungbyhed",
    "lat": "56.07437",
    "lng": "13.2401"
  },
  {
    "country": "SE",
    "name": "Ljungby",
    "lat": "56.83324",
    "lng": "13.94082"
  },
  {
    "country": "SE",
    "name": "Lit",
    "lat": "63.32029",
    "lng": "14.84594"
  },
  {
    "country": "SE",
    "name": "Linköping",
    "lat": "58.41086",
    "lng": "15.62157"
  },
  {
    "country": "SE",
    "name": "Linghem",
    "lat": "58.43333",
    "lng": "15.78333"
  },
  {
    "country": "SE",
    "name": "Lindsdal",
    "lat": "56.73333",
    "lng": "16.3"
  },
  {
    "country": "SE",
    "name": "Lindome",
    "lat": "57.56667",
    "lng": "12.08333"
  },
  {
    "country": "SE",
    "name": "Lindö",
    "lat": "58.61667",
    "lng": "16.25"
  },
  {
    "country": "SE",
    "name": "Lindholmen",
    "lat": "59.58333",
    "lng": "18.1"
  },
  {
    "country": "SE",
    "name": "Lindesberg",
    "lat": "59.59202",
    "lng": "15.2304"
  },
  {
    "country": "SE",
    "name": "Limmared",
    "lat": "57.53592",
    "lng": "13.35566"
  },
  {
    "country": "SE",
    "name": "Lilla Edet",
    "lat": "58.13333",
    "lng": "12.13333"
  },
  {
    "country": "SE",
    "name": "Lidköping",
    "lat": "58.50517",
    "lng": "13.15765"
  },
  {
    "country": "SE",
    "name": "Lidingö",
    "lat": "59.36667",
    "lng": "18.13333"
  },
  {
    "country": "SE",
    "name": "Lessebo",
    "lat": "56.75185",
    "lng": "15.26969"
  },
  {
    "country": "SE",
    "name": "Lerum",
    "lat": "57.77051",
    "lng": "12.26904"
  },
  {
    "country": "SE",
    "name": "Lenhovda",
    "lat": "57",
    "lng": "15.28333"
  },
  {
    "country": "SE",
    "name": "Leksand",
    "lat": "60.7303",
    "lng": "14.99994"
  },
  {
    "country": "SE",
    "name": "Laxå",
    "lat": "58.9863",
    "lng": "14.61904"
  },
  {
    "country": "SE",
    "name": "Långvik",
    "lat": "59.24583",
    "lng": "18.51667"
  },
  {
    "country": "SE",
    "name": "Långshyttan",
    "lat": "60.45238",
    "lng": "16.03831"
  },
  {
    "country": "SE",
    "name": "Långsele",
    "lat": "63.18333",
    "lng": "17.06667"
  },
  {
    "country": "SE",
    "name": "Länghem",
    "lat": "57.6",
    "lng": "13.23333"
  },
  {
    "country": "SE",
    "name": "Landvetter",
    "lat": "57.68665",
    "lng": "12.21169"
  },
  {
    "country": "SE",
    "name": "Landskrona",
    "lat": "55.8708",
    "lng": "12.83016"
  },
  {
    "country": "SE",
    "name": "Landsbro",
    "lat": "57.36667",
    "lng": "14.9"
  },
  {
    "country": "SE",
    "name": "Lammhult",
    "lat": "57.16667",
    "lng": "14.58333"
  },
  {
    "country": "SE",
    "name": "Laholm",
    "lat": "56.51207",
    "lng": "13.04371"
  },
  {
    "country": "SE",
    "name": "Lagan",
    "lat": "56.91667",
    "lng": "13.98333"
  },
  {
    "country": "SE",
    "name": "Kvissleby",
    "lat": "62.29361",
    "lng": "17.375"
  },
  {
    "country": "SE",
    "name": "Kvidinge",
    "lat": "56.13386",
    "lng": "13.04678"
  },
  {
    "country": "SE",
    "name": "Kvicksund",
    "lat": "59.45099",
    "lng": "16.32131"
  },
  {
    "country": "SE",
    "name": "Kvänum",
    "lat": "58.3",
    "lng": "13.18333"
  },
  {
    "country": "SE",
    "name": "Kungsör",
    "lat": "59.42245",
    "lng": "16.09656"
  },
  {
    "country": "SE",
    "name": "Kungsholmen",
    "lat": "59.33183",
    "lng": "18.04118"
  },
  {
    "country": "SE",
    "name": "Kungshamn",
    "lat": "58.36305",
    "lng": "11.25938"
  },
  {
    "country": "SE",
    "name": "Kungsbacka",
    "lat": "57.48719",
    "lng": "12.07612"
  },
  {
    "country": "SE",
    "name": "Kungsängen",
    "lat": "59.47857",
    "lng": "17.74834"
  },
  {
    "country": "SE",
    "name": "Kungälv",
    "lat": "57.87096",
    "lng": "11.98054"
  },
  {
    "country": "SE",
    "name": "Kummelnäs",
    "lat": "59.35",
    "lng": "18.28333"
  },
  {
    "country": "SE",
    "name": "Kumla",
    "lat": "59.1277",
    "lng": "15.14341"
  },
  {
    "country": "SE",
    "name": "Krylbo",
    "lat": "60.13333",
    "lng": "16.21667"
  },
  {
    "country": "SE",
    "name": "Krokom",
    "lat": "63.32589",
    "lng": "14.44883"
  },
  {
    "country": "SE",
    "name": "Krokek",
    "lat": "58.67231",
    "lng": "16.36741"
  },
  {
    "country": "SE",
    "name": "Kristinehamn",
    "lat": "59.30978",
    "lng": "14.10808"
  },
  {
    "country": "SE",
    "name": "Kristianstad",
    "lat": "56.03129",
    "lng": "14.15242"
  },
  {
    "country": "SE",
    "name": "Kristdala",
    "lat": "57.4007",
    "lng": "16.20496"
  },
  {
    "country": "SE",
    "name": "Kramfors",
    "lat": "62.93161",
    "lng": "17.77646"
  },
  {
    "country": "SE",
    "name": "Kopparmora",
    "lat": "59.33306",
    "lng": "18.58306"
  },
  {
    "country": "SE",
    "name": "Kopparberg",
    "lat": "59.87597",
    "lng": "14.99436"
  },
  {
    "country": "SE",
    "name": "Köpmanholmen",
    "lat": "63.16667",
    "lng": "18.56667"
  },
  {
    "country": "SE",
    "name": "Köpingebro",
    "lat": "55.45526",
    "lng": "13.93453"
  },
  {
    "country": "SE",
    "name": "Köping",
    "lat": "59.51404",
    "lng": "15.99255"
  },
  {
    "country": "SE",
    "name": "Kolsva",
    "lat": "59.6",
    "lng": "15.83333"
  },
  {
    "country": "SE",
    "name": "Kolbäck",
    "lat": "59.56516",
    "lng": "16.23037"
  },
  {
    "country": "SE",
    "name": "Kode",
    "lat": "57.94263",
    "lng": "11.85051"
  },
  {
    "country": "SE",
    "name": "Knivsta",
    "lat": "59.72564",
    "lng": "17.78753"
  },
  {
    "country": "SE",
    "name": "Knislinge",
    "lat": "56.18333",
    "lng": "14.08333"
  },
  {
    "country": "SE",
    "name": "Knäred",
    "lat": "56.51861",
    "lng": "13.32423"
  },
  {
    "country": "SE",
    "name": "Klippan",
    "lat": "56.13559",
    "lng": "13.13086"
  },
  {
    "country": "SE",
    "name": "Klintehamn",
    "lat": "57.38667",
    "lng": "18.20371"
  },
  {
    "country": "SE",
    "name": "Klågerup",
    "lat": "55.59416",
    "lng": "13.24574"
  },
  {
    "country": "SE",
    "name": "Kista",
    "lat": "59.40316",
    "lng": "17.94479"
  },
  {
    "country": "SE",
    "name": "Kisa",
    "lat": "57.98781",
    "lng": "15.63303"
  },
  {
    "country": "SE",
    "name": "Kinna",
    "lat": "57.50728",
    "lng": "12.69463"
  },
  {
    "country": "SE",
    "name": "Kimstad",
    "lat": "58.54967",
    "lng": "15.96296"
  },
  {
    "country": "SE",
    "name": "Kilafors",
    "lat": "61.23333",
    "lng": "16.56667"
  },
  {
    "country": "SE",
    "name": "Kil",
    "lat": "59.50234",
    "lng": "13.31277"
  },
  {
    "country": "SE",
    "name": "Kaxholmen",
    "lat": "57.85345",
    "lng": "14.30457"
  },
  {
    "country": "SE",
    "name": "Kävlinge",
    "lat": "55.79188",
    "lng": "13.11021"
  },
  {
    "country": "SE",
    "name": "Katrineholm",
    "lat": "58.99587",
    "lng": "16.20721"
  },
  {
    "country": "SE",
    "name": "Karlstad",
    "lat": "59.3793",
    "lng": "13.50357"
  },
  {
    "country": "SE",
    "name": "Karlskrona",
    "lat": "56.16156",
    "lng": "15.58661"
  },
  {
    "country": "SE",
    "name": "Karlskoga",
    "lat": "59.32667",
    "lng": "14.52386"
  },
  {
    "country": "SE",
    "name": "Karlshamn",
    "lat": "56.1706",
    "lng": "14.86188"
  },
  {
    "country": "SE",
    "name": "Karlsborg",
    "lat": "58.53724",
    "lng": "14.5047"
  },
  {
    "country": "SE",
    "name": "Karlholmsbruk",
    "lat": "60.52091",
    "lng": "17.63152"
  },
  {
    "country": "SE",
    "name": "Kalmar",
    "lat": "56.66157",
    "lng": "16.36163"
  },
  {
    "country": "SE",
    "name": "Kallinge",
    "lat": "56.24841",
    "lng": "15.28721"
  },
  {
    "country": "SE",
    "name": "Kållered",
    "lat": "57.60992",
    "lng": "12.05106"
  },
  {
    "country": "SE",
    "name": "Källby",
    "lat": "58.50999",
    "lng": "13.30582"
  },
  {
    "country": "SE",
    "name": "Kågeröd",
    "lat": "55.99976",
    "lng": "13.08795"
  },
  {
    "country": "SE",
    "name": "Jursla",
    "lat": "58.66667",
    "lng": "16.18333"
  },
  {
    "country": "SE",
    "name": "Jörlanda",
    "lat": "57.9863",
    "lng": "11.82943"
  },
  {
    "country": "SE",
    "name": "Jordbro",
    "lat": "59.14972",
    "lng": "18.11667"
  },
  {
    "country": "SE",
    "name": "Jonstorp",
    "lat": "58",
    "lng": "12.71667"
  },
  {
    "country": "SE",
    "name": "Jonstorp",
    "lat": "56.2338",
    "lng": "12.67184"
  },
  {
    "country": "SE",
    "name": "Jönköping",
    "lat": "57.78145",
    "lng": "14.15618"
  },
  {
    "country": "SE",
    "name": "Jokkmokk",
    "lat": "66.60665",
    "lng": "19.82324"
  },
  {
    "country": "SE",
    "name": "Johannedal",
    "lat": "62.43424",
    "lng": "17.37273"
  },
  {
    "country": "SE",
    "name": "Järvsö",
    "lat": "61.71667",
    "lng": "16.16667"
  },
  {
    "country": "SE",
    "name": "Järpen",
    "lat": "63.3462",
    "lng": "13.46572"
  },
  {
    "country": "SE",
    "name": "Järna",
    "lat": "60.53333",
    "lng": "14.36667"
  },
  {
    "country": "SE",
    "name": "Järna",
    "lat": "59.09165",
    "lng": "17.56615"
  },
  {
    "country": "SE",
    "name": "Järbo",
    "lat": "60.71667",
    "lng": "16.6"
  },
  {
    "country": "SE",
    "name": "Jämshög",
    "lat": "56.23333",
    "lng": "14.51667"
  },
  {
    "country": "SE",
    "name": "Jämjö",
    "lat": "56.19187",
    "lng": "15.84115"
  },
  {
    "country": "SE",
    "name": "Jakobsberg",
    "lat": "59.42268",
    "lng": "17.83508"
  },
  {
    "country": "SE",
    "name": "Irsta",
    "lat": "59.7",
    "lng": "16.93333"
  },
  {
    "country": "SE",
    "name": "Irsta",
    "lat": "59.6",
    "lng": "16.7"
  },
  {
    "country": "SE",
    "name": "Insjön",
    "lat": "64.4",
    "lng": "17.48333"
  },
  {
    "country": "SE",
    "name": "Insjön",
    "lat": "60.67688",
    "lng": "15.09487"
  },
  {
    "country": "SE",
    "name": "Ingelstad",
    "lat": "56.75",
    "lng": "14.91667"
  },
  {
    "country": "SE",
    "name": "Iggesund",
    "lat": "61.64219",
    "lng": "17.07477"
  },
  {
    "country": "SE",
    "name": "Hyltebruk",
    "lat": "56.99892",
    "lng": "13.23958"
  },
  {
    "country": "SE",
    "name": "Hyllinge",
    "lat": "56.1",
    "lng": "12.85"
  },
  {
    "country": "SE",
    "name": "Husum",
    "lat": "63.33333",
    "lng": "19.16667"
  },
  {
    "country": "SE",
    "name": "Huskvarna",
    "lat": "57.78596",
    "lng": "14.30214"
  },
  {
    "country": "SE",
    "name": "Hunnebostrand",
    "lat": "58.44127",
    "lng": "11.3032"
  },
  {
    "country": "SE",
    "name": "Hultsfred",
    "lat": "57.48815",
    "lng": "15.84357"
  },
  {
    "country": "SE",
    "name": "Hudiksvall",
    "lat": "61.72744",
    "lng": "17.10558"
  },
  {
    "country": "SE",
    "name": "Huddinge",
    "lat": "59.23705",
    "lng": "17.98192"
  },
  {
    "country": "SE",
    "name": "Hovsta",
    "lat": "59.35",
    "lng": "15.21667"
  },
  {
    "country": "SE",
    "name": "Hovmantorp",
    "lat": "56.78685",
    "lng": "15.14023"
  },
  {
    "country": "SE",
    "name": "Höviksnäs",
    "lat": "58.03333",
    "lng": "11.76667"
  },
  {
    "country": "SE",
    "name": "Hova",
    "lat": "58.85363",
    "lng": "14.21914"
  },
  {
    "country": "SE",
    "name": "Horred",
    "lat": "57.35475",
    "lng": "12.47777"
  },
  {
    "country": "SE",
    "name": "Hörnefors",
    "lat": "63.62312",
    "lng": "19.90856"
  },
  {
    "country": "SE",
    "name": "Horndal",
    "lat": "60.3",
    "lng": "16.41667"
  },
  {
    "country": "SE",
    "name": "Hörby",
    "lat": "55.85238",
    "lng": "13.66094"
  },
  {
    "country": "SE",
    "name": "Höör",
    "lat": "55.93444",
    "lng": "13.5385"
  },
  {
    "country": "SE",
    "name": "Hönö",
    "lat": "57.68972",
    "lng": "11.64972"
  },
  {
    "country": "SE",
    "name": "Hölö",
    "lat": "59.28333",
    "lng": "18.66667"
  },
  {
    "country": "SE",
    "name": "Hölö",
    "lat": "59.01667",
    "lng": "17.53333"
  },
  {
    "country": "SE",
    "name": "Höllviken",
    "lat": "55.40982",
    "lng": "12.9558"
  },
  {
    "country": "SE",
    "name": "Hököpinge",
    "lat": "55.49411",
    "lng": "13.00782"
  },
  {
    "country": "SE",
    "name": "Hökåsen",
    "lat": "59.66667",
    "lng": "16.58333"
  },
  {
    "country": "SE",
    "name": "Högsby",
    "lat": "57.16597",
    "lng": "16.02562"
  },
  {
    "country": "SE",
    "name": "Höganäs",
    "lat": "56.19971",
    "lng": "12.55795"
  },
  {
    "country": "SE",
    "name": "Hofterup",
    "lat": "55.80485",
    "lng": "12.9797"
  },
  {
    "country": "SE",
    "name": "Hofors",
    "lat": "60.54573",
    "lng": "16.28668"
  },
  {
    "country": "SE",
    "name": "Hjuvik",
    "lat": "57.70167",
    "lng": "11.71639"
  },
  {
    "country": "SE",
    "name": "Hjo",
    "lat": "58.30133",
    "lng": "14.28784"
  },
  {
    "country": "SE",
    "name": "Hjärnarp",
    "lat": "56.31667",
    "lng": "12.91667"
  },
  {
    "country": "SE",
    "name": "Hittarp",
    "lat": "56.28333",
    "lng": "14.11667"
  },
  {
    "country": "SE",
    "name": "Hittarp",
    "lat": "56.1",
    "lng": "12.63333"
  },
  {
    "country": "SE",
    "name": "Hindås",
    "lat": "57.70338",
    "lng": "12.44657"
  },
  {
    "country": "SE",
    "name": "Hillerstorp",
    "lat": "57.31293",
    "lng": "13.88437"
  },
  {
    "country": "SE",
    "name": "Hestra",
    "lat": "57.91667",
    "lng": "14.58333"
  },
  {
    "country": "SE",
    "name": "Hestra",
    "lat": "57.44232",
    "lng": "13.59575"
  },
  {
    "country": "SE",
    "name": "Herrljunga",
    "lat": "58.07739",
    "lng": "13.02662"
  },
  {
    "country": "SE",
    "name": "Herrestad",
    "lat": "58.38333",
    "lng": "14.8"
  },
  {
    "country": "SE",
    "name": "Henån",
    "lat": "58.23848",
    "lng": "11.67598"
  },
  {
    "country": "SE",
    "name": "Hemse",
    "lat": "57.23788",
    "lng": "18.37443"
  },
  {
    "country": "SE",
    "name": "Hemmesta",
    "lat": "59.32273",
    "lng": "18.48675"
  },
  {
    "country": "SE",
    "name": "Helsingborg",
    "lat": "56.04673",
    "lng": "12.69437"
  },
  {
    "country": "SE",
    "name": "Hedesunda",
    "lat": "60.4",
    "lng": "17"
  },
  {
    "country": "SE",
    "name": "Hedemora",
    "lat": "60.27973",
    "lng": "15.98855"
  },
  {
    "country": "SE",
    "name": "Heby",
    "lat": "59.93815",
    "lng": "16.86217"
  },
  {
    "country": "SE",
    "name": "Haverdal",
    "lat": "56.72222",
    "lng": "12.67194"
  },
  {
    "country": "SE",
    "name": "Hästveda",
    "lat": "56.28468",
    "lng": "13.93547"
  },
  {
    "country": "SE",
    "name": "Hasslö",
    "lat": "56.11667",
    "lng": "15.48333"
  },
  {
    "country": "SE",
    "name": "Hässleholm",
    "lat": "56.15905",
    "lng": "13.76638"
  },
  {
    "country": "SE",
    "name": "Harplinge",
    "lat": "56.74491",
    "lng": "12.72758"
  },
  {
    "country": "SE",
    "name": "Härnösand",
    "lat": "62.63228",
    "lng": "17.93794"
  },
  {
    "country": "SE",
    "name": "Haninge",
    "lat": "59.16775",
    "lng": "18.14478"
  },
  {
    "country": "SE",
    "name": "Handen",
    "lat": "59.16809",
    "lng": "18.13796"
  },
  {
    "country": "SE",
    "name": "Hanaskog",
    "lat": "56.16061",
    "lng": "14.09307"
  },
  {
    "country": "SE",
    "name": "Hammerdal",
    "lat": "63.57615",
    "lng": "15.36516"
  },
  {
    "country": "SE",
    "name": "Hammarstrand",
    "lat": "63.11041",
    "lng": "16.35377"
  },
  {
    "country": "SE",
    "name": "Hammar",
    "lat": "56.01667",
    "lng": "14.21667"
  },
  {
    "country": "SE",
    "name": "Halmstad",
    "lat": "56.67446",
    "lng": "12.85676"
  },
  {
    "country": "SE",
    "name": "Hallstavik",
    "lat": "60.05",
    "lng": "18.6"
  },
  {
    "country": "SE",
    "name": "Hallstahammar",
    "lat": "59.61395",
    "lng": "16.22846"
  },
  {
    "country": "SE",
    "name": "Hallsberg",
    "lat": "59.06463",
    "lng": "15.10993"
  },
  {
    "country": "SE",
    "name": "Hällevik",
    "lat": "56.01667",
    "lng": "14.7"
  },
  {
    "country": "SE",
    "name": "Hälleforsnäs",
    "lat": "59.15208",
    "lng": "16.497"
  },
  {
    "country": "SE",
    "name": "Hällefors",
    "lat": "59.78388",
    "lng": "14.52197"
  },
  {
    "country": "SE",
    "name": "Hällbybrunn",
    "lat": "59.39152",
    "lng": "16.42229"
  },
  {
    "country": "SE",
    "name": "Hällabrottet",
    "lat": "59.11667",
    "lng": "15.2"
  },
  {
    "country": "SE",
    "name": "Häljarp",
    "lat": "55.85",
    "lng": "12.91667"
  },
  {
    "country": "SE",
    "name": "Hagfors",
    "lat": "60.02378",
    "lng": "13.67214"
  },
  {
    "country": "SE",
    "name": "Habo",
    "lat": "57.91185",
    "lng": "14.07444"
  },
  {
    "country": "SE",
    "name": "Gusum",
    "lat": "58.2688",
    "lng": "16.49894"
  },
  {
    "country": "SE",
    "name": "Gustavsberg",
    "lat": "59.32684",
    "lng": "18.38975"
  },
  {
    "country": "SE",
    "name": "Gunnebo",
    "lat": "57.71667",
    "lng": "16.53333"
  },
  {
    "country": "SE",
    "name": "Gullspång",
    "lat": "58.98615",
    "lng": "14.09644"
  },
  {
    "country": "SE",
    "name": "Gullbrandstorp",
    "lat": "56.7",
    "lng": "12.73333"
  },
  {
    "country": "SE",
    "name": "Grycksbo",
    "lat": "60.68751",
    "lng": "15.48507"
  },
  {
    "country": "SE",
    "name": "Grums",
    "lat": "59.35141",
    "lng": "13.11105"
  },
  {
    "country": "SE",
    "name": "Grillby",
    "lat": "59.62603",
    "lng": "17.25787"
  },
  {
    "country": "SE",
    "name": "Grebo",
    "lat": "58.30145",
    "lng": "15.87085"
  },
  {
    "country": "SE",
    "name": "Grebbestad",
    "lat": "58.70248",
    "lng": "11.25738"
  },
  {
    "country": "SE",
    "name": "Grästorp",
    "lat": "58.33219",
    "lng": "12.68122"
  },
  {
    "country": "SE",
    "name": "Gränna",
    "lat": "58.01667",
    "lng": "14.46667"
  },
  {
    "country": "SE",
    "name": "Grängesberg",
    "lat": "60.07465",
    "lng": "15.00784"
  },
  {
    "country": "SE",
    "name": "Gråbo",
    "lat": "57.83625",
    "lng": "12.29954"
  },
  {
    "country": "SE",
    "name": "Götene",
    "lat": "58.52824",
    "lng": "13.49458"
  },
  {
    "country": "SE",
    "name": "Göteborg",
    "lat": "57.70716",
    "lng": "11.96679"
  },
  {
    "country": "SE",
    "name": "Göta",
    "lat": "58.10617",
    "lng": "12.15254"
  },
  {
    "country": "SE",
    "name": "Gnosjö",
    "lat": "57.3585",
    "lng": "13.73686"
  },
  {
    "country": "SE",
    "name": "Gnesta",
    "lat": "59.04751",
    "lng": "17.31191"
  },
  {
    "country": "SE",
    "name": "Gnarp",
    "lat": "62.04874",
    "lng": "17.25858"
  },
  {
    "country": "SE",
    "name": "Glumslöv",
    "lat": "55.94091",
    "lng": "12.80929"
  },
  {
    "country": "SE",
    "name": "Glommen",
    "lat": "56.93333",
    "lng": "12.35"
  },
  {
    "country": "SE",
    "name": "Glimåkra",
    "lat": "56.3",
    "lng": "14.13333"
  },
  {
    "country": "SE",
    "name": "Gislaved",
    "lat": "57.3044",
    "lng": "13.54078"
  },
  {
    "country": "SE",
    "name": "Getinge",
    "lat": "56.81667",
    "lng": "12.73333"
  },
  {
    "country": "SE",
    "name": "Genarp",
    "lat": "55.59907",
    "lng": "13.3982"
  },
  {
    "country": "SE",
    "name": "Gemla",
    "lat": "56.86753",
    "lng": "14.64379"
  },
  {
    "country": "SE",
    "name": "Gävle",
    "lat": "60.67452",
    "lng": "17.14174"
  },
  {
    "country": "SE",
    "name": "Gärsnäs",
    "lat": "55.54949",
    "lng": "14.17923"
  },
  {
    "country": "SE",
    "name": "Garphyttan",
    "lat": "59.30429",
    "lng": "14.94623"
  },
  {
    "country": "SE",
    "name": "Gantofta",
    "lat": "55.98729",
    "lng": "12.80482"
  },
  {
    "country": "SE",
    "name": "Gånghester",
    "lat": "57.7",
    "lng": "13.01667"
  },
  {
    "country": "SE",
    "name": "Gamleby",
    "lat": "57.89485",
    "lng": "16.40508"
  },
  {
    "country": "SE",
    "name": "Gamla Uppsala",
    "lat": "59.89817",
    "lng": "17.63386"
  },
  {
    "country": "SE",
    "name": "Gagnef",
    "lat": "60.59856",
    "lng": "15.07745"
  },
  {
    "country": "SE",
    "name": "Fyllinge",
    "lat": "56.65",
    "lng": "12.91667"
  },
  {
    "country": "SE",
    "name": "Furulund",
    "lat": "57.71667",
    "lng": "12.13333"
  },
  {
    "country": "SE",
    "name": "Furulund",
    "lat": "55.7738",
    "lng": "13.09022"
  },
  {
    "country": "SE",
    "name": "Frövi",
    "lat": "59.46667",
    "lng": "15.36667"
  },
  {
    "country": "SE",
    "name": "Frösakull",
    "lat": "56.68333",
    "lng": "12.73333"
  },
  {
    "country": "SE",
    "name": "Fritsla",
    "lat": "57.55655",
    "lng": "12.78457"
  },
  {
    "country": "SE",
    "name": "Fristad",
    "lat": "57.82483",
    "lng": "13.01064"
  },
  {
    "country": "SE",
    "name": "Frillesås",
    "lat": "57.31667",
    "lng": "12.16667"
  },
  {
    "country": "SE",
    "name": "Fränsta",
    "lat": "62.49855",
    "lng": "16.17016"
  },
  {
    "country": "SE",
    "name": "Förslöv",
    "lat": "56.35",
    "lng": "12.81667"
  },
  {
    "country": "SE",
    "name": "Forsheda",
    "lat": "57.16415",
    "lng": "13.83016"
  },
  {
    "country": "SE",
    "name": "Forshaga",
    "lat": "59.52541",
    "lng": "13.48127"
  },
  {
    "country": "SE",
    "name": "Forserum",
    "lat": "57.7",
    "lng": "14.46667"
  },
  {
    "country": "SE",
    "name": "Forsbacka",
    "lat": "60.61667",
    "lng": "16.88333"
  },
  {
    "country": "SE",
    "name": "Floby",
    "lat": "58.13333",
    "lng": "13.33333"
  },
  {
    "country": "SE",
    "name": "Flen",
    "lat": "59.05834",
    "lng": "16.58781"
  },
  {
    "country": "SE",
    "name": "Fjugesta",
    "lat": "59.17375",
    "lng": "14.87227"
  },
  {
    "country": "SE",
    "name": "Fjärås kyrkby",
    "lat": "57.45913",
    "lng": "12.17508"
  },
  {
    "country": "SE",
    "name": "Fjälkinge",
    "lat": "56.04364",
    "lng": "14.27562"
  },
  {
    "country": "SE",
    "name": "Fittja",
    "lat": "59.24868",
    "lng": "17.85991"
  },
  {
    "country": "SE",
    "name": "Finspång",
    "lat": "58.70578",
    "lng": "15.76739"
  },
  {
    "country": "SE",
    "name": "Filipstad",
    "lat": "59.71236",
    "lng": "14.16831"
  },
  {
    "country": "SE",
    "name": "Fellingsbro",
    "lat": "59.43333",
    "lng": "15.58333"
  },
  {
    "country": "SE",
    "name": "Färlöv",
    "lat": "56.06667",
    "lng": "14.08333"
  },
  {
    "country": "SE",
    "name": "Färjestaden",
    "lat": "56.6499",
    "lng": "16.46859"
  },
  {
    "country": "SE",
    "name": "Färila",
    "lat": "61.80011",
    "lng": "15.84422"
  },
  {
    "country": "SE",
    "name": "Färgelanda",
    "lat": "58.56816",
    "lng": "11.99235"
  },
  {
    "country": "SE",
    "name": "Falun",
    "lat": "60.60357",
    "lng": "15.62597"
  },
  {
    "country": "SE",
    "name": "Falköping",
    "lat": "58.17347",
    "lng": "13.55068"
  },
  {
    "country": "SE",
    "name": "Falkenberg",
    "lat": "56.90552",
    "lng": "12.49118"
  },
  {
    "country": "SE",
    "name": "Fagersta",
    "lat": "60.00418",
    "lng": "15.79316"
  },
  {
    "country": "SE",
    "name": "Eslöv",
    "lat": "55.83928",
    "lng": "13.30393"
  },
  {
    "country": "SE",
    "name": "Eskilstuna",
    "lat": "59.36661",
    "lng": "16.5077"
  },
  {
    "country": "SE",
    "name": "Eriksberg",
    "lat": "59.24241",
    "lng": "17.81631"
  },
  {
    "country": "SE",
    "name": "Enköping",
    "lat": "59.63607",
    "lng": "17.07768"
  },
  {
    "country": "SE",
    "name": "Enebyberg",
    "lat": "59.43333",
    "lng": "18.05"
  },
  {
    "country": "SE",
    "name": "Enbacka",
    "lat": "60.40993",
    "lng": "15.59575"
  },
  {
    "country": "SE",
    "name": "Emmaboda",
    "lat": "56.63268",
    "lng": "15.53648"
  },
  {
    "country": "SE",
    "name": "Ellös",
    "lat": "58.18333",
    "lng": "11.46667"
  },
  {
    "country": "SE",
    "name": "Eksjö",
    "lat": "57.66643",
    "lng": "14.97205"
  },
  {
    "country": "SE",
    "name": "Ekshärad",
    "lat": "60.17275",
    "lng": "13.49647"
  },
  {
    "country": "SE",
    "name": "Ekerö",
    "lat": "59.291",
    "lng": "17.81212"
  },
  {
    "country": "SE",
    "name": "Ekenässjön",
    "lat": "57.49175",
    "lng": "15.02226"
  },
  {
    "country": "SE",
    "name": "Ekeby-Almby",
    "lat": "59.26",
    "lng": "15.33"
  },
  {
    "country": "SE",
    "name": "Ekängen",
    "lat": "58.46667",
    "lng": "15.63333"
  },
  {
    "country": "SE",
    "name": "Edsbyn",
    "lat": "61.37692",
    "lng": "15.81747"
  },
  {
    "country": "SE",
    "name": "Ed",
    "lat": "58.91247",
    "lng": "11.93308"
  },
  {
    "country": "SE",
    "name": "Dorotea",
    "lat": "64.26185",
    "lng": "16.41306"
  },
  {
    "country": "SE",
    "name": "Donsö",
    "lat": "57.6",
    "lng": "11.79917"
  },
  {
    "country": "SE",
    "name": "Djursholm",
    "lat": "59.39926",
    "lng": "18.05619"
  },
  {
    "country": "SE",
    "name": "Djurö",
    "lat": "59.32653",
    "lng": "18.71152"
  },
  {
    "country": "SE",
    "name": "Djurås",
    "lat": "60.56061",
    "lng": "15.13281"
  },
  {
    "country": "SE",
    "name": "Diseröd",
    "lat": "57.92636",
    "lng": "12.02598"
  },
  {
    "country": "SE",
    "name": "Dingtuna",
    "lat": "59.57279",
    "lng": "16.38722"
  },
  {
    "country": "SE",
    "name": "Delsbo",
    "lat": "61.80104",
    "lng": "16.55571"
  },
  {
    "country": "SE",
    "name": "Deje",
    "lat": "59.603",
    "lng": "13.472"
  },
  {
    "country": "SE",
    "name": "Degerfors",
    "lat": "59.23797",
    "lng": "14.43077"
  },
  {
    "country": "SE",
    "name": "Degeberga",
    "lat": "55.83333",
    "lng": "14.08333"
  },
  {
    "country": "SE",
    "name": "Dals Långed",
    "lat": "58.92555",
    "lng": "12.30865"
  },
  {
    "country": "SE",
    "name": "Dalsjöfors",
    "lat": "57.71667",
    "lng": "13.08333"
  },
  {
    "country": "SE",
    "name": "Dalby",
    "lat": "55.66655",
    "lng": "13.34976"
  },
  {
    "country": "SE",
    "name": "Dalarö",
    "lat": "59.13306",
    "lng": "18.40639"
  },
  {
    "country": "SE",
    "name": "Charlottenberg",
    "lat": "59.88422",
    "lng": "12.30398"
  },
  {
    "country": "SE",
    "name": "Bunkeflostrand",
    "lat": "55.54478",
    "lng": "12.92375"
  },
  {
    "country": "SE",
    "name": "Bua",
    "lat": "57.2378",
    "lng": "12.12187"
  },
  {
    "country": "SE",
    "name": "Brunna",
    "lat": "60.26255",
    "lng": "16.01034"
  },
  {
    "country": "SE",
    "name": "Brunna",
    "lat": "59.51667",
    "lng": "17.75"
  },
  {
    "country": "SE",
    "name": "Brunn",
    "lat": "59.28",
    "lng": "18.43"
  },
  {
    "country": "SE",
    "name": "Brunflo",
    "lat": "63.07586",
    "lng": "14.83203"
  },
  {
    "country": "SE",
    "name": "Bromölla",
    "lat": "56.07551",
    "lng": "14.46958"
  },
  {
    "country": "SE",
    "name": "Bromma",
    "lat": "59.34",
    "lng": "17.94"
  },
  {
    "country": "SE",
    "name": "Broby",
    "lat": "56.25521",
    "lng": "14.07797"
  },
  {
    "country": "SE",
    "name": "Bro",
    "lat": "59.51667",
    "lng": "17.63333"
  },
  {
    "country": "SE",
    "name": "Brevik",
    "lat": "59.35",
    "lng": "18.2"
  },
  {
    "country": "SE",
    "name": "Brevik",
    "lat": "59.21667",
    "lng": "18.38333"
  },
  {
    "country": "SE",
    "name": "Bredbyn",
    "lat": "63.44655",
    "lng": "18.11019"
  },
  {
    "country": "SE",
    "name": "Bredaryd",
    "lat": "57.17343",
    "lng": "13.73789"
  },
  {
    "country": "SE",
    "name": "Brastad",
    "lat": "58.38333",
    "lng": "11.48333"
  },
  {
    "country": "SE",
    "name": "Brålanda",
    "lat": "58.56344",
    "lng": "12.34923"
  },
  {
    "country": "SE",
    "name": "Bräkne-Hoby",
    "lat": "56.23333",
    "lng": "15.11667"
  },
  {
    "country": "SE",
    "name": "Bräcke",
    "lat": "62.75067",
    "lng": "15.42193"
  },
  {
    "country": "SE",
    "name": "Braås",
    "lat": "57.06667",
    "lng": "15.05"
  },
  {
    "country": "SE",
    "name": "Boxholm",
    "lat": "58.19719",
    "lng": "15.05376"
  },
  {
    "country": "SE",
    "name": "Borlänge",
    "lat": "60.4858",
    "lng": "15.43714"
  },
  {
    "country": "SE",
    "name": "Borgholm",
    "lat": "56.8793",
    "lng": "16.65634"
  },
  {
    "country": "SE",
    "name": "Borensberg",
    "lat": "58.56667",
    "lng": "15.28333"
  },
  {
    "country": "SE",
    "name": "Borås",
    "lat": "57.72101",
    "lng": "12.9401"
  },
  {
    "country": "SE",
    "name": "Bor",
    "lat": "57.11667",
    "lng": "14.16667"
  },
  {
    "country": "SE",
    "name": "Bollstabruk",
    "lat": "62.99777",
    "lng": "17.67348"
  },
  {
    "country": "SE",
    "name": "Bollnäs",
    "lat": "61.34817",
    "lng": "16.39464"
  },
  {
    "country": "SE",
    "name": "Bollmora",
    "lat": "59.24196",
    "lng": "18.22762"
  },
  {
    "country": "SE",
    "name": "Bollebygd",
    "lat": "57.66866",
    "lng": "12.57272"
  },
  {
    "country": "SE",
    "name": "Bodafors",
    "lat": "57.5",
    "lng": "14.7"
  },
  {
    "country": "SE",
    "name": "Boo",
    "lat": "59.33333",
    "lng": "18.28333"
  },
  {
    "country": "SE",
    "name": "Blomstermåla",
    "lat": "56.98333",
    "lng": "16.33333"
  },
  {
    "country": "SE",
    "name": "Blentarp",
    "lat": "55.58333",
    "lng": "13.6"
  },
  {
    "country": "SE",
    "name": "Bjuv",
    "lat": "56.08372",
    "lng": "12.91914"
  },
  {
    "country": "SE",
    "name": "Bjursås",
    "lat": "60.73726",
    "lng": "15.45291"
  },
  {
    "country": "SE",
    "name": "Bjurholm",
    "lat": "63.93027",
    "lng": "19.21369"
  },
  {
    "country": "SE",
    "name": "Björneborg",
    "lat": "59.24122",
    "lng": "14.24942"
  },
  {
    "country": "SE",
    "name": "Björlanda",
    "lat": "57.76667",
    "lng": "11.83333"
  },
  {
    "country": "SE",
    "name": "Björkö",
    "lat": "57.73221",
    "lng": "11.67916"
  },
  {
    "country": "SE",
    "name": "Björboholm",
    "lat": "57.87096",
    "lng": "12.32546"
  },
  {
    "country": "SE",
    "name": "Bjästa",
    "lat": "63.2",
    "lng": "18.5"
  },
  {
    "country": "SE",
    "name": "Bjärred",
    "lat": "55.71667",
    "lng": "13.01667"
  },
  {
    "country": "SE",
    "name": "Bjärnum",
    "lat": "56.29032",
    "lng": "13.71128"
  },
  {
    "country": "SE",
    "name": "Billingsfors",
    "lat": "58.98333",
    "lng": "12.25"
  },
  {
    "country": "SE",
    "name": "Billesholm",
    "lat": "56.05",
    "lng": "13"
  },
  {
    "country": "SE",
    "name": "Billeberga",
    "lat": "55.88333",
    "lng": "13"
  },
  {
    "country": "SE",
    "name": "Billdal",
    "lat": "57.56667",
    "lng": "11.93333"
  },
  {
    "country": "SE",
    "name": "Bergsjö",
    "lat": "61.98253",
    "lng": "17.06368"
  },
  {
    "country": "SE",
    "name": "Bergshamra",
    "lat": "59.38083",
    "lng": "18.03427"
  },
  {
    "country": "SE",
    "name": "Hoverberg",
    "lat": "62.81381",
    "lng": "14.44735"
  },
  {
    "country": "SE",
    "name": "Bergkvara",
    "lat": "56.39063",
    "lng": "16.07274"
  },
  {
    "country": "SE",
    "name": "Bergeforsen",
    "lat": "62.53074",
    "lng": "17.38123"
  },
  {
    "country": "SE",
    "name": "Bergby",
    "lat": "60.92931",
    "lng": "17.04194"
  },
  {
    "country": "SE",
    "name": "Berg",
    "lat": "58.48831",
    "lng": "15.52969"
  },
  {
    "country": "SE",
    "name": "Bengtsfors",
    "lat": "59.02912",
    "lng": "12.23207"
  },
  {
    "country": "SE",
    "name": "Båstad",
    "lat": "56.42689",
    "lng": "12.85339"
  },
  {
    "country": "SE",
    "name": "Bårslöv",
    "lat": "56.0091",
    "lng": "12.8058"
  },
  {
    "country": "SE",
    "name": "Barkarö",
    "lat": "59.54935",
    "lng": "16.5074"
  },
  {
    "country": "SE",
    "name": "Bara",
    "lat": "58.68333",
    "lng": "17.06667"
  },
  {
    "country": "SE",
    "name": "Bara",
    "lat": "55.58155",
    "lng": "13.17862"
  },
  {
    "country": "SE",
    "name": "Bankeryd",
    "lat": "57.86021",
    "lng": "14.124"
  },
  {
    "country": "SE",
    "name": "Bålsta",
    "lat": "59.5671",
    "lng": "17.52781"
  },
  {
    "country": "SE",
    "name": "Bälinge",
    "lat": "59.95",
    "lng": "17.53333"
  },
  {
    "country": "SE",
    "name": "Axvall",
    "lat": "58.38333",
    "lng": "13.56667"
  },
  {
    "country": "SE",
    "name": "Avesta",
    "lat": "60.14274",
    "lng": "16.16295"
  },
  {
    "country": "SE",
    "name": "Åtvidaberg",
    "lat": "58.20152",
    "lng": "15.9977"
  },
  {
    "country": "SE",
    "name": "Åstorp",
    "lat": "56.13566",
    "lng": "12.9443"
  },
  {
    "country": "SE",
    "name": "Asmundtorp",
    "lat": "55.88333",
    "lng": "12.93333"
  },
  {
    "country": "SE",
    "name": "Askersund",
    "lat": "58.87988",
    "lng": "14.9023"
  },
  {
    "country": "SE",
    "name": "Åsele",
    "lat": "64.16026",
    "lng": "17.34762"
  },
  {
    "country": "SE",
    "name": "Åseda",
    "lat": "57.1701",
    "lng": "15.3443"
  },
  {
    "country": "SE",
    "name": "Åsbro",
    "lat": "59",
    "lng": "15.05"
  },
  {
    "country": "SE",
    "name": "Åsa",
    "lat": "57.35",
    "lng": "12.11667"
  },
  {
    "country": "SE",
    "name": "Ås",
    "lat": "63.36667",
    "lng": "16.58333"
  },
  {
    "country": "SE",
    "name": "Ås",
    "lat": "63.25",
    "lng": "14.56667"
  },
  {
    "country": "SE",
    "name": "Arvika",
    "lat": "59.65528",
    "lng": "12.58518"
  },
  {
    "country": "SE",
    "name": "Arvidsjaur",
    "lat": "65.59033",
    "lng": "19.16682"
  },
  {
    "country": "SE",
    "name": "Årsunda",
    "lat": "60.51644",
    "lng": "16.73436"
  },
  {
    "country": "SE",
    "name": "Årsta",
    "lat": "59.2978",
    "lng": "18.0514"
  },
  {
    "country": "SE",
    "name": "Arnö",
    "lat": "60.11667",
    "lng": "18.63333"
  },
  {
    "country": "SE",
    "name": "Arnö",
    "lat": "58.72675",
    "lng": "17.02322"
  },
  {
    "country": "SE",
    "name": "Arlöv",
    "lat": "55.63248",
    "lng": "13.07141"
  },
  {
    "country": "SE",
    "name": "Ärla",
    "lat": "59.27983",
    "lng": "16.67896"
  },
  {
    "country": "SE",
    "name": "Arjeplog",
    "lat": "66.05173",
    "lng": "17.88606"
  },
  {
    "country": "SE",
    "name": "Årjäng",
    "lat": "59.39217",
    "lng": "12.13336"
  },
  {
    "country": "SE",
    "name": "Arbrå",
    "lat": "61.46667",
    "lng": "16.38333"
  },
  {
    "country": "SE",
    "name": "Arboga",
    "lat": "59.39387",
    "lng": "15.83882"
  },
  {
    "country": "SE",
    "name": "Annelund",
    "lat": "57.98843",
    "lng": "13.07483"
  },
  {
    "country": "SE",
    "name": "Ankarsrum",
    "lat": "57.69896",
    "lng": "16.33407"
  },
  {
    "country": "SE",
    "name": "Angered",
    "lat": "57.78628",
    "lng": "12.09852"
  },
  {
    "country": "SE",
    "name": "Ängelholm",
    "lat": "56.2428",
    "lng": "12.86219"
  },
  {
    "country": "SE",
    "name": "Ånge",
    "lat": "62.52495",
    "lng": "15.65904"
  },
  {
    "country": "SE",
    "name": "Aneby",
    "lat": "57.83895",
    "lng": "14.81016"
  },
  {
    "country": "SE",
    "name": "Anderstorp",
    "lat": "58.88333",
    "lng": "14.28333"
  },
  {
    "country": "SE",
    "name": "Anderstorp",
    "lat": "57.28333",
    "lng": "13.63333"
  },
  {
    "country": "SE",
    "name": "Anderslöv",
    "lat": "55.43836",
    "lng": "13.31966"
  },
  {
    "country": "SE",
    "name": "Åmotfors",
    "lat": "59.76191",
    "lng": "12.36211"
  },
  {
    "country": "SE",
    "name": "Åmål",
    "lat": "59.051",
    "lng": "12.70492"
  },
  {
    "country": "SE",
    "name": "Älvkarleby",
    "lat": "60.57081",
    "lng": "17.44895"
  },
  {
    "country": "SE",
    "name": "Alvesta",
    "lat": "56.89935",
    "lng": "14.55559"
  },
  {
    "country": "SE",
    "name": "Älvdalen",
    "lat": "61.22774",
    "lng": "14.03935"
  },
  {
    "country": "SE",
    "name": "Älvängen",
    "lat": "57.95872",
    "lng": "12.1235"
  },
  {
    "country": "SE",
    "name": "Alunda",
    "lat": "60.06667",
    "lng": "18.08333"
  },
  {
    "country": "SE",
    "name": "Älta",
    "lat": "59.26667",
    "lng": "18.18333"
  },
  {
    "country": "SE",
    "name": "Alsike",
    "lat": "59.75324",
    "lng": "17.77331"
  },
  {
    "country": "SE",
    "name": "Älmsta",
    "lat": "59.96667",
    "lng": "18.8"
  },
  {
    "country": "SE",
    "name": "Älmhult",
    "lat": "56.55146",
    "lng": "14.13827"
  },
  {
    "country": "SE",
    "name": "Alingsås",
    "lat": "57.93033",
    "lng": "12.53345"
  },
  {
    "country": "SE",
    "name": "Alfta",
    "lat": "61.34675",
    "lng": "16.07499"
  },
  {
    "country": "SE",
    "name": "Åled",
    "lat": "56.75",
    "lng": "12.93333"
  },
  {
    "country": "SE",
    "name": "Alafors",
    "lat": "57.92579",
    "lng": "12.07835"
  },
  {
    "country": "SE",
    "name": "Åkers Styckebruk",
    "lat": "59.25",
    "lng": "17.08333"
  },
  {
    "country": "SE",
    "name": "Åkersberga",
    "lat": "59.47944",
    "lng": "18.29967"
  },
  {
    "country": "SE",
    "name": "Åkarp",
    "lat": "58.23333",
    "lng": "13.65"
  },
  {
    "country": "SE",
    "name": "Åkarp",
    "lat": "55.65396",
    "lng": "13.11107"
  },
  {
    "country": "SE",
    "name": "Åhus",
    "lat": "55.91667",
    "lng": "14.28333"
  },
  {
    "country": "SE",
    "name": "Åby",
    "lat": "58.66667",
    "lng": "16.18333"
  },
  {
    "country": "SE",
    "name": "Abborrberget",
    "lat": "60.15",
    "lng": "14.8"
  },
  {
    "country": "SE",
    "name": "Västra Hagen",
    "lat": "57.42444",
    "lng": "11.93583"
  },
  {
    "country": "SE",
    "name": "Enhagen-Ekbacken",
    "lat": "59.56543",
    "lng": "16.53045"
  },
  {
    "country": "SE",
    "name": "Saxtorpsskogen",
    "lat": "55.83208",
    "lng": "12.94429"
  },
  {
    "country": "SE",
    "name": "Andalen",
    "lat": "57.70039",
    "lng": "11.76136"
  },
  {
    "country": "SE",
    "name": "Nolvik",
    "lat": "57.775",
    "lng": "11.83333"
  },
  {
    "country": "SE",
    "name": "Vi",
    "lat": "62.43333",
    "lng": "17.41667"
  },
  {
    "country": "SE",
    "name": "Fisksätra",
    "lat": "59.29153",
    "lng": "18.2549"
  },
  {
    "country": "SE",
    "name": "Ekeby",
    "lat": "56",
    "lng": "12.96667"
  },
  {
    "country": "SE",
    "name": "Skanör med Falsterbo",
    "lat": "55.4",
    "lng": "12.85"
  },
  {
    "country": "SE",
    "name": "Nödinge-Nol",
    "lat": "57.91259",
    "lng": "12.05591"
  },
  {
    "country": "SE",
    "name": "Ingared",
    "lat": "57.85989",
    "lng": "12.45161"
  },
  {
    "country": "SE",
    "name": "Majorna",
    "lat": "57.69195",
    "lng": "11.91605"
  },
  {
    "country": "SE",
    "name": "Onsala",
    "lat": "57.42531",
    "lng": "12.02903"
  },
  {
    "country": "SE",
    "name": "Olstorp",
    "lat": "57.82277",
    "lng": "12.27696"
  },
  {
    "country": "SE",
    "name": "Akalla",
    "lat": "59.41465",
    "lng": "17.91398"
  },
  {
    "country": "SE",
    "name": "Tensta",
    "lat": "59.3939",
    "lng": "17.90111"
  },
  {
    "country": "SE",
    "name": "Björkskatan",
    "lat": "65.61373",
    "lng": "22.17702"
  },
  {
    "country": "SE",
    "name": "Alby",
    "lat": "59.2335",
    "lng": "17.8538"
  },
  {
    "country": "SE",
    "name": "Hammarkullen",
    "lat": "57.78049",
    "lng": "12.03604"
  },
  {
    "country": "SE",
    "name": "Rannebergen",
    "lat": "57.80236",
    "lng": "12.07131"
  },
  {
    "country": "SE",
    "name": "Eriksbo",
    "lat": "57.77141",
    "lng": "12.04183"
  },
  {
    "country": "SE",
    "name": "Gårdsten",
    "lat": "57.8048",
    "lng": "12.02883"
  },
  {
    "country": "SE",
    "name": "Lövgärdet",
    "lat": "57.81555",
    "lng": "12.03861"
  },
  {
    "country": "SE",
    "name": "Åre",
    "lat": "63.39911",
    "lng": "13.07995"
  },
  {
    "country": "SE",
    "name": "Marielund",
    "lat": "65.85307",
    "lng": "24.10486"
  },
  {
    "country": "SG",
    "name": "Singapore",
    "lat": "1.28967",
    "lng": "103.85007"
  },
  {
    "country": "SH",
    "name": "Georgetown",
    "lat": "-7.92861",
    "lng": "-14.41194"
  },
  {
    "country": "SH",
    "name": "Edinburgh of the Seven Seas",
    "lat": "-37.06757",
    "lng": "-12.31155"
  },
  {
    "country": "SH",
    "name": "Jamestown",
    "lat": "-15.93872",
    "lng": "-5.71675"
  },
  {
    "country": "SI",
    "name": "Žužemberk",
    "lat": "45.83389",
    "lng": "14.92917"
  },
  {
    "country": "SI",
    "name": "Žirovnica",
    "lat": "46.40472",
    "lng": "14.14"
  },
  {
    "country": "SI",
    "name": "Žiri",
    "lat": "46.04222",
    "lng": "14.10722"
  },
  {
    "country": "SI",
    "name": "Zgornji Duplek",
    "lat": "46.51361",
    "lng": "15.72083"
  },
  {
    "country": "SI",
    "name": "Zgornje Pirniče",
    "lat": "46.14251",
    "lng": "14.43158"
  },
  {
    "country": "SI",
    "name": "Zgornje Jezersko",
    "lat": "46.3941",
    "lng": "14.50659"
  },
  {
    "country": "SI",
    "name": "Zgornje Gorje",
    "lat": "46.37962",
    "lng": "14.06937"
  },
  {
    "country": "SI",
    "name": "Zgornje Bitnje",
    "lat": "46.22",
    "lng": "14.33667"
  },
  {
    "country": "SI",
    "name": "Zgornja Polskava",
    "lat": "46.42556",
    "lng": "15.61222"
  },
  {
    "country": "SI",
    "name": "Zgornja Kungota",
    "lat": "46.63917",
    "lng": "15.61556"
  },
  {
    "country": "SI",
    "name": "Žetale",
    "lat": "46.27356",
    "lng": "15.82658"
  },
  {
    "country": "SI",
    "name": "Železniki",
    "lat": "46.22482",
    "lng": "14.17205"
  },
  {
    "country": "SI",
    "name": "Zavrč",
    "lat": "46.39167",
    "lng": "16.04972"
  },
  {
    "country": "SI",
    "name": "Žalec",
    "lat": "46.25151",
    "lng": "15.16482"
  },
  {
    "country": "SI",
    "name": "Zagorje ob Savi",
    "lat": "46.13179",
    "lng": "14.99694"
  },
  {
    "country": "SI",
    "name": "Zabukovica",
    "lat": "46.21408",
    "lng": "15.15954"
  },
  {
    "country": "SI",
    "name": "Vuzenica",
    "lat": "46.59639",
    "lng": "15.16722"
  },
  {
    "country": "SI",
    "name": "Vrtojba",
    "lat": "45.9125",
    "lng": "13.63417"
  },
  {
    "country": "SI",
    "name": "Vrhnika",
    "lat": "45.9635",
    "lng": "14.29484"
  },
  {
    "country": "SI",
    "name": "Vransko",
    "lat": "46.24389",
    "lng": "14.95139"
  },
  {
    "country": "SI",
    "name": "Volčja Draga",
    "lat": "45.90694",
    "lng": "13.6775"
  },
  {
    "country": "SI",
    "name": "Vojnik",
    "lat": "46.29333",
    "lng": "15.30333"
  },
  {
    "country": "SI",
    "name": "Vodice",
    "lat": "46.18987",
    "lng": "14.49492"
  },
  {
    "country": "SI",
    "name": "Vnanje Gorice",
    "lat": "46.00722",
    "lng": "14.42194"
  },
  {
    "country": "SI",
    "name": "Vitomarci",
    "lat": "46.5275",
    "lng": "15.93944"
  },
  {
    "country": "SI",
    "name": "Vitanje",
    "lat": "46.38167",
    "lng": "15.29583"
  },
  {
    "country": "SI",
    "name": "Vipava",
    "lat": "45.84667",
    "lng": "13.96306"
  },
  {
    "country": "SI",
    "name": "Videm",
    "lat": "45.85",
    "lng": "14.69417"
  },
  {
    "country": "SI",
    "name": "Veržej",
    "lat": "46.58361",
    "lng": "16.16528"
  },
  {
    "country": "SI",
    "name": "Verd",
    "lat": "45.95667",
    "lng": "14.30583"
  },
  {
    "country": "SI",
    "name": "Velike Lašče",
    "lat": "45.83222",
    "lng": "14.63639"
  },
  {
    "country": "SI",
    "name": "Velika Polana",
    "lat": "46.57194",
    "lng": "16.34694"
  },
  {
    "country": "SI",
    "name": "Turnišče",
    "lat": "46.62778",
    "lng": "16.32028"
  },
  {
    "country": "SI",
    "name": "Trzin",
    "lat": "46.13333",
    "lng": "14.56667"
  },
  {
    "country": "SI",
    "name": "Tržič",
    "lat": "46.36357",
    "lng": "14.31046"
  },
  {
    "country": "SI",
    "name": "Trnovska Vas",
    "lat": "46.52019",
    "lng": "15.88657"
  },
  {
    "country": "SI",
    "name": "Trnovlje pri Celju",
    "lat": "46.25667",
    "lng": "15.29528"
  },
  {
    "country": "SI",
    "name": "Trebnje",
    "lat": "45.90417",
    "lng": "15.02167"
  },
  {
    "country": "SI",
    "name": "Trbovlje",
    "lat": "46.155",
    "lng": "15.05333"
  },
  {
    "country": "SI",
    "name": "Topolšica",
    "lat": "46.40028",
    "lng": "15.02157"
  },
  {
    "country": "SI",
    "name": "Sveti Tomaž",
    "lat": "46.48417",
    "lng": "16.08361"
  },
  {
    "country": "SI",
    "name": "Tolmin",
    "lat": "46.18304",
    "lng": "13.73321"
  },
  {
    "country": "SI",
    "name": "Velenje",
    "lat": "46.35917",
    "lng": "15.11028"
  },
  {
    "country": "SI",
    "name": "Tišina",
    "lat": "46.65806",
    "lng": "16.09167"
  },
  {
    "country": "SI",
    "name": "Tabor",
    "lat": "46.23611",
    "lng": "15.01833"
  },
  {
    "country": "SI",
    "name": "Sv. Duh",
    "lat": "46.18333",
    "lng": "14.33333"
  },
  {
    "country": "SI",
    "name": "Sv. Anton",
    "lat": "45.52583",
    "lng": "13.83194"
  },
  {
    "country": "SI",
    "name": "Sv. Ana v Slov. Goricah",
    "lat": "46.64917",
    "lng": "15.84417"
  },
  {
    "country": "SI",
    "name": "Štore",
    "lat": "46.22083",
    "lng": "15.31389"
  },
  {
    "country": "SI",
    "name": "Starše",
    "lat": "46.46583",
    "lng": "15.76722"
  },
  {
    "country": "SI",
    "name": "Središče ob Dravi",
    "lat": "46.39417",
    "lng": "16.26806"
  },
  {
    "country": "SI",
    "name": "Spodnji Duplek",
    "lat": "46.50306",
    "lng": "15.74528"
  },
  {
    "country": "SI",
    "name": "Spodnje Hoče",
    "lat": "46.5",
    "lng": "15.65"
  },
  {
    "country": "SI",
    "name": "Spodnja Idrija",
    "lat": "46.03194",
    "lng": "14.02722"
  },
  {
    "country": "SI",
    "name": "Spodnja Hajdina",
    "lat": "46.40889",
    "lng": "15.84694"
  },
  {
    "country": "SI",
    "name": "Šoštanj",
    "lat": "46.38",
    "lng": "15.04861"
  },
  {
    "country": "SI",
    "name": "Solčava",
    "lat": "46.41944",
    "lng": "14.69361"
  },
  {
    "country": "SI",
    "name": "Sodražica",
    "lat": "45.76111",
    "lng": "14.63556"
  },
  {
    "country": "SI",
    "name": "Šmartno pri Slovenj Gradcu",
    "lat": "46.48944",
    "lng": "15.10667"
  },
  {
    "country": "SI",
    "name": "Šmartno pri Litiji",
    "lat": "46.04444",
    "lng": "14.84417"
  },
  {
    "country": "SI",
    "name": "Šmartno ob Paki",
    "lat": "46.33333",
    "lng": "15.03333"
  },
  {
    "country": "SI",
    "name": "Šmarjeta",
    "lat": "45.88333",
    "lng": "15.25"
  },
  {
    "country": "SI",
    "name": "Šmarje pri Jelšah",
    "lat": "46.22722",
    "lng": "15.51917"
  },
  {
    "country": "SI",
    "name": "Šmarje-Sap",
    "lat": "45.97618",
    "lng": "14.61177"
  },
  {
    "country": "SI",
    "name": "Šmarca",
    "lat": "46.19333",
    "lng": "14.59667"
  },
  {
    "country": "SI",
    "name": "Slovenske Konjice",
    "lat": "46.33667",
    "lng": "15.42583"
  },
  {
    "country": "SI",
    "name": "Slovenska Bistrica",
    "lat": "46.39278",
    "lng": "15.57444"
  },
  {
    "country": "SI",
    "name": "Slovenj Gradec",
    "lat": "46.51028",
    "lng": "15.08056"
  },
  {
    "country": "SI",
    "name": "Škofljica",
    "lat": "45.98333",
    "lng": "14.57667"
  },
  {
    "country": "SI",
    "name": "Škofja Loka",
    "lat": "46.16551",
    "lng": "14.30626"
  },
  {
    "country": "SI",
    "name": "Škocjan",
    "lat": "45.90667",
    "lng": "15.29139"
  },
  {
    "country": "SI",
    "name": "Sežana",
    "lat": "45.70924",
    "lng": "13.87333"
  },
  {
    "country": "SI",
    "name": "Sevnica",
    "lat": "46.00778",
    "lng": "15.31556"
  },
  {
    "country": "SI",
    "name": "Šentvid pri Stični",
    "lat": "45.95004",
    "lng": "14.84344"
  },
  {
    "country": "SI",
    "name": "Šentrupert",
    "lat": "45.97778",
    "lng": "15.09556"
  },
  {
    "country": "SI",
    "name": "Šentjur",
    "lat": "46.21722",
    "lng": "15.3975"
  },
  {
    "country": "SI",
    "name": "Šentjernej",
    "lat": "45.84",
    "lng": "15.33611"
  },
  {
    "country": "SI",
    "name": "Šentilj v Slov. Goricah",
    "lat": "46.68167",
    "lng": "15.64806"
  },
  {
    "country": "SI",
    "name": "Senovo",
    "lat": "46.02361",
    "lng": "15.47694"
  },
  {
    "country": "SI",
    "name": "Šenčur",
    "lat": "46.24556",
    "lng": "14.41972"
  },
  {
    "country": "SI",
    "name": "Šempeter v Savinj. Dolini",
    "lat": "46.25639",
    "lng": "15.12194"
  },
  {
    "country": "SI",
    "name": "Šempeter pri Gorici",
    "lat": "45.9275",
    "lng": "13.64111"
  },
  {
    "country": "SI",
    "name": "Šempas",
    "lat": "45.93028",
    "lng": "13.74361"
  },
  {
    "country": "SI",
    "name": "Semič",
    "lat": "45.64611",
    "lng": "15.18222"
  },
  {
    "country": "SI",
    "name": "Selnica ob Muri",
    "lat": "46.68333",
    "lng": "15.7"
  },
  {
    "country": "SI",
    "name": "Šalovci",
    "lat": "46.825",
    "lng": "16.29806"
  },
  {
    "country": "SI",
    "name": "Ruše",
    "lat": "46.53944",
    "lng": "15.51583"
  },
  {
    "country": "SI",
    "name": "Rogoza",
    "lat": "46.5",
    "lng": "15.68333"
  },
  {
    "country": "SI",
    "name": "Rogatec",
    "lat": "46.22944",
    "lng": "15.70028"
  },
  {
    "country": "SI",
    "name": "Rogašovci",
    "lat": "46.8",
    "lng": "16.03333"
  },
  {
    "country": "SI",
    "name": "Rogaška Slatina",
    "lat": "46.2375",
    "lng": "15.63972"
  },
  {
    "country": "SI",
    "name": "Ribnica na Pohorju",
    "lat": "46.535",
    "lng": "15.27278"
  },
  {
    "country": "SI",
    "name": "Ribnica",
    "lat": "45.73861",
    "lng": "14.7275"
  },
  {
    "country": "SI",
    "name": "Renče",
    "lat": "45.89",
    "lng": "13.66861"
  },
  {
    "country": "SI",
    "name": "Rečica ob Savinji",
    "lat": "46.31667",
    "lng": "14.91667"
  },
  {
    "country": "SI",
    "name": "Razvanje",
    "lat": "46.51444",
    "lng": "15.63611"
  },
  {
    "country": "SI",
    "name": "Ravne na Koroškem",
    "lat": "46.54306",
    "lng": "14.96917"
  },
  {
    "country": "SI",
    "name": "Ravne",
    "lat": "46.41413",
    "lng": "15.06087"
  },
  {
    "country": "SI",
    "name": "Rakičan",
    "lat": "46.65167",
    "lng": "16.20417"
  },
  {
    "country": "SI",
    "name": "Rakek",
    "lat": "45.81333",
    "lng": "14.31111"
  },
  {
    "country": "SI",
    "name": "Radovljica",
    "lat": "46.34444",
    "lng": "14.17444"
  },
  {
    "country": "SI",
    "name": "Radomlje",
    "lat": "46.17361",
    "lng": "14.61222"
  },
  {
    "country": "SI",
    "name": "Radlje ob Dravi",
    "lat": "46.61417",
    "lng": "15.22639"
  },
  {
    "country": "SI",
    "name": "Radenci",
    "lat": "46.64201",
    "lng": "16.03781"
  },
  {
    "country": "SI",
    "name": "Radeče",
    "lat": "46.06806",
    "lng": "15.18389"
  },
  {
    "country": "SI",
    "name": "Rače",
    "lat": "46.45194",
    "lng": "15.68139"
  },
  {
    "country": "SI",
    "name": "Puconci",
    "lat": "46.70667",
    "lng": "16.15639"
  },
  {
    "country": "SI",
    "name": "Ptuj",
    "lat": "46.42005",
    "lng": "15.87018"
  },
  {
    "country": "SI",
    "name": "Prvačina",
    "lat": "45.89",
    "lng": "13.71806"
  },
  {
    "country": "SI",
    "name": "Prevalje",
    "lat": "46.54694",
    "lng": "14.92083"
  },
  {
    "country": "SI",
    "name": "Preserje pri Radomljah",
    "lat": "46.16911",
    "lng": "14.59698"
  },
  {
    "country": "SI",
    "name": "Preddvor",
    "lat": "46.3025",
    "lng": "14.42306"
  },
  {
    "country": "SI",
    "name": "Prebold",
    "lat": "46.23694",
    "lng": "15.0925"
  },
  {
    "country": "SI",
    "name": "Pragersko",
    "lat": "46.39667",
    "lng": "15.66"
  },
  {
    "country": "SI",
    "name": "Postojna",
    "lat": "45.77435",
    "lng": "14.21528"
  },
  {
    "country": "SI",
    "name": "Portorož",
    "lat": "45.51429",
    "lng": "13.59206"
  },
  {
    "country": "SI",
    "name": "Polzela",
    "lat": "46.28333",
    "lng": "15.06667"
  },
  {
    "country": "SI",
    "name": "Poljčane",
    "lat": "46.31194",
    "lng": "15.57917"
  },
  {
    "country": "SI",
    "name": "Podvelka",
    "lat": "46.58694",
    "lng": "15.33056"
  },
  {
    "country": "SI",
    "name": "Podlehnik",
    "lat": "46.33528",
    "lng": "15.88"
  },
  {
    "country": "SI",
    "name": "Podčetrtek",
    "lat": "46.15694",
    "lng": "15.59861"
  },
  {
    "country": "SI",
    "name": "Pivka",
    "lat": "45.68292",
    "lng": "14.19588"
  },
  {
    "country": "SI",
    "name": "Piran",
    "lat": "45.52778",
    "lng": "13.57056"
  },
  {
    "country": "SI",
    "name": "Pesnica pri Mariboru",
    "lat": "46.60694",
    "lng": "15.67667"
  },
  {
    "country": "SI",
    "name": "Pekre",
    "lat": "46.54722",
    "lng": "15.59556"
  },
  {
    "country": "SI",
    "name": "Pameče",
    "lat": "46.53417",
    "lng": "15.07917"
  },
  {
    "country": "SI",
    "name": "Osilnica",
    "lat": "45.52914",
    "lng": "14.69838"
  },
  {
    "country": "SI",
    "name": "Ormož",
    "lat": "46.41139",
    "lng": "16.15444"
  },
  {
    "country": "SI",
    "name": "Oplotnica",
    "lat": "46.38778",
    "lng": "15.44667"
  },
  {
    "country": "SI",
    "name": "Odranci",
    "lat": "46.58667",
    "lng": "16.28028"
  },
  {
    "country": "SI",
    "name": "Novo Mesto",
    "lat": "45.80397",
    "lng": "15.16886"
  },
  {
    "country": "SI",
    "name": "Nova Vas",
    "lat": "45.77167",
    "lng": "14.50583"
  },
  {
    "country": "SI",
    "name": "Nova Gorica",
    "lat": "45.95604",
    "lng": "13.64837"
  },
  {
    "country": "SI",
    "name": "Notranje Gorice",
    "lat": "45.9875",
    "lng": "14.39889"
  },
  {
    "country": "SI",
    "name": "Naklo",
    "lat": "46.27278",
    "lng": "14.31722"
  },
  {
    "country": "SI",
    "name": "Muta",
    "lat": "46.61139",
    "lng": "15.16611"
  },
  {
    "country": "SI",
    "name": "Murska Sobota",
    "lat": "46.6625",
    "lng": "16.16639"
  },
  {
    "country": "SI",
    "name": "Mozirje",
    "lat": "46.33944",
    "lng": "14.96333"
  },
  {
    "country": "SI",
    "name": "Moste",
    "lat": "46.195",
    "lng": "14.55139"
  },
  {
    "country": "SI",
    "name": "Morje",
    "lat": "46.44444",
    "lng": "15.62139"
  },
  {
    "country": "SI",
    "name": "Moravske Toplice",
    "lat": "46.68313",
    "lng": "16.2208"
  },
  {
    "country": "SI",
    "name": "Moravče",
    "lat": "46.13694",
    "lng": "14.745"
  },
  {
    "country": "SI",
    "name": "Mokronog",
    "lat": "45.93417",
    "lng": "15.14083"
  },
  {
    "country": "SI",
    "name": "Mojstrana",
    "lat": "46.42383",
    "lng": "13.8752"
  },
  {
    "country": "SI",
    "name": "Mlaka pri Kranju",
    "lat": "46.28333",
    "lng": "14.35"
  },
  {
    "country": "SI",
    "name": "Mislinja",
    "lat": "46.44141",
    "lng": "15.20027"
  },
  {
    "country": "SI",
    "name": "Mirna Peč",
    "lat": "45.86028",
    "lng": "15.08333"
  },
  {
    "country": "SI",
    "name": "Mirna",
    "lat": "45.95528",
    "lng": "15.06194"
  },
  {
    "country": "SI",
    "name": "Miren",
    "lat": "45.89556",
    "lng": "13.6075"
  },
  {
    "country": "SI",
    "name": "Miklavž na Dravskem Polju",
    "lat": "46.50583",
    "lng": "15.69722"
  },
  {
    "country": "SI",
    "name": "Mežica",
    "lat": "46.52139",
    "lng": "14.85444"
  },
  {
    "country": "SI",
    "name": "Metlika",
    "lat": "45.64722",
    "lng": "15.31417"
  },
  {
    "country": "SI",
    "name": "Mengeš",
    "lat": "46.16694",
    "lng": "14.575"
  },
  {
    "country": "SI",
    "name": "Mekinje",
    "lat": "46.23333",
    "lng": "14.61667"
  },
  {
    "country": "SI",
    "name": "Medvode",
    "lat": "46.1422",
    "lng": "14.41114"
  },
  {
    "country": "SI",
    "name": "Markovci",
    "lat": "46.39557",
    "lng": "15.92831"
  },
  {
    "country": "SI",
    "name": "Maribor",
    "lat": "46.55472",
    "lng": "15.64667"
  },
  {
    "country": "SI",
    "name": "Makole",
    "lat": "46.31722",
    "lng": "15.66722"
  },
  {
    "country": "SI",
    "name": "Majšperk",
    "lat": "46.35167",
    "lng": "15.73361"
  },
  {
    "country": "SI",
    "name": "Lukovica pri Domžalah",
    "lat": "46.16988",
    "lng": "14.69179"
  },
  {
    "country": "SI",
    "name": "Luče",
    "lat": "46.35611",
    "lng": "14.74667"
  },
  {
    "country": "SI",
    "name": "Lovrenc na Pohorju",
    "lat": "46.54056",
    "lng": "15.39306"
  },
  {
    "country": "SI",
    "name": "Loški Potok",
    "lat": "45.70139",
    "lng": "14.58028"
  },
  {
    "country": "SI",
    "name": "Lokavec",
    "lat": "45.90167",
    "lng": "13.87972"
  },
  {
    "country": "SI",
    "name": "Log pri Brezovici",
    "lat": "46.01667",
    "lng": "14.36667"
  },
  {
    "country": "SI",
    "name": "Ljutomer",
    "lat": "46.52083",
    "lng": "16.1975"
  },
  {
    "country": "SI",
    "name": "Ljubno ob Savinji",
    "lat": "46.34358",
    "lng": "14.83377"
  },
  {
    "country": "SI",
    "name": "Ljubljana",
    "lat": "46.05108",
    "lng": "14.50513"
  },
  {
    "country": "SI",
    "name": "Ljubečna",
    "lat": "46.25567",
    "lng": "15.3243"
  },
  {
    "country": "SI",
    "name": "Litija",
    "lat": "46.05861",
    "lng": "14.8225"
  },
  {
    "country": "SI",
    "name": "Lipovci",
    "lat": "46.62833",
    "lng": "16.22806"
  },
  {
    "country": "SI",
    "name": "Limbuš",
    "lat": "46.55361",
    "lng": "15.58361"
  },
  {
    "country": "SI",
    "name": "Leskovec pri Krškem",
    "lat": "45.93566",
    "lng": "15.47184"
  },
  {
    "country": "SI",
    "name": "Lesce",
    "lat": "46.36111",
    "lng": "14.15778"
  },
  {
    "country": "SI",
    "name": "Lendava",
    "lat": "46.56494",
    "lng": "16.45091"
  },
  {
    "country": "SI",
    "name": "Lenart v Slov. Goricah",
    "lat": "46.57611",
    "lng": "15.83139"
  },
  {
    "country": "SI",
    "name": "Laško",
    "lat": "46.15463",
    "lng": "15.23555"
  },
  {
    "country": "SI",
    "name": "Kuzma",
    "lat": "46.83694",
    "lng": "16.08333"
  },
  {
    "country": "SI",
    "name": "Krško",
    "lat": "45.95915",
    "lng": "15.49167"
  },
  {
    "country": "SI",
    "name": "Kromberk",
    "lat": "45.96083",
    "lng": "13.66556"
  },
  {
    "country": "SI",
    "name": "Krog",
    "lat": "46.63806",
    "lng": "16.14139"
  },
  {
    "country": "SI",
    "name": "Križevci pri Ljutomeru",
    "lat": "46.56833",
    "lng": "16.13861"
  },
  {
    "country": "SI",
    "name": "Kranjska Gora",
    "lat": "46.45689",
    "lng": "13.77824"
  },
  {
    "country": "SI",
    "name": "Kranj",
    "lat": "46.23887",
    "lng": "14.35561"
  },
  {
    "country": "SI",
    "name": "Kozje",
    "lat": "46.075",
    "lng": "15.56028"
  },
  {
    "country": "SI",
    "name": "Kozina",
    "lat": "45.61",
    "lng": "13.93556"
  },
  {
    "country": "SI",
    "name": "Kotlje",
    "lat": "46.52139",
    "lng": "14.98694"
  },
  {
    "country": "SI",
    "name": "Kostanjevica na Krki",
    "lat": "45.84611",
    "lng": "15.42222"
  },
  {
    "country": "SI",
    "name": "Koper",
    "lat": "45.54694",
    "lng": "13.72944"
  },
  {
    "country": "SI",
    "name": "Komen",
    "lat": "45.81528",
    "lng": "13.74833"
  },
  {
    "country": "SI",
    "name": "Kokrica",
    "lat": "46.27028",
    "lng": "14.36111"
  },
  {
    "country": "SI",
    "name": "Kočevje",
    "lat": "45.64333",
    "lng": "14.86333"
  },
  {
    "country": "SI",
    "name": "Kobilje",
    "lat": "46.68472",
    "lng": "16.39778"
  },
  {
    "country": "SI",
    "name": "Kobarid",
    "lat": "46.24761",
    "lng": "13.57907"
  },
  {
    "country": "SI",
    "name": "Kidričevo",
    "lat": "46.40361",
    "lng": "15.79111"
  },
  {
    "country": "SI",
    "name": "Kanal",
    "lat": "46.08861",
    "lng": "13.63972"
  },
  {
    "country": "SI",
    "name": "Kamnik",
    "lat": "46.22587",
    "lng": "14.61207"
  },
  {
    "country": "SI",
    "name": "Kamnica",
    "lat": "46.57444",
    "lng": "15.61417"
  },
  {
    "country": "SI",
    "name": "Juršinci",
    "lat": "46.48472",
    "lng": "15.97139"
  },
  {
    "country": "SI",
    "name": "Jurovski Dol",
    "lat": "46.60639",
    "lng": "15.78472"
  },
  {
    "country": "SI",
    "name": "Sveti Jurij ob Ščavnici",
    "lat": "46.5695",
    "lng": "16.02347"
  },
  {
    "country": "SI",
    "name": "Jesenice",
    "lat": "46.43056",
    "lng": "14.06694"
  },
  {
    "country": "SI",
    "name": "Izola",
    "lat": "45.53694",
    "lng": "13.66194"
  },
  {
    "country": "SI",
    "name": "Izlake",
    "lat": "46.15",
    "lng": "14.95"
  },
  {
    "country": "SI",
    "name": "Ivančna Gorica",
    "lat": "45.93833",
    "lng": "14.80444"
  },
  {
    "country": "SI",
    "name": "Ilirska Bistrica",
    "lat": "45.56757",
    "lng": "14.24571"
  },
  {
    "country": "SI",
    "name": "Ig",
    "lat": "45.96028",
    "lng": "14.52889"
  },
  {
    "country": "SI",
    "name": "Idrija",
    "lat": "46.00278",
    "lng": "14.03056"
  },
  {
    "country": "SI",
    "name": "Hrvatini",
    "lat": "45.58278",
    "lng": "13.75667"
  },
  {
    "country": "SI",
    "name": "Hrušica",
    "lat": "46.445",
    "lng": "14.01778"
  },
  {
    "country": "SI",
    "name": "Hrib-Loški Potok",
    "lat": "45.70688",
    "lng": "14.61674"
  },
  {
    "country": "SI",
    "name": "Hrastnik",
    "lat": "46.14611",
    "lng": "15.08139"
  },
  {
    "country": "SI",
    "name": "Hrastje",
    "lat": "46.21667",
    "lng": "14.4"
  },
  {
    "country": "SI",
    "name": "Hotinja Vas",
    "lat": "46.46667",
    "lng": "15.66667"
  },
  {
    "country": "SI",
    "name": "Horjul",
    "lat": "46.02361",
    "lng": "14.29917"
  },
  {
    "country": "SI",
    "name": "Hodoš",
    "lat": "46.82333",
    "lng": "16.33417"
  },
  {
    "country": "SI",
    "name": "Grosuplje",
    "lat": "45.95556",
    "lng": "14.65889"
  },
  {
    "country": "SI",
    "name": "Sv. Trojica v Slov. Goricah",
    "lat": "46.57667",
    "lng": "15.87694"
  },
  {
    "country": "SI",
    "name": "Grad",
    "lat": "46.8",
    "lng": "16.1"
  },
  {
    "country": "SI",
    "name": "Gotovlje",
    "lat": "46.27418",
    "lng": "15.15186"
  },
  {
    "country": "SI",
    "name": "Gornji Petrovci",
    "lat": "46.80528",
    "lng": "16.2225"
  },
  {
    "country": "SI",
    "name": "Gornji Grad",
    "lat": "46.29528",
    "lng": "14.80833"
  },
  {
    "country": "SI",
    "name": "Gornja Radgona",
    "lat": "46.67333",
    "lng": "15.99222"
  },
  {
    "country": "SI",
    "name": "Gorišnica",
    "lat": "46.41472",
    "lng": "16.01389"
  },
  {
    "country": "SI",
    "name": "Gorenja Vas",
    "lat": "46.10722",
    "lng": "14.14806"
  },
  {
    "country": "SI",
    "name": "Straža",
    "lat": "45.78",
    "lng": "15.07278"
  },
  {
    "country": "SI",
    "name": "Golnik",
    "lat": "46.33333",
    "lng": "14.33333"
  },
  {
    "country": "SI",
    "name": "Gančani",
    "lat": "46.6325",
    "lng": "16.25111"
  },
  {
    "country": "SI",
    "name": "Fram",
    "lat": "46.456",
    "lng": "15.63007"
  },
  {
    "country": "SI",
    "name": "Dravograd",
    "lat": "46.58806",
    "lng": "15.01917"
  },
  {
    "country": "SI",
    "name": "Dragomer",
    "lat": "46.01667",
    "lng": "14.38333"
  },
  {
    "country": "SI",
    "name": "Dornava",
    "lat": "46.43667",
    "lng": "15.95361"
  },
  {
    "country": "SI",
    "name": "Domžale",
    "lat": "46.13774",
    "lng": "14.59371"
  },
  {
    "country": "SI",
    "name": "Dol pri Ljubljani",
    "lat": "46.08861",
    "lng": "14.60083"
  },
  {
    "country": "SI",
    "name": "Dol pri Hrastniku",
    "lat": "46.14194",
    "lng": "15.11278"
  },
  {
    "country": "SI",
    "name": "Dolenjske Toplice",
    "lat": "45.75657",
    "lng": "15.05917"
  },
  {
    "country": "SI",
    "name": "Dobrovo",
    "lat": "45.99639",
    "lng": "13.52639"
  },
  {
    "country": "SI",
    "name": "Dobrovnik",
    "lat": "46.65139",
    "lng": "16.3525"
  },
  {
    "country": "SI",
    "name": "Dobrova",
    "lat": "46.0458",
    "lng": "14.39186"
  },
  {
    "country": "SI",
    "name": "Dobrna",
    "lat": "46.3375",
    "lng": "15.22639"
  },
  {
    "country": "SI",
    "name": "Dobje pri Planini",
    "lat": "46.13747",
    "lng": "15.39412"
  },
  {
    "country": "SI",
    "name": "Dob",
    "lat": "46.15194",
    "lng": "14.62861"
  },
  {
    "country": "SI",
    "name": "Divača",
    "lat": "45.68472",
    "lng": "13.97028"
  },
  {
    "country": "SI",
    "name": "Destrnik",
    "lat": "46.49254",
    "lng": "15.87893"
  },
  {
    "country": "SI",
    "name": "Deskle",
    "lat": "46.05307",
    "lng": "13.61382"
  },
  {
    "country": "SI",
    "name": "Dekani",
    "lat": "45.54972",
    "lng": "13.81361"
  },
  {
    "country": "SI",
    "name": "Črnomelj",
    "lat": "45.57111",
    "lng": "15.18889"
  },
  {
    "country": "SI",
    "name": "Črna na Koroškem",
    "lat": "46.47045",
    "lng": "14.85009"
  },
  {
    "country": "SI",
    "name": "Črenšovci",
    "lat": "46.55794",
    "lng": "16.3041"
  },
  {
    "country": "SI",
    "name": "Černelavci",
    "lat": "46.66667",
    "lng": "16.13333"
  },
  {
    "country": "SI",
    "name": "Cerkvenjak",
    "lat": "46.57056",
    "lng": "15.94361"
  },
  {
    "country": "SI",
    "name": "Cerknica",
    "lat": "45.79306",
    "lng": "14.3625"
  },
  {
    "country": "SI",
    "name": "Cerklje na Gorenjskem",
    "lat": "46.25417",
    "lng": "14.48861"
  },
  {
    "country": "SI",
    "name": "Celje",
    "lat": "46.23092",
    "lng": "15.26044"
  },
  {
    "country": "SI",
    "name": "Cankova",
    "lat": "46.72083",
    "lng": "16.0225"
  },
  {
    "country": "SI",
    "name": "Britof",
    "lat": "46.26024",
    "lng": "14.39037"
  },
  {
    "country": "SI",
    "name": "Brezovica pri Ljubljani",
    "lat": "46.03333",
    "lng": "14.4"
  },
  {
    "country": "SI",
    "name": "Brežice",
    "lat": "45.90333",
    "lng": "15.59111"
  },
  {
    "country": "SI",
    "name": "Bresternica",
    "lat": "46.56972",
    "lng": "15.575"
  },
  {
    "country": "SI",
    "name": "Braslovče",
    "lat": "46.28972",
    "lng": "15.03889"
  },
  {
    "country": "SI",
    "name": "Bovec",
    "lat": "46.33808",
    "lng": "13.55245"
  },
  {
    "country": "SI",
    "name": "Borovnica",
    "lat": "45.91583",
    "lng": "14.36306"
  },
  {
    "country": "SI",
    "name": "Bohinjska Bistrica",
    "lat": "46.27216",
    "lng": "13.9535"
  },
  {
    "country": "SI",
    "name": "Bled",
    "lat": "46.36917",
    "lng": "14.11361"
  },
  {
    "country": "SI",
    "name": "Bistrica pri Tržiču",
    "lat": "46.35472",
    "lng": "14.29167"
  },
  {
    "country": "SI",
    "name": "Bistrica ob Sotli",
    "lat": "46.05889",
    "lng": "15.66417"
  },
  {
    "country": "SI",
    "name": "Bilje",
    "lat": "45.89444",
    "lng": "13.63222"
  },
  {
    "country": "SI",
    "name": "Benedikt",
    "lat": "46.60861",
    "lng": "15.88833"
  },
  {
    "country": "SI",
    "name": "Beltinci",
    "lat": "46.60528",
    "lng": "16.24056"
  },
  {
    "country": "SI",
    "name": "Bakovci",
    "lat": "46.61889",
    "lng": "16.15028"
  },
  {
    "country": "SI",
    "name": "Apače",
    "lat": "46.69722",
    "lng": "15.91056"
  },
  {
    "country": "SI",
    "name": "Ajdovščina",
    "lat": "45.88601",
    "lng": "13.90946"
  },
  {
    "country": "SI",
    "name": "Razkrižje",
    "lat": "46.52167",
    "lng": "16.28111"
  },
  {
    "country": "SI",
    "name": "Solkan",
    "lat": "45.97139",
    "lng": "13.64944"
  },
  {
    "country": "SI",
    "name": "Slovenski Javornik",
    "lat": "46.42611",
    "lng": "14.08722"
  },
  {
    "country": "SI",
    "name": "Koroška Bela",
    "lat": "46.44913",
    "lng": "14.11135"
  },
  {
    "country": "SI",
    "name": "Cerkno",
    "lat": "46.12556",
    "lng": "13.98167"
  },
  {
    "country": "SI",
    "name": "Leskova Dolina",
    "lat": "45.62139",
    "lng": "14.46056"
  },
  {
    "country": "SI",
    "name": "Logatec",
    "lat": "45.91444",
    "lng": "14.22583"
  },
  {
    "country": "SI",
    "name": "Ankaran",
    "lat": "45.57861",
    "lng": "13.73611"
  },
  {
    "country": "SI",
    "name": "Videm pri Ptuju",
    "lat": "46.36861",
    "lng": "15.90639"
  },
  {
    "country": "SI",
    "name": "Legen",
    "lat": "46.50651",
    "lng": "15.14424"
  },
  {
    "country": "SI",
    "name": "Zreče",
    "lat": "46.38222",
    "lng": "15.37917"
  },
  {
    "country": "SI",
    "name": "Radizel",
    "lat": "46.47444",
    "lng": "15.65583"
  },
  {
    "country": "SI",
    "name": "Selnica ob Dravi",
    "lat": "46.55",
    "lng": "15.495"
  },
  {
    "country": "SI",
    "name": "Lucija",
    "lat": "45.50526",
    "lng": "13.6024"
  },
  {
    "country": "SI",
    "name": "Jagodje",
    "lat": "45.52845",
    "lng": "13.64721"
  },
  {
    "country": "SI",
    "name": "Pobegi",
    "lat": "45.53944",
    "lng": "13.79611"
  },
  {
    "country": "SI",
    "name": "Spodnje Škofije",
    "lat": "45.57167",
    "lng": "13.7925"
  },
  {
    "country": "SI",
    "name": "Rožna Dolina",
    "lat": "45.94194",
    "lng": "13.66779"
  },
  {
    "country": "SI",
    "name": "Kisovec",
    "lat": "46.13911",
    "lng": "14.96295"
  },
  {
    "country": "SI",
    "name": "Cirkulane",
    "lat": "46.34408",
    "lng": "15.99472"
  },
  {
    "country": "SI",
    "name": "Komenda",
    "lat": "46.20484",
    "lng": "14.53839"
  },
  {
    "country": "SI",
    "name": "Nazarje",
    "lat": "46.31757",
    "lng": "14.94674"
  },
  {
    "country": "SI",
    "name": "Kostel",
    "lat": "45.50842",
    "lng": "14.91005"
  },
  {
    "country": "SI",
    "name": "Vir",
    "lat": "46.15325",
    "lng": "14.60741"
  },
  {
    "country": "SI",
    "name": "Lavrica",
    "lat": "46.00002",
    "lng": "14.5573"
  },
  {
    "country": "SI",
    "name": "Seča",
    "lat": "45.49584",
    "lng": "13.61466"
  },
  {
    "country": "SI",
    "name": "Prade",
    "lat": "45.54003",
    "lng": "13.77607"
  },
  {
    "country": "SI",
    "name": "Zasip",
    "lat": "46.39284",
    "lng": "14.10869"
  },
  {
    "country": "SI",
    "name": "Bistrica ob Dravi",
    "lat": "46.55419",
    "lng": "15.54855"
  },
  {
    "country": "SJ",
    "name": "Longyearbyen",
    "lat": "78.22334",
    "lng": "15.64689"
  },
  {
    "country": "SJ",
    "name": "Olonkinbyen",
    "lat": "70.9221",
    "lng": "-8.7187"
  },
  {
    "country": "SK",
    "name": "Žehra",
    "lat": "48.9796",
    "lng": "20.7917"
  },
  {
    "country": "SK",
    "name": "Ždiar",
    "lat": "49.271",
    "lng": "20.26239"
  },
  {
    "country": "SK",
    "name": "Vysoké Tatry",
    "lat": "49.13637",
    "lng": "20.24386"
  },
  {
    "country": "SK",
    "name": "Vyšné Ružbachy",
    "lat": "49.30387",
    "lng": "20.56558"
  },
  {
    "country": "SK",
    "name": "Vrbov",
    "lat": "49.08764",
    "lng": "20.4253"
  },
  {
    "country": "SK",
    "name": "Vranov nad Topľou",
    "lat": "48.88836",
    "lng": "21.68479"
  },
  {
    "country": "SK",
    "name": "Vinné",
    "lat": "48.80965",
    "lng": "21.96757"
  },
  {
    "country": "SK",
    "name": "Trebišov",
    "lat": "48.62858",
    "lng": "21.71954"
  },
  {
    "country": "SK",
    "name": "Svit",
    "lat": "49.06014",
    "lng": "20.20695"
  },
  {
    "country": "SK",
    "name": "Svidník",
    "lat": "49.30819",
    "lng": "21.5703"
  },
  {
    "country": "SK",
    "name": "Stropkov",
    "lat": "49.20211",
    "lng": "21.65216"
  },
  {
    "country": "SK",
    "name": "Štrba",
    "lat": "49.05913",
    "lng": "20.07975"
  },
  {
    "country": "SK",
    "name": "Strážske",
    "lat": "48.8735",
    "lng": "21.83668"
  },
  {
    "country": "SK",
    "name": "Stará Ľubovňa",
    "lat": "49.29859",
    "lng": "20.6862"
  },
  {
    "country": "SK",
    "name": "Spišské Podhradie",
    "lat": "49.00088",
    "lng": "20.75307"
  },
  {
    "country": "SK",
    "name": "Spišská Nová Ves",
    "lat": "48.94464",
    "lng": "20.56153"
  },
  {
    "country": "SK",
    "name": "Spišská Belá",
    "lat": "49.18725",
    "lng": "20.45948"
  },
  {
    "country": "SK",
    "name": "Sobrance",
    "lat": "48.74455",
    "lng": "22.18136"
  },
  {
    "country": "SK",
    "name": "Snina",
    "lat": "48.98857",
    "lng": "22.15099"
  },
  {
    "country": "SK",
    "name": "Sečovce",
    "lat": "48.70074",
    "lng": "21.66104"
  },
  {
    "country": "SK",
    "name": "Sabinov",
    "lat": "49.10309",
    "lng": "21.0988"
  },
  {
    "country": "SK",
    "name": "Rožňava",
    "lat": "48.66009",
    "lng": "20.53758"
  },
  {
    "country": "SK",
    "name": "Rimavská Sobota",
    "lat": "48.38284",
    "lng": "20.02239"
  },
  {
    "country": "SK",
    "name": "Revúca",
    "lat": "48.68346",
    "lng": "20.11734"
  },
  {
    "country": "SK",
    "name": "Prešov",
    "lat": "48.99839",
    "lng": "21.23393"
  },
  {
    "country": "SK",
    "name": "Poprad",
    "lat": "49.06144",
    "lng": "20.29798"
  },
  {
    "country": "SK",
    "name": "Podolínec",
    "lat": "49.25869",
    "lng": "20.536"
  },
  {
    "country": "SK",
    "name": "Nová Lesná",
    "lat": "49.12253",
    "lng": "20.26737"
  },
  {
    "country": "SK",
    "name": "Moldava nad Bodvou",
    "lat": "48.61428",
    "lng": "20.99957"
  },
  {
    "country": "SK",
    "name": "Michalovce",
    "lat": "48.75434",
    "lng": "21.9195"
  },
  {
    "country": "SK",
    "name": "Medzilaborce",
    "lat": "49.27195",
    "lng": "21.90073"
  },
  {
    "country": "SK",
    "name": "Medzev",
    "lat": "48.70041",
    "lng": "20.89367"
  },
  {
    "country": "SK",
    "name": "Ľubica",
    "lat": "49.11667",
    "lng": "20.45"
  },
  {
    "country": "SK",
    "name": "Lipany",
    "lat": "49.15376",
    "lng": "20.96382"
  },
  {
    "country": "SK",
    "name": "Levoča",
    "lat": "49.02173",
    "lng": "20.59212"
  },
  {
    "country": "SK",
    "name": "Krompachy",
    "lat": "48.91447",
    "lng": "20.87514"
  },
  {
    "country": "SK",
    "name": "Košice",
    "lat": "48.71395",
    "lng": "21.25808"
  },
  {
    "country": "SK",
    "name": "Kežmarok",
    "lat": "49.13571",
    "lng": "20.43352"
  },
  {
    "country": "SK",
    "name": "Kavečany",
    "lat": "48.77592",
    "lng": "21.20587"
  },
  {
    "country": "SK",
    "name": "Humenné",
    "lat": "48.93707",
    "lng": "21.91625"
  },
  {
    "country": "SK",
    "name": "Giraltovce",
    "lat": "49.11398",
    "lng": "21.51731"
  },
  {
    "country": "SK",
    "name": "Gelnica",
    "lat": "48.85584",
    "lng": "20.93713"
  },
  {
    "country": "SK",
    "name": "Dobšiná",
    "lat": "48.82073",
    "lng": "20.36988"
  },
  {
    "country": "SK",
    "name": "Čierna nad Tisou",
    "lat": "48.41704",
    "lng": "22.08865"
  },
  {
    "country": "SK",
    "name": "Chlmec",
    "lat": "48.88628",
    "lng": "21.9393"
  },
  {
    "country": "SK",
    "name": "Bardejov",
    "lat": "49.29175",
    "lng": "21.27271"
  },
  {
    "country": "SK",
    "name": "Zvolen",
    "lat": "48.57442",
    "lng": "19.15324"
  },
  {
    "country": "SK",
    "name": "Zlaté Moravce",
    "lat": "48.38553",
    "lng": "18.40063"
  },
  {
    "country": "SK",
    "name": "Žilina",
    "lat": "49.22315",
    "lng": "18.73941"
  },
  {
    "country": "SK",
    "name": "Žiar nad Hronom",
    "lat": "48.59184",
    "lng": "18.84958"
  },
  {
    "country": "SK",
    "name": "Želiezovce",
    "lat": "48.05075",
    "lng": "18.65421"
  },
  {
    "country": "SK",
    "name": "Žarnovica",
    "lat": "48.48123",
    "lng": "18.71565"
  },
  {
    "country": "SK",
    "name": "Vrútky",
    "lat": "49.11328",
    "lng": "18.91714"
  },
  {
    "country": "SK",
    "name": "Vrbové",
    "lat": "48.61973",
    "lng": "17.7226"
  },
  {
    "country": "SK",
    "name": "Vráble",
    "lat": "48.24371",
    "lng": "18.30846"
  },
  {
    "country": "SK",
    "name": "Veľký Meder",
    "lat": "47.85798",
    "lng": "17.76884"
  },
  {
    "country": "SK",
    "name": "Veľký Krtíš",
    "lat": "48.21059",
    "lng": "19.35043"
  },
  {
    "country": "SK",
    "name": "Tvrdošín",
    "lat": "49.337",
    "lng": "19.556"
  },
  {
    "country": "SK",
    "name": "Turzovka",
    "lat": "49.40429",
    "lng": "18.62258"
  },
  {
    "country": "SK",
    "name": "Turčianske Teplice",
    "lat": "48.86225",
    "lng": "18.86048"
  },
  {
    "country": "SK",
    "name": "Trstená",
    "lat": "49.36101",
    "lng": "19.61249"
  },
  {
    "country": "SK",
    "name": "Trnava",
    "lat": "48.37741",
    "lng": "17.58723"
  },
  {
    "country": "SK",
    "name": "Trenčín",
    "lat": "48.89452",
    "lng": "18.04436"
  },
  {
    "country": "SK",
    "name": "Trenčianske Teplice",
    "lat": "48.91063",
    "lng": "18.16691"
  },
  {
    "country": "SK",
    "name": "Topoľčany",
    "lat": "48.56361",
    "lng": "18.16712"
  },
  {
    "country": "SK",
    "name": "Tlmače",
    "lat": "48.28926",
    "lng": "18.53152"
  },
  {
    "country": "SK",
    "name": "Tisovec",
    "lat": "48.67738",
    "lng": "19.94364"
  },
  {
    "country": "SK",
    "name": "Terchová",
    "lat": "49.25895",
    "lng": "19.02935"
  },
  {
    "country": "SK",
    "name": "Svodín",
    "lat": "47.91054",
    "lng": "18.49967"
  },
  {
    "country": "SK",
    "name": "Svätý Jur",
    "lat": "48.25216",
    "lng": "17.21539"
  },
  {
    "country": "SK",
    "name": "Svätý Anton",
    "lat": "48.41923",
    "lng": "18.9401"
  },
  {
    "country": "SK",
    "name": "Šurany",
    "lat": "48.08613",
    "lng": "18.18447"
  },
  {
    "country": "SK",
    "name": "Štúrovo",
    "lat": "47.79495",
    "lng": "18.7175"
  },
  {
    "country": "SK",
    "name": "Stupava",
    "lat": "48.27474",
    "lng": "17.03173"
  },
  {
    "country": "SK",
    "name": "Stará Turá",
    "lat": "48.77721",
    "lng": "17.69433"
  },
  {
    "country": "SK",
    "name": "Smolenice",
    "lat": "48.50478",
    "lng": "17.43067"
  },
  {
    "country": "SK",
    "name": "Sládkovičovo",
    "lat": "48.20137",
    "lng": "17.63852"
  },
  {
    "country": "SK",
    "name": "Skalica",
    "lat": "48.8449",
    "lng": "17.22635"
  },
  {
    "country": "SK",
    "name": "Senica",
    "lat": "48.67922",
    "lng": "17.36697"
  },
  {
    "country": "SK",
    "name": "Senec",
    "lat": "48.21951",
    "lng": "17.40043"
  },
  {
    "country": "SK",
    "name": "Šamorín",
    "lat": "48.03015",
    "lng": "17.30972"
  },
  {
    "country": "SK",
    "name": "Sellye",
    "lat": "48.15127",
    "lng": "17.88062"
  },
  {
    "country": "SK",
    "name": "Šahy",
    "lat": "48.07408",
    "lng": "18.94946"
  },
  {
    "country": "SK",
    "name": "Ružomberok",
    "lat": "49.0748",
    "lng": "19.30751"
  },
  {
    "country": "SK",
    "name": "Rajec",
    "lat": "49.08899",
    "lng": "18.64007"
  },
  {
    "country": "SK",
    "name": "Púchov",
    "lat": "49.12494",
    "lng": "18.32597"
  },
  {
    "country": "SK",
    "name": "Prievidza",
    "lat": "48.77446",
    "lng": "18.6275"
  },
  {
    "country": "SK",
    "name": "Pribylina",
    "lat": "49.0995",
    "lng": "19.79427"
  },
  {
    "country": "SK",
    "name": "Považská Bystrica",
    "lat": "49.12153",
    "lng": "18.42169"
  },
  {
    "country": "SK",
    "name": "Poltár",
    "lat": "48.43094",
    "lng": "19.79408"
  },
  {
    "country": "SK",
    "name": "Piešťany",
    "lat": "48.59479",
    "lng": "17.82591"
  },
  {
    "country": "SK",
    "name": "Pezinok",
    "lat": "48.28986",
    "lng": "17.26664"
  },
  {
    "country": "SK",
    "name": "Partizánske",
    "lat": "48.62861",
    "lng": "18.38455"
  },
  {
    "country": "SK",
    "name": "Oravský Podzámok",
    "lat": "49.25939",
    "lng": "19.3569"
  },
  {
    "country": "SK",
    "name": "Nové Zámky",
    "lat": "47.98544",
    "lng": "18.16195"
  },
  {
    "country": "SK",
    "name": "Nové Mesto nad Váhom",
    "lat": "48.75763",
    "lng": "17.8309"
  },
  {
    "country": "SK",
    "name": "Nováky",
    "lat": "48.71106",
    "lng": "18.53389"
  },
  {
    "country": "SK",
    "name": "Nová Dubnica",
    "lat": "48.93479",
    "lng": "18.14632"
  },
  {
    "country": "SK",
    "name": "Nová Baňa",
    "lat": "48.42305",
    "lng": "18.64037"
  },
  {
    "country": "SK",
    "name": "Nižná",
    "lat": "49.31046",
    "lng": "19.52428"
  },
  {
    "country": "SK",
    "name": "Nitra",
    "lat": "48.30763",
    "lng": "18.08453"
  },
  {
    "country": "SK",
    "name": "Nemšová",
    "lat": "48.96702",
    "lng": "18.11892"
  },
  {
    "country": "SK",
    "name": "Námestovo",
    "lat": "49.4079",
    "lng": "19.48032"
  },
  {
    "country": "SK",
    "name": "Myjava",
    "lat": "48.75876",
    "lng": "17.56866"
  },
  {
    "country": "SK",
    "name": "Modra",
    "lat": "48.33397",
    "lng": "17.30711"
  },
  {
    "country": "SK",
    "name": "Martin",
    "lat": "49.06651",
    "lng": "18.92399"
  },
  {
    "country": "SK",
    "name": "Marianka",
    "lat": "48.24903",
    "lng": "17.064"
  },
  {
    "country": "SK",
    "name": "Malacky",
    "lat": "48.43604",
    "lng": "17.02188"
  },
  {
    "country": "SK",
    "name": "Lúčky",
    "lat": "49.12944",
    "lng": "19.40228"
  },
  {
    "country": "SK",
    "name": "Lučenec",
    "lat": "48.33249",
    "lng": "19.66708"
  },
  {
    "country": "SK",
    "name": "Liptovský Mikuláš",
    "lat": "49.08061",
    "lng": "19.62218"
  },
  {
    "country": "SK",
    "name": "Liptovský Hrádok",
    "lat": "49.03962",
    "lng": "19.72335"
  },
  {
    "country": "SK",
    "name": "Levice",
    "lat": "48.21563",
    "lng": "18.60705"
  },
  {
    "country": "SK",
    "name": "Leopoldov",
    "lat": "48.44575",
    "lng": "17.76458"
  },
  {
    "country": "SK",
    "name": "Kysucké Nové Mesto",
    "lat": "49.3",
    "lng": "18.78333"
  },
  {
    "country": "SK",
    "name": "Krupina",
    "lat": "48.3554",
    "lng": "19.06474"
  },
  {
    "country": "SK",
    "name": "Kremnica",
    "lat": "48.70519",
    "lng": "18.91834"
  },
  {
    "country": "SK",
    "name": "Krasňany",
    "lat": "49.21491",
    "lng": "18.88718"
  },
  {
    "country": "SK",
    "name": "Kováčová",
    "lat": "48.60148",
    "lng": "19.10252"
  },
  {
    "country": "SK",
    "name": "Komárno",
    "lat": "48.11667",
    "lng": "18.31667"
  },
  {
    "country": "SK",
    "name": "Komárno",
    "lat": "47.76356",
    "lng": "18.12263"
  },
  {
    "country": "SK",
    "name": "Kolárovo",
    "lat": "47.92294",
    "lng": "17.98467"
  },
  {
    "country": "SK",
    "name": "Ivanka pri Dunaji",
    "lat": "48.18675",
    "lng": "17.2554"
  },
  {
    "country": "SK",
    "name": "Ilava",
    "lat": "48.99769",
    "lng": "18.2353"
  },
  {
    "country": "SK",
    "name": "Hybe",
    "lat": "49.04439",
    "lng": "19.82895"
  },
  {
    "country": "SK",
    "name": "Hurbanovo",
    "lat": "47.86984",
    "lng": "18.19233"
  },
  {
    "country": "SK",
    "name": "Hrochoť,Slovakia",
    "lat": "48.65567",
    "lng": "19.31284"
  },
  {
    "country": "SK",
    "name": "Hriňová",
    "lat": "48.57787",
    "lng": "19.52574"
  },
  {
    "country": "SK",
    "name": "Holíč",
    "lat": "48.81105",
    "lng": "17.16238"
  },
  {
    "country": "SK",
    "name": "Hlohovec",
    "lat": "48.43174",
    "lng": "17.8031"
  },
  {
    "country": "SK",
    "name": "Handlová",
    "lat": "48.7276",
    "lng": "18.76012"
  },
  {
    "country": "SK",
    "name": "Gbely",
    "lat": "48.718",
    "lng": "17.11628"
  },
  {
    "country": "SK",
    "name": "Galanta",
    "lat": "48.19001",
    "lng": "17.72747"
  },
  {
    "country": "SK",
    "name": "Gabčíkovo",
    "lat": "47.89211",
    "lng": "17.57884"
  },
  {
    "country": "SK",
    "name": "Fiľakovo",
    "lat": "48.26757",
    "lng": "19.82473"
  },
  {
    "country": "SK",
    "name": "Bratislava - Vajnory",
    "lat": "48.20563",
    "lng": "17.20759"
  },
  {
    "country": "SK",
    "name": "Dunajská Streda",
    "lat": "47.99268",
    "lng": "17.61211"
  },
  {
    "country": "SK",
    "name": "Dudince",
    "lat": "48.17135",
    "lng": "18.88782"
  },
  {
    "country": "SK",
    "name": "Dubnica nad Váhom",
    "lat": "48.95981",
    "lng": "18.16634"
  },
  {
    "country": "SK",
    "name": "Dolný Kubín",
    "lat": "49.20983",
    "lng": "19.30341"
  },
  {
    "country": "SK",
    "name": "Detva",
    "lat": "48.56082",
    "lng": "19.41954"
  },
  {
    "country": "SK",
    "name": "Čierny Balog",
    "lat": "48.74722",
    "lng": "19.65125"
  },
  {
    "country": "SK",
    "name": "Čadca",
    "lat": "49.43503",
    "lng": "18.78895"
  },
  {
    "country": "SK",
    "name": "Čachtice",
    "lat": "48.71226",
    "lng": "17.78704"
  },
  {
    "country": "SK",
    "name": "Bytča",
    "lat": "49.22404",
    "lng": "18.55878"
  },
  {
    "country": "SK",
    "name": "Brezová pod Bradlom",
    "lat": "48.66349",
    "lng": "17.53905"
  },
  {
    "country": "SK",
    "name": "Brezno",
    "lat": "48.80431",
    "lng": "19.63631"
  },
  {
    "country": "SK",
    "name": "Bratislava",
    "lat": "48.14816",
    "lng": "17.10674"
  },
  {
    "country": "SK",
    "name": "Bojnice",
    "lat": "48.78511",
    "lng": "18.5864"
  },
  {
    "country": "SK",
    "name": "Banská Štiavnica",
    "lat": "48.44858",
    "lng": "18.91003"
  },
  {
    "country": "SK",
    "name": "Banská Bystrica",
    "lat": "48.73946",
    "lng": "19.15349"
  },
  {
    "country": "SK",
    "name": "Bánovce nad Bebravou",
    "lat": "48.7213",
    "lng": "18.25754"
  },
  {
    "country": "SK",
    "name": "Oravská Lesná",
    "lat": "49.36672",
    "lng": "19.18093"
  },
  {
    "country": "SK",
    "name": "Dunajská Lužná",
    "lat": "48.08347",
    "lng": "17.26072"
  },
  {
    "country": "SK",
    "name": "Vinosady",
    "lat": "48.31142",
    "lng": "17.29042"
  },
  {
    "country": "SL",
    "name": "Zimmi",
    "lat": "7.31356",
    "lng": "-11.30818"
  },
  {
    "country": "SL",
    "name": "Yonibana",
    "lat": "8.44347",
    "lng": "-12.23929"
  },
  {
    "country": "SL",
    "name": "Yengema",
    "lat": "8.71441",
    "lng": "-11.17057"
  },
  {
    "country": "SL",
    "name": "Wima",
    "lat": "8.30052",
    "lng": "-11.20455"
  },
  {
    "country": "SL",
    "name": "Waterloo",
    "lat": "8.3389",
    "lng": "-13.07091"
  },
  {
    "country": "SL",
    "name": "Tongole",
    "lat": "7.45092",
    "lng": "-11.90071"
  },
  {
    "country": "SL",
    "name": "Tombu",
    "lat": "8.53991",
    "lng": "-10.73132"
  },
  {
    "country": "SL",
    "name": "Tombodu",
    "lat": "8.13526",
    "lng": "-10.6196"
  },
  {
    "country": "SL",
    "name": "Tintafor",
    "lat": "8.62667",
    "lng": "-13.215"
  },
  {
    "country": "SL",
    "name": "Tefeya",
    "lat": "8.70395",
    "lng": "-11.2126"
  },
  {
    "country": "SL",
    "name": "Sumbuya",
    "lat": "7.64789",
    "lng": "-11.9606"
  },
  {
    "country": "SL",
    "name": "Simbakoro",
    "lat": "8.61243",
    "lng": "-11.00755"
  },
  {
    "country": "SL",
    "name": "Serabu",
    "lat": "7.79311",
    "lng": "-12.05294"
  },
  {
    "country": "SL",
    "name": "Seidu",
    "lat": "9.01801",
    "lng": "-10.59496"
  },
  {
    "country": "SL",
    "name": "Segbwema",
    "lat": "7.99471",
    "lng": "-10.9502"
  },
  {
    "country": "SL",
    "name": "Sawkta",
    "lat": "8.6323",
    "lng": "-13.2025"
  },
  {
    "country": "SL",
    "name": "Rotifunk",
    "lat": "8.22591",
    "lng": "-12.6776"
  },
  {
    "country": "SL",
    "name": "Rokupr",
    "lat": "8.67121",
    "lng": "-12.38497"
  },
  {
    "country": "SL",
    "name": "Potoru",
    "lat": "7.50596",
    "lng": "-11.47897"
  },
  {
    "country": "SL",
    "name": "Port Loko",
    "lat": "8.76609",
    "lng": "-12.78696"
  },
  {
    "country": "SL",
    "name": "Koyima",
    "lat": "8.70552",
    "lng": "-11.02241"
  },
  {
    "country": "SL",
    "name": "Pepel",
    "lat": "8.58611",
    "lng": "-13.05444"
  },
  {
    "country": "SL",
    "name": "Pendembu",
    "lat": "8.09807",
    "lng": "-10.69429"
  },
  {
    "country": "SL",
    "name": "Panguma",
    "lat": "8.18507",
    "lng": "-11.1329"
  },
  {
    "country": "SL",
    "name": "Giehun",
    "lat": "8.55518",
    "lng": "-11.04278"
  },
  {
    "country": "SL",
    "name": "Moyamba",
    "lat": "8.15898",
    "lng": "-12.43168"
  },
  {
    "country": "SL",
    "name": "Motema",
    "lat": "8.61427",
    "lng": "-11.01252"
  },
  {
    "country": "SL",
    "name": "Mogbwemo",
    "lat": "7.76237",
    "lng": "-12.30864"
  },
  {
    "country": "SL",
    "name": "Mobai",
    "lat": "7.99343",
    "lng": "-10.75355"
  },
  {
    "country": "SL",
    "name": "Masoyila",
    "lat": "8.61119",
    "lng": "-13.19101"
  },
  {
    "country": "SL",
    "name": "Masingbi",
    "lat": "8.78197",
    "lng": "-11.95171"
  },
  {
    "country": "SL",
    "name": "Masaka",
    "lat": "8.66492",
    "lng": "-11.8026"
  },
  {
    "country": "SL",
    "name": "Manowa",
    "lat": "8.17392",
    "lng": "-10.74834"
  },
  {
    "country": "SL",
    "name": "Mange",
    "lat": "8.92262",
    "lng": "-12.85688"
  },
  {
    "country": "SL",
    "name": "Mamboma",
    "lat": "8.08742",
    "lng": "-11.68841"
  },
  {
    "country": "SL",
    "name": "Mambolo",
    "lat": "8.9186",
    "lng": "-13.03674"
  },
  {
    "country": "SL",
    "name": "Makeni",
    "lat": "8.88605",
    "lng": "-12.04417"
  },
  {
    "country": "SL",
    "name": "Makali",
    "lat": "8.62964",
    "lng": "-11.66168"
  },
  {
    "country": "SL",
    "name": "Magburaka",
    "lat": "8.72306",
    "lng": "-11.9488"
  },
  {
    "country": "SL",
    "name": "Lunsar",
    "lat": "8.68439",
    "lng": "-12.53499"
  },
  {
    "country": "SL",
    "name": "Loma",
    "lat": "9.75931",
    "lng": "-12.03383"
  },
  {
    "country": "SL",
    "name": "Largo",
    "lat": "8.27903",
    "lng": "-12.1578"
  },
  {
    "country": "SL",
    "name": "Kukuna",
    "lat": "9.39841",
    "lng": "-12.66476"
  },
  {
    "country": "SL",
    "name": "Koribundu",
    "lat": "7.70952",
    "lng": "-11.69354"
  },
  {
    "country": "SL",
    "name": "Koidu",
    "lat": "8.64387",
    "lng": "-10.9714"
  },
  {
    "country": "SL",
    "name": "Kenema",
    "lat": "7.87687",
    "lng": "-11.19025"
  },
  {
    "country": "SL",
    "name": "Kayima",
    "lat": "8.8879",
    "lng": "-11.15932"
  },
  {
    "country": "SL",
    "name": "Kassiri",
    "lat": "8.93814",
    "lng": "-13.11541"
  },
  {
    "country": "SL",
    "name": "Kambia",
    "lat": "9.12504",
    "lng": "-12.91816"
  },
  {
    "country": "SL",
    "name": "Kamakwie",
    "lat": "9.49689",
    "lng": "-12.24061"
  },
  {
    "country": "SL",
    "name": "Kailahun",
    "lat": "8.2789",
    "lng": "-10.573"
  },
  {
    "country": "SL",
    "name": "Kabala",
    "lat": "9.58893",
    "lng": "-11.55256"
  },
  {
    "country": "SL",
    "name": "Jojoima",
    "lat": "7.87815",
    "lng": "-10.78976"
  },
  {
    "country": "SL",
    "name": "Hastings",
    "lat": "8.37994",
    "lng": "-13.13693"
  },
  {
    "country": "SL",
    "name": "Hangha",
    "lat": "7.93974",
    "lng": "-11.14132"
  },
  {
    "country": "SL",
    "name": "Gorahun",
    "lat": "7.46439",
    "lng": "-11.23952"
  },
  {
    "country": "SL",
    "name": "Freetown",
    "lat": "8.43194",
    "lng": "-13.28972"
  },
  {
    "country": "SL",
    "name": "Giehun",
    "lat": "7.88405",
    "lng": "-11.04908"
  },
  {
    "country": "SL",
    "name": "Gberia Fotombu",
    "lat": "9.87852",
    "lng": "-11.16548"
  },
  {
    "country": "SL",
    "name": "Gandorhun",
    "lat": "7.55502",
    "lng": "-11.6926"
  },
  {
    "country": "SL",
    "name": "Gandorhun",
    "lat": "7.49431",
    "lng": "-11.83064"
  },
  {
    "country": "SL",
    "name": "Freetown",
    "lat": "8.48714",
    "lng": "-13.2356"
  },
  {
    "country": "SL",
    "name": "Foindu",
    "lat": "7.40906",
    "lng": "-11.54328"
  },
  {
    "country": "SL",
    "name": "Daru",
    "lat": "7.98976",
    "lng": "-10.84223"
  },
  {
    "country": "SL",
    "name": "Buedu",
    "lat": "8.2796",
    "lng": "-10.37135"
  },
  {
    "country": "SL",
    "name": "Bunumbu",
    "lat": "8.17421",
    "lng": "-10.86432"
  },
  {
    "country": "SL",
    "name": "Bumpe",
    "lat": "7.89209",
    "lng": "-11.90541"
  },
  {
    "country": "SL",
    "name": "Bumbuna",
    "lat": "9.04466",
    "lng": "-11.74576"
  },
  {
    "country": "SL",
    "name": "Bonthe",
    "lat": "7.52639",
    "lng": "-12.505"
  },
  {
    "country": "SL",
    "name": "Bomi",
    "lat": "7.24611",
    "lng": "-11.52583"
  },
  {
    "country": "SL",
    "name": "Boajibu",
    "lat": "8.18763",
    "lng": "-11.34026"
  },
  {
    "country": "SL",
    "name": "Bo",
    "lat": "7.96472",
    "lng": "-11.73833"
  },
  {
    "country": "SL",
    "name": "Blama",
    "lat": "7.87481",
    "lng": "-11.34548"
  },
  {
    "country": "SL",
    "name": "Binkolo",
    "lat": "8.95225",
    "lng": "-11.98029"
  },
  {
    "country": "SL",
    "name": "Bindi",
    "lat": "9.91376",
    "lng": "-11.44669"
  },
  {
    "country": "SL",
    "name": "Barma",
    "lat": "8.34959",
    "lng": "-11.33059"
  },
  {
    "country": "SL",
    "name": "Baoma",
    "lat": "7.99344",
    "lng": "-11.71468"
  },
  {
    "country": "SL",
    "name": "Palima",
    "lat": "8.11996",
    "lng": "-11.50702"
  },
  {
    "country": "SL",
    "name": "Baiima",
    "lat": "8.10826",
    "lng": "-11.84772"
  },
  {
    "country": "SL",
    "name": "Alikalia",
    "lat": "9.15356",
    "lng": "-11.38712"
  },
  {
    "country": "SL",
    "name": "Konakridee",
    "lat": "8.69778",
    "lng": "-13.23917"
  },
  {
    "country": "SL",
    "name": "Gbewebu",
    "lat": "7.55091",
    "lng": "-11.6075"
  },
  {
    "country": "SL",
    "name": "Pujehun",
    "lat": "7.35806",
    "lng": "-11.72083"
  },
  {
    "country": "SL",
    "name": "Kent",
    "lat": "8.33333",
    "lng": "-13.06667"
  },
  {
    "country": "SM",
    "name": "Serravalle",
    "lat": "43.96897",
    "lng": "12.48167"
  },
  {
    "country": "SM",
    "name": "San Marino",
    "lat": "43.93667",
    "lng": "12.44639"
  },
  {
    "country": "SM",
    "name": "Poggio di Chiesanuova",
    "lat": "43.90451",
    "lng": "12.42142"
  },
  {
    "country": "SM",
    "name": "Monte Giardino",
    "lat": "43.90878",
    "lng": "12.48201"
  },
  {
    "country": "SM",
    "name": "Fiorentino",
    "lat": "43.91001",
    "lng": "12.45738"
  },
  {
    "country": "SM",
    "name": "Faetano",
    "lat": "43.92831",
    "lng": "12.49798"
  },
  {
    "country": "SM",
    "name": "Domagnano",
    "lat": "43.94961",
    "lng": "12.46828"
  },
  {
    "country": "SM",
    "name": "Borgo Maggiore",
    "lat": "43.94193",
    "lng": "12.44738"
  },
  {
    "country": "SM",
    "name": "Acquaviva",
    "lat": "43.94593",
    "lng": "12.4185"
  },
  {
    "country": "SN",
    "name": "Ziguinchor",
    "lat": "12.56801",
    "lng": "-16.27326"
  },
  {
    "country": "SN",
    "name": "Vélingara",
    "lat": "13.15",
    "lng": "-14.11667"
  },
  {
    "country": "SN",
    "name": "Touba",
    "lat": "14.85",
    "lng": "-15.88333"
  },
  {
    "country": "SN",
    "name": "Tionk Essil",
    "lat": "12.78556",
    "lng": "-16.52167"
  },
  {
    "country": "SN",
    "name": "Tiébo",
    "lat": "14.63333",
    "lng": "-16.23333"
  },
  {
    "country": "SN",
    "name": "Tiadiaye",
    "lat": "14.41667",
    "lng": "-16.7"
  },
  {
    "country": "SN",
    "name": "Thiès Nones",
    "lat": "14.78333",
    "lng": "-16.96667"
  },
  {
    "country": "SN",
    "name": "Thiès",
    "lat": "14.78944",
    "lng": "-16.92602"
  },
  {
    "country": "SN",
    "name": "Tambacounda",
    "lat": "13.77073",
    "lng": "-13.66734"
  },
  {
    "country": "SN",
    "name": "Sokone",
    "lat": "13.88333",
    "lng": "-16.36667"
  },
  {
    "country": "SN",
    "name": "Sémé",
    "lat": "15.19422",
    "lng": "-12.94482"
  },
  {
    "country": "SN",
    "name": "Sédhiou",
    "lat": "12.70806",
    "lng": "-15.55694"
  },
  {
    "country": "SN",
    "name": "Saint-Louis",
    "lat": "16.01793",
    "lng": "-16.48962"
  },
  {
    "country": "SN",
    "name": "Rosso",
    "lat": "16.42028",
    "lng": "-15.79834"
  },
  {
    "country": "SN",
    "name": "Richard-Toll",
    "lat": "16.4625",
    "lng": "-15.70083"
  },
  {
    "country": "SN",
    "name": "Ranérou",
    "lat": "15.3",
    "lng": "-13.96667"
  },
  {
    "country": "SN",
    "name": "Pout",
    "lat": "14.77099",
    "lng": "-17.06107"
  },
  {
    "country": "SN",
    "name": "Pourham",
    "lat": "14.35",
    "lng": "-16.41667"
  },
  {
    "country": "SN",
    "name": "Polel Diaoubé",
    "lat": "15.26667",
    "lng": "-13"
  },
  {
    "country": "SN",
    "name": "Pikine",
    "lat": "14.76457",
    "lng": "-17.39071"
  },
  {
    "country": "SN",
    "name": "Passi",
    "lat": "13.98333",
    "lng": "-16.26667"
  },
  {
    "country": "SN",
    "name": "Oussouye",
    "lat": "12.485",
    "lng": "-16.54694"
  },
  {
    "country": "SN",
    "name": "Ouro Sogui",
    "lat": "15.60588",
    "lng": "-13.3223"
  },
  {
    "country": "SN",
    "name": "Waoundé",
    "lat": "15.26367",
    "lng": "-12.86821"
  },
  {
    "country": "SN",
    "name": "Nioro du Rip",
    "lat": "13.75",
    "lng": "-15.8"
  },
  {
    "country": "SN",
    "name": "Nguékhokh",
    "lat": "14.51255",
    "lng": "-17.00447"
  },
  {
    "country": "SN",
    "name": "Ndofane",
    "lat": "13.91667",
    "lng": "-15.93333"
  },
  {
    "country": "SN",
    "name": "Ndioum",
    "lat": "16.51293",
    "lng": "-14.64706"
  },
  {
    "country": "SN",
    "name": "Ndibène Dahra",
    "lat": "15.3338",
    "lng": "-15.4766"
  },
  {
    "country": "SN",
    "name": "Mékhé",
    "lat": "15.1097",
    "lng": "-16.6218"
  },
  {
    "country": "SN",
    "name": "Mbaké",
    "lat": "14.79032",
    "lng": "-15.90803"
  },
  {
    "country": "SN",
    "name": "Matam",
    "lat": "15.65587",
    "lng": "-13.25544"
  },
  {
    "country": "SN",
    "name": "Marsassoum",
    "lat": "12.8275",
    "lng": "-15.98056"
  },
  {
    "country": "SN",
    "name": "Louga",
    "lat": "15.61867",
    "lng": "-16.22436"
  },
  {
    "country": "SN",
    "name": "Koungheul",
    "lat": "13.98333",
    "lng": "-14.8"
  },
  {
    "country": "SN",
    "name": "Kolda",
    "lat": "12.8939",
    "lng": "-14.94125"
  },
  {
    "country": "SN",
    "name": "Khombole",
    "lat": "14.76667",
    "lng": "-16.7"
  },
  {
    "country": "SN",
    "name": "Kédougou",
    "lat": "12.55561",
    "lng": "-12.18076"
  },
  {
    "country": "SN",
    "name": "Kayar",
    "lat": "14.91893",
    "lng": "-17.11978"
  },
  {
    "country": "SN",
    "name": "Kaolack",
    "lat": "14.15197",
    "lng": "-16.07259"
  },
  {
    "country": "SN",
    "name": "Kanel",
    "lat": "15.4916",
    "lng": "-13.17627"
  },
  {
    "country": "SN",
    "name": "Kaffrine",
    "lat": "14.10594",
    "lng": "-15.5508"
  },
  {
    "country": "SN",
    "name": "Joal-Fadiout",
    "lat": "14.16667",
    "lng": "-16.83333"
  },
  {
    "country": "SN",
    "name": "Guinguinéo",
    "lat": "14.26667",
    "lng": "-15.95"
  },
  {
    "country": "SN",
    "name": "Guéoul",
    "lat": "15.48333",
    "lng": "-16.35"
  },
  {
    "country": "SN",
    "name": "Goléré",
    "lat": "16.25575",
    "lng": "-14.10165"
  },
  {
    "country": "SN",
    "name": "Gandiaye",
    "lat": "14.23333",
    "lng": "-16.26667"
  },
  {
    "country": "SN",
    "name": "Foundiougne",
    "lat": "14.13333",
    "lng": "-16.46667"
  },
  {
    "country": "SN",
    "name": "Fatick",
    "lat": "14.33236",
    "lng": "-16.40513"
  },
  {
    "country": "SN",
    "name": "Diourbel",
    "lat": "14.64792",
    "lng": "-16.24363"
  },
  {
    "country": "SN",
    "name": "Diofior",
    "lat": "14.18333",
    "lng": "-16.66667"
  },
  {
    "country": "SN",
    "name": "Diawara",
    "lat": "15.02196",
    "lng": "-12.54374"
  },
  {
    "country": "SN",
    "name": "Dara",
    "lat": "15.34844",
    "lng": "-15.47993"
  },
  {
    "country": "SN",
    "name": "Dakar",
    "lat": "14.6937",
    "lng": "-17.44406"
  },
  {
    "country": "SN",
    "name": "Bignona",
    "lat": "12.81028",
    "lng": "-16.22639"
  },
  {
    "country": "SN",
    "name": "Adéane",
    "lat": "12.63",
    "lng": "-16.01694"
  },
  {
    "country": "SN",
    "name": "Warang",
    "lat": "14.37349",
    "lng": "-16.94366"
  },
  {
    "country": "SN",
    "name": "Mermoz Boabab",
    "lat": "14.70649",
    "lng": "-17.47581"
  },
  {
    "country": "SN",
    "name": "N’diareme limamoulaye",
    "lat": "14.78148",
    "lng": "-17.3841"
  },
  {
    "country": "SO",
    "name": "Yeed",
    "lat": "4.55",
    "lng": "43.03333"
  },
  {
    "country": "SO",
    "name": "Xuddur",
    "lat": "4.12129",
    "lng": "43.88945"
  },
  {
    "country": "SO",
    "name": "Xarardheere",
    "lat": "4.6544",
    "lng": "47.8575"
  },
  {
    "country": "SO",
    "name": "Wanlaweyn",
    "lat": "2.6185",
    "lng": "44.8938"
  },
  {
    "country": "SO",
    "name": "Waajid",
    "lat": "3.80958",
    "lng": "43.24627"
  },
  {
    "country": "SO",
    "name": "Tayeeglow",
    "lat": "4.01897",
    "lng": "44.51111"
  },
  {
    "country": "SO",
    "name": "Saacow",
    "lat": "1.62794",
    "lng": "42.44067"
  },
  {
    "country": "SO",
    "name": "Qoryooley",
    "lat": "1.78784",
    "lng": "44.52999"
  },
  {
    "country": "SO",
    "name": "Qandala",
    "lat": "11.47197",
    "lng": "49.87282"
  },
  {
    "country": "SO",
    "name": "Oodweyne",
    "lat": "9.4092",
    "lng": "45.06397"
  },
  {
    "country": "SO",
    "name": "Mogadishu",
    "lat": "2.03711",
    "lng": "45.34375"
  },
  {
    "country": "SO",
    "name": "Marka",
    "lat": "1.71594",
    "lng": "44.77166"
  },
  {
    "country": "SO",
    "name": "Mahaddayweyne",
    "lat": "2.9726",
    "lng": "45.5347"
  },
  {
    "country": "SO",
    "name": "Luuq",
    "lat": "3.80315",
    "lng": "42.54417"
  },
  {
    "country": "SO",
    "name": "Lughaye",
    "lat": "10.68573",
    "lng": "43.94397"
  },
  {
    "country": "SO",
    "name": "Las Khorey",
    "lat": "11.1595",
    "lng": "48.1967"
  },
  {
    "country": "SO",
    "name": "Kismayo",
    "lat": "-0.35817",
    "lng": "42.54536"
  },
  {
    "country": "SO",
    "name": "Jilib",
    "lat": "0.48829",
    "lng": "42.78535"
  },
  {
    "country": "SO",
    "name": "Jawhar",
    "lat": "2.78087",
    "lng": "45.50048"
  },
  {
    "country": "SO",
    "name": "Jamaame",
    "lat": "0.06968",
    "lng": "42.74497"
  },
  {
    "country": "SO",
    "name": "Jalalaqsi",
    "lat": "3.3766",
    "lng": "45.5996"
  },
  {
    "country": "SO",
    "name": "Iskushuban",
    "lat": "10.2837",
    "lng": "50.23"
  },
  {
    "country": "SO",
    "name": "Hobyo",
    "lat": "5.3505",
    "lng": "48.5268"
  },
  {
    "country": "SO",
    "name": "Hargeysa",
    "lat": "9.56",
    "lng": "44.065"
  },
  {
    "country": "SO",
    "name": "Garoowe",
    "lat": "8.40207",
    "lng": "48.48284"
  },
  {
    "country": "SO",
    "name": "Garbahaarrey",
    "lat": "3.32892",
    "lng": "42.22091"
  },
  {
    "country": "SO",
    "name": "Gaalkacyo",
    "lat": "6.76972",
    "lng": "47.43083"
  },
  {
    "country": "SO",
    "name": "Eyl",
    "lat": "7.9803",
    "lng": "49.8164"
  },
  {
    "country": "SO",
    "name": "Dujuuma",
    "lat": "1.25311",
    "lng": "42.57377"
  },
  {
    "country": "SO",
    "name": "Dhuusamarreeb",
    "lat": "5.53597",
    "lng": "46.38666"
  },
  {
    "country": "SO",
    "name": "Ceerigaabo",
    "lat": "10.61616",
    "lng": "47.36795"
  },
  {
    "country": "SO",
    "name": "Ceeldheer",
    "lat": "3.84878",
    "lng": "47.18064"
  },
  {
    "country": "SO",
    "name": "Ceelbuur",
    "lat": "4.68501",
    "lng": "46.6176"
  },
  {
    "country": "SO",
    "name": "Ceek",
    "lat": "8.99907",
    "lng": "45.35824"
  },
  {
    "country": "SO",
    "name": "Caluula",
    "lat": "11.96611",
    "lng": "50.75694"
  },
  {
    "country": "SO",
    "name": "Cadale",
    "lat": "2.7603",
    "lng": "46.3222"
  },
  {
    "country": "SO",
    "name": "Adado",
    "lat": "6.13603",
    "lng": "46.62761"
  },
  {
    "country": "SO",
    "name": "Buurhakaba",
    "lat": "2.80257",
    "lng": "44.07805"
  },
  {
    "country": "SO",
    "name": "Buur Gaabo",
    "lat": "-1.21917",
    "lng": "41.83725"
  },
  {
    "country": "SO",
    "name": "Buulobarde",
    "lat": "3.85375",
    "lng": "45.56744"
  },
  {
    "country": "SO",
    "name": "Burao",
    "lat": "9.52213",
    "lng": "45.53363"
  },
  {
    "country": "SO",
    "name": "Bu’aale",
    "lat": "1.08333",
    "lng": "42.58333"
  },
  {
    "country": "SO",
    "name": "Bosaso",
    "lat": "11.28421",
    "lng": "49.18158"
  },
  {
    "country": "SO",
    "name": "Bereeda",
    "lat": "11.87037",
    "lng": "51.05795"
  },
  {
    "country": "SO",
    "name": "Berbera",
    "lat": "10.43959",
    "lng": "45.01432"
  },
  {
    "country": "SO",
    "name": "Beledweyne",
    "lat": "4.73583",
    "lng": "45.20361"
  },
  {
    "country": "SO",
    "name": "Baidoa",
    "lat": "3.11383",
    "lng": "43.6498"
  },
  {
    "country": "SO",
    "name": "Bargaal",
    "lat": "11.28636",
    "lng": "51.0773"
  },
  {
    "country": "SO",
    "name": "Bandarbeyla",
    "lat": "9.4942",
    "lng": "50.8122"
  },
  {
    "country": "SO",
    "name": "Baardheere",
    "lat": "2.34464",
    "lng": "42.27644"
  },
  {
    "country": "SO",
    "name": "Afgooye",
    "lat": "2.1381",
    "lng": "45.1212"
  },
  {
    "country": "SO",
    "name": "Laascaanood",
    "lat": "8.47738",
    "lng": "47.35971"
  },
  {
    "country": "SO",
    "name": "Baki",
    "lat": "9.89206",
    "lng": "43.38531"
  },
  {
    "country": "SO",
    "name": "Baligubadle",
    "lat": "9",
    "lng": "44.00028"
  },
  {
    "country": "SR",
    "name": "Wageningen",
    "lat": "5.7601",
    "lng": "-56.66523"
  },
  {
    "country": "SR",
    "name": "Totness",
    "lat": "5.87618",
    "lng": "-56.32572"
  },
  {
    "country": "SR",
    "name": "Paramaribo",
    "lat": "5.86638",
    "lng": "-55.16682"
  },
  {
    "country": "SR",
    "name": "Onverwacht",
    "lat": "5.58983",
    "lng": "-55.19462"
  },
  {
    "country": "SR",
    "name": "Nieuw Nickerie",
    "lat": "5.92606",
    "lng": "-56.97297"
  },
  {
    "country": "SR",
    "name": "Nieuw Amsterdam",
    "lat": "5.88573",
    "lng": "-55.08871"
  },
  {
    "country": "SR",
    "name": "Moengo",
    "lat": "5.61411",
    "lng": "-54.40121"
  },
  {
    "country": "SR",
    "name": "Mariënburg",
    "lat": "5.87722",
    "lng": "-55.04322"
  },
  {
    "country": "SR",
    "name": "Lelydorp",
    "lat": "5.7",
    "lng": "-55.23333"
  },
  {
    "country": "SR",
    "name": "Groningen",
    "lat": "5.8",
    "lng": "-55.46667"
  },
  {
    "country": "SR",
    "name": "Brownsweg",
    "lat": "5.00435",
    "lng": "-55.15333"
  },
  {
    "country": "SR",
    "name": "Brokopondo",
    "lat": "5.05594",
    "lng": "-54.98043"
  },
  {
    "country": "SR",
    "name": "Albina",
    "lat": "5.49788",
    "lng": "-54.05522"
  },
  {
    "country": "SS",
    "name": "Yirol",
    "lat": "6.5525",
    "lng": "30.49806"
  },
  {
    "country": "SS",
    "name": "Yei",
    "lat": "4.09444",
    "lng": "30.67639"
  },
  {
    "country": "SS",
    "name": "Yambio",
    "lat": "4.57083",
    "lng": "28.39417"
  },
  {
    "country": "SS",
    "name": "Winejok",
    "lat": "9.01222",
    "lng": "27.57081"
  },
  {
    "country": "SS",
    "name": "Wau",
    "lat": "7.70111",
    "lng": "27.98972"
  },
  {
    "country": "SS",
    "name": "Waat",
    "lat": "8.17925",
    "lng": "32.15206"
  },
  {
    "country": "SS",
    "name": "Aweil",
    "lat": "8.76194",
    "lng": "27.39194"
  },
  {
    "country": "SS",
    "name": "Torit",
    "lat": "4.41177",
    "lng": "32.57046"
  },
  {
    "country": "SS",
    "name": "Tonj",
    "lat": "7.27389",
    "lng": "28.6775"
  },
  {
    "country": "SS",
    "name": "Terekeka",
    "lat": "5.44389",
    "lng": "31.75083"
  },
  {
    "country": "SS",
    "name": "Tambura",
    "lat": "5.6",
    "lng": "27.46667"
  },
  {
    "country": "SS",
    "name": "Rumbek",
    "lat": "6.80619",
    "lng": "29.67742"
  },
  {
    "country": "SS",
    "name": "Raja",
    "lat": "8.4675",
    "lng": "25.67833"
  },
  {
    "country": "SS",
    "name": "Pibor",
    "lat": "6.79853",
    "lng": "33.13045"
  },
  {
    "country": "SS",
    "name": "Nasir",
    "lat": "8.61658",
    "lng": "33.06215"
  },
  {
    "country": "SS",
    "name": "Mundri",
    "lat": "5.3472",
    "lng": "30.32433"
  },
  {
    "country": "SS",
    "name": "Maridi",
    "lat": "4.91667",
    "lng": "29.46944"
  },
  {
    "country": "SS",
    "name": "Malakal",
    "lat": "9.53342",
    "lng": "31.66049"
  },
  {
    "country": "SS",
    "name": "Maiwut",
    "lat": "8.60975",
    "lng": "33.92621"
  },
  {
    "country": "SS",
    "name": "Leer",
    "lat": "8.30306",
    "lng": "30.14056"
  },
  {
    "country": "SS",
    "name": "Kuacjok",
    "lat": "8.30278",
    "lng": "27.98"
  },
  {
    "country": "SS",
    "name": "Kodok",
    "lat": "9.88889",
    "lng": "32.10944"
  },
  {
    "country": "SS",
    "name": "Kapoeta",
    "lat": "4.77222",
    "lng": "33.59139"
  },
  {
    "country": "SS",
    "name": "Juba",
    "lat": "4.85165",
    "lng": "31.58247"
  },
  {
    "country": "SS",
    "name": "Gogrial",
    "lat": "8.53324",
    "lng": "28.10037"
  },
  {
    "country": "SS",
    "name": "Pajok",
    "lat": "3.86512",
    "lng": "32.48212"
  },
  {
    "country": "SS",
    "name": "Cueibet",
    "lat": "7.02667",
    "lng": "29.24611"
  },
  {
    "country": "SS",
    "name": "Bor",
    "lat": "6.20889",
    "lng": "31.55861"
  },
  {
    "country": "SS",
    "name": "Bentiu",
    "lat": "9.25722",
    "lng": "29.79833"
  },
  {
    "country": "SS",
    "name": "Ayod",
    "lat": "8.12193",
    "lng": "31.40904"
  },
  {
    "country": "SS",
    "name": "Renk",
    "lat": "11.7431",
    "lng": "32.8049"
  },
  {
    "country": "SS",
    "name": "Akobo",
    "lat": "7.79111",
    "lng": "33.00444"
  },
  {
    "country": "SS",
    "name": "Pariang",
    "lat": "9.91542",
    "lng": "29.98109"
  },
  {
    "country": "SS",
    "name": "Mayen Abun",
    "lat": "9.13639",
    "lng": "28.34583"
  },
  {
    "country": "ST",
    "name": "São Tomé",
    "lat": "0.33654",
    "lng": "6.72732"
  },
  {
    "country": "ST",
    "name": "Santo António",
    "lat": "1.63943",
    "lng": "7.41951"
  },
  {
    "country": "ST",
    "name": "São João dos Angolares",
    "lat": "0.13333",
    "lng": "6.65"
  },
  {
    "country": "SV",
    "name": "Zaragoza",
    "lat": "13.58944",
    "lng": "-89.28889"
  },
  {
    "country": "SV",
    "name": "Zacatecoluca",
    "lat": "13.5",
    "lng": "-88.86667"
  },
  {
    "country": "SV",
    "name": "Victoria",
    "lat": "13.95",
    "lng": "-88.63333"
  },
  {
    "country": "SV",
    "name": "Usulután",
    "lat": "13.35",
    "lng": "-88.45"
  },
  {
    "country": "SV",
    "name": "Tonacatepeque",
    "lat": "13.78111",
    "lng": "-89.11861"
  },
  {
    "country": "SV",
    "name": "Texistepeque",
    "lat": "14.13333",
    "lng": "-89.5"
  },
  {
    "country": "SV",
    "name": "Tenancingo",
    "lat": "13.83333",
    "lng": "-88.98333"
  },
  {
    "country": "SV",
    "name": "Tecoluca",
    "lat": "13.78917",
    "lng": "-89.00528"
  },
  {
    "country": "SV",
    "name": "Tacuba",
    "lat": "13.90111",
    "lng": "-89.92972"
  },
  {
    "country": "SV",
    "name": "Suchitoto",
    "lat": "13.93806",
    "lng": "-89.02778"
  },
  {
    "country": "SV",
    "name": "Soyapango",
    "lat": "13.71024",
    "lng": "-89.13989"
  },
  {
    "country": "SV",
    "name": "Sonzacate",
    "lat": "13.73417",
    "lng": "-89.71472"
  },
  {
    "country": "SV",
    "name": "Sonsonate",
    "lat": "13.71889",
    "lng": "-89.72417"
  },
  {
    "country": "SV",
    "name": "Sociedad",
    "lat": "13.7",
    "lng": "-88.01667"
  },
  {
    "country": "SV",
    "name": "Sesori",
    "lat": "13.71667",
    "lng": "-88.36667"
  },
  {
    "country": "SV",
    "name": "Sensuntepeque",
    "lat": "13.86667",
    "lng": "-88.63333"
  },
  {
    "country": "SV",
    "name": "San Vicente",
    "lat": "13.63333",
    "lng": "-88.8"
  },
  {
    "country": "SV",
    "name": "Santo Tomás",
    "lat": "13.64083",
    "lng": "-89.13333"
  },
  {
    "country": "SV",
    "name": "Santiago Nonualco",
    "lat": "13.51667",
    "lng": "-88.95"
  },
  {
    "country": "SV",
    "name": "Santiago de María",
    "lat": "13.48333",
    "lng": "-88.46667"
  },
  {
    "country": "SV",
    "name": "Santa Rosa de Lima",
    "lat": "13.62472",
    "lng": "-87.89361"
  },
  {
    "country": "SV",
    "name": "Santa Elena",
    "lat": "13.38333",
    "lng": "-88.41667"
  },
  {
    "country": "SV",
    "name": "Santa Ana",
    "lat": "13.99417",
    "lng": "-89.55972"
  },
  {
    "country": "SV",
    "name": "San Sebastián",
    "lat": "13.73333",
    "lng": "-88.83333"
  },
  {
    "country": "SV",
    "name": "San Salvador",
    "lat": "13.68935",
    "lng": "-89.18718"
  },
  {
    "country": "SV",
    "name": "San Rafael Oriente",
    "lat": "13.38333",
    "lng": "-88.35"
  },
  {
    "country": "SV",
    "name": "San Pedro Masahuat",
    "lat": "13.54361",
    "lng": "-89.03861"
  },
  {
    "country": "SV",
    "name": "San Pablo Tacachico",
    "lat": "13.97556",
    "lng": "-89.34"
  },
  {
    "country": "SV",
    "name": "San Miguel",
    "lat": "13.48333",
    "lng": "-88.18333"
  },
  {
    "country": "SV",
    "name": "San Martín",
    "lat": "13.78333",
    "lng": "-88.91667"
  },
  {
    "country": "SV",
    "name": "San Marcos",
    "lat": "13.65889",
    "lng": "-89.18306"
  },
  {
    "country": "SV",
    "name": "San Juan Opico",
    "lat": "13.87611",
    "lng": "-89.35972"
  },
  {
    "country": "SV",
    "name": "San Francisco Menéndez",
    "lat": "13.84306",
    "lng": "-90.01583"
  },
  {
    "country": "SV",
    "name": "San Francisco",
    "lat": "13.7",
    "lng": "-88.1"
  },
  {
    "country": "SV",
    "name": "San Antonio del Monte",
    "lat": "13.71639",
    "lng": "-89.73833"
  },
  {
    "country": "SV",
    "name": "San Alejo",
    "lat": "13.43139",
    "lng": "-87.96306"
  },
  {
    "country": "SV",
    "name": "San Agustín",
    "lat": "13.43333",
    "lng": "-88.6"
  },
  {
    "country": "SV",
    "name": "Rosario de Mora",
    "lat": "13.57528",
    "lng": "-89.20889"
  },
  {
    "country": "SV",
    "name": "Quezaltepeque",
    "lat": "13.83124",
    "lng": "-89.27221"
  },
  {
    "country": "SV",
    "name": "Puerto El Triunfo",
    "lat": "13.28333",
    "lng": "-88.55"
  },
  {
    "country": "SV",
    "name": "Pasaquina",
    "lat": "13.58444",
    "lng": "-87.84111"
  },
  {
    "country": "SV",
    "name": "Panchimalco",
    "lat": "13.61278",
    "lng": "-89.18"
  },
  {
    "country": "SV",
    "name": "Ozatlán",
    "lat": "13.38333",
    "lng": "-88.5"
  },
  {
    "country": "SV",
    "name": "Olocuilta",
    "lat": "13.56972",
    "lng": "-89.11722"
  },
  {
    "country": "SV",
    "name": "Nuevo Cuscatlán",
    "lat": "13.64861",
    "lng": "-89.26528"
  },
  {
    "country": "SV",
    "name": "Santa Tecla",
    "lat": "13.67694",
    "lng": "-89.27972"
  },
  {
    "country": "SV",
    "name": "Nueva Guadalupe",
    "lat": "13.53333",
    "lng": "-88.35"
  },
  {
    "country": "SV",
    "name": "Nueva Esparta",
    "lat": "13.78361",
    "lng": "-87.83861"
  },
  {
    "country": "SV",
    "name": "Nueva Concepción",
    "lat": "14.13333",
    "lng": "-89.3"
  },
  {
    "country": "SV",
    "name": "Nahuizalco",
    "lat": "13.7775",
    "lng": "-89.73667"
  },
  {
    "country": "SV",
    "name": "Moncagua",
    "lat": "13.53333",
    "lng": "-88.25"
  },
  {
    "country": "SV",
    "name": "Metapán",
    "lat": "14.33333",
    "lng": "-89.45"
  },
  {
    "country": "SV",
    "name": "Mejicanos",
    "lat": "13.74028",
    "lng": "-89.21306"
  },
  {
    "country": "SV",
    "name": "Lolotique",
    "lat": "13.55",
    "lng": "-88.35"
  },
  {
    "country": "SV",
    "name": "La Unión",
    "lat": "13.33694",
    "lng": "-87.84389"
  },
  {
    "country": "SV",
    "name": "La Libertad",
    "lat": "13.48833",
    "lng": "-89.32222"
  },
  {
    "country": "SV",
    "name": "Jujutla",
    "lat": "13.78694",
    "lng": "-89.85722"
  },
  {
    "country": "SV",
    "name": "Jucuarán",
    "lat": "13.25389",
    "lng": "-88.24778"
  },
  {
    "country": "SV",
    "name": "Jucuapa",
    "lat": "13.51667",
    "lng": "-88.38333"
  },
  {
    "country": "SV",
    "name": "Juayúa",
    "lat": "13.84139",
    "lng": "-89.74556"
  },
  {
    "country": "SV",
    "name": "Jocoro",
    "lat": "13.61667",
    "lng": "-88.01667"
  },
  {
    "country": "SV",
    "name": "Jiquilisco",
    "lat": "13.31667",
    "lng": "-88.58333"
  },
  {
    "country": "SV",
    "name": "Izalco",
    "lat": "13.74472",
    "lng": "-89.67306"
  },
  {
    "country": "SV",
    "name": "Intipucá",
    "lat": "13.19694",
    "lng": "-88.05444"
  },
  {
    "country": "SV",
    "name": "Ilopango",
    "lat": "13.70167",
    "lng": "-89.10944"
  },
  {
    "country": "SV",
    "name": "Guazapa",
    "lat": "13.87694",
    "lng": "-89.17306"
  },
  {
    "country": "SV",
    "name": "Guaymango",
    "lat": "13.75028",
    "lng": "-89.84222"
  },
  {
    "country": "SV",
    "name": "Guatajiagua",
    "lat": "13.66667",
    "lng": "-88.2"
  },
  {
    "country": "SV",
    "name": "El Tránsito",
    "lat": "13.35",
    "lng": "-88.35"
  },
  {
    "country": "SV",
    "name": "El Rosario",
    "lat": "13.49778",
    "lng": "-89.02972"
  },
  {
    "country": "SV",
    "name": "El Paisnal",
    "lat": "13.97361",
    "lng": "-89.21861"
  },
  {
    "country": "SV",
    "name": "El Congo",
    "lat": "13.90889",
    "lng": "-89.49583"
  },
  {
    "country": "SV",
    "name": "Delgado",
    "lat": "13.72417",
    "lng": "-89.17028"
  },
  {
    "country": "SV",
    "name": "Cuscatancingo",
    "lat": "13.73611",
    "lng": "-89.18139"
  },
  {
    "country": "SV",
    "name": "Corinto",
    "lat": "13.81083",
    "lng": "-87.97139"
  },
  {
    "country": "SV",
    "name": "Conchagua",
    "lat": "13.30778",
    "lng": "-87.86472"
  },
  {
    "country": "SV",
    "name": "Concepción de Ataco",
    "lat": "13.87028",
    "lng": "-89.84861"
  },
  {
    "country": "SV",
    "name": "Concepción Batres",
    "lat": "13.35",
    "lng": "-88.36667"
  },
  {
    "country": "SV",
    "name": "Cojutepeque",
    "lat": "13.71667",
    "lng": "-88.93333"
  },
  {
    "country": "SV",
    "name": "Coatepeque",
    "lat": "13.92861",
    "lng": "-89.50417"
  },
  {
    "country": "SV",
    "name": "Ciudad Barrios",
    "lat": "13.76667",
    "lng": "-88.26667"
  },
  {
    "country": "SV",
    "name": "Ciudad Arce",
    "lat": "13.84028",
    "lng": "-89.44722"
  },
  {
    "country": "SV",
    "name": "Chirilagua",
    "lat": "13.22028",
    "lng": "-88.13861"
  },
  {
    "country": "SV",
    "name": "Chinameca",
    "lat": "13.5",
    "lng": "-88.35"
  },
  {
    "country": "SV",
    "name": "Chapeltique",
    "lat": "13.63333",
    "lng": "-88.26667"
  },
  {
    "country": "SV",
    "name": "Chalchuapa",
    "lat": "13.98667",
    "lng": "-89.68111"
  },
  {
    "country": "SV",
    "name": "Chalatenango",
    "lat": "14.03333",
    "lng": "-88.93333"
  },
  {
    "country": "SV",
    "name": "Candelaria de La Frontera",
    "lat": "14.11667",
    "lng": "-89.65"
  },
  {
    "country": "SV",
    "name": "Cacaopera",
    "lat": "13.76667",
    "lng": "-88.08333"
  },
  {
    "country": "SV",
    "name": "Berlín",
    "lat": "13.5",
    "lng": "-88.53333"
  },
  {
    "country": "SV",
    "name": "Ayutuxtepeque",
    "lat": "13.74556",
    "lng": "-89.20639"
  },
  {
    "country": "SV",
    "name": "Atiquizaya",
    "lat": "13.97694",
    "lng": "-89.7525"
  },
  {
    "country": "SV",
    "name": "Armenia",
    "lat": "13.74361",
    "lng": "-89.49889"
  },
  {
    "country": "SV",
    "name": "Apopa",
    "lat": "13.80722",
    "lng": "-89.17917"
  },
  {
    "country": "SV",
    "name": "Apastepeque",
    "lat": "13.66667",
    "lng": "-88.78333"
  },
  {
    "country": "SV",
    "name": "Antiguo Cuscatlán",
    "lat": "13.66492",
    "lng": "-89.25319"
  },
  {
    "country": "SV",
    "name": "Anamorós",
    "lat": "13.74056",
    "lng": "-87.87361"
  },
  {
    "country": "SV",
    "name": "Ahuachapán",
    "lat": "13.92139",
    "lng": "-89.845"
  },
  {
    "country": "SV",
    "name": "Aguilares",
    "lat": "13.95722",
    "lng": "-89.18972"
  },
  {
    "country": "SV",
    "name": "Acajutla",
    "lat": "13.59278",
    "lng": "-89.8275"
  },
  {
    "country": "SX",
    "name": "Philipsburg",
    "lat": "18.026",
    "lng": "-63.04582"
  },
  {
    "country": "SX",
    "name": "Lower Prince’s Quarter",
    "lat": "18.04987",
    "lng": "-63.03789"
  },
  {
    "country": "SX",
    "name": "Cul de Sac",
    "lat": "18.04852",
    "lng": "-63.06513"
  },
  {
    "country": "SX",
    "name": "Koolbaai",
    "lat": "18.04048",
    "lng": "-63.08397"
  },
  {
    "country": "SY",
    "name": "‘Ayn Ḩalāqīm",
    "lat": "34.93998",
    "lng": "36.32212"
  },
  {
    "country": "SY",
    "name": "Al Karāmah",
    "lat": "35.86865",
    "lng": "39.27803"
  },
  {
    "country": "SY",
    "name": "‘Arīqah",
    "lat": "32.88981",
    "lng": "36.48336"
  },
  {
    "country": "SY",
    "name": "Aş Şūrah aş Şaghīrah",
    "lat": "33.03247",
    "lng": "36.5742"
  },
  {
    "country": "SY",
    "name": "Mūḩ Ḩasan",
    "lat": "35.23349",
    "lng": "40.3166"
  },
  {
    "country": "SY",
    "name": "Yabrūd",
    "lat": "33.96921",
    "lng": "36.65729"
  },
  {
    "country": "SY",
    "name": "Wādī al ‘Uyūn",
    "lat": "35.00119",
    "lng": "36.18683"
  },
  {
    "country": "SY",
    "name": "‘Uqayribāt",
    "lat": "35.0431",
    "lng": "37.46442"
  },
  {
    "country": "SY",
    "name": "Ţayyibat al Imām",
    "lat": "35.26592",
    "lng": "36.71219"
  },
  {
    "country": "SY",
    "name": "Tasīl",
    "lat": "32.83395",
    "lng": "35.96973"
  },
  {
    "country": "SY",
    "name": "Tartouss",
    "lat": "34.88902",
    "lng": "35.88659"
  },
  {
    "country": "SY",
    "name": "Tall Tamr",
    "lat": "36.65556",
    "lng": "40.37079"
  },
  {
    "country": "SY",
    "name": "Tall Salḩab",
    "lat": "35.25884",
    "lng": "36.38461"
  },
  {
    "country": "SY",
    "name": "Tall Rif‘at",
    "lat": "36.47229",
    "lng": "37.09471"
  },
  {
    "country": "SY",
    "name": "Tallkalakh",
    "lat": "34.66842",
    "lng": "36.25995"
  },
  {
    "country": "SY",
    "name": "Tall Ḩamīs",
    "lat": "36.75678",
    "lng": "41.39943"
  },
  {
    "country": "SY",
    "name": "Talldaww",
    "lat": "34.87632",
    "lng": "36.524"
  },
  {
    "country": "SY",
    "name": "Tall aḑ Ḑamān",
    "lat": "35.80776",
    "lng": "37.25378"
  },
  {
    "country": "SY",
    "name": "Tall Abyaḑ",
    "lat": "36.69648",
    "lng": "38.95382"
  },
  {
    "country": "SY",
    "name": "Tālīn",
    "lat": "35.14849",
    "lng": "36.03288"
  },
  {
    "country": "SY",
    "name": "Tallbīsah",
    "lat": "34.84072",
    "lng": "36.73092"
  },
  {
    "country": "SY",
    "name": "Taftanāz",
    "lat": "35.99832",
    "lng": "36.78579"
  },
  {
    "country": "SY",
    "name": "Ţafas",
    "lat": "32.73709",
    "lng": "36.06654"
  },
  {
    "country": "SY",
    "name": "Tadmur",
    "lat": "34.5624",
    "lng": "38.28402"
  },
  {
    "country": "SY",
    "name": "Tādif",
    "lat": "36.34814",
    "lng": "37.5309"
  },
  {
    "country": "SY",
    "name": "Şūrān",
    "lat": "36.56579",
    "lng": "37.2127"
  },
  {
    "country": "SY",
    "name": "Souran",
    "lat": "35.29193",
    "lng": "36.74848"
  },
  {
    "country": "SY",
    "name": "As Suqaylibīyah",
    "lat": "35.36674",
    "lng": "36.39359"
  },
  {
    "country": "SY",
    "name": "Subaykhān",
    "lat": "34.85305",
    "lng": "40.59987"
  },
  {
    "country": "SY",
    "name": "Şlinfah",
    "lat": "35.59822",
    "lng": "36.1877"
  },
  {
    "country": "SY",
    "name": "Şirrīn ash Shamālīyah",
    "lat": "36.58838",
    "lng": "38.29788"
  },
  {
    "country": "SY",
    "name": "Sirghāyā",
    "lat": "33.8104",
    "lng": "36.15787"
  },
  {
    "country": "SY",
    "name": "Sinjār",
    "lat": "35.59011",
    "lng": "37.00472"
  },
  {
    "country": "SY",
    "name": "Shuyūkh Taḩtānī",
    "lat": "36.75059",
    "lng": "38.07676"
  },
  {
    "country": "SY",
    "name": "Shīn",
    "lat": "34.77863",
    "lng": "36.42366"
  },
  {
    "country": "SY",
    "name": "Ash Shaykh Miskīn",
    "lat": "32.82944",
    "lng": "36.15933"
  },
  {
    "country": "SY",
    "name": "Shaykh al Ḩadīd",
    "lat": "36.50069",
    "lng": "36.59945"
  },
  {
    "country": "SY",
    "name": "Shaţḩah",
    "lat": "35.50509",
    "lng": "36.24377"
  },
  {
    "country": "SY",
    "name": "Sharān",
    "lat": "36.62336",
    "lng": "36.93659"
  },
  {
    "country": "SY",
    "name": "Shaqqā",
    "lat": "32.89773",
    "lng": "36.69653"
  },
  {
    "country": "SY",
    "name": "Shahbā",
    "lat": "32.85514",
    "lng": "36.62896"
  },
  {
    "country": "SY",
    "name": "Şaydnāyā",
    "lat": "33.69473",
    "lng": "36.37146"
  },
  {
    "country": "SY",
    "name": "Sa‘sa‘",
    "lat": "33.28198",
    "lng": "36.01947"
  },
  {
    "country": "SY",
    "name": "Sarmīn",
    "lat": "35.90403",
    "lng": "36.72501"
  },
  {
    "country": "SY",
    "name": "Sarāqib",
    "lat": "35.86447",
    "lng": "36.80591"
  },
  {
    "country": "SY",
    "name": "Sulūk",
    "lat": "36.59596",
    "lng": "39.1299"
  },
  {
    "country": "SY",
    "name": "Salqīn",
    "lat": "36.13865",
    "lng": "36.45244"
  },
  {
    "country": "SY",
    "name": "Şalkhad",
    "lat": "32.492",
    "lng": "36.71114"
  },
  {
    "country": "SY",
    "name": "As Salamīyah",
    "lat": "35.01127",
    "lng": "37.05324"
  },
  {
    "country": "SY",
    "name": "Şalākhid",
    "lat": "32.87271",
    "lng": "36.57271"
  },
  {
    "country": "SY",
    "name": "Sahnaiya",
    "lat": "33.42531",
    "lng": "36.22552"
  },
  {
    "country": "SY",
    "name": "Satita",
    "lat": "34.82099",
    "lng": "36.11773"
  },
  {
    "country": "SY",
    "name": "Şadad",
    "lat": "34.31248",
    "lng": "36.92562"
  },
  {
    "country": "SY",
    "name": "Şabbūrah",
    "lat": "35.15595",
    "lng": "37.20908"
  },
  {
    "country": "SY",
    "name": "As Sab‘ Biyār",
    "lat": "33.77974",
    "lng": "37.68357"
  },
  {
    "country": "SY",
    "name": "Ar Riqāmā",
    "lat": "34.53879",
    "lng": "36.91909"
  },
  {
    "country": "SY",
    "name": "Rasm al Ḩarmal",
    "lat": "36.24486",
    "lng": "37.71607"
  },
  {
    "country": "SY",
    "name": "Ra’s al ‘Ayn",
    "lat": "36.85034",
    "lng": "40.07055"
  },
  {
    "country": "SY",
    "name": "Rankūs",
    "lat": "33.75623",
    "lng": "36.3883"
  },
  {
    "country": "SY",
    "name": "Radjun",
    "lat": "36.67598",
    "lng": "36.66415"
  },
  {
    "country": "SY",
    "name": "Al Quţaylibīyah",
    "lat": "35.29203",
    "lng": "36.01592"
  },
  {
    "country": "SY",
    "name": "Qarqania",
    "lat": "36.13849",
    "lng": "36.61247"
  },
  {
    "country": "SY",
    "name": "Al Qaḩţānīyah",
    "lat": "37.029",
    "lng": "41.54596"
  },
  {
    "country": "SY",
    "name": "Qaţanā",
    "lat": "33.43757",
    "lng": "36.07888"
  },
  {
    "country": "SY",
    "name": "Qasţal Ma‘āf",
    "lat": "35.82439",
    "lng": "35.95193"
  },
  {
    "country": "SY",
    "name": "Jāsim",
    "lat": "32.99233",
    "lng": "36.06018"
  },
  {
    "country": "SY",
    "name": "Qārah",
    "lat": "34.15558",
    "lng": "36.74284"
  },
  {
    "country": "SY",
    "name": "Al Qamşīyah",
    "lat": "35.03357",
    "lng": "36.01455"
  },
  {
    "country": "SY",
    "name": "Qal‘at al Maḑīq",
    "lat": "35.41465",
    "lng": "36.39085"
  },
  {
    "country": "SY",
    "name": "Qadsayyā",
    "lat": "33.54832",
    "lng": "36.21563"
  },
  {
    "country": "SY",
    "name": "Nubl",
    "lat": "36.37867",
    "lng": "36.99294"
  },
  {
    "country": "SY",
    "name": "Nawá",
    "lat": "32.89044",
    "lng": "36.0399"
  },
  {
    "country": "SY",
    "name": "Al Muzayrīb",
    "lat": "32.71084",
    "lng": "36.02751"
  },
  {
    "country": "SY",
    "name": "Al Muzayri‘ah",
    "lat": "35.5318",
    "lng": "36.07003"
  },
  {
    "country": "SY",
    "name": "Al Jalā’",
    "lat": "34.63346",
    "lng": "40.84054"
  },
  {
    "country": "SY",
    "name": "Mūrak",
    "lat": "35.37615",
    "lng": "36.6897"
  },
  {
    "country": "SY",
    "name": "Mukharram al Fawqānī",
    "lat": "34.81521",
    "lng": "37.08677"
  },
  {
    "country": "SY",
    "name": "Muḩradah",
    "lat": "35.2479",
    "lng": "36.5725"
  },
  {
    "country": "SY",
    "name": "Muḩambal",
    "lat": "35.78735",
    "lng": "36.4721"
  },
  {
    "country": "SY",
    "name": "Mazra‘at Bayt Jinn",
    "lat": "33.32836",
    "lng": "35.92144"
  },
  {
    "country": "SY",
    "name": "Maşyāf",
    "lat": "35.0653",
    "lng": "36.3406"
  },
  {
    "country": "SY",
    "name": "Maskanah",
    "lat": "35.96577",
    "lng": "38.04165"
  },
  {
    "country": "SY",
    "name": "Mashtá al Ḩulw",
    "lat": "34.87462",
    "lng": "36.25099"
  },
  {
    "country": "SY",
    "name": "Mas‘adah",
    "lat": "33.23203",
    "lng": "35.75572"
  },
  {
    "country": "SY",
    "name": "Markadah",
    "lat": "35.74607",
    "lng": "40.75304"
  },
  {
    "country": "SY",
    "name": "Māri‘",
    "lat": "36.48259",
    "lng": "37.19709"
  },
  {
    "country": "SY",
    "name": "Manbij",
    "lat": "36.52815",
    "lng": "37.95495"
  },
  {
    "country": "SY",
    "name": "Ma‘lūlā",
    "lat": "33.84529",
    "lng": "36.54514"
  },
  {
    "country": "SY",
    "name": "Malaḩ",
    "lat": "32.50795",
    "lng": "36.85719"
  },
  {
    "country": "SY",
    "name": "Mahīn",
    "lat": "34.24168",
    "lng": "37.05843"
  },
  {
    "country": "SY",
    "name": "Ma‘dān",
    "lat": "35.7552",
    "lng": "39.59835"
  },
  {
    "country": "SY",
    "name": "Medaya",
    "lat": "33.69032",
    "lng": "36.10354"
  },
  {
    "country": "SY",
    "name": "Al Ma‘baţlī",
    "lat": "36.56246",
    "lng": "36.74292"
  },
  {
    "country": "SY",
    "name": "Ma‘arratmişrīn",
    "lat": "36.01152",
    "lng": "36.67183"
  },
  {
    "country": "SY",
    "name": "Ma‘arrat an Nu‘mān",
    "lat": "35.6483",
    "lng": "36.67693"
  },
  {
    "country": "SY",
    "name": "Kuwayris Sharqī",
    "lat": "36.16685",
    "lng": "37.53815"
  },
  {
    "country": "SY",
    "name": "Kurnāz",
    "lat": "35.38972",
    "lng": "36.48773"
  },
  {
    "country": "SY",
    "name": "Kinnsibbā",
    "lat": "35.7441",
    "lng": "36.164"
  },
  {
    "country": "SY",
    "name": "Rabī‘ah",
    "lat": "35.78656",
    "lng": "36.03825"
  },
  {
    "country": "SY",
    "name": "Khushām",
    "lat": "35.30088",
    "lng": "40.28916"
  },
  {
    "country": "SY",
    "name": "Khirbat Tīn Nūr",
    "lat": "34.70122",
    "lng": "36.55658"
  },
  {
    "country": "SY",
    "name": "Al Qabw",
    "lat": "34.84324",
    "lng": "36.45493"
  },
  {
    "country": "SY",
    "name": "Khirbat al Ma‘azzah",
    "lat": "34.80454",
    "lng": "36.00077"
  },
  {
    "country": "SY",
    "name": "Khirbat Ghazālah",
    "lat": "32.73376",
    "lng": "36.20455"
  },
  {
    "country": "SY",
    "name": "Khān Shaykhūn",
    "lat": "35.44208",
    "lng": "36.65095"
  },
  {
    "country": "SY",
    "name": "Khanāşir",
    "lat": "35.78159",
    "lng": "37.49919"
  },
  {
    "country": "SY",
    "name": "Khān Arnabah",
    "lat": "33.18378",
    "lng": "35.89158"
  },
  {
    "country": "SY",
    "name": "Al Khafsah",
    "lat": "36.2311",
    "lng": "38.02172"
  },
  {
    "country": "SY",
    "name": "Al Ghandūrah",
    "lat": "36.66945",
    "lng": "37.73251"
  },
  {
    "country": "SY",
    "name": "Kassab",
    "lat": "35.92639",
    "lng": "35.9897"
  },
  {
    "country": "SY",
    "name": "Ra’s al Khashūfah",
    "lat": "34.82653",
    "lng": "36.05167"
  },
  {
    "country": "SY",
    "name": "Al Karīmah",
    "lat": "34.66941",
    "lng": "36.07546"
  },
  {
    "country": "SY",
    "name": "Kafr Zaytā",
    "lat": "35.37425",
    "lng": "36.6033"
  },
  {
    "country": "SY",
    "name": "Kafr Takhārīm",
    "lat": "36.1168",
    "lng": "36.51522"
  },
  {
    "country": "SY",
    "name": "Kafranbel",
    "lat": "35.61376",
    "lng": "36.56449"
  },
  {
    "country": "SY",
    "name": "Kafr Lāhā",
    "lat": "34.89469",
    "lng": "36.49582"
  },
  {
    "country": "SY",
    "name": "Kafr Baţnā",
    "lat": "33.51168",
    "lng": "36.37273"
  },
  {
    "country": "SY",
    "name": "Kafr Şaghīr",
    "lat": "36.29264",
    "lng": "37.2559"
  },
  {
    "country": "SY",
    "name": "Junaynat Raslān",
    "lat": "34.92789",
    "lng": "36.124"
  },
  {
    "country": "SY",
    "name": "Jubb Ramlah",
    "lat": "35.20922",
    "lng": "36.43104"
  },
  {
    "country": "SY",
    "name": "Jubb al Jarrāḩ",
    "lat": "34.83444",
    "lng": "37.32396"
  },
  {
    "country": "SY",
    "name": "Al Jīzah",
    "lat": "32.56909",
    "lng": "36.31551"
  },
  {
    "country": "SY",
    "name": "Jisr ash Shughūr",
    "lat": "35.81418",
    "lng": "36.31983"
  },
  {
    "country": "SY",
    "name": "Jayrūd",
    "lat": "33.80709",
    "lng": "36.73861"
  },
  {
    "country": "SY",
    "name": "Jawbat Burghāl",
    "lat": "35.48995",
    "lng": "36.17473"
  },
  {
    "country": "SY",
    "name": "Tchoban Bey",
    "lat": "36.61182",
    "lng": "37.4478"
  },
  {
    "country": "SY",
    "name": "Al Jarnīyah",
    "lat": "36.16054",
    "lng": "38.23337"
  },
  {
    "country": "SY",
    "name": "Jaramānā",
    "lat": "33.4862",
    "lng": "36.34614"
  },
  {
    "country": "SY",
    "name": "Jarābulus",
    "lat": "36.8175",
    "lng": "38.01111"
  },
  {
    "country": "SY",
    "name": "Jindayris",
    "lat": "36.39496",
    "lng": "36.6889"
  },
  {
    "country": "SY",
    "name": "Jablah",
    "lat": "35.36211",
    "lng": "35.92759"
  },
  {
    "country": "SY",
    "name": "Izra‘",
    "lat": "32.8706",
    "lng": "36.25453"
  },
  {
    "country": "SY",
    "name": "‘Irbīn",
    "lat": "33.53719",
    "lng": "36.36635"
  },
  {
    "country": "SY",
    "name": "Inkhil",
    "lat": "33.01809",
    "lng": "36.12828"
  },
  {
    "country": "SY",
    "name": "Idlib",
    "lat": "35.93062",
    "lng": "36.63393"
  },
  {
    "country": "SY",
    "name": "Hisya",
    "lat": "34.41197",
    "lng": "36.75867"
  },
  {
    "country": "SY",
    "name": "Ḩīsh",
    "lat": "35.54793",
    "lng": "36.64356"
  },
  {
    "country": "SY",
    "name": "Homs",
    "lat": "34.72682",
    "lng": "36.72339"
  },
  {
    "country": "SY",
    "name": "Ḩimmīn",
    "lat": "34.90035",
    "lng": "36.0401"
  },
  {
    "country": "SY",
    "name": "Ḩarrān al ‘Awāmīd",
    "lat": "33.44885",
    "lng": "36.56001"
  },
  {
    "country": "SY",
    "name": "Ḩuraytān",
    "lat": "36.28861",
    "lng": "37.08527"
  },
  {
    "country": "SY",
    "name": "Ḩārim",
    "lat": "36.21176",
    "lng": "36.52078"
  },
  {
    "country": "SY",
    "name": "Ḩarf al Musaytirah",
    "lat": "35.38808",
    "lng": "36.13439"
  },
  {
    "country": "SY",
    "name": "Ḩarbinafsah",
    "lat": "34.93745",
    "lng": "36.62243"
  },
  {
    "country": "SY",
    "name": "Ḩarastā",
    "lat": "33.55869",
    "lng": "36.36515"
  },
  {
    "country": "SY",
    "name": "Ḩammām Wāşil",
    "lat": "35.07437",
    "lng": "36.08677"
  },
  {
    "country": "SY",
    "name": "Ḩamāh",
    "lat": "35.13179",
    "lng": "36.75783"
  },
  {
    "country": "SY",
    "name": "Ḩalfāyā",
    "lat": "35.26014",
    "lng": "36.60581"
  },
  {
    "country": "SY",
    "name": "Aleppo",
    "lat": "36.20124",
    "lng": "37.16117"
  },
  {
    "country": "SY",
    "name": "Ḩadīdah",
    "lat": "34.67337",
    "lng": "36.39734"
  },
  {
    "country": "SY",
    "name": "Al Ḩāḑir",
    "lat": "35.99024",
    "lng": "37.05086"
  },
  {
    "country": "SY",
    "name": "Ghabāghib",
    "lat": "33.18235",
    "lng": "36.22534"
  },
  {
    "country": "SY",
    "name": "Al Furqlus",
    "lat": "34.60638",
    "lng": "37.08745"
  },
  {
    "country": "SY",
    "name": "Fīq",
    "lat": "32.77935",
    "lng": "35.70032"
  },
  {
    "country": "SY",
    "name": "Al Fākhūrah",
    "lat": "35.49846",
    "lng": "36.00955"
  },
  {
    "country": "SY",
    "name": "Duwayr Raslān",
    "lat": "34.9491",
    "lng": "36.18179"
  },
  {
    "country": "SY",
    "name": "Ad Duraykīsh",
    "lat": "34.89514",
    "lng": "36.14303"
  },
  {
    "country": "SY",
    "name": "Aḑ Ḑumayr",
    "lat": "33.64389",
    "lng": "36.69376"
  },
  {
    "country": "SY",
    "name": "Douma",
    "lat": "33.57175",
    "lng": "36.4027"
  },
  {
    "country": "SY",
    "name": "Damascus",
    "lat": "33.5102",
    "lng": "36.29128"
  },
  {
    "country": "SY",
    "name": "Dhībīn",
    "lat": "32.43842",
    "lng": "36.56551"
  },
  {
    "country": "SY",
    "name": "Dhībān",
    "lat": "35.01498",
    "lng": "40.51028"
  },
  {
    "country": "SY",
    "name": "Dayr Ḩāfir",
    "lat": "36.15694",
    "lng": "37.70778"
  },
  {
    "country": "SY",
    "name": "Deir ez-Zor",
    "lat": "35.33588",
    "lng": "40.14084"
  },
  {
    "country": "SY",
    "name": "Dayr ‘Aţīyah",
    "lat": "34.09541",
    "lng": "36.76791"
  },
  {
    "country": "SY",
    "name": "Dayr al ‘Aşāfīr",
    "lat": "33.46585",
    "lng": "36.42044"
  },
  {
    "country": "SY",
    "name": "Dārat ‘Izzah",
    "lat": "36.28247",
    "lng": "36.85216"
  },
  {
    "country": "SY",
    "name": "Darkūsh",
    "lat": "35.9918",
    "lng": "36.39361"
  },
  {
    "country": "SY",
    "name": "Ad Darbāsīyah",
    "lat": "37.07279",
    "lng": "40.65199"
  },
  {
    "country": "SY",
    "name": "Dārayyā",
    "lat": "33.45835",
    "lng": "36.23256"
  },
  {
    "country": "SY",
    "name": "Dar‘ā",
    "lat": "32.61889",
    "lng": "36.10213"
  },
  {
    "country": "SY",
    "name": "Dā‘il",
    "lat": "32.75466",
    "lng": "36.12958"
  },
  {
    "country": "SY",
    "name": "Buşrá ash Shām",
    "lat": "32.52013",
    "lng": "36.48256"
  },
  {
    "country": "SY",
    "name": "Bulbul",
    "lat": "36.76947",
    "lng": "36.81969"
  },
  {
    "country": "SY",
    "name": "Brummānat al Mashāyikh",
    "lat": "35.01883",
    "lng": "36.17083"
  },
  {
    "country": "SY",
    "name": "Bi’r al Ḩulw al Wardīyah",
    "lat": "36.69694",
    "lng": "41.03528"
  },
  {
    "country": "SY",
    "name": "Binnish",
    "lat": "35.95664",
    "lng": "36.7138"
  },
  {
    "country": "SY",
    "name": "Bdāmā",
    "lat": "35.81151",
    "lng": "36.19649"
  },
  {
    "country": "SY",
    "name": "Ar Rawḑah",
    "lat": "35.07204",
    "lng": "35.91375"
  },
  {
    "country": "SY",
    "name": "Barrī ash Sharqī",
    "lat": "34.98099",
    "lng": "37.20096"
  },
  {
    "country": "SY",
    "name": "Bāniyās",
    "lat": "35.18188",
    "lng": "35.94871"
  },
  {
    "country": "SY",
    "name": "Banān",
    "lat": "35.97358",
    "lng": "37.30234"
  },
  {
    "country": "SY",
    "name": "Babīlā",
    "lat": "33.47101",
    "lng": "36.33076"
  },
  {
    "country": "SY",
    "name": "Az Ziyārah",
    "lat": "35.68482",
    "lng": "36.33867"
  },
  {
    "country": "SY",
    "name": "Az Zarbah",
    "lat": "36.06771",
    "lng": "36.98012"
  },
  {
    "country": "SY",
    "name": "Az Zabadānī",
    "lat": "33.72488",
    "lng": "36.1005"
  },
  {
    "country": "SY",
    "name": "I‘zāz",
    "lat": "36.58662",
    "lng": "37.04628"
  },
  {
    "country": "SY",
    "name": "‘Ayn ‘Īsá",
    "lat": "36.3855",
    "lng": "38.86228"
  },
  {
    "country": "SY",
    "name": "‘Ayn at Tīnah",
    "lat": "35.56445",
    "lng": "36.10098"
  },
  {
    "country": "SY",
    "name": "Sabbah",
    "lat": "34.90292",
    "lng": "36.23711"
  },
  {
    "country": "SY",
    "name": "‘Ayn Shiqāq",
    "lat": "35.39441",
    "lng": "36.03012"
  },
  {
    "country": "SY",
    "name": "‘Ayn ash Sharqīyah",
    "lat": "35.33169",
    "lng": "36.09973"
  },
  {
    "country": "SY",
    "name": "‘Ayn al Fījah",
    "lat": "33.61529",
    "lng": "36.18285"
  },
  {
    "country": "SY",
    "name": "‘Ayn al Bayḑā",
    "lat": "35.65599",
    "lng": "35.88871"
  },
  {
    "country": "SY",
    "name": "‘Ayn al ‘Arab",
    "lat": "36.89095",
    "lng": "38.35347"
  },
  {
    "country": "SY",
    "name": "‘Awaj",
    "lat": "34.90704",
    "lng": "36.40444"
  },
  {
    "country": "SY",
    "name": "At Tibnī",
    "lat": "35.6117",
    "lng": "39.8181"
  },
  {
    "country": "SY",
    "name": "Aţ Ţawāḩīn",
    "lat": "35.12751",
    "lng": "36.21444"
  },
  {
    "country": "SY",
    "name": "At Tamāni‘ah",
    "lat": "35.45846",
    "lng": "36.74816"
  },
  {
    "country": "SY",
    "name": "At Tall",
    "lat": "33.61033",
    "lng": "36.3107"
  },
  {
    "country": "SY",
    "name": "Ath Thawrah",
    "lat": "35.83758",
    "lng": "38.54828"
  },
  {
    "country": "SY",
    "name": "As Suwaydā’",
    "lat": "32.70896",
    "lng": "36.56951"
  },
  {
    "country": "SY",
    "name": "As Sūsah",
    "lat": "34.53366",
    "lng": "40.95819"
  },
  {
    "country": "SY",
    "name": "As Sukhnah",
    "lat": "34.88533",
    "lng": "38.8711"
  },
  {
    "country": "SY",
    "name": "As Sīsnīyah",
    "lat": "34.78108",
    "lng": "36.14298"
  },
  {
    "country": "SY",
    "name": "Al Mazra‘ah",
    "lat": "32.78398",
    "lng": "36.47695"
  },
  {
    "country": "SY",
    "name": "As Sawdā",
    "lat": "34.98151",
    "lng": "35.94414"
  },
  {
    "country": "SY",
    "name": "Aş Şanamayn",
    "lat": "33.07186",
    "lng": "36.18316"
  },
  {
    "country": "SY",
    "name": "‘Assāl al Ward",
    "lat": "33.86453",
    "lng": "36.4139"
  },
  {
    "country": "SY",
    "name": "Aş Şafşāfah",
    "lat": "34.73481",
    "lng": "36.05318"
  },
  {
    "country": "SY",
    "name": "As Safīrah",
    "lat": "36.07696",
    "lng": "37.37251"
  },
  {
    "country": "SY",
    "name": "As Sabkhah",
    "lat": "35.81182",
    "lng": "39.26268"
  },
  {
    "country": "SY",
    "name": "As Si‘in",
    "lat": "35.26375",
    "lng": "37.37402"
  },
  {
    "country": "SY",
    "name": "Ash Shaykh Badr",
    "lat": "34.99174",
    "lng": "36.0835"
  },
  {
    "country": "SY",
    "name": "Ash Shajarah",
    "lat": "32.77411",
    "lng": "35.88202"
  },
  {
    "country": "SY",
    "name": "Ash Shaddādah",
    "lat": "36.05756",
    "lng": "40.73478"
  },
  {
    "country": "SY",
    "name": "Arwād",
    "lat": "34.85604",
    "lng": "35.85854"
  },
  {
    "country": "SY",
    "name": "Ar Ruḩaybah",
    "lat": "33.74424",
    "lng": "36.70394"
  },
  {
    "country": "SY",
    "name": "Ar Rastan",
    "lat": "34.92667",
    "lng": "36.73241"
  },
  {
    "country": "SY",
    "name": "Ar Raqqah",
    "lat": "35.95283",
    "lng": "39.00788"
  },
  {
    "country": "SY",
    "name": "Armanāz",
    "lat": "36.08363",
    "lng": "36.5031"
  },
  {
    "country": "SY",
    "name": "Arīḩā",
    "lat": "35.81374",
    "lng": "36.60964"
  },
  {
    "country": "SY",
    "name": "An Nashābīyah",
    "lat": "33.51051",
    "lng": "36.48569"
  },
  {
    "country": "SY",
    "name": "An Nabk",
    "lat": "34.02403",
    "lng": "36.72848"
  },
  {
    "country": "SY",
    "name": "Amude",
    "lat": "37.10417",
    "lng": "40.93"
  },
  {
    "country": "SY",
    "name": "Al Ghanţū",
    "lat": "34.82202",
    "lng": "36.69613"
  },
  {
    "country": "SY",
    "name": "Al Quţayfah",
    "lat": "33.73848",
    "lng": "36.60071"
  },
  {
    "country": "SY",
    "name": "Al Quşayr",
    "lat": "34.5078",
    "lng": "36.58029"
  },
  {
    "country": "SY",
    "name": "Al Qurayyā",
    "lat": "32.54337",
    "lng": "36.59776"
  },
  {
    "country": "SY",
    "name": "Al Qunayţirah",
    "lat": "33.12595",
    "lng": "35.82461"
  },
  {
    "country": "SY",
    "name": "Al Qaryatayn",
    "lat": "34.22956",
    "lng": "37.24066"
  },
  {
    "country": "SY",
    "name": "Al Qardāḩah",
    "lat": "35.45644",
    "lng": "36.05909"
  },
  {
    "country": "SY",
    "name": "Al Qāmishlī",
    "lat": "37.05215",
    "lng": "41.23142"
  },
  {
    "country": "SY",
    "name": "Al Qadmūs",
    "lat": "35.09855",
    "lng": "36.15984"
  },
  {
    "country": "SY",
    "name": "Al Mushannaf",
    "lat": "32.73931",
    "lng": "36.77473"
  },
  {
    "country": "SY",
    "name": "Al Musayfirah",
    "lat": "32.63205",
    "lng": "36.33934"
  },
  {
    "country": "SY",
    "name": "Al Mulayḩah",
    "lat": "33.48522",
    "lng": "36.37561"
  },
  {
    "country": "SY",
    "name": "Mismīyah",
    "lat": "33.12902",
    "lng": "36.39402"
  },
  {
    "country": "SY",
    "name": "Al Mayādīn",
    "lat": "35.01982",
    "lng": "40.45154"
  },
  {
    "country": "SY",
    "name": "Al Mālikīyah",
    "lat": "37.17701",
    "lng": "42.14006"
  },
  {
    "country": "SY",
    "name": "Al Buţayḩah",
    "lat": "32.90871",
    "lng": "35.63199"
  },
  {
    "country": "SY",
    "name": "Latakia",
    "lat": "35.53168",
    "lng": "35.79011"
  },
  {
    "country": "SY",
    "name": "Al Kiswah",
    "lat": "33.3581",
    "lng": "36.2419"
  },
  {
    "country": "SY",
    "name": "Al Khushnīyah",
    "lat": "32.99941",
    "lng": "35.81084"
  },
  {
    "country": "SY",
    "name": "An Nāşirah",
    "lat": "34.78769",
    "lng": "36.28559"
  },
  {
    "country": "SY",
    "name": "Al Jawādīyah",
    "lat": "36.9866",
    "lng": "41.82015"
  },
  {
    "country": "SY",
    "name": "Al Jānūdīyah",
    "lat": "35.88469",
    "lng": "36.29108"
  },
  {
    "country": "SY",
    "name": "Al Hinādī",
    "lat": "35.51324",
    "lng": "35.8744"
  },
  {
    "country": "SY",
    "name": "Al Ḩawl",
    "lat": "36.39042",
    "lng": "41.14983"
  },
  {
    "country": "SY",
    "name": "Al Ḩawāsh",
    "lat": "34.76004",
    "lng": "36.32127"
  },
  {
    "country": "SY",
    "name": "Al Ḩasakah",
    "lat": "36.50237",
    "lng": "40.74772"
  },
  {
    "country": "SY",
    "name": "Al Ḩarāk",
    "lat": "32.74932",
    "lng": "36.30994"
  },
  {
    "country": "SY",
    "name": "Al Ḩamrā’",
    "lat": "35.315",
    "lng": "37.08632"
  },
  {
    "country": "SY",
    "name": "Al Ḩamīdīyah",
    "lat": "34.71455",
    "lng": "35.95163"
  },
  {
    "country": "SY",
    "name": "Al Ḩājib",
    "lat": "35.86409",
    "lng": "37.3968"
  },
  {
    "country": "SY",
    "name": "Al Ḩaffah",
    "lat": "35.59824",
    "lng": "36.03006"
  },
  {
    "country": "SY",
    "name": "Al Ghizlānīyah",
    "lat": "33.39671",
    "lng": "36.45491"
  },
  {
    "country": "SY",
    "name": "Al Ghāriyah",
    "lat": "32.39332",
    "lng": "36.65067"
  },
  {
    "country": "SY",
    "name": "Al Buşayrah",
    "lat": "35.15618",
    "lng": "40.42716"
  },
  {
    "country": "SY",
    "name": "Al Bāriqīyah",
    "lat": "34.82924",
    "lng": "36.22863"
  },
  {
    "country": "SY",
    "name": "Al Bahlūlīyah",
    "lat": "35.63679",
    "lng": "35.96022"
  },
  {
    "country": "SY",
    "name": "Al Bāb",
    "lat": "36.37051",
    "lng": "37.5157"
  },
  {
    "country": "SY",
    "name": "Al Atārib",
    "lat": "36.13907",
    "lng": "36.82504"
  },
  {
    "country": "SY",
    "name": "Al ‘Ashārah",
    "lat": "34.92133",
    "lng": "40.56007"
  },
  {
    "country": "SY",
    "name": "Al ‘Arīmah",
    "lat": "36.47296",
    "lng": "37.72113"
  },
  {
    "country": "SY",
    "name": "Al ‘Annāzah",
    "lat": "35.19503",
    "lng": "36.06571"
  },
  {
    "country": "SY",
    "name": "Akhtarīn",
    "lat": "36.51072",
    "lng": "37.33571"
  },
  {
    "country": "SY",
    "name": "Iḩsim",
    "lat": "35.72078",
    "lng": "36.55631"
  },
  {
    "country": "SY",
    "name": "‘Afrīn",
    "lat": "36.51194",
    "lng": "36.86954"
  },
  {
    "country": "SY",
    "name": "Ad Dīmās",
    "lat": "33.58739",
    "lng": "36.09262"
  },
  {
    "country": "SY",
    "name": "Ad Dānā",
    "lat": "36.21254",
    "lng": "36.76998"
  },
  {
    "country": "SY",
    "name": "Ad Dālīyah",
    "lat": "35.23605",
    "lng": "36.14371"
  },
  {
    "country": "SY",
    "name": "Abū Qalqal",
    "lat": "36.43806",
    "lng": "38.11984"
  },
  {
    "country": "SY",
    "name": "Ālbū Kamāl",
    "lat": "34.45226",
    "lng": "40.91854"
  },
  {
    "country": "SY",
    "name": "Hajīn",
    "lat": "34.69508",
    "lng": "40.83138"
  },
  {
    "country": "SY",
    "name": "Abū az̧ Z̧uhūr",
    "lat": "35.74058",
    "lng": "37.0448"
  },
  {
    "country": "SY",
    "name": "Al Ya‘rubīyah",
    "lat": "36.81138",
    "lng": "42.06206"
  },
  {
    "country": "SY",
    "name": "‘Arīshah",
    "lat": "36.23154",
    "lng": "40.77214"
  },
  {
    "country": "SY",
    "name": "Kaff al-Jaa",
    "lat": "35.08638",
    "lng": "36.20605"
  },
  {
    "country": "SY",
    "name": "‘Ayn an Nasr",
    "lat": "34.84113",
    "lng": "36.92837"
  },
  {
    "country": "SY",
    "name": "Nāḩiyat as Sab‘ Biyār",
    "lat": "33.53228",
    "lng": "38.00818"
  },
  {
    "country": "SY",
    "name": "Al Kasrah",
    "lat": "35.56743",
    "lng": "39.9202"
  },
  {
    "country": "SY",
    "name": "Al Ḩajar al Aswad",
    "lat": "33.45759",
    "lng": "36.30419"
  },
  {
    "country": "SY",
    "name": "Al Manşūrah",
    "lat": "35.83917",
    "lng": "38.74288"
  },
  {
    "country": "SY",
    "name": "Bayt Yāshūţ",
    "lat": "35.31025",
    "lng": "36.11523"
  },
  {
    "country": "SY",
    "name": "Tremseh",
    "lat": "35.27181",
    "lng": "36.50395"
  },
  {
    "country": "SY",
    "name": "Qenterê",
    "lat": "36.5635",
    "lng": "36.72841"
  },
  {
    "country": "SZ",
    "name": "Tshaneni",
    "lat": "-25.98333",
    "lng": "31.71667"
  },
  {
    "country": "SZ",
    "name": "Siteki",
    "lat": "-26.4525",
    "lng": "31.94722"
  },
  {
    "country": "SZ",
    "name": "Sidvokodvo",
    "lat": "-26.6282",
    "lng": "31.42021"
  },
  {
    "country": "SZ",
    "name": "Piggs Peak",
    "lat": "-25.96082",
    "lng": "31.24666"
  },
  {
    "country": "SZ",
    "name": "Nsoko",
    "lat": "-27.03333",
    "lng": "31.95"
  },
  {
    "country": "SZ",
    "name": "Nhlangano",
    "lat": "-27.11222",
    "lng": "31.19833"
  },
  {
    "country": "SZ",
    "name": "Mhlume",
    "lat": "-26.03333",
    "lng": "31.85"
  },
  {
    "country": "SZ",
    "name": "Mhlambanyatsi",
    "lat": "-26.45",
    "lng": "31.01667"
  },
  {
    "country": "SZ",
    "name": "Mbabane",
    "lat": "-26.31667",
    "lng": "31.13333"
  },
  {
    "country": "SZ",
    "name": "Manzini",
    "lat": "-26.49884",
    "lng": "31.38004"
  },
  {
    "country": "SZ",
    "name": "Malkerns",
    "lat": "-26.56667",
    "lng": "31.18333"
  },
  {
    "country": "SZ",
    "name": "Lobamba",
    "lat": "-26.46667",
    "lng": "31.2"
  },
  {
    "country": "SZ",
    "name": "Lavumisa",
    "lat": "-27.31005",
    "lng": "31.89198"
  },
  {
    "country": "SZ",
    "name": "Kwaluseni",
    "lat": "-26.48333",
    "lng": "31.33333"
  },
  {
    "country": "SZ",
    "name": "Kubuta",
    "lat": "-26.88333",
    "lng": "31.48333"
  },
  {
    "country": "SZ",
    "name": "Hluti",
    "lat": "-27.21667",
    "lng": "31.61667"
  },
  {
    "country": "SZ",
    "name": "Hlatikulu",
    "lat": "-26.97917",
    "lng": "31.32444"
  },
  {
    "country": "SZ",
    "name": "Darkton",
    "lat": "-26.23333",
    "lng": "31.03333"
  },
  {
    "country": "SZ",
    "name": "Bulembu",
    "lat": "-25.96667",
    "lng": "31.13333"
  },
  {
    "country": "SZ",
    "name": "Big Bend",
    "lat": "-26.81667",
    "lng": "31.93333"
  },
  {
    "country": "SZ",
    "name": "Bhunya",
    "lat": "-26.55",
    "lng": "31.01667"
  },
  {
    "country": "SZ",
    "name": "Vuvulane",
    "lat": "-26.07427",
    "lng": "31.87672"
  },
  {
    "country": "SZ",
    "name": "Ntfonjeni",
    "lat": "-25.82659",
    "lng": "31.3273"
  },
  {
    "country": "TC",
    "name": "Cockburn Town",
    "lat": "21.46122",
    "lng": "-71.14188"
  },
  {
    "country": "TD",
    "name": "Iriba",
    "lat": "15.11667",
    "lng": "22.25"
  },
  {
    "country": "TD",
    "name": "Goz Béïda",
    "lat": "13.94563",
    "lng": "20.5468"
  },
  {
    "country": "TD",
    "name": "Goz Beïda",
    "lat": "12.22484",
    "lng": "21.41034"
  },
  {
    "country": "TD",
    "name": "Fada",
    "lat": "17.18535",
    "lng": "21.58114"
  },
  {
    "country": "TD",
    "name": "Biltine",
    "lat": "14.52791",
    "lng": "20.92749"
  },
  {
    "country": "TD",
    "name": "Am Timan",
    "lat": "11.0297",
    "lng": "20.2827"
  },
  {
    "country": "TD",
    "name": "Adré",
    "lat": "13.46648",
    "lng": "22.19875"
  },
  {
    "country": "TD",
    "name": "Abéché",
    "lat": "13.82916",
    "lng": "20.8324"
  },
  {
    "country": "TD",
    "name": "Sarh",
    "lat": "9.1429",
    "lng": "18.3923"
  },
  {
    "country": "TD",
    "name": "Pala",
    "lat": "9.3642",
    "lng": "14.9046"
  },
  {
    "country": "TD",
    "name": "Oum Hadjer",
    "lat": "13.2954",
    "lng": "19.6966"
  },
  {
    "country": "TD",
    "name": "Ngama",
    "lat": "11.78333",
    "lng": "17.16667"
  },
  {
    "country": "TD",
    "name": "N'Djamena",
    "lat": "12.10672",
    "lng": "15.0444"
  },
  {
    "country": "TD",
    "name": "Moussoro",
    "lat": "13.64143",
    "lng": "16.48941"
  },
  {
    "country": "TD",
    "name": "Moundou",
    "lat": "8.56667",
    "lng": "16.08333"
  },
  {
    "country": "TD",
    "name": "Mongo",
    "lat": "12.18441",
    "lng": "18.69303"
  },
  {
    "country": "TD",
    "name": "Moïssala",
    "lat": "8.3404",
    "lng": "17.7663"
  },
  {
    "country": "TD",
    "name": "Melfi",
    "lat": "11.0598",
    "lng": "17.9355"
  },
  {
    "country": "TD",
    "name": "Mboursou Léré",
    "lat": "9.7639",
    "lng": "14.1539"
  },
  {
    "country": "TD",
    "name": "Massenya",
    "lat": "11.4039",
    "lng": "16.1705"
  },
  {
    "country": "TD",
    "name": "Massakory",
    "lat": "12.996",
    "lng": "15.72927"
  },
  {
    "country": "TD",
    "name": "Massaguet",
    "lat": "12.47554",
    "lng": "15.43647"
  },
  {
    "country": "TD",
    "name": "Mao",
    "lat": "14.12116",
    "lng": "15.3103"
  },
  {
    "country": "TD",
    "name": "Laï",
    "lat": "9.3972",
    "lng": "16.30066"
  },
  {
    "country": "TD",
    "name": "Kyabé",
    "lat": "9.45149",
    "lng": "18.94493"
  },
  {
    "country": "TD",
    "name": "Koumra",
    "lat": "8.91256",
    "lng": "17.55392"
  },
  {
    "country": "TD",
    "name": "Kelo",
    "lat": "9.30859",
    "lng": "15.80658"
  },
  {
    "country": "TD",
    "name": "Guelendeng",
    "lat": "10.91762",
    "lng": "15.55011"
  },
  {
    "country": "TD",
    "name": "Gounou Gaya",
    "lat": "9.6294",
    "lng": "15.5132"
  },
  {
    "country": "TD",
    "name": "Goundi",
    "lat": "9.36267",
    "lng": "17.36597"
  },
  {
    "country": "TD",
    "name": "Faya-Largeau",
    "lat": "17.9257",
    "lng": "19.10428"
  },
  {
    "country": "TD",
    "name": "Dourbali",
    "lat": "11.80909",
    "lng": "15.86323"
  },
  {
    "country": "TD",
    "name": "Doba",
    "lat": "8.65",
    "lng": "16.85"
  },
  {
    "country": "TD",
    "name": "Bousso",
    "lat": "10.48473",
    "lng": "16.71076"
  },
  {
    "country": "TD",
    "name": "Bongor",
    "lat": "10.28056",
    "lng": "15.37222"
  },
  {
    "country": "TD",
    "name": "Bol",
    "lat": "13.45861",
    "lng": "14.71472"
  },
  {
    "country": "TD",
    "name": "Bokoro",
    "lat": "12.37813",
    "lng": "17.05876"
  },
  {
    "country": "TD",
    "name": "Bitkine",
    "lat": "11.9801",
    "lng": "18.2138"
  },
  {
    "country": "TD",
    "name": "Béré",
    "lat": "9.3202",
    "lng": "16.1552"
  },
  {
    "country": "TD",
    "name": "Benoy",
    "lat": "8.98327",
    "lng": "16.31991"
  },
  {
    "country": "TD",
    "name": "Beïnamar",
    "lat": "8.6698",
    "lng": "15.3813"
  },
  {
    "country": "TD",
    "name": "Béboto",
    "lat": "8.26681",
    "lng": "16.93898"
  },
  {
    "country": "TD",
    "name": "Bébédja",
    "lat": "8.6761",
    "lng": "16.566"
  },
  {
    "country": "TD",
    "name": "Bardaï",
    "lat": "21.35494",
    "lng": "17.00121"
  },
  {
    "country": "TD",
    "name": "Ati",
    "lat": "13.2154",
    "lng": "18.3353"
  },
  {
    "country": "TD",
    "name": "Aozou",
    "lat": "21.8375",
    "lng": "17.4275"
  },
  {
    "country": "TD",
    "name": "Am Djarass",
    "lat": "16.06589",
    "lng": "22.84308"
  },
  {
    "country": "TF",
    "name": "Port-aux-Français",
    "lat": "-49.34916",
    "lng": "70.21937"
  },
  {
    "country": "TG",
    "name": "Vogan",
    "lat": "6.33333",
    "lng": "1.53333"
  },
  {
    "country": "TG",
    "name": "Tsévié",
    "lat": "6.42611",
    "lng": "1.21333"
  },
  {
    "country": "TG",
    "name": "Tchamba",
    "lat": "9.03333",
    "lng": "1.41667"
  },
  {
    "country": "TG",
    "name": "Tabligbo",
    "lat": "6.58333",
    "lng": "1.5"
  },
  {
    "country": "TG",
    "name": "Sotouboua",
    "lat": "8.5634",
    "lng": "0.98399"
  },
  {
    "country": "TG",
    "name": "Sokodé",
    "lat": "8.98333",
    "lng": "1.13333"
  },
  {
    "country": "TG",
    "name": "Notsé",
    "lat": "6.95",
    "lng": "1.16667"
  },
  {
    "country": "TG",
    "name": "Niamtougou",
    "lat": "9.76806",
    "lng": "1.10528"
  },
  {
    "country": "TG",
    "name": "Sansanné-Mango",
    "lat": "10.35917",
    "lng": "0.47083"
  },
  {
    "country": "TG",
    "name": "Lomé",
    "lat": "6.12874",
    "lng": "1.22154"
  },
  {
    "country": "TG",
    "name": "Kpalimé",
    "lat": "6.9",
    "lng": "0.63333"
  },
  {
    "country": "TG",
    "name": "Pagouda",
    "lat": "9.7525",
    "lng": "1.32778"
  },
  {
    "country": "TG",
    "name": "Kara",
    "lat": "9.55111",
    "lng": "1.18611"
  },
  {
    "country": "TG",
    "name": "Kandé",
    "lat": "9.95778",
    "lng": "1.04472"
  },
  {
    "country": "TG",
    "name": "Dapaong",
    "lat": "10.86225",
    "lng": "0.20762"
  },
  {
    "country": "TG",
    "name": "Bassar",
    "lat": "9.25025",
    "lng": "0.78213"
  },
  {
    "country": "TG",
    "name": "Bafilo",
    "lat": "9.35",
    "lng": "1.26667"
  },
  {
    "country": "TG",
    "name": "Badou",
    "lat": "7.58333",
    "lng": "0.6"
  },
  {
    "country": "TG",
    "name": "Atakpamé",
    "lat": "7.53333",
    "lng": "1.13333"
  },
  {
    "country": "TG",
    "name": "Aného",
    "lat": "6.22798",
    "lng": "1.5919"
  },
  {
    "country": "TG",
    "name": "Amlamé",
    "lat": "7.46667",
    "lng": "0.9"
  },
  {
    "country": "TH",
    "name": "Don Sak",
    "lat": "9.31676",
    "lng": "99.69184"
  },
  {
    "country": "TH",
    "name": "Thung Sai",
    "lat": "16.31489",
    "lng": "99.83267"
  },
  {
    "country": "TH",
    "name": "Tham Phannara",
    "lat": "8.42045",
    "lng": "99.39517"
  },
  {
    "country": "TH",
    "name": "Ban Talat Yai",
    "lat": "7.88481",
    "lng": "98.40008"
  },
  {
    "country": "TH",
    "name": "Ban Talat Nua",
    "lat": "7.88489",
    "lng": "98.38557"
  },
  {
    "country": "TH",
    "name": "Sam Roi Yot",
    "lat": "12.27081",
    "lng": "99.87203"
  },
  {
    "country": "TH",
    "name": "Nopphitam",
    "lat": "8.72206",
    "lng": "99.74878"
  },
  {
    "country": "TH",
    "name": "Lam Thap",
    "lat": "8.07228",
    "lng": "99.29225"
  },
  {
    "country": "TH",
    "name": "Ban Huai I Huak",
    "lat": "18.07861",
    "lng": "98.035"
  },
  {
    "country": "TH",
    "name": "Phrao",
    "lat": "19.36586",
    "lng": "99.20187"
  },
  {
    "country": "TH",
    "name": "Mae Taeng",
    "lat": "19.11712",
    "lng": "98.94176"
  },
  {
    "country": "TH",
    "name": "Mae Ai",
    "lat": "20.02883",
    "lng": "99.29833"
  },
  {
    "country": "TH",
    "name": "Phetchaburi",
    "lat": "13.11189",
    "lng": "99.94467"
  },
  {
    "country": "TH",
    "name": "Mae Chai",
    "lat": "19.34597",
    "lng": "99.814"
  },
  {
    "country": "TH",
    "name": "Yan Ta Khao",
    "lat": "7.38622",
    "lng": "99.66692"
  },
  {
    "country": "TH",
    "name": "Wiang Sa",
    "lat": "8.63585",
    "lng": "99.3666"
  },
  {
    "country": "TH",
    "name": "Wiang Pa Pao",
    "lat": "19.34778",
    "lng": "99.50722"
  },
  {
    "country": "TH",
    "name": "Wiang Haeng",
    "lat": "19.557",
    "lng": "98.6425"
  },
  {
    "country": "TH",
    "name": "Wiang Chai",
    "lat": "19.88361",
    "lng": "99.93314"
  },
  {
    "country": "TH",
    "name": "Wat Phleng",
    "lat": "13.45407",
    "lng": "99.88637"
  },
  {
    "country": "TH",
    "name": "Wang Wiset",
    "lat": "7.73631",
    "lng": "99.3987"
  },
  {
    "country": "TH",
    "name": "Wang Nuea",
    "lat": "19.14678",
    "lng": "99.61933"
  },
  {
    "country": "TH",
    "name": "U Thong",
    "lat": "14.37514",
    "lng": "99.89225"
  },
  {
    "country": "TH",
    "name": "Umphang",
    "lat": "16.01622",
    "lng": "98.8627"
  },
  {
    "country": "TH",
    "name": "Trang",
    "lat": "7.55633",
    "lng": "99.61141"
  },
  {
    "country": "TH",
    "name": "Thung Yai",
    "lat": "8.30119",
    "lng": "99.36611"
  },
  {
    "country": "TH",
    "name": "Thung Tako",
    "lat": "10.11022",
    "lng": "99.08306"
  },
  {
    "country": "TH",
    "name": "Thung Song",
    "lat": "8.16453",
    "lng": "99.68039"
  },
  {
    "country": "TH",
    "name": "Thung Saliam",
    "lat": "17.32106",
    "lng": "99.56092"
  },
  {
    "country": "TH",
    "name": "Thong Pha Phum",
    "lat": "14.74345",
    "lng": "98.63101"
  },
  {
    "country": "TH",
    "name": "Thoen",
    "lat": "17.61289",
    "lng": "99.21612"
  },
  {
    "country": "TH",
    "name": "Tha Song Yang",
    "lat": "17.22708",
    "lng": "98.22572"
  },
  {
    "country": "TH",
    "name": "Tha Sala",
    "lat": "8.66733",
    "lng": "99.93078"
  },
  {
    "country": "TH",
    "name": "Tha Sae",
    "lat": "10.66461",
    "lng": "99.17281"
  },
  {
    "country": "TH",
    "name": "Thap Than",
    "lat": "15.46063",
    "lng": "99.89166"
  },
  {
    "country": "TH",
    "name": "Thap Sakae",
    "lat": "11.49964",
    "lng": "99.6217"
  },
  {
    "country": "TH",
    "name": "Thap Put",
    "lat": "8.51625",
    "lng": "98.63972"
  },
  {
    "country": "TH",
    "name": "Tha Phae",
    "lat": "6.79014",
    "lng": "99.97005"
  },
  {
    "country": "TH",
    "name": "Tha Muang",
    "lat": "13.96118",
    "lng": "99.64122"
  },
  {
    "country": "TH",
    "name": "Tha Maka",
    "lat": "13.9",
    "lng": "99.76667"
  },
  {
    "country": "TH",
    "name": "Thalang",
    "lat": "8.03169",
    "lng": "98.33408"
  },
  {
    "country": "TH",
    "name": "Thai Mueang",
    "lat": "8.39914",
    "lng": "98.26061"
  },
  {
    "country": "TH",
    "name": "Tha Chang",
    "lat": "9.26418",
    "lng": "99.19218"
  },
  {
    "country": "TH",
    "name": "Tha Chana",
    "lat": "9.57203",
    "lng": "99.16586"
  },
  {
    "country": "TH",
    "name": "Takua Thung",
    "lat": "8.38373",
    "lng": "98.45123"
  },
  {
    "country": "TH",
    "name": "Takua Pa",
    "lat": "8.8705",
    "lng": "98.34383"
  },
  {
    "country": "TH",
    "name": "Tak",
    "lat": "16.86968",
    "lng": "99.12898"
  },
  {
    "country": "TH",
    "name": "Surat Thani",
    "lat": "9.14011",
    "lng": "99.33311"
  },
  {
    "country": "TH",
    "name": "Sukhothai",
    "lat": "17.00778",
    "lng": "99.823"
  },
  {
    "country": "TH",
    "name": "Suan Phueng",
    "lat": "13.5429",
    "lng": "99.33961"
  },
  {
    "country": "TH",
    "name": "Sop Prap",
    "lat": "17.88053",
    "lng": "99.337"
  },
  {
    "country": "TH",
    "name": "Soem Ngam",
    "lat": "18.06506",
    "lng": "99.24537"
  },
  {
    "country": "TH",
    "name": "Si Sawat",
    "lat": "14.59922",
    "lng": "99.11406"
  },
  {
    "country": "TH",
    "name": "Si Satchanalai",
    "lat": "17.51692",
    "lng": "99.75978"
  },
  {
    "country": "TH",
    "name": "Si Samrong",
    "lat": "17.164",
    "lng": "99.86222"
  },
  {
    "country": "TH",
    "name": "Si Nakhon",
    "lat": "17.34907",
    "lng": "99.98563"
  },
  {
    "country": "TH",
    "name": "Sikao",
    "lat": "7.57158",
    "lng": "99.34494"
  },
  {
    "country": "TH",
    "name": "Si Banphot",
    "lat": "7.72136",
    "lng": "99.8843"
  },
  {
    "country": "TH",
    "name": "Sawi",
    "lat": "10.23668",
    "lng": "99.10938"
  },
  {
    "country": "TH",
    "name": "Sawankhalok",
    "lat": "17.31597",
    "lng": "99.83186"
  },
  {
    "country": "TH",
    "name": "Sawang Arom",
    "lat": "15.58394",
    "lng": "99.86089"
  },
  {
    "country": "TH",
    "name": "Saraphi",
    "lat": "18.71417",
    "lng": "99.03528"
  },
  {
    "country": "TH",
    "name": "San Sai",
    "lat": "18.84792",
    "lng": "99.04508"
  },
  {
    "country": "TH",
    "name": "San Pa Tong",
    "lat": "18.62828",
    "lng": "98.89572"
  },
  {
    "country": "TH",
    "name": "San Kamphaeng",
    "lat": "18.74486",
    "lng": "99.11953"
  },
  {
    "country": "TH",
    "name": "Sangkhla Buri",
    "lat": "15.15553",
    "lng": "98.45361"
  },
  {
    "country": "TH",
    "name": "Samoeng",
    "lat": "18.84806",
    "lng": "98.73242"
  },
  {
    "country": "TH",
    "name": "Sam Ngao",
    "lat": "17.24331",
    "lng": "99.02256"
  },
  {
    "country": "TH",
    "name": "Sai Yok",
    "lat": "14.11899",
    "lng": "99.142"
  },
  {
    "country": "TH",
    "name": "Sai Ngam",
    "lat": "16.46862",
    "lng": "99.88843"
  },
  {
    "country": "TH",
    "name": "Ron Phibun",
    "lat": "8.17911",
    "lng": "99.85425"
  },
  {
    "country": "TH",
    "name": "Ratchaburi",
    "lat": "13.53671",
    "lng": "99.81712"
  },
  {
    "country": "TH",
    "name": "Ranong",
    "lat": "9.96583",
    "lng": "98.63476"
  },
  {
    "country": "TH",
    "name": "Pran Buri",
    "lat": "12.38487",
    "lng": "99.90157"
  },
  {
    "country": "TH",
    "name": "Prachuap Khiri Khan",
    "lat": "11.82098",
    "lng": "99.7841"
  },
  {
    "country": "TH",
    "name": "Plai Phraya",
    "lat": "8.53278",
    "lng": "98.8637"
  },
  {
    "country": "TH",
    "name": "Tha Kham",
    "lat": "9.11072",
    "lng": "99.23208"
  },
  {
    "country": "TH",
    "name": "Phuket",
    "lat": "7.89059",
    "lng": "98.3981"
  },
  {
    "country": "TH",
    "name": "Phrom Khiri",
    "lat": "8.52333",
    "lng": "99.82275"
  },
  {
    "country": "TH",
    "name": "Phrasaeng",
    "lat": "8.56781",
    "lng": "99.24756"
  },
  {
    "country": "TH",
    "name": "Phran Kratai",
    "lat": "16.66511",
    "lng": "99.58894"
  },
  {
    "country": "TH",
    "name": "Photharam",
    "lat": "13.69234",
    "lng": "99.84969"
  },
  {
    "country": "TH",
    "name": "Phop Phra",
    "lat": "16.38461",
    "lng": "98.69028"
  },
  {
    "country": "TH",
    "name": "Phipun",
    "lat": "8.56036",
    "lng": "99.60703"
  },
  {
    "country": "TH",
    "name": "Phayao",
    "lat": "19.19203",
    "lng": "99.87883"
  },
  {
    "country": "TH",
    "name": "Phato",
    "lat": "9.79089",
    "lng": "98.77658"
  },
  {
    "country": "TH",
    "name": "Phanom Thuan",
    "lat": "14.13031",
    "lng": "99.69858"
  },
  {
    "country": "TH",
    "name": "Phanom",
    "lat": "8.85475",
    "lng": "98.81267"
  },
  {
    "country": "TH",
    "name": "Phang Nga",
    "lat": "8.45091",
    "lng": "98.52985"
  },
  {
    "country": "TH",
    "name": "Phan",
    "lat": "19.55395",
    "lng": "99.74045"
  },
  {
    "country": "TH",
    "name": "Pathio",
    "lat": "10.70908",
    "lng": "99.3182"
  },
  {
    "country": "TH",
    "name": "Pa Sang",
    "lat": "18.52617",
    "lng": "98.93936"
  },
  {
    "country": "TH",
    "name": "Palian",
    "lat": "7.17237",
    "lng": "99.68624"
  },
  {
    "country": "TH",
    "name": "Pak Tho",
    "lat": "13.37263",
    "lng": "99.83938"
  },
  {
    "country": "TH",
    "name": "Pai",
    "lat": "19.36168",
    "lng": "98.43973"
  },
  {
    "country": "TH",
    "name": "Om Koi",
    "lat": "17.80122",
    "lng": "98.35933"
  },
  {
    "country": "TH",
    "name": "Nong Ya Plong",
    "lat": "13.16288",
    "lng": "99.69723"
  },
  {
    "country": "TH",
    "name": "Nong Kha Yang",
    "lat": "15.364",
    "lng": "99.92939"
  },
  {
    "country": "TH",
    "name": "Nong Chang",
    "lat": "15.39147",
    "lng": "99.84147"
  },
  {
    "country": "TH",
    "name": "Ngao",
    "lat": "18.75678",
    "lng": "99.97814"
  },
  {
    "country": "TH",
    "name": "Nakhon Si Thammarat",
    "lat": "8.43333",
    "lng": "99.96667"
  },
  {
    "country": "TH",
    "name": "Na Bon",
    "lat": "8.26167",
    "lng": "99.59472"
  },
  {
    "country": "TH",
    "name": "Mueang Pan",
    "lat": "18.76803",
    "lng": "99.5025"
  },
  {
    "country": "TH",
    "name": "Mae Tha",
    "lat": "18.46456",
    "lng": "99.14026"
  },
  {
    "country": "TH",
    "name": "Mae Tha",
    "lat": "18.13411",
    "lng": "99.51389"
  },
  {
    "country": "TH",
    "name": "Mae Suai",
    "lat": "19.65633",
    "lng": "99.54367"
  },
  {
    "country": "TH",
    "name": "Mae Sot",
    "lat": "16.71667",
    "lng": "98.56667"
  },
  {
    "country": "TH",
    "name": "Mae Sai",
    "lat": "20.43353",
    "lng": "99.87617"
  },
  {
    "country": "TH",
    "name": "Mae Ramat",
    "lat": "16.98403",
    "lng": "98.51665"
  },
  {
    "country": "TH",
    "name": "Mae Phrik",
    "lat": "17.44688",
    "lng": "99.1142"
  },
  {
    "country": "TH",
    "name": "Mae Mo",
    "lat": "18.27561",
    "lng": "99.65045"
  },
  {
    "country": "TH",
    "name": "Mae La Noi",
    "lat": "18.38181",
    "lng": "97.94372"
  },
  {
    "country": "TH",
    "name": "Mae Hong Son",
    "lat": "19.30029",
    "lng": "97.96852"
  },
  {
    "country": "TH",
    "name": "Mae Chan",
    "lat": "20.14675",
    "lng": "99.85256"
  },
  {
    "country": "TH",
    "name": "Mae Chaem",
    "lat": "18.49926",
    "lng": "98.36494"
  },
  {
    "country": "TH",
    "name": "Long",
    "lat": "18.07422",
    "lng": "99.83073"
  },
  {
    "country": "TH",
    "name": "Li",
    "lat": "17.80269",
    "lng": "98.95097"
  },
  {
    "country": "TH",
    "name": "La-Un",
    "lat": "10.11646",
    "lng": "98.75"
  },
  {
    "country": "TH",
    "name": "Lat Yao",
    "lat": "15.751",
    "lng": "99.78925"
  },
  {
    "country": "TH",
    "name": "Lao Khwan",
    "lat": "14.59522",
    "lng": "99.77431"
  },
  {
    "country": "TH",
    "name": "Lan Saka",
    "lat": "8.37097",
    "lng": "99.80564"
  },
  {
    "country": "TH",
    "name": "Lan Sak",
    "lat": "15.45289",
    "lng": "99.57606"
  },
  {
    "country": "TH",
    "name": "Lan Krabue",
    "lat": "16.60003",
    "lng": "99.84889"
  },
  {
    "country": "TH",
    "name": "La-ngu",
    "lat": "6.88492",
    "lng": "99.78836"
  },
  {
    "country": "TH",
    "name": "Lang Suan",
    "lat": "9.94561",
    "lng": "99.07847"
  },
  {
    "country": "TH",
    "name": "Lamphun",
    "lat": "18.58054",
    "lng": "99.00745"
  },
  {
    "country": "TH",
    "name": "Lampang",
    "lat": "18.29232",
    "lng": "99.49277"
  },
  {
    "country": "TH",
    "name": "Lamae",
    "lat": "9.76789",
    "lng": "99.09256"
  },
  {
    "country": "TH",
    "name": "Kui Buri",
    "lat": "12.08283",
    "lng": "99.85431"
  },
  {
    "country": "TH",
    "name": "Kra Buri",
    "lat": "10.40429",
    "lng": "98.77266"
  },
  {
    "country": "TH",
    "name": "Krabi",
    "lat": "8.07257",
    "lng": "98.91052"
  },
  {
    "country": "TH",
    "name": "Ko Yao",
    "lat": "8.11013",
    "lng": "98.59231"
  },
  {
    "country": "TH",
    "name": "Kong Ra",
    "lat": "7.40272",
    "lng": "99.94972"
  },
  {
    "country": "TH",
    "name": "Kong Krailat",
    "lat": "16.95197",
    "lng": "99.97769"
  },
  {
    "country": "TH",
    "name": "Ko Lanta",
    "lat": "7.53362",
    "lng": "99.08647"
  },
  {
    "country": "TH",
    "name": "Ko Kha",
    "lat": "18.19225",
    "lng": "99.39433"
  },
  {
    "country": "TH",
    "name": "Khura Buri",
    "lat": "9.19397",
    "lng": "98.41514"
  },
  {
    "country": "TH",
    "name": "Khun Yuam",
    "lat": "18.82958",
    "lng": "97.93347"
  },
  {
    "country": "TH",
    "name": "Khlong Thom",
    "lat": "7.9375",
    "lng": "99.14457"
  },
  {
    "country": "TH",
    "name": "Khlong Lan",
    "lat": "16.20331",
    "lng": "99.31997"
  },
  {
    "country": "TH",
    "name": "Khlong Khlung",
    "lat": "16.21633",
    "lng": "99.71906"
  },
  {
    "country": "TH",
    "name": "Tha Khanon",
    "lat": "9.0302",
    "lng": "98.95286"
  },
  {
    "country": "TH",
    "name": "Khiri Mat",
    "lat": "16.83333",
    "lng": "99.8"
  },
  {
    "country": "TH",
    "name": "Khian Sa",
    "lat": "8.84295",
    "lng": "99.19856"
  },
  {
    "country": "TH",
    "name": "Khao Yoi",
    "lat": "13.24025",
    "lng": "99.82428"
  },
  {
    "country": "TH",
    "name": "Khao Phanom",
    "lat": "8.26549",
    "lng": "99.05124"
  },
  {
    "country": "TH",
    "name": "Khanu Woralaksaburi",
    "lat": "16.0617",
    "lng": "99.86058"
  },
  {
    "country": "TH",
    "name": "Kathu",
    "lat": "7.91779",
    "lng": "98.33322"
  },
  {
    "country": "TH",
    "name": "Kapong",
    "lat": "8.69697",
    "lng": "98.40914"
  },
  {
    "country": "TH",
    "name": "Kapoe",
    "lat": "9.58522",
    "lng": "98.59611"
  },
  {
    "country": "TH",
    "name": "Kantang",
    "lat": "7.40542",
    "lng": "99.51561"
  },
  {
    "country": "TH",
    "name": "Kanchanadit",
    "lat": "9.16611",
    "lng": "99.47014"
  },
  {
    "country": "TH",
    "name": "Kanchanaburi",
    "lat": "14.00412",
    "lng": "99.54832"
  },
  {
    "country": "TH",
    "name": "Kamphaeng Phet",
    "lat": "16.48344",
    "lng": "99.52153"
  },
  {
    "country": "TH",
    "name": "Huai Yot",
    "lat": "7.78937",
    "lng": "99.63469"
  },
  {
    "country": "TH",
    "name": "Huai Khot",
    "lat": "15.29095",
    "lng": "99.61661"
  },
  {
    "country": "TH",
    "name": "Hua Hin",
    "lat": "12.57065",
    "lng": "99.95876"
  },
  {
    "country": "TH",
    "name": "Hot",
    "lat": "18.19317",
    "lng": "98.61039"
  },
  {
    "country": "TH",
    "name": "Hang Dong",
    "lat": "18.68703",
    "lng": "98.91939"
  },
  {
    "country": "TH",
    "name": "Hang Chat",
    "lat": "18.32883",
    "lng": "99.34621"
  },
  {
    "country": "TH",
    "name": "Fang",
    "lat": "19.91689",
    "lng": "99.2145"
  },
  {
    "country": "TH",
    "name": "Dok Kham Tai",
    "lat": "19.16242",
    "lng": "99.99342"
  },
  {
    "country": "TH",
    "name": "Doi Tao",
    "lat": "17.95286",
    "lng": "98.68458"
  },
  {
    "country": "TH",
    "name": "Dan Chang",
    "lat": "14.84183",
    "lng": "99.69756"
  },
  {
    "country": "TH",
    "name": "Damnoen Saduak",
    "lat": "13.51825",
    "lng": "99.95469"
  },
  {
    "country": "TH",
    "name": "Chumphon",
    "lat": "10.4957",
    "lng": "99.17971"
  },
  {
    "country": "TH",
    "name": "Chom Thong",
    "lat": "18.41742",
    "lng": "98.67428"
  },
  {
    "country": "TH",
    "name": "Chom Bueng",
    "lat": "13.62",
    "lng": "99.59169"
  },
  {
    "country": "TH",
    "name": "Chiang Rai",
    "lat": "19.90858",
    "lng": "99.8325"
  },
  {
    "country": "TH",
    "name": "Chiang Mai",
    "lat": "18.79038",
    "lng": "98.98468"
  },
  {
    "country": "TH",
    "name": "Chiang Dao",
    "lat": "19.36542",
    "lng": "98.96453"
  },
  {
    "country": "TH",
    "name": "Chawang",
    "lat": "8.42614",
    "lng": "99.50472"
  },
  {
    "country": "TH",
    "name": "Chaiya",
    "lat": "9.38625",
    "lng": "99.19861"
  },
  {
    "country": "TH",
    "name": "Chai Buri",
    "lat": "8.46222",
    "lng": "99.07631"
  },
  {
    "country": "TH",
    "name": "Chae Hom",
    "lat": "18.71267",
    "lng": "99.55758"
  },
  {
    "country": "TH",
    "name": "Cha-am",
    "lat": "12.8",
    "lng": "99.96667"
  },
  {
    "country": "TH",
    "name": "Bo Phloi",
    "lat": "14.32517",
    "lng": "99.51467"
  },
  {
    "country": "TH",
    "name": "Wiang Nuea",
    "lat": "19.37972",
    "lng": "98.44644"
  },
  {
    "country": "TH",
    "name": "Wang Chin",
    "lat": "17.8802",
    "lng": "99.6105"
  },
  {
    "country": "TH",
    "name": "Wang Chao",
    "lat": "16.67441",
    "lng": "99.26903"
  },
  {
    "country": "TH",
    "name": "Thung Wa",
    "lat": "7.10957",
    "lng": "99.75586"
  },
  {
    "country": "TH",
    "name": "Thung Hua Chang",
    "lat": "18.00301",
    "lng": "99.0278"
  },
  {
    "country": "TH",
    "name": "Tha Maka",
    "lat": "13.92081",
    "lng": "99.76553"
  },
  {
    "country": "TH",
    "name": "Ban Tak",
    "lat": "17.04325",
    "lng": "99.08128"
  },
  {
    "country": "TH",
    "name": "Ko Samui",
    "lat": "9.53567",
    "lng": "99.93567"
  },
  {
    "country": "TH",
    "name": "Rawai",
    "lat": "7.77965",
    "lng": "98.32532"
  },
  {
    "country": "TH",
    "name": "Ban Rai",
    "lat": "15.08417",
    "lng": "99.52108"
  },
  {
    "country": "TH",
    "name": "Ban Pong",
    "lat": "13.81629",
    "lng": "99.87739"
  },
  {
    "country": "TH",
    "name": "Banphot Phisai",
    "lat": "15.93558",
    "lng": "99.98129"
  },
  {
    "country": "TH",
    "name": "Ban Phru Nai",
    "lat": "7.95458",
    "lng": "98.58989"
  },
  {
    "country": "TH",
    "name": "Nuea Khlong",
    "lat": "8.07143",
    "lng": "98.99933"
  },
  {
    "country": "TH",
    "name": "Nong Prue",
    "lat": "14.60784",
    "lng": "99.45783"
  },
  {
    "country": "TH",
    "name": "Nong Mamong",
    "lat": "15.27613",
    "lng": "99.8664"
  },
  {
    "country": "TH",
    "name": "Noen Kham",
    "lat": "14.9501",
    "lng": "99.93899"
  },
  {
    "country": "TH",
    "name": "Ban Na San",
    "lat": "8.80036",
    "lng": "99.36372"
  },
  {
    "country": "TH",
    "name": "Ban Na Doem",
    "lat": "8.88361",
    "lng": "99.31014"
  },
  {
    "country": "TH",
    "name": "Ban Na",
    "lat": "17.01717",
    "lng": "99.73283"
  },
  {
    "country": "TH",
    "name": "Ban Lat",
    "lat": "13.0515",
    "lng": "99.91701"
  },
  {
    "country": "TH",
    "name": "Ban Laem",
    "lat": "13.20468",
    "lng": "99.97959"
  },
  {
    "country": "TH",
    "name": "Ban Ko Kaeo",
    "lat": "7.93599",
    "lng": "98.39664"
  },
  {
    "country": "TH",
    "name": "Ban Khao Lak",
    "lat": "8.61501",
    "lng": "98.23994"
  },
  {
    "country": "TH",
    "name": "Ban Kha",
    "lat": "13.43047",
    "lng": "99.40967"
  },
  {
    "country": "TH",
    "name": "Ban Karon",
    "lat": "7.84769",
    "lng": "98.2985"
  },
  {
    "country": "TH",
    "name": "Kaeng Krachan",
    "lat": "12.90742",
    "lng": "99.64795"
  },
  {
    "country": "TH",
    "name": "Huai Krachao",
    "lat": "14.3275",
    "lng": "99.66767"
  },
  {
    "country": "TH",
    "name": "Ban Hong",
    "lat": "18.33086",
    "lng": "98.81925"
  },
  {
    "country": "TH",
    "name": "Bang Saphan Noi",
    "lat": "11.07535",
    "lng": "99.44152"
  },
  {
    "country": "TH",
    "name": "Bang Saphan",
    "lat": "11.21259",
    "lng": "99.51167"
  },
  {
    "country": "TH",
    "name": "Bang Phae",
    "lat": "13.69157",
    "lng": "99.92982"
  },
  {
    "country": "TH",
    "name": "Bang Khon Thi",
    "lat": "13.46906",
    "lng": "99.94021"
  },
  {
    "country": "TH",
    "name": "Bang Khan",
    "lat": "8.02689",
    "lng": "99.47372"
  },
  {
    "country": "TH",
    "name": "Don Tum",
    "lat": "13.9609",
    "lng": "100.07888"
  },
  {
    "country": "TH",
    "name": "Doi Lo",
    "lat": "18.46098",
    "lng": "98.77767"
  },
  {
    "country": "TH",
    "name": "Dan Makham Tia",
    "lat": "13.85339",
    "lng": "99.41042"
  },
  {
    "country": "TH",
    "name": "Ban Dan Lan Hoi",
    "lat": "17.00683",
    "lng": "99.57497"
  },
  {
    "country": "TH",
    "name": "Ban Ao Nang",
    "lat": "8.0458",
    "lng": "98.81035"
  },
  {
    "country": "TH",
    "name": "Ao Luek",
    "lat": "8.37803",
    "lng": "98.72117"
  },
  {
    "country": "TH",
    "name": "Amphawa",
    "lat": "13.42436",
    "lng": "99.95688"
  },
  {
    "country": "TH",
    "name": "Sa Bot",
    "lat": "15.21006",
    "lng": "100.83076"
  },
  {
    "country": "TH",
    "name": "Phatthana Nikhom",
    "lat": "14.85647",
    "lng": "100.98459"
  },
  {
    "country": "TH",
    "name": "Nong Kung Si",
    "lat": "16.65",
    "lng": "103.3"
  },
  {
    "country": "TH",
    "name": "Na Dun",
    "lat": "15.71668",
    "lng": "103.22781"
  },
  {
    "country": "TH",
    "name": "Ko Pha Ngan",
    "lat": "9.71945",
    "lng": "99.99511"
  },
  {
    "country": "TH",
    "name": "Yang Si Surat",
    "lat": "15.68361",
    "lng": "103.10311"
  },
  {
    "country": "TH",
    "name": "Mueang Yang",
    "lat": "15.4206",
    "lng": "102.89282"
  },
  {
    "country": "TH",
    "name": "Siao",
    "lat": "14.79583",
    "lng": "104.67017"
  },
  {
    "country": "TH",
    "name": "Samran",
    "lat": "16.86322",
    "lng": "103.54106"
  },
  {
    "country": "TH",
    "name": "Thepharak",
    "lat": "15.30868",
    "lng": "101.55045"
  },
  {
    "country": "TH",
    "name": "Sak Lek",
    "lat": "16.50528",
    "lng": "100.47103"
  },
  {
    "country": "TH",
    "name": "Phayu",
    "lat": "14.90851",
    "lng": "104.39101"
  },
  {
    "country": "TH",
    "name": "Pha Khao",
    "lat": "17.06507",
    "lng": "102.02965"
  },
  {
    "country": "TH",
    "name": "Non Suwan",
    "lat": "14.58044",
    "lng": "102.59689"
  },
  {
    "country": "TH",
    "name": "Ban Nong Wua So",
    "lat": "17.2675",
    "lng": "103.22472"
  },
  {
    "country": "TH",
    "name": "Nong Wua So",
    "lat": "17.16261",
    "lng": "102.57272"
  },
  {
    "country": "TH",
    "name": "Nong Na Kham",
    "lat": "16.8043",
    "lng": "102.33647"
  },
  {
    "country": "TH",
    "name": "Nong Muang",
    "lat": "15.24592",
    "lng": "100.65556"
  },
  {
    "country": "TH",
    "name": "Nong Hin",
    "lat": "17.12356",
    "lng": "101.85789"
  },
  {
    "country": "TH",
    "name": "Nong Hi",
    "lat": "15.61117",
    "lng": "103.99484"
  },
  {
    "country": "TH",
    "name": "Na Yung",
    "lat": "17.89747",
    "lng": "102.14981"
  },
  {
    "country": "TH",
    "name": "Na Tan",
    "lat": "15.89749",
    "lng": "105.29318"
  },
  {
    "country": "TH",
    "name": "Ban Nam Yuen",
    "lat": "9.87686",
    "lng": "98.86592"
  },
  {
    "country": "TH",
    "name": "Na Mom",
    "lat": "6.95856",
    "lng": "100.55683"
  },
  {
    "country": "TH",
    "name": "Mueang Chan",
    "lat": "15.15951",
    "lng": "104.03615"
  },
  {
    "country": "TH",
    "name": "Ban Mai",
    "lat": "7.20411",
    "lng": "100.54508"
  },
  {
    "country": "TH",
    "name": "Lam Sonthi",
    "lat": "15.30154",
    "lng": "101.36365"
  },
  {
    "country": "TH",
    "name": "Ban Huai Thalaeng",
    "lat": "14.98333",
    "lng": "102.65"
  },
  {
    "country": "TH",
    "name": "Huai Rat",
    "lat": "14.96039",
    "lng": "103.18911"
  },
  {
    "country": "TH",
    "name": "Ban Haet",
    "lat": "16.19648",
    "lng": "102.75959"
  },
  {
    "country": "TH",
    "name": "Fao Rai",
    "lat": "18.01791",
    "lng": "103.30388"
  },
  {
    "country": "TH",
    "name": "Ban Dan",
    "lat": "15.10839",
    "lng": "103.17551"
  },
  {
    "country": "TH",
    "name": "Charoen Sin",
    "lat": "17.57925",
    "lng": "103.54033"
  },
  {
    "country": "TH",
    "name": "Ban Khlong Bang Sao Thong",
    "lat": "13.64172",
    "lng": "100.83272"
  },
  {
    "country": "TH",
    "name": "Waeng",
    "lat": "5.928",
    "lng": "101.88382"
  },
  {
    "country": "TH",
    "name": "Thepha",
    "lat": "6.82936",
    "lng": "100.96431"
  },
  {
    "country": "TH",
    "name": "Tak Fa",
    "lat": "15.34917",
    "lng": "100.49522"
  },
  {
    "country": "TH",
    "name": "Prakhon Chai",
    "lat": "14.61073",
    "lng": "103.07923"
  },
  {
    "country": "TH",
    "name": "Na Klang",
    "lat": "17.3072",
    "lng": "102.18886"
  },
  {
    "country": "TH",
    "name": "Bacho",
    "lat": "6.51678",
    "lng": "101.651"
  },
  {
    "country": "TH",
    "name": "Yi-ngo",
    "lat": "6.40297",
    "lng": "101.70625"
  },
  {
    "country": "TH",
    "name": "Yasothon",
    "lat": "15.79408",
    "lng": "104.1451"
  },
  {
    "country": "TH",
    "name": "Yaring",
    "lat": "6.86617",
    "lng": "101.36894"
  },
  {
    "country": "TH",
    "name": "Yan Nawa",
    "lat": "13.69634",
    "lng": "100.54212"
  },
  {
    "country": "TH",
    "name": "Yang Talat",
    "lat": "16.39982",
    "lng": "103.36785"
  },
  {
    "country": "TH",
    "name": "Yang Chum Noi",
    "lat": "15.26453",
    "lng": "104.39769"
  },
  {
    "country": "TH",
    "name": "Yarang",
    "lat": "6.75986",
    "lng": "101.29339"
  },
  {
    "country": "TH",
    "name": "Yala",
    "lat": "6.53995",
    "lng": "101.28128"
  },
  {
    "country": "TH",
    "name": "Yaha",
    "lat": "6.4797",
    "lng": "101.132"
  },
  {
    "country": "TH",
    "name": "Wiset Chaichan",
    "lat": "14.5945",
    "lng": "100.33825"
  },
  {
    "country": "TH",
    "name": "Wihan Daeng",
    "lat": "14.34586",
    "lng": "100.98942"
  },
  {
    "country": "TH",
    "name": "Wichian Buri",
    "lat": "15.65778",
    "lng": "101.10603"
  },
  {
    "country": "TH",
    "name": "Wiang Sa",
    "lat": "18.59856",
    "lng": "100.74103"
  },
  {
    "country": "TH",
    "name": "Watthana Nakhon",
    "lat": "13.74462",
    "lng": "102.31863"
  },
  {
    "country": "TH",
    "name": "Wat Sing",
    "lat": "15.25987",
    "lng": "100.0404"
  },
  {
    "country": "TH",
    "name": "Wat Bot",
    "lat": "16.98114",
    "lng": "100.33195"
  },
  {
    "country": "TH",
    "name": "Warin Chamrap",
    "lat": "15.19319",
    "lng": "104.8628"
  },
  {
    "country": "TH",
    "name": "Warichaphum",
    "lat": "17.29409",
    "lng": "103.63816"
  },
  {
    "country": "TH",
    "name": "Wapi Pathum",
    "lat": "15.84523",
    "lng": "103.37678"
  },
  {
    "country": "TH",
    "name": "Wan Yai",
    "lat": "16.72229",
    "lng": "104.74135"
  },
  {
    "country": "TH",
    "name": "Wanon Niwat",
    "lat": "17.63391",
    "lng": "103.75241"
  },
  {
    "country": "TH",
    "name": "Wang Thong",
    "lat": "16.82458",
    "lng": "100.42936"
  },
  {
    "country": "TH",
    "name": "Wang Saphung",
    "lat": "17.30097",
    "lng": "101.7685"
  },
  {
    "country": "TH",
    "name": "Wang Sam Mo",
    "lat": "16.95294",
    "lng": "103.4365"
  },
  {
    "country": "TH",
    "name": "Wang Noi",
    "lat": "14.22689",
    "lng": "100.7155"
  },
  {
    "country": "TH",
    "name": "Wang Nam Yen",
    "lat": "13.50325",
    "lng": "102.18115"
  },
  {
    "country": "TH",
    "name": "Wang Hin",
    "lat": "14.94783",
    "lng": "104.23097"
  },
  {
    "country": "TH",
    "name": "Wang Chan",
    "lat": "12.93646",
    "lng": "101.52303"
  },
  {
    "country": "TH",
    "name": "Wang Sai Phun",
    "lat": "16.3885",
    "lng": "100.53801"
  },
  {
    "country": "TH",
    "name": "Waeng Yai",
    "lat": "15.95547",
    "lng": "102.5469"
  },
  {
    "country": "TH",
    "name": "Waeng Noi",
    "lat": "15.8035",
    "lng": "102.41614"
  },
  {
    "country": "TH",
    "name": "Uttaradit",
    "lat": "17.62557",
    "lng": "100.09421"
  },
  {
    "country": "TH",
    "name": "Uthumphon Phisai",
    "lat": "15.11161",
    "lng": "104.14011"
  },
  {
    "country": "TH",
    "name": "Uthai Thani",
    "lat": "15.37939",
    "lng": "100.0245"
  },
  {
    "country": "TH",
    "name": "Uthai",
    "lat": "14.36278",
    "lng": "100.67203"
  },
  {
    "country": "TH",
    "name": "Udon Thani",
    "lat": "17.41567",
    "lng": "102.78589"
  },
  {
    "country": "TH",
    "name": "Ubon Ratchathani",
    "lat": "15.23844",
    "lng": "104.84866"
  },
  {
    "country": "TH",
    "name": "Khuean Ubonrat",
    "lat": "16.75269",
    "lng": "102.63245"
  },
  {
    "country": "TH",
    "name": "Tron",
    "lat": "17.48181",
    "lng": "100.11281"
  },
  {
    "country": "TH",
    "name": "Trat",
    "lat": "12.24364",
    "lng": "102.51514"
  },
  {
    "country": "TH",
    "name": "Trakan Phut Phon",
    "lat": "15.61183",
    "lng": "105.02147"
  },
  {
    "country": "TH",
    "name": "Thung Fon",
    "lat": "17.47167",
    "lng": "103.26033"
  },
  {
    "country": "TH",
    "name": "Thon Buri",
    "lat": "13.725",
    "lng": "100.48511"
  },
  {
    "country": "TH",
    "name": "Thoeng",
    "lat": "19.68508",
    "lng": "100.19456"
  },
  {
    "country": "TH",
    "name": "Thep Sathit",
    "lat": "15.39247",
    "lng": "101.45061"
  },
  {
    "country": "TH",
    "name": "Tha Yang",
    "lat": "12.95772",
    "lng": "99.90555"
  },
  {
    "country": "TH",
    "name": "Tha Wung",
    "lat": "14.811",
    "lng": "100.50333"
  },
  {
    "country": "TH",
    "name": "Thawat Buri",
    "lat": "16.0385",
    "lng": "103.74647"
  },
  {
    "country": "TH",
    "name": "Tha Wang Pha",
    "lat": "19.12189",
    "lng": "100.81106"
  },
  {
    "country": "TH",
    "name": "Tha Uthen",
    "lat": "17.57605",
    "lng": "104.59906"
  },
  {
    "country": "TH",
    "name": "Tha Tum",
    "lat": "15.3195",
    "lng": "103.67542"
  },
  {
    "country": "TH",
    "name": "That Phanom",
    "lat": "16.93636",
    "lng": "104.71039"
  },
  {
    "country": "TH",
    "name": "Tha Tako",
    "lat": "15.64218",
    "lng": "100.47839"
  },
  {
    "country": "TH",
    "name": "Tha Ruea",
    "lat": "14.56739",
    "lng": "100.72598"
  },
  {
    "country": "TH",
    "name": "Tha Pla",
    "lat": "17.79112",
    "lng": "100.37611"
  },
  {
    "country": "TH",
    "name": "Thap Khlo",
    "lat": "16.16003",
    "lng": "100.59656"
  },
  {
    "country": "TH",
    "name": "Thanyaburi",
    "lat": "14.02114",
    "lng": "100.73433"
  },
  {
    "country": "TH",
    "name": "Than To",
    "lat": "6.16739",
    "lng": "101.18008"
  },
  {
    "country": "TH",
    "name": "Tha Mai",
    "lat": "12.62137",
    "lng": "102.00481"
  },
  {
    "country": "TH",
    "name": "Tha Luang",
    "lat": "15.07124",
    "lng": "101.09801"
  },
  {
    "country": "TH",
    "name": "Tha Li",
    "lat": "17.62355",
    "lng": "101.42099"
  },
  {
    "country": "TH",
    "name": "Tha Khantho",
    "lat": "16.93953",
    "lng": "103.24586"
  },
  {
    "country": "TH",
    "name": "Tha Chang",
    "lat": "14.76142",
    "lng": "100.38989"
  },
  {
    "country": "TH",
    "name": "Tha Bo",
    "lat": "17.85003",
    "lng": "102.58139"
  },
  {
    "country": "TH",
    "name": "Ta Phraya",
    "lat": "14.00308",
    "lng": "102.80541"
  },
  {
    "country": "TH",
    "name": "Taphan Hin",
    "lat": "16.22095",
    "lng": "100.41978"
  },
  {
    "country": "TH",
    "name": "Tao Ngoi",
    "lat": "16.99689",
    "lng": "104.16672"
  },
  {
    "country": "TH",
    "name": "Tan Sum",
    "lat": "15.31569",
    "lng": "105.15464"
  },
  {
    "country": "TH",
    "name": "Tamot",
    "lat": "7.33922",
    "lng": "100.11167"
  },
  {
    "country": "TH",
    "name": "Taling Chan",
    "lat": "13.77698",
    "lng": "100.4567"
  },
  {
    "country": "TH",
    "name": "Takhli",
    "lat": "15.26336",
    "lng": "100.34378"
  },
  {
    "country": "TH",
    "name": "Tak Bai",
    "lat": "6.25947",
    "lng": "102.05461"
  },
  {
    "country": "TH",
    "name": "Suwannaphum",
    "lat": "15.60348",
    "lng": "103.80207"
  },
  {
    "country": "TH",
    "name": "Suwannakhuha",
    "lat": "17.56292",
    "lng": "102.27989"
  },
  {
    "country": "TH",
    "name": "Surin",
    "lat": "14.88181",
    "lng": "103.49364"
  },
  {
    "country": "TH",
    "name": "Suphan Buri",
    "lat": "14.47418",
    "lng": "100.12218"
  },
  {
    "country": "TH",
    "name": "Sung Noen",
    "lat": "14.8992",
    "lng": "101.82075"
  },
  {
    "country": "TH",
    "name": "Sung Men",
    "lat": "18.0494",
    "lng": "100.11457"
  },
  {
    "country": "TH",
    "name": "Ban Su-ngai Pa Di",
    "lat": "6.07239",
    "lng": "101.87172"
  },
  {
    "country": "TH",
    "name": "Su-ngai Kolok",
    "lat": "6.02977",
    "lng": "101.96586"
  },
  {
    "country": "TH",
    "name": "Sukhirin",
    "lat": "5.93889",
    "lng": "101.77077"
  },
  {
    "country": "TH",
    "name": "So Phisai",
    "lat": "18.0772",
    "lng": "103.4432"
  },
  {
    "country": "TH",
    "name": "Song Phi Nong",
    "lat": "14.22408",
    "lng": "100.02094"
  },
  {
    "country": "TH",
    "name": "Songkhla",
    "lat": "7.19882",
    "lng": "100.5951"
  },
  {
    "country": "TH",
    "name": "Song",
    "lat": "18.47204",
    "lng": "100.18346"
  },
  {
    "country": "TH",
    "name": "Somdet",
    "lat": "16.70462",
    "lng": "103.74935"
  },
  {
    "country": "TH",
    "name": "Soeng Sang",
    "lat": "14.42642",
    "lng": "102.46058"
  },
  {
    "country": "TH",
    "name": "Si Thep",
    "lat": "15.45214",
    "lng": "101.06667"
  },
  {
    "country": "TH",
    "name": "Si That",
    "lat": "16.97361",
    "lng": "103.21644"
  },
  {
    "country": "TH",
    "name": "Si Songkhram",
    "lat": "17.62745",
    "lng": "104.25069"
  },
  {
    "country": "TH",
    "name": "Si Sakhon",
    "lat": "6.23137",
    "lng": "101.50048"
  },
  {
    "country": "TH",
    "name": "Si Sa Ket",
    "lat": "15.11481",
    "lng": "104.32938"
  },
  {
    "country": "TH",
    "name": "Si Rattana",
    "lat": "14.79328",
    "lng": "104.46922"
  },
  {
    "country": "TH",
    "name": "Si Racha",
    "lat": "13.17372",
    "lng": "100.93111"
  },
  {
    "country": "TH",
    "name": "Si Prachan",
    "lat": "14.61992",
    "lng": "100.14483"
  },
  {
    "country": "TH",
    "name": "Sing Buri",
    "lat": "14.88786",
    "lng": "100.40464"
  },
  {
    "country": "TH",
    "name": "Si Mueang Mai",
    "lat": "15.49315",
    "lng": "105.27624"
  },
  {
    "country": "TH",
    "name": "Si Maha Phot",
    "lat": "13.96597",
    "lng": "101.51303"
  },
  {
    "country": "TH",
    "name": "Si Khoraphum",
    "lat": "14.94418",
    "lng": "103.79704"
  },
  {
    "country": "TH",
    "name": "Sikhio",
    "lat": "14.89225",
    "lng": "101.72314"
  },
  {
    "country": "TH",
    "name": "Si Chomphu",
    "lat": "16.79878",
    "lng": "102.18466"
  },
  {
    "country": "TH",
    "name": "Si Chiang Mai",
    "lat": "17.95639",
    "lng": "102.58667"
  },
  {
    "country": "TH",
    "name": "Si Bun Rueang",
    "lat": "16.96705",
    "lng": "102.27607"
  },
  {
    "country": "TH",
    "name": "Senangkhanikhom",
    "lat": "16.03972",
    "lng": "104.66939"
  },
  {
    "country": "TH",
    "name": "Sena",
    "lat": "14.327",
    "lng": "100.40433"
  },
  {
    "country": "TH",
    "name": "Selaphum",
    "lat": "16.02992",
    "lng": "103.93826"
  },
  {
    "country": "TH",
    "name": "Seka",
    "lat": "17.92851",
    "lng": "103.95519"
  },
  {
    "country": "TH",
    "name": "Sawang Daen Din",
    "lat": "17.47531",
    "lng": "103.45753"
  },
  {
    "country": "TH",
    "name": "Sawaeng Ha",
    "lat": "14.74642",
    "lng": "100.32942"
  },
  {
    "country": "TH",
    "name": "Satun",
    "lat": "6.62314",
    "lng": "100.06676"
  },
  {
    "country": "TH",
    "name": "Satuek",
    "lat": "15.29703",
    "lng": "103.29192"
  },
  {
    "country": "TH",
    "name": "Sattahip",
    "lat": "12.66644",
    "lng": "100.90073"
  },
  {
    "country": "TH",
    "name": "Sathing Phra",
    "lat": "7.47303",
    "lng": "100.43908"
  },
  {
    "country": "TH",
    "name": "Saraburi",
    "lat": "14.53333",
    "lng": "100.91667"
  },
  {
    "country": "TH",
    "name": "Sao Hai",
    "lat": "14.55083",
    "lng": "100.84436"
  },
  {
    "country": "TH",
    "name": "Sapphaya",
    "lat": "15.14616",
    "lng": "100.24215"
  },
  {
    "country": "TH",
    "name": "Sanom",
    "lat": "15.2036",
    "lng": "103.76054"
  },
  {
    "country": "TH",
    "name": "Sankhaburi",
    "lat": "15.04733",
    "lng": "100.16178"
  },
  {
    "country": "TH",
    "name": "Sangkhom",
    "lat": "18.06389",
    "lng": "102.27364"
  },
  {
    "country": "TH",
    "name": "Sang Khom",
    "lat": "17.82649",
    "lng": "103.09262"
  },
  {
    "country": "TH",
    "name": "Sangkha",
    "lat": "14.6362",
    "lng": "103.85278"
  },
  {
    "country": "TH",
    "name": "Sanam Chai Khet",
    "lat": "13.65864",
    "lng": "101.43906"
  },
  {
    "country": "TH",
    "name": "Samut Songkhram",
    "lat": "13.41456",
    "lng": "100.00264"
  },
  {
    "country": "TH",
    "name": "Samut Sakhon",
    "lat": "13.54753",
    "lng": "100.27362"
  },
  {
    "country": "TH",
    "name": "Samut Prakan",
    "lat": "13.59934",
    "lng": "100.59675"
  },
  {
    "country": "TH",
    "name": "Samrong Thap",
    "lat": "15.02258",
    "lng": "103.93631"
  },
  {
    "country": "TH",
    "name": "Sam Phran",
    "lat": "13.72698",
    "lng": "100.21526"
  },
  {
    "country": "TH",
    "name": "Samphanthawong",
    "lat": "13.73147",
    "lng": "100.51414"
  },
  {
    "country": "TH",
    "name": "Sam Ngam",
    "lat": "16.50653",
    "lng": "100.20497"
  },
  {
    "country": "TH",
    "name": "Sam Ko",
    "lat": "14.60735",
    "lng": "100.2186"
  },
  {
    "country": "TH",
    "name": "Sam Khok",
    "lat": "14.0655",
    "lng": "100.52264"
  },
  {
    "country": "TH",
    "name": "Sam Chuk",
    "lat": "14.75763",
    "lng": "100.08992"
  },
  {
    "country": "TH",
    "name": "Sakon Nakhon",
    "lat": "17.16116",
    "lng": "104.14725"
  },
  {
    "country": "TH",
    "name": "Sa Kaeo",
    "lat": "13.81411",
    "lng": "102.07222"
  },
  {
    "country": "TH",
    "name": "Sai Noi",
    "lat": "13.97915",
    "lng": "100.31209"
  },
  {
    "country": "TH",
    "name": "Sai Mun",
    "lat": "15.94495",
    "lng": "104.20812"
  },
  {
    "country": "TH",
    "name": "Sai Buri",
    "lat": "6.70131",
    "lng": "101.61675"
  },
  {
    "country": "TH",
    "name": "Sahatsakhan",
    "lat": "16.71236",
    "lng": "103.5202"
  },
  {
    "country": "TH",
    "name": "Sadao",
    "lat": "6.63883",
    "lng": "100.42342"
  },
  {
    "country": "TH",
    "name": "Saba Yoi",
    "lat": "6.6175",
    "lng": "100.95189"
  },
  {
    "country": "TH",
    "name": "Rueso",
    "lat": "6.39364",
    "lng": "101.51847"
  },
  {
    "country": "TH",
    "name": "Rong Kwang",
    "lat": "18.33903",
    "lng": "100.31736"
  },
  {
    "country": "TH",
    "name": "Rong Kham",
    "lat": "16.26943",
    "lng": "103.74689"
  },
  {
    "country": "TH",
    "name": "Roi Et",
    "lat": "16.0567",
    "lng": "103.65309"
  },
  {
    "country": "TH",
    "name": "Renu Nakhon",
    "lat": "17.05157",
    "lng": "104.67709"
  },
  {
    "country": "TH",
    "name": "Rayong",
    "lat": "12.68095",
    "lng": "101.25798"
  },
  {
    "country": "TH",
    "name": "Rattaphum",
    "lat": "7.13478",
    "lng": "100.25647"
  },
  {
    "country": "TH",
    "name": "Rattanaburi",
    "lat": "15.31788",
    "lng": "103.84859"
  },
  {
    "country": "TH",
    "name": "Rat Burana",
    "lat": "13.68219",
    "lng": "100.50603"
  },
  {
    "country": "TH",
    "name": "Rasi Salai",
    "lat": "15.34466",
    "lng": "104.15476"
  },
  {
    "country": "TH",
    "name": "Ranot",
    "lat": "7.77768",
    "lng": "100.32134"
  },
  {
    "country": "TH",
    "name": "Ra-ngae",
    "lat": "6.29678",
    "lng": "101.72844"
  },
  {
    "country": "TH",
    "name": "Raman",
    "lat": "6.47862",
    "lng": "101.42414"
  },
  {
    "country": "TH",
    "name": "Pueai Noi",
    "lat": "15.86978",
    "lng": "102.90767"
  },
  {
    "country": "TH",
    "name": "Pua",
    "lat": "19.17503",
    "lng": "100.91622"
  },
  {
    "country": "TH",
    "name": "Prathai",
    "lat": "15.53319",
    "lng": "102.72283"
  },
  {
    "country": "TH",
    "name": "Prasat",
    "lat": "14.64039",
    "lng": "103.40447"
  },
  {
    "country": "TH",
    "name": "Prang Ku",
    "lat": "14.85672",
    "lng": "104.03981"
  },
  {
    "country": "TH",
    "name": "Prakhon Chai",
    "lat": "14.60592",
    "lng": "103.12081"
  },
  {
    "country": "TH",
    "name": "Pakham",
    "lat": "14.43817",
    "lng": "102.72558"
  },
  {
    "country": "TH",
    "name": "Prachin Buri",
    "lat": "14.04992",
    "lng": "101.36864"
  },
  {
    "country": "TH",
    "name": "Prachantakham",
    "lat": "14.06442",
    "lng": "101.51503"
  },
  {
    "country": "TH",
    "name": "Pong Nam Ron",
    "lat": "12.90575",
    "lng": "102.26225"
  },
  {
    "country": "TH",
    "name": "Pong",
    "lat": "19.14931",
    "lng": "100.27522"
  },
  {
    "country": "TH",
    "name": "Pom Prap Sattru Phai",
    "lat": "13.75822",
    "lng": "100.51325"
  },
  {
    "country": "TH",
    "name": "Pluak Daeng",
    "lat": "12.97122",
    "lng": "101.21463"
  },
  {
    "country": "TH",
    "name": "Pla Pak",
    "lat": "17.18064",
    "lng": "104.52606"
  },
  {
    "country": "TH",
    "name": "Plaeng Yao",
    "lat": "13.58467",
    "lng": "101.28403"
  },
  {
    "country": "TH",
    "name": "Phu Wiang",
    "lat": "16.65259",
    "lng": "102.37555"
  },
  {
    "country": "TH",
    "name": "Phutthaisong",
    "lat": "15.54783",
    "lng": "103.02467"
  },
  {
    "country": "TH",
    "name": "Phu Ruea",
    "lat": "17.4538",
    "lng": "101.36231"
  },
  {
    "country": "TH",
    "name": "Phu Pha Man",
    "lat": "16.64888",
    "lng": "101.90097"
  },
  {
    "country": "TH",
    "name": "Phu Luang",
    "lat": "17.1392",
    "lng": "101.66392"
  },
  {
    "country": "TH",
    "name": "Phu Kradueng",
    "lat": "16.88425",
    "lng": "101.88467"
  },
  {
    "country": "TH",
    "name": "Phu Khiao",
    "lat": "16.3765",
    "lng": "102.12853"
  },
  {
    "country": "TH",
    "name": "Phrom Phiram",
    "lat": "17.03352",
    "lng": "100.2019"
  },
  {
    "country": "TH",
    "name": "Phrom Buri",
    "lat": "14.79086",
    "lng": "100.45325"
  },
  {
    "country": "TH",
    "name": "Phra Yuen",
    "lat": "16.3293",
    "lng": "102.65182"
  },
  {
    "country": "TH",
    "name": "Phra Pradaeng",
    "lat": "13.65855",
    "lng": "100.53362"
  },
  {
    "country": "TH",
    "name": "Phra Phutthabat",
    "lat": "14.72526",
    "lng": "100.79536"
  },
  {
    "country": "TH",
    "name": "Phra Nakhon Si Ayutthaya",
    "lat": "14.35167",
    "lng": "100.57739"
  },
  {
    "country": "TH",
    "name": "Phra Khanong",
    "lat": "13.70185",
    "lng": "100.60157"
  },
  {
    "country": "TH",
    "name": "Phrai Bueng",
    "lat": "14.74833",
    "lng": "104.36261"
  },
  {
    "country": "TH",
    "name": "Phrae",
    "lat": "18.14589",
    "lng": "100.14103"
  },
  {
    "country": "TH",
    "name": "Pho Thong",
    "lat": "14.66731",
    "lng": "100.40878"
  },
  {
    "country": "TH",
    "name": "Pho Thale",
    "lat": "16.09269",
    "lng": "100.26089"
  },
  {
    "country": "TH",
    "name": "Pho Sai",
    "lat": "15.82586",
    "lng": "105.26064"
  },
  {
    "country": "TH",
    "name": "Waeng",
    "lat": "16.30006",
    "lng": "103.97786"
  },
  {
    "country": "TH",
    "name": "Phon Sai",
    "lat": "15.48797",
    "lng": "103.99642"
  },
  {
    "country": "TH",
    "name": "Phon Phisai",
    "lat": "18.02106",
    "lng": "103.07664"
  },
  {
    "country": "TH",
    "name": "Phon Charoen",
    "lat": "18.03333",
    "lng": "103.16667"
  },
  {
    "country": "TH",
    "name": "Phon",
    "lat": "15.816",
    "lng": "102.59981"
  },
  {
    "country": "TH",
    "name": "Pho Chai",
    "lat": "16.32827",
    "lng": "103.77033"
  },
  {
    "country": "TH",
    "name": "Phitsanulok",
    "lat": "16.82481",
    "lng": "100.25858"
  },
  {
    "country": "TH",
    "name": "Phimai",
    "lat": "15.22324",
    "lng": "102.49473"
  },
  {
    "country": "TH",
    "name": "Phichit",
    "lat": "16.44184",
    "lng": "100.34879"
  },
  {
    "country": "TH",
    "name": "Phichai",
    "lat": "17.28764",
    "lng": "100.0867"
  },
  {
    "country": "TH",
    "name": "Phibun Mangsahan",
    "lat": "15.24467",
    "lng": "105.22908"
  },
  {
    "country": "TH",
    "name": "Phetchabun",
    "lat": "16.41904",
    "lng": "101.16056"
  },
  {
    "country": "TH",
    "name": "Phen",
    "lat": "17.69614",
    "lng": "102.90689"
  },
  {
    "country": "TH",
    "name": "Phayuha Khiri",
    "lat": "15.45525",
    "lng": "100.13533"
  },
  {
    "country": "TH",
    "name": "Phayakkhaphum Phisai",
    "lat": "15.51631",
    "lng": "103.19367"
  },
  {
    "country": "TH",
    "name": "Phatthalung",
    "lat": "7.61786",
    "lng": "100.07792"
  },
  {
    "country": "TH",
    "name": "Phasi Charoen",
    "lat": "13.71466",
    "lng": "100.43691"
  },
  {
    "country": "TH",
    "name": "Phan Thong",
    "lat": "13.46804",
    "lng": "101.09532"
  },
  {
    "country": "TH",
    "name": "Phanom Sarakham",
    "lat": "13.74872",
    "lng": "101.34888"
  },
  {
    "country": "TH",
    "name": "Phanom Phrai",
    "lat": "15.67783",
    "lng": "104.11025"
  },
  {
    "country": "TH",
    "name": "Phanna Nikhom",
    "lat": "17.35245",
    "lng": "103.85032"
  },
  {
    "country": "TH",
    "name": "Phang Khon",
    "lat": "17.39051",
    "lng": "103.71692"
  },
  {
    "country": "TH",
    "name": "Phanat Nikhom",
    "lat": "13.44581",
    "lng": "101.18445"
  },
  {
    "country": "TH",
    "name": "Phana",
    "lat": "15.68231",
    "lng": "104.84603"
  },
  {
    "country": "TH",
    "name": "Phak Hai",
    "lat": "14.45736",
    "lng": "100.36989"
  },
  {
    "country": "TH",
    "name": "Phai Sali",
    "lat": "15.60003",
    "lng": "100.64937"
  },
  {
    "country": "TH",
    "name": "Phachi",
    "lat": "14.44914",
    "lng": "100.72833"
  },
  {
    "country": "TH",
    "name": "Pa Bon",
    "lat": "7.26942",
    "lng": "100.17036"
  },
  {
    "country": "TH",
    "name": "Phaya Mengrai",
    "lat": "19.84922",
    "lng": "100.15358"
  },
  {
    "country": "TH",
    "name": "Pattani",
    "lat": "6.86814",
    "lng": "101.25009"
  },
  {
    "country": "TH",
    "name": "Pa Tio",
    "lat": "15.83281",
    "lng": "104.38673"
  },
  {
    "country": "TH",
    "name": "Pathum Thani",
    "lat": "14.01346",
    "lng": "100.53049"
  },
  {
    "country": "TH",
    "name": "Pathum Rat",
    "lat": "15.6345",
    "lng": "103.34325"
  },
  {
    "country": "TH",
    "name": "Panare",
    "lat": "6.86192",
    "lng": "101.49103"
  },
  {
    "country": "TH",
    "name": "Pa Mok",
    "lat": "14.48989",
    "lng": "100.44847"
  },
  {
    "country": "TH",
    "name": "Pak Thong Chai",
    "lat": "14.7226",
    "lng": "102.02512"
  },
  {
    "country": "TH",
    "name": "Pak Phli",
    "lat": "14.16308",
    "lng": "101.26886"
  },
  {
    "country": "TH",
    "name": "Pak Phayun",
    "lat": "7.34219",
    "lng": "100.31747"
  },
  {
    "country": "TH",
    "name": "Pak Phanang",
    "lat": "8.35109",
    "lng": "100.20195"
  },
  {
    "country": "TH",
    "name": "Pak Kret",
    "lat": "13.91301",
    "lng": "100.49883"
  },
  {
    "country": "TH",
    "name": "Pak Khat",
    "lat": "18.30556",
    "lng": "103.30441"
  },
  {
    "country": "TH",
    "name": "Pak Chong",
    "lat": "14.70802",
    "lng": "101.41614"
  },
  {
    "country": "TH",
    "name": "Pa Daet",
    "lat": "19.50489",
    "lng": "99.99241"
  },
  {
    "country": "TH",
    "name": "Ongkharak",
    "lat": "14.12117",
    "lng": "101.00364"
  },
  {
    "country": "TH",
    "name": "Non Thai",
    "lat": "15.1958",
    "lng": "102.07145"
  },
  {
    "country": "TH",
    "name": "Mueang Nonthaburi",
    "lat": "13.86075",
    "lng": "100.51477"
  },
  {
    "country": "TH",
    "name": "Non Sung",
    "lat": "15.18014",
    "lng": "102.25695"
  },
  {
    "country": "TH",
    "name": "Non Sang",
    "lat": "16.8687",
    "lng": "102.56642"
  },
  {
    "country": "TH",
    "name": "Non Sa-at",
    "lat": "16.97914",
    "lng": "102.89369"
  },
  {
    "country": "TH",
    "name": "Non Kho",
    "lat": "14.91666",
    "lng": "104.72522"
  },
  {
    "country": "TH",
    "name": "Nong Yai",
    "lat": "13.15515",
    "lng": "101.37226"
  },
  {
    "country": "TH",
    "name": "Nong Sung",
    "lat": "16.48299",
    "lng": "104.34712"
  },
  {
    "country": "TH",
    "name": "Nong Suea",
    "lat": "14.13478",
    "lng": "100.82503"
  },
  {
    "country": "TH",
    "name": "Nong Saeng",
    "lat": "17.16739",
    "lng": "102.78081"
  },
  {
    "country": "TH",
    "name": "Nong Saeng",
    "lat": "14.49208",
    "lng": "100.78431"
  },
  {
    "country": "TH",
    "name": "Nong Ruea",
    "lat": "16.49333",
    "lng": "102.43339"
  },
  {
    "country": "TH",
    "name": "Nong Phok",
    "lat": "16.31006",
    "lng": "104.20247"
  },
  {
    "country": "TH",
    "name": "Nong Phai",
    "lat": "15.99025",
    "lng": "101.06183"
  },
  {
    "country": "TH",
    "name": "Nong Ki",
    "lat": "14.68679",
    "lng": "102.538"
  },
  {
    "country": "TH",
    "name": "Nong Khai",
    "lat": "17.87847",
    "lng": "102.742"
  },
  {
    "country": "TH",
    "name": "Nong Khaem",
    "lat": "13.70528",
    "lng": "100.34923"
  },
  {
    "country": "TH",
    "name": "Nong Khae",
    "lat": "14.34062",
    "lng": "100.86733"
  },
  {
    "country": "TH",
    "name": "Nong Hong",
    "lat": "14.84782",
    "lng": "102.68401"
  },
  {
    "country": "TH",
    "name": "Nong Han",
    "lat": "17.36083",
    "lng": "103.10533"
  },
  {
    "country": "TH",
    "name": "Nong Chok",
    "lat": "13.85585",
    "lng": "100.86216"
  },
  {
    "country": "TH",
    "name": "Nong Chik",
    "lat": "6.84356",
    "lng": "101.17803"
  },
  {
    "country": "TH",
    "name": "Nong Bun Nak",
    "lat": "14.73947",
    "lng": "102.36564"
  },
  {
    "country": "TH",
    "name": "Nong Bua Rawe",
    "lat": "15.75314",
    "lng": "101.76396"
  },
  {
    "country": "TH",
    "name": "Nong Bua Lamphu",
    "lat": "17.20406",
    "lng": "102.44068"
  },
  {
    "country": "TH",
    "name": "Nong Bua Daeng",
    "lat": "16.07978",
    "lng": "101.80225"
  },
  {
    "country": "TH",
    "name": "Nong Bua",
    "lat": "15.86458",
    "lng": "100.58581"
  },
  {
    "country": "TH",
    "name": "Noen Maprang",
    "lat": "16.56667",
    "lng": "100.63333"
  },
  {
    "country": "TH",
    "name": "Nikhom Nam Un",
    "lat": "17.18314",
    "lng": "103.71842"
  },
  {
    "country": "TH",
    "name": "Nikhom Kham Soi",
    "lat": "16.37167",
    "lng": "104.55147"
  },
  {
    "country": "TH",
    "name": "Na Wa",
    "lat": "17.4897",
    "lng": "104.10056"
  },
  {
    "country": "TH",
    "name": "Na Thawi",
    "lat": "6.74192",
    "lng": "100.69139"
  },
  {
    "country": "TH",
    "name": "Narathiwat",
    "lat": "6.42639",
    "lng": "101.82308"
  },
  {
    "country": "TH",
    "name": "Na Pho",
    "lat": "15.64113",
    "lng": "102.95462"
  },
  {
    "country": "TH",
    "name": "Na Noi",
    "lat": "18.32639",
    "lng": "100.71417"
  },
  {
    "country": "TH",
    "name": "Nang Rong",
    "lat": "14.6377",
    "lng": "102.79138"
  },
  {
    "country": "TH",
    "name": "Nan",
    "lat": "18.78378",
    "lng": "100.77899"
  },
  {
    "country": "TH",
    "name": "Na Muen",
    "lat": "18.18931",
    "lng": "100.66047"
  },
  {
    "country": "TH",
    "name": "Nam Som",
    "lat": "17.77036",
    "lng": "102.18947"
  },
  {
    "country": "TH",
    "name": "Nam Phong",
    "lat": "16.70228",
    "lng": "102.85569"
  },
  {
    "country": "TH",
    "name": "Nam Pat",
    "lat": "17.72806",
    "lng": "100.68433"
  },
  {
    "country": "TH",
    "name": "Na Mon",
    "lat": "16.57653",
    "lng": "103.78711"
  },
  {
    "country": "TH",
    "name": "Nam Nao",
    "lat": "16.76753",
    "lng": "101.66917"
  },
  {
    "country": "TH",
    "name": "Nam Kliang",
    "lat": "14.92731",
    "lng": "104.51303"
  },
  {
    "country": "TH",
    "name": "Nakhon Thai",
    "lat": "17.10056",
    "lng": "100.83739"
  },
  {
    "country": "TH",
    "name": "Nakhon Sawan",
    "lat": "15.70472",
    "lng": "100.13717"
  },
  {
    "country": "TH",
    "name": "Nakhon Ratchasima",
    "lat": "14.97066",
    "lng": "102.10196"
  },
  {
    "country": "TH",
    "name": "Nakhon Phanom",
    "lat": "17.41081",
    "lng": "104.77856"
  },
  {
    "country": "TH",
    "name": "Nakhon Pathom",
    "lat": "13.8196",
    "lng": "100.04427"
  },
  {
    "country": "TH",
    "name": "Nakhon Nayok",
    "lat": "14.20463",
    "lng": "101.21295"
  },
  {
    "country": "TH",
    "name": "Nakhon Luang",
    "lat": "14.46281",
    "lng": "100.60832"
  },
  {
    "country": "TH",
    "name": "Nakhon Chai Si",
    "lat": "13.80126",
    "lng": "100.18451"
  },
  {
    "country": "TH",
    "name": "Na Kae",
    "lat": "16.94645",
    "lng": "104.50081"
  },
  {
    "country": "TH",
    "name": "Na Chueak",
    "lat": "15.79339",
    "lng": "103.03184"
  },
  {
    "country": "TH",
    "name": "Na Chaluai",
    "lat": "14.52046",
    "lng": "105.24478"
  },
  {
    "country": "TH",
    "name": "Mukdahan",
    "lat": "16.54531",
    "lng": "104.72351"
  },
  {
    "country": "TH",
    "name": "Mueang Suang",
    "lat": "15.82192",
    "lng": "103.72884"
  },
  {
    "country": "TH",
    "name": "Muang Sam Sip",
    "lat": "15.51307",
    "lng": "104.72565"
  },
  {
    "country": "TH",
    "name": "Min Buri",
    "lat": "13.81407",
    "lng": "100.73135"
  },
  {
    "country": "TH",
    "name": "Moeiwadi",
    "lat": "16.38944",
    "lng": "104.1572"
  },
  {
    "country": "TH",
    "name": "Mayo",
    "lat": "6.71864",
    "lng": "101.40983"
  },
  {
    "country": "TH",
    "name": "Manorom",
    "lat": "15.30997",
    "lng": "100.08283"
  },
  {
    "country": "TH",
    "name": "Mancha Khiri",
    "lat": "16.13048",
    "lng": "102.53712"
  },
  {
    "country": "TH",
    "name": "Makham",
    "lat": "12.67292",
    "lng": "102.19575"
  },
  {
    "country": "TH",
    "name": "Mai Kaen",
    "lat": "6.60975",
    "lng": "101.66686"
  },
  {
    "country": "TH",
    "name": "Maha Sarakham",
    "lat": "16.18483",
    "lng": "103.30067"
  },
  {
    "country": "TH",
    "name": "Maha Rat",
    "lat": "14.53367",
    "lng": "100.52672"
  },
  {
    "country": "TH",
    "name": "Maha Chana Chai",
    "lat": "15.52935",
    "lng": "104.23847"
  },
  {
    "country": "TH",
    "name": "Mae Charim",
    "lat": "18.70614",
    "lng": "101.0057"
  },
  {
    "country": "TH",
    "name": "Lop Buri",
    "lat": "14.79808",
    "lng": "100.65397"
  },
  {
    "country": "TH",
    "name": "Lom Sak",
    "lat": "16.77983",
    "lng": "101.24225"
  },
  {
    "country": "TH",
    "name": "Lom Kao",
    "lat": "16.88614",
    "lng": "101.22894"
  },
  {
    "country": "TH",
    "name": "Loeng Nok Tha",
    "lat": "16.2075",
    "lng": "104.55528"
  },
  {
    "country": "TH",
    "name": "Loei",
    "lat": "17.49052",
    "lng": "101.72749"
  },
  {
    "country": "TH",
    "name": "Lat Lum Kaeo",
    "lat": "14.03728",
    "lng": "100.40486"
  },
  {
    "country": "TH",
    "name": "Lat Bua Luang",
    "lat": "14.16572",
    "lng": "100.30789"
  },
  {
    "country": "TH",
    "name": "Lap Lae",
    "lat": "17.65211",
    "lng": "100.03892"
  },
  {
    "country": "TH",
    "name": "Lam Plai Mat",
    "lat": "15.0252",
    "lng": "102.83894"
  },
  {
    "country": "TH",
    "name": "Lam Luk Ka",
    "lat": "13.93226",
    "lng": "100.74937"
  },
  {
    "country": "TH",
    "name": "Lamduan",
    "lat": "14.72205",
    "lng": "103.66934"
  },
  {
    "country": "TH",
    "name": "Lahan Sai",
    "lat": "14.41142",
    "lng": "102.85936"
  },
  {
    "country": "TH",
    "name": "Laem Sing",
    "lat": "12.48164",
    "lng": "102.07375"
  },
  {
    "country": "TH",
    "name": "Laem Ngop",
    "lat": "12.17169",
    "lng": "102.39489"
  },
  {
    "country": "TH",
    "name": "Kut Khaopun",
    "lat": "15.79267",
    "lng": "104.99814"
  },
  {
    "country": "TH",
    "name": "Kut Chum",
    "lat": "16.03289",
    "lng": "104.33936"
  },
  {
    "country": "TH",
    "name": "Kut Chap",
    "lat": "17.4257",
    "lng": "102.56692"
  },
  {
    "country": "TH",
    "name": "Kut Bak",
    "lat": "17.08882",
    "lng": "103.81875"
  },
  {
    "country": "TH",
    "name": "Kusuman",
    "lat": "17.33259",
    "lng": "104.33147"
  },
  {
    "country": "TH",
    "name": "Kumphawapi",
    "lat": "17.10875",
    "lng": "103.01487"
  },
  {
    "country": "TH",
    "name": "Kuchinarai",
    "lat": "16.541",
    "lng": "104.05004"
  },
  {
    "country": "TH",
    "name": "Bangkok",
    "lat": "13.75398",
    "lng": "100.50144"
  },
  {
    "country": "TH",
    "name": "Krok Phra",
    "lat": "15.55589",
    "lng": "100.07153"
  },
  {
    "country": "TH",
    "name": "Krathum Baen",
    "lat": "13.6533",
    "lng": "100.25972"
  },
  {
    "country": "TH",
    "name": "Krasang",
    "lat": "14.92375",
    "lng": "103.30369"
  },
  {
    "country": "TH",
    "name": "Krasae Sin",
    "lat": "7.61548",
    "lng": "100.32842"
  },
  {
    "country": "TH",
    "name": "Kranuan",
    "lat": "16.70672",
    "lng": "103.07878"
  },
  {
    "country": "TH",
    "name": "Kosum Phisai",
    "lat": "16.24858",
    "lng": "103.06739"
  },
  {
    "country": "TH",
    "name": "Ko Si Chang",
    "lat": "13.16389",
    "lng": "100.80547"
  },
  {
    "country": "TH",
    "name": "Klaeng",
    "lat": "12.77972",
    "lng": "101.64831"
  },
  {
    "country": "TH",
    "name": "Khun Han",
    "lat": "14.61739",
    "lng": "104.42506"
  },
  {
    "country": "TH",
    "name": "Khu Mueang",
    "lat": "15.2716",
    "lng": "103.00167"
  },
  {
    "country": "TH",
    "name": "Khu Khan",
    "lat": "14.71358",
    "lng": "104.19836"
  },
  {
    "country": "TH",
    "name": "Khuan Niang",
    "lat": "7.19138",
    "lng": "100.35355"
  },
  {
    "country": "TH",
    "name": "Khuan Khanun",
    "lat": "7.7347",
    "lng": "100.00931"
  },
  {
    "country": "TH",
    "name": "Khuan Kalong",
    "lat": "6.84538",
    "lng": "100.07148"
  },
  {
    "country": "TH",
    "name": "Khueang Nai",
    "lat": "15.38989",
    "lng": "104.55083"
  },
  {
    "country": "TH",
    "name": "Khuan Don",
    "lat": "6.78758",
    "lng": "100.07778"
  },
  {
    "country": "TH",
    "name": "Kho Wang",
    "lat": "15.36998",
    "lng": "104.35231"
  },
  {
    "country": "TH",
    "name": "Khon Sawan",
    "lat": "15.93192",
    "lng": "102.28103"
  },
  {
    "country": "TH",
    "name": "Khon San",
    "lat": "16.61286",
    "lng": "101.91944"
  },
  {
    "country": "TH",
    "name": "Khon Kaen",
    "lat": "16.44671",
    "lng": "102.833"
  },
  {
    "country": "TH",
    "name": "Khong Chiam",
    "lat": "15.31856",
    "lng": "105.49506"
  },
  {
    "country": "TH",
    "name": "Khong",
    "lat": "15.44393",
    "lng": "102.32862"
  },
  {
    "country": "TH",
    "name": "Khon Buri",
    "lat": "14.52541",
    "lng": "102.24591"
  },
  {
    "country": "TH",
    "name": "Khok Si Suphan",
    "lat": "17.04507",
    "lng": "104.2756"
  },
  {
    "country": "TH",
    "name": "Khok Samrong",
    "lat": "15.06649",
    "lng": "100.72233"
  },
  {
    "country": "TH",
    "name": "Khok Pho",
    "lat": "6.73064",
    "lng": "101.09619"
  },
  {
    "country": "TH",
    "name": "Khok Charoen",
    "lat": "15.37927",
    "lng": "100.8187"
  },
  {
    "country": "TH",
    "name": "Khlung",
    "lat": "12.45467",
    "lng": "102.22142"
  },
  {
    "country": "TH",
    "name": "Khlong Yai",
    "lat": "11.77645",
    "lng": "102.88567"
  },
  {
    "country": "TH",
    "name": "Khlong San",
    "lat": "13.73086",
    "lng": "100.50903"
  },
  {
    "country": "TH",
    "name": "Khlong Luang",
    "lat": "14.06467",
    "lng": "100.64578"
  },
  {
    "country": "TH",
    "name": "Khlong Hat",
    "lat": "13.45177",
    "lng": "102.29823"
  },
  {
    "country": "TH",
    "name": "Khemarat",
    "lat": "16.04252",
    "lng": "105.21836"
  },
  {
    "country": "TH",
    "name": "Khao Wong",
    "lat": "16.70008",
    "lng": "104.09019"
  },
  {
    "country": "TH",
    "name": "Khao Saming",
    "lat": "12.35353",
    "lng": "102.4355"
  },
  {
    "country": "TH",
    "name": "Khao Chaison",
    "lat": "7.46125",
    "lng": "100.13372"
  },
  {
    "country": "TH",
    "name": "Kham Thale So",
    "lat": "14.96083",
    "lng": "101.94789"
  },
  {
    "country": "TH",
    "name": "Kham Ta Kla",
    "lat": "17.85231",
    "lng": "103.75657"
  },
  {
    "country": "TH",
    "name": "Kham Sakae Saeng",
    "lat": "15.33221",
    "lng": "102.17278"
  },
  {
    "country": "TH",
    "name": "Kham Muang",
    "lat": "16.92902",
    "lng": "103.63518"
  },
  {
    "country": "TH",
    "name": "Kham Khuean Kaeo",
    "lat": "15.65233",
    "lng": "104.30861"
  },
  {
    "country": "TH",
    "name": "Khamcha-i",
    "lat": "16.57764",
    "lng": "104.41956"
  },
  {
    "country": "TH",
    "name": "Kaset Wisai",
    "lat": "15.65558",
    "lng": "103.58361"
  },
  {
    "country": "TH",
    "name": "Kaset Sombun",
    "lat": "16.28053",
    "lng": "101.95422"
  },
  {
    "country": "TH",
    "name": "Kao Liao",
    "lat": "15.85053",
    "lng": "100.07914"
  },
  {
    "country": "TH",
    "name": "Kantharawichai",
    "lat": "16.32719",
    "lng": "103.29864"
  },
  {
    "country": "TH",
    "name": "Kanthararom",
    "lat": "15.10323",
    "lng": "104.57343"
  },
  {
    "country": "TH",
    "name": "Kantharalak",
    "lat": "14.64056",
    "lng": "104.64992"
  },
  {
    "country": "TH",
    "name": "Krong Pi Nang",
    "lat": "6.4112",
    "lng": "101.27394"
  },
  {
    "country": "TH",
    "name": "Su-ngai Padi",
    "lat": "6.0857",
    "lng": "101.87959"
  },
  {
    "country": "TH",
    "name": "Ka Bang",
    "lat": "6.41536",
    "lng": "101.05456"
  },
  {
    "country": "TH",
    "name": "Cho-airong",
    "lat": "6.22553",
    "lng": "101.81128"
  },
  {
    "country": "TH",
    "name": "Kamphaeng Saen",
    "lat": "13.99966",
    "lng": "99.98981"
  },
  {
    "country": "TH",
    "name": "Kamalasai",
    "lat": "16.33839",
    "lng": "103.57564"
  },
  {
    "country": "TH",
    "name": "Kalasin",
    "lat": "16.43281",
    "lng": "103.50658"
  },
  {
    "country": "TH",
    "name": "Kaeng Khoi",
    "lat": "14.58617",
    "lng": "100.99758"
  },
  {
    "country": "TH",
    "name": "Kaeng Khro",
    "lat": "16.10864",
    "lng": "102.25808"
  },
  {
    "country": "TH",
    "name": "Kae Dam",
    "lat": "16.02397",
    "lng": "103.38444"
  },
  {
    "country": "TH",
    "name": "Kabin Buri",
    "lat": "13.95114",
    "lng": "101.71769"
  },
  {
    "country": "TH",
    "name": "In Buri",
    "lat": "15.00787",
    "lng": "100.32691"
  },
  {
    "country": "TH",
    "name": "Hua Taphan",
    "lat": "15.6971",
    "lng": "104.4916"
  },
  {
    "country": "TH",
    "name": "Hua Sai",
    "lat": "8.04408",
    "lng": "100.30586"
  },
  {
    "country": "TH",
    "name": "Huai Thap Than",
    "lat": "15.05333",
    "lng": "104.02754"
  },
  {
    "country": "TH",
    "name": "Huai Thalaeng",
    "lat": "14.99701",
    "lng": "102.64746"
  },
  {
    "country": "TH",
    "name": "Huai Phueng",
    "lat": "16.65038",
    "lng": "103.91005"
  },
  {
    "country": "TH",
    "name": "Huai Mek",
    "lat": "16.58975",
    "lng": "103.23547"
  },
  {
    "country": "TH",
    "name": "Hat Yai",
    "lat": "7.00836",
    "lng": "100.47668"
  },
  {
    "country": "TH",
    "name": "Hankha",
    "lat": "14.98122",
    "lng": "100.0147"
  },
  {
    "country": "TH",
    "name": "Fak Tha",
    "lat": "17.99948",
    "lng": "100.88014"
  },
  {
    "country": "TH",
    "name": "Dusit",
    "lat": "13.7775",
    "lng": "100.51977"
  },
  {
    "country": "TH",
    "name": "Don Tan",
    "lat": "16.31697",
    "lng": "104.92"
  },
  {
    "country": "TH",
    "name": "Dong Luang",
    "lat": "16.81589",
    "lng": "104.538"
  },
  {
    "country": "TH",
    "name": "Don Chedi",
    "lat": "14.63497",
    "lng": "100.02097"
  },
  {
    "country": "TH",
    "name": "Doembang Nangbuat",
    "lat": "14.83333",
    "lng": "100.1"
  },
  {
    "country": "TH",
    "name": "Det Udom",
    "lat": "14.90598",
    "lng": "105.07836"
  },
  {
    "country": "TH",
    "name": "Den Chai",
    "lat": "17.98372",
    "lng": "100.05217"
  },
  {
    "country": "TH",
    "name": "Dan Sai",
    "lat": "17.28011",
    "lng": "101.14686"
  },
  {
    "country": "TH",
    "name": "Dan Khun Thot",
    "lat": "15.2085",
    "lng": "101.77138"
  },
  {
    "country": "TH",
    "name": "Chum Phuang",
    "lat": "15.34861",
    "lng": "102.74161"
  },
  {
    "country": "TH",
    "name": "Chumphon Buri",
    "lat": "15.34862",
    "lng": "103.39217"
  },
  {
    "country": "TH",
    "name": "Chum Phae",
    "lat": "16.5443",
    "lng": "102.09924"
  },
  {
    "country": "TH",
    "name": "Chonnabot",
    "lat": "16.08861",
    "lng": "102.62178"
  },
  {
    "country": "TH",
    "name": "Chon Daen",
    "lat": "16.18953",
    "lng": "100.85958"
  },
  {
    "country": "TH",
    "name": "Chon Buri",
    "lat": "13.3622",
    "lng": "100.98345"
  },
  {
    "country": "TH",
    "name": "Chom Phra",
    "lat": "15.11814",
    "lng": "103.60743"
  },
  {
    "country": "TH",
    "name": "Chok Chai",
    "lat": "14.72844",
    "lng": "102.16524"
  },
  {
    "country": "TH",
    "name": "Chian Yai",
    "lat": "8.16936",
    "lng": "100.14469"
  },
  {
    "country": "TH",
    "name": "Chiang Yuen",
    "lat": "16.41042",
    "lng": "103.09767"
  },
  {
    "country": "TH",
    "name": "Chiang Saen",
    "lat": "20.27511",
    "lng": "100.08689"
  },
  {
    "country": "TH",
    "name": "Chiang Klang",
    "lat": "19.29378",
    "lng": "100.86169"
  },
  {
    "country": "TH",
    "name": "Chiang Khong",
    "lat": "20.26125",
    "lng": "100.40461"
  },
  {
    "country": "TH",
    "name": "Chiang Khan",
    "lat": "17.89382",
    "lng": "101.65997"
  },
  {
    "country": "TH",
    "name": "Chiang Kham",
    "lat": "19.52331",
    "lng": "100.3"
  },
  {
    "country": "TH",
    "name": "Cha-uat",
    "lat": "7.96773",
    "lng": "99.99985"
  },
  {
    "country": "TH",
    "name": "Chaturaphak Phiman",
    "lat": "15.84572",
    "lng": "103.55719"
  },
  {
    "country": "TH",
    "name": "Chatturat",
    "lat": "15.56542",
    "lng": "101.84547"
  },
  {
    "country": "TH",
    "name": "Chat Trakan",
    "lat": "17.27606",
    "lng": "100.60022"
  },
  {
    "country": "TH",
    "name": "Chanuman",
    "lat": "16.23356",
    "lng": "105.0005"
  },
  {
    "country": "TH",
    "name": "Chanthaburi",
    "lat": "12.60961",
    "lng": "102.10447"
  },
  {
    "country": "TH",
    "name": "Chanae",
    "lat": "6.09914",
    "lng": "101.69353"
  },
  {
    "country": "TH",
    "name": "Chana",
    "lat": "6.91542",
    "lng": "100.74039"
  },
  {
    "country": "TH",
    "name": "Chaloem Phra Kiat",
    "lat": "15.00508",
    "lng": "102.27033"
  },
  {
    "country": "TH",
    "name": "Chaiyo",
    "lat": "14.64878",
    "lng": "100.47878"
  },
  {
    "country": "TH",
    "name": "Chaiyaphum",
    "lat": "15.81047",
    "lng": "102.02881"
  },
  {
    "country": "TH",
    "name": "Chaiwan",
    "lat": "17.29447",
    "lng": "103.23385"
  },
  {
    "country": "TH",
    "name": "Chai Nat",
    "lat": "15.18636",
    "lng": "100.12353"
  },
  {
    "country": "TH",
    "name": "Chai Badan",
    "lat": "15.2",
    "lng": "101.13333"
  },
  {
    "country": "TH",
    "name": "Chachoengsao",
    "lat": "13.6882",
    "lng": "101.07156"
  },
  {
    "country": "TH",
    "name": "Buri Ram",
    "lat": "14.99433",
    "lng": "103.10392"
  },
  {
    "country": "TH",
    "name": "Buntharik",
    "lat": "14.75639",
    "lng": "105.41147"
  },
  {
    "country": "TH",
    "name": "Bueng Sam Phan",
    "lat": "15.83024",
    "lng": "100.91938"
  },
  {
    "country": "TH",
    "name": "Bueng Khong Long",
    "lat": "17.96129",
    "lng": "104.04667"
  },
  {
    "country": "TH",
    "name": "Bueng Kan",
    "lat": "18.36303",
    "lng": "103.65194"
  },
  {
    "country": "TH",
    "name": "Bua Yai",
    "lat": "15.58552",
    "lng": "102.42587"
  },
  {
    "country": "TH",
    "name": "Bua Chet",
    "lat": "14.52814",
    "lng": "103.94567"
  },
  {
    "country": "TH",
    "name": "Bo Thong",
    "lat": "13.27825",
    "lng": "101.44028"
  },
  {
    "country": "TH",
    "name": "Bo Rai",
    "lat": "12.57283",
    "lng": "102.53714"
  },
  {
    "country": "TH",
    "name": "Borabue",
    "lat": "16.04179",
    "lng": "103.11506"
  },
  {
    "country": "TH",
    "name": "Bo Kluea",
    "lat": "19.15029",
    "lng": "101.1556"
  },
  {
    "country": "TH",
    "name": "Betong",
    "lat": "5.77434",
    "lng": "101.07231"
  },
  {
    "country": "TH",
    "name": "Wang Pong",
    "lat": "16.34147",
    "lng": "100.79317"
  },
  {
    "country": "TH",
    "name": "Wang Muang",
    "lat": "14.84228",
    "lng": "101.1255"
  },
  {
    "country": "TH",
    "name": "Ban Thai Tan",
    "lat": "14.62161",
    "lng": "100.48739"
  },
  {
    "country": "TH",
    "name": "Ban Thaen",
    "lat": "16.40506",
    "lng": "102.34239"
  },
  {
    "country": "TH",
    "name": "Song Khwae",
    "lat": "19.35964",
    "lng": "100.70042"
  },
  {
    "country": "TH",
    "name": "Ban Selaphum",
    "lat": "16.01667",
    "lng": "103.95"
  },
  {
    "country": "TH",
    "name": "Sawang Wirawong",
    "lat": "15.24158",
    "lng": "105.0922"
  },
  {
    "country": "TH",
    "name": "Ban Sang",
    "lat": "13.99503",
    "lng": "101.22095"
  },
  {
    "country": "TH",
    "name": "Ban Sam Chuk",
    "lat": "14.74219",
    "lng": "100.09531"
  },
  {
    "country": "TH",
    "name": "Ratchasan",
    "lat": "13.78211",
    "lng": "101.28133"
  },
  {
    "country": "TH",
    "name": "Ban Phue",
    "lat": "17.68877",
    "lng": "102.47878"
  },
  {
    "country": "TH",
    "name": "Ban Phraek",
    "lat": "14.64681",
    "lng": "100.57617"
  },
  {
    "country": "TH",
    "name": "Ban Pho",
    "lat": "13.59864",
    "lng": "101.07956"
  },
  {
    "country": "TH",
    "name": "Ban Phe",
    "lat": "12.62824",
    "lng": "101.43757"
  },
  {
    "country": "TH",
    "name": "Pattaya",
    "lat": "12.93333",
    "lng": "100.88333"
  },
  {
    "country": "TH",
    "name": "Ban Phan Don",
    "lat": "17.14272",
    "lng": "102.97261"
  },
  {
    "country": "TH",
    "name": "Ban Phai",
    "lat": "16.05997",
    "lng": "102.73097"
  },
  {
    "country": "TH",
    "name": "Ban Phaeo",
    "lat": "13.59072",
    "lng": "100.10748"
  },
  {
    "country": "TH",
    "name": "Ban Phaeng",
    "lat": "17.96507",
    "lng": "104.21534"
  },
  {
    "country": "TH",
    "name": "Pak Chom",
    "lat": "18.02061",
    "lng": "101.89828"
  },
  {
    "country": "TH",
    "name": "Nong Muang Khai",
    "lat": "18.26464",
    "lng": "100.18967"
  },
  {
    "country": "TH",
    "name": "Nong Don",
    "lat": "14.68488",
    "lng": "100.7094"
  },
  {
    "country": "TH",
    "name": "Na Yia",
    "lat": "15.06367",
    "lng": "105.05994"
  },
  {
    "country": "TH",
    "name": "Na Yai Am",
    "lat": "12.78153",
    "lng": "101.82256"
  },
  {
    "country": "TH",
    "name": "Na Thom",
    "lat": "17.78491",
    "lng": "104.09082"
  },
  {
    "country": "TH",
    "name": "Ban Nang Sata",
    "lat": "6.26638",
    "lng": "101.26461"
  },
  {
    "country": "TH",
    "name": "Na Khu",
    "lat": "16.76384",
    "lng": "104.02626"
  },
  {
    "country": "TH",
    "name": "Na Haeo",
    "lat": "17.48536",
    "lng": "101.06808"
  },
  {
    "country": "TH",
    "name": "Na Di",
    "lat": "14.11517",
    "lng": "101.78189"
  },
  {
    "country": "TH",
    "name": "Ban Na",
    "lat": "14.26238",
    "lng": "101.07111"
  },
  {
    "country": "TH",
    "name": "Ban Muang",
    "lat": "17.8508",
    "lng": "103.56939"
  },
  {
    "country": "TH",
    "name": "Muak Lek",
    "lat": "14.65287",
    "lng": "101.20022"
  },
  {
    "country": "TH",
    "name": "Ban Mo",
    "lat": "14.61544",
    "lng": "100.72731"
  },
  {
    "country": "TH",
    "name": "Ban Mi",
    "lat": "15.04428",
    "lng": "100.53681"
  },
  {
    "country": "TH",
    "name": "Mae Lan",
    "lat": "6.66114",
    "lng": "101.23958"
  },
  {
    "country": "TH",
    "name": "Chiang Muan",
    "lat": "18.88969",
    "lng": "100.30589"
  },
  {
    "country": "TH",
    "name": "Ban Luang",
    "lat": "18.84969",
    "lng": "100.43725"
  },
  {
    "country": "TH",
    "name": "Ban Lueam",
    "lat": "15.60916",
    "lng": "102.12928"
  },
  {
    "country": "TH",
    "name": "Lao Suea Kok",
    "lat": "15.4183",
    "lng": "104.92363"
  },
  {
    "country": "TH",
    "name": "Ban Lam Luk Ka",
    "lat": "13.97738",
    "lng": "100.77776"
  },
  {
    "country": "TH",
    "name": "Kut Rang",
    "lat": "16.09398",
    "lng": "103.00998"
  },
  {
    "country": "TH",
    "name": "Ban Kruat",
    "lat": "14.42313",
    "lng": "103.09974"
  },
  {
    "country": "TH",
    "name": "Ban Ko Lan",
    "lat": "12.92419",
    "lng": "100.78794"
  },
  {
    "country": "TH",
    "name": "Ban Khwao",
    "lat": "15.77772",
    "lng": "101.9072"
  },
  {
    "country": "TH",
    "name": "Khok Sung",
    "lat": "13.83824",
    "lng": "102.62254"
  },
  {
    "country": "TH",
    "name": "Bang Rachan",
    "lat": "14.79717",
    "lng": "100.3065"
  },
  {
    "country": "TH",
    "name": "Ban Khok",
    "lat": "18.02614",
    "lng": "101.06772"
  },
  {
    "country": "TH",
    "name": "Khlong Khuean",
    "lat": "13.79131",
    "lng": "101.16353"
  },
  {
    "country": "TH",
    "name": "Khlong Hoi Khong",
    "lat": "6.89865",
    "lng": "100.38885"
  },
  {
    "country": "TH",
    "name": "Khao Chakan",
    "lat": "13.6535",
    "lng": "102.08825"
  },
  {
    "country": "TH",
    "name": "Ban Khai",
    "lat": "12.78261",
    "lng": "101.29639"
  },
  {
    "country": "TH",
    "name": "Kap Choeng",
    "lat": "14.47486",
    "lng": "103.59439"
  },
  {
    "country": "TH",
    "name": "Kapho",
    "lat": "6.55968",
    "lng": "101.53426"
  },
  {
    "country": "TH",
    "name": "Kaeng Sanam Nang",
    "lat": "15.74954",
    "lng": "102.25484"
  },
  {
    "country": "TH",
    "name": "Kaeng Hang Maeo",
    "lat": "13.00825",
    "lng": "101.90608"
  },
  {
    "country": "TH",
    "name": "Bang Yai",
    "lat": "13.84341",
    "lng": "100.36251"
  },
  {
    "country": "TH",
    "name": "Bang Sai",
    "lat": "14.33433",
    "lng": "100.30378"
  },
  {
    "country": "TH",
    "name": "Bang Rakam",
    "lat": "16.75847",
    "lng": "100.11742"
  },
  {
    "country": "TH",
    "name": "Bang Rak",
    "lat": "13.73058",
    "lng": "100.52388"
  },
  {
    "country": "TH",
    "name": "Bang Racham",
    "lat": "14.892",
    "lng": "100.31728"
  },
  {
    "country": "TH",
    "name": "Bang Pla Ma",
    "lat": "14.39604",
    "lng": "100.1587"
  },
  {
    "country": "TH",
    "name": "Bang Pakong",
    "lat": "13.54297",
    "lng": "100.99333"
  },
  {
    "country": "TH",
    "name": "Bang Pa-in",
    "lat": "14.22783",
    "lng": "100.57589"
  },
  {
    "country": "TH",
    "name": "Bang Pahan",
    "lat": "14.46217",
    "lng": "100.54478"
  },
  {
    "country": "TH",
    "name": "Bang Nam Priao",
    "lat": "13.84739",
    "lng": "101.05306"
  },
  {
    "country": "TH",
    "name": "Bang Mun Nak",
    "lat": "16.02781",
    "lng": "100.37917"
  },
  {
    "country": "TH",
    "name": "Bang Len",
    "lat": "14.02188",
    "lng": "100.17183"
  },
  {
    "country": "TH",
    "name": "Bang Lamung",
    "lat": "13.04704",
    "lng": "100.92891"
  },
  {
    "country": "TH",
    "name": "Bang Kruai",
    "lat": "13.805",
    "lng": "100.47283"
  },
  {
    "country": "TH",
    "name": "Bang Krathum",
    "lat": "16.57831",
    "lng": "100.30034"
  },
  {
    "country": "TH",
    "name": "Bangkok Yai",
    "lat": "13.72319",
    "lng": "100.476"
  },
  {
    "country": "TH",
    "name": "Bangkok Noi",
    "lat": "13.76266",
    "lng": "100.47798"
  },
  {
    "country": "TH",
    "name": "Bang Khun Thian",
    "lat": "13.66302",
    "lng": "100.43416"
  },
  {
    "country": "TH",
    "name": "Bang Khla",
    "lat": "13.72144",
    "lng": "101.20814"
  },
  {
    "country": "TH",
    "name": "Bang Kapi",
    "lat": "13.7653",
    "lng": "100.647"
  },
  {
    "country": "TH",
    "name": "Bang Bua Thong",
    "lat": "13.91783",
    "lng": "100.42403"
  },
  {
    "country": "TH",
    "name": "Bang Bo",
    "lat": "13.57428",
    "lng": "100.83533"
  },
  {
    "country": "TH",
    "name": "Bang Ban",
    "lat": "14.37395",
    "lng": "100.48528"
  },
  {
    "country": "TH",
    "name": "Ban Fang",
    "lat": "16.45331",
    "lng": "102.63892"
  },
  {
    "country": "TH",
    "name": "Ban Dung",
    "lat": "17.699",
    "lng": "103.25957"
  },
  {
    "country": "TH",
    "name": "Don Phut",
    "lat": "14.59175",
    "lng": "100.62828"
  },
  {
    "country": "TH",
    "name": "Ban Chang",
    "lat": "12.72543",
    "lng": "101.05531"
  },
  {
    "country": "TH",
    "name": "Chamni",
    "lat": "14.78629",
    "lng": "102.82277"
  },
  {
    "country": "TH",
    "name": "Chakkarat",
    "lat": "15.01353",
    "lng": "102.41289"
  },
  {
    "country": "TH",
    "name": "Ban Bueng",
    "lat": "13.311",
    "lng": "101.11214"
  },
  {
    "country": "TH",
    "name": "Bueng Na Rang",
    "lat": "16.1712",
    "lng": "100.12531"
  },
  {
    "country": "TH",
    "name": "Ban Talat Bueng",
    "lat": "13.07147",
    "lng": "101.00314"
  },
  {
    "country": "TH",
    "name": "Bang Na",
    "lat": "13.66744",
    "lng": "100.64206"
  },
  {
    "country": "TH",
    "name": "Bang Klam",
    "lat": "7.08953",
    "lng": "100.41075"
  },
  {
    "country": "TH",
    "name": "Bang Kaeo",
    "lat": "7.42947",
    "lng": "100.17803"
  },
  {
    "country": "TH",
    "name": "Ban Bang Kadi Pathum Thani",
    "lat": "13.99904",
    "lng": "100.54962"
  },
  {
    "country": "TH",
    "name": "Bang Bo District",
    "lat": "13.58333",
    "lng": "100.81667"
  },
  {
    "country": "TH",
    "name": "Lue Amnat",
    "lat": "15.69476",
    "lng": "104.64846"
  },
  {
    "country": "TH",
    "name": "Bamnet Narong",
    "lat": "15.50189",
    "lng": "101.68982"
  },
  {
    "country": "TH",
    "name": "At Samat",
    "lat": "15.84308",
    "lng": "103.87839"
  },
  {
    "country": "TH",
    "name": "Aranyaprathet",
    "lat": "13.69276",
    "lng": "102.50128"
  },
  {
    "country": "TH",
    "name": "Ang Thong",
    "lat": "14.58839",
    "lng": "100.45283"
  },
  {
    "country": "TH",
    "name": "Amnat Charoen",
    "lat": "15.85851",
    "lng": "104.62883"
  },
  {
    "country": "TH",
    "name": "Akat Amnuai",
    "lat": "17.59639",
    "lng": "103.9816"
  },
  {
    "country": "TH",
    "name": "Phon Charoen",
    "lat": "18.03143",
    "lng": "103.70996"
  },
  {
    "country": "TH",
    "name": "Chaiyo",
    "lat": "14.67639",
    "lng": "100.46861"
  },
  {
    "country": "TH",
    "name": "Samrong",
    "lat": "15.00781",
    "lng": "104.78419"
  },
  {
    "country": "TH",
    "name": "Bueng Bun",
    "lat": "15.3303",
    "lng": "104.04485"
  },
  {
    "country": "TH",
    "name": "Song Dao",
    "lat": "17.33628",
    "lng": "103.47547"
  },
  {
    "country": "TH",
    "name": "Thung Yang Daeng",
    "lat": "6.61822",
    "lng": "101.4265"
  },
  {
    "country": "TH",
    "name": "Amphoe Sikhiu",
    "lat": "14.89944",
    "lng": "101.70833"
  },
  {
    "country": "TH",
    "name": "Phanom Dong Rak",
    "lat": "14.44575",
    "lng": "103.30508"
  },
  {
    "country": "TH",
    "name": "Saladan",
    "lat": "7.61342",
    "lng": "99.03651"
  },
  {
    "country": "TH",
    "name": "Wichit",
    "lat": "7.8894",
    "lng": "98.38523"
  },
  {
    "country": "TH",
    "name": "Ko Pha Ngan",
    "lat": "9.75778",
    "lng": "100.02914"
  },
  {
    "country": "TH",
    "name": "Koh Tao",
    "lat": "10.09808",
    "lng": "99.83809"
  },
  {
    "country": "TH",
    "name": "Bang Sue",
    "lat": "13.81003",
    "lng": "100.53714"
  },
  {
    "country": "TH",
    "name": "Don Mueang",
    "lat": "13.91392",
    "lng": "100.58994"
  },
  {
    "country": "TH",
    "name": "Salaya",
    "lat": "13.802",
    "lng": "100.32111"
  },
  {
    "country": "TH",
    "name": "Khlong Toei",
    "lat": "13.71669",
    "lng": "100.57159"
  },
  {
    "country": "TH",
    "name": "Patong",
    "lat": "7.89607",
    "lng": "98.29661"
  },
  {
    "country": "TH",
    "name": "Chun",
    "lat": "19.33695",
    "lng": "100.13478"
  },
  {
    "country": "TH",
    "name": "Thung Chang",
    "lat": "19.38786",
    "lng": "100.87619"
  },
  {
    "country": "TH",
    "name": "Lat Krabang",
    "lat": "13.72341",
    "lng": "100.78436"
  },
  {
    "country": "TH",
    "name": "Bang Khae",
    "lat": "13.69196",
    "lng": "100.40691"
  },
  {
    "country": "TH",
    "name": "Bang Kho Laem",
    "lat": "13.69347",
    "lng": "100.5022"
  },
  {
    "country": "TH",
    "name": "Bueng Kum",
    "lat": "13.78528",
    "lng": "100.66958"
  },
  {
    "country": "TH",
    "name": "Chatuchak",
    "lat": "13.82893",
    "lng": "100.55985"
  },
  {
    "country": "TH",
    "name": "Chom Thong",
    "lat": "13.67717",
    "lng": "100.48407"
  },
  {
    "country": "TH",
    "name": "Huai Khwang",
    "lat": "13.77678",
    "lng": "100.579"
  },
  {
    "country": "TH",
    "name": "Khan Na Yao",
    "lat": "13.82609",
    "lng": "100.67933"
  },
  {
    "country": "TH",
    "name": "Khlong Sam Wa",
    "lat": "13.83616",
    "lng": "100.73524"
  },
  {
    "country": "TH",
    "name": "Lat Phrao",
    "lat": "13.80349",
    "lng": "100.60749"
  },
  {
    "country": "TH",
    "name": "Pathum Wan",
    "lat": "13.73649",
    "lng": "100.5239"
  },
  {
    "country": "TH",
    "name": "Phaya Thai",
    "lat": "13.78005",
    "lng": "100.54275"
  },
  {
    "country": "TH",
    "name": "Ratchathewi",
    "lat": "13.759",
    "lng": "100.53358"
  },
  {
    "country": "TH",
    "name": "Sai Mai",
    "lat": "13.92068",
    "lng": "100.64552"
  },
  {
    "country": "TH",
    "name": "Saphan Sung",
    "lat": "13.77019",
    "lng": "100.68531"
  },
  {
    "country": "TH",
    "name": "Sathon",
    "lat": "13.7085",
    "lng": "100.52619"
  },
  {
    "country": "TH",
    "name": "Suan Luang",
    "lat": "13.73028",
    "lng": "100.65138"
  },
  {
    "country": "TH",
    "name": "Thawi Watthana",
    "lat": "13.78851",
    "lng": "100.33334"
  },
  {
    "country": "TH",
    "name": "Thung Khru",
    "lat": "13.62875",
    "lng": "100.50964"
  },
  {
    "country": "TH",
    "name": "Wang Thonglang",
    "lat": "13.78546",
    "lng": "100.61165"
  },
  {
    "country": "TH",
    "name": "Watthana",
    "lat": "13.72978",
    "lng": "100.58536"
  },
  {
    "country": "TH",
    "name": "Sop Pong",
    "lat": "19.51881",
    "lng": "98.26042"
  },
  {
    "country": "TH",
    "name": "Ban Chalong",
    "lat": "7.84468",
    "lng": "98.33897"
  },
  {
    "country": "TH",
    "name": "Ban Ratsada",
    "lat": "7.90963",
    "lng": "98.40248"
  },
  {
    "country": "TH",
    "name": "Mueang Phuket",
    "lat": "7.86338",
    "lng": "98.36437"
  },
  {
    "country": "TH",
    "name": "Bang Sao Thong",
    "lat": "13.595",
    "lng": "100.83042"
  },
  {
    "country": "TH",
    "name": "Ko Chang Tai",
    "lat": "12.00171",
    "lng": "102.37267"
  },
  {
    "country": "TH",
    "name": "Nai Harn",
    "lat": "7.77859",
    "lng": "98.30661"
  },
  {
    "country": "TH",
    "name": "Mae Fa Luang",
    "lat": "20.26628",
    "lng": "99.79846"
  },
  {
    "country": "TH",
    "name": "Wiang Chiang Rung",
    "lat": "20.01328",
    "lng": "100.05639"
  },
  {
    "country": "TH",
    "name": "Wiang Kaen",
    "lat": "20.11297",
    "lng": "100.51331"
  },
  {
    "country": "TH",
    "name": "Khun Tan",
    "lat": "19.83353",
    "lng": "100.25858"
  },
  {
    "country": "TH",
    "name": "Chaloem Phra Kiat",
    "lat": "19.57881",
    "lng": "101.08011"
  },
  {
    "country": "TH",
    "name": "Mae Lao",
    "lat": "19.79003",
    "lng": "99.69967"
  },
  {
    "country": "TH",
    "name": "Suk Samran",
    "lat": "9.34458",
    "lng": "98.42903"
  },
  {
    "country": "TH",
    "name": "Ban Takhun",
    "lat": "8.90364",
    "lng": "98.8845"
  },
  {
    "country": "TH",
    "name": "Takuk Nuea",
    "lat": "9.23894",
    "lng": "98.97861"
  },
  {
    "country": "TH",
    "name": "Wiang Nong Long",
    "lat": "18.42043",
    "lng": "98.74967"
  },
  {
    "country": "TH",
    "name": "Mae Poen",
    "lat": "15.65789",
    "lng": "99.46981"
  },
  {
    "country": "TH",
    "name": "Pang Sila Thong",
    "lat": "16.09631",
    "lng": "99.48906"
  },
  {
    "country": "TH",
    "name": "Kosamphi Nakhon",
    "lat": "16.63131",
    "lng": "99.34975"
  },
  {
    "country": "TH",
    "name": "Ban Thi",
    "lat": "18.63186",
    "lng": "99.11661"
  },
  {
    "country": "TH",
    "name": "Manang",
    "lat": "6.99933",
    "lng": "99.92161"
  },
  {
    "country": "TH",
    "name": "Ratsada",
    "lat": "7.97467",
    "lng": "99.63353"
  },
  {
    "country": "TH",
    "name": "Phra Phrom",
    "lat": "8.33911",
    "lng": "99.90092"
  },
  {
    "country": "TH",
    "name": "Chulabhorn",
    "lat": "8.07597",
    "lng": "99.86947"
  },
  {
    "country": "TH",
    "name": "Chang Klang",
    "lat": "8.37094",
    "lng": "99.56249"
  },
  {
    "country": "TH",
    "name": "Nong Yasai",
    "lat": "14.77988",
    "lng": "99.91073"
  },
  {
    "country": "TH",
    "name": "Chum Ta Bong",
    "lat": "15.63194",
    "lng": "99.55231"
  },
  {
    "country": "TH",
    "name": "Mae Wong",
    "lat": "15.78164",
    "lng": "99.51864"
  },
  {
    "country": "TH",
    "name": "Bueng Samakkhi",
    "lat": "16.18728",
    "lng": "99.97525"
  },
  {
    "country": "TH",
    "name": "Phu Kam Yao",
    "lat": "19.2705",
    "lng": "99.97011"
  },
  {
    "country": "TH",
    "name": "Chaloem Phra Kiat",
    "lat": "8.17689",
    "lng": "100.03581"
  },
  {
    "country": "TH",
    "name": "Sawaengha",
    "lat": "14.75186",
    "lng": "100.32481"
  },
  {
    "country": "TH",
    "name": "Doem Bang Nang Buat",
    "lat": "14.85428",
    "lng": "100.09772"
  },
  {
    "country": "TH",
    "name": "Chumsaeng",
    "lat": "15.89152",
    "lng": "100.30795"
  },
  {
    "country": "TH",
    "name": "Wachira Barami",
    "lat": "16.52314",
    "lng": "100.14464"
  },
  {
    "country": "TH",
    "name": "Thong Saen Khan",
    "lat": "17.47065",
    "lng": "100.33146"
  },
  {
    "country": "TH",
    "name": "Laplae",
    "lat": "17.65211",
    "lng": "100.03892"
  },
  {
    "country": "TH",
    "name": "Chaloem Phra Kiat",
    "lat": "14.6115",
    "lng": "100.90825"
  },
  {
    "country": "TH",
    "name": "Santi Suk",
    "lat": "18.9137",
    "lng": "100.94169"
  },
  {
    "country": "TH",
    "name": "Phu Phiang",
    "lat": "18.74264",
    "lng": "100.79951"
  },
  {
    "country": "TH",
    "name": "Nikhom Phattana",
    "lat": "12.82736",
    "lng": "101.20273"
  },
  {
    "country": "TH",
    "name": "Ko Chan",
    "lat": "13.41658",
    "lng": "101.33458"
  },
  {
    "country": "TH",
    "name": "Si Mahosot",
    "lat": "13.8878",
    "lng": "101.40501"
  },
  {
    "country": "TH",
    "name": "Phakdi Chumphon",
    "lat": "15.90517",
    "lng": "101.42228"
  },
  {
    "country": "TH",
    "name": "Khao Chamao",
    "lat": "12.97586",
    "lng": "101.68511"
  },
  {
    "country": "TH",
    "name": "Tha Takiap",
    "lat": "13.44547",
    "lng": "101.61133"
  },
  {
    "country": "TH",
    "name": "Wang Nam Khiao",
    "lat": "14.41801",
    "lng": "101.86113"
  },
  {
    "country": "TH",
    "name": "Prachamtakham",
    "lat": "14.06442",
    "lng": "101.51503"
  },
  {
    "country": "TH",
    "name": "Sap Yai",
    "lat": "15.63739",
    "lng": "101.61671"
  },
  {
    "country": "TH",
    "name": "Erawan",
    "lat": "17.30181",
    "lng": "101.95382"
  },
  {
    "country": "TH",
    "name": "Khao Khitchakut",
    "lat": "12.80481",
    "lng": "102.11514"
  },
  {
    "country": "TH",
    "name": "Soi Dao",
    "lat": "13.12894",
    "lng": "102.21402"
  },
  {
    "country": "TH",
    "name": "Wang Sombun",
    "lat": "13.36176",
    "lng": "102.19105"
  },
  {
    "country": "TH",
    "name": "Noen Sa-nga",
    "lat": "15.56428",
    "lng": "102.00128"
  },
  {
    "country": "TH",
    "name": "Khok Pho Chai",
    "lat": "16.08375",
    "lng": "102.399"
  },
  {
    "country": "TH",
    "name": "Na Wang",
    "lat": "17.32444",
    "lng": "102.07829"
  },
  {
    "country": "TH",
    "name": "Suwanna Khuha",
    "lat": "17.56292",
    "lng": "102.27989"
  },
  {
    "country": "TH",
    "name": "Non Din Daeng",
    "lat": "14.31353",
    "lng": "102.74814"
  },
  {
    "country": "TH",
    "name": "Pa Kham",
    "lat": "14.43817",
    "lng": "102.72558"
  },
  {
    "country": "TH",
    "name": "Chaloem Phra Kiat",
    "lat": "14.55839",
    "lng": "102.92475"
  },
  {
    "country": "TH",
    "name": "Lam Thamen Chai",
    "lat": "15.3535",
    "lng": "102.91803"
  },
  {
    "country": "TH",
    "name": "Non Daeng",
    "lat": "15.41061",
    "lng": "102.54025"
  },
  {
    "country": "TH",
    "name": "Ban Mai Chaiyaphot",
    "lat": "15.57361",
    "lng": "102.83331"
  },
  {
    "country": "TH",
    "name": "Non Sila",
    "lat": "15.97439",
    "lng": "102.66983"
  },
  {
    "country": "TH",
    "name": "Ubonratana",
    "lat": "16.75269",
    "lng": "102.63245"
  },
  {
    "country": "TH",
    "name": "Ban Na Muang",
    "lat": "17.23824",
    "lng": "103.00892"
  },
  {
    "country": "TH",
    "name": "Sa Khrai",
    "lat": "17.67544",
    "lng": "102.75069"
  },
  {
    "country": "TH",
    "name": "Phlapphla Chai",
    "lat": "14.73011",
    "lng": "103.16728"
  },
  {
    "country": "TH",
    "name": "Si Somdet",
    "lat": "15.99797",
    "lng": "103.48789"
  },
  {
    "country": "TH",
    "name": "Khong Chai",
    "lat": "16.26025",
    "lng": "103.45828"
  },
  {
    "country": "TH",
    "name": "Chuen Chom",
    "lat": "16.55488",
    "lng": "103.17661"
  },
  {
    "country": "TH",
    "name": "Sam Sung",
    "lat": "16.5432",
    "lng": "103.07992"
  },
  {
    "country": "TH",
    "name": "Ku Kaeo",
    "lat": "17.17214",
    "lng": "103.15303"
  },
  {
    "country": "TH",
    "name": "Phibun Rak",
    "lat": "17.55312",
    "lng": "103.05794"
  },
  {
    "country": "TH",
    "name": "Pakkhat",
    "lat": "18.29789",
    "lng": "103.30689"
  },
  {
    "country": "TH",
    "name": "Phonphisai",
    "lat": "18.02106",
    "lng": "103.07664"
  },
  {
    "country": "TH",
    "name": "Si Narong",
    "lat": "14.76736",
    "lng": "103.87392"
  },
  {
    "country": "TH",
    "name": "Non Narai",
    "lat": "15.23764",
    "lng": "103.91333"
  },
  {
    "country": "TH",
    "name": "Khwao Sinarin",
    "lat": "15.00244",
    "lng": "103.59154"
  },
  {
    "country": "TH",
    "name": "Thung Khao Luang",
    "lat": "15.99397",
    "lng": "103.86264"
  },
  {
    "country": "TH",
    "name": "Chiang Khwan",
    "lat": "16.16328",
    "lng": "103.75359"
  },
  {
    "country": "TH",
    "name": "Changhan",
    "lat": "16.13873",
    "lng": "103.60388"
  },
  {
    "country": "TH",
    "name": "Don Chan",
    "lat": "16.45711",
    "lng": "103.69558"
  },
  {
    "country": "TH",
    "name": "Phu Phan",
    "lat": "16.99891",
    "lng": "103.97347"
  },
  {
    "country": "TH",
    "name": "Si Wilai",
    "lat": "18.18188",
    "lng": "103.74793"
  },
  {
    "country": "TH",
    "name": "Phu Sing",
    "lat": "14.54744",
    "lng": "104.13167"
  },
  {
    "country": "TH",
    "name": "Pho Si Suwan",
    "lat": "15.22929",
    "lng": "104.0767"
  },
  {
    "country": "TH",
    "name": "Sila Lat",
    "lat": "15.47156",
    "lng": "104.07153"
  },
  {
    "country": "TH",
    "name": "Thai Charoen",
    "lat": "16.06645",
    "lng": "104.44018"
  },
  {
    "country": "TH",
    "name": "Phon Na Kaeo",
    "lat": "17.22122",
    "lng": "104.28995"
  },
  {
    "country": "TH",
    "name": "Wang Yang",
    "lat": "17.05751",
    "lng": "104.45333"
  },
  {
    "country": "TH",
    "name": "Nathom",
    "lat": "17.78536",
    "lng": "104.09072"
  },
  {
    "country": "TH",
    "name": "Thung Si Udom",
    "lat": "14.73303",
    "lng": "104.90897"
  },
  {
    "country": "TH",
    "name": "Nam Khun",
    "lat": "14.58386",
    "lng": "104.92481"
  },
  {
    "country": "TH",
    "name": "Benchalak",
    "lat": "14.79583",
    "lng": "104.67017"
  },
  {
    "country": "TH",
    "name": "Pathum Ratchawongsa",
    "lat": "15.89224",
    "lng": "104.90563"
  },
  {
    "country": "TH",
    "name": "Don Mot Daeng",
    "lat": "15.37903",
    "lng": "105.02786"
  },
  {
    "country": "TH",
    "name": "Mae Wang",
    "lat": "18.61604",
    "lng": "98.77292"
  },
  {
    "country": "TH",
    "name": "Khao Kho",
    "lat": "16.65791",
    "lng": "101.02208"
  },
  {
    "country": "TH",
    "name": "Phra Thong Kham",
    "lat": "15.26686",
    "lng": "102.02024"
  },
  {
    "country": "TH",
    "name": "Wiang Kao",
    "lat": "16.68247",
    "lng": "102.28511"
  },
  {
    "country": "TH",
    "name": "Khaen Dong",
    "lat": "15.32476",
    "lng": "103.13343"
  },
  {
    "country": "TH",
    "name": "Sirindhorn",
    "lat": "15.20084",
    "lng": "105.39222"
  },
  {
    "country": "TH",
    "name": "Sida",
    "lat": "15.54994",
    "lng": "102.56675"
  },
  {
    "country": "TH",
    "name": "Srinagarindra",
    "lat": "7.56991",
    "lng": "99.94353"
  },
  {
    "country": "TH",
    "name": "Sam Chai",
    "lat": "16.86322",
    "lng": "103.54106"
  },
  {
    "country": "TH",
    "name": "Dong Charoen",
    "lat": "16.02058",
    "lng": "100.66286"
  },
  {
    "country": "TH",
    "name": "Chaem Luang",
    "lat": "19.03193",
    "lng": "98.28767"
  },
  {
    "country": "TH",
    "name": "Rattanawapi",
    "lat": "18.21365",
    "lng": "103.17967"
  },
  {
    "country": "TH",
    "name": "Hat Samran",
    "lat": "7.24034",
    "lng": "99.57621"
  },
  {
    "country": "TH",
    "name": "Ban Pa Pae",
    "lat": "18.28425",
    "lng": "98.05683"
  },
  {
    "country": "TH",
    "name": "Bung Khla",
    "lat": "18.30232",
    "lng": "103.97418"
  },
  {
    "country": "TH",
    "name": "Chai Prakan",
    "lat": "19.73136",
    "lng": "99.13997"
  },
  {
    "country": "TH",
    "name": "Doi Luang",
    "lat": "20.11783",
    "lng": "100.09919"
  },
  {
    "country": "TH",
    "name": "Mae On",
    "lat": "18.77681",
    "lng": "99.24861"
  },
  {
    "country": "TH",
    "name": "Sop Moei",
    "lat": "17.96209",
    "lng": "97.93288"
  },
  {
    "country": "TH",
    "name": "Bua Lai",
    "lat": "15.66548",
    "lng": "102.49881"
  },
  {
    "country": "TH",
    "name": "Phra Samut Chedi",
    "lat": "13.60222",
    "lng": "100.5721"
  },
  {
    "country": "TH",
    "name": "Singhanakhon",
    "lat": "7.23903",
    "lng": "100.55272"
  },
  {
    "country": "TH",
    "name": "Phu Sang",
    "lat": "19.59903",
    "lng": "100.32444"
  },
  {
    "country": "TH",
    "name": "Mae Hi",
    "lat": "19.34286",
    "lng": "98.45023"
  },
  {
    "country": "TH",
    "name": "Pa Phayom",
    "lat": "7.84031",
    "lng": "99.91773"
  },
  {
    "country": "TH",
    "name": "Na Yong",
    "lat": "7.56167",
    "lng": "99.69483"
  },
  {
    "country": "TH",
    "name": "Pho Tak",
    "lat": "17.87486",
    "lng": "102.40406"
  },
  {
    "country": "TH",
    "name": "Ko Kut",
    "lat": "11.65856",
    "lng": "102.54197"
  },
  {
    "country": "TH",
    "name": "Bang Bon",
    "lat": "13.66185",
    "lng": "100.39567"
  },
  {
    "country": "TH",
    "name": "Din Daeng",
    "lat": "13.76994",
    "lng": "100.55299"
  },
  {
    "country": "TH",
    "name": "Phra Nakhon",
    "lat": "13.76512",
    "lng": "100.49864"
  },
  {
    "country": "TH",
    "name": "Na Kluea",
    "lat": "12.96199",
    "lng": "100.89715"
  },
  {
    "country": "TJ",
    "name": "Yovon",
    "lat": "38.31408",
    "lng": "69.03784"
  },
  {
    "country": "TJ",
    "name": "Vose’",
    "lat": "37.80396",
    "lng": "69.64417"
  },
  {
    "country": "TJ",
    "name": "Vorukh",
    "lat": "39.85125",
    "lng": "70.58012"
  },
  {
    "country": "TJ",
    "name": "Varzob",
    "lat": "38.77369",
    "lng": "68.81776"
  },
  {
    "country": "TJ",
    "name": "Vanj",
    "lat": "38.37078",
    "lng": "71.45474"
  },
  {
    "country": "TJ",
    "name": "Vakhsh",
    "lat": "37.71485",
    "lng": "68.83456"
  },
  {
    "country": "TJ",
    "name": "Istaravshan",
    "lat": "39.9142",
    "lng": "69.00328"
  },
  {
    "country": "TJ",
    "name": "Tavildara",
    "lat": "38.69529",
    "lng": "70.48422"
  },
  {
    "country": "TJ",
    "name": "Tartiki",
    "lat": "37.58221",
    "lng": "68.13347"
  },
  {
    "country": "TJ",
    "name": "Tagob",
    "lat": "38.83827",
    "lng": "68.89847"
  },
  {
    "country": "TJ",
    "name": "Tajikobod",
    "lat": "39.12405",
    "lng": "70.84009"
  },
  {
    "country": "TJ",
    "name": "Sovet",
    "lat": "38.0467",
    "lng": "69.58822"
  },
  {
    "country": "TJ",
    "name": "Shŭrobod",
    "lat": "37.84137",
    "lng": "70.04865"
  },
  {
    "country": "TJ",
    "name": "Shahrinav",
    "lat": "38.57085",
    "lng": "68.33498"
  },
  {
    "country": "TJ",
    "name": "Shahriston",
    "lat": "39.77447",
    "lng": "68.80929"
  },
  {
    "country": "TJ",
    "name": "Shahritus",
    "lat": "37.26206",
    "lng": "68.13849"
  },
  {
    "country": "TJ",
    "name": "Rŭshon",
    "lat": "37.94487",
    "lng": "71.55745"
  },
  {
    "country": "TJ",
    "name": "Roshtqal’a",
    "lat": "37.25827",
    "lng": "71.82591"
  },
  {
    "country": "TJ",
    "name": "Roghun",
    "lat": "38.78257",
    "lng": "69.87081"
  },
  {
    "country": "TJ",
    "name": "Qŭrghonteppa",
    "lat": "37.83399",
    "lng": "68.78186"
  },
  {
    "country": "TJ",
    "name": "Panj",
    "lat": "37.23634",
    "lng": "69.09911"
  },
  {
    "country": "TJ",
    "name": "Panjakent",
    "lat": "39.49524",
    "lng": "67.60931"
  },
  {
    "country": "TJ",
    "name": "Farkhor",
    "lat": "37.49219",
    "lng": "69.40356"
  },
  {
    "country": "TJ",
    "name": "Orzu",
    "lat": "37.5582",
    "lng": "68.81952"
  },
  {
    "country": "TJ",
    "name": "Vahdat",
    "lat": "38.55632",
    "lng": "69.01354"
  },
  {
    "country": "TJ",
    "name": "Ismoili Somoní",
    "lat": "37.76627",
    "lng": "68.80126"
  },
  {
    "country": "TJ",
    "name": "Obikiik",
    "lat": "38.16033",
    "lng": "68.66605"
  },
  {
    "country": "TJ",
    "name": "Obigarm",
    "lat": "38.71731",
    "lng": "69.70885"
  },
  {
    "country": "TJ",
    "name": "Norak",
    "lat": "38.38917",
    "lng": "69.32272"
  },
  {
    "country": "TJ",
    "name": "Novobod",
    "lat": "39.01084",
    "lng": "70.15082"
  },
  {
    "country": "TJ",
    "name": "Murghob",
    "lat": "38.17023",
    "lng": "73.96674"
  },
  {
    "country": "TJ",
    "name": "Moskva",
    "lat": "37.66101",
    "lng": "69.62849"
  },
  {
    "country": "TJ",
    "name": "Somoniyon",
    "lat": "38.44173",
    "lng": "68.77458"
  },
  {
    "country": "TJ",
    "name": "Mŭ’minobod",
    "lat": "38.10714",
    "lng": "70.03213"
  },
  {
    "country": "TJ",
    "name": "Abdurahmoni Jomí",
    "lat": "37.94636",
    "lng": "68.80878"
  },
  {
    "country": "TJ",
    "name": "Kŭlob",
    "lat": "37.91459",
    "lng": "69.78454"
  },
  {
    "country": "TJ",
    "name": "Darband",
    "lat": "38.86776",
    "lng": "69.96642"
  },
  {
    "country": "TJ",
    "name": "Kolkhozobod",
    "lat": "37.58823",
    "lng": "68.65886"
  },
  {
    "country": "TJ",
    "name": "Kirov",
    "lat": "37.81908",
    "lng": "68.85905"
  },
  {
    "country": "TJ",
    "name": "Khovaling",
    "lat": "38.34194",
    "lng": "69.97531"
  },
  {
    "country": "TJ",
    "name": "Khorugh",
    "lat": "37.48974",
    "lng": "71.55304"
  },
  {
    "country": "TJ",
    "name": "Khodzha-Maston",
    "lat": "38.74457",
    "lng": "68.62702"
  },
  {
    "country": "TJ",
    "name": "Karakenja",
    "lat": "39.23585",
    "lng": "71.52412"
  },
  {
    "country": "TJ",
    "name": "Sarband",
    "lat": "37.87136",
    "lng": "68.92233"
  },
  {
    "country": "TJ",
    "name": "Qalaikhumb",
    "lat": "38.45373",
    "lng": "70.78902"
  },
  {
    "country": "TJ",
    "name": "Qubodiyon",
    "lat": "37.40973",
    "lng": "68.18644"
  },
  {
    "country": "TJ",
    "name": "Ishqoshim",
    "lat": "36.72484",
    "lng": "71.61331"
  },
  {
    "country": "TJ",
    "name": "Hisor",
    "lat": "38.52504",
    "lng": "68.55124"
  },
  {
    "country": "TJ",
    "name": "Rasht",
    "lat": "39.02871",
    "lng": "70.37446"
  },
  {
    "country": "TJ",
    "name": "Gharavŭtí",
    "lat": "37.56703",
    "lng": "68.44668"
  },
  {
    "country": "TJ",
    "name": "Ghonchí",
    "lat": "39.96238",
    "lng": "69.12966"
  },
  {
    "country": "TJ",
    "name": "Fayzobod",
    "lat": "38.54731",
    "lng": "69.3198"
  },
  {
    "country": "TJ",
    "name": "Jirghatol",
    "lat": "39.21966",
    "lng": "71.19155"
  },
  {
    "country": "TJ",
    "name": "Jilikŭl",
    "lat": "37.49167",
    "lng": "68.53106"
  },
  {
    "country": "TJ",
    "name": "Dŭstí",
    "lat": "37.34812",
    "lng": "68.66398"
  },
  {
    "country": "TJ",
    "name": "Dushanbe",
    "lat": "38.53575",
    "lng": "68.77905"
  },
  {
    "country": "TJ",
    "name": "Danghara",
    "lat": "38.09578",
    "lng": "69.33998"
  },
  {
    "country": "TJ",
    "name": "Chubek",
    "lat": "37.61453",
    "lng": "69.70525"
  },
  {
    "country": "TJ",
    "name": "Boshchorbogh",
    "lat": "37.52027",
    "lng": "68.12825"
  },
  {
    "country": "TJ",
    "name": "Bŭstonqal’a",
    "lat": "37.84783",
    "lng": "68.83125"
  },
  {
    "country": "TJ",
    "name": "Boshkengash",
    "lat": "38.46613",
    "lng": "68.80533"
  },
  {
    "country": "TJ",
    "name": "Baljuvon",
    "lat": "38.30838",
    "lng": "69.67672"
  },
  {
    "country": "TJ",
    "name": "Ayní",
    "lat": "39.39406",
    "lng": "68.53766"
  },
  {
    "country": "TJ",
    "name": "Tursunzoda",
    "lat": "38.51271",
    "lng": "68.23163"
  },
  {
    "country": "TJ",
    "name": "Roghun",
    "lat": "38.69331",
    "lng": "69.73692"
  },
  {
    "country": "TJ",
    "name": "Bahorí",
    "lat": "37.40195",
    "lng": "67.99446"
  },
  {
    "country": "TJ",
    "name": "Zafarobod",
    "lat": "40.17603",
    "lng": "68.84679"
  },
  {
    "country": "TJ",
    "name": "Taboshar",
    "lat": "40.57017",
    "lng": "69.64175"
  },
  {
    "country": "TJ",
    "name": "Shŭrob",
    "lat": "40.04605",
    "lng": "70.54117"
  },
  {
    "country": "TJ",
    "name": "Proletar",
    "lat": "40.16713",
    "lng": "69.50163"
  },
  {
    "country": "TJ",
    "name": "Palos",
    "lat": "40.31628",
    "lng": "69.73743"
  },
  {
    "country": "TJ",
    "name": "Pakhtakoron",
    "lat": "40.15709",
    "lng": "68.74659"
  },
  {
    "country": "TJ",
    "name": "Neftobod",
    "lat": "40.21524",
    "lng": "70.57193"
  },
  {
    "country": "TJ",
    "name": "Nov",
    "lat": "40.1522",
    "lng": "69.37076"
  },
  {
    "country": "TJ",
    "name": "Quruqsoy",
    "lat": "40.57648",
    "lng": "69.37962"
  },
  {
    "country": "TJ",
    "name": "Kim",
    "lat": "40.20798",
    "lng": "70.46882"
  },
  {
    "country": "TJ",
    "name": "Khŭjand",
    "lat": "40.28256",
    "lng": "69.62216"
  },
  {
    "country": "TJ",
    "name": "Konsoy",
    "lat": "40.49155",
    "lng": "69.70245"
  },
  {
    "country": "TJ",
    "name": "Konibodom",
    "lat": "40.29414",
    "lng": "70.43122"
  },
  {
    "country": "TJ",
    "name": "Isfara",
    "lat": "40.12649",
    "lng": "70.62526"
  },
  {
    "country": "TJ",
    "name": "Ghafurov",
    "lat": "40.21571",
    "lng": "69.72867"
  },
  {
    "country": "TJ",
    "name": "Bŭston",
    "lat": "40.52286",
    "lng": "69.33307"
  },
  {
    "country": "TJ",
    "name": "Shaydon",
    "lat": "40.66992",
    "lng": "70.3502"
  },
  {
    "country": "TJ",
    "name": "Oltintopkan",
    "lat": "40.65425",
    "lng": "69.59811"
  },
  {
    "country": "TJ",
    "name": "Adrasmon",
    "lat": "40.64928",
    "lng": "69.98472"
  },
  {
    "country": "TJ",
    "name": "Chkalov",
    "lat": "40.23417",
    "lng": "69.69481"
  },
  {
    "country": "TJ",
    "name": "Mehron",
    "lat": "39.41691",
    "lng": "69.28677"
  },
  {
    "country": "TJ",
    "name": "Moskovskiy",
    "lat": "37.60931",
    "lng": "68.58094"
  },
  {
    "country": "TK",
    "name": "Fale old settlement",
    "lat": "-9.38516",
    "lng": "-171.24675"
  },
  {
    "country": "TK",
    "name": "Nukunonu",
    "lat": "-9.20045",
    "lng": "-171.84804"
  },
  {
    "country": "TK",
    "name": "Atafu Village",
    "lat": "-8.54212",
    "lng": "-172.51591"
  },
  {
    "country": "TL",
    "name": "Viqueque",
    "lat": "-8.8575",
    "lng": "126.36472"
  },
  {
    "country": "TL",
    "name": "Suai",
    "lat": "-9.31286",
    "lng": "125.25648"
  },
  {
    "country": "TL",
    "name": "Same",
    "lat": "-9.00417",
    "lng": "125.64861"
  },
  {
    "country": "TL",
    "name": "Pante Makasar",
    "lat": "-9.2",
    "lng": "124.38333"
  },
  {
    "country": "TL",
    "name": "Metinaro",
    "lat": "-8.53007",
    "lng": "125.74163"
  },
  {
    "country": "TL",
    "name": "Maubara",
    "lat": "-8.61194",
    "lng": "125.20611"
  },
  {
    "country": "TL",
    "name": "Manatutu",
    "lat": "-8.51139",
    "lng": "126.01306"
  },
  {
    "country": "TL",
    "name": "Maliana",
    "lat": "-8.99167",
    "lng": "125.21972"
  },
  {
    "country": "TL",
    "name": "Likisá",
    "lat": "-8.5875",
    "lng": "125.34194"
  },
  {
    "country": "TL",
    "name": "Dili",
    "lat": "-8.55861",
    "lng": "125.57361"
  },
  {
    "country": "TL",
    "name": "Baukau",
    "lat": "-8.47572",
    "lng": "126.45633"
  },
  {
    "country": "TL",
    "name": "Ainaro",
    "lat": "-8.99241",
    "lng": "125.50816"
  },
  {
    "country": "TL",
    "name": "Aileu",
    "lat": "-8.72806",
    "lng": "125.56639"
  },
  {
    "country": "TL",
    "name": "Lospalos",
    "lat": "-8.52167",
    "lng": "126.99833"
  },
  {
    "country": "TL",
    "name": "Gleno",
    "lat": "-8.72389",
    "lng": "125.43611"
  },
  {
    "country": "TL",
    "name": "Venilale",
    "lat": "-8.64306",
    "lng": "126.37833"
  },
  {
    "country": "TM",
    "name": "Balkanabat",
    "lat": "39.51075",
    "lng": "54.36713"
  },
  {
    "country": "TM",
    "name": "Kaka",
    "lat": "37.34821",
    "lng": "59.61431"
  },
  {
    "country": "TM",
    "name": "Serdar",
    "lat": "38.97644",
    "lng": "56.27575"
  },
  {
    "country": "TM",
    "name": "Gumdag",
    "lat": "39.20611",
    "lng": "54.59056"
  },
  {
    "country": "TM",
    "name": "Bereket",
    "lat": "39.24463",
    "lng": "55.51536"
  },
  {
    "country": "TM",
    "name": "Magtymguly",
    "lat": "38.43749",
    "lng": "56.28081"
  },
  {
    "country": "TM",
    "name": "Arçabil",
    "lat": "37.915",
    "lng": "58.08987"
  },
  {
    "country": "TM",
    "name": "Abadan",
    "lat": "38.05415",
    "lng": "58.19721"
  },
  {
    "country": "TM",
    "name": "Baharly",
    "lat": "38.43624",
    "lng": "57.43158"
  },
  {
    "country": "TM",
    "name": "Ashgabat",
    "lat": "37.95",
    "lng": "58.38333"
  },
  {
    "country": "TM",
    "name": "Annau",
    "lat": "37.88754",
    "lng": "58.51596"
  },
  {
    "country": "TM",
    "name": "Yylanly",
    "lat": "41.83333",
    "lng": "59.65"
  },
  {
    "country": "TM",
    "name": "Tagta",
    "lat": "41.65041",
    "lng": "59.9164"
  },
  {
    "country": "TM",
    "name": "Akdepe",
    "lat": "42.05513",
    "lng": "59.37877"
  },
  {
    "country": "TM",
    "name": "Türkmenbaşy",
    "lat": "40.02216",
    "lng": "52.95517"
  },
  {
    "country": "TM",
    "name": "Köneürgench",
    "lat": "42.32773",
    "lng": "59.15442"
  },
  {
    "country": "TM",
    "name": "Boldumsaz",
    "lat": "42.12824",
    "lng": "59.67101"
  },
  {
    "country": "TM",
    "name": "Daşoguz",
    "lat": "41.83625",
    "lng": "59.96661"
  },
  {
    "country": "TM",
    "name": "Yolöten",
    "lat": "37.29886",
    "lng": "62.35975"
  },
  {
    "country": "TM",
    "name": "Tejen",
    "lat": "37.38338",
    "lng": "60.50545"
  },
  {
    "country": "TM",
    "name": "Seydi",
    "lat": "39.4816",
    "lng": "62.91374"
  },
  {
    "country": "TM",
    "name": "Saýat",
    "lat": "38.78393",
    "lng": "63.88035"
  },
  {
    "country": "TM",
    "name": "Murgab",
    "lat": "37.49656",
    "lng": "61.97142"
  },
  {
    "country": "TM",
    "name": "Mary",
    "lat": "37.59378",
    "lng": "61.83031"
  },
  {
    "country": "TM",
    "name": "Atamyrat",
    "lat": "37.83573",
    "lng": "65.21058"
  },
  {
    "country": "TM",
    "name": "Serhetabat",
    "lat": "35.27992",
    "lng": "62.34383"
  },
  {
    "country": "TM",
    "name": "Gowurdak",
    "lat": "37.81244",
    "lng": "66.04656"
  },
  {
    "country": "TM",
    "name": "Farap",
    "lat": "39.17037",
    "lng": "63.61165"
  },
  {
    "country": "TM",
    "name": "Türkmenabat",
    "lat": "39.07328",
    "lng": "63.57861"
  },
  {
    "country": "TM",
    "name": "Bayramaly",
    "lat": "37.61852",
    "lng": "62.16715"
  },
  {
    "country": "TM",
    "name": "Gazojak",
    "lat": "41.18746",
    "lng": "61.4036"
  },
  {
    "country": "TN",
    "name": "Matmata",
    "lat": "33.54445",
    "lng": "9.97157"
  },
  {
    "country": "TN",
    "name": "Zaouiat Djedidi",
    "lat": "36.64375",
    "lng": "10.57428"
  },
  {
    "country": "TN",
    "name": "Zahānah",
    "lat": "37.03959",
    "lng": "10.03876"
  },
  {
    "country": "TN",
    "name": "Zaghouan",
    "lat": "36.40291",
    "lng": "10.14292"
  },
  {
    "country": "TN",
    "name": "Oued Meliz",
    "lat": "36.46813",
    "lng": "8.54951"
  },
  {
    "country": "TN",
    "name": "Oued Lill",
    "lat": "36.83408",
    "lng": "10.04057"
  },
  {
    "country": "TN",
    "name": "Touza",
    "lat": "35.63544",
    "lng": "10.82732"
  },
  {
    "country": "TN",
    "name": "Tunis",
    "lat": "36.81897",
    "lng": "10.16579"
  },
  {
    "country": "TN",
    "name": "Tozeur",
    "lat": "33.91968",
    "lng": "8.13352"
  },
  {
    "country": "TN",
    "name": "Tataouine",
    "lat": "32.92967",
    "lng": "10.45177"
  },
  {
    "country": "TN",
    "name": "Testour",
    "lat": "36.5513",
    "lng": "9.44307"
  },
  {
    "country": "TN",
    "name": "Tamaghzah",
    "lat": "34.38849",
    "lng": "7.94313"
  },
  {
    "country": "TN",
    "name": "Thala",
    "lat": "35.57244",
    "lng": "8.67031"
  },
  {
    "country": "TN",
    "name": "Takelsa",
    "lat": "36.78333",
    "lng": "10.63333"
  },
  {
    "country": "TN",
    "name": "Tajerouine",
    "lat": "35.89174",
    "lng": "8.55276"
  },
  {
    "country": "TN",
    "name": "Tabursuq",
    "lat": "36.45692",
    "lng": "9.24751"
  },
  {
    "country": "TN",
    "name": "Tabarka",
    "lat": "36.95442",
    "lng": "8.75801"
  },
  {
    "country": "TN",
    "name": "Sousse",
    "lat": "35.82539",
    "lng": "10.63699"
  },
  {
    "country": "TN",
    "name": "Siliana",
    "lat": "36.08497",
    "lng": "9.37082"
  },
  {
    "country": "TN",
    "name": "Sidi Alouane",
    "lat": "35.37505",
    "lng": "10.93899"
  },
  {
    "country": "TN",
    "name": "Sidi Bouzid",
    "lat": "35.03823",
    "lng": "9.48494"
  },
  {
    "country": "TN",
    "name": "Sidi Bou Ali",
    "lat": "35.95667",
    "lng": "10.47306"
  },
  {
    "country": "TN",
    "name": "Sidi Ben Nour",
    "lat": "35.53333",
    "lng": "10.91667"
  },
  {
    "country": "TN",
    "name": "Sidi el Hani",
    "lat": "35.67139",
    "lng": "10.31583"
  },
  {
    "country": "TN",
    "name": "Sidi Bou Saïd",
    "lat": "36.8687",
    "lng": "10.34174"
  },
  {
    "country": "TN",
    "name": "Chorbane",
    "lat": "35.28581",
    "lng": "10.3858"
  },
  {
    "country": "TN",
    "name": "Chebika",
    "lat": "34.31909",
    "lng": "7.93519"
  },
  {
    "country": "TN",
    "name": "Sakiet Sidi Youssef",
    "lat": "36.22292",
    "lng": "8.35547"
  },
  {
    "country": "TN",
    "name": "Skanes",
    "lat": "35.78333",
    "lng": "10.8"
  },
  {
    "country": "TN",
    "name": "Salakta",
    "lat": "35.39444",
    "lng": "11.04361"
  },
  {
    "country": "TN",
    "name": "Sejenane",
    "lat": "37.05722",
    "lng": "9.23806"
  },
  {
    "country": "TN",
    "name": "Sfax",
    "lat": "34.74056",
    "lng": "10.76028"
  },
  {
    "country": "TN",
    "name": "Sbiba",
    "lat": "35.54332",
    "lng": "9.0737"
  },
  {
    "country": "TN",
    "name": "La Sebala du Mornag",
    "lat": "36.67931",
    "lng": "10.29195"
  },
  {
    "country": "TN",
    "name": "Remada",
    "lat": "32.31662",
    "lng": "10.39551"
  },
  {
    "country": "TN",
    "name": "Rafrāf",
    "lat": "37.19043",
    "lng": "10.18365"
  },
  {
    "country": "TN",
    "name": "Radès",
    "lat": "36.76806",
    "lng": "10.27528"
  },
  {
    "country": "TN",
    "name": "Ksour Essaf",
    "lat": "35.41808",
    "lng": "10.99475"
  },
  {
    "country": "TN",
    "name": "Ksibet el Mediouni",
    "lat": "35.68561",
    "lng": "10.84256"
  },
  {
    "country": "TN",
    "name": "Korbous",
    "lat": "36.81668",
    "lng": "10.56865"
  },
  {
    "country": "TN",
    "name": "Korba",
    "lat": "36.57861",
    "lng": "10.85861"
  },
  {
    "country": "TN",
    "name": "Kélibia",
    "lat": "36.84757",
    "lng": "11.09386"
  },
  {
    "country": "TN",
    "name": "Goubellat",
    "lat": "36.54178",
    "lng": "9.66334"
  },
  {
    "country": "TN",
    "name": "Kebili",
    "lat": "33.70439",
    "lng": "8.96903"
  },
  {
    "country": "TN",
    "name": "Ksar Hellal",
    "lat": "35.64773",
    "lng": "10.89046"
  },
  {
    "country": "TN",
    "name": "Carthage",
    "lat": "36.86108",
    "lng": "10.33161"
  },
  {
    "country": "TN",
    "name": "El Fahs",
    "lat": "36.37419",
    "lng": "9.90651"
  },
  {
    "country": "TN",
    "name": "Galaat el Andeless",
    "lat": "37.0629",
    "lng": "10.11829"
  },
  {
    "country": "TN",
    "name": "Gafour",
    "lat": "36.32045",
    "lng": "9.32424"
  },
  {
    "country": "TN",
    "name": "Gafsa",
    "lat": "34.425",
    "lng": "8.78417"
  },
  {
    "country": "TN",
    "name": "Gabès",
    "lat": "33.88146",
    "lng": "10.0982"
  },
  {
    "country": "TN",
    "name": "Nibbar",
    "lat": "36.29411",
    "lng": "8.76657"
  },
  {
    "country": "TN",
    "name": "Nefta",
    "lat": "33.87309",
    "lng": "7.87765"
  },
  {
    "country": "TN",
    "name": "Nabeul",
    "lat": "36.45606",
    "lng": "10.73763"
  },
  {
    "country": "TN",
    "name": "Midoun",
    "lat": "33.80813",
    "lng": "10.99228"
  },
  {
    "country": "TN",
    "name": "Mateur",
    "lat": "37.04045",
    "lng": "9.66557"
  },
  {
    "country": "TN",
    "name": "Msaken",
    "lat": "35.72917",
    "lng": "10.58082"
  },
  {
    "country": "TN",
    "name": "Menzel Salem",
    "lat": "35.85673",
    "lng": "8.47654"
  },
  {
    "country": "TN",
    "name": "Menzel Kamel",
    "lat": "35.62477",
    "lng": "10.66727"
  },
  {
    "country": "TN",
    "name": "Menzel Jemil",
    "lat": "37.23618",
    "lng": "9.91448"
  },
  {
    "country": "TN",
    "name": "Menzel Heurr",
    "lat": "36.72818",
    "lng": "10.95757"
  },
  {
    "country": "TN",
    "name": "Mennzel Bou Zelfa",
    "lat": "36.68312",
    "lng": "10.58431"
  },
  {
    "country": "TN",
    "name": "Menzel Bourguiba",
    "lat": "37.15368",
    "lng": "9.78594"
  },
  {
    "country": "TN",
    "name": "Menzel Abderhaman",
    "lat": "37.23737",
    "lng": "9.86313"
  },
  {
    "country": "TN",
    "name": "Manouba",
    "lat": "36.80803",
    "lng": "10.09721"
  },
  {
    "country": "TN",
    "name": "Melloulèche",
    "lat": "35.16617",
    "lng": "11.03504"
  },
  {
    "country": "TN",
    "name": "Maktar",
    "lat": "35.85798",
    "lng": "9.20072"
  },
  {
    "country": "TN",
    "name": "Medjez el Bab",
    "lat": "36.64964",
    "lng": "9.61231"
  },
  {
    "country": "TN",
    "name": "Medenine",
    "lat": "33.35495",
    "lng": "10.50548"
  },
  {
    "country": "TN",
    "name": "Lemta",
    "lat": "35.66667",
    "lng": "10.88333"
  },
  {
    "country": "TN",
    "name": "Kesra",
    "lat": "35.81363",
    "lng": "9.36434"
  },
  {
    "country": "TN",
    "name": "Jendouba",
    "lat": "36.50114",
    "lng": "8.78024"
  },
  {
    "country": "TN",
    "name": "Jilma",
    "lat": "35.27311",
    "lng": "9.42385"
  },
  {
    "country": "TN",
    "name": "Zarzis",
    "lat": "33.50398",
    "lng": "11.11215"
  },
  {
    "country": "TN",
    "name": "Jemna",
    "lat": "33.57778",
    "lng": "9.01472"
  },
  {
    "country": "TN",
    "name": "Djemmal",
    "lat": "35.62231",
    "lng": "10.75696"
  },
  {
    "country": "TN",
    "name": "Djebeniana",
    "lat": "35.035",
    "lng": "10.90809"
  },
  {
    "country": "TN",
    "name": "Houmt El Souk",
    "lat": "33.87576",
    "lng": "10.85745"
  },
  {
    "country": "TN",
    "name": "Harqalah",
    "lat": "36.03027",
    "lng": "10.50904"
  },
  {
    "country": "TN",
    "name": "Hammam Sousse",
    "lat": "35.8609",
    "lng": "10.60313"
  },
  {
    "country": "TN",
    "name": "Hammam-Lif",
    "lat": "36.72866",
    "lng": "10.34163"
  },
  {
    "country": "TN",
    "name": "La Goulette",
    "lat": "36.81806",
    "lng": "10.305"
  },
  {
    "country": "TN",
    "name": "Haffouz",
    "lat": "35.63235",
    "lng": "9.67624"
  },
  {
    "country": "TN",
    "name": "Rhar el Melah",
    "lat": "37.16939",
    "lng": "10.19064"
  },
  {
    "country": "TN",
    "name": "Douz",
    "lat": "33.46632",
    "lng": "9.0203"
  },
  {
    "country": "TN",
    "name": "Degache",
    "lat": "33.97606",
    "lng": "8.2081"
  },
  {
    "country": "TN",
    "name": "Douar Tindja",
    "lat": "37.16667",
    "lng": "9.75"
  },
  {
    "country": "TN",
    "name": "Dar Chabanne",
    "lat": "36.46798",
    "lng": "10.75167"
  },
  {
    "country": "TN",
    "name": "Bou Arkoub",
    "lat": "36.53853",
    "lng": "10.55093"
  },
  {
    "country": "TN",
    "name": "Bou Attouche",
    "lat": "33.89927",
    "lng": "9.78496"
  },
  {
    "country": "TN",
    "name": "Bou Arada",
    "lat": "36.35251",
    "lng": "9.62175"
  },
  {
    "country": "TN",
    "name": "Bir Ali Ben Khalifa",
    "lat": "34.73592",
    "lng": "10.0924"
  },
  {
    "country": "TN",
    "name": "Bir el Hafey",
    "lat": "34.93212",
    "lng": "9.19321"
  },
  {
    "country": "TN",
    "name": "Ben Gardane",
    "lat": "33.13783",
    "lng": "11.21965"
  },
  {
    "country": "TN",
    "name": "Ben Arous",
    "lat": "36.75306",
    "lng": "10.21889"
  },
  {
    "country": "TN",
    "name": "Bizerte",
    "lat": "37.27442",
    "lng": "9.87391"
  },
  {
    "country": "TN",
    "name": "Beni Khiar",
    "lat": "36.46917",
    "lng": "10.78222"
  },
  {
    "country": "TN",
    "name": "Beni Khalled",
    "lat": "36.65038",
    "lng": "10.59004"
  },
  {
    "country": "TN",
    "name": "Beni Kheddache",
    "lat": "33.25279",
    "lng": "10.19883"
  },
  {
    "country": "TN",
    "name": "Beni Hassane",
    "lat": "35.5672",
    "lng": "10.80869"
  },
  {
    "country": "TN",
    "name": "Banbalah",
    "lat": "35.7",
    "lng": "10.8"
  },
  {
    "country": "TN",
    "name": "Béja",
    "lat": "36.72564",
    "lng": "9.18169"
  },
  {
    "country": "TN",
    "name": "Zouila",
    "lat": "35.50056",
    "lng": "11.06056"
  },
  {
    "country": "TN",
    "name": "Skhira",
    "lat": "34.2992",
    "lng": "10.06999"
  },
  {
    "country": "TN",
    "name": "Sbikha",
    "lat": "35.93325",
    "lng": "10.02081"
  },
  {
    "country": "TN",
    "name": "Seïada",
    "lat": "35.66887",
    "lng": "10.89246"
  },
  {
    "country": "TN",
    "name": "As Sars",
    "lat": "36.0764",
    "lng": "9.02117"
  },
  {
    "country": "TN",
    "name": "As Sanad",
    "lat": "34.4628",
    "lng": "9.26404"
  },
  {
    "country": "TN",
    "name": "Sahline",
    "lat": "35.75166",
    "lng": "10.71109"
  },
  {
    "country": "TN",
    "name": "Chebba",
    "lat": "35.23722",
    "lng": "11.115"
  },
  {
    "country": "TN",
    "name": "Ariana",
    "lat": "36.86012",
    "lng": "10.19337"
  },
  {
    "country": "TN",
    "name": "Ar Rudayyif",
    "lat": "34.3827",
    "lng": "8.15549"
  },
  {
    "country": "TN",
    "name": "Er Regueb",
    "lat": "34.85932",
    "lng": "9.78654"
  },
  {
    "country": "TN",
    "name": "Rohia",
    "lat": "35.65129",
    "lng": "9.05306"
  },
  {
    "country": "TN",
    "name": "Ouardenine",
    "lat": "35.70915",
    "lng": "10.67397"
  },
  {
    "country": "TN",
    "name": "El Ksour",
    "lat": "35.89607",
    "lng": "8.88493"
  },
  {
    "country": "TN",
    "name": "Kairouan",
    "lat": "35.6781",
    "lng": "10.09633"
  },
  {
    "country": "TN",
    "name": "Kasserine",
    "lat": "35.16758",
    "lng": "8.83651"
  },
  {
    "country": "TN",
    "name": "Gremda",
    "lat": "34.75",
    "lng": "10.78333"
  },
  {
    "country": "TN",
    "name": "El Golaa",
    "lat": "33.48485",
    "lng": "9.00678"
  },
  {
    "country": "TN",
    "name": "Monastir",
    "lat": "35.77799",
    "lng": "10.82617"
  },
  {
    "country": "TN",
    "name": "La Mohammedia",
    "lat": "36.67446",
    "lng": "10.15633"
  },
  {
    "country": "TN",
    "name": "El Mida",
    "lat": "36.72556",
    "lng": "10.85528"
  },
  {
    "country": "TN",
    "name": "Metlaoui",
    "lat": "34.32081",
    "lng": "8.40157"
  },
  {
    "country": "TN",
    "name": "Mezzouna",
    "lat": "34.57758",
    "lng": "9.84193"
  },
  {
    "country": "TN",
    "name": "Al Matlīn",
    "lat": "37.24516",
    "lng": "10.05"
  },
  {
    "country": "TN",
    "name": "Mesdour",
    "lat": "35.68206",
    "lng": "10.72746"
  },
  {
    "country": "TN",
    "name": "Al Marsá",
    "lat": "36.87818",
    "lng": "10.32466"
  },
  {
    "country": "TN",
    "name": "El Maamoura",
    "lat": "36.46499",
    "lng": "10.80612"
  },
  {
    "country": "TN",
    "name": "Mahdia",
    "lat": "35.50472",
    "lng": "11.06222"
  },
  {
    "country": "TN",
    "name": "Le Krib",
    "lat": "36.32802",
    "lng": "9.13613"
  },
  {
    "country": "TN",
    "name": "El Kef",
    "lat": "36.17424",
    "lng": "8.70486"
  },
  {
    "country": "TN",
    "name": "El Jem",
    "lat": "35.3",
    "lng": "10.71667"
  },
  {
    "country": "TN",
    "name": "El Haouaria",
    "lat": "37.05002",
    "lng": "11.01442"
  },
  {
    "country": "TN",
    "name": "Erriadh",
    "lat": "33.82063",
    "lng": "10.85394"
  },
  {
    "country": "TN",
    "name": "Hammamet",
    "lat": "36.4",
    "lng": "10.61667"
  },
  {
    "country": "TN",
    "name": "El Hamma",
    "lat": "33.89152",
    "lng": "9.79629"
  },
  {
    "country": "TN",
    "name": "Fernana",
    "lat": "36.65547",
    "lng": "8.69602"
  },
  {
    "country": "TN",
    "name": "El Battan",
    "lat": "36.80368",
    "lng": "9.84424"
  },
  {
    "country": "TN",
    "name": "Bekalta",
    "lat": "35.61739",
    "lng": "10.99466"
  },
  {
    "country": "TN",
    "name": "El Alia",
    "lat": "37.16911",
    "lng": "10.03478"
  },
  {
    "country": "TN",
    "name": "Akouda",
    "lat": "35.8691",
    "lng": "10.5653"
  },
  {
    "country": "TN",
    "name": "Douane",
    "lat": "36.44766",
    "lng": "10.7557"
  },
  {
    "country": "TN",
    "name": "Port el Kantaoui",
    "lat": "35.89239",
    "lng": "10.59434"
  },
  {
    "country": "TO",
    "name": "Vaini",
    "lat": "-21.19292",
    "lng": "-175.17678"
  },
  {
    "country": "TO",
    "name": "Pangai",
    "lat": "-19.81468",
    "lng": "-174.35423"
  },
  {
    "country": "TO",
    "name": "‘Ohonua",
    "lat": "-21.33333",
    "lng": "-174.95"
  },
  {
    "country": "TO",
    "name": "Nuku‘alofa",
    "lat": "-21.13938",
    "lng": "-175.2018"
  },
  {
    "country": "TO",
    "name": "Neiafu",
    "lat": "-18.6506",
    "lng": "-173.98404"
  },
  {
    "country": "TO",
    "name": "Hihifo",
    "lat": "-15.9544",
    "lng": "-173.79616"
  },
  {
    "country": "TO",
    "name": "Haveluloto",
    "lat": "-21.15216",
    "lng": "-175.21333"
  },
  {
    "country": "TR",
    "name": "Demre",
    "lat": "36.24444",
    "lng": "29.985"
  },
  {
    "country": "TR",
    "name": "Zeytinliova",
    "lat": "38.99118",
    "lng": "27.67635"
  },
  {
    "country": "TR",
    "name": "Zeytindağ",
    "lat": "38.96722",
    "lng": "27.07222"
  },
  {
    "country": "TR",
    "name": "Zara",
    "lat": "39.89778",
    "lng": "37.75833"
  },
  {
    "country": "TR",
    "name": "Yunak",
    "lat": "38.81418",
    "lng": "31.73223"
  },
  {
    "country": "TR",
    "name": "Yumurtalık",
    "lat": "36.76863",
    "lng": "35.78938"
  },
  {
    "country": "TR",
    "name": "Yüksekova",
    "lat": "37.57362",
    "lng": "44.28716"
  },
  {
    "country": "TR",
    "name": "Salat",
    "lat": "37.84172",
    "lng": "40.8865"
  },
  {
    "country": "TR",
    "name": "Kozak",
    "lat": "39.25124",
    "lng": "27.09021"
  },
  {
    "country": "TR",
    "name": "Yücebağ",
    "lat": "38.39367",
    "lng": "41.26713"
  },
  {
    "country": "TR",
    "name": "Yozgat",
    "lat": "39.82",
    "lng": "34.80444"
  },
  {
    "country": "TR",
    "name": "Yoncalı",
    "lat": "39.00913",
    "lng": "38.2532"
  },
  {
    "country": "TR",
    "name": "Yolboyu",
    "lat": "37.89764",
    "lng": "40.00086"
  },
  {
    "country": "TR",
    "name": "Yolbaşı",
    "lat": "37.38717",
    "lng": "41.31778"
  },
  {
    "country": "TR",
    "name": "Yolağzı",
    "lat": "37.52554",
    "lng": "41.3534"
  },
  {
    "country": "TR",
    "name": "Yıldızeli",
    "lat": "39.86639",
    "lng": "36.59889"
  },
  {
    "country": "TR",
    "name": "Yiğityolu",
    "lat": "35.99563",
    "lng": "36.26004"
  },
  {
    "country": "TR",
    "name": "Yiğitler",
    "lat": "39.8675",
    "lng": "26.61111"
  },
  {
    "country": "TR",
    "name": "Yeşilyurt",
    "lat": "38.33972",
    "lng": "28.66444"
  },
  {
    "country": "TR",
    "name": "Yeşilyurt",
    "lat": "38.29602",
    "lng": "38.24526"
  },
  {
    "country": "TR",
    "name": "Yeşilyurt",
    "lat": "37.19324",
    "lng": "28.27537"
  },
  {
    "country": "TR",
    "name": "Yeşilyazı",
    "lat": "39.33473",
    "lng": "39.08122"
  },
  {
    "country": "TR",
    "name": "Yeşilova",
    "lat": "38.4095",
    "lng": "33.83804"
  },
  {
    "country": "TR",
    "name": "Yeşilova",
    "lat": "37.50806",
    "lng": "29.75472"
  },
  {
    "country": "TR",
    "name": "Yeşilli",
    "lat": "37.33813",
    "lng": "40.81739"
  },
  {
    "country": "TR",
    "name": "Erzin",
    "lat": "36.95348",
    "lng": "36.19839"
  },
  {
    "country": "TR",
    "name": "Yeşilhisar",
    "lat": "38.35232",
    "lng": "35.08873"
  },
  {
    "country": "TR",
    "name": "Misli",
    "lat": "38.23119",
    "lng": "34.77671"
  },
  {
    "country": "TR",
    "name": "Yeşildere",
    "lat": "37.15668",
    "lng": "33.51447"
  },
  {
    "country": "TR",
    "name": "Yeşilalan",
    "lat": "37.46066",
    "lng": "40.78441"
  },
  {
    "country": "TR",
    "name": "Yerköy",
    "lat": "39.63806",
    "lng": "34.46722"
  },
  {
    "country": "TR",
    "name": "Yerkesik",
    "lat": "37.13625",
    "lng": "28.28403"
  },
  {
    "country": "TR",
    "name": "Yenişarbademli",
    "lat": "37.70778",
    "lng": "31.38639"
  },
  {
    "country": "TR",
    "name": "Yenişakran",
    "lat": "38.88639",
    "lng": "27.06694"
  },
  {
    "country": "TR",
    "name": "Yenipınar",
    "lat": "37.84291",
    "lng": "41.30137"
  },
  {
    "country": "TR",
    "name": "Yenipazar",
    "lat": "39.46361",
    "lng": "35.08306"
  },
  {
    "country": "TR",
    "name": "Yenipazar",
    "lat": "37.82332",
    "lng": "28.19573"
  },
  {
    "country": "TR",
    "name": "Yenimehmetli",
    "lat": "39.42",
    "lng": "32.16889"
  },
  {
    "country": "TR",
    "name": "Yeniköy",
    "lat": "39.77874",
    "lng": "28.00299"
  },
  {
    "country": "TR",
    "name": "Yeniköy",
    "lat": "37.88042",
    "lng": "41.05004"
  },
  {
    "country": "TR",
    "name": "Yenicekale",
    "lat": "37.59874",
    "lng": "36.63264"
  },
  {
    "country": "TR",
    "name": "Yeniköy",
    "lat": "37.27074",
    "lng": "42.42472"
  },
  {
    "country": "TR",
    "name": "Didim",
    "lat": "37.38496",
    "lng": "27.25643"
  },
  {
    "country": "TR",
    "name": "Yenifoça",
    "lat": "38.73333",
    "lng": "26.83333"
  },
  {
    "country": "TR",
    "name": "Yenifakılı",
    "lat": "39.21142",
    "lng": "35.00036"
  },
  {
    "country": "TR",
    "name": "Altpınar",
    "lat": "39.20417",
    "lng": "32.74778"
  },
  {
    "country": "TR",
    "name": "Yeniceoba",
    "lat": "38.86972",
    "lng": "32.78833"
  },
  {
    "country": "TR",
    "name": "Yenice",
    "lat": "39.93083",
    "lng": "27.25806"
  },
  {
    "country": "TR",
    "name": "Yenice",
    "lat": "39.76089",
    "lng": "28.90729"
  },
  {
    "country": "TR",
    "name": "Yenice",
    "lat": "37.82837",
    "lng": "28.57115"
  },
  {
    "country": "TR",
    "name": "Yenice",
    "lat": "36.97744",
    "lng": "35.05197"
  },
  {
    "country": "TR",
    "name": "Yenibaşak",
    "lat": "38.80414",
    "lng": "40.99222"
  },
  {
    "country": "TR",
    "name": "Reşadiye",
    "lat": "38.48879",
    "lng": "42.53501"
  },
  {
    "country": "TR",
    "name": "Yeditepe",
    "lat": "35.96753",
    "lng": "36.01452"
  },
  {
    "country": "TR",
    "name": "Yedisu",
    "lat": "39.43277",
    "lng": "40.53368"
  },
  {
    "country": "TR",
    "name": "Yazyurdu",
    "lat": "38.79926",
    "lng": "36.9319"
  },
  {
    "country": "TR",
    "name": "Yazıhan",
    "lat": "38.59292",
    "lng": "38.17327"
  },
  {
    "country": "TR",
    "name": "Yayvantepe",
    "lat": "37.30131",
    "lng": "41.52061"
  },
  {
    "country": "TR",
    "name": "Yaylı",
    "lat": "37.20293",
    "lng": "40.75375"
  },
  {
    "country": "TR",
    "name": "Yaylak",
    "lat": "37.38268",
    "lng": "38.33892"
  },
  {
    "country": "TR",
    "name": "Yayladere",
    "lat": "39.22614",
    "lng": "40.0695"
  },
  {
    "country": "TR",
    "name": "Yayladağı",
    "lat": "35.9025",
    "lng": "36.06272"
  },
  {
    "country": "TR",
    "name": "Yayla",
    "lat": "38.63092",
    "lng": "40.52793"
  },
  {
    "country": "TR",
    "name": "Yaygın",
    "lat": "38.89748",
    "lng": "41.30613"
  },
  {
    "country": "TR",
    "name": "Yavuzeli",
    "lat": "37.31772",
    "lng": "37.56824"
  },
  {
    "country": "TR",
    "name": "Yavu",
    "lat": "39.79202",
    "lng": "36.20603"
  },
  {
    "country": "TR",
    "name": "Yatağan",
    "lat": "37.34025",
    "lng": "28.14279"
  },
  {
    "country": "TR",
    "name": "Yarpuzlu",
    "lat": "38.05414",
    "lng": "38.5213"
  },
  {
    "country": "TR",
    "name": "Yarpuz",
    "lat": "37.04824",
    "lng": "36.43066"
  },
  {
    "country": "TR",
    "name": "Yarma",
    "lat": "37.81149",
    "lng": "32.88278"
  },
  {
    "country": "TR",
    "name": "Yardımcı",
    "lat": "37.02091",
    "lng": "39.00533"
  },
  {
    "country": "TR",
    "name": "Yarbasan",
    "lat": "38.98889",
    "lng": "28.80806"
  },
  {
    "country": "TR",
    "name": "Yaprakbaşı",
    "lat": "37.65409",
    "lng": "40.54635"
  },
  {
    "country": "TR",
    "name": "Yanarsu",
    "lat": "38.03641",
    "lng": "41.55227"
  },
  {
    "country": "TR",
    "name": "Yamaç",
    "lat": "38.77623",
    "lng": "40.43894"
  },
  {
    "country": "TR",
    "name": "Yalvaç",
    "lat": "38.29556",
    "lng": "31.17778"
  },
  {
    "country": "TR",
    "name": "Yalınca",
    "lat": "37.85657",
    "lng": "43.5223"
  },
  {
    "country": "TR",
    "name": "Yalıkavak",
    "lat": "37.10528",
    "lng": "27.29722"
  },
  {
    "country": "TR",
    "name": "Yalıhüyük",
    "lat": "37.30077",
    "lng": "32.08548"
  },
  {
    "country": "TR",
    "name": "Yalangöz",
    "lat": "36.5768",
    "lng": "36.50766"
  },
  {
    "country": "TR",
    "name": "Yakapınar",
    "lat": "36.97342",
    "lng": "35.62043"
  },
  {
    "country": "TR",
    "name": "Payas",
    "lat": "36.756",
    "lng": "36.21432"
  },
  {
    "country": "TR",
    "name": "Yahyalı",
    "lat": "38.10228",
    "lng": "35.35704"
  },
  {
    "country": "TR",
    "name": "Yahşihan",
    "lat": "39.85028",
    "lng": "33.45294"
  },
  {
    "country": "TR",
    "name": "Yağcılar",
    "lat": "39.41712",
    "lng": "28.38109"
  },
  {
    "country": "TR",
    "name": "Viranşehir",
    "lat": "37.22349",
    "lng": "39.75519"
  },
  {
    "country": "TR",
    "name": "Varto",
    "lat": "39.17375",
    "lng": "41.45402"
  },
  {
    "country": "TR",
    "name": "Van",
    "lat": "38.49457",
    "lng": "43.38323"
  },
  {
    "country": "TR",
    "name": "Uzunkuyu",
    "lat": "38.27858",
    "lng": "26.54315"
  },
  {
    "country": "TR",
    "name": "Uzungeçit",
    "lat": "37.49052",
    "lng": "42.99036"
  },
  {
    "country": "TR",
    "name": "Cimin",
    "lat": "39.70947",
    "lng": "39.70015"
  },
  {
    "country": "TR",
    "name": "Üzümlü",
    "lat": "37.54057",
    "lng": "31.6038"
  },
  {
    "country": "TR",
    "name": "Yeşilüzümlü",
    "lat": "36.73361",
    "lng": "29.23333"
  },
  {
    "country": "TR",
    "name": "Uşak",
    "lat": "38.67351",
    "lng": "29.4058"
  },
  {
    "country": "TR",
    "name": "Urla",
    "lat": "38.32292",
    "lng": "26.76403"
  },
  {
    "country": "TR",
    "name": "Ürgüp",
    "lat": "38.6296",
    "lng": "34.91199"
  },
  {
    "country": "TR",
    "name": "Şanlıurfa",
    "lat": "37.16708",
    "lng": "38.79392"
  },
  {
    "country": "TR",
    "name": "Umurlu",
    "lat": "37.85003",
    "lng": "27.96275"
  },
  {
    "country": "TR",
    "name": "Umraniye",
    "lat": "39.175",
    "lng": "31.23444"
  },
  {
    "country": "TR",
    "name": "Uluyatır",
    "lat": "36.96333",
    "lng": "37.69361"
  },
  {
    "country": "TR",
    "name": "Ulukışla",
    "lat": "37.54776",
    "lng": "34.48528"
  },
  {
    "country": "TR",
    "name": "Uludere",
    "lat": "37.44074",
    "lng": "42.85236"
  },
  {
    "country": "TR",
    "name": "Arsuz",
    "lat": "36.41305",
    "lng": "35.89033"
  },
  {
    "country": "TR",
    "name": "Uluborlu",
    "lat": "38.07825",
    "lng": "30.45019"
  },
  {
    "country": "TR",
    "name": "Ulubey",
    "lat": "38.41987",
    "lng": "29.29129"
  },
  {
    "country": "TR",
    "name": "Ulaş",
    "lat": "39.44492",
    "lng": "37.039"
  },
  {
    "country": "TR",
    "name": "Ula",
    "lat": "37.10491",
    "lng": "28.41667"
  },
  {
    "country": "TR",
    "name": "Kerh",
    "lat": "37.8257",
    "lng": "40.54402"
  },
  {
    "country": "TR",
    "name": "Üçpınar",
    "lat": "37.13413",
    "lng": "32.26146"
  },
  {
    "country": "TR",
    "name": "Reshidi",
    "lat": "37.49471",
    "lng": "40.96806"
  },
  {
    "country": "TR",
    "name": "Üçdam",
    "lat": "39.56308",
    "lng": "40.1757"
  },
  {
    "country": "TR",
    "name": "Tuzlukçu",
    "lat": "38.47778",
    "lng": "31.62639"
  },
  {
    "country": "TR",
    "name": "Melefan",
    "lat": "38.18022",
    "lng": "41.5687"
  },
  {
    "country": "TR",
    "name": "Tutak",
    "lat": "39.53854",
    "lng": "42.76587"
  },
  {
    "country": "TR",
    "name": "Tut",
    "lat": "37.79529",
    "lng": "37.9161"
  },
  {
    "country": "TR",
    "name": "Turunçova",
    "lat": "36.36889",
    "lng": "30.1375"
  },
  {
    "country": "TR",
    "name": "Türkoğlu",
    "lat": "37.38649",
    "lng": "36.84262"
  },
  {
    "country": "TR",
    "name": "Turgutlu",
    "lat": "38.49533",
    "lng": "27.6997"
  },
  {
    "country": "TR",
    "name": "Turgut",
    "lat": "38.62694",
    "lng": "31.81083"
  },
  {
    "country": "TR",
    "name": "Turgut",
    "lat": "37.375",
    "lng": "28.03111"
  },
  {
    "country": "TR",
    "name": "Tunceli",
    "lat": "39.09921",
    "lng": "39.54351"
  },
  {
    "country": "TR",
    "name": "Sütlüce",
    "lat": "39.16228",
    "lng": "39.544"
  },
  {
    "country": "TR",
    "name": "Tufanbeyli",
    "lat": "38.26333",
    "lng": "36.22056"
  },
  {
    "country": "TR",
    "name": "Torbalı",
    "lat": "38.1519",
    "lng": "27.36223"
  },
  {
    "country": "TR",
    "name": "Toptepe",
    "lat": "37.26113",
    "lng": "41.24948"
  },
  {
    "country": "TR",
    "name": "Toprakkale",
    "lat": "37.06855",
    "lng": "36.14661"
  },
  {
    "country": "TR",
    "name": "Topaklı",
    "lat": "39.00555",
    "lng": "34.82644"
  },
  {
    "country": "TR",
    "name": "Pınarbaşı",
    "lat": "36.7034",
    "lng": "34.3627"
  },
  {
    "country": "TR",
    "name": "Tomarza",
    "lat": "38.44722",
    "lng": "35.79917"
  },
  {
    "country": "TR",
    "name": "Toklar",
    "lat": "38.41806",
    "lng": "36.015"
  },
  {
    "country": "TR",
    "name": "Tire",
    "lat": "38.08877",
    "lng": "27.73508"
  },
  {
    "country": "TR",
    "name": "Tercan",
    "lat": "39.77709",
    "lng": "40.37783"
  },
  {
    "country": "TR",
    "name": "Telminar",
    "lat": "37.11129",
    "lng": "41.38359"
  },
  {
    "country": "TR",
    "name": "Tepehan",
    "lat": "38.11788",
    "lng": "38.72622"
  },
  {
    "country": "TR",
    "name": "Tepecikören",
    "lat": "37.36135",
    "lng": "35.62627"
  },
  {
    "country": "TR",
    "name": "Tepecik",
    "lat": "37.82358",
    "lng": "27.87496"
  },
  {
    "country": "TR",
    "name": "Tepebaşı",
    "lat": "36.66628",
    "lng": "32.72214"
  },
  {
    "country": "TR",
    "name": "Tepealtı",
    "lat": "37.09595",
    "lng": "41.36834"
  },
  {
    "country": "TR",
    "name": "Tepe",
    "lat": "37.78943",
    "lng": "40.77161"
  },
  {
    "country": "TR",
    "name": "Temelli",
    "lat": "39.7275",
    "lng": "32.35528"
  },
  {
    "country": "TR",
    "name": "Tekman",
    "lat": "39.64111",
    "lng": "41.50542"
  },
  {
    "country": "TR",
    "name": "Tekirova",
    "lat": "36.5017",
    "lng": "30.52723"
  },
  {
    "country": "TR",
    "name": "Tefenni",
    "lat": "37.30968",
    "lng": "29.77538"
  },
  {
    "country": "TR",
    "name": "Tecirli",
    "lat": "37.16183",
    "lng": "36.10978"
  },
  {
    "country": "TR",
    "name": "Tavşanlı",
    "lat": "39.54237",
    "lng": "29.49866"
  },
  {
    "country": "TR",
    "name": "Tavas",
    "lat": "37.57351",
    "lng": "29.07058"
  },
  {
    "country": "TR",
    "name": "Tatvan",
    "lat": "38.49221",
    "lng": "42.28269"
  },
  {
    "country": "TR",
    "name": "Taşucu",
    "lat": "36.3214",
    "lng": "33.88165"
  },
  {
    "country": "TR",
    "name": "Taşpınar",
    "lat": "38.17963",
    "lng": "34.02499"
  },
  {
    "country": "TR",
    "name": "Taşlıçay",
    "lat": "39.62966",
    "lng": "43.36878"
  },
  {
    "country": "TR",
    "name": "Taşlı",
    "lat": "37.98699",
    "lng": "42.1351"
  },
  {
    "country": "TR",
    "name": "Taşkent",
    "lat": "36.9243",
    "lng": "32.49131"
  },
  {
    "country": "TR",
    "name": "Taşdelen",
    "lat": "38.8381",
    "lng": "38.50457"
  },
  {
    "country": "TR",
    "name": "Bakırdağı",
    "lat": "38.21597",
    "lng": "35.79021"
  },
  {
    "country": "TR",
    "name": "Taşağıl",
    "lat": "36.9224",
    "lng": "31.23608"
  },
  {
    "country": "TR",
    "name": "Tarsus",
    "lat": "36.91766",
    "lng": "34.89277"
  },
  {
    "country": "TR",
    "name": "Taraksu",
    "lat": "38.15416",
    "lng": "39.14837"
  },
  {
    "country": "TR",
    "name": "Taraksu",
    "lat": "38.01667",
    "lng": "39.08333"
  },
  {
    "country": "TR",
    "name": "Tanyeri",
    "lat": "39.61137",
    "lng": "39.83151"
  },
  {
    "country": "TR",
    "name": "Tanır",
    "lat": "38.41944",
    "lng": "36.91222"
  },
  {
    "country": "TR",
    "name": "Talas",
    "lat": "38.6908",
    "lng": "35.5538"
  },
  {
    "country": "TR",
    "name": "Tahtaköprü",
    "lat": "39.95",
    "lng": "29.65"
  },
  {
    "country": "TR",
    "name": "Tahir",
    "lat": "39.85586",
    "lng": "42.42834"
  },
  {
    "country": "TR",
    "name": "Suvarlı",
    "lat": "37.53867",
    "lng": "37.6321"
  },
  {
    "country": "TR",
    "name": "Şenocak",
    "lat": "37.65035",
    "lng": "40.69441"
  },
  {
    "country": "TR",
    "name": "Pavlu Cebel",
    "lat": "37.49737",
    "lng": "30.97727"
  },
  {
    "country": "TR",
    "name": "Susurluk",
    "lat": "39.91361",
    "lng": "28.15778"
  },
  {
    "country": "TR",
    "name": "Suruç",
    "lat": "36.97612",
    "lng": "38.42533"
  },
  {
    "country": "TR",
    "name": "Avine",
    "lat": "37.57373",
    "lng": "40.73252"
  },
  {
    "country": "TR",
    "name": "Sürgü",
    "lat": "38.00548",
    "lng": "37.9635"
  },
  {
    "country": "TR",
    "name": "Sulusaray",
    "lat": "39.99389",
    "lng": "36.08404"
  },
  {
    "country": "TR",
    "name": "Sülüklü",
    "lat": "38.88111",
    "lng": "32.3425"
  },
  {
    "country": "TR",
    "name": "Suluçem",
    "lat": "39.69386",
    "lng": "43.81472"
  },
  {
    "country": "TR",
    "name": "Sultanhisar",
    "lat": "37.88989",
    "lng": "28.15436"
  },
  {
    "country": "TR",
    "name": "Sultanhanı",
    "lat": "38.2471",
    "lng": "33.54961"
  },
  {
    "country": "TR",
    "name": "Sultandağı",
    "lat": "38.53111",
    "lng": "31.22806"
  },
  {
    "country": "TR",
    "name": "Süleymanlı",
    "lat": "37.87264",
    "lng": "36.81714"
  },
  {
    "country": "TR",
    "name": "Sulak",
    "lat": "37.41342",
    "lng": "41.96114"
  },
  {
    "country": "TR",
    "name": "Sulak",
    "lat": "37.29458",
    "lng": "42.13637"
  },
  {
    "country": "TR",
    "name": "Şuhut",
    "lat": "38.53111",
    "lng": "30.54583"
  },
  {
    "country": "TR",
    "name": "Sorgun",
    "lat": "39.81012",
    "lng": "35.18596"
  },
  {
    "country": "TR",
    "name": "Soma",
    "lat": "39.18554",
    "lng": "27.60945"
  },
  {
    "country": "TR",
    "name": "Solhan",
    "lat": "38.96525",
    "lng": "41.05443"
  },
  {
    "country": "TR",
    "name": "Söke",
    "lat": "37.7482",
    "lng": "27.40614"
  },
  {
    "country": "TR",
    "name": "Söğütlü",
    "lat": "38.80019",
    "lng": "40.66971"
  },
  {
    "country": "TR",
    "name": "Kindirip",
    "lat": "37.44706",
    "lng": "41.21976"
  },
  {
    "country": "TR",
    "name": "Söğüt",
    "lat": "40.0143",
    "lng": "30.18486"
  },
  {
    "country": "TR",
    "name": "Sivrihisar",
    "lat": "39.45037",
    "lng": "31.53409"
  },
  {
    "country": "TR",
    "name": "Sivrice",
    "lat": "38.44223",
    "lng": "39.30938"
  },
  {
    "country": "TR",
    "name": "Sivrice",
    "lat": "37.27675",
    "lng": "41.33569"
  },
  {
    "country": "TR",
    "name": "Siverek",
    "lat": "37.75503",
    "lng": "39.31667"
  },
  {
    "country": "TR",
    "name": "Sivaslı",
    "lat": "38.49944",
    "lng": "29.68361"
  },
  {
    "country": "TR",
    "name": "Sivas",
    "lat": "39.74833",
    "lng": "37.01611"
  },
  {
    "country": "TR",
    "name": "Şirvan",
    "lat": "38.06251",
    "lng": "42.02517"
  },
  {
    "country": "TR",
    "name": "Tililan",
    "lat": "37.37428",
    "lng": "42.03386"
  },
  {
    "country": "TR",
    "name": "Şırnak",
    "lat": "37.51393",
    "lng": "42.45432"
  },
  {
    "country": "TR",
    "name": "Sındırgı",
    "lat": "39.24128",
    "lng": "28.17842"
  },
  {
    "country": "TR",
    "name": "Yenice",
    "lat": "39.27528",
    "lng": "32.68028"
  },
  {
    "country": "TR",
    "name": "Sincik",
    "lat": "38.03645",
    "lng": "38.61257"
  },
  {
    "country": "TR",
    "name": "Sincan",
    "lat": "39.47167",
    "lng": "37.87083"
  },
  {
    "country": "TR",
    "name": "Sinanpaşa",
    "lat": "38.74444",
    "lng": "30.24278"
  },
  {
    "country": "TR",
    "name": "Sinanköy",
    "lat": "37.86166",
    "lng": "40.99283"
  },
  {
    "country": "TR",
    "name": "Simav",
    "lat": "39.0882",
    "lng": "28.97767"
  },
  {
    "country": "TR",
    "name": "Silvan",
    "lat": "38.13708",
    "lng": "41.00817"
  },
  {
    "country": "TR",
    "name": "Silopi",
    "lat": "37.24379",
    "lng": "42.46345"
  },
  {
    "country": "TR",
    "name": "Sille",
    "lat": "37.92731",
    "lng": "32.41995"
  },
  {
    "country": "TR",
    "name": "Silifke",
    "lat": "36.37778",
    "lng": "33.93444"
  },
  {
    "country": "TR",
    "name": "Siirt",
    "lat": "37.9293",
    "lng": "41.94134"
  },
  {
    "country": "TR",
    "name": "Seyitgazi",
    "lat": "39.44472",
    "lng": "30.69472"
  },
  {
    "country": "TR",
    "name": "Seyhan",
    "lat": "36.98747",
    "lng": "35.30592"
  },
  {
    "country": "TR",
    "name": "Seydişehir",
    "lat": "37.41926",
    "lng": "31.84527"
  },
  {
    "country": "TR",
    "name": "Sevinç",
    "lat": "39.78",
    "lng": "30.68889"
  },
  {
    "country": "TR",
    "name": "Servi",
    "lat": "38.57038",
    "lng": "40.32004"
  },
  {
    "country": "TR",
    "name": "Serinyol",
    "lat": "36.36139",
    "lng": "36.21361"
  },
  {
    "country": "TR",
    "name": "Serik",
    "lat": "36.91694",
    "lng": "31.09889"
  },
  {
    "country": "TR",
    "name": "Şereflikoçhisar",
    "lat": "38.93925",
    "lng": "33.5386"
  },
  {
    "country": "TR",
    "name": "Şenyurt",
    "lat": "37.07932",
    "lng": "40.64246"
  },
  {
    "country": "TR",
    "name": "Şenoba",
    "lat": "37.46436",
    "lng": "42.72248"
  },
  {
    "country": "TR",
    "name": "Ebish",
    "lat": "37.46347",
    "lng": "41.18863"
  },
  {
    "country": "TR",
    "name": "Şenköy",
    "lat": "36.04841",
    "lng": "36.14366"
  },
  {
    "country": "TR",
    "name": "Senirkent",
    "lat": "38.10444",
    "lng": "30.54861"
  },
  {
    "country": "TR",
    "name": "Şemdinli",
    "lat": "37.30514",
    "lng": "44.5742"
  },
  {
    "country": "TR",
    "name": "Selimiye",
    "lat": "37.40035",
    "lng": "27.65543"
  },
  {
    "country": "TR",
    "name": "Side",
    "lat": "36.76667",
    "lng": "31.38889"
  },
  {
    "country": "TR",
    "name": "Selendi",
    "lat": "38.74444",
    "lng": "28.86778"
  },
  {
    "country": "TR",
    "name": "Selçuk",
    "lat": "37.95137",
    "lng": "27.36849"
  },
  {
    "country": "TR",
    "name": "Selçikler",
    "lat": "38.49837",
    "lng": "29.65482"
  },
  {
    "country": "TR",
    "name": "Seksenören",
    "lat": "36.97252",
    "lng": "39.07484"
  },
  {
    "country": "TR",
    "name": "Sekili",
    "lat": "36.97876",
    "lng": "37.67174"
  },
  {
    "country": "TR",
    "name": "Seki",
    "lat": "36.80378",
    "lng": "29.65155"
  },
  {
    "country": "TR",
    "name": "Şekerli",
    "lat": "37.5705",
    "lng": "39.3872"
  },
  {
    "country": "TR",
    "name": "Şehit Nusretbey",
    "lat": "36.84667",
    "lng": "38.73583"
  },
  {
    "country": "TR",
    "name": "Seferihisar",
    "lat": "38.1975",
    "lng": "26.83881"
  },
  {
    "country": "TR",
    "name": "Şefaatlı",
    "lat": "39.5043",
    "lng": "34.7563"
  },
  {
    "country": "TR",
    "name": "Savur",
    "lat": "37.53544",
    "lng": "40.87876"
  },
  {
    "country": "TR",
    "name": "Savcılı",
    "lat": "39.22889",
    "lng": "33.68139"
  },
  {
    "country": "TR",
    "name": "Kayacık",
    "lat": "38.34142",
    "lng": "40.61336"
  },
  {
    "country": "TR",
    "name": "Savaştepe",
    "lat": "39.38319",
    "lng": "27.65612"
  },
  {
    "country": "TR",
    "name": "Sason",
    "lat": "38.32767",
    "lng": "41.41377"
  },
  {
    "country": "TR",
    "name": "Saruhanlı",
    "lat": "38.73455",
    "lng": "27.56811"
  },
  {
    "country": "TR",
    "name": "Edremit",
    "lat": "38.42069",
    "lng": "43.25889"
  },
  {
    "country": "TR",
    "name": "Şarkışla",
    "lat": "39.35186",
    "lng": "36.40976"
  },
  {
    "country": "TR",
    "name": "Şarkîkaraağaç",
    "lat": "38.07944",
    "lng": "31.36639"
  },
  {
    "country": "TR",
    "name": "Sarız",
    "lat": "38.47917",
    "lng": "36.49898"
  },
  {
    "country": "TR",
    "name": "Sarıyahşi",
    "lat": "38.98349",
    "lng": "33.84136"
  },
  {
    "country": "TR",
    "name": "Sarıveliler",
    "lat": "36.69705",
    "lng": "32.61203"
  },
  {
    "country": "TR",
    "name": "Sarısu",
    "lat": "39.01887",
    "lng": "42.92092"
  },
  {
    "country": "TR",
    "name": "Sarıoğlan",
    "lat": "39.07694",
    "lng": "35.96671"
  },
  {
    "country": "TR",
    "name": "Seri",
    "lat": "37.36001",
    "lng": "41.30055"
  },
  {
    "country": "TR",
    "name": "Sarıkonak",
    "lat": "38.24309",
    "lng": "41.95933"
  },
  {
    "country": "TR",
    "name": "Sarıkemer",
    "lat": "37.56609",
    "lng": "27.3643"
  },
  {
    "country": "TR",
    "name": "Sarıkaya",
    "lat": "39.49361",
    "lng": "35.37694"
  },
  {
    "country": "TR",
    "name": "Sarıgöl",
    "lat": "38.23953",
    "lng": "28.69663"
  },
  {
    "country": "TR",
    "name": "Sarıçam",
    "lat": "37.15172",
    "lng": "35.50769"
  },
  {
    "country": "TR",
    "name": "Sarıbeyler",
    "lat": "39.39833",
    "lng": "27.57722"
  },
  {
    "country": "TR",
    "name": "Sarayönü",
    "lat": "38.26201",
    "lng": "32.40457"
  },
  {
    "country": "TR",
    "name": "Sarayköy",
    "lat": "37.92448",
    "lng": "28.92516"
  },
  {
    "country": "TR",
    "name": "Saraykent",
    "lat": "39.69361",
    "lng": "35.51111"
  },
  {
    "country": "TR",
    "name": "Saray",
    "lat": "38.64691",
    "lng": "44.16116"
  },
  {
    "country": "TR",
    "name": "Şaphane",
    "lat": "39.0273",
    "lng": "29.22218"
  },
  {
    "country": "TR",
    "name": "Sandıklı",
    "lat": "38.46472",
    "lng": "30.26946"
  },
  {
    "country": "TR",
    "name": "Sancak",
    "lat": "39.09222",
    "lng": "40.38753"
  },
  {
    "country": "TR",
    "name": "Samsat",
    "lat": "37.58194",
    "lng": "38.47417"
  },
  {
    "country": "TR",
    "name": "Şamlı",
    "lat": "39.81184",
    "lng": "27.84559"
  },
  {
    "country": "TR",
    "name": "Şambayat",
    "lat": "37.68441",
    "lng": "38.04676"
  },
  {
    "country": "TR",
    "name": "Samandağ",
    "lat": "36.08012",
    "lng": "35.97603"
  },
  {
    "country": "TR",
    "name": "Salihli",
    "lat": "38.48258",
    "lng": "28.14774"
  },
  {
    "country": "TR",
    "name": "Salavatlı",
    "lat": "37.89123",
    "lng": "28.10333"
  },
  {
    "country": "TR",
    "name": "Sakçagöz",
    "lat": "37.17152",
    "lng": "36.91632"
  },
  {
    "country": "TR",
    "name": "Saimbeyli",
    "lat": "37.98632",
    "lng": "36.09056"
  },
  {
    "country": "TR",
    "name": "Sağkaya",
    "lat": "37.17852",
    "lng": "35.68843"
  },
  {
    "country": "TR",
    "name": "Simos",
    "lat": "38.05731",
    "lng": "42.58375"
  },
  {
    "country": "TR",
    "name": "Sabuncu",
    "lat": "39.56131",
    "lng": "30.18813"
  },
  {
    "country": "TR",
    "name": "Reyhanlı",
    "lat": "36.26791",
    "lng": "36.56747"
  },
  {
    "country": "TR",
    "name": "Reis",
    "lat": "38.27139",
    "lng": "31.57139"
  },
  {
    "country": "TR",
    "name": "Refahiye",
    "lat": "39.89315",
    "lng": "38.76607"
  },
  {
    "country": "TR",
    "name": "Pütürge",
    "lat": "38.19923",
    "lng": "38.86296"
  },
  {
    "country": "TR",
    "name": "Pulumer",
    "lat": "39.48449",
    "lng": "39.89532"
  },
  {
    "country": "TR",
    "name": "Pozantı",
    "lat": "37.42778",
    "lng": "34.87167"
  },
  {
    "country": "TR",
    "name": "Poyraz",
    "lat": "38.68596",
    "lng": "39.023"
  },
  {
    "country": "TR",
    "name": "Polatlı",
    "lat": "39.57715",
    "lng": "32.14132"
  },
  {
    "country": "TR",
    "name": "Razvaliny Ayinvan",
    "lat": "37.27983",
    "lng": "42.33427"
  },
  {
    "country": "TR",
    "name": "Pınarlar",
    "lat": "38.87424",
    "lng": "39.47263"
  },
  {
    "country": "TR",
    "name": "Pınardere",
    "lat": "37.47231",
    "lng": "40.83402"
  },
  {
    "country": "TR",
    "name": "Pınarbaşı",
    "lat": "38.72285",
    "lng": "36.39314"
  },
  {
    "country": "TR",
    "name": "Pınarbaşı",
    "lat": "37.21368",
    "lng": "41.88689"
  },
  {
    "country": "TR",
    "name": "Pervari",
    "lat": "37.93573",
    "lng": "42.54927"
  },
  {
    "country": "TR",
    "name": "Pertek",
    "lat": "38.86574",
    "lng": "39.32273"
  },
  {
    "country": "TR",
    "name": "Akpazar",
    "lat": "38.84625",
    "lng": "39.66833"
  },
  {
    "country": "TR",
    "name": "Pazaryeri",
    "lat": "39.99395",
    "lng": "29.90424"
  },
  {
    "country": "TR",
    "name": "Pazarören",
    "lat": "38.67389",
    "lng": "36.15944"
  },
  {
    "country": "TR",
    "name": "Pazarlar",
    "lat": "38.995",
    "lng": "29.12583"
  },
  {
    "country": "TR",
    "name": "Pazarköy",
    "lat": "39.8532",
    "lng": "27.40299"
  },
  {
    "country": "TR",
    "name": "Pazarcık",
    "lat": "37.48685",
    "lng": "37.29961"
  },
  {
    "country": "TR",
    "name": "Payallar",
    "lat": "36.6016",
    "lng": "31.85057"
  },
  {
    "country": "TR",
    "name": "Patnos",
    "lat": "39.22493",
    "lng": "42.85693"
  },
  {
    "country": "TR",
    "name": "Pasinler",
    "lat": "39.97975",
    "lng": "41.66997"
  },
  {
    "country": "TR",
    "name": "Pamukören",
    "lat": "37.92317",
    "lng": "28.54175"
  },
  {
    "country": "TR",
    "name": "Pamukkale",
    "lat": "37.91644",
    "lng": "29.11729"
  },
  {
    "country": "TR",
    "name": "Palu",
    "lat": "38.69135",
    "lng": "39.91984"
  },
  {
    "country": "TR",
    "name": "Palamutlu",
    "lat": "37.89583",
    "lng": "42.2025"
  },
  {
    "country": "TR",
    "name": "Özpınar",
    "lat": "38.00478",
    "lng": "42.24386"
  },
  {
    "country": "TR",
    "name": "Özonak",
    "lat": "38.81213",
    "lng": "34.84096"
  },
  {
    "country": "TR",
    "name": "Özdere",
    "lat": "38.01611",
    "lng": "27.12806"
  },
  {
    "country": "TR",
    "name": "Özbek",
    "lat": "37.17704",
    "lng": "41.69322"
  },
  {
    "country": "TR",
    "name": "Özalp",
    "lat": "38.65455",
    "lng": "43.98869"
  },
  {
    "country": "TR",
    "name": "Oymataş",
    "lat": "37.79856",
    "lng": "41.02083"
  },
  {
    "country": "TR",
    "name": "Oyalı",
    "lat": "37.22126",
    "lng": "41.73862"
  },
  {
    "country": "TR",
    "name": "Ovakışla",
    "lat": "38.81733",
    "lng": "42.31643"
  },
  {
    "country": "TR",
    "name": "Ovakent",
    "lat": "38.10722",
    "lng": "28.02111"
  },
  {
    "country": "TR",
    "name": "Ovakavağı",
    "lat": "37.71079",
    "lng": "32.93482"
  },
  {
    "country": "TR",
    "name": "Ovacık",
    "lat": "39.35259",
    "lng": "39.2089"
  },
  {
    "country": "TR",
    "name": "Ovacık",
    "lat": "37.51343",
    "lng": "38.77933"
  },
  {
    "country": "TR",
    "name": "Ovabağ",
    "lat": "37.70849",
    "lng": "39.98697"
  },
  {
    "country": "TR",
    "name": "Otlukbeli",
    "lat": "39.97",
    "lng": "40.01872"
  },
  {
    "country": "TR",
    "name": "Osmanpaşa",
    "lat": "39.62472",
    "lng": "34.96472"
  },
  {
    "country": "TR",
    "name": "Osmaniye",
    "lat": "37.07417",
    "lng": "36.24778"
  },
  {
    "country": "TR",
    "name": "Osmancalı",
    "lat": "38.7625",
    "lng": "27.25306"
  },
  {
    "country": "TR",
    "name": "Ortaköy",
    "lat": "39.42153",
    "lng": "36.23403"
  },
  {
    "country": "TR",
    "name": "Ortaköy",
    "lat": "38.73728",
    "lng": "34.03866"
  },
  {
    "country": "TR",
    "name": "Ortaköy",
    "lat": "37.32745",
    "lng": "43.28403"
  },
  {
    "country": "TR",
    "name": "Ortaköy",
    "lat": "37.22089",
    "lng": "40.78476"
  },
  {
    "country": "TR",
    "name": "Ortaklar",
    "lat": "37.88788",
    "lng": "27.50234"
  },
  {
    "country": "TR",
    "name": "Ortyakent Yahşi",
    "lat": "37.04944",
    "lng": "27.34833"
  },
  {
    "country": "TR",
    "name": "Ortaca",
    "lat": "37.47394",
    "lng": "41.55598"
  },
  {
    "country": "TR",
    "name": "Ortaca",
    "lat": "36.83915",
    "lng": "28.76457"
  },
  {
    "country": "TR",
    "name": "Ortabağ",
    "lat": "37.39671",
    "lng": "42.9101"
  },
  {
    "country": "TR",
    "name": "Orhaneli",
    "lat": "39.90333",
    "lng": "28.99056"
  },
  {
    "country": "TR",
    "name": "Örenşehir",
    "lat": "38.99843",
    "lng": "36.64929"
  },
  {
    "country": "TR",
    "name": "Örencik",
    "lat": "39.2625",
    "lng": "29.54389"
  },
  {
    "country": "TR",
    "name": "Ören",
    "lat": "37.03609",
    "lng": "27.96723"
  },
  {
    "country": "TR",
    "name": "Öncül",
    "lat": "36.71222",
    "lng": "39.02917"
  },
  {
    "country": "TR",
    "name": "Ömerli",
    "lat": "37.39903",
    "lng": "40.95442"
  },
  {
    "country": "TR",
    "name": "Ömerköy",
    "lat": "39.83063",
    "lng": "28.06682"
  },
  {
    "country": "TR",
    "name": "Okçular",
    "lat": "37.74152",
    "lng": "42.44075"
  },
  {
    "country": "TR",
    "name": "Oğuzeli",
    "lat": "36.96572",
    "lng": "37.51339"
  },
  {
    "country": "TR",
    "name": "Oğuz",
    "lat": "39.5059",
    "lng": "38.88369"
  },
  {
    "country": "TR",
    "name": "Oğuz",
    "lat": "37.81487",
    "lng": "41.37425"
  },
  {
    "country": "TR",
    "name": "Dara",
    "lat": "37.17902",
    "lng": "40.95455"
  },
  {
    "country": "TR",
    "name": "Ödemiş",
    "lat": "38.2278",
    "lng": "27.96955"
  },
  {
    "country": "TR",
    "name": "Obruk",
    "lat": "38.18444",
    "lng": "33.18095"
  },
  {
    "country": "TR",
    "name": "Nusaybin",
    "lat": "37.07028",
    "lng": "41.21465"
  },
  {
    "country": "TR",
    "name": "Nurhak",
    "lat": "37.96366",
    "lng": "37.44047"
  },
  {
    "country": "TR",
    "name": "Nurettin",
    "lat": "39.28104",
    "lng": "42.50746"
  },
  {
    "country": "TR",
    "name": "Nurettin",
    "lat": "39.22883",
    "lng": "42.41832"
  },
  {
    "country": "TR",
    "name": "Nizip",
    "lat": "37.00972",
    "lng": "37.79417"
  },
  {
    "country": "TR",
    "name": "Niğde",
    "lat": "37.96583",
    "lng": "34.67935"
  },
  {
    "country": "TR",
    "name": "Nevşehir",
    "lat": "38.625",
    "lng": "34.71222"
  },
  {
    "country": "TR",
    "name": "Nazimiye",
    "lat": "39.17986",
    "lng": "39.82843"
  },
  {
    "country": "TR",
    "name": "Nazilli",
    "lat": "37.91631",
    "lng": "28.32225"
  },
  {
    "country": "TR",
    "name": "Demirci",
    "lat": "37.41269",
    "lng": "39.76838"
  },
  {
    "country": "TR",
    "name": "Narlıdere",
    "lat": "38.2268",
    "lng": "41.89014"
  },
  {
    "country": "TR",
    "name": "Narlı",
    "lat": "37.88449",
    "lng": "42.97597"
  },
  {
    "country": "TR",
    "name": "Narlı",
    "lat": "37.39148",
    "lng": "37.13614"
  },
  {
    "country": "TR",
    "name": "Narince",
    "lat": "37.88253",
    "lng": "38.7592"
  },
  {
    "country": "TR",
    "name": "Mutki",
    "lat": "38.40624",
    "lng": "41.92018"
  },
  {
    "country": "TR",
    "name": "Mut",
    "lat": "36.64389",
    "lng": "33.43885"
  },
  {
    "country": "TR",
    "name": "Musabeyli",
    "lat": "39.83306",
    "lng": "34.62306"
  },
  {
    "country": "TR",
    "name": "Musabeyli",
    "lat": "36.88639",
    "lng": "36.91861"
  },
  {
    "country": "TR",
    "name": "Muş",
    "lat": "38.73163",
    "lng": "41.48482"
  },
  {
    "country": "TR",
    "name": "Mürşitpınar",
    "lat": "36.903",
    "lng": "38.34746"
  },
  {
    "country": "TR",
    "name": "Mursal",
    "lat": "39.16778",
    "lng": "37.95694"
  },
  {
    "country": "TR",
    "name": "Muratlı",
    "lat": "36.96167",
    "lng": "40.10056"
  },
  {
    "country": "TR",
    "name": "Murat",
    "lat": "39.67281",
    "lng": "43.23952"
  },
  {
    "country": "TR",
    "name": "Muradiye",
    "lat": "38.98568",
    "lng": "43.7531"
  },
  {
    "country": "TR",
    "name": "Muradiye",
    "lat": "38.66025",
    "lng": "27.33836"
  },
  {
    "country": "TR",
    "name": "Muncusun",
    "lat": "38.90253",
    "lng": "35.62743"
  },
  {
    "country": "TR",
    "name": "Karaova",
    "lat": "37.10699",
    "lng": "27.66578"
  },
  {
    "country": "TR",
    "name": "Muğla",
    "lat": "37.21807",
    "lng": "28.3665"
  },
  {
    "country": "TR",
    "name": "Mucur",
    "lat": "39.06147",
    "lng": "34.38286"
  },
  {
    "country": "TR",
    "name": "Mordoğan",
    "lat": "38.51648",
    "lng": "26.62447"
  },
  {
    "country": "TR",
    "name": "Elmalıdere",
    "lat": "39.63721",
    "lng": "42.31996"
  },
  {
    "country": "TR",
    "name": "Mollakendi",
    "lat": "38.57735",
    "lng": "39.33292"
  },
  {
    "country": "TR",
    "name": "Minare",
    "lat": "36.93083",
    "lng": "39.00444"
  },
  {
    "country": "TR",
    "name": "Balveren",
    "lat": "37.48357",
    "lng": "42.54834"
  },
  {
    "country": "TR",
    "name": "Milas",
    "lat": "37.31639",
    "lng": "27.78389"
  },
  {
    "country": "TR",
    "name": "Mihalıçcık",
    "lat": "39.86594",
    "lng": "31.49572"
  },
  {
    "country": "TR",
    "name": "Midyat",
    "lat": "37.41908",
    "lng": "41.33909"
  },
  {
    "country": "TR",
    "name": "Mezraa",
    "lat": "39.3859",
    "lng": "39.82439"
  },
  {
    "country": "TR",
    "name": "Mezraa",
    "lat": "37.66257",
    "lng": "43.18885"
  },
  {
    "country": "TR",
    "name": "Mezitli",
    "lat": "36.74541",
    "lng": "34.52256"
  },
  {
    "country": "TR",
    "name": "Meydankapı",
    "lat": "36.78278",
    "lng": "39.15833"
  },
  {
    "country": "TR",
    "name": "Meydan",
    "lat": "38.35585",
    "lng": "41.76941"
  },
  {
    "country": "TR",
    "name": "Söylemez",
    "lat": "39.76045",
    "lng": "41.80153"
  },
  {
    "country": "TR",
    "name": "Mersin",
    "lat": "36.81196",
    "lng": "34.63886"
  },
  {
    "country": "TR",
    "name": "Mermer",
    "lat": "38.11828",
    "lng": "40.44874"
  },
  {
    "country": "TR",
    "name": "Mercimekkale",
    "lat": "38.92945",
    "lng": "41.50325"
  },
  {
    "country": "TR",
    "name": "Meram",
    "lat": "37.82985",
    "lng": "32.46777"
  },
  {
    "country": "TR",
    "name": "Menemen",
    "lat": "38.60754",
    "lng": "27.06938"
  },
  {
    "country": "TR",
    "name": "Mazıdağı",
    "lat": "37.47801",
    "lng": "40.48152"
  },
  {
    "country": "TR",
    "name": "Mazgirt",
    "lat": "39.01783",
    "lng": "39.60064"
  },
  {
    "country": "TR",
    "name": "Marmaris",
    "lat": "36.855",
    "lng": "28.27417"
  },
  {
    "country": "TR",
    "name": "Mardin",
    "lat": "37.31309",
    "lng": "40.74357"
  },
  {
    "country": "TR",
    "name": "Mansurlu",
    "lat": "37.84853",
    "lng": "35.65436"
  },
  {
    "country": "TR",
    "name": "Manisa",
    "lat": "38.61202",
    "lng": "27.42647"
  },
  {
    "country": "TR",
    "name": "Manavgat",
    "lat": "36.78667",
    "lng": "31.44306"
  },
  {
    "country": "TR",
    "name": "Mamak",
    "lat": "39.94044",
    "lng": "32.91012"
  },
  {
    "country": "TR",
    "name": "Malazgirt",
    "lat": "39.1465",
    "lng": "42.53536"
  },
  {
    "country": "TR",
    "name": "Malatya",
    "lat": "38.35018",
    "lng": "38.31667"
  },
  {
    "country": "TR",
    "name": "Mahmutlar",
    "lat": "36.49463",
    "lng": "32.09085"
  },
  {
    "country": "TR",
    "name": "Mahmudiye",
    "lat": "39.49778",
    "lng": "30.98722"
  },
  {
    "country": "TR",
    "name": "Mağaralı",
    "lat": "36.96889",
    "lng": "38.07444"
  },
  {
    "country": "TR",
    "name": "Kırobası",
    "lat": "36.7224",
    "lng": "33.86711"
  },
  {
    "country": "TR",
    "name": "Maden",
    "lat": "38.38669",
    "lng": "39.66408"
  },
  {
    "country": "TR",
    "name": "Lice",
    "lat": "38.45821",
    "lng": "40.63888"
  },
  {
    "country": "TR",
    "name": "Levent",
    "lat": "38.43704",
    "lng": "37.85425"
  },
  {
    "country": "TR",
    "name": "Kuzucubelen",
    "lat": "36.83996",
    "lng": "34.43765"
  },
  {
    "country": "TR",
    "name": "Kuyulusebil",
    "lat": "38.65389",
    "lng": "32.52972"
  },
  {
    "country": "TR",
    "name": "Kuyucak",
    "lat": "37.9133",
    "lng": "28.45917"
  },
  {
    "country": "TR",
    "name": "Kuyucak",
    "lat": "37.86306",
    "lng": "38.34365"
  },
  {
    "country": "TR",
    "name": "Kutlubey",
    "lat": "37.30719",
    "lng": "41.1772"
  },
  {
    "country": "TR",
    "name": "Kütahya",
    "lat": "39.42417",
    "lng": "29.98333"
  },
  {
    "country": "TR",
    "name": "Kuşsarayı",
    "lat": "38.45121",
    "lng": "38.67912"
  },
  {
    "country": "TR",
    "name": "Kuşkayası",
    "lat": "39.06076",
    "lng": "37.07929"
  },
  {
    "country": "TR",
    "name": "Kuşadası",
    "lat": "37.85562",
    "lng": "27.2566"
  },
  {
    "country": "TR",
    "name": "Kuruçay",
    "lat": "39.64024",
    "lng": "38.47422"
  },
  {
    "country": "TR",
    "name": "Kurthasanlı",
    "lat": "38.32611",
    "lng": "32.17528"
  },
  {
    "country": "TR",
    "name": "Kurtalan",
    "lat": "37.92533",
    "lng": "41.68493"
  },
  {
    "country": "TR",
    "name": "Kurşunlu",
    "lat": "38.65328",
    "lng": "37.85081"
  },
  {
    "country": "TR",
    "name": "Sarıkavak",
    "lat": "36.58127",
    "lng": "33.64299"
  },
  {
    "country": "TR",
    "name": "Beykonak",
    "lat": "36.32573",
    "lng": "30.30302"
  },
  {
    "country": "TR",
    "name": "Kumluca",
    "lat": "36.37028",
    "lng": "30.28694"
  },
  {
    "country": "TR",
    "name": "Kumlu",
    "lat": "37.17222",
    "lng": "40.73536"
  },
  {
    "country": "TR",
    "name": "Kumlu",
    "lat": "36.36353",
    "lng": "36.45502"
  },
  {
    "country": "TR",
    "name": "Kumköy",
    "lat": "36.88286",
    "lng": "30.95178"
  },
  {
    "country": "TR",
    "name": "Kumdanlı",
    "lat": "38.3239",
    "lng": "30.9764"
  },
  {
    "country": "TR",
    "name": "Kumçatı",
    "lat": "37.46594",
    "lng": "42.28791"
  },
  {
    "country": "TR",
    "name": "Kuluncak",
    "lat": "38.87656",
    "lng": "37.66279"
  },
  {
    "country": "TR",
    "name": "Kulu",
    "lat": "39.09513",
    "lng": "33.07989"
  },
  {
    "country": "TR",
    "name": "Kulp",
    "lat": "38.49754",
    "lng": "41.00668"
  },
  {
    "country": "TR",
    "name": "Kula",
    "lat": "38.54726",
    "lng": "28.64976"
  },
  {
    "country": "TR",
    "name": "Kotum",
    "lat": "38.43899",
    "lng": "42.31905"
  },
  {
    "country": "TR",
    "name": "Küçükkuyu",
    "lat": "39.54889",
    "lng": "26.60528"
  },
  {
    "country": "TR",
    "name": "Denizgiren",
    "lat": "38.55734",
    "lng": "26.39305"
  },
  {
    "country": "TR",
    "name": "Kozluk",
    "lat": "38.19118",
    "lng": "41.47775"
  },
  {
    "country": "TR",
    "name": "Kozan",
    "lat": "37.45517",
    "lng": "35.81573"
  },
  {
    "country": "TR",
    "name": "Kozaklı",
    "lat": "39.22139",
    "lng": "34.85056"
  },
  {
    "country": "TR",
    "name": "Kovancılar",
    "lat": "38.71882",
    "lng": "39.86268"
  },
  {
    "country": "TR",
    "name": "Kösreli",
    "lat": "37.1625",
    "lng": "35.97834"
  },
  {
    "country": "TR",
    "name": "Köşk",
    "lat": "37.85333",
    "lng": "28.05167"
  },
  {
    "country": "TR",
    "name": "Köseli",
    "lat": "37.83879",
    "lng": "40.60811"
  },
  {
    "country": "TR",
    "name": "Kösefakılı",
    "lat": "39.59386",
    "lng": "34.13625"
  },
  {
    "country": "TR",
    "name": "Korucu",
    "lat": "39.47028",
    "lng": "27.36528"
  },
  {
    "country": "TR",
    "name": "Korkuteli",
    "lat": "37.06498",
    "lng": "30.19565"
  },
  {
    "country": "TR",
    "name": "Korkut",
    "lat": "38.7339",
    "lng": "41.78396"
  },
  {
    "country": "TR",
    "name": "Köprüören",
    "lat": "39.50832",
    "lng": "29.76233"
  },
  {
    "country": "TR",
    "name": "Köprülü",
    "lat": "36.7323",
    "lng": "32.18497"
  },
  {
    "country": "TR",
    "name": "Köprüköy",
    "lat": "39.966",
    "lng": "41.86844"
  },
  {
    "country": "TR",
    "name": "Köprübaşı",
    "lat": "38.74972",
    "lng": "28.40472"
  },
  {
    "country": "TR",
    "name": "Konyaaltı",
    "lat": "36.86644",
    "lng": "30.63031"
  },
  {
    "country": "TR",
    "name": "Konya",
    "lat": "37.87135",
    "lng": "32.48464"
  },
  {
    "country": "TR",
    "name": "Konalga",
    "lat": "37.86035",
    "lng": "43.09678"
  },
  {
    "country": "TR",
    "name": "Konakpınar",
    "lat": "39.43389",
    "lng": "27.83623"
  },
  {
    "country": "TR",
    "name": "Konakpınar",
    "lat": "38.90583",
    "lng": "37.29694"
  },
  {
    "country": "TR",
    "name": "Konaklı",
    "lat": "38.11278",
    "lng": "27.99611"
  },
  {
    "country": "TR",
    "name": "Göcek",
    "lat": "36.75345",
    "lng": "28.94571"
  },
  {
    "country": "TR",
    "name": "Kocatepe",
    "lat": "37.22922",
    "lng": "40.16104"
  },
  {
    "country": "TR",
    "name": "Koçarlı",
    "lat": "37.76113",
    "lng": "27.70583"
  },
  {
    "country": "TR",
    "name": "Kocapınar",
    "lat": "39.09553",
    "lng": "43.19616"
  },
  {
    "country": "TR",
    "name": "Koçali",
    "lat": "37.92306",
    "lng": "38.25788"
  },
  {
    "country": "TR",
    "name": "Kocaköy",
    "lat": "38.28889",
    "lng": "40.49786"
  },
  {
    "country": "TR",
    "name": "Kocakoç",
    "lat": "39.11664",
    "lng": "39.65931"
  },
  {
    "country": "TR",
    "name": "Kocahasanlı",
    "lat": "36.58417",
    "lng": "34.27359"
  },
  {
    "country": "TR",
    "name": "Kocaaliler",
    "lat": "37.31694",
    "lng": "30.74"
  },
  {
    "country": "TR",
    "name": "Kızılyaka",
    "lat": "36.98301",
    "lng": "29.52847"
  },
  {
    "country": "TR",
    "name": "Kızıltepe",
    "lat": "37.18836",
    "lng": "40.57723"
  },
  {
    "country": "TR",
    "name": "Kızılsu",
    "lat": "37.45402",
    "lng": "42.19639"
  },
  {
    "country": "TR",
    "name": "Kızılören",
    "lat": "38.25806",
    "lng": "30.15167"
  },
  {
    "country": "TR",
    "name": "Kızılören",
    "lat": "37.86847",
    "lng": "32.11618"
  },
  {
    "country": "TR",
    "name": "Kızılkaya",
    "lat": "37.30361",
    "lng": "30.44417"
  },
  {
    "country": "TR",
    "name": "Serinhisar",
    "lat": "37.58105",
    "lng": "29.26639"
  },
  {
    "country": "TR",
    "name": "Kızılcasöğüt",
    "lat": "38.65111",
    "lng": "29.66611"
  },
  {
    "country": "TR",
    "name": "Kızılcadağ",
    "lat": "37.01722",
    "lng": "29.96306"
  },
  {
    "country": "TR",
    "name": "Kızılcabölük",
    "lat": "37.61191",
    "lng": "29.01838"
  },
  {
    "country": "TR",
    "name": "Kızılağaç",
    "lat": "38.78019",
    "lng": "41.31385"
  },
  {
    "country": "TR",
    "name": "Kışlak",
    "lat": "35.9675",
    "lng": "36.15749"
  },
  {
    "country": "TR",
    "name": "Kırşehir",
    "lat": "39.14583",
    "lng": "34.16389"
  },
  {
    "country": "TR",
    "name": "Kırkgeçit",
    "lat": "38.13558",
    "lng": "43.49387"
  },
  {
    "country": "TR",
    "name": "Kırkağaç",
    "lat": "39.10638",
    "lng": "27.66925"
  },
  {
    "country": "TR",
    "name": "Kırka",
    "lat": "39.27944",
    "lng": "30.52639"
  },
  {
    "country": "TR",
    "name": "Kırıkkale",
    "lat": "39.84528",
    "lng": "33.50639"
  },
  {
    "country": "TR",
    "name": "Kırıkhan",
    "lat": "36.49939",
    "lng": "36.35755"
  },
  {
    "country": "TR",
    "name": "Kireç",
    "lat": "39.55517",
    "lng": "28.36506"
  },
  {
    "country": "TR",
    "name": "Kiraz",
    "lat": "38.23056",
    "lng": "28.20444"
  },
  {
    "country": "TR",
    "name": "Kınık",
    "lat": "39.08722",
    "lng": "27.38333"
  },
  {
    "country": "TR",
    "name": "Kilis",
    "lat": "36.71611",
    "lng": "37.115"
  },
  {
    "country": "TR",
    "name": "Kılbasan",
    "lat": "37.32488",
    "lng": "33.18634"
  },
  {
    "country": "TR",
    "name": "Kılavuz",
    "lat": "37.4796",
    "lng": "41.78374"
  },
  {
    "country": "TR",
    "name": "Kasaba",
    "lat": "39.31361",
    "lng": "40.35028"
  },
  {
    "country": "TR",
    "name": "Keskin",
    "lat": "39.67306",
    "lng": "33.61361"
  },
  {
    "country": "TR",
    "name": "Kepsut",
    "lat": "39.68889",
    "lng": "28.15222"
  },
  {
    "country": "TR",
    "name": "Kemerhisar",
    "lat": "37.82388",
    "lng": "34.57145"
  },
  {
    "country": "TR",
    "name": "Kemer",
    "lat": "37.35222",
    "lng": "30.06306"
  },
  {
    "country": "TR",
    "name": "Kemer",
    "lat": "36.6481",
    "lng": "29.3591"
  },
  {
    "country": "TR",
    "name": "Kemer",
    "lat": "36.59778",
    "lng": "30.56056"
  },
  {
    "country": "TR",
    "name": "Kemalpaşa",
    "lat": "38.42621",
    "lng": "27.41731"
  },
  {
    "country": "TR",
    "name": "Kemaliye",
    "lat": "39.26288",
    "lng": "38.49674"
  },
  {
    "country": "TR",
    "name": "Kemah",
    "lat": "39.59606",
    "lng": "39.02329"
  },
  {
    "country": "TR",
    "name": "Keles",
    "lat": "39.91361",
    "lng": "29.22944"
  },
  {
    "country": "TR",
    "name": "Kelekçi",
    "lat": "37.24073",
    "lng": "29.30425"
  },
  {
    "country": "TR",
    "name": "Keçiborlu",
    "lat": "37.9425",
    "lng": "30.30222"
  },
  {
    "country": "TR",
    "name": "Keban",
    "lat": "38.7938",
    "lng": "38.73517"
  },
  {
    "country": "TR",
    "name": "Kazımkarabekir",
    "lat": "37.23028",
    "lng": "32.95889"
  },
  {
    "country": "TR",
    "name": "Kazanlı",
    "lat": "36.81565",
    "lng": "34.75761"
  },
  {
    "country": "TR",
    "name": "Kazancı",
    "lat": "37.77106",
    "lng": "40.6"
  },
  {
    "country": "TR",
    "name": "Kazancı",
    "lat": "36.50188",
    "lng": "32.86128"
  },
  {
    "country": "TR",
    "name": "Kayseri",
    "lat": "38.73222",
    "lng": "35.48528"
  },
  {
    "country": "TR",
    "name": "Kaypak",
    "lat": "37.11487",
    "lng": "36.46511"
  },
  {
    "country": "TR",
    "name": "Kaynar",
    "lat": "38.89917",
    "lng": "36.45417"
  },
  {
    "country": "TR",
    "name": "Kaynakkaya",
    "lat": "37.33968",
    "lng": "40.93274"
  },
  {
    "country": "TR",
    "name": "Kaymaz",
    "lat": "39.51667",
    "lng": "31.17972"
  },
  {
    "country": "TR",
    "name": "Kaymakçı",
    "lat": "38.16778",
    "lng": "28.11528"
  },
  {
    "country": "TR",
    "name": "Kayapınar",
    "lat": "37.93733",
    "lng": "40.17756"
  },
  {
    "country": "TR",
    "name": "Kayapınar",
    "lat": "37.55762",
    "lng": "41.16231"
  },
  {
    "country": "TR",
    "name": "Kayapa",
    "lat": "39.49271",
    "lng": "27.44547"
  },
  {
    "country": "TR",
    "name": "Kayalıpınar",
    "lat": "37.32983",
    "lng": "41.2276"
  },
  {
    "country": "TR",
    "name": "Salmanlı",
    "lat": "39.90222",
    "lng": "34.25472"
  },
  {
    "country": "TR",
    "name": "Kayadibi",
    "lat": "39.47993",
    "lng": "36.71245"
  },
  {
    "country": "TR",
    "name": "Kayabağlar",
    "lat": "37.98599",
    "lng": "41.66756"
  },
  {
    "country": "TR",
    "name": "Kavaklıdere",
    "lat": "37.44463",
    "lng": "28.36276"
  },
  {
    "country": "TR",
    "name": "Kavakbaşı",
    "lat": "38.48337",
    "lng": "41.81967"
  },
  {
    "country": "TR",
    "name": "Kavak",
    "lat": "39.29205",
    "lng": "37.48127"
  },
  {
    "country": "TR",
    "name": "Hazar",
    "lat": "38.3878",
    "lng": "39.42365"
  },
  {
    "country": "TR",
    "name": "Kavacık",
    "lat": "39.67551",
    "lng": "28.49446"
  },
  {
    "country": "TR",
    "name": "Kasımlar",
    "lat": "37.52875",
    "lng": "31.1927"
  },
  {
    "country": "TR",
    "name": "Kaş",
    "lat": "36.20176",
    "lng": "29.63766"
  },
  {
    "country": "TR",
    "name": "Karşıyaka",
    "lat": "38.45733",
    "lng": "27.11062"
  },
  {
    "country": "TR",
    "name": "Aladağ",
    "lat": "37.5485",
    "lng": "35.39603"
  },
  {
    "country": "TR",
    "name": "Karpuzlu",
    "lat": "37.55861",
    "lng": "27.83528"
  },
  {
    "country": "TR",
    "name": "Kızılağaç",
    "lat": "36.73055",
    "lng": "31.53517"
  },
  {
    "country": "TR",
    "name": "Karlıova",
    "lat": "39.29044",
    "lng": "41.00594"
  },
  {
    "country": "TR",
    "name": "Karıncalı",
    "lat": "39.97118",
    "lng": "28.85894"
  },
  {
    "country": "TR",
    "name": "Kargı",
    "lat": "36.70132",
    "lng": "29.07557"
  },
  {
    "country": "TR",
    "name": "Karkamış",
    "lat": "36.83452",
    "lng": "37.9983"
  },
  {
    "country": "TR",
    "name": "Karayün",
    "lat": "39.68194",
    "lng": "37.30528"
  },
  {
    "country": "TR",
    "name": "Karayazı",
    "lat": "39.69604",
    "lng": "42.14277"
  },
  {
    "country": "TR",
    "name": "Karatoprak",
    "lat": "37.01385",
    "lng": "27.25893"
  },
  {
    "country": "TR",
    "name": "Karataş",
    "lat": "36.58204",
    "lng": "35.37014"
  },
  {
    "country": "TR",
    "name": "Karapınar",
    "lat": "37.71596",
    "lng": "33.55064"
  },
  {
    "country": "TR",
    "name": "Karaoğlanlı",
    "lat": "38.52917",
    "lng": "27.56667"
  },
  {
    "country": "TR",
    "name": "Karaoğlan",
    "lat": "39.22644",
    "lng": "39.20853"
  },
  {
    "country": "TR",
    "name": "Karamanlı",
    "lat": "37.37301",
    "lng": "29.82308"
  },
  {
    "country": "TR",
    "name": "Karaman",
    "lat": "37.18111",
    "lng": "33.215"
  },
  {
    "country": "TR",
    "name": "Karalar",
    "lat": "37.30073",
    "lng": "41.67582"
  },
  {
    "country": "TR",
    "name": "Karakoyunlu",
    "lat": "39.87036",
    "lng": "43.63014"
  },
  {
    "country": "TR",
    "name": "Karaköy",
    "lat": "39.09101",
    "lng": "41.68301"
  },
  {
    "country": "TR",
    "name": "Ağrı",
    "lat": "39.71944",
    "lng": "43.05139"
  },
  {
    "country": "TR",
    "name": "Karaköprü",
    "lat": "39.31512",
    "lng": "41.96458"
  },
  {
    "country": "TR",
    "name": "Karaköprü",
    "lat": "37.20361",
    "lng": "38.79944"
  },
  {
    "country": "TR",
    "name": "Karakoçan",
    "lat": "38.95178",
    "lng": "40.02706"
  },
  {
    "country": "TR",
    "name": "Karakeçili",
    "lat": "39.59417",
    "lng": "33.37778"
  },
  {
    "country": "TR",
    "name": "Karakeçi",
    "lat": "37.45234",
    "lng": "39.44285"
  },
  {
    "country": "TR",
    "name": "Karaisalı",
    "lat": "37.25667",
    "lng": "35.05889"
  },
  {
    "country": "TR",
    "name": "Karahasanlı",
    "lat": "39.29693",
    "lng": "34.72159"
  },
  {
    "country": "TR",
    "name": "Karahallı",
    "lat": "38.32083",
    "lng": "29.53028"
  },
  {
    "country": "TR",
    "name": "Karadirek",
    "lat": "38.56834",
    "lng": "30.18417"
  },
  {
    "country": "TR",
    "name": "Karaçoban",
    "lat": "39.34364",
    "lng": "42.09918"
  },
  {
    "country": "TR",
    "name": "Karaçay",
    "lat": "36.13551",
    "lng": "36.07743"
  },
  {
    "country": "TR",
    "name": "Karacaören",
    "lat": "39.73062",
    "lng": "38.11527"
  },
  {
    "country": "TR",
    "name": "Karacasu",
    "lat": "37.72816",
    "lng": "28.60569"
  },
  {
    "country": "TR",
    "name": "Karacadağ",
    "lat": "37.72894",
    "lng": "39.63547"
  },
  {
    "country": "TR",
    "name": "Karaburun",
    "lat": "38.6364",
    "lng": "26.51094"
  },
  {
    "country": "TR",
    "name": "Karaağıl",
    "lat": "39.13609",
    "lng": "42.08459"
  },
  {
    "country": "TR",
    "name": "Kanlıavşar",
    "lat": "37.21646",
    "lng": "38.30936"
  },
  {
    "country": "TR",
    "name": "Kangal",
    "lat": "39.23354",
    "lng": "37.39111"
  },
  {
    "country": "TR",
    "name": "Kandilli",
    "lat": "39.90587",
    "lng": "40.83662"
  },
  {
    "country": "TR",
    "name": "Kaman",
    "lat": "39.3575",
    "lng": "33.72389"
  },
  {
    "country": "TR",
    "name": "Kalkım",
    "lat": "39.81167",
    "lng": "27.215"
  },
  {
    "country": "TR",
    "name": "Kalkan",
    "lat": "36.2651",
    "lng": "29.41369"
  },
  {
    "country": "TR",
    "name": "Kabahaydar",
    "lat": "37.31338",
    "lng": "39.00995"
  },
  {
    "country": "TR",
    "name": "Kale",
    "lat": "39.03333",
    "lng": "38"
  },
  {
    "country": "TR",
    "name": "Kale",
    "lat": "37.43917",
    "lng": "28.84528"
  },
  {
    "country": "TR",
    "name": "Kâhta",
    "lat": "37.78552",
    "lng": "38.6237"
  },
  {
    "country": "TR",
    "name": "Kahramanmaraş",
    "lat": "37.5847",
    "lng": "36.92641"
  },
  {
    "country": "TR",
    "name": "Kadışehri",
    "lat": "39.99568",
    "lng": "35.79193"
  },
  {
    "country": "TR",
    "name": "Kadirli",
    "lat": "37.37389",
    "lng": "36.09611"
  },
  {
    "country": "TR",
    "name": "Kadınhanı",
    "lat": "38.23972",
    "lng": "32.21139"
  },
  {
    "country": "TR",
    "name": "Kabala",
    "lat": "37.34585",
    "lng": "40.80059"
  },
  {
    "country": "TR",
    "name": "Kabahaydar",
    "lat": "37.4",
    "lng": "39.08333"
  },
  {
    "country": "TR",
    "name": "İzmir",
    "lat": "38.41273",
    "lng": "27.13838"
  },
  {
    "country": "TR",
    "name": "İvrindi",
    "lat": "39.58389",
    "lng": "27.48639"
  },
  {
    "country": "TR",
    "name": "Isparta",
    "lat": "37.76444",
    "lng": "30.55222"
  },
  {
    "country": "TR",
    "name": "Yuntdağ",
    "lat": "38.93167",
    "lng": "27.21361"
  },
  {
    "country": "TR",
    "name": "İslahiye",
    "lat": "37.025",
    "lng": "36.63056"
  },
  {
    "country": "TR",
    "name": "İskenderun",
    "lat": "36.58718",
    "lng": "36.17347"
  },
  {
    "country": "TR",
    "name": "Işıklar",
    "lat": "38.67101",
    "lng": "30.74098"
  },
  {
    "country": "TR",
    "name": "İshaklı",
    "lat": "38.19972",
    "lng": "30.01333"
  },
  {
    "country": "TR",
    "name": "Kavsan",
    "lat": "37.65653",
    "lng": "40.65806"
  },
  {
    "country": "TR",
    "name": "İscehisar",
    "lat": "38.86194",
    "lng": "30.75028"
  },
  {
    "country": "TR",
    "name": "İsabeyli",
    "lat": "37.90147",
    "lng": "28.26475"
  },
  {
    "country": "TR",
    "name": "İnönü",
    "lat": "39.81534",
    "lng": "30.14549"
  },
  {
    "country": "TR",
    "name": "İnönü",
    "lat": "37.31667",
    "lng": "33.76667"
  },
  {
    "country": "TR",
    "name": "İncirliova",
    "lat": "37.85222",
    "lng": "27.72361"
  },
  {
    "country": "TR",
    "name": "İncesu",
    "lat": "38.6224",
    "lng": "35.18261"
  },
  {
    "country": "TR",
    "name": "İmranlı",
    "lat": "39.87544",
    "lng": "38.11358"
  },
  {
    "country": "TR",
    "name": "İmamoğlu",
    "lat": "37.26506",
    "lng": "35.65717"
  },
  {
    "country": "TR",
    "name": "İlyaslı",
    "lat": "38.60389",
    "lng": "29.20056"
  },
  {
    "country": "TR",
    "name": "Ilıca",
    "lat": "39.94653",
    "lng": "41.0952"
  },
  {
    "country": "TR",
    "name": "Ilıca",
    "lat": "39.87583",
    "lng": "27.77639"
  },
  {
    "country": "TR",
    "name": "Ilıcalar",
    "lat": "38.98034",
    "lng": "40.67394"
  },
  {
    "country": "TR",
    "name": "İliç",
    "lat": "39.45106",
    "lng": "38.55836"
  },
  {
    "country": "TR",
    "name": "Ilgın",
    "lat": "38.27917",
    "lng": "31.91389"
  },
  {
    "country": "TR",
    "name": "İkizce",
    "lat": "39.59516",
    "lng": "32.66097"
  },
  {
    "country": "TR",
    "name": "İkizce",
    "lat": "36.86262",
    "lng": "37.77432"
  },
  {
    "country": "TR",
    "name": "Aviski",
    "lat": "37.96459",
    "lng": "41.33119"
  },
  {
    "country": "TR",
    "name": "İhsaniye",
    "lat": "39.02916",
    "lng": "30.41639"
  },
  {
    "country": "TR",
    "name": "Iğdır",
    "lat": "39.92371",
    "lng": "44.045"
  },
  {
    "country": "TR",
    "name": "İdil",
    "lat": "37.33481",
    "lng": "41.88944"
  },
  {
    "country": "TR",
    "name": "Teffi",
    "lat": "37.55781",
    "lng": "41.09551"
  },
  {
    "country": "TR",
    "name": "İçme",
    "lat": "38.61257",
    "lng": "39.5513"
  },
  {
    "country": "TR",
    "name": "Hüyük",
    "lat": "37.95388",
    "lng": "31.59639"
  },
  {
    "country": "TR",
    "name": "Hozat",
    "lat": "39.10029",
    "lng": "39.20816"
  },
  {
    "country": "TR",
    "name": "Hotamış",
    "lat": "37.64004",
    "lng": "33.31862"
  },
  {
    "country": "TR",
    "name": "Horsunlu",
    "lat": "37.91441",
    "lng": "28.59151"
  },
  {
    "country": "TR",
    "name": "Honaz",
    "lat": "37.7573",
    "lng": "29.26996"
  },
  {
    "country": "TR",
    "name": "Hocalar",
    "lat": "38.57824",
    "lng": "29.96768"
  },
  {
    "country": "TR",
    "name": "Gyundyukoru",
    "lat": "37.14207",
    "lng": "40.50149"
  },
  {
    "country": "TR",
    "name": "Selçuklu",
    "lat": "37.8842",
    "lng": "32.49222"
  },
  {
    "country": "TR",
    "name": "Hizan",
    "lat": "38.22498",
    "lng": "42.4183"
  },
  {
    "country": "TR",
    "name": "Hisarcık",
    "lat": "39.25057",
    "lng": "29.23116"
  },
  {
    "country": "TR",
    "name": "Hisar",
    "lat": "37.60094",
    "lng": "41.22799"
  },
  {
    "country": "TR",
    "name": "Hınıs",
    "lat": "39.35766",
    "lng": "41.69253"
  },
  {
    "country": "TR",
    "name": "Himmetdede",
    "lat": "38.91028",
    "lng": "35.09607"
  },
  {
    "country": "TR",
    "name": "Hilvan",
    "lat": "37.58687",
    "lng": "38.95505"
  },
  {
    "country": "TR",
    "name": "Hilal",
    "lat": "37.47528",
    "lng": "42.78583"
  },
  {
    "country": "TR",
    "name": "Hıdırbey",
    "lat": "36.20802",
    "lng": "36.12787"
  },
  {
    "country": "TR",
    "name": "Hıdırbaba",
    "lat": "38.76706",
    "lng": "38.97698"
  },
  {
    "country": "TR",
    "name": "Hekimhan",
    "lat": "38.81622",
    "lng": "37.92882"
  },
  {
    "country": "TR",
    "name": "Hekimdağ",
    "lat": "39.90904",
    "lng": "30.5646"
  },
  {
    "country": "TR",
    "name": "Hazro",
    "lat": "38.24903",
    "lng": "40.77129"
  },
  {
    "country": "TR",
    "name": "Haymana",
    "lat": "39.43212",
    "lng": "32.49732"
  },
  {
    "country": "TR",
    "name": "Haydarlı",
    "lat": "38.25972",
    "lng": "30.38583"
  },
  {
    "country": "TR",
    "name": "Havran",
    "lat": "39.55833",
    "lng": "27.09833"
  },
  {
    "country": "TR",
    "name": "Hatunsaray",
    "lat": "37.58753",
    "lng": "32.34802"
  },
  {
    "country": "TR",
    "name": "Hatip",
    "lat": "37.75447",
    "lng": "32.4222"
  },
  {
    "country": "TR",
    "name": "Hassa",
    "lat": "36.79944",
    "lng": "36.51778"
  },
  {
    "country": "TR",
    "name": "Alacakaya",
    "lat": "38.45751",
    "lng": "39.85956"
  },
  {
    "country": "TR",
    "name": "Hasköy",
    "lat": "38.68231",
    "lng": "41.67851"
  },
  {
    "country": "TR",
    "name": "Hasbek",
    "lat": "39.54945",
    "lng": "35.54772"
  },
  {
    "country": "TR",
    "name": "Hasankeyf",
    "lat": "37.70612",
    "lng": "41.4048"
  },
  {
    "country": "TR",
    "name": "Hasançelebi",
    "lat": "38.95093",
    "lng": "37.88064"
  },
  {
    "country": "TR",
    "name": "Hasanbeyli",
    "lat": "37.12838",
    "lng": "36.54608"
  },
  {
    "country": "TR",
    "name": "Haruniye",
    "lat": "37.24216",
    "lng": "36.45484"
  },
  {
    "country": "TR",
    "name": "Harran",
    "lat": "36.86",
    "lng": "39.03139"
  },
  {
    "country": "TR",
    "name": "Harput",
    "lat": "38.70373",
    "lng": "39.2415"
  },
  {
    "country": "TR",
    "name": "Harmanlı",
    "lat": "37.83812",
    "lng": "37.74428"
  },
  {
    "country": "TR",
    "name": "Harmancık",
    "lat": "39.67611",
    "lng": "29.15528"
  },
  {
    "country": "TR",
    "name": "Harbiye",
    "lat": "36.13685",
    "lng": "36.13293"
  },
  {
    "country": "TR",
    "name": "Han",
    "lat": "39.15917",
    "lng": "30.86139"
  },
  {
    "country": "TR",
    "name": "Hankendi",
    "lat": "38.56879",
    "lng": "39.05739"
  },
  {
    "country": "TR",
    "name": "Hani",
    "lat": "38.40741",
    "lng": "40.38578"
  },
  {
    "country": "TR",
    "name": "Hanköy",
    "lat": "36.95081",
    "lng": "40.19855"
  },
  {
    "country": "TR",
    "name": "Hamzalı",
    "lat": "38.34159",
    "lng": "41.16254"
  },
  {
    "country": "TR",
    "name": "Hamur",
    "lat": "39.60561",
    "lng": "42.985"
  },
  {
    "country": "TR",
    "name": "Hamdibey",
    "lat": "39.84944",
    "lng": "27.24806"
  },
  {
    "country": "TR",
    "name": "Halkapınar",
    "lat": "37.43394",
    "lng": "34.18743"
  },
  {
    "country": "TR",
    "name": "Halitpaşa",
    "lat": "38.68541",
    "lng": "27.67836"
  },
  {
    "country": "TR",
    "name": "Halilçavuş",
    "lat": "39.2472",
    "lng": "41.79257"
  },
  {
    "country": "TR",
    "name": "Halfeti",
    "lat": "37.24529",
    "lng": "37.86874"
  },
  {
    "country": "TR",
    "name": "Tuzla",
    "lat": "36.70074",
    "lng": "35.08726"
  },
  {
    "country": "TR",
    "name": "Hafik",
    "lat": "39.85639",
    "lng": "37.38639"
  },
  {
    "country": "TR",
    "name": "Hadim",
    "lat": "36.98776",
    "lng": "32.45674"
  },
  {
    "country": "TR",
    "name": "Hacılar",
    "lat": "38.64631",
    "lng": "35.44937"
  },
  {
    "country": "TR",
    "name": "Hacıbektaş",
    "lat": "38.94077",
    "lng": "34.5577"
  },
  {
    "country": "TR",
    "name": "Aydınlar",
    "lat": "38.62198",
    "lng": "38.54052"
  },
  {
    "country": "TR",
    "name": "Haberli",
    "lat": "37.3051",
    "lng": "41.61758"
  },
  {
    "country": "TR",
    "name": "Güzelyurt",
    "lat": "38.27722",
    "lng": "34.37194"
  },
  {
    "country": "TR",
    "name": "Güzelsu",
    "lat": "38.31032",
    "lng": "43.79906"
  },
  {
    "country": "TR",
    "name": "Güzelsu",
    "lat": "36.89472",
    "lng": "31.85639"
  },
  {
    "country": "TR",
    "name": "Güzeloluk",
    "lat": "36.79444",
    "lng": "34.08274"
  },
  {
    "country": "TR",
    "name": "Güzelbağ",
    "lat": "36.73363",
    "lng": "31.89837"
  },
  {
    "country": "TR",
    "name": "Güvercinlik",
    "lat": "37.13706",
    "lng": "27.58186"
  },
  {
    "country": "TR",
    "name": "Gürün",
    "lat": "38.72225",
    "lng": "37.27097"
  },
  {
    "country": "TR",
    "name": "Gürpınar",
    "lat": "38.32372",
    "lng": "43.40991"
  },
  {
    "country": "TR",
    "name": "Güroymak",
    "lat": "38.5758",
    "lng": "42.01558"
  },
  {
    "country": "TR",
    "name": "Güre",
    "lat": "38.65111",
    "lng": "29.16694"
  },
  {
    "country": "TR",
    "name": "Günyüzü",
    "lat": "39.38345",
    "lng": "31.80995"
  },
  {
    "country": "TR",
    "name": "Güney",
    "lat": "38.15444",
    "lng": "29.06778"
  },
  {
    "country": "TR",
    "name": "Güneren",
    "lat": "36.73417",
    "lng": "39.08861"
  },
  {
    "country": "TR",
    "name": "Eksere",
    "lat": "36.81339",
    "lng": "31.99971"
  },
  {
    "country": "TR",
    "name": "Homa",
    "lat": "38.23927",
    "lng": "29.98651"
  },
  {
    "country": "TR",
    "name": "Salanda",
    "lat": "38.82556",
    "lng": "34.53212"
  },
  {
    "country": "TR",
    "name": "Gümüşakar",
    "lat": "39.79382",
    "lng": "38.67297"
  },
  {
    "country": "TR",
    "name": "Becuh",
    "lat": "37.39141",
    "lng": "42.99018"
  },
  {
    "country": "TR",
    "name": "Gülveren",
    "lat": "37.48711",
    "lng": "41.49446"
  },
  {
    "country": "TR",
    "name": "Gülşehir",
    "lat": "38.74594",
    "lng": "34.62524"
  },
  {
    "country": "TR",
    "name": "Gülpınar",
    "lat": "39.53278",
    "lng": "26.12056"
  },
  {
    "country": "TR",
    "name": "Gülnar",
    "lat": "36.34148",
    "lng": "33.39921"
  },
  {
    "country": "TR",
    "name": "Kiulukioi",
    "lat": "37.23972",
    "lng": "27.60028"
  },
  {
    "country": "TR",
    "name": "Güllü",
    "lat": "38.27114",
    "lng": "29.10451"
  },
  {
    "country": "TR",
    "name": "Yenisu",
    "lat": "38.75201",
    "lng": "40.87571"
  },
  {
    "country": "TR",
    "name": "Güleçler",
    "lat": "37.95333",
    "lng": "42.53861"
  },
  {
    "country": "TR",
    "name": "Başköy",
    "lat": "39.87231",
    "lng": "39.84188"
  },
  {
    "country": "TR",
    "name": "Gücük",
    "lat": "38.1936",
    "lng": "37.4812"
  },
  {
    "country": "TR",
    "name": "Baraniferho",
    "lat": "37.46957",
    "lng": "41.90593"
  },
  {
    "country": "TR",
    "name": "Gözpınar",
    "lat": "37.97717",
    "lng": "41.45761"
  },
  {
    "country": "TR",
    "name": "Gözne",
    "lat": "36.99528",
    "lng": "34.57306"
  },
  {
    "country": "TR",
    "name": "Gözler",
    "lat": "38.10679",
    "lng": "29.15375"
  },
  {
    "country": "TR",
    "name": "Gözeli",
    "lat": "38.4246",
    "lng": "39.05728"
  },
  {
    "country": "TR",
    "name": "Göynük",
    "lat": "39.13947",
    "lng": "40.87438"
  },
  {
    "country": "TR",
    "name": "Göynük",
    "lat": "36.66",
    "lng": "30.55"
  },
  {
    "country": "TR",
    "name": "Payamlı",
    "lat": "37.03651",
    "lng": "38.61337"
  },
  {
    "country": "TR",
    "name": "Bisbin",
    "lat": "37.33929",
    "lng": "42.56945"
  },
  {
    "country": "TR",
    "name": "Göreme",
    "lat": "38.6437",
    "lng": "34.83529"
  },
  {
    "country": "TR",
    "name": "Gördes",
    "lat": "38.93278",
    "lng": "28.28942"
  },
  {
    "country": "TR",
    "name": "Gönen",
    "lat": "37.95639",
    "lng": "30.5114"
  },
  {
    "country": "TR",
    "name": "Gömeç",
    "lat": "39.39016",
    "lng": "26.84127"
  },
  {
    "country": "TR",
    "name": "Gölova",
    "lat": "36.79917",
    "lng": "30.03889"
  },
  {
    "country": "TR",
    "name": "Beyviran",
    "lat": "37.84949",
    "lng": "33.8597"
  },
  {
    "country": "TR",
    "name": "Gölmarmara",
    "lat": "38.71389",
    "lng": "27.91417"
  },
  {
    "country": "TR",
    "name": "Göllü",
    "lat": "39.4499",
    "lng": "34.30011"
  },
  {
    "country": "TR",
    "name": "Gölhisar",
    "lat": "37.1459",
    "lng": "29.50876"
  },
  {
    "country": "TR",
    "name": "Gölgelikonak",
    "lat": "37.76923",
    "lng": "42.12744"
  },
  {
    "country": "TR",
    "name": "Göldüzü",
    "lat": "38.81335",
    "lng": "43.01904"
  },
  {
    "country": "TR",
    "name": "Gölcük",
    "lat": "39.31309",
    "lng": "27.98319"
  },
  {
    "country": "TR",
    "name": "Tilfetis",
    "lat": "37.48135",
    "lng": "39.04736"
  },
  {
    "country": "TR",
    "name": "Gölbaşı",
    "lat": "39.79043",
    "lng": "32.80903"
  },
  {
    "country": "TR",
    "name": "Gölbaşı",
    "lat": "37.78361",
    "lng": "37.63667"
  },
  {
    "country": "TR",
    "name": "Göktepe",
    "lat": "37.41908",
    "lng": "28.55894"
  },
  {
    "country": "TR",
    "name": "Göktepe",
    "lat": "36.62687",
    "lng": "32.6228"
  },
  {
    "country": "TR",
    "name": "Göksun",
    "lat": "38.02096",
    "lng": "36.4973"
  },
  {
    "country": "TR",
    "name": "Göksu",
    "lat": "39.48906",
    "lng": "42.15127"
  },
  {
    "country": "TR",
    "name": "Gökoğlan",
    "lat": "39.54648",
    "lng": "41.30402"
  },
  {
    "country": "TR",
    "name": "Gökdere",
    "lat": "38.7428",
    "lng": "40.20815"
  },
  {
    "country": "TR",
    "name": "Ergama",
    "lat": "39.62712",
    "lng": "27.63139"
  },
  {
    "country": "TR",
    "name": "Menye",
    "lat": "38.57528",
    "lng": "28.48889"
  },
  {
    "country": "TR",
    "name": "Gökçen",
    "lat": "38.11367",
    "lng": "27.87144"
  },
  {
    "country": "TR",
    "name": "Gökçekoru",
    "lat": "37.95621",
    "lng": "42.44971"
  },
  {
    "country": "TR",
    "name": "Gökçedağ",
    "lat": "39.55832",
    "lng": "28.91911"
  },
  {
    "country": "TR",
    "name": "Civankan",
    "lat": "37.90339",
    "lng": "41.87752"
  },
  {
    "country": "TR",
    "name": "Selah",
    "lat": "37.20541",
    "lng": "40.69748"
  },
  {
    "country": "TR",
    "name": "Gökbudak",
    "lat": "37.90367",
    "lng": "42.64866"
  },
  {
    "country": "TR",
    "name": "Göçbeyli",
    "lat": "39.22328",
    "lng": "27.40386"
  },
  {
    "country": "TR",
    "name": "Girmeli",
    "lat": "37.11106",
    "lng": "41.4196"
  },
  {
    "country": "TR",
    "name": "Geyikpınar",
    "lat": "38.31759",
    "lng": "41.82065"
  },
  {
    "country": "TR",
    "name": "Geyikli",
    "lat": "39.80472",
    "lng": "26.2075"
  },
  {
    "country": "TR",
    "name": "Gevaş",
    "lat": "38.2921",
    "lng": "43.10189"
  },
  {
    "country": "TR",
    "name": "Gesi",
    "lat": "38.7918",
    "lng": "35.65923"
  },
  {
    "country": "TR",
    "name": "Germencik",
    "lat": "37.87056",
    "lng": "27.60283"
  },
  {
    "country": "TR",
    "name": "Geriş",
    "lat": "36.9625",
    "lng": "31.73306"
  },
  {
    "country": "TR",
    "name": "Gerger",
    "lat": "37.95",
    "lng": "39.01667"
  },
  {
    "country": "TR",
    "name": "Gerdzhyush",
    "lat": "37.56249",
    "lng": "41.37753"
  },
  {
    "country": "TR",
    "name": "Gencek",
    "lat": "37.44984",
    "lng": "31.54588"
  },
  {
    "country": "TR",
    "name": "Genç",
    "lat": "38.74773",
    "lng": "40.55343"
  },
  {
    "country": "TR",
    "name": "Gemerek",
    "lat": "39.18342",
    "lng": "36.07189"
  },
  {
    "country": "TR",
    "name": "Gelinkaya",
    "lat": "37.41683",
    "lng": "41.26994"
  },
  {
    "country": "TR",
    "name": "Gelendost",
    "lat": "38.12083",
    "lng": "31.01528"
  },
  {
    "country": "TR",
    "name": "Gelembe",
    "lat": "39.17872",
    "lng": "27.84848"
  },
  {
    "country": "TR",
    "name": "Gediz",
    "lat": "38.99389",
    "lng": "29.39131"
  },
  {
    "country": "TR",
    "name": "Gedikler",
    "lat": "39.08229",
    "lng": "38.80346"
  },
  {
    "country": "TR",
    "name": "Timar",
    "lat": "38.82865",
    "lng": "43.4333"
  },
  {
    "country": "TR",
    "name": "Gedikbaşı",
    "lat": "39.48939",
    "lng": "38.24743"
  },
  {
    "country": "TR",
    "name": "Geçitli",
    "lat": "37.58669",
    "lng": "43.56163"
  },
  {
    "country": "TR",
    "name": "Gebiz",
    "lat": "37.10417",
    "lng": "30.93778"
  },
  {
    "country": "TR",
    "name": "Gazipaşa",
    "lat": "36.26942",
    "lng": "32.31792"
  },
  {
    "country": "TR",
    "name": "Gaziemir",
    "lat": "38.32392",
    "lng": "27.12918"
  },
  {
    "country": "TR",
    "name": "Gaziantep",
    "lat": "37.05944",
    "lng": "37.3825"
  },
  {
    "country": "TR",
    "name": "Foça",
    "lat": "38.6703",
    "lng": "26.75656"
  },
  {
    "country": "TR",
    "name": "Finike",
    "lat": "36.295",
    "lng": "30.14056"
  },
  {
    "country": "TR",
    "name": "Fındık",
    "lat": "37.51317",
    "lng": "41.96418"
  },
  {
    "country": "TR",
    "name": "Fevzipaşa",
    "lat": "37.09418",
    "lng": "36.63719"
  },
  {
    "country": "TR",
    "name": "Fethiye",
    "lat": "36.64038",
    "lng": "29.12758"
  },
  {
    "country": "TR",
    "name": "Felahiye",
    "lat": "39.09056",
    "lng": "35.56722"
  },
  {
    "country": "TR",
    "name": "Feke",
    "lat": "37.81446",
    "lng": "35.91233"
  },
  {
    "country": "TR",
    "name": "Ezine",
    "lat": "39.78561",
    "lng": "26.34083"
  },
  {
    "country": "TR",
    "name": "Eymirli",
    "lat": "37.1703",
    "lng": "40.68684"
  },
  {
    "country": "TR",
    "name": "Evciler",
    "lat": "39.77556",
    "lng": "26.77167"
  },
  {
    "country": "TR",
    "name": "Evciler",
    "lat": "38.04139",
    "lng": "29.88667"
  },
  {
    "country": "TR",
    "name": "Etimesgut",
    "lat": "39.95328",
    "lng": "32.63285"
  },
  {
    "country": "TR",
    "name": "Etili",
    "lat": "39.98556",
    "lng": "26.89667"
  },
  {
    "country": "TR",
    "name": "Eşme",
    "lat": "38.39976",
    "lng": "28.96905"
  },
  {
    "country": "TR",
    "name": "Eşme",
    "lat": "37.15569",
    "lng": "40.64142"
  },
  {
    "country": "TR",
    "name": "Eskişehir",
    "lat": "39.77667",
    "lng": "30.52056"
  },
  {
    "country": "TR",
    "name": "Eskil",
    "lat": "38.40167",
    "lng": "33.41306"
  },
  {
    "country": "TR",
    "name": "Esendere",
    "lat": "37.71144",
    "lng": "44.60099"
  },
  {
    "country": "TR",
    "name": "Eşen",
    "lat": "36.4548",
    "lng": "29.28154"
  },
  {
    "country": "TR",
    "name": "Erzurum",
    "lat": "39.90861",
    "lng": "41.27694"
  },
  {
    "country": "TR",
    "name": "Erzincan",
    "lat": "39.73919",
    "lng": "39.49015"
  },
  {
    "country": "TR",
    "name": "Eruh",
    "lat": "37.74183",
    "lng": "42.17422"
  },
  {
    "country": "TR",
    "name": "Ertuğrul",
    "lat": "39.57578",
    "lng": "27.70672"
  },
  {
    "country": "TR",
    "name": "Ermenek",
    "lat": "36.64043",
    "lng": "32.89179"
  },
  {
    "country": "TR",
    "name": "Erköklü",
    "lat": "37.86182",
    "lng": "41.14413"
  },
  {
    "country": "TR",
    "name": "Erkilet",
    "lat": "38.82043",
    "lng": "35.44011"
  },
  {
    "country": "TR",
    "name": "Ergani",
    "lat": "38.26899",
    "lng": "39.75446"
  },
  {
    "country": "TR",
    "name": "Erentepe",
    "lat": "39.00893",
    "lng": "42.04364"
  },
  {
    "country": "TR",
    "name": "Ereğli",
    "lat": "37.51333",
    "lng": "34.04672"
  },
  {
    "country": "TR",
    "name": "Erdemli",
    "lat": "36.60498",
    "lng": "34.30836"
  },
  {
    "country": "TR",
    "name": "Erciş",
    "lat": "39.02587",
    "lng": "43.35964"
  },
  {
    "country": "TR",
    "name": "Erçek",
    "lat": "38.65107",
    "lng": "43.64401"
  },
  {
    "country": "TR",
    "name": "Bulucan",
    "lat": "39.7025",
    "lng": "37.75972"
  },
  {
    "country": "TR",
    "name": "Emirgazi",
    "lat": "37.90222",
    "lng": "33.83722"
  },
  {
    "country": "TR",
    "name": "Emirdağ",
    "lat": "39.01972",
    "lng": "31.15"
  },
  {
    "country": "TR",
    "name": "Emiralem",
    "lat": "38.60971",
    "lng": "27.14588"
  },
  {
    "country": "TR",
    "name": "Emet",
    "lat": "39.343",
    "lng": "29.25847"
  },
  {
    "country": "TR",
    "name": "Elvanlı",
    "lat": "36.70401",
    "lng": "34.37374"
  },
  {
    "country": "TR",
    "name": "Güneysınır",
    "lat": "37.26944",
    "lng": "32.72898"
  },
  {
    "country": "TR",
    "name": "Elmalı",
    "lat": "36.73583",
    "lng": "29.91775"
  },
  {
    "country": "TR",
    "name": "Elmadağ",
    "lat": "39.92083",
    "lng": "33.23083"
  },
  {
    "country": "TR",
    "name": "Eleşkirt",
    "lat": "39.79803",
    "lng": "42.67574"
  },
  {
    "country": "TR",
    "name": "Elbistan",
    "lat": "38.20591",
    "lng": "37.1983"
  },
  {
    "country": "TR",
    "name": "Elbeyli",
    "lat": "36.67417",
    "lng": "37.46667"
  },
  {
    "country": "TR",
    "name": "Elbaşı",
    "lat": "38.67351",
    "lng": "35.96753"
  },
  {
    "country": "TR",
    "name": "Elazığ",
    "lat": "38.67431",
    "lng": "39.22321"
  },
  {
    "country": "TR",
    "name": "Celeyke",
    "lat": "38.05974",
    "lng": "37.18786"
  },
  {
    "country": "TR",
    "name": "Üçpınar",
    "lat": "38.73423",
    "lng": "27.36164"
  },
  {
    "country": "TR",
    "name": "Eğirdir",
    "lat": "37.87462",
    "lng": "30.85042"
  },
  {
    "country": "TR",
    "name": "Eğil",
    "lat": "38.25748",
    "lng": "40.07435"
  },
  {
    "country": "TR",
    "name": "Kocasinan",
    "lat": "38.77147",
    "lng": "35.5725"
  },
  {
    "country": "TR",
    "name": "Edremit",
    "lat": "39.59611",
    "lng": "27.02444"
  },
  {
    "country": "TR",
    "name": "Düzova",
    "lat": "37.35413",
    "lng": "42.08837"
  },
  {
    "country": "TR",
    "name": "Dutluca",
    "lat": "39.13586",
    "lng": "38.60662"
  },
  {
    "country": "TR",
    "name": "Duruca",
    "lat": "37.09309",
    "lng": "41.30986"
  },
  {
    "country": "TR",
    "name": "Dursunbey",
    "lat": "39.58596",
    "lng": "28.62568"
  },
  {
    "country": "TR",
    "name": "Durak",
    "lat": "39.70658",
    "lng": "28.27176"
  },
  {
    "country": "TR",
    "name": "Dumlupınar",
    "lat": "38.85408",
    "lng": "29.9772"
  },
  {
    "country": "TR",
    "name": "Sumbas",
    "lat": "37.4513",
    "lng": "36.02349"
  },
  {
    "country": "TR",
    "name": "Döşemealtı",
    "lat": "37.02333",
    "lng": "30.60247"
  },
  {
    "country": "TR",
    "name": "Dorutay",
    "lat": "38.79939",
    "lng": "44.06726"
  },
  {
    "country": "TR",
    "name": "Dorumali",
    "lat": "36.805",
    "lng": "38.85306"
  },
  {
    "country": "TR",
    "name": "Dörtyol",
    "lat": "36.83917",
    "lng": "36.23025"
  },
  {
    "country": "TR",
    "name": "Dombay",
    "lat": "38.15421",
    "lng": "30.20876"
  },
  {
    "country": "TR",
    "name": "Domaniç",
    "lat": "39.80194",
    "lng": "29.60918"
  },
  {
    "country": "TR",
    "name": "Doğubayazıt",
    "lat": "39.54694",
    "lng": "44.08417"
  },
  {
    "country": "TR",
    "name": "Doğanyol",
    "lat": "38.30746",
    "lng": "39.03431"
  },
  {
    "country": "TR",
    "name": "Doğansu",
    "lat": "39.13248",
    "lng": "42.73249"
  },
  {
    "country": "TR",
    "name": "Doğanşehir",
    "lat": "38.08574",
    "lng": "37.87116"
  },
  {
    "country": "TR",
    "name": "Doğanpınar",
    "lat": "36.84321",
    "lng": "37.61759"
  },
  {
    "country": "TR",
    "name": "Doğanköy",
    "lat": "37.76334",
    "lng": "42.78929"
  },
  {
    "country": "TR",
    "name": "Doğankent",
    "lat": "36.84432",
    "lng": "35.34396"
  },
  {
    "country": "TR",
    "name": "Doğankavak",
    "lat": "37.96265",
    "lng": "41.22675"
  },
  {
    "country": "TR",
    "name": "Doğanhisar",
    "lat": "38.1463",
    "lng": "31.67648"
  },
  {
    "country": "TR",
    "name": "Doğanca",
    "lat": "37.79955",
    "lng": "42.33099"
  },
  {
    "country": "TR",
    "name": "Doğanbeyli",
    "lat": "39.69517",
    "lng": "39.03499"
  },
  {
    "country": "TR",
    "name": "Doğanbey",
    "lat": "37.8005",
    "lng": "31.8911"
  },
  {
    "country": "TR",
    "name": "Dodurga",
    "lat": "39.79972",
    "lng": "29.91722"
  },
  {
    "country": "TR",
    "name": "Diyarbakır",
    "lat": "37.91363",
    "lng": "40.21721"
  },
  {
    "country": "TR",
    "name": "Diyadin",
    "lat": "39.54056",
    "lng": "43.67135"
  },
  {
    "country": "TR",
    "name": "Divriği",
    "lat": "39.371",
    "lng": "38.1137"
  },
  {
    "country": "TR",
    "name": "Direkli",
    "lat": "39.71167",
    "lng": "36.65167"
  },
  {
    "country": "TR",
    "name": "Dinek",
    "lat": "37.32481",
    "lng": "32.61602"
  },
  {
    "country": "TR",
    "name": "Dinar",
    "lat": "38.065",
    "lng": "30.16557"
  },
  {
    "country": "TR",
    "name": "Dilektepe",
    "lat": "38.07517",
    "lng": "41.82717"
  },
  {
    "country": "TR",
    "name": "Dikili",
    "lat": "39.071",
    "lng": "26.89017"
  },
  {
    "country": "TR",
    "name": "Dicle",
    "lat": "38.36571",
    "lng": "40.0645"
  },
  {
    "country": "TR",
    "name": "Dicle",
    "lat": "37.28869",
    "lng": "42.06721"
  },
  {
    "country": "TR",
    "name": "Develi",
    "lat": "38.39056",
    "lng": "35.49222"
  },
  {
    "country": "TR",
    "name": "Devecikonağı",
    "lat": "39.91486",
    "lng": "28.56176"
  },
  {
    "country": "TR",
    "name": "Derinkuyu",
    "lat": "38.3751",
    "lng": "34.73419"
  },
  {
    "country": "TR",
    "name": "Derik",
    "lat": "37.36336",
    "lng": "40.26473"
  },
  {
    "country": "TR",
    "name": "Dereyanı",
    "lat": "37.42746",
    "lng": "40.86096"
  },
  {
    "country": "TR",
    "name": "Turanlı",
    "lat": "39.27682",
    "lng": "27.3246"
  },
  {
    "country": "TR",
    "name": "Derebucak",
    "lat": "37.39179",
    "lng": "31.50918"
  },
  {
    "country": "TR",
    "name": "Dere",
    "lat": "38.98295",
    "lng": "39.30017"
  },
  {
    "country": "TR",
    "name": "Derbent",
    "lat": "38.01422",
    "lng": "32.01639"
  },
  {
    "country": "TR",
    "name": "Denizli",
    "lat": "37.77417",
    "lng": "29.0875"
  },
  {
    "country": "TR",
    "name": "Demiryol",
    "lat": "37.91751",
    "lng": "41.14984"
  },
  {
    "country": "TR",
    "name": "Adala",
    "lat": "38.57757",
    "lng": "28.26847"
  },
  {
    "country": "TR",
    "name": "Demirci",
    "lat": "39.04607",
    "lng": "28.65889"
  },
  {
    "country": "TR",
    "name": "Deliktaş",
    "lat": "39.34157",
    "lng": "37.20378"
  },
  {
    "country": "TR",
    "name": "Delice",
    "lat": "39.95371",
    "lng": "34.02587"
  },
  {
    "country": "TR",
    "name": "Deliçay",
    "lat": "39.08163",
    "lng": "43.48552"
  },
  {
    "country": "TR",
    "name": "Değirmendere",
    "lat": "38.11361",
    "lng": "27.14139"
  },
  {
    "country": "TR",
    "name": "Dedeli",
    "lat": "39.17435",
    "lng": "43.05524"
  },
  {
    "country": "TR",
    "name": "Dazkırı",
    "lat": "37.91861",
    "lng": "29.86056"
  },
  {
    "country": "TR",
    "name": "Davutlar",
    "lat": "37.73392",
    "lng": "27.29283"
  },
  {
    "country": "TR",
    "name": "Davulga",
    "lat": "38.97917",
    "lng": "31.37139"
  },
  {
    "country": "TR",
    "name": "Datça",
    "lat": "36.73778",
    "lng": "27.68417"
  },
  {
    "country": "TR",
    "name": "Darıkent",
    "lat": "38.96252",
    "lng": "39.80792"
  },
  {
    "country": "TR",
    "name": "Dargeçit",
    "lat": "37.54616",
    "lng": "41.71652"
  },
  {
    "country": "TR",
    "name": "Darende",
    "lat": "38.54583",
    "lng": "37.50583"
  },
  {
    "country": "TR",
    "name": "Danişment",
    "lat": "39.86917",
    "lng": "27.63306"
  },
  {
    "country": "TR",
    "name": "Damlacık",
    "lat": "37.9142",
    "lng": "38.65392"
  },
  {
    "country": "TR",
    "name": "Dalyan",
    "lat": "36.83429",
    "lng": "28.6446"
  },
  {
    "country": "TR",
    "name": "Dallıbahçe",
    "lat": "39.13321",
    "lng": "39.87929"
  },
  {
    "country": "TR",
    "name": "Dalama",
    "lat": "37.79028",
    "lng": "28.06639"
  },
  {
    "country": "TR",
    "name": "Dağyolu",
    "lat": "39.53845",
    "lng": "39.90765"
  },
  {
    "country": "TR",
    "name": "Dağlıca",
    "lat": "37.36658",
    "lng": "44.08528"
  },
  {
    "country": "TR",
    "name": "Dağkızılca",
    "lat": "38.311",
    "lng": "27.39081"
  },
  {
    "country": "TR",
    "name": "Serhatta",
    "lat": "37.66278",
    "lng": "42.14064"
  },
  {
    "country": "TR",
    "name": "Dağ",
    "lat": "37.19306",
    "lng": "30.50417"
  },
  {
    "country": "TR",
    "name": "Karahan",
    "lat": "37.89825",
    "lng": "39.33366"
  },
  {
    "country": "TR",
    "name": "Dağardı",
    "lat": "39.4308",
    "lng": "28.99558"
  },
  {
    "country": "TR",
    "name": "Dadaşköy",
    "lat": "39.94489",
    "lng": "41.25465"
  },
  {
    "country": "TR",
    "name": "Çüngüş",
    "lat": "38.20798",
    "lng": "39.28554"
  },
  {
    "country": "TR",
    "name": "Çumra",
    "lat": "37.5732",
    "lng": "32.77446"
  },
  {
    "country": "TR",
    "name": "Menderes",
    "lat": "38.24963",
    "lng": "27.13429"
  },
  {
    "country": "TR",
    "name": "Cumaçay",
    "lat": "39.91524",
    "lng": "43.18653"
  },
  {
    "country": "TR",
    "name": "Akziyaret",
    "lat": "37.35328",
    "lng": "38.79609"
  },
  {
    "country": "TR",
    "name": "Çukurca",
    "lat": "37.24806",
    "lng": "43.61361"
  },
  {
    "country": "TR",
    "name": "Özvatan",
    "lat": "39.1069",
    "lng": "35.69994"
  },
  {
    "country": "TR",
    "name": "Düvertepe",
    "lat": "39.23734",
    "lng": "28.44001"
  },
  {
    "country": "TR",
    "name": "Hakkari",
    "lat": "37.57444",
    "lng": "43.74083"
  },
  {
    "country": "TR",
    "name": "Çolaklı",
    "lat": "38.33351",
    "lng": "38.51946"
  },
  {
    "country": "TR",
    "name": "Çokak",
    "lat": "37.73613",
    "lng": "36.32865"
  },
  {
    "country": "TR",
    "name": "Çobanlar",
    "lat": "38.70139",
    "lng": "30.78278"
  },
  {
    "country": "TR",
    "name": "Cizre",
    "lat": "37.33024",
    "lng": "42.18484"
  },
  {
    "country": "TR",
    "name": "Çivril",
    "lat": "38.30139",
    "lng": "29.73861"
  },
  {
    "country": "TR",
    "name": "Çırpı",
    "lat": "38.16444",
    "lng": "27.4975"
  },
  {
    "country": "TR",
    "name": "Çine",
    "lat": "37.61266",
    "lng": "28.05912"
  },
  {
    "country": "TR",
    "name": "Çınaraltı",
    "lat": "37.3849",
    "lng": "40.85938"
  },
  {
    "country": "TR",
    "name": "Çınar",
    "lat": "37.72226",
    "lng": "40.40696"
  },
  {
    "country": "TR",
    "name": "Evren",
    "lat": "39.02402",
    "lng": "33.80626"
  },
  {
    "country": "TR",
    "name": "Cihanbeyli",
    "lat": "38.66072",
    "lng": "32.92437"
  },
  {
    "country": "TR",
    "name": "Ashuta",
    "lat": "37.3229",
    "lng": "43.37482"
  },
  {
    "country": "TR",
    "name": "Serkan",
    "lat": "37.15878",
    "lng": "41.74132"
  },
  {
    "country": "TR",
    "name": "Çiğil",
    "lat": "37.47923",
    "lng": "33.31805"
  },
  {
    "country": "TR",
    "name": "Girikbedro",
    "lat": "37.18028",
    "lng": "42.42111"
  },
  {
    "country": "TR",
    "name": "Çiftlik",
    "lat": "39.78276",
    "lng": "40.63484"
  },
  {
    "country": "TR",
    "name": "Melikgazi",
    "lat": "38.75",
    "lng": "35.45"
  },
  {
    "country": "TR",
    "name": "Çiftlik",
    "lat": "38.1758",
    "lng": "34.48535"
  },
  {
    "country": "TR",
    "name": "Çifteler",
    "lat": "39.38306",
    "lng": "31.03917"
  },
  {
    "country": "TR",
    "name": "Çiftehan",
    "lat": "37.51233",
    "lng": "34.76953"
  },
  {
    "country": "TR",
    "name": "Çiçekli",
    "lat": "39.05468",
    "lng": "39.41604"
  },
  {
    "country": "TR",
    "name": "Çiçekdağı",
    "lat": "39.60694",
    "lng": "34.40861"
  },
  {
    "country": "TR",
    "name": "Ceylanpınar",
    "lat": "36.84722",
    "lng": "40.05"
  },
  {
    "country": "TR",
    "name": "Ceyhan",
    "lat": "37.02472",
    "lng": "35.8175"
  },
  {
    "country": "TR",
    "name": "Çevrimova",
    "lat": "37.84003",
    "lng": "41.27288"
  },
  {
    "country": "TR",
    "name": "Cevizlik",
    "lat": "38.17554",
    "lng": "42.22602"
  },
  {
    "country": "TR",
    "name": "Cevizli",
    "lat": "37.19694",
    "lng": "31.76333"
  },
  {
    "country": "TR",
    "name": "Çatalan",
    "lat": "37.24857",
    "lng": "35.2911"
  },
  {
    "country": "TR",
    "name": "Çetinkaya",
    "lat": "39.26178",
    "lng": "37.62603"
  },
  {
    "country": "TR",
    "name": "Çeşme",
    "lat": "38.32614",
    "lng": "26.30574"
  },
  {
    "country": "TR",
    "name": "Çermik",
    "lat": "38.13538",
    "lng": "39.445"
  },
  {
    "country": "TR",
    "name": "Cengerli",
    "lat": "39.79426",
    "lng": "38.84814"
  },
  {
    "country": "TR",
    "name": "Çemişgezek",
    "lat": "39.05539",
    "lng": "38.90754"
  },
  {
    "country": "TR",
    "name": "Çeltikçi",
    "lat": "37.52947",
    "lng": "30.48028"
  },
  {
    "country": "TR",
    "name": "Çeltik",
    "lat": "39.02444",
    "lng": "31.79056"
  },
  {
    "country": "TR",
    "name": "Çelikhan",
    "lat": "38.0256",
    "lng": "38.23665"
  },
  {
    "country": "TR",
    "name": "Çelebi",
    "lat": "39.46418",
    "lng": "33.5241"
  },
  {
    "country": "TR",
    "name": "Celâlli",
    "lat": "39.6925",
    "lng": "37.42389"
  },
  {
    "country": "TR",
    "name": "Çaylı",
    "lat": "38.1533",
    "lng": "28.14406"
  },
  {
    "country": "TR",
    "name": "Çaylarbaşı",
    "lat": "37.7001",
    "lng": "39.00965"
  },
  {
    "country": "TR",
    "name": "Çaylar",
    "lat": "39.26731",
    "lng": "41.28344"
  },
  {
    "country": "TR",
    "name": "Mans",
    "lat": "39.80775",
    "lng": "40.028"
  },
  {
    "country": "TR",
    "name": "Çayıralan",
    "lat": "39.30278",
    "lng": "35.64389"
  },
  {
    "country": "TR",
    "name": "Çaybağı",
    "lat": "38.69401",
    "lng": "39.62022"
  },
  {
    "country": "TR",
    "name": "Çay",
    "lat": "38.59167",
    "lng": "31.02861"
  },
  {
    "country": "TR",
    "name": "Çavuşlu",
    "lat": "37.50179",
    "lng": "41.24877"
  },
  {
    "country": "TR",
    "name": "Çavuş",
    "lat": "37.60963",
    "lng": "31.93135"
  },
  {
    "country": "TR",
    "name": "Çavdır",
    "lat": "37.155",
    "lng": "29.69389"
  },
  {
    "country": "TR",
    "name": "Çavdarhisar",
    "lat": "39.19344",
    "lng": "29.61915"
  },
  {
    "country": "TR",
    "name": "Çatalçam",
    "lat": "39.97438",
    "lng": "38.84777"
  },
  {
    "country": "TR",
    "name": "Çatalarmut",
    "lat": "39.80286",
    "lng": "39.31539"
  },
  {
    "country": "TR",
    "name": "Malabadi",
    "lat": "38.15162",
    "lng": "41.20256"
  },
  {
    "country": "TR",
    "name": "Çatak",
    "lat": "38.00293",
    "lng": "43.05243"
  },
  {
    "country": "TR",
    "name": "Çat",
    "lat": "39.60641",
    "lng": "40.96844"
  },
  {
    "country": "TR",
    "name": "Çardak",
    "lat": "38.09171",
    "lng": "36.82356"
  },
  {
    "country": "TR",
    "name": "Çardak",
    "lat": "37.82694",
    "lng": "29.66833"
  },
  {
    "country": "TR",
    "name": "Çandır",
    "lat": "39.24446",
    "lng": "35.51396"
  },
  {
    "country": "TR",
    "name": "Çandarlı",
    "lat": "38.93503",
    "lng": "26.934"
  },
  {
    "country": "TR",
    "name": "Çan",
    "lat": "39.14833",
    "lng": "40.20348"
  },
  {
    "country": "TR",
    "name": "Çamlıyayla",
    "lat": "37.16652",
    "lng": "34.59296"
  },
  {
    "country": "TR",
    "name": "Çamlıdere",
    "lat": "37.1544",
    "lng": "39.06697"
  },
  {
    "country": "TR",
    "name": "Anamas",
    "lat": "37.76667",
    "lng": "30.8"
  },
  {
    "country": "TR",
    "name": "Çameli",
    "lat": "37.07611",
    "lng": "29.34472"
  },
  {
    "country": "TR",
    "name": "Çamardı",
    "lat": "37.83222",
    "lng": "34.98139"
  },
  {
    "country": "TR",
    "name": "Çaltılıbük",
    "lat": "39.9559",
    "lng": "28.5991"
  },
  {
    "country": "TR",
    "name": "Çalpınar",
    "lat": "37.36542",
    "lng": "41.18576"
  },
  {
    "country": "TR",
    "name": "Çalışkan",
    "lat": "37.29751",
    "lng": "42.64226"
  },
  {
    "country": "TR",
    "name": "Çaldıran",
    "lat": "39.14317",
    "lng": "43.91068"
  },
  {
    "country": "TR",
    "name": "Çal",
    "lat": "38.08361",
    "lng": "29.39889"
  },
  {
    "country": "TR",
    "name": "Çakırlar",
    "lat": "36.87145",
    "lng": "30.56208"
  },
  {
    "country": "TR",
    "name": "Keysun",
    "lat": "37.56075",
    "lng": "37.85583"
  },
  {
    "country": "TR",
    "name": "Çakırbeyli",
    "lat": "37.73501",
    "lng": "27.82388"
  },
  {
    "country": "TR",
    "name": "Menteşe",
    "lat": "37.11667",
    "lng": "28.26667"
  },
  {
    "country": "TR",
    "name": "Çağlayancerit",
    "lat": "37.74523",
    "lng": "37.28618"
  },
  {
    "country": "TR",
    "name": "Çağlayan",
    "lat": "39.58502",
    "lng": "39.68702"
  },
  {
    "country": "TR",
    "name": "Çağlarca",
    "lat": "39.03732",
    "lng": "39.13865"
  },
  {
    "country": "TR",
    "name": "Çağış",
    "lat": "39.51881",
    "lng": "28.01224"
  },
  {
    "country": "TR",
    "name": "Dereova",
    "lat": "39.25042",
    "lng": "39.86916"
  },
  {
    "country": "TR",
    "name": "Nikfer",
    "lat": "37.40542",
    "lng": "29.13727"
  },
  {
    "country": "TR",
    "name": "Cinatamiho",
    "lat": "37.27304",
    "lng": "41.03364"
  },
  {
    "country": "TR",
    "name": "Boğaziçi",
    "lat": "38.03472",
    "lng": "27.55944"
  },
  {
    "country": "TR",
    "name": "Armutlu",
    "lat": "39.5755",
    "lng": "38.42722"
  },
  {
    "country": "TR",
    "name": "Burhaniye",
    "lat": "39.50041",
    "lng": "26.97269"
  },
  {
    "country": "TR",
    "name": "Buharkent",
    "lat": "37.96397",
    "lng": "28.7427"
  },
  {
    "country": "TR",
    "name": "Burdur",
    "lat": "37.72028",
    "lng": "30.29083"
  },
  {
    "country": "TR",
    "name": "Burç",
    "lat": "37.01362",
    "lng": "37.17913"
  },
  {
    "country": "TR",
    "name": "Bünyan",
    "lat": "38.8463",
    "lng": "35.86033"
  },
  {
    "country": "TR",
    "name": "Buldan",
    "lat": "38.045",
    "lng": "28.83056"
  },
  {
    "country": "TR",
    "name": "Bulanık",
    "lat": "39.08656",
    "lng": "42.27158"
  },
  {
    "country": "TR",
    "name": "Bucakkışla",
    "lat": "36.95443",
    "lng": "33.02196"
  },
  {
    "country": "TR",
    "name": "Buca",
    "lat": "38.3983",
    "lng": "27.16662"
  },
  {
    "country": "TR",
    "name": "Bucak",
    "lat": "37.45917",
    "lng": "30.595"
  },
  {
    "country": "TR",
    "name": "Bozyazı",
    "lat": "36.1082",
    "lng": "32.96113"
  },
  {
    "country": "TR",
    "name": "Bozüyük",
    "lat": "39.90778",
    "lng": "30.03667"
  },
  {
    "country": "TR",
    "name": "Boztepe",
    "lat": "39.26972",
    "lng": "34.26111"
  },
  {
    "country": "TR",
    "name": "Bozova",
    "lat": "37.3625",
    "lng": "38.52667"
  },
  {
    "country": "TR",
    "name": "Bozova",
    "lat": "37.21611",
    "lng": "30.28583"
  },
  {
    "country": "TR",
    "name": "Bozoğlak",
    "lat": "39.62292",
    "lng": "38.80194"
  },
  {
    "country": "TR",
    "name": "Bozkurt",
    "lat": "37.82417",
    "lng": "29.60972"
  },
  {
    "country": "TR",
    "name": "Bozkır",
    "lat": "37.18963",
    "lng": "32.24736"
  },
  {
    "country": "TR",
    "name": "Taliban",
    "lat": "37.981",
    "lng": "41.41328"
  },
  {
    "country": "TR",
    "name": "Bozdoğan",
    "lat": "37.67134",
    "lng": "28.31395"
  },
  {
    "country": "TR",
    "name": "Bozcaada",
    "lat": "39.835",
    "lng": "26.06972"
  },
  {
    "country": "TR",
    "name": "Bozburun",
    "lat": "36.69495",
    "lng": "28.04336"
  },
  {
    "country": "TR",
    "name": "Bozarmut",
    "lat": "37.30917",
    "lng": "28.16972"
  },
  {
    "country": "TR",
    "name": "Bozan",
    "lat": "39.78806",
    "lng": "31.10167"
  },
  {
    "country": "TR",
    "name": "Bozalan",
    "lat": "37.32874",
    "lng": "42.26366"
  },
  {
    "country": "TR",
    "name": "Bostancı",
    "lat": "37.17778",
    "lng": "42.32906"
  },
  {
    "country": "TR",
    "name": "Bornova",
    "lat": "38.47921",
    "lng": "27.2399"
  },
  {
    "country": "TR",
    "name": "Borlu",
    "lat": "38.75291",
    "lng": "28.46744"
  },
  {
    "country": "TR",
    "name": "Bor",
    "lat": "37.89056",
    "lng": "34.55889"
  },
  {
    "country": "TR",
    "name": "Bolvadin",
    "lat": "38.71111",
    "lng": "31.04861"
  },
  {
    "country": "TR",
    "name": "Simek",
    "lat": "38.32748",
    "lng": "42.17448"
  },
  {
    "country": "TR",
    "name": "Bölme",
    "lat": "38.62076",
    "lng": "29.37373"
  },
  {
    "country": "TR",
    "name": "Böğürtlen",
    "lat": "37.16632",
    "lng": "38.0811"
  },
  {
    "country": "TR",
    "name": "Boğazören",
    "lat": "37.52775",
    "lng": "43.00778"
  },
  {
    "country": "TR",
    "name": "Boğazlıyan",
    "lat": "39.18877",
    "lng": "35.24537"
  },
  {
    "country": "TR",
    "name": "Boğazkent",
    "lat": "36.85319",
    "lng": "31.16388"
  },
  {
    "country": "TR",
    "name": "Bodrum",
    "lat": "37.03833",
    "lng": "27.42917"
  },
  {
    "country": "TR",
    "name": "Bitlis",
    "lat": "38.40115",
    "lng": "42.10784"
  },
  {
    "country": "TR",
    "name": "Bismil",
    "lat": "37.84514",
    "lng": "40.65931"
  },
  {
    "country": "TR",
    "name": "Birgi",
    "lat": "38.25028",
    "lng": "28.05917"
  },
  {
    "country": "TR",
    "name": "Birecik",
    "lat": "37.02577",
    "lng": "37.97841"
  },
  {
    "country": "TR",
    "name": "Bingöl",
    "lat": "38.88472",
    "lng": "40.49389"
  },
  {
    "country": "TR",
    "name": "Binatlı",
    "lat": "37.84708",
    "lng": "41.21608"
  },
  {
    "country": "TR",
    "name": "Bigadiç",
    "lat": "39.3925",
    "lng": "28.13111"
  },
  {
    "country": "TR",
    "name": "Beytüşşebap",
    "lat": "37.56318",
    "lng": "43.16583"
  },
  {
    "country": "TR",
    "name": "Beyşehir",
    "lat": "37.67735",
    "lng": "31.72458"
  },
  {
    "country": "TR",
    "name": "Beypınarı",
    "lat": "39.5064",
    "lng": "37.7069"
  },
  {
    "country": "TR",
    "name": "Beylikova",
    "lat": "39.68694",
    "lng": "31.20556"
  },
  {
    "country": "TR",
    "name": "Beyçayırı",
    "lat": "38.01412",
    "lng": "41.32372"
  },
  {
    "country": "TR",
    "name": "Beyağaç",
    "lat": "37.23526",
    "lng": "28.89612"
  },
  {
    "country": "TR",
    "name": "Kızılin",
    "lat": "37.54693",
    "lng": "38.07595"
  },
  {
    "country": "TR",
    "name": "Beşpınar",
    "lat": "37.83709",
    "lng": "41.60219"
  },
  {
    "country": "TR",
    "name": "Besni",
    "lat": "37.69278",
    "lng": "37.86111"
  },
  {
    "country": "TR",
    "name": "Beşkonak",
    "lat": "37.14444",
    "lng": "31.19917"
  },
  {
    "country": "TR",
    "name": "Beşiri",
    "lat": "37.91573",
    "lng": "41.2865"
  },
  {
    "country": "TR",
    "name": "Bergama",
    "lat": "39.12074",
    "lng": "27.18052"
  },
  {
    "country": "TR",
    "name": "Belören",
    "lat": "37.63723",
    "lng": "37.5803"
  },
  {
    "country": "TR",
    "name": "Belören",
    "lat": "37.2148",
    "lng": "32.55363"
  },
  {
    "country": "TR",
    "name": "Belevi",
    "lat": "38.015",
    "lng": "27.45028"
  },
  {
    "country": "TR",
    "name": "Belen",
    "lat": "36.48866",
    "lng": "36.19489"
  },
  {
    "country": "TR",
    "name": "Demirtaş",
    "lat": "36.42611",
    "lng": "32.1925"
  },
  {
    "country": "TR",
    "name": "Belek",
    "lat": "36.86278",
    "lng": "31.05556"
  },
  {
    "country": "TR",
    "name": "Bekirhan",
    "lat": "38.14086",
    "lng": "41.29351"
  },
  {
    "country": "TR",
    "name": "Bekilli",
    "lat": "38.23105",
    "lng": "29.4197"
  },
  {
    "country": "TR",
    "name": "Behram",
    "lat": "39.49344",
    "lng": "26.33316"
  },
  {
    "country": "TR",
    "name": "Beğendik",
    "lat": "37.97557",
    "lng": "42.64823"
  },
  {
    "country": "TR",
    "name": "Bucak",
    "lat": "37.8693",
    "lng": "39.06199"
  },
  {
    "country": "TR",
    "name": "Bedirli",
    "lat": "39.58276",
    "lng": "36.62049"
  },
  {
    "country": "TR",
    "name": "Bayramiç",
    "lat": "39.80862",
    "lng": "26.60983"
  },
  {
    "country": "TR",
    "name": "Bayraklı",
    "lat": "38.46717",
    "lng": "27.16384"
  },
  {
    "country": "TR",
    "name": "Baykan",
    "lat": "38.15754",
    "lng": "41.7733"
  },
  {
    "country": "TR",
    "name": "Bayır",
    "lat": "37.26774",
    "lng": "28.21677"
  },
  {
    "country": "TR",
    "name": "Bayındır",
    "lat": "38.21741",
    "lng": "27.64744"
  },
  {
    "country": "TR",
    "name": "Bayat",
    "lat": "38.98306",
    "lng": "30.92472"
  },
  {
    "country": "TR",
    "name": "Batman",
    "lat": "37.88738",
    "lng": "41.13221"
  },
  {
    "country": "TR",
    "name": "Başyurt",
    "lat": "38.83505",
    "lng": "39.97929"
  },
  {
    "country": "TR",
    "name": "Başpınar",
    "lat": "39.19017",
    "lng": "38.68737"
  },
  {
    "country": "TR",
    "name": "Başmakçı",
    "lat": "37.89722",
    "lng": "30.01167"
  },
  {
    "country": "TR",
    "name": "Baskil",
    "lat": "38.56866",
    "lng": "38.81634"
  },
  {
    "country": "TR",
    "name": "Başkavak",
    "lat": "37.56468",
    "lng": "40.88757"
  },
  {
    "country": "TR",
    "name": "Başkale",
    "lat": "38.04526",
    "lng": "44.01718"
  },
  {
    "country": "TR",
    "name": "Yoğun",
    "lat": "38.09906",
    "lng": "39.51321"
  },
  {
    "country": "TR",
    "name": "Barla",
    "lat": "38.01778",
    "lng": "30.78278"
  },
  {
    "country": "TR",
    "name": "Barıştepe",
    "lat": "37.4832",
    "lng": "41.40251"
  },
  {
    "country": "TR",
    "name": "Banaz",
    "lat": "38.73707",
    "lng": "29.75194"
  },
  {
    "country": "TR",
    "name": "Balya",
    "lat": "39.74861",
    "lng": "27.57889"
  },
  {
    "country": "TR",
    "name": "Balpınar",
    "lat": "37.86804",
    "lng": "41.05536"
  },
  {
    "country": "TR",
    "name": "Balpayam",
    "lat": "39.42006",
    "lng": "40.05713"
  },
  {
    "country": "TR",
    "name": "Balışeyh",
    "lat": "39.91411",
    "lng": "33.72333"
  },
  {
    "country": "TR",
    "name": "Balıkesir",
    "lat": "39.64917",
    "lng": "27.88611"
  },
  {
    "country": "TR",
    "name": "Balcı",
    "lat": "38.72532",
    "lng": "34.10123"
  },
  {
    "country": "TR",
    "name": "Balaban",
    "lat": "38.46106",
    "lng": "37.57881"
  },
  {
    "country": "TR",
    "name": "Bala",
    "lat": "39.55422",
    "lng": "33.12344"
  },
  {
    "country": "TR",
    "name": "Baklan",
    "lat": "37.97694",
    "lng": "29.60861"
  },
  {
    "country": "TR",
    "name": "Bahşılı",
    "lat": "39.80017",
    "lng": "33.43701"
  },
  {
    "country": "TR",
    "name": "Bahçesaray",
    "lat": "38.1246",
    "lng": "42.79825"
  },
  {
    "country": "TR",
    "name": "Bahçe",
    "lat": "37.19724",
    "lng": "36.57658"
  },
  {
    "country": "TR",
    "name": "Bağpınar",
    "lat": "37.59139",
    "lng": "38.3191"
  },
  {
    "country": "TR",
    "name": "Bağlıca",
    "lat": "37.86974",
    "lng": "41.7511"
  },
  {
    "country": "TR",
    "name": "Bağlıca",
    "lat": "37.52705",
    "lng": "40.68618"
  },
  {
    "country": "TR",
    "name": "Bağlıca",
    "lat": "37.43333",
    "lng": "42.77417"
  },
  {
    "country": "TR",
    "name": "Bağkonak",
    "lat": "38.2175",
    "lng": "31.27222"
  },
  {
    "country": "TR",
    "name": "Hazekyan",
    "lat": "37.71769",
    "lng": "44.0356"
  },
  {
    "country": "TR",
    "name": "Lodi",
    "lat": "37.71261",
    "lng": "41.9154"
  },
  {
    "country": "TR",
    "name": "Bağdere",
    "lat": "38.11442",
    "lng": "40.73382"
  },
  {
    "country": "TR",
    "name": "Bağarası",
    "lat": "37.7071",
    "lng": "27.54875"
  },
  {
    "country": "TR",
    "name": "Bademli",
    "lat": "38.08167",
    "lng": "28.05778"
  },
  {
    "country": "TR",
    "name": "Babatorun",
    "lat": "36.07743",
    "lng": "36.29051"
  },
  {
    "country": "TR",
    "name": "Babadağ",
    "lat": "37.80764",
    "lng": "28.85665"
  },
  {
    "country": "TR",
    "name": "Ayvalık",
    "lat": "39.31905",
    "lng": "26.6954"
  },
  {
    "country": "TR",
    "name": "Ayvacık",
    "lat": "39.60111",
    "lng": "26.40472"
  },
  {
    "country": "TR",
    "name": "Ayrancı",
    "lat": "37.36127",
    "lng": "33.6883"
  },
  {
    "country": "TR",
    "name": "Tillo",
    "lat": "37.94911",
    "lng": "42.0121"
  },
  {
    "country": "TR",
    "name": "Aydınkonak",
    "lat": "37.89461",
    "lng": "41.16405"
  },
  {
    "country": "TR",
    "name": "İbradı",
    "lat": "37.09694",
    "lng": "31.59917"
  },
  {
    "country": "TR",
    "name": "Aydıncık",
    "lat": "36.1437",
    "lng": "33.32016"
  },
  {
    "country": "TR",
    "name": "Aydın",
    "lat": "37.84501",
    "lng": "27.83963"
  },
  {
    "country": "TR",
    "name": "Avsallar",
    "lat": "36.62448",
    "lng": "31.76941"
  },
  {
    "country": "TR",
    "name": "Avanos",
    "lat": "38.715",
    "lng": "34.84667"
  },
  {
    "country": "TR",
    "name": "Atça",
    "lat": "37.88859",
    "lng": "28.21528"
  },
  {
    "country": "TR",
    "name": "Atburgazı",
    "lat": "37.63639",
    "lng": "27.24611"
  },
  {
    "country": "TR",
    "name": "Atabey",
    "lat": "37.95083",
    "lng": "30.63861"
  },
  {
    "country": "TR",
    "name": "Aslanapa",
    "lat": "39.21581",
    "lng": "29.8699"
  },
  {
    "country": "TR",
    "name": "Aşkale",
    "lat": "39.92083",
    "lng": "40.695"
  },
  {
    "country": "TR",
    "name": "Aşağıpınarbaşı",
    "lat": "38.03833",
    "lng": "32.60083"
  },
  {
    "country": "TR",
    "name": "Kale",
    "lat": "38.41538",
    "lng": "38.77092"
  },
  {
    "country": "TR",
    "name": "Aşağıçiğil",
    "lat": "38.0515",
    "lng": "31.86379"
  },
  {
    "country": "TR",
    "name": "Aşağı Beğdeş",
    "lat": "36.81472",
    "lng": "38.91917"
  },
  {
    "country": "TR",
    "name": "Arslanköy",
    "lat": "37.01884",
    "lng": "34.28741"
  },
  {
    "country": "TR",
    "name": "Danişment",
    "lat": "39.17153",
    "lng": "38.19851"
  },
  {
    "country": "TR",
    "name": "Arıcak",
    "lat": "38.5634",
    "lng": "40.1248"
  },
  {
    "country": "TR",
    "name": "Arguvan",
    "lat": "38.77375",
    "lng": "38.26328"
  },
  {
    "country": "TR",
    "name": "Argıthanı",
    "lat": "38.29259",
    "lng": "31.71452"
  },
  {
    "country": "TR",
    "name": "Aras",
    "lat": "39.98821",
    "lng": "42.30628"
  },
  {
    "country": "TR",
    "name": "Yüreğir",
    "lat": "36.97439",
    "lng": "35.35916"
  },
  {
    "country": "TR",
    "name": "Arapgir",
    "lat": "39.04117",
    "lng": "38.49516"
  },
  {
    "country": "TR",
    "name": "Aran",
    "lat": "37.44768",
    "lng": "40.74755"
  },
  {
    "country": "TR",
    "name": "Aralık",
    "lat": "39.87278",
    "lng": "44.51917"
  },
  {
    "country": "TR",
    "name": "Aralık",
    "lat": "37.82945",
    "lng": "40.68025"
  },
  {
    "country": "TR",
    "name": "Araban",
    "lat": "37.42667",
    "lng": "37.689"
  },
  {
    "country": "TR",
    "name": "Yeşilyurt",
    "lat": "40.0064",
    "lng": "36.22069"
  },
  {
    "country": "TR",
    "name": "Antalya",
    "lat": "36.90812",
    "lng": "30.69556"
  },
  {
    "country": "TR",
    "name": "Antakya",
    "lat": "36.20655",
    "lng": "36.15722"
  },
  {
    "country": "TR",
    "name": "Ankara",
    "lat": "39.91987",
    "lng": "32.85427"
  },
  {
    "country": "TR",
    "name": "Andırın",
    "lat": "37.57757",
    "lng": "36.35492"
  },
  {
    "country": "TR",
    "name": "Andaç",
    "lat": "37.355",
    "lng": "43.26395"
  },
  {
    "country": "TR",
    "name": "Anamur",
    "lat": "36.07508",
    "lng": "32.83691"
  },
  {
    "country": "TR",
    "name": "Ambar",
    "lat": "37.85305",
    "lng": "40.52798"
  },
  {
    "country": "TR",
    "name": "Altınyayla",
    "lat": "39.27249",
    "lng": "36.75098"
  },
  {
    "country": "TR",
    "name": "Altınyayla",
    "lat": "36.99722",
    "lng": "29.54579"
  },
  {
    "country": "TR",
    "name": "Altınyaka",
    "lat": "36.55861",
    "lng": "30.34833"
  },
  {
    "country": "TR",
    "name": "Altıntaş",
    "lat": "39.05972",
    "lng": "30.10917"
  },
  {
    "country": "TR",
    "name": "Altınözü",
    "lat": "36.11244",
    "lng": "36.24488"
  },
  {
    "country": "TR",
    "name": "Altınova",
    "lat": "39.2173",
    "lng": "26.79008"
  },
  {
    "country": "TR",
    "name": "Altınoluk",
    "lat": "39.57944",
    "lng": "26.73722"
  },
  {
    "country": "TR",
    "name": "Altınkum",
    "lat": "38.26374",
    "lng": "41.0625"
  },
  {
    "country": "TR",
    "name": "Altunhisar",
    "lat": "37.99159",
    "lng": "34.37334"
  },
  {
    "country": "TR",
    "name": "Altınekin",
    "lat": "38.30778",
    "lng": "32.86861"
  },
  {
    "country": "TR",
    "name": "Alpu",
    "lat": "39.76903",
    "lng": "30.9606"
  },
  {
    "country": "TR",
    "name": "Alpköy",
    "lat": "39.61393",
    "lng": "39.18639"
  },
  {
    "country": "TR",
    "name": "Aliağa",
    "lat": "38.79975",
    "lng": "26.97203"
  },
  {
    "country": "TR",
    "name": "Gerger",
    "lat": "38.02807",
    "lng": "39.03418"
  },
  {
    "country": "TR",
    "name": "Albayrak",
    "lat": "38.14252",
    "lng": "44.2012"
  },
  {
    "country": "TR",
    "name": "Alaşehir",
    "lat": "38.35083",
    "lng": "28.51718"
  },
  {
    "country": "TR",
    "name": "Alanya",
    "lat": "36.54375",
    "lng": "31.99982"
  },
  {
    "country": "TR",
    "name": "Alakamış",
    "lat": "37.15898",
    "lng": "41.78915"
  },
  {
    "country": "TR",
    "name": "Alaçatı",
    "lat": "38.28246",
    "lng": "26.37459"
  },
  {
    "country": "TR",
    "name": "Turluk",
    "lat": "39.44034",
    "lng": "39.87773"
  },
  {
    "country": "TR",
    "name": "Alacahan",
    "lat": "39.10667",
    "lng": "37.57556"
  },
  {
    "country": "TR",
    "name": "Aktuzla",
    "lat": "39.33012",
    "lng": "42.28533"
  },
  {
    "country": "TR",
    "name": "Aktepe",
    "lat": "36.70161",
    "lng": "36.48535"
  },
  {
    "country": "TR",
    "name": "Aksu",
    "lat": "37.79889",
    "lng": "31.07111"
  },
  {
    "country": "TR",
    "name": "Aksu",
    "lat": "36.95389",
    "lng": "30.84778"
  },
  {
    "country": "TR",
    "name": "Akseki",
    "lat": "37.04861",
    "lng": "31.79"
  },
  {
    "country": "TR",
    "name": "Akşehir",
    "lat": "38.3575",
    "lng": "31.41639"
  },
  {
    "country": "TR",
    "name": "Aksaray",
    "lat": "38.37255",
    "lng": "34.02537"
  },
  {
    "country": "TR",
    "name": "Akşar",
    "lat": "38.1",
    "lng": "42.53333"
  },
  {
    "country": "TR",
    "name": "Akpınar",
    "lat": "39.45005",
    "lng": "33.96484"
  },
  {
    "country": "TR",
    "name": "Akpınar",
    "lat": "37.57389",
    "lng": "38.22077"
  },
  {
    "country": "TR",
    "name": "Akören",
    "lat": "37.45345",
    "lng": "32.3707"
  },
  {
    "country": "TR",
    "name": "Akköy",
    "lat": "37.95694",
    "lng": "29.07813"
  },
  {
    "country": "TR",
    "name": "Akköy",
    "lat": "37.49139",
    "lng": "27.26944"
  },
  {
    "country": "TR",
    "name": "Akkışla",
    "lat": "39.00222",
    "lng": "36.17381"
  },
  {
    "country": "TR",
    "name": "Akkent",
    "lat": "38.15268",
    "lng": "29.3789"
  },
  {
    "country": "TR",
    "name": "Akıncılar",
    "lat": "37.76444",
    "lng": "38.82308"
  },
  {
    "country": "TR",
    "name": "Akıncı",
    "lat": "37.16643",
    "lng": "40.84706"
  },
  {
    "country": "TR",
    "name": "Akhisar",
    "lat": "38.91852",
    "lng": "27.84006"
  },
  {
    "country": "TR",
    "name": "Akdere",
    "lat": "36.24083",
    "lng": "33.75041"
  },
  {
    "country": "TR",
    "name": "Akdağmadeni",
    "lat": "39.66028",
    "lng": "35.88361"
  },
  {
    "country": "TR",
    "name": "Akçay",
    "lat": "36.60217",
    "lng": "29.74626"
  },
  {
    "country": "TR",
    "name": "Akçapınar",
    "lat": "38.94728",
    "lng": "38.9423"
  },
  {
    "country": "TR",
    "name": "Akçaova",
    "lat": "37.50278",
    "lng": "28.02667"
  },
  {
    "country": "TR",
    "name": "Akçakent",
    "lat": "39.62278",
    "lng": "34.09583"
  },
  {
    "country": "TR",
    "name": "Akçakale",
    "lat": "36.71111",
    "lng": "38.9475"
  },
  {
    "country": "TR",
    "name": "Akçadağ",
    "lat": "38.33899",
    "lng": "37.97021"
  },
  {
    "country": "TR",
    "name": "Akarsu",
    "lat": "39.92878",
    "lng": "38.61382"
  },
  {
    "country": "TR",
    "name": "Akarsu",
    "lat": "37.22616",
    "lng": "41.05138"
  },
  {
    "country": "TR",
    "name": "Ahmetli",
    "lat": "38.5196",
    "lng": "27.93865"
  },
  {
    "country": "TR",
    "name": "Ahmetli",
    "lat": "38.17817",
    "lng": "39.85627"
  },
  {
    "country": "TR",
    "name": "Ahlat",
    "lat": "38.7489",
    "lng": "42.48007"
  },
  {
    "country": "TR",
    "name": "Ahırlı",
    "lat": "37.23874",
    "lng": "32.11881"
  },
  {
    "country": "TR",
    "name": "Ağlasun",
    "lat": "37.64944",
    "lng": "30.53417"
  },
  {
    "country": "TR",
    "name": "Ağın",
    "lat": "38.93792",
    "lng": "38.71155"
  },
  {
    "country": "TR",
    "name": "Akcakışla",
    "lat": "39.53818",
    "lng": "36.33626"
  },
  {
    "country": "TR",
    "name": "Ağaçören",
    "lat": "38.87484",
    "lng": "33.91674"
  },
  {
    "country": "TR",
    "name": "Ağaçlı",
    "lat": "38.51728",
    "lng": "40.90401"
  },
  {
    "country": "TR",
    "name": "Gülağaç",
    "lat": "38.39576",
    "lng": "34.34576"
  },
  {
    "country": "TR",
    "name": "Ağabeyli",
    "lat": "37.73362",
    "lng": "37.11625"
  },
  {
    "country": "TR",
    "name": "Afyonkarahisar",
    "lat": "38.75667",
    "lng": "30.54333"
  },
  {
    "country": "TR",
    "name": "Afşin",
    "lat": "38.24769",
    "lng": "36.91399"
  },
  {
    "country": "TR",
    "name": "Adıyaman",
    "lat": "37.76441",
    "lng": "38.27629"
  },
  {
    "country": "TR",
    "name": "Adilcevaz",
    "lat": "38.79911",
    "lng": "42.73159"
  },
  {
    "country": "TR",
    "name": "Adana",
    "lat": "37.00167",
    "lng": "35.32889"
  },
  {
    "country": "TR",
    "name": "Adaklı",
    "lat": "39.2262",
    "lng": "40.48283"
  },
  {
    "country": "TR",
    "name": "Acırlı",
    "lat": "37.45549",
    "lng": "41.29499"
  },
  {
    "country": "TR",
    "name": "Acıpınar",
    "lat": "38.52671",
    "lng": "33.85225"
  },
  {
    "country": "TR",
    "name": "Acıpayam",
    "lat": "37.42385",
    "lng": "29.34941"
  },
  {
    "country": "TR",
    "name": "Acıgöl",
    "lat": "38.55028",
    "lng": "34.50917"
  },
  {
    "country": "TR",
    "name": "Acarlar",
    "lat": "37.82444",
    "lng": "27.74667"
  },
  {
    "country": "TR",
    "name": "Çardaklı",
    "lat": "37.23098",
    "lng": "42.58409"
  },
  {
    "country": "TR",
    "name": "Ballı",
    "lat": "37.41333",
    "lng": "42.83944"
  },
  {
    "country": "TR",
    "name": "Yemişli",
    "lat": "37.3671",
    "lng": "43.07717"
  },
  {
    "country": "TR",
    "name": "Karsani",
    "lat": "37.30716",
    "lng": "43.4541"
  },
  {
    "country": "TR",
    "name": "Nurdağı",
    "lat": "37.16821",
    "lng": "36.73623"
  },
  {
    "country": "TR",
    "name": "Yeşildere",
    "lat": "36.973",
    "lng": "37.49488"
  },
  {
    "country": "TR",
    "name": "Küçükkendirci",
    "lat": "36.90583",
    "lng": "38.34611"
  },
  {
    "country": "TR",
    "name": "Mahmutlar",
    "lat": "36.949",
    "lng": "36.19231"
  },
  {
    "country": "TR",
    "name": "Gyuvench",
    "lat": "36.68538",
    "lng": "36.42312"
  },
  {
    "country": "TR",
    "name": "Aşağı Karafakılı",
    "lat": "36.77885",
    "lng": "36.55776"
  },
  {
    "country": "TR",
    "name": "Çırtıman",
    "lat": "36.52531",
    "lng": "36.18129"
  },
  {
    "country": "TR",
    "name": "Kızkalesi",
    "lat": "36.46192",
    "lng": "34.14199"
  },
  {
    "country": "TR",
    "name": "Kuzeytepe",
    "lat": "36.26505",
    "lng": "36.1535"
  },
  {
    "country": "TR",
    "name": "Kastal",
    "lat": "36.2476",
    "lng": "36.2409"
  },
  {
    "country": "TR",
    "name": "Açıkdere",
    "lat": "36.21909",
    "lng": "36.25992"
  },
  {
    "country": "TR",
    "name": "Toygarlı",
    "lat": "36.21261",
    "lng": "36.07262"
  },
  {
    "country": "TR",
    "name": "Gümüşgöze",
    "lat": "36.14785",
    "lng": "36.13284"
  },
  {
    "country": "TR",
    "name": "Dursunlu",
    "lat": "36.16736",
    "lng": "36.15788"
  },
  {
    "country": "TR",
    "name": "Aşağıokçular",
    "lat": "36.17802",
    "lng": "36.14033"
  },
  {
    "country": "TR",
    "name": "Boynuyoğun",
    "lat": "36.16935",
    "lng": "36.34249"
  },
  {
    "country": "TR",
    "name": "Uzunbağ",
    "lat": "36.14023",
    "lng": "36.03603"
  },
  {
    "country": "TR",
    "name": "Büyükçat",
    "lat": "36.115",
    "lng": "36.0774"
  },
  {
    "country": "TR",
    "name": "Balıklıdere",
    "lat": "36.12096",
    "lng": "36.10481"
  },
  {
    "country": "TR",
    "name": "Hacıpaşa",
    "lat": "36.06907",
    "lng": "36.37076"
  },
  {
    "country": "TR",
    "name": "Samankaya",
    "lat": "36.15027",
    "lng": "36.12829"
  },
  {
    "country": "TR",
    "name": "Anayazı",
    "lat": "36.32107",
    "lng": "36.19061"
  },
  {
    "country": "TR",
    "name": "Karasüleymanlı",
    "lat": "36.34191",
    "lng": "36.41431"
  },
  {
    "country": "TR",
    "name": "Büyük Dalyan",
    "lat": "36.28824",
    "lng": "36.20903"
  },
  {
    "country": "TR",
    "name": "Günyazı",
    "lat": "36.23307",
    "lng": "36.11702"
  },
  {
    "country": "TR",
    "name": "Tepehan",
    "lat": "36.15853",
    "lng": "36.2286"
  },
  {
    "country": "TR",
    "name": "Uzunkavak",
    "lat": "36.3524",
    "lng": "36.41952"
  },
  {
    "country": "TR",
    "name": "Denizciler",
    "lat": "36.6411",
    "lng": "36.21418"
  },
  {
    "country": "TR",
    "name": "Başaran",
    "lat": "37.47655",
    "lng": "43.12984"
  },
  {
    "country": "TR",
    "name": "Doruklu",
    "lat": "37.2555",
    "lng": "42.33518"
  },
  {
    "country": "TR",
    "name": "Akdiken",
    "lat": "36.725",
    "lng": "39.30861"
  },
  {
    "country": "TR",
    "name": "Bulutlu",
    "lat": "36.73583",
    "lng": "39.39389"
  },
  {
    "country": "TR",
    "name": "Pekmezli",
    "lat": "36.75361",
    "lng": "39.45"
  },
  {
    "country": "TR",
    "name": "Koyunluca",
    "lat": "36.82278",
    "lng": "39.34333"
  },
  {
    "country": "TR",
    "name": "Yukarı Taşyalak",
    "lat": "36.96306",
    "lng": "40.13194"
  },
  {
    "country": "TR",
    "name": "Işıklar",
    "lat": "36.99417",
    "lng": "40.12639"
  },
  {
    "country": "TR",
    "name": "Çıplak",
    "lat": "36.94472",
    "lng": "40.2375"
  },
  {
    "country": "TR",
    "name": "Batikent",
    "lat": "39.96833",
    "lng": "32.73083"
  },
  {
    "country": "TR",
    "name": "Türkler",
    "lat": "36.60198",
    "lng": "31.82067"
  },
  {
    "country": "TR",
    "name": "Başyayla",
    "lat": "36.75337",
    "lng": "32.68018"
  },
  {
    "country": "TR",
    "name": "Dalaman",
    "lat": "36.76591",
    "lng": "28.8028"
  },
  {
    "country": "TR",
    "name": "Zonguldak",
    "lat": "41.45139",
    "lng": "31.79305"
  },
  {
    "country": "TR",
    "name": "Zile",
    "lat": "40.30306",
    "lng": "35.88639"
  },
  {
    "country": "TR",
    "name": "Zeytinlik",
    "lat": "41.11013",
    "lng": "41.85816"
  },
  {
    "country": "TR",
    "name": "Zeytinburnu",
    "lat": "40.99441",
    "lng": "28.90417"
  },
  {
    "country": "TR",
    "name": "Zeytinbağı",
    "lat": "40.39083",
    "lng": "28.79639"
  },
  {
    "country": "TR",
    "name": "Yuvacık",
    "lat": "40.68815",
    "lng": "29.96738"
  },
  {
    "country": "TR",
    "name": "Yusufeli",
    "lat": "40.82042",
    "lng": "41.53743"
  },
  {
    "country": "TR",
    "name": "Yürük",
    "lat": "40.93553",
    "lng": "27.06631"
  },
  {
    "country": "TR",
    "name": "Yomra",
    "lat": "40.95326",
    "lng": "39.85546"
  },
  {
    "country": "TR",
    "name": "Yoğuntaş",
    "lat": "41.83081",
    "lng": "27.06971"
  },
  {
    "country": "TR",
    "name": "Boztepe",
    "lat": "40.18778",
    "lng": "35.8875"
  },
  {
    "country": "TR",
    "name": "Yığılca",
    "lat": "40.95983",
    "lng": "31.44355"
  },
  {
    "country": "TR",
    "name": "Yeşilyurt",
    "lat": "40.32786",
    "lng": "36.35144"
  },
  {
    "country": "TR",
    "name": "Yeşilvadi",
    "lat": "41.123",
    "lng": "29.47696"
  },
  {
    "country": "TR",
    "name": "Yeşilce",
    "lat": "40.53577",
    "lng": "37.79566"
  },
  {
    "country": "TR",
    "name": "Yenişehir",
    "lat": "40.26444",
    "lng": "29.65306"
  },
  {
    "country": "TR",
    "name": "Yenipazar",
    "lat": "40.17833",
    "lng": "30.52"
  },
  {
    "country": "TR",
    "name": "Yeniköy",
    "lat": "40.53568",
    "lng": "29.35364"
  },
  {
    "country": "TR",
    "name": "Yenice",
    "lat": "40.08778",
    "lng": "29.42194"
  },
  {
    "country": "TR",
    "name": "Yenice",
    "lat": "41.19962",
    "lng": "32.33133"
  },
  {
    "country": "TR",
    "name": "Yeniçağa",
    "lat": "40.77115",
    "lng": "32.03375"
  },
  {
    "country": "TR",
    "name": "Yavuzkemal",
    "lat": "40.69329",
    "lng": "38.33723"
  },
  {
    "country": "TR",
    "name": "Körfez",
    "lat": "40.76704",
    "lng": "29.78275"
  },
  {
    "country": "TR",
    "name": "Yapraklı",
    "lat": "40.75785",
    "lng": "33.77819"
  },
  {
    "country": "TR",
    "name": "Yalova",
    "lat": "40.65501",
    "lng": "29.27693"
  },
  {
    "country": "TR",
    "name": "Yalnızçam",
    "lat": "41.06444",
    "lng": "42.50081"
  },
  {
    "country": "TR",
    "name": "Yalakdere",
    "lat": "40.60636",
    "lng": "29.56225"
  },
  {
    "country": "TR",
    "name": "Yakuplu",
    "lat": "40.98894",
    "lng": "28.67582"
  },
  {
    "country": "TR",
    "name": "Yakakent",
    "lat": "41.6325",
    "lng": "35.52889"
  },
  {
    "country": "TR",
    "name": "Yağmurdere",
    "lat": "40.57487",
    "lng": "39.86244"
  },
  {
    "country": "TR",
    "name": "Yağlıdere",
    "lat": "40.85672",
    "lng": "38.62035"
  },
  {
    "country": "TR",
    "name": "Yağlıdere",
    "lat": "40.54432",
    "lng": "39.52762"
  },
  {
    "country": "TR",
    "name": "Vize",
    "lat": "41.5725",
    "lng": "27.76583"
  },
  {
    "country": "TR",
    "name": "Vezirköprü",
    "lat": "41.14361",
    "lng": "35.45472"
  },
  {
    "country": "TR",
    "name": "Vezirhan",
    "lat": "40.24472",
    "lng": "30.02"
  },
  {
    "country": "TR",
    "name": "Velimeşe",
    "lat": "41.25361",
    "lng": "27.87833"
  },
  {
    "country": "TR",
    "name": "Veliköy",
    "lat": "41.31528",
    "lng": "42.4325"
  },
  {
    "country": "TR",
    "name": "Vakfıkebir",
    "lat": "41.04583",
    "lng": "39.27639"
  },
  {
    "country": "TR",
    "name": "Uzunköprü",
    "lat": "41.26597",
    "lng": "26.6885"
  },
  {
    "country": "TR",
    "name": "Uzunisa",
    "lat": "40.91465",
    "lng": "37.84818"
  },
  {
    "country": "TR",
    "name": "Uzungöl",
    "lat": "40.61594",
    "lng": "40.28853"
  },
  {
    "country": "TR",
    "name": "Uzundere",
    "lat": "40.53218",
    "lng": "41.53832"
  },
  {
    "country": "TR",
    "name": "Üsküp",
    "lat": "41.73583",
    "lng": "27.40528"
  },
  {
    "country": "TR",
    "name": "Üsküdar",
    "lat": "41.02252",
    "lng": "29.02369"
  },
  {
    "country": "TR",
    "name": "Uruş",
    "lat": "40.24903",
    "lng": "32.13785"
  },
  {
    "country": "TR",
    "name": "Ünye",
    "lat": "41.13139",
    "lng": "37.2825"
  },
  {
    "country": "TR",
    "name": "Şenyurt",
    "lat": "40.42645",
    "lng": "41.42826"
  },
  {
    "country": "TR",
    "name": "Umurbey",
    "lat": "40.41472",
    "lng": "29.18306"
  },
  {
    "country": "TR",
    "name": "Umurbey",
    "lat": "40.23373",
    "lng": "26.60632"
  },
  {
    "country": "TR",
    "name": "Umraniye",
    "lat": "41.01643",
    "lng": "29.12476"
  },
  {
    "country": "TR",
    "name": "Ulus",
    "lat": "41.58417",
    "lng": "32.64139"
  },
  {
    "country": "TR",
    "name": "Ulubey",
    "lat": "40.86863",
    "lng": "37.75405"
  },
  {
    "country": "TR",
    "name": "Ulaşlı",
    "lat": "40.70583",
    "lng": "29.69608"
  },
  {
    "country": "TR",
    "name": "Uğurludağ",
    "lat": "40.44631",
    "lng": "34.45259"
  },
  {
    "country": "TR",
    "name": "Ovacık",
    "lat": "40.20049",
    "lng": "40.99727"
  },
  {
    "country": "TR",
    "name": "Tuzluca",
    "lat": "40.03871",
    "lng": "43.65208"
  },
  {
    "country": "TR",
    "name": "Tütüncü",
    "lat": "40.06694",
    "lng": "27.71972"
  },
  {
    "country": "TR",
    "name": "Gülyalı",
    "lat": "40.96153",
    "lng": "38.04937"
  },
  {
    "country": "TR",
    "name": "Türkeli",
    "lat": "41.94764",
    "lng": "34.33861"
  },
  {
    "country": "TR",
    "name": "Turhal",
    "lat": "40.3875",
    "lng": "36.08111"
  },
  {
    "country": "TR",
    "name": "Trabzon",
    "lat": "41.005",
    "lng": "39.72694"
  },
  {
    "country": "TR",
    "name": "Tosya",
    "lat": "41.01545",
    "lng": "34.04013"
  },
  {
    "country": "TR",
    "name": "Torul",
    "lat": "40.55071",
    "lng": "39.28344"
  },
  {
    "country": "TR",
    "name": "Tortum",
    "lat": "40.28892",
    "lng": "41.54096"
  },
  {
    "country": "TR",
    "name": "Topçam",
    "lat": "40.61658",
    "lng": "37.77057"
  },
  {
    "country": "TR",
    "name": "Tonya",
    "lat": "40.88402",
    "lng": "39.28486"
  },
  {
    "country": "TR",
    "name": "Tokat",
    "lat": "40.31389",
    "lng": "36.55444"
  },
  {
    "country": "TR",
    "name": "Tirebolu",
    "lat": "41.00694",
    "lng": "38.81389"
  },
  {
    "country": "TR",
    "name": "Terme",
    "lat": "41.20917",
    "lng": "36.97389"
  },
  {
    "country": "TR",
    "name": "Tepecik",
    "lat": "41.02931",
    "lng": "28.54978"
  },
  {
    "country": "TR",
    "name": "Tekkiraz",
    "lat": "40.98588",
    "lng": "37.16028"
  },
  {
    "country": "TR",
    "name": "Tekkeköy",
    "lat": "41.21167",
    "lng": "36.46"
  },
  {
    "country": "TR",
    "name": "Tekke",
    "lat": "40.71556",
    "lng": "36.19247"
  },
  {
    "country": "TR",
    "name": "Tekirdağ",
    "lat": "40.9781",
    "lng": "27.51101"
  },
  {
    "country": "TR",
    "name": "Teke",
    "lat": "41.0605",
    "lng": "29.65381"
  },
  {
    "country": "TR",
    "name": "Tavşanlı",
    "lat": "40.81876",
    "lng": "29.51136"
  },
  {
    "country": "TR",
    "name": "Tavşancıl",
    "lat": "40.77083",
    "lng": "29.57194"
  },
  {
    "country": "TR",
    "name": "Tatkavaklı",
    "lat": "40.03333",
    "lng": "28.36667"
  },
  {
    "country": "TR",
    "name": "Taşova",
    "lat": "40.75972",
    "lng": "36.3225"
  },
  {
    "country": "TR",
    "name": "Taşköprü",
    "lat": "41.5098",
    "lng": "34.21414"
  },
  {
    "country": "TR",
    "name": "Taşköprü",
    "lat": "40.67361",
    "lng": "29.39111"
  },
  {
    "country": "TR",
    "name": "Zigopor",
    "lat": "40.94745",
    "lng": "41.49477"
  },
  {
    "country": "TR",
    "name": "Taraklı",
    "lat": "40.39694",
    "lng": "30.49278"
  },
  {
    "country": "TR",
    "name": "Taflan",
    "lat": "41.40944",
    "lng": "36.12889"
  },
  {
    "country": "TR",
    "name": "Tacir",
    "lat": "40.52556",
    "lng": "29.73972"
  },
  {
    "country": "TR",
    "name": "Susuzmüsellim",
    "lat": "41.09889",
    "lng": "27.0675"
  },
  {
    "country": "TR",
    "name": "Susuz",
    "lat": "40.7791",
    "lng": "43.12769"
  },
  {
    "country": "TR",
    "name": "Suşehri",
    "lat": "40.16005",
    "lng": "38.08413"
  },
  {
    "country": "TR",
    "name": "Sürmene",
    "lat": "40.90588",
    "lng": "40.12792"
  },
  {
    "country": "TR",
    "name": "Sungurlu",
    "lat": "40.1675",
    "lng": "34.37389"
  },
  {
    "country": "TR",
    "name": "Suluova",
    "lat": "40.83129",
    "lng": "35.64788"
  },
  {
    "country": "TR",
    "name": "Sultanköy",
    "lat": "41.02139",
    "lng": "27.98861"
  },
  {
    "country": "TR",
    "name": "Süloğlu",
    "lat": "41.76901",
    "lng": "26.90999"
  },
  {
    "country": "TR",
    "name": "Sulakyurt",
    "lat": "40.15733",
    "lng": "33.716"
  },
  {
    "country": "TR",
    "name": "Sölöz",
    "lat": "40.3948",
    "lng": "29.41559"
  },
  {
    "country": "TR",
    "name": "Mahmudiye",
    "lat": "40.33787",
    "lng": "28.64945"
  },
  {
    "country": "TR",
    "name": "Söğütlü",
    "lat": "40.9059",
    "lng": "30.47448"
  },
  {
    "country": "TR",
    "name": "Soldere",
    "lat": "40.06089",
    "lng": "28.57231"
  },
  {
    "country": "TR",
    "name": "Şişli",
    "lat": "41.06046",
    "lng": "28.98717"
  },
  {
    "country": "TR",
    "name": "Sırpsındığı",
    "lat": "41.78124",
    "lng": "26.47888"
  },
  {
    "country": "TR",
    "name": "Şiran",
    "lat": "40.19064",
    "lng": "39.11747"
  },
  {
    "country": "TR",
    "name": "Sinop",
    "lat": "42.02683",
    "lng": "35.16253"
  },
  {
    "country": "TR",
    "name": "Sinekli",
    "lat": "41.22798",
    "lng": "28.19043"
  },
  {
    "country": "TR",
    "name": "Sinekçi",
    "lat": "40.27073",
    "lng": "27.40667"
  },
  {
    "country": "TR",
    "name": "Silivri",
    "lat": "41.07393",
    "lng": "28.24644"
  },
  {
    "country": "TR",
    "name": "Şile",
    "lat": "41.1754",
    "lng": "29.61333"
  },
  {
    "country": "TR",
    "name": "Seyitler",
    "lat": "41.19484",
    "lng": "41.83696"
  },
  {
    "country": "TR",
    "name": "Şeyhli",
    "lat": "40.92194",
    "lng": "36.06333"
  },
  {
    "country": "TR",
    "name": "Seydim",
    "lat": "40.54302",
    "lng": "34.73812"
  },
  {
    "country": "TR",
    "name": "Seydiler",
    "lat": "41.62005",
    "lng": "33.71815"
  },
  {
    "country": "TR",
    "name": "Şevketiye",
    "lat": "40.09347",
    "lng": "27.84667"
  },
  {
    "country": "TR",
    "name": "Sergen",
    "lat": "41.70528",
    "lng": "27.70833"
  },
  {
    "country": "TR",
    "name": "Şerefiye",
    "lat": "40.11195",
    "lng": "37.75624"
  },
  {
    "country": "TR",
    "name": "Serdivan",
    "lat": "40.77376",
    "lng": "30.38006"
  },
  {
    "country": "TR",
    "name": "Şenpazar",
    "lat": "41.8089",
    "lng": "33.23135"
  },
  {
    "country": "TR",
    "name": "Şenkaya",
    "lat": "40.55652",
    "lng": "42.34266"
  },
  {
    "country": "TR",
    "name": "Selimpaşa",
    "lat": "41.05448",
    "lng": "28.36678"
  },
  {
    "country": "TR",
    "name": "Selim",
    "lat": "40.45772",
    "lng": "42.78287"
  },
  {
    "country": "TR",
    "name": "Şebin Karahisar",
    "lat": "40.28833",
    "lng": "38.42361"
  },
  {
    "country": "TR",
    "name": "Seben",
    "lat": "40.41134",
    "lng": "31.57359"
  },
  {
    "country": "TR",
    "name": "Şavşat",
    "lat": "41.24027",
    "lng": "42.36109"
  },
  {
    "country": "TR",
    "name": "Şarköy",
    "lat": "40.61395",
    "lng": "27.11563"
  },
  {
    "country": "TR",
    "name": "Sarıköy",
    "lat": "40.2075",
    "lng": "27.59611"
  },
  {
    "country": "TR",
    "name": "Sarıkamış",
    "lat": "40.32769",
    "lng": "42.58705"
  },
  {
    "country": "TR",
    "name": "Sarıbuğday",
    "lat": "40.74806",
    "lng": "35.45972"
  },
  {
    "country": "TR",
    "name": "Saraydüzü",
    "lat": "41.32865",
    "lng": "34.84686"
  },
  {
    "country": "TR",
    "name": "Saraycık",
    "lat": "40.95017",
    "lng": "35.11165"
  },
  {
    "country": "TR",
    "name": "Saray",
    "lat": "41.44431",
    "lng": "27.92194"
  },
  {
    "country": "TR",
    "name": "Sapanca",
    "lat": "40.69141",
    "lng": "30.26738"
  },
  {
    "country": "TR",
    "name": "Samsun",
    "lat": "41.27976",
    "lng": "36.3361"
  },
  {
    "country": "TR",
    "name": "Samandıra",
    "lat": "40.999",
    "lng": "29.22565"
  },
  {
    "country": "TR",
    "name": "Şalpazarı",
    "lat": "40.93826",
    "lng": "39.19006"
  },
  {
    "country": "TR",
    "name": "Şahin",
    "lat": "41.02167",
    "lng": "26.8425"
  },
  {
    "country": "TR",
    "name": "Safranbolu",
    "lat": "41.25083",
    "lng": "32.69417"
  },
  {
    "country": "TR",
    "name": "Şabanözü",
    "lat": "40.48249",
    "lng": "33.28352"
  },
  {
    "country": "TR",
    "name": "Rize",
    "lat": "41.02083",
    "lng": "40.52194"
  },
  {
    "country": "TR",
    "name": "Reşadiye",
    "lat": "40.39194",
    "lng": "37.3375"
  },
  {
    "country": "TR",
    "name": "Pursaklar",
    "lat": "40.03203",
    "lng": "32.89528"
  },
  {
    "country": "TR",
    "name": "Posof",
    "lat": "41.51111",
    "lng": "42.72917"
  },
  {
    "country": "TR",
    "name": "Piraziz",
    "lat": "40.95299",
    "lng": "38.1089"
  },
  {
    "country": "TR",
    "name": "Piraziz",
    "lat": "40.92244",
    "lng": "38.12458"
  },
  {
    "country": "TR",
    "name": "Pınarhisar",
    "lat": "41.62417",
    "lng": "27.52"
  },
  {
    "country": "TR",
    "name": "Pınarbaşı",
    "lat": "41.60388",
    "lng": "33.11099"
  },
  {
    "country": "TR",
    "name": "Perşembe",
    "lat": "41.06556",
    "lng": "37.77139"
  },
  {
    "country": "TR",
    "name": "Pendik",
    "lat": "40.8775",
    "lng": "29.2725"
  },
  {
    "country": "TR",
    "name": "Pehlivanköy",
    "lat": "41.34812",
    "lng": "26.92522"
  },
  {
    "country": "TR",
    "name": "Peçenek",
    "lat": "40.41857",
    "lng": "32.30833"
  },
  {
    "country": "TR",
    "name": "Pazaryolu",
    "lat": "40.41142",
    "lng": "40.7678"
  },
  {
    "country": "TR",
    "name": "Pazarköy",
    "lat": "40.92555",
    "lng": "32.1807"
  },
  {
    "country": "TR",
    "name": "Pazar",
    "lat": "41.17917",
    "lng": "40.88417"
  },
  {
    "country": "TR",
    "name": "Pazar",
    "lat": "40.33027",
    "lng": "32.7482"
  },
  {
    "country": "TR",
    "name": "Pazar",
    "lat": "40.27652",
    "lng": "36.28347"
  },
  {
    "country": "TR",
    "name": "Pamukova",
    "lat": "40.5081",
    "lng": "30.16732"
  },
  {
    "country": "TR",
    "name": "Ovacuma",
    "lat": "41.4485",
    "lng": "32.75361"
  },
  {
    "country": "TR",
    "name": "Ovacık",
    "lat": "41.07661",
    "lng": "32.91994"
  },
  {
    "country": "TR",
    "name": "Yenikonak",
    "lat": "41.87319",
    "lng": "34.60308"
  },
  {
    "country": "TR",
    "name": "Osmaneli",
    "lat": "40.35722",
    "lng": "30.01417"
  },
  {
    "country": "TR",
    "name": "Osmancık",
    "lat": "40.97818",
    "lng": "34.8047"
  },
  {
    "country": "TR",
    "name": "Ortaköy",
    "lat": "41.25104",
    "lng": "41.98363"
  },
  {
    "country": "TR",
    "name": "Ortaköy",
    "lat": "41.10154",
    "lng": "28.37588"
  },
  {
    "country": "TR",
    "name": "Hemşin",
    "lat": "41.04777",
    "lng": "40.8984"
  },
  {
    "country": "TR",
    "name": "Ortakent",
    "lat": "40.39367",
    "lng": "38.01028"
  },
  {
    "country": "TR",
    "name": "Ortaköy",
    "lat": "40.27352",
    "lng": "35.25175"
  },
  {
    "country": "TR",
    "name": "Ortacalar",
    "lat": "41.27896",
    "lng": "41.37887"
  },
  {
    "country": "TR",
    "name": "Orta",
    "lat": "40.6242",
    "lng": "33.10928"
  },
  {
    "country": "TR",
    "name": "Ormanlı",
    "lat": "41.16472",
    "lng": "31.61417"
  },
  {
    "country": "TR",
    "name": "Orhangazi",
    "lat": "40.48917",
    "lng": "29.30889"
  },
  {
    "country": "TR",
    "name": "Ordu",
    "lat": "40.97782",
    "lng": "37.89047"
  },
  {
    "country": "TR",
    "name": "Olur",
    "lat": "40.82165",
    "lng": "42.13055"
  },
  {
    "country": "TR",
    "name": "Oltu",
    "lat": "40.53945",
    "lng": "41.98722"
  },
  {
    "country": "TR",
    "name": "Öğdem",
    "lat": "40.91728",
    "lng": "41.63612"
  },
  {
    "country": "TR",
    "name": "Of",
    "lat": "40.94055",
    "lng": "40.25918"
  },
  {
    "country": "TR",
    "name": "Niksar",
    "lat": "40.59167",
    "lng": "36.95167"
  },
  {
    "country": "TR",
    "name": "Narman",
    "lat": "40.34449",
    "lng": "41.86088"
  },
  {
    "country": "TR",
    "name": "Narlıca",
    "lat": "40.38583",
    "lng": "29.48111"
  },
  {
    "country": "TR",
    "name": "Nallıhan",
    "lat": "40.18593",
    "lng": "31.35179"
  },
  {
    "country": "TR",
    "name": "Mustafakemalpaşa",
    "lat": "40.03815",
    "lng": "28.40866"
  },
  {
    "country": "TR",
    "name": "Muratlı",
    "lat": "41.47405",
    "lng": "41.70647"
  },
  {
    "country": "TR",
    "name": "Muratlı",
    "lat": "41.17216",
    "lng": "27.4992"
  },
  {
    "country": "TR",
    "name": "Mudurnu",
    "lat": "40.473",
    "lng": "31.20755"
  },
  {
    "country": "TR",
    "name": "Mudanya",
    "lat": "40.37528",
    "lng": "28.88222"
  },
  {
    "country": "TR",
    "name": "Mimarsinan",
    "lat": "41.0179",
    "lng": "28.56176"
  },
  {
    "country": "TR",
    "name": "Mihalgazi",
    "lat": "40.02621",
    "lng": "30.57707"
  },
  {
    "country": "TR",
    "name": "Mezraa",
    "lat": "41.19764",
    "lng": "35.11684"
  },
  {
    "country": "TR",
    "name": "Meydancık",
    "lat": "41.40964",
    "lng": "42.2364"
  },
  {
    "country": "TR",
    "name": "Mesudiye",
    "lat": "40.45446",
    "lng": "37.77353"
  },
  {
    "country": "TR",
    "name": "Merzifon",
    "lat": "40.87333",
    "lng": "35.46306"
  },
  {
    "country": "TR",
    "name": "Meriç",
    "lat": "41.19183",
    "lng": "26.42097"
  },
  {
    "country": "TR",
    "name": "Mengen",
    "lat": "40.93877",
    "lng": "32.07642"
  },
  {
    "country": "TR",
    "name": "Mecitözü",
    "lat": "40.52",
    "lng": "35.29528"
  },
  {
    "country": "TR",
    "name": "Mecidiye",
    "lat": "40.63889",
    "lng": "26.53917"
  },
  {
    "country": "TR",
    "name": "Marmara Ereğlisi",
    "lat": "40.97003",
    "lng": "27.95528"
  },
  {
    "country": "TR",
    "name": "Marmaracık",
    "lat": "41.20667",
    "lng": "27.75444"
  },
  {
    "country": "TR",
    "name": "Marmara",
    "lat": "40.58633",
    "lng": "27.55541"
  },
  {
    "country": "TR",
    "name": "Manyas",
    "lat": "40.04639",
    "lng": "27.97"
  },
  {
    "country": "TR",
    "name": "Maltepe",
    "lat": "40.93567",
    "lng": "29.15507"
  },
  {
    "country": "TR",
    "name": "Malkara",
    "lat": "40.89",
    "lng": "26.90111"
  },
  {
    "country": "TR",
    "name": "Mahmut Şevket Paşa",
    "lat": "41.15281",
    "lng": "29.18968"
  },
  {
    "country": "TR",
    "name": "Mahmutbey",
    "lat": "41.05361",
    "lng": "28.82556"
  },
  {
    "country": "TR",
    "name": "Maden",
    "lat": "40.18139",
    "lng": "40.40417"
  },
  {
    "country": "TR",
    "name": "Maçka",
    "lat": "40.81072",
    "lng": "39.60465"
  },
  {
    "country": "TR",
    "name": "Lüleburgaz",
    "lat": "41.40385",
    "lng": "27.35918"
  },
  {
    "country": "TR",
    "name": "Lapseki",
    "lat": "40.34417",
    "lng": "26.68556"
  },
  {
    "country": "TR",
    "name": "Lâlapaşa",
    "lat": "41.83951",
    "lng": "26.73561"
  },
  {
    "country": "TR",
    "name": "Ladik",
    "lat": "40.91056",
    "lng": "35.89194"
  },
  {
    "country": "TR",
    "name": "Kuzyaka",
    "lat": "41.232",
    "lng": "33.72267"
  },
  {
    "country": "TR",
    "name": "Kurucaşile",
    "lat": "41.83781",
    "lng": "32.71621"
  },
  {
    "country": "TR",
    "name": "Kurtkale",
    "lat": "41.26546",
    "lng": "43.1258"
  },
  {
    "country": "TR",
    "name": "Kurşunlu",
    "lat": "40.84101",
    "lng": "33.26028"
  },
  {
    "country": "TR",
    "name": "Kurşunlu",
    "lat": "40.03712",
    "lng": "29.65972"
  },
  {
    "country": "TR",
    "name": "Küre",
    "lat": "41.80578",
    "lng": "33.71161"
  },
  {
    "country": "TR",
    "name": "Küplü",
    "lat": "41.10694",
    "lng": "26.35194"
  },
  {
    "country": "TR",
    "name": "Küplü",
    "lat": "40.09837",
    "lng": "30.0001"
  },
  {
    "country": "TR",
    "name": "Kumru",
    "lat": "40.87444",
    "lng": "37.26389"
  },
  {
    "country": "TR",
    "name": "Kumluca",
    "lat": "41.44724",
    "lng": "32.46759"
  },
  {
    "country": "TR",
    "name": "Kumburgaz",
    "lat": "41.02108",
    "lng": "28.48033"
  },
  {
    "country": "TR",
    "name": "Kumbağ",
    "lat": "40.88236",
    "lng": "27.45919"
  },
  {
    "country": "TR",
    "name": "Kullar",
    "lat": "40.72419",
    "lng": "29.98943"
  },
  {
    "country": "TR",
    "name": "Küçükkumla",
    "lat": "40.47047",
    "lng": "29.10152"
  },
  {
    "country": "TR",
    "name": "Küçükdere",
    "lat": "40.80748",
    "lng": "40.05512"
  },
  {
    "country": "TR",
    "name": "Kozlu",
    "lat": "41.43194",
    "lng": "31.74583"
  },
  {
    "country": "TR",
    "name": "Kozlu",
    "lat": "40.60878",
    "lng": "36.47858"
  },
  {
    "country": "TR",
    "name": "Kozcağız",
    "lat": "41.48333",
    "lng": "32.33333"
  },
  {
    "country": "TR",
    "name": "Koyulhisar",
    "lat": "40.30184",
    "lng": "37.82336"
  },
  {
    "country": "TR",
    "name": "Kovanlık",
    "lat": "40.75484",
    "lng": "38.11155"
  },
  {
    "country": "TR",
    "name": "Kötek",
    "lat": "40.2185",
    "lng": "43.0022"
  },
  {
    "country": "TR",
    "name": "Köseköy",
    "lat": "40.74012",
    "lng": "30.00556"
  },
  {
    "country": "TR",
    "name": "Köse",
    "lat": "40.20692",
    "lng": "39.64626"
  },
  {
    "country": "TR",
    "name": "Koruköy",
    "lat": "40.65435",
    "lng": "29.16289"
  },
  {
    "country": "TR",
    "name": "Korgun",
    "lat": "40.73479",
    "lng": "33.51844"
  },
  {
    "country": "TR",
    "name": "Korgan",
    "lat": "40.82472",
    "lng": "37.34667"
  },
  {
    "country": "TR",
    "name": "Köprübaşı",
    "lat": "40.80692",
    "lng": "40.11439"
  },
  {
    "country": "TR",
    "name": "Konuralp",
    "lat": "40.90538",
    "lng": "31.14568"
  },
  {
    "country": "TR",
    "name": "Kolay",
    "lat": "41.41824",
    "lng": "35.80136"
  },
  {
    "country": "TR",
    "name": "Saltukova",
    "lat": "41.52022",
    "lng": "32.09621"
  },
  {
    "country": "TR",
    "name": "Kofçaz",
    "lat": "41.94481",
    "lng": "27.15829"
  },
  {
    "country": "TR",
    "name": "Kocadere",
    "lat": "40.63",
    "lng": "29.03"
  },
  {
    "country": "TR",
    "name": "Kocaali",
    "lat": "41.05336",
    "lng": "30.85278"
  },
  {
    "country": "TR",
    "name": "Kızılırmak",
    "lat": "40.34556",
    "lng": "33.98639"
  },
  {
    "country": "TR",
    "name": "Kızılcahamam",
    "lat": "40.46972",
    "lng": "32.65056"
  },
  {
    "country": "TR",
    "name": "Salmydessus",
    "lat": "41.63476",
    "lng": "28.09459"
  },
  {
    "country": "TR",
    "name": "Kışlaköy",
    "lat": "40.32353",
    "lng": "42.02233"
  },
  {
    "country": "TR",
    "name": "Kırklareli",
    "lat": "41.73508",
    "lng": "27.22521"
  },
  {
    "country": "TR",
    "name": "Kırcasalih",
    "lat": "41.39019",
    "lng": "26.79496"
  },
  {
    "country": "TR",
    "name": "Dikmen",
    "lat": "41.65",
    "lng": "35.26667"
  },
  {
    "country": "TR",
    "name": "Gelegra",
    "lat": "40.01378",
    "lng": "31.83197"
  },
  {
    "country": "TR",
    "name": "Kirazlı",
    "lat": "40.09964",
    "lng": "29.04163"
  },
  {
    "country": "TR",
    "name": "Kirazlı",
    "lat": "40.04176",
    "lng": "26.7009"
  },
  {
    "country": "TR",
    "name": "Kınalı",
    "lat": "40.90713",
    "lng": "29.05499"
  },
  {
    "country": "TR",
    "name": "Kilimli",
    "lat": "41.49111",
    "lng": "31.83861"
  },
  {
    "country": "TR",
    "name": "Kılıçkaya",
    "lat": "40.70471",
    "lng": "41.47385"
  },
  {
    "country": "TR",
    "name": "Kılıç",
    "lat": "40.63306",
    "lng": "29.39472"
  },
  {
    "country": "TR",
    "name": "Kıbrıscık",
    "lat": "40.40778",
    "lng": "31.85194"
  },
  {
    "country": "TR",
    "name": "Kestel",
    "lat": "40.19828",
    "lng": "29.21237"
  },
  {
    "country": "TR",
    "name": "Keşap",
    "lat": "40.91032",
    "lng": "38.5013"
  },
  {
    "country": "TR",
    "name": "Keşan",
    "lat": "40.85583",
    "lng": "26.63028"
  },
  {
    "country": "TR",
    "name": "Kemerburgaz",
    "lat": "41.15902",
    "lng": "28.91572"
  },
  {
    "country": "TR",
    "name": "Kemalpaşa",
    "lat": "41.48336",
    "lng": "41.5275"
  },
  {
    "country": "TR",
    "name": "Kelkit",
    "lat": "40.12682",
    "lng": "39.43424"
  },
  {
    "country": "TR",
    "name": "Kefken",
    "lat": "41.16833",
    "lng": "30.22972"
  },
  {
    "country": "TR",
    "name": "Kazan",
    "lat": "40.23167",
    "lng": "32.68389"
  },
  {
    "country": "TR",
    "name": "Kaytazdere",
    "lat": "40.68225",
    "lng": "29.53236"
  },
  {
    "country": "TR",
    "name": "Kaynaşlı",
    "lat": "40.76917",
    "lng": "31.32211"
  },
  {
    "country": "TR",
    "name": "Kaynarca",
    "lat": "41.03083",
    "lng": "30.3075"
  },
  {
    "country": "TR",
    "name": "Kaymas",
    "lat": "40.9231",
    "lng": "30.26597"
  },
  {
    "country": "TR",
    "name": "Kavaklı",
    "lat": "41.09258",
    "lng": "28.33172"
  },
  {
    "country": "TR",
    "name": "Kavak",
    "lat": "41.07833",
    "lng": "36.0425"
  },
  {
    "country": "TR",
    "name": "Kastamonu",
    "lat": "41.37805",
    "lng": "33.77528"
  },
  {
    "country": "TR",
    "name": "Beycuma",
    "lat": "41.32812",
    "lng": "31.96811"
  },
  {
    "country": "TR",
    "name": "Kars",
    "lat": "40.59825",
    "lng": "43.08548"
  },
  {
    "country": "TR",
    "name": "Kargı",
    "lat": "41.13373",
    "lng": "34.48744"
  },
  {
    "country": "TR",
    "name": "Karayaka",
    "lat": "40.74402",
    "lng": "36.59018"
  },
  {
    "country": "TR",
    "name": "Karaurgan",
    "lat": "40.23964",
    "lng": "42.27283"
  },
  {
    "country": "TR",
    "name": "Karasu",
    "lat": "41.10442",
    "lng": "30.69664"
  },
  {
    "country": "TR",
    "name": "Karasu Mahallesi",
    "lat": "41.07096",
    "lng": "30.78543"
  },
  {
    "country": "TR",
    "name": "Karaşar",
    "lat": "40.32573",
    "lng": "31.98682"
  },
  {
    "country": "TR",
    "name": "Karapürçek",
    "lat": "40.64194",
    "lng": "30.53944"
  },
  {
    "country": "TR",
    "name": "Oğuzlar",
    "lat": "40.75353",
    "lng": "34.70275"
  },
  {
    "country": "TR",
    "name": "Karamürsel",
    "lat": "40.69144",
    "lng": "29.61568"
  },
  {
    "country": "TR",
    "name": "Karakurt",
    "lat": "40.16591",
    "lng": "42.60453"
  },
  {
    "country": "TR",
    "name": "Karakasım",
    "lat": "41.51718",
    "lng": "26.64381"
  },
  {
    "country": "TR",
    "name": "Karadere",
    "lat": "40.73174",
    "lng": "30.83992"
  },
  {
    "country": "TR",
    "name": "Karacaköy",
    "lat": "41.40338",
    "lng": "28.38055"
  },
  {
    "country": "TR",
    "name": "Karacaköy",
    "lat": "41.15126",
    "lng": "29.76935"
  },
  {
    "country": "TR",
    "name": "Karacabey",
    "lat": "40.21323",
    "lng": "28.3612"
  },
  {
    "country": "TR",
    "name": "Karabulduk",
    "lat": "40.82043",
    "lng": "38.54941"
  },
  {
    "country": "TR",
    "name": "Karabük",
    "lat": "41.20488",
    "lng": "32.62768"
  },
  {
    "country": "TR",
    "name": "Karabiga",
    "lat": "40.40361",
    "lng": "27.30389"
  },
  {
    "country": "TR",
    "name": "Kaptanpaşa",
    "lat": "40.96067",
    "lng": "40.78238"
  },
  {
    "country": "TR",
    "name": "Kapaklı",
    "lat": "41.32912",
    "lng": "27.98064"
  },
  {
    "country": "TR",
    "name": "Kandıra",
    "lat": "41.07",
    "lng": "30.15262"
  },
  {
    "country": "TR",
    "name": "Kâmil",
    "lat": "41.10364",
    "lng": "34.76298"
  },
  {
    "country": "TR",
    "name": "Kalkandere",
    "lat": "40.92046",
    "lng": "40.43692"
  },
  {
    "country": "TR",
    "name": "Kalecik",
    "lat": "40.09722",
    "lng": "33.40833"
  },
  {
    "country": "TR",
    "name": "Kale",
    "lat": "40.38688",
    "lng": "39.68332"
  },
  {
    "country": "TR",
    "name": "Kağızman",
    "lat": "40.15669",
    "lng": "43.13424"
  },
  {
    "country": "TR",
    "name": "Evreşe",
    "lat": "40.66667",
    "lng": "26.88333"
  },
  {
    "country": "TR",
    "name": "Kadıköy",
    "lat": "40.62015",
    "lng": "29.22536"
  },
  {
    "country": "TR",
    "name": "Kabataş",
    "lat": "40.75",
    "lng": "37.45"
  },
  {
    "country": "TR",
    "name": "Kabalı",
    "lat": "41.85211",
    "lng": "35.06249"
  },
  {
    "country": "TR",
    "name": "Kabadüz",
    "lat": "40.86096",
    "lng": "37.8847"
  },
  {
    "country": "TR",
    "name": "İznik",
    "lat": "40.42861",
    "lng": "29.72111"
  },
  {
    "country": "TR",
    "name": "İzmit",
    "lat": "40.76694",
    "lng": "29.91694"
  },
  {
    "country": "TR",
    "name": "İyidere",
    "lat": "41.01192",
    "lng": "40.36185"
  },
  {
    "country": "TR",
    "name": "Istanbul",
    "lat": "41.01384",
    "lng": "28.94966"
  },
  {
    "country": "TR",
    "name": "İspir",
    "lat": "40.47981",
    "lng": "40.99373"
  },
  {
    "country": "TR",
    "name": "İskilip",
    "lat": "40.73528",
    "lng": "34.47389"
  },
  {
    "country": "TR",
    "name": "İpsala",
    "lat": "40.92115",
    "lng": "26.38273"
  },
  {
    "country": "TR",
    "name": "İntepe",
    "lat": "40.01333",
    "lng": "26.33287"
  },
  {
    "country": "TR",
    "name": "Boyalı",
    "lat": "41.0271",
    "lng": "33.3041"
  },
  {
    "country": "TR",
    "name": "İnhisar",
    "lat": "40.04932",
    "lng": "30.38521"
  },
  {
    "country": "TR",
    "name": "İnegol",
    "lat": "40.07806",
    "lng": "29.51333"
  },
  {
    "country": "TR",
    "name": "İnecik",
    "lat": "40.93518",
    "lng": "27.28118"
  },
  {
    "country": "TR",
    "name": "İnece",
    "lat": "41.67747",
    "lng": "27.06786"
  },
  {
    "country": "TR",
    "name": "İnebolu",
    "lat": "41.97472",
    "lng": "33.76083"
  },
  {
    "country": "TR",
    "name": "Gökçeada",
    "lat": "40.20107",
    "lng": "25.90902"
  },
  {
    "country": "TR",
    "name": "Yarhisar",
    "lat": "40.21673",
    "lng": "29.87088"
  },
  {
    "country": "TR",
    "name": "Ilgaz",
    "lat": "40.92511",
    "lng": "33.62586"
  },
  {
    "country": "TR",
    "name": "İkizören",
    "lat": "40.68833",
    "lng": "33.88333"
  },
  {
    "country": "TR",
    "name": "İkizdere",
    "lat": "40.77484",
    "lng": "40.55227"
  },
  {
    "country": "TR",
    "name": "İkizce",
    "lat": "41.05833",
    "lng": "37.08028"
  },
  {
    "country": "TR",
    "name": "İhsaniye",
    "lat": "40.69087",
    "lng": "29.83472"
  },
  {
    "country": "TR",
    "name": "İhsangazi",
    "lat": "41.20432",
    "lng": "33.55455"
  },
  {
    "country": "TR",
    "name": "İğneada",
    "lat": "41.87444",
    "lng": "27.98389"
  },
  {
    "country": "TR",
    "name": "İğdir",
    "lat": "41.22617",
    "lng": "33.13699"
  },
  {
    "country": "TR",
    "name": "İğdir",
    "lat": "40.26633",
    "lng": "35.62645"
  },
  {
    "country": "TR",
    "name": "İbriktepe",
    "lat": "41.01037",
    "lng": "26.50343"
  },
  {
    "country": "TR",
    "name": "Horasan",
    "lat": "40.03885",
    "lng": "42.16366"
  },
  {
    "country": "TR",
    "name": "Hopa",
    "lat": "41.39046",
    "lng": "41.41966"
  },
  {
    "country": "TR",
    "name": "Filyos",
    "lat": "41.55383",
    "lng": "32.02389"
  },
  {
    "country": "TR",
    "name": "Hereke",
    "lat": "40.78611",
    "lng": "29.61472"
  },
  {
    "country": "TR",
    "name": "Hendek",
    "lat": "40.79944",
    "lng": "30.74806"
  },
  {
    "country": "TR",
    "name": "Nurluca",
    "lat": "41.03519",
    "lng": "40.90584"
  },
  {
    "country": "TR",
    "name": "Güzelkent",
    "lat": "41.94843",
    "lng": "34.3945"
  },
  {
    "country": "TR",
    "name": "Hayrat",
    "lat": "40.8853",
    "lng": "40.36495"
  },
  {
    "country": "TR",
    "name": "Hayrabolu",
    "lat": "41.21311",
    "lng": "27.10688"
  },
  {
    "country": "TR",
    "name": "Havza",
    "lat": "40.97056",
    "lng": "35.66222"
  },
  {
    "country": "TR",
    "name": "Havsa",
    "lat": "41.54898",
    "lng": "26.82207"
  },
  {
    "country": "TR",
    "name": "Hasköy",
    "lat": "41.63822",
    "lng": "26.85746"
  },
  {
    "country": "TR",
    "name": "Hasköy",
    "lat": "40.99106",
    "lng": "42.88396"
  },
  {
    "country": "TR",
    "name": "Hasayaz",
    "lat": "40.24067",
    "lng": "33.328"
  },
  {
    "country": "TR",
    "name": "Hanönü",
    "lat": "41.62705",
    "lng": "34.46667"
  },
  {
    "country": "TR",
    "name": "Hanak",
    "lat": "41.23344",
    "lng": "42.84037"
  },
  {
    "country": "TR",
    "name": "Hamzabey",
    "lat": "40.13583",
    "lng": "29.52639"
  },
  {
    "country": "TR",
    "name": "Hamidiye",
    "lat": "41.15128",
    "lng": "26.66411"
  },
  {
    "country": "TR",
    "name": "Dedeköy",
    "lat": "40.74752",
    "lng": "35.04249"
  },
  {
    "country": "TR",
    "name": "Hamamözü",
    "lat": "40.78476",
    "lng": "35.0258"
  },
  {
    "country": "TR",
    "name": "Perşembe",
    "lat": "41.41867",
    "lng": "32.15984"
  },
  {
    "country": "TR",
    "name": "Hacıhamza",
    "lat": "41.0743",
    "lng": "34.449"
  },
  {
    "country": "TR",
    "name": "Dokurcun",
    "lat": "40.5732",
    "lng": "30.86784"
  },
  {
    "country": "TR",
    "name": "Çayırova",
    "lat": "40.83444",
    "lng": "29.4"
  },
  {
    "country": "TR",
    "name": "Güvem",
    "lat": "40.59069",
    "lng": "32.66111"
  },
  {
    "country": "TR",
    "name": "Gürsu",
    "lat": "40.21876",
    "lng": "29.19487"
  },
  {
    "country": "TR",
    "name": "Gürpınar",
    "lat": "40.99256",
    "lng": "28.61428"
  },
  {
    "country": "TR",
    "name": "Gürgentepe",
    "lat": "40.78567",
    "lng": "37.58969"
  },
  {
    "country": "TR",
    "name": "Güneysu",
    "lat": "40.9813",
    "lng": "40.60465"
  },
  {
    "country": "TR",
    "name": "Kırık",
    "lat": "40.32794",
    "lng": "40.91863"
  },
  {
    "country": "TR",
    "name": "Güneyce",
    "lat": "40.82095",
    "lng": "40.47035"
  },
  {
    "country": "TR",
    "name": "Gündoğdu",
    "lat": "41.05319",
    "lng": "40.60664"
  },
  {
    "country": "TR",
    "name": "Gündoğdu",
    "lat": "40.26408",
    "lng": "27.09288"
  },
  {
    "country": "TR",
    "name": "Gümüşova",
    "lat": "40.84694",
    "lng": "30.94111"
  },
  {
    "country": "TR",
    "name": "Gumushkhane",
    "lat": "40.46001",
    "lng": "39.47176"
  },
  {
    "country": "TR",
    "name": "Gümüşhacıköy",
    "lat": "40.87306",
    "lng": "35.21472"
  },
  {
    "country": "TR",
    "name": "Dimetoka",
    "lat": "40.28228",
    "lng": "27.28205"
  },
  {
    "country": "TR",
    "name": "Gümüş",
    "lat": "40.84018",
    "lng": "35.17195"
  },
  {
    "country": "TR",
    "name": "Güdül",
    "lat": "40.21051",
    "lng": "32.24552"
  },
  {
    "country": "TR",
    "name": "Akkaya",
    "lat": "41.21913",
    "lng": "33.48487"
  },
  {
    "country": "TR",
    "name": "Göynük",
    "lat": "40.40028",
    "lng": "30.78833"
  },
  {
    "country": "TR",
    "name": "Göynücek",
    "lat": "40.39917",
    "lng": "35.525"
  },
  {
    "country": "TR",
    "name": "Görükle",
    "lat": "40.23114",
    "lng": "28.84017"
  },
  {
    "country": "TR",
    "name": "Görele",
    "lat": "41.03083",
    "lng": "39.00306"
  },
  {
    "country": "TR",
    "name": "Gönen",
    "lat": "40.1049",
    "lng": "27.65399"
  },
  {
    "country": "TR",
    "name": "Gölyaka",
    "lat": "40.7769",
    "lng": "30.99587"
  },
  {
    "country": "TR",
    "name": "Gölpazarı",
    "lat": "40.28472",
    "lng": "30.31722"
  },
  {
    "country": "TR",
    "name": "Gölova",
    "lat": "40.06194",
    "lng": "38.60667"
  },
  {
    "country": "TR",
    "name": "Balarim",
    "lat": "40.37381",
    "lng": "29.59025"
  },
  {
    "country": "TR",
    "name": "Kömürlü",
    "lat": "40.73539",
    "lng": "42.28819"
  },
  {
    "country": "TR",
    "name": "Gölköy",
    "lat": "40.68689",
    "lng": "37.61544"
  },
  {
    "country": "TR",
    "name": "Göle",
    "lat": "40.78746",
    "lng": "42.60603"
  },
  {
    "country": "TR",
    "name": "Gölcük",
    "lat": "40.70323",
    "lng": "29.87216"
  },
  {
    "country": "TR",
    "name": "Murgul",
    "lat": "41.27937",
    "lng": "41.55514"
  },
  {
    "country": "TR",
    "name": "Gökdere",
    "lat": "40.47292",
    "lng": "36.7525"
  },
  {
    "country": "TR",
    "name": "Gökçeli",
    "lat": "40.58333",
    "lng": "36.73333"
  },
  {
    "country": "TR",
    "name": "Gökçesu",
    "lat": "40.89389",
    "lng": "31.95957"
  },
  {
    "country": "TR",
    "name": "Gökçekent",
    "lat": "40.28644",
    "lng": "38.11771"
  },
  {
    "country": "TR",
    "name": "Gökçebey",
    "lat": "41.30583",
    "lng": "32.14234"
  },
  {
    "country": "TR",
    "name": "Göbel",
    "lat": "40.01972",
    "lng": "28.14556"
  },
  {
    "country": "TR",
    "name": "Giresun",
    "lat": "40.91698",
    "lng": "38.38741"
  },
  {
    "country": "TR",
    "name": "Geyve",
    "lat": "40.5075",
    "lng": "30.2925"
  },
  {
    "country": "TR",
    "name": "Gerze",
    "lat": "41.80361",
    "lng": "35.20111"
  },
  {
    "country": "TR",
    "name": "Gerede",
    "lat": "40.80083",
    "lng": "32.19694"
  },
  {
    "country": "TR",
    "name": "Çiftlik",
    "lat": "40.07234",
    "lng": "42.25617"
  },
  {
    "country": "TR",
    "name": "Gemlik",
    "lat": "40.43094",
    "lng": "29.15969"
  },
  {
    "country": "TR",
    "name": "Gelibolu",
    "lat": "40.41028",
    "lng": "26.67083"
  },
  {
    "country": "TR",
    "name": "Gediksaray",
    "lat": "40.44529",
    "lng": "35.62627"
  },
  {
    "country": "TR",
    "name": "Gebze",
    "lat": "40.80276",
    "lng": "29.43068"
  },
  {
    "country": "TR",
    "name": "Gaziler",
    "lat": "40.42153",
    "lng": "42.34799"
  },
  {
    "country": "TR",
    "name": "Gaziler",
    "lat": "40.08125",
    "lng": "43.45187"
  },
  {
    "country": "TR",
    "name": "Fındıklı",
    "lat": "41.269",
    "lng": "41.14002"
  },
  {
    "country": "TR",
    "name": "Ferizli",
    "lat": "40.94082",
    "lng": "30.48583"
  },
  {
    "country": "TR",
    "name": "Fatsa",
    "lat": "41.02778",
    "lng": "37.50139"
  },
  {
    "country": "TR",
    "name": "Eynesil",
    "lat": "41.06436",
    "lng": "39.14274"
  },
  {
    "country": "TR",
    "name": "Eymir",
    "lat": "40.01927",
    "lng": "35.20788"
  },
  {
    "country": "TR",
    "name": "Eğerci",
    "lat": "41.09922",
    "lng": "31.81739"
  },
  {
    "country": "TR",
    "name": "Evren",
    "lat": "40.24527",
    "lng": "39.17535"
  },
  {
    "country": "TR",
    "name": "Eskipazar",
    "lat": "40.94298",
    "lng": "32.53091"
  },
  {
    "country": "TR",
    "name": "Gözyeri",
    "lat": "40.86596",
    "lng": "32.54167"
  },
  {
    "country": "TR",
    "name": "Esiroğlu",
    "lat": "40.87331",
    "lng": "39.68829"
  },
  {
    "country": "TR",
    "name": "Esenyurt",
    "lat": "41.02697",
    "lng": "28.67732"
  },
  {
    "country": "TR",
    "name": "Esenler",
    "lat": "41.0435",
    "lng": "28.87619"
  },
  {
    "country": "TR",
    "name": "Esençay",
    "lat": "40.66806",
    "lng": "36.38028"
  },
  {
    "country": "TR",
    "name": "Erfelek",
    "lat": "41.87926",
    "lng": "34.91838"
  },
  {
    "country": "TR",
    "name": "Erenler",
    "lat": "40.75504",
    "lng": "30.39344"
  },
  {
    "country": "TR",
    "name": "Ereğli",
    "lat": "41.28261",
    "lng": "31.41806"
  },
  {
    "country": "TR",
    "name": "Erdek",
    "lat": "40.3996",
    "lng": "27.79348"
  },
  {
    "country": "TR",
    "name": "Erbaa",
    "lat": "40.66889",
    "lng": "36.5675"
  },
  {
    "country": "TR",
    "name": "Enez",
    "lat": "40.72472",
    "lng": "26.0825"
  },
  {
    "country": "TR",
    "name": "Eminönü",
    "lat": "41.01766",
    "lng": "28.97438"
  },
  {
    "country": "TR",
    "name": "Eldivan",
    "lat": "40.52975",
    "lng": "33.49903"
  },
  {
    "country": "TR",
    "name": "Elbeyli",
    "lat": "40.48611",
    "lng": "29.72472"
  },
  {
    "country": "TR",
    "name": "Eflani",
    "lat": "41.42289",
    "lng": "32.95761"
  },
  {
    "country": "TR",
    "name": "Edirne",
    "lat": "41.67719",
    "lng": "26.55597"
  },
  {
    "country": "TR",
    "name": "Edincik",
    "lat": "40.34229",
    "lng": "27.86129"
  },
  {
    "country": "TR",
    "name": "Eceabat",
    "lat": "40.18416",
    "lng": "26.3574"
  },
  {
    "country": "TR",
    "name": "Düzköy",
    "lat": "40.87461",
    "lng": "39.41536"
  },
  {
    "country": "TR",
    "name": "Düzce",
    "lat": "40.83889",
    "lng": "31.16389"
  },
  {
    "country": "TR",
    "name": "Durusu",
    "lat": "41.30337",
    "lng": "28.67635"
  },
  {
    "country": "TR",
    "name": "Durağan",
    "lat": "41.41583",
    "lng": "35.05444"
  },
  {
    "country": "TR",
    "name": "Dumlu",
    "lat": "40.05862",
    "lng": "41.35654"
  },
  {
    "country": "TR",
    "name": "Dörtdivan",
    "lat": "40.72052",
    "lng": "32.06314"
  },
  {
    "country": "TR",
    "name": "Karşıyaka",
    "lat": "40.6936",
    "lng": "29.94154"
  },
  {
    "country": "TR",
    "name": "Dökmetepe",
    "lat": "40.31224",
    "lng": "36.2918"
  },
  {
    "country": "TR",
    "name": "Doğruyol",
    "lat": "40.97986",
    "lng": "43.47098"
  },
  {
    "country": "TR",
    "name": "Doğanyurt",
    "lat": "42.00457",
    "lng": "33.46029"
  },
  {
    "country": "TR",
    "name": "Doğanyurt",
    "lat": "40.68806",
    "lng": "36.71639"
  },
  {
    "country": "TR",
    "name": "Doğantepe",
    "lat": "40.59778",
    "lng": "35.60417"
  },
  {
    "country": "TR",
    "name": "Doğanşar",
    "lat": "40.20841",
    "lng": "37.53123"
  },
  {
    "country": "TR",
    "name": "Doğankent",
    "lat": "40.8075",
    "lng": "38.91722"
  },
  {
    "country": "TR",
    "name": "Doğançay",
    "lat": "40.62647",
    "lng": "30.33557"
  },
  {
    "country": "TR",
    "name": "Dodurga",
    "lat": "40.85489",
    "lng": "34.80703"
  },
  {
    "country": "TR",
    "name": "Dikbıyık",
    "lat": "41.22078",
    "lng": "36.615"
  },
  {
    "country": "TR",
    "name": "Digor",
    "lat": "40.36896",
    "lng": "43.40997"
  },
  {
    "country": "TR",
    "name": "Devrekani",
    "lat": "41.60303",
    "lng": "33.83922"
  },
  {
    "country": "TR",
    "name": "Devrek",
    "lat": "41.21917",
    "lng": "31.95583"
  },
  {
    "country": "TR",
    "name": "Destek",
    "lat": "40.84667",
    "lng": "36.18306"
  },
  {
    "country": "TR",
    "name": "Dernekpazarı",
    "lat": "40.79658",
    "lng": "40.2446"
  },
  {
    "country": "TR",
    "name": "Derince",
    "lat": "40.75694",
    "lng": "29.81472"
  },
  {
    "country": "TR",
    "name": "Derepazarı",
    "lat": "41.02398",
    "lng": "40.42332"
  },
  {
    "country": "TR",
    "name": "Dereli",
    "lat": "40.7389",
    "lng": "38.44337"
  },
  {
    "country": "TR",
    "name": "Dereköy",
    "lat": "41.93008",
    "lng": "27.37052"
  },
  {
    "country": "TR",
    "name": "Derecik",
    "lat": "40.9459",
    "lng": "39.59401"
  },
  {
    "country": "TR",
    "name": "Büyükderbent",
    "lat": "40.70753",
    "lng": "30.11434"
  },
  {
    "country": "TR",
    "name": "Demirtaş",
    "lat": "40.27194",
    "lng": "29.09833"
  },
  {
    "country": "TR",
    "name": "Pulur",
    "lat": "40.16023",
    "lng": "39.89239"
  },
  {
    "country": "TR",
    "name": "Demirkent",
    "lat": "40.87908",
    "lng": "41.72953"
  },
  {
    "country": "TR",
    "name": "Değirmendere",
    "lat": "40.72",
    "lng": "29.78083"
  },
  {
    "country": "TR",
    "name": "Darıca",
    "lat": "40.77973",
    "lng": "29.39454"
  },
  {
    "country": "TR",
    "name": "Darıca",
    "lat": "40.0206",
    "lng": "27.86374"
  },
  {
    "country": "TR",
    "name": "Dambaslar",
    "lat": "41.22417",
    "lng": "27.24806"
  },
  {
    "country": "TR",
    "name": "Damal",
    "lat": "41.34145",
    "lng": "42.8368"
  },
  {
    "country": "TR",
    "name": "Dağbaşı",
    "lat": "40.72763",
    "lng": "39.91177"
  },
  {
    "country": "TR",
    "name": "Daday",
    "lat": "41.47866",
    "lng": "33.46667"
  },
  {
    "country": "TR",
    "name": "Çubuk",
    "lat": "40.23861",
    "lng": "33.03222"
  },
  {
    "country": "TR",
    "name": "Çorum",
    "lat": "40.54889",
    "lng": "34.95333"
  },
  {
    "country": "TR",
    "name": "Çorlu",
    "lat": "41.15917",
    "lng": "27.8"
  },
  {
    "country": "TR",
    "name": "Çöpköy",
    "lat": "41.21972",
    "lng": "26.82278"
  },
  {
    "country": "TR",
    "name": "Çırçır",
    "lat": "40.055",
    "lng": "36.775"
  },
  {
    "country": "TR",
    "name": "Çınarcık",
    "lat": "40.64538",
    "lng": "29.1245"
  },
  {
    "country": "TR",
    "name": "Çilimli",
    "lat": "40.89361",
    "lng": "31.04917"
  },
  {
    "country": "TR",
    "name": "Zurzuna",
    "lat": "41.12141",
    "lng": "43.1299"
  },
  {
    "country": "TR",
    "name": "Çiftlikköy",
    "lat": "40.66028",
    "lng": "29.32361"
  },
  {
    "country": "TR",
    "name": "Cide",
    "lat": "41.89211",
    "lng": "33.00439"
  },
  {
    "country": "TR",
    "name": "Cerrah",
    "lat": "40.07124",
    "lng": "29.44661"
  },
  {
    "country": "TR",
    "name": "Çerkezköy",
    "lat": "41.28629",
    "lng": "27.99939"
  },
  {
    "country": "TR",
    "name": "Çerkeş",
    "lat": "40.81164",
    "lng": "32.89358"
  },
  {
    "country": "TR",
    "name": "Çerçiler",
    "lat": "41.3945",
    "lng": "35.23665"
  },
  {
    "country": "TR",
    "name": "Cemilbey",
    "lat": "40.34529",
    "lng": "35.05136"
  },
  {
    "country": "TR",
    "name": "Çeltikçi",
    "lat": "40.32194",
    "lng": "32.45569"
  },
  {
    "country": "TR",
    "name": "Çekmeköy",
    "lat": "41.04118",
    "lng": "29.17838"
  },
  {
    "country": "TR",
    "name": "Çekerek",
    "lat": "40.07306",
    "lng": "35.49472"
  },
  {
    "country": "TR",
    "name": "Kürtün",
    "lat": "40.69516",
    "lng": "39.09468"
  },
  {
    "country": "TR",
    "name": "Çaykara",
    "lat": "40.74267",
    "lng": "40.23175"
  },
  {
    "country": "TR",
    "name": "Çayırhan",
    "lat": "40.09806",
    "lng": "31.67319"
  },
  {
    "country": "TR",
    "name": "Çayeli",
    "lat": "41.08609",
    "lng": "40.72213"
  },
  {
    "country": "TR",
    "name": "Çaycuma",
    "lat": "41.42639",
    "lng": "32.07556"
  },
  {
    "country": "TR",
    "name": "Çaybaşı",
    "lat": "41.01711",
    "lng": "37.09796"
  },
  {
    "country": "TR",
    "name": "Çatalzeytin",
    "lat": "41.95314",
    "lng": "34.21627"
  },
  {
    "country": "TR",
    "name": "Çatalca",
    "lat": "41.14324",
    "lng": "28.46154"
  },
  {
    "country": "TR",
    "name": "Çarşıbaşı",
    "lat": "41.08278",
    "lng": "39.38278"
  },
  {
    "country": "TR",
    "name": "Çarşamba",
    "lat": "41.19889",
    "lng": "36.72194"
  },
  {
    "country": "TR",
    "name": "Çanta",
    "lat": "41.07897",
    "lng": "28.08323"
  },
  {
    "country": "TR",
    "name": "Khanjarah",
    "lat": "40.59995",
    "lng": "33.6153"
  },
  {
    "country": "TR",
    "name": "Çandır",
    "lat": "40.25717",
    "lng": "33.46868"
  },
  {
    "country": "TR",
    "name": "Çanakkale",
    "lat": "40.15552",
    "lng": "26.41271"
  },
  {
    "country": "TR",
    "name": "Çanakçı",
    "lat": "40.91139",
    "lng": "38.98813"
  },
  {
    "country": "TR",
    "name": "Çan",
    "lat": "40.03328",
    "lng": "27.05236"
  },
  {
    "country": "TR",
    "name": "Çamoluk",
    "lat": "40.12732",
    "lng": "38.73006"
  },
  {
    "country": "TR",
    "name": "Çamlıkaya",
    "lat": "40.6391",
    "lng": "41.15218"
  },
  {
    "country": "TR",
    "name": "Çamlıhemşin",
    "lat": "41.04765",
    "lng": "40.99996"
  },
  {
    "country": "TR",
    "name": "Çamlıdere",
    "lat": "40.48958",
    "lng": "32.47499"
  },
  {
    "country": "TR",
    "name": "Çamlıbel",
    "lat": "40.08639",
    "lng": "36.47722"
  },
  {
    "country": "TR",
    "name": "Camili",
    "lat": "41.47838",
    "lng": "41.89825"
  },
  {
    "country": "TR",
    "name": "Çağlayan",
    "lat": "40.90019",
    "lng": "39.71231"
  },
  {
    "country": "TR",
    "name": "Çamaş",
    "lat": "40.902",
    "lng": "37.52786"
  },
  {
    "country": "TR",
    "name": "Çalı",
    "lat": "40.16861",
    "lng": "28.92083"
  },
  {
    "country": "TR",
    "name": "Çakırlı",
    "lat": "40.51806",
    "lng": "29.45222"
  },
  {
    "country": "TR",
    "name": "Çakırca",
    "lat": "40.47056",
    "lng": "29.66333"
  },
  {
    "country": "TR",
    "name": "Çakıralan",
    "lat": "41.16824",
    "lng": "35.76017"
  },
  {
    "country": "TR",
    "name": "Laçin",
    "lat": "40.77486",
    "lng": "34.88068"
  },
  {
    "country": "TR",
    "name": "Büyükköy",
    "lat": "41.01489",
    "lng": "40.67302"
  },
  {
    "country": "TR",
    "name": "Büyükkarıştıran",
    "lat": "41.30028",
    "lng": "27.54528"
  },
  {
    "country": "TR",
    "name": "Chekmejeh",
    "lat": "41.01284",
    "lng": "28.53824"
  },
  {
    "country": "TR",
    "name": "Büyükçavuşlu",
    "lat": "41.24002",
    "lng": "28.06331"
  },
  {
    "country": "TR",
    "name": "Adalar",
    "lat": "40.86778",
    "lng": "29.13306"
  },
  {
    "country": "TR",
    "name": "Bursa",
    "lat": "40.19559",
    "lng": "29.06013"
  },
  {
    "country": "TR",
    "name": "Sarıcakaya",
    "lat": "40.03686",
    "lng": "30.62675"
  },
  {
    "country": "TR",
    "name": "Bulancak",
    "lat": "40.93805",
    "lng": "38.23148"
  },
  {
    "country": "TR",
    "name": "Buğdaylı",
    "lat": "40.21889",
    "lng": "27.77056"
  },
  {
    "country": "TR",
    "name": "Bozkurt",
    "lat": "41.95769",
    "lng": "34.01087"
  },
  {
    "country": "TR",
    "name": "Boyalık",
    "lat": "41.26337",
    "lng": "28.63142"
  },
  {
    "country": "TR",
    "name": "Boyalıca",
    "lat": "40.48194",
    "lng": "29.56083"
  },
  {
    "country": "TR",
    "name": "Boyabat",
    "lat": "41.46889",
    "lng": "34.76667"
  },
  {
    "country": "TR",
    "name": "Borçka",
    "lat": "41.35792",
    "lng": "41.66579"
  },
  {
    "country": "TR",
    "name": "Bolu",
    "lat": "40.73583",
    "lng": "31.60611"
  },
  {
    "country": "TR",
    "name": "Bolayır",
    "lat": "40.5153",
    "lng": "26.75664"
  },
  {
    "country": "TR",
    "name": "Bolaman",
    "lat": "41.03435",
    "lng": "37.59409"
  },
  {
    "country": "TR",
    "name": "Boğazkale",
    "lat": "40.02191",
    "lng": "34.60947"
  },
  {
    "country": "TR",
    "name": "Boğazkaya",
    "lat": "41.45",
    "lng": "35.86667"
  },
  {
    "country": "TR",
    "name": "Eminbey",
    "lat": "41.54755",
    "lng": "42.78199"
  },
  {
    "country": "TR",
    "name": "Bilecik",
    "lat": "40.14192",
    "lng": "29.97932"
  },
  {
    "country": "TR",
    "name": "Biga",
    "lat": "40.22806",
    "lng": "27.24222"
  },
  {
    "country": "TR",
    "name": "Asarcık",
    "lat": "41.03556",
    "lng": "36.23556"
  },
  {
    "country": "TR",
    "name": "Beypazarı",
    "lat": "40.1675",
    "lng": "31.92111"
  },
  {
    "country": "TR",
    "name": "Beyçayırı",
    "lat": "40.25515",
    "lng": "26.92442"
  },
  {
    "country": "TR",
    "name": "Beyazköy",
    "lat": "41.34833",
    "lng": "27.70389"
  },
  {
    "country": "TR",
    "name": "Beşpınar",
    "lat": "41.13822",
    "lng": "35.21724"
  },
  {
    "country": "TR",
    "name": "Beşikdüzü",
    "lat": "41.05202",
    "lng": "39.23294"
  },
  {
    "country": "TR",
    "name": "Bereketli",
    "lat": "40.51273",
    "lng": "37.28862"
  },
  {
    "country": "TR",
    "name": "Belören",
    "lat": "40.86156",
    "lng": "33.49557"
  },
  {
    "country": "TR",
    "name": "Bayramören",
    "lat": "40.94329",
    "lng": "33.203"
  },
  {
    "country": "TR",
    "name": "Bayburt",
    "lat": "40.25631",
    "lng": "40.22289"
  },
  {
    "country": "TR",
    "name": "Bayat",
    "lat": "40.64583",
    "lng": "34.26139"
  },
  {
    "country": "TR",
    "name": "Başgedikler",
    "lat": "40.64069",
    "lng": "43.52179"
  },
  {
    "country": "TR",
    "name": "Başçiftlik",
    "lat": "40.54694",
    "lng": "37.16917"
  },
  {
    "country": "TR",
    "name": "Bartın",
    "lat": "41.63583",
    "lng": "32.3375"
  },
  {
    "country": "TR",
    "name": "Bandırma",
    "lat": "40.35222",
    "lng": "27.97667"
  },
  {
    "country": "TR",
    "name": "Banarlı",
    "lat": "41.06702",
    "lng": "27.33575"
  },
  {
    "country": "TR",
    "name": "Ondokuzmayıs",
    "lat": "41.5011",
    "lng": "36.06887"
  },
  {
    "country": "TR",
    "name": "Ballı",
    "lat": "40.83028",
    "lng": "27.05548"
  },
  {
    "country": "TR",
    "name": "Balıklıçeşme",
    "lat": "40.31029",
    "lng": "27.08171"
  },
  {
    "country": "TR",
    "name": "Balçık",
    "lat": "40.8725",
    "lng": "29.42833"
  },
  {
    "country": "TR",
    "name": "Bakacak",
    "lat": "40.20499",
    "lng": "27.08317"
  },
  {
    "country": "TR",
    "name": "Bahçecik",
    "lat": "40.6681",
    "lng": "29.91478"
  },
  {
    "country": "TR",
    "name": "Bağcılar",
    "lat": "41.03903",
    "lng": "28.85671"
  },
  {
    "country": "TR",
    "name": "Bafra",
    "lat": "41.56778",
    "lng": "35.90694"
  },
  {
    "country": "TR",
    "name": "Babaeski",
    "lat": "41.4325",
    "lng": "27.09306"
  },
  {
    "country": "TR",
    "name": "Azdavay",
    "lat": "41.64267",
    "lng": "33.3"
  },
  {
    "country": "TR",
    "name": "Ayvacık",
    "lat": "40.99111",
    "lng": "36.63139"
  },
  {
    "country": "TR",
    "name": "Aydıntepe",
    "lat": "40.38325",
    "lng": "40.14272"
  },
  {
    "country": "TR",
    "name": "Aydıncık",
    "lat": "40.12727",
    "lng": "35.28765"
  },
  {
    "country": "TR",
    "name": "Ezinepazarı",
    "lat": "40.56972",
    "lng": "36.13917"
  },
  {
    "country": "TR",
    "name": "Aybastı",
    "lat": "40.68667",
    "lng": "37.39917"
  },
  {
    "country": "TR",
    "name": "Ayaş",
    "lat": "40.01933",
    "lng": "32.33221"
  },
  {
    "country": "TR",
    "name": "Ayancık",
    "lat": "41.94472",
    "lng": "34.58611"
  },
  {
    "country": "TR",
    "name": "Atkaracalar",
    "lat": "40.81593",
    "lng": "33.07556"
  },
  {
    "country": "TR",
    "name": "Aşağı Irmaklar",
    "lat": "41.18299",
    "lng": "42.17443"
  },
  {
    "country": "TR",
    "name": "Artvin",
    "lat": "41.18161",
    "lng": "41.82172"
  },
  {
    "country": "TR",
    "name": "Artova",
    "lat": "40.11578",
    "lng": "36.3001"
  },
  {
    "country": "TR",
    "name": "Arsin",
    "lat": "40.95271",
    "lng": "39.92674"
  },
  {
    "country": "TR",
    "name": "Arpaçay",
    "lat": "40.84522",
    "lng": "43.32747"
  },
  {
    "country": "TR",
    "name": "Arnavutköy",
    "lat": "41.18355",
    "lng": "28.7402"
  },
  {
    "country": "TR",
    "name": "Armutlu",
    "lat": "40.51944",
    "lng": "28.82806"
  },
  {
    "country": "TR",
    "name": "Arıt",
    "lat": "41.68706",
    "lng": "32.62396"
  },
  {
    "country": "TR",
    "name": "Arifiye",
    "lat": "40.70036",
    "lng": "30.35076"
  },
  {
    "country": "TR",
    "name": "Arhavi",
    "lat": "41.35121",
    "lng": "41.30456"
  },
  {
    "country": "TR",
    "name": "Çamiçi",
    "lat": "40.6181",
    "lng": "37.00169"
  },
  {
    "country": "TR",
    "name": "Ardeşen",
    "lat": "41.19111",
    "lng": "40.9875"
  },
  {
    "country": "TR",
    "name": "Ardanuç",
    "lat": "41.12738",
    "lng": "42.06292"
  },
  {
    "country": "TR",
    "name": "Ardahan",
    "lat": "41.10871",
    "lng": "42.70222"
  },
  {
    "country": "TR",
    "name": "Araklı",
    "lat": "40.93854",
    "lng": "40.05842"
  },
  {
    "country": "TR",
    "name": "Araç",
    "lat": "41.24222",
    "lng": "33.32767"
  },
  {
    "country": "TR",
    "name": "Amasya",
    "lat": "40.65333",
    "lng": "35.83306"
  },
  {
    "country": "TR",
    "name": "Amasra",
    "lat": "41.74633",
    "lng": "32.38633"
  },
  {
    "country": "TR",
    "name": "Alucra",
    "lat": "40.31656",
    "lng": "38.75285"
  },
  {
    "country": "TR",
    "name": "Altınova",
    "lat": "40.69495",
    "lng": "29.50986"
  },
  {
    "country": "TR",
    "name": "Almus",
    "lat": "40.37583",
    "lng": "36.90444"
  },
  {
    "country": "TR",
    "name": "Alıcık",
    "lat": "40.80275",
    "lng": "35.32256"
  },
  {
    "country": "TR",
    "name": "Alaplı",
    "lat": "41.1814",
    "lng": "31.38514"
  },
  {
    "country": "TR",
    "name": "Alanyurt",
    "lat": "40.10881",
    "lng": "29.51871"
  },
  {
    "country": "TR",
    "name": "Alaçam",
    "lat": "41.60556",
    "lng": "35.59806"
  },
  {
    "country": "TR",
    "name": "Alaca",
    "lat": "40.16833",
    "lng": "34.8425"
  },
  {
    "country": "TR",
    "name": "Akyurt",
    "lat": "40.13512",
    "lng": "33.08614"
  },
  {
    "country": "TR",
    "name": "Akyazı",
    "lat": "40.685",
    "lng": "30.62222"
  },
  {
    "country": "TR",
    "name": "Akyaka",
    "lat": "40.74093",
    "lng": "43.61432"
  },
  {
    "country": "TR",
    "name": "Aksu",
    "lat": "40.08964",
    "lng": "38.03467"
  },
  {
    "country": "TR",
    "name": "Akşar",
    "lat": "40.64651",
    "lng": "42.3391"
  },
  {
    "country": "TR",
    "name": "Aksakal",
    "lat": "40.14725",
    "lng": "28.1068"
  },
  {
    "country": "TR",
    "name": "Mollafeneri",
    "lat": "40.88611",
    "lng": "29.49444"
  },
  {
    "country": "TR",
    "name": "Akmeşe",
    "lat": "40.84929",
    "lng": "30.19822"
  },
  {
    "country": "TR",
    "name": "Akkuş",
    "lat": "40.79306",
    "lng": "37.01639"
  },
  {
    "country": "TR",
    "name": "Akıncılar",
    "lat": "40.07172",
    "lng": "38.3433"
  },
  {
    "country": "TR",
    "name": "Akdağ",
    "lat": "40.71235",
    "lng": "35.97605"
  },
  {
    "country": "TR",
    "name": "Akçakoca",
    "lat": "41.08663",
    "lng": "31.11623"
  },
  {
    "country": "TR",
    "name": "Akçaabat",
    "lat": "41.02121",
    "lng": "39.57146"
  },
  {
    "country": "TR",
    "name": "Ağva",
    "lat": "41.13806",
    "lng": "29.85667"
  },
  {
    "country": "TR",
    "name": "Ağlı",
    "lat": "41.68602",
    "lng": "33.55383"
  },
  {
    "country": "TR",
    "name": "Adapazarı",
    "lat": "40.78056",
    "lng": "30.40333"
  },
  {
    "country": "TR",
    "name": "Abana",
    "lat": "41.97858",
    "lng": "34.011"
  },
  {
    "country": "TR",
    "name": "Espiye",
    "lat": "40.94705",
    "lng": "38.70299"
  },
  {
    "country": "TR",
    "name": "Celâliye",
    "lat": "41.05188",
    "lng": "28.41867"
  },
  {
    "country": "TR",
    "name": "Muratbey",
    "lat": "41.0963",
    "lng": "28.49227"
  },
  {
    "country": "TR",
    "name": "Halıdere",
    "lat": "40.71604",
    "lng": "29.75223"
  },
  {
    "country": "TR",
    "name": "İçmeler",
    "lat": "40.84639",
    "lng": "29.30889"
  },
  {
    "country": "TR",
    "name": "Merter Keresteciler",
    "lat": "41.01295",
    "lng": "28.88593"
  },
  {
    "country": "TR",
    "name": "güngören merter",
    "lat": "41.00711",
    "lng": "28.88795"
  },
  {
    "country": "TR",
    "name": "Turgutreis",
    "lat": "37.01667",
    "lng": "27.26667"
  },
  {
    "country": "TR",
    "name": "Karatay",
    "lat": "37.86726",
    "lng": "32.52863"
  },
  {
    "country": "TR",
    "name": "Sarigerme",
    "lat": "36.71549",
    "lng": "28.70436"
  },
  {
    "country": "TR",
    "name": "Ölüdeniz",
    "lat": "36.56674",
    "lng": "29.14467"
  },
  {
    "country": "TR",
    "name": "Arıköy",
    "lat": "41.23044",
    "lng": "29.00425"
  },
  {
    "country": "TR",
    "name": "Çatalhöyük",
    "lat": "37.66847",
    "lng": "32.82689"
  },
  {
    "country": "TR",
    "name": "Adalan",
    "lat": "40.8759",
    "lng": "29.0894"
  },
  {
    "country": "TR",
    "name": "Ataşehir",
    "lat": "40.9833",
    "lng": "29.1167"
  },
  {
    "country": "TR",
    "name": "Başakşehir",
    "lat": "41.09307",
    "lng": "28.80203"
  },
  {
    "country": "TR",
    "name": "Beylikdüzü",
    "lat": "40.982",
    "lng": "28.6399"
  },
  {
    "country": "TR",
    "name": "Büyükçekmece",
    "lat": "41.02072",
    "lng": "28.58502"
  },
  {
    "country": "TR",
    "name": "Çankaya",
    "lat": "39.9179",
    "lng": "32.86268"
  },
  {
    "country": "TR",
    "name": "Yaniklar",
    "lat": "36.70827",
    "lng": "29.05081"
  },
  {
    "country": "TR",
    "name": "Battalgazi",
    "lat": "38.42286",
    "lng": "38.3585"
  },
  {
    "country": "TR",
    "name": "Güce",
    "lat": "40.8932",
    "lng": "38.7982"
  },
  {
    "country": "TR",
    "name": "Çatalpınar",
    "lat": "40.87899",
    "lng": "37.45351"
  },
  {
    "country": "TR",
    "name": "Şehitkamil",
    "lat": "37.07962",
    "lng": "37.38003"
  },
  {
    "country": "TR",
    "name": "Şahinbey",
    "lat": "37.04836",
    "lng": "37.34371"
  },
  {
    "country": "TR",
    "name": "Bahçelievler",
    "lat": "41.00231",
    "lng": "28.8598"
  },
  {
    "country": "TR",
    "name": "Sultangazi",
    "lat": "41.10652",
    "lng": "28.86847"
  },
  {
    "country": "TR",
    "name": "Sultanbeyli",
    "lat": "40.96072",
    "lng": "29.27067"
  },
  {
    "country": "TR",
    "name": "Sancaktepe",
    "lat": "41.00244",
    "lng": "29.23187"
  },
  {
    "country": "TR",
    "name": "Kamışlı",
    "lat": "37.55519",
    "lng": "34.9472"
  },
  {
    "country": "TR",
    "name": "Köprübaşı",
    "lat": "41.04754",
    "lng": "35.51687"
  },
  {
    "country": "TR",
    "name": "Çayırkent",
    "lat": "41.17128",
    "lng": "36.32883"
  },
  {
    "country": "TR",
    "name": "Salıpazarı",
    "lat": "41.08398",
    "lng": "36.8304"
  },
  {
    "country": "TR",
    "name": "Karabağlar",
    "lat": "38.37396",
    "lng": "27.1352"
  },
  {
    "country": "TR",
    "name": "Muratpaşa",
    "lat": "36.89157",
    "lng": "30.76498"
  },
  {
    "country": "TR",
    "name": "Okurcalar",
    "lat": "36.64876",
    "lng": "31.70387"
  },
  {
    "country": "TR",
    "name": "Cumayeri",
    "lat": "40.87389",
    "lng": "30.95091"
  },
  {
    "country": "TR",
    "name": "Ortaköy",
    "lat": "40.97305",
    "lng": "30.67686"
  },
  {
    "country": "TR",
    "name": "Polateli",
    "lat": "36.84137",
    "lng": "37.14407"
  },
  {
    "country": "TR",
    "name": "Ovacık",
    "lat": "36.17132",
    "lng": "33.55581"
  },
  {
    "country": "TR",
    "name": "Kazımpaşa",
    "lat": "40.7916",
    "lng": "30.295"
  },
  {
    "country": "TR",
    "name": "Akçaova",
    "lat": "41.0366",
    "lng": "29.9018"
  },
  {
    "country": "TR",
    "name": "Termal",
    "lat": "40.60779",
    "lng": "29.1736"
  },
  {
    "country": "TR",
    "name": "Yıldırım",
    "lat": "40.18851",
    "lng": "29.10974"
  },
  {
    "country": "TR",
    "name": "Osmangazi",
    "lat": "40.19671",
    "lng": "29.05935"
  },
  {
    "country": "TR",
    "name": "Büyükorhan",
    "lat": "39.77102",
    "lng": "28.88614"
  },
  {
    "country": "TR",
    "name": "Akçasır",
    "lat": "38.44722",
    "lng": "41.26513"
  },
  {
    "country": "TR",
    "name": "Taşburun",
    "lat": "39.98607",
    "lng": "44.22359"
  },
  {
    "country": "TR",
    "name": "Bağlar",
    "lat": "37.91375",
    "lng": "40.20584"
  },
  {
    "country": "TR",
    "name": "Sur",
    "lat": "37.91351",
    "lng": "40.22859"
  },
  {
    "country": "TR",
    "name": "Yenişehir",
    "lat": "37.94146",
    "lng": "40.13801"
  },
  {
    "country": "TR",
    "name": "Palandöken",
    "lat": "39.88898",
    "lng": "41.28055"
  },
  {
    "country": "TR",
    "name": "Kazımkarabekir",
    "lat": "39.91598",
    "lng": "41.28145"
  },
  {
    "country": "TR",
    "name": "Yakutiye",
    "lat": "39.89821",
    "lng": "41.26916"
  },
  {
    "country": "TR",
    "name": "Tepebaşı",
    "lat": "39.81091",
    "lng": "30.52551"
  },
  {
    "country": "TR",
    "name": "Odunpazarı",
    "lat": "39.76821",
    "lng": "30.53538"
  },
  {
    "country": "TR",
    "name": "Pamukkale",
    "lat": "37.7912",
    "lng": "29.10141"
  },
  {
    "country": "TR",
    "name": "Nilüfer",
    "lat": "40.21401",
    "lng": "28.91567"
  },
  {
    "country": "TR",
    "name": "Çaybağı",
    "lat": "38.82855",
    "lng": "39.61057"
  },
  {
    "country": "TR",
    "name": "Merkez",
    "lat": "40.12954",
    "lng": "26.42075"
  },
  {
    "country": "TR",
    "name": "İlkadım",
    "lat": "41.28732",
    "lng": "36.29046"
  },
  {
    "country": "TR",
    "name": "Kepez",
    "lat": "36.91579",
    "lng": "30.70782"
  },
  {
    "country": "TR",
    "name": "Ümraniye",
    "lat": "41.03291",
    "lng": "29.10137"
  },
  {
    "country": "TR",
    "name": "Altınordu",
    "lat": "40.98404",
    "lng": "37.87348"
  },
  {
    "country": "TR",
    "name": "Kürecik",
    "lat": "38.33675",
    "lng": "37.74142"
  },
  {
    "country": "TR",
    "name": "Doğruyol",
    "lat": "41.06132",
    "lng": "43.32201"
  },
  {
    "country": "TR",
    "name": "Merkezefendi",
    "lat": "37.80544",
    "lng": "29.04236"
  },
  {
    "country": "TT",
    "name": "Tunapuna",
    "lat": "10.65245",
    "lng": "-61.38878"
  },
  {
    "country": "TT",
    "name": "Tabaquite",
    "lat": "10.38824",
    "lng": "-61.29704"
  },
  {
    "country": "TT",
    "name": "Siparia",
    "lat": "10.14525",
    "lng": "-61.5074"
  },
  {
    "country": "TT",
    "name": "Scarborough",
    "lat": "11.18229",
    "lng": "-60.73525"
  },
  {
    "country": "TT",
    "name": "Sangre Grande",
    "lat": "10.58705",
    "lng": "-61.13008"
  },
  {
    "country": "TT",
    "name": "San Fernando",
    "lat": "10.27969",
    "lng": "-61.46835"
  },
  {
    "country": "TT",
    "name": "Rio Claro",
    "lat": "10.30594",
    "lng": "-61.17556"
  },
  {
    "country": "TT",
    "name": "Princes Town",
    "lat": "10.27184",
    "lng": "-61.37103"
  },
  {
    "country": "TT",
    "name": "Port of Spain",
    "lat": "10.66668",
    "lng": "-61.51889"
  },
  {
    "country": "TT",
    "name": "Point Fortin",
    "lat": "10.17411",
    "lng": "-61.68407"
  },
  {
    "country": "TT",
    "name": "Petit Valley",
    "lat": "10.69974",
    "lng": "-61.54717"
  },
  {
    "country": "TT",
    "name": "Peñal",
    "lat": "10.16667",
    "lng": "-61.46667"
  },
  {
    "country": "TT",
    "name": "Paradise",
    "lat": "10.65298",
    "lng": "-61.36298"
  },
  {
    "country": "TT",
    "name": "Mucurapo",
    "lat": "10.66253",
    "lng": "-61.53697"
  },
  {
    "country": "TT",
    "name": "Mon Repos",
    "lat": "10.27979",
    "lng": "-61.4459"
  },
  {
    "country": "TT",
    "name": "Marabella",
    "lat": "10.30618",
    "lng": "-61.44671"
  },
  {
    "country": "TT",
    "name": "Laventille",
    "lat": "10.64917",
    "lng": "-61.49889"
  },
  {
    "country": "TT",
    "name": "Diego Martin",
    "lat": "10.72081",
    "lng": "-61.56616"
  },
  {
    "country": "TT",
    "name": "Debe",
    "lat": "10.20846",
    "lng": "-61.45273"
  },
  {
    "country": "TT",
    "name": "Couva",
    "lat": "10.42248",
    "lng": "-61.46748"
  },
  {
    "country": "TT",
    "name": "Chaguanas",
    "lat": "10.51667",
    "lng": "-61.41667"
  },
  {
    "country": "TT",
    "name": "Arouca",
    "lat": "10.62877",
    "lng": "-61.33487"
  },
  {
    "country": "TT",
    "name": "Arima",
    "lat": "10.63737",
    "lng": "-61.28228"
  },
  {
    "country": "TV",
    "name": "Toga Village",
    "lat": "-6.28764",
    "lng": "176.31472"
  },
  {
    "country": "TV",
    "name": "Tanrake Village",
    "lat": "-7.24562",
    "lng": "177.14511"
  },
  {
    "country": "TV",
    "name": "Kulia Village",
    "lat": "-6.10819",
    "lng": "177.33393"
  },
  {
    "country": "TV",
    "name": "Funafuti",
    "lat": "-8.52425",
    "lng": "179.19417"
  },
  {
    "country": "TV",
    "name": "Asau Village",
    "lat": "-7.49026",
    "lng": "178.68016"
  },
  {
    "country": "TV",
    "name": "Savave Village",
    "lat": "-8.02731",
    "lng": "178.31351"
  },
  {
    "country": "TV",
    "name": "Alapi Village",
    "lat": "-8.52074",
    "lng": "179.1968"
  },
  {
    "country": "TV",
    "name": "Fakaifou Village",
    "lat": "-8.51758",
    "lng": "179.20094"
  },
  {
    "country": "TW",
    "name": "Douliu",
    "lat": "23.70944",
    "lng": "120.54333"
  },
  {
    "country": "TW",
    "name": "Yujing",
    "lat": "23.12493",
    "lng": "120.46138"
  },
  {
    "country": "TW",
    "name": "Yuanlin",
    "lat": "23.96113",
    "lng": "120.57209"
  },
  {
    "country": "TW",
    "name": "Donggang",
    "lat": "22.46515",
    "lng": "120.44927"
  },
  {
    "country": "TW",
    "name": "Taoyuan",
    "lat": "24.9896",
    "lng": "121.3187"
  },
  {
    "country": "TW",
    "name": "Taitung",
    "lat": "22.75991",
    "lng": "121.14457"
  },
  {
    "country": "TW",
    "name": "Taipei",
    "lat": "25.04776",
    "lng": "121.53185"
  },
  {
    "country": "TW",
    "name": "Taibao",
    "lat": "23.45944",
    "lng": "120.33222"
  },
  {
    "country": "TW",
    "name": "Xinying",
    "lat": "23.30694",
    "lng": "120.31056"
  },
  {
    "country": "TW",
    "name": "Tainan",
    "lat": "22.99083",
    "lng": "120.21333"
  },
  {
    "country": "TW",
    "name": "Fengyuan",
    "lat": "24.25",
    "lng": "120.71694"
  },
  {
    "country": "TW",
    "name": "Taichung",
    "lat": "24.1469",
    "lng": "120.6839"
  },
  {
    "country": "TW",
    "name": "Daxi",
    "lat": "24.88373",
    "lng": "121.29043"
  },
  {
    "country": "TW",
    "name": "Banqiao",
    "lat": "25.01427",
    "lng": "121.46719"
  },
  {
    "country": "TW",
    "name": "Puli",
    "lat": "23.96639",
    "lng": "120.96952"
  },
  {
    "country": "TW",
    "name": "Pizitou",
    "lat": "23.48556",
    "lng": "120.44472"
  },
  {
    "country": "TW",
    "name": "Pingtung",
    "lat": "22.67135",
    "lng": "120.48814"
  },
  {
    "country": "TW",
    "name": "Nantou",
    "lat": "23.91566",
    "lng": "120.66387"
  },
  {
    "country": "TW",
    "name": "Miaoli",
    "lat": "24.56427",
    "lng": "120.82367"
  },
  {
    "country": "TW",
    "name": "Magong",
    "lat": "23.5654",
    "lng": "119.58627"
  },
  {
    "country": "TW",
    "name": "Lugu",
    "lat": "23.74639",
    "lng": "120.7525"
  },
  {
    "country": "TW",
    "name": "Fengshan",
    "lat": "22.62659",
    "lng": "120.36126"
  },
  {
    "country": "TW",
    "name": "Kaohsiung",
    "lat": "22.61626",
    "lng": "120.31333"
  },
  {
    "country": "TW",
    "name": "Yilan",
    "lat": "24.757",
    "lng": "121.753"
  },
  {
    "country": "TW",
    "name": "Hualien City",
    "lat": "23.97694",
    "lng": "121.60444"
  },
  {
    "country": "TW",
    "name": "Xindian",
    "lat": "24.96005",
    "lng": "121.53892"
  },
  {
    "country": "TW",
    "name": "Hsinchu",
    "lat": "24.80361",
    "lng": "120.96861"
  },
  {
    "country": "TW",
    "name": "Hengchun",
    "lat": "22.00417",
    "lng": "120.74389"
  },
  {
    "country": "TW",
    "name": "Zhubei",
    "lat": "24.83833",
    "lng": "121.00778"
  },
  {
    "country": "TW",
    "name": "Jincheng",
    "lat": "24.43415",
    "lng": "118.31712"
  },
  {
    "country": "TW",
    "name": "Keelung",
    "lat": "25.12825",
    "lng": "121.7419"
  },
  {
    "country": "TW",
    "name": "Jiayi Shi",
    "lat": "23.47917",
    "lng": "120.44889"
  },
  {
    "country": "TW",
    "name": "Chang-hua",
    "lat": "24.07327",
    "lng": "120.56276"
  },
  {
    "country": "TW",
    "name": "Taoyuan City",
    "lat": "24.99368",
    "lng": "121.29696"
  },
  {
    "country": "TW",
    "name": "Taitung City",
    "lat": "22.7583",
    "lng": "121.1444"
  },
  {
    "country": "TW",
    "name": "Nangan",
    "lat": "26.15039",
    "lng": "119.93284"
  },
  {
    "country": "TW",
    "name": "Zhongxing New Village",
    "lat": "23.95908",
    "lng": "120.68516"
  },
  {
    "country": "TZ",
    "name": "Zanzibar",
    "lat": "-6.16394",
    "lng": "39.19793"
  },
  {
    "country": "TZ",
    "name": "Wete",
    "lat": "-5.05589",
    "lng": "39.72938"
  },
  {
    "country": "TZ",
    "name": "Vwawa",
    "lat": "-9.10806",
    "lng": "32.93472"
  },
  {
    "country": "TZ",
    "name": "Vikindu",
    "lat": "-7.00667",
    "lng": "39.29849"
  },
  {
    "country": "TZ",
    "name": "Uyovu",
    "lat": "-3.28333",
    "lng": "31.52583"
  },
  {
    "country": "TZ",
    "name": "Uwelini",
    "lat": "-5.4",
    "lng": "39.68333"
  },
  {
    "country": "TZ",
    "name": "Uvinza",
    "lat": "-5.10361",
    "lng": "30.39111"
  },
  {
    "country": "TZ",
    "name": "Utete",
    "lat": "-7.98598",
    "lng": "38.75795"
  },
  {
    "country": "TZ",
    "name": "Usoke",
    "lat": "-5.16667",
    "lng": "32.35"
  },
  {
    "country": "TZ",
    "name": "Ushirombo",
    "lat": "-3.49194",
    "lng": "31.96389"
  },
  {
    "country": "TZ",
    "name": "Usevia",
    "lat": "-7.1",
    "lng": "31.23333"
  },
  {
    "country": "TZ",
    "name": "Usagara",
    "lat": "-2.68333",
    "lng": "33"
  },
  {
    "country": "TZ",
    "name": "Usa River",
    "lat": "-3.36667",
    "lng": "36.85"
  },
  {
    "country": "TZ",
    "name": "Urambo",
    "lat": "-5.06667",
    "lng": "32.05"
  },
  {
    "country": "TZ",
    "name": "Ulenje",
    "lat": "-8.93333",
    "lng": "33.68333"
  },
  {
    "country": "TZ",
    "name": "Tunduma",
    "lat": "-9.3",
    "lng": "32.76667"
  },
  {
    "country": "TZ",
    "name": "Tumbi",
    "lat": "-5.06667",
    "lng": "32.73333"
  },
  {
    "country": "TZ",
    "name": "Tukuyu",
    "lat": "-9.25",
    "lng": "33.65"
  },
  {
    "country": "TZ",
    "name": "Tinde",
    "lat": "-3.88333",
    "lng": "33.2"
  },
  {
    "country": "TZ",
    "name": "Tarime",
    "lat": "-1.35",
    "lng": "34.36667"
  },
  {
    "country": "TZ",
    "name": "Tanga",
    "lat": "-5.06893",
    "lng": "39.09875"
  },
  {
    "country": "TZ",
    "name": "Tabora",
    "lat": "-5.01622",
    "lng": "32.82663"
  },
  {
    "country": "TZ",
    "name": "Sumbawanga",
    "lat": "-7.96667",
    "lng": "31.61667"
  },
  {
    "country": "TZ",
    "name": "Soni",
    "lat": "-4.85",
    "lng": "38.36667"
  },
  {
    "country": "TZ",
    "name": "Songwa",
    "lat": "-3.51667",
    "lng": "33.51667"
  },
  {
    "country": "TZ",
    "name": "Somanda",
    "lat": "-3.36667",
    "lng": "33.95"
  },
  {
    "country": "TZ",
    "name": "Sokoni",
    "lat": "-6.43333",
    "lng": "39.55"
  },
  {
    "country": "TZ",
    "name": "Sirari",
    "lat": "-1.25367",
    "lng": "34.47596"
  },
  {
    "country": "TZ",
    "name": "Singida",
    "lat": "-4.81629",
    "lng": "34.74358"
  },
  {
    "country": "TZ",
    "name": "Sikonge",
    "lat": "-5.63333",
    "lng": "32.76667"
  },
  {
    "country": "TZ",
    "name": "Shinyanga",
    "lat": "-3.66393",
    "lng": "33.42118"
  },
  {
    "country": "TZ",
    "name": "Shelui",
    "lat": "-4.36667",
    "lng": "34.2"
  },
  {
    "country": "TZ",
    "name": "Sepuka",
    "lat": "-4.75",
    "lng": "34.53333"
  },
  {
    "country": "TZ",
    "name": "Same",
    "lat": "-4.06667",
    "lng": "37.73333"
  },
  {
    "country": "TZ",
    "name": "Rulenge",
    "lat": "-2.7175",
    "lng": "30.6325"
  },
  {
    "country": "TZ",
    "name": "Rujewa",
    "lat": "-8.7",
    "lng": "34.38333"
  },
  {
    "country": "TZ",
    "name": "Puma",
    "lat": "-5",
    "lng": "34.73333"
  },
  {
    "country": "TZ",
    "name": "Poli",
    "lat": "-3.33333",
    "lng": "36.8"
  },
  {
    "country": "TZ",
    "name": "Pangani",
    "lat": "-5.42526",
    "lng": "38.97473"
  },
  {
    "country": "TZ",
    "name": "Old Shinyanga",
    "lat": "-3.55",
    "lng": "33.4"
  },
  {
    "country": "TZ",
    "name": "Nzega",
    "lat": "-4.21667",
    "lng": "33.18333"
  },
  {
    "country": "TZ",
    "name": "Nyanguge",
    "lat": "-2.55",
    "lng": "33.2"
  },
  {
    "country": "TZ",
    "name": "Nyamuswa",
    "lat": "-1.9",
    "lng": "34.01667"
  },
  {
    "country": "TZ",
    "name": "Nyalikungu",
    "lat": "-3.18333",
    "lng": "33.78333"
  },
  {
    "country": "TZ",
    "name": "Nyakahanga",
    "lat": "-1.60333",
    "lng": "31.14139"
  },
  {
    "country": "TZ",
    "name": "Nyakabindi",
    "lat": "-2.63333",
    "lng": "33.98333"
  },
  {
    "country": "TZ",
    "name": "Nsunga",
    "lat": "-1.14389",
    "lng": "31.39472"
  },
  {
    "country": "TZ",
    "name": "Nshamba",
    "lat": "-1.79833",
    "lng": "31.55111"
  },
  {
    "country": "TZ",
    "name": "Nkove",
    "lat": "-7.95",
    "lng": "30.85"
  },
  {
    "country": "TZ",
    "name": "Nkoaranga",
    "lat": "-3.33333",
    "lng": "36.8"
  },
  {
    "country": "TZ",
    "name": "Njombe",
    "lat": "-9.34917",
    "lng": "34.77167"
  },
  {
    "country": "TZ",
    "name": "Nguruka",
    "lat": "-5.10917",
    "lng": "31.04194"
  },
  {
    "country": "TZ",
    "name": "Ngudu",
    "lat": "-2.96667",
    "lng": "33.33333"
  },
  {
    "country": "TZ",
    "name": "Ngorongoro",
    "lat": "-3.23973",
    "lng": "35.48747"
  },
  {
    "country": "TZ",
    "name": "Ngerengere",
    "lat": "-6.75",
    "lng": "38.11667"
  },
  {
    "country": "TZ",
    "name": "Ngara",
    "lat": "-2.51222",
    "lng": "30.65583"
  },
  {
    "country": "TZ",
    "name": "Nganane",
    "lat": "-6.4",
    "lng": "39.55"
  },
  {
    "country": "TZ",
    "name": "Ndungu",
    "lat": "-4.36667",
    "lng": "38.05"
  },
  {
    "country": "TZ",
    "name": "Ndago",
    "lat": "-4.6",
    "lng": "34.35"
  },
  {
    "country": "TZ",
    "name": "Nansio",
    "lat": "-2.13333",
    "lng": "33.05"
  },
  {
    "country": "TZ",
    "name": "Nangwa",
    "lat": "-4.46667",
    "lng": "35.45"
  },
  {
    "country": "TZ",
    "name": "Namanyere",
    "lat": "-7.51667",
    "lng": "31.05"
  },
  {
    "country": "TZ",
    "name": "Namanga",
    "lat": "-2.55116",
    "lng": "36.78377"
  },
  {
    "country": "TZ",
    "name": "Nakatunguru",
    "lat": "-2.11667",
    "lng": "33.06667"
  },
  {
    "country": "TZ",
    "name": "Naberera",
    "lat": "-4.2",
    "lng": "36.93333"
  },
  {
    "country": "TZ",
    "name": "Mwembe",
    "lat": "-4.15",
    "lng": "37.85"
  },
  {
    "country": "TZ",
    "name": "Mwaya",
    "lat": "-9.55",
    "lng": "33.95"
  },
  {
    "country": "TZ",
    "name": "Mwanza",
    "lat": "-2.51667",
    "lng": "32.9"
  },
  {
    "country": "TZ",
    "name": "Mwanga",
    "lat": "-4.8",
    "lng": "38.2"
  },
  {
    "country": "TZ",
    "name": "Mwadui",
    "lat": "-3.55",
    "lng": "33.6"
  },
  {
    "country": "TZ",
    "name": "Mvomero",
    "lat": "-6.25",
    "lng": "38.66667"
  },
  {
    "country": "TZ",
    "name": "Musoma",
    "lat": "-1.5",
    "lng": "33.8"
  },
  {
    "country": "TZ",
    "name": "Muriti",
    "lat": "-1.98333",
    "lng": "32.91667"
  },
  {
    "country": "TZ",
    "name": "Mungaa",
    "lat": "-4.96667",
    "lng": "34.88333"
  },
  {
    "country": "TZ",
    "name": "Muleba",
    "lat": "-1.83972",
    "lng": "31.65444"
  },
  {
    "country": "TZ",
    "name": "Muheza",
    "lat": "-5.16667",
    "lng": "38.78333"
  },
  {
    "country": "TZ",
    "name": "Mugumu",
    "lat": "-1.85",
    "lng": "34.7"
  },
  {
    "country": "TZ",
    "name": "Mugango",
    "lat": "-1.68333",
    "lng": "33.7"
  },
  {
    "country": "TZ",
    "name": "Mtwango",
    "lat": "-9.01667",
    "lng": "34.8"
  },
  {
    "country": "TZ",
    "name": "Mto wa Mbu",
    "lat": "-3.35",
    "lng": "35.85"
  },
  {
    "country": "TZ",
    "name": "Mtinko",
    "lat": "-4.55",
    "lng": "34.85"
  },
  {
    "country": "TZ",
    "name": "Mtimbira",
    "lat": "-8.78333",
    "lng": "36.35"
  },
  {
    "country": "TZ",
    "name": "Mtambile",
    "lat": "-5.38333",
    "lng": "39.7"
  },
  {
    "country": "TZ",
    "name": "Msowero",
    "lat": "-6.53333",
    "lng": "37.2"
  },
  {
    "country": "TZ",
    "name": "Msanga",
    "lat": "-6.05",
    "lng": "36.03333"
  },
  {
    "country": "TZ",
    "name": "Mpwapwa",
    "lat": "-6.35",
    "lng": "36.48333"
  },
  {
    "country": "TZ",
    "name": "Mpanda",
    "lat": "-6.34379",
    "lng": "31.06951"
  },
  {
    "country": "TZ",
    "name": "Moshi",
    "lat": "-3.35",
    "lng": "37.33333"
  },
  {
    "country": "TZ",
    "name": "Morogoro",
    "lat": "-6.82102",
    "lng": "37.66122"
  },
  {
    "country": "TZ",
    "name": "Monduli",
    "lat": "-3.3",
    "lng": "36.45"
  },
  {
    "country": "TZ",
    "name": "Mlowo",
    "lat": "-9",
    "lng": "32.98333"
  },
  {
    "country": "TZ",
    "name": "Mlimba",
    "lat": "-8.8",
    "lng": "35.81667"
  },
  {
    "country": "TZ",
    "name": "Mlangali",
    "lat": "-9.78333",
    "lng": "34.51667"
  },
  {
    "country": "TZ",
    "name": "Mlandizi",
    "lat": "-6.7",
    "lng": "38.73333"
  },
  {
    "country": "TZ",
    "name": "Mlalo",
    "lat": "-4.93333",
    "lng": "38.93333"
  },
  {
    "country": "TZ",
    "name": "Mkuranga",
    "lat": "-7.11799",
    "lng": "39.20782"
  },
  {
    "country": "TZ",
    "name": "Mkokotoni",
    "lat": "-5.87506",
    "lng": "39.25523"
  },
  {
    "country": "TZ",
    "name": "Mwandiga",
    "lat": "-4.83",
    "lng": "29.65806"
  },
  {
    "country": "TZ",
    "name": "Misungwi",
    "lat": "-2.85",
    "lng": "33.08333"
  },
  {
    "country": "TZ",
    "name": "Misasi",
    "lat": "-3",
    "lng": "33.08333"
  },
  {
    "country": "TZ",
    "name": "Mikumi",
    "lat": "-7.40409",
    "lng": "36.98309"
  },
  {
    "country": "TZ",
    "name": "Micheweni",
    "lat": "-4.96667",
    "lng": "39.83333"
  },
  {
    "country": "TZ",
    "name": "Mhango",
    "lat": "-3.28333",
    "lng": "32.85"
  },
  {
    "country": "TZ",
    "name": "Mgandu",
    "lat": "-5.95",
    "lng": "34.13333"
  },
  {
    "country": "TZ",
    "name": "Mbumi",
    "lat": "-7.90577",
    "lng": "39.21047"
  },
  {
    "country": "TZ",
    "name": "Mbulu",
    "lat": "-3.85",
    "lng": "35.53333"
  },
  {
    "country": "TZ",
    "name": "Mbuguni",
    "lat": "-3.56667",
    "lng": "36.95"
  },
  {
    "country": "TZ",
    "name": "Mbeya",
    "lat": "-8.9",
    "lng": "33.45"
  },
  {
    "country": "TZ",
    "name": "Mazinde",
    "lat": "-4.8",
    "lng": "38.21667"
  },
  {
    "country": "TZ",
    "name": "Matui",
    "lat": "-4.8",
    "lng": "38.25"
  },
  {
    "country": "TZ",
    "name": "Matonga",
    "lat": "-2.38333",
    "lng": "34.08333"
  },
  {
    "country": "TZ",
    "name": "Matamba",
    "lat": "-8.98333",
    "lng": "33.96667"
  },
  {
    "country": "TZ",
    "name": "Matai",
    "lat": "-8.3",
    "lng": "31.51667"
  },
  {
    "country": "TZ",
    "name": "Maswa",
    "lat": "-2.68333",
    "lng": "33.98333"
  },
  {
    "country": "TZ",
    "name": "Masumbwe",
    "lat": "-3.63333",
    "lng": "32.18333"
  },
  {
    "country": "TZ",
    "name": "Masoko",
    "lat": "-9.33333",
    "lng": "33.75"
  },
  {
    "country": "TZ",
    "name": "Maramba",
    "lat": "-5.05",
    "lng": "38.61667"
  },
  {
    "country": "TZ",
    "name": "Maneromango",
    "lat": "-7.1988",
    "lng": "38.78478"
  },
  {
    "country": "TZ",
    "name": "Malya",
    "lat": "-2.98333",
    "lng": "33.51667"
  },
  {
    "country": "TZ",
    "name": "Malinyi",
    "lat": "-8.93333",
    "lng": "36.13333"
  },
  {
    "country": "TZ",
    "name": "Malangali",
    "lat": "-8.56667",
    "lng": "34.85"
  },
  {
    "country": "TZ",
    "name": "Malampaka",
    "lat": "-3.13333",
    "lng": "33.53333"
  },
  {
    "country": "TZ",
    "name": "Makuyuni",
    "lat": "-4.73333",
    "lng": "38.1"
  },
  {
    "country": "TZ",
    "name": "Makungu",
    "lat": "-8.73333",
    "lng": "35.28333"
  },
  {
    "country": "TZ",
    "name": "Makumbako",
    "lat": "-8.85",
    "lng": "34.83333"
  },
  {
    "country": "TZ",
    "name": "Makanya",
    "lat": "-4.36667",
    "lng": "37.83333"
  },
  {
    "country": "TZ",
    "name": "Majengo",
    "lat": "-5.15",
    "lng": "38.98333"
  },
  {
    "country": "TZ",
    "name": "Mahonda",
    "lat": "-6.45",
    "lng": "39.46667"
  },
  {
    "country": "TZ",
    "name": "Mahenge",
    "lat": "-8.68333",
    "lng": "36.71667"
  },
  {
    "country": "TZ",
    "name": "Mahanje",
    "lat": "-9.93333",
    "lng": "35.33333"
  },
  {
    "country": "TZ",
    "name": "Kihangara",
    "lat": "-2.58333",
    "lng": "33.35"
  },
  {
    "country": "TZ",
    "name": "Magugu",
    "lat": "-4.01667",
    "lng": "35.76667"
  },
  {
    "country": "TZ",
    "name": "Magomeni",
    "lat": "-6.8",
    "lng": "39.25"
  },
  {
    "country": "TZ",
    "name": "Magomeni",
    "lat": "-5.23333",
    "lng": "38.11667"
  },
  {
    "country": "TZ",
    "name": "Magole",
    "lat": "-6.37697",
    "lng": "37.37373"
  },
  {
    "country": "TZ",
    "name": "Mafinga",
    "lat": "-7.25",
    "lng": "35.06667"
  },
  {
    "country": "TZ",
    "name": "Mabamba",
    "lat": "-3.59833",
    "lng": "30.50194"
  },
  {
    "country": "TZ",
    "name": "Mabama",
    "lat": "-5.13333",
    "lng": "32.53333"
  },
  {
    "country": "TZ",
    "name": "Lushoto",
    "lat": "-4.78333",
    "lng": "38.28333"
  },
  {
    "country": "TZ",
    "name": "Lupiro",
    "lat": "-8.38333",
    "lng": "36.66667"
  },
  {
    "country": "TZ",
    "name": "Lugoba",
    "lat": "-6.45",
    "lng": "38.33333"
  },
  {
    "country": "TZ",
    "name": "Longido",
    "lat": "-2.73319",
    "lng": "36.69773"
  },
  {
    "country": "TZ",
    "name": "Liwale",
    "lat": "-9.76667",
    "lng": "37.93333"
  },
  {
    "country": "TZ",
    "name": "Lembeni",
    "lat": "-3.78333",
    "lng": "37.61667"
  },
  {
    "country": "TZ",
    "name": "Lalago",
    "lat": "-3.45",
    "lng": "33.95"
  },
  {
    "country": "TZ",
    "name": "Laela",
    "lat": "-8.56667",
    "lng": "32.05"
  },
  {
    "country": "TZ",
    "name": "Kyela",
    "lat": "-9.58333",
    "lng": "33.85"
  },
  {
    "country": "TZ",
    "name": "Kyaka",
    "lat": "-1.25222",
    "lng": "31.42028"
  },
  {
    "country": "TZ",
    "name": "Kwakoa",
    "lat": "-3.76667",
    "lng": "37.71667"
  },
  {
    "country": "TZ",
    "name": "Kongwa",
    "lat": "-6.2",
    "lng": "36.41667"
  },
  {
    "country": "TZ",
    "name": "Kondoa",
    "lat": "-4.9",
    "lng": "35.78333"
  },
  {
    "country": "TZ",
    "name": "Konde",
    "lat": "-4.95",
    "lng": "39.75"
  },
  {
    "country": "TZ",
    "name": "Koani Ndogo",
    "lat": "-6.13333",
    "lng": "39.28333"
  },
  {
    "country": "TZ",
    "name": "Koani",
    "lat": "-6.13333",
    "lng": "39.28333"
  },
  {
    "country": "TZ",
    "name": "Kiwira",
    "lat": "-9.17307",
    "lng": "33.54152"
  },
  {
    "country": "TZ",
    "name": "Kiwengwa",
    "lat": "-5.98957",
    "lng": "39.3768"
  },
  {
    "country": "TZ",
    "name": "Kisiwani",
    "lat": "-4.13333",
    "lng": "37.95"
  },
  {
    "country": "TZ",
    "name": "Kishapu",
    "lat": "-3.61667",
    "lng": "33.86667"
  },
  {
    "country": "TZ",
    "name": "Kisesa",
    "lat": "-3.08333",
    "lng": "34.15"
  },
  {
    "country": "TZ",
    "name": "Kisarawe",
    "lat": "-6.9",
    "lng": "39.06667"
  },
  {
    "country": "TZ",
    "name": "Kisanga",
    "lat": "-7.43622",
    "lng": "37.70337"
  },
  {
    "country": "TZ",
    "name": "Kirya",
    "lat": "-3.91667",
    "lng": "37.48333"
  },
  {
    "country": "TZ",
    "name": "Kirando",
    "lat": "-7.41667",
    "lng": "30.6"
  },
  {
    "country": "TZ",
    "name": "Kiomboi",
    "lat": "-4.26667",
    "lng": "34.36667"
  },
  {
    "country": "TZ",
    "name": "Kintinku",
    "lat": "-5.88333",
    "lng": "35.23333"
  },
  {
    "country": "TZ",
    "name": "Kingori",
    "lat": "-3.28333",
    "lng": "36.98333"
  },
  {
    "country": "TZ",
    "name": "Kimamba",
    "lat": "-6.78333",
    "lng": "37.13333"
  },
  {
    "country": "TZ",
    "name": "Kilosa",
    "lat": "-6.83333",
    "lng": "36.98333"
  },
  {
    "country": "TZ",
    "name": "Kilindoni",
    "lat": "-7.91446",
    "lng": "39.66204"
  },
  {
    "country": "TZ",
    "name": "Kilimatinde",
    "lat": "-5.85",
    "lng": "34.95"
  },
  {
    "country": "TZ",
    "name": "Kijini",
    "lat": "-5.85",
    "lng": "39.31667"
  },
  {
    "country": "TZ",
    "name": "Kihurio",
    "lat": "-4.46667",
    "lng": "38.06667"
  },
  {
    "country": "TZ",
    "name": "Kigoma",
    "lat": "-4.87694",
    "lng": "29.62667"
  },
  {
    "country": "TZ",
    "name": "Kidodi",
    "lat": "-7.60361",
    "lng": "37.00438"
  },
  {
    "country": "TZ",
    "name": "Kidatu",
    "lat": "-7.69916",
    "lng": "36.95722"
  },
  {
    "country": "TZ",
    "name": "Kibondo",
    "lat": "-3.58639",
    "lng": "30.72028"
  },
  {
    "country": "TZ",
    "name": "Kibiti",
    "lat": "-7.72178",
    "lng": "38.93749"
  },
  {
    "country": "TZ",
    "name": "Kibaya",
    "lat": "-5.3",
    "lng": "36.56667"
  },
  {
    "country": "TZ",
    "name": "Kibara",
    "lat": "-2.15",
    "lng": "33.45"
  },
  {
    "country": "TZ",
    "name": "Kibakwe",
    "lat": "-6.71667",
    "lng": "36.36667"
  },
  {
    "country": "TZ",
    "name": "Kibaha",
    "lat": "-6.76667",
    "lng": "38.91667"
  },
  {
    "country": "TZ",
    "name": "Katumba",
    "lat": "-9.23333",
    "lng": "33.61667"
  },
  {
    "country": "TZ",
    "name": "Katoro",
    "lat": "-3.02028",
    "lng": "31.89583"
  },
  {
    "country": "TZ",
    "name": "Katoro",
    "lat": "-1.39972",
    "lng": "31.50028"
  },
  {
    "country": "TZ",
    "name": "Katesh",
    "lat": "-4.52483",
    "lng": "35.3849"
  },
  {
    "country": "TZ",
    "name": "Katerero",
    "lat": "-1.4",
    "lng": "31.73333"
  },
  {
    "country": "TZ",
    "name": "Kasulu",
    "lat": "-4.57667",
    "lng": "30.1025"
  },
  {
    "country": "TZ",
    "name": "Kasamwa",
    "lat": "-2.85",
    "lng": "32.43333"
  },
  {
    "country": "TZ",
    "name": "Karema",
    "lat": "-6.82052",
    "lng": "30.43887"
  },
  {
    "country": "TZ",
    "name": "Kiratu",
    "lat": "-3.33333",
    "lng": "35.66667"
  },
  {
    "country": "TZ",
    "name": "Kandete",
    "lat": "-9.15",
    "lng": "33.8"
  },
  {
    "country": "TZ",
    "name": "Kamachumu",
    "lat": "-1.61861",
    "lng": "31.62"
  },
  {
    "country": "TZ",
    "name": "Kaliua",
    "lat": "-5.06056",
    "lng": "31.79361"
  },
  {
    "country": "TZ",
    "name": "Kakonko",
    "lat": "-3.28278",
    "lng": "30.96417"
  },
  {
    "country": "TZ",
    "name": "Kahama",
    "lat": "-3.83333",
    "lng": "32.6"
  },
  {
    "country": "TZ",
    "name": "Kabanga",
    "lat": "-2.63861",
    "lng": "30.46778"
  },
  {
    "country": "TZ",
    "name": "Izazi",
    "lat": "-7.2",
    "lng": "35.73333"
  },
  {
    "country": "TZ",
    "name": "Itumba",
    "lat": "-9.4",
    "lng": "33.18333"
  },
  {
    "country": "TZ",
    "name": "Itigi",
    "lat": "-5.7",
    "lng": "34.48333"
  },
  {
    "country": "TZ",
    "name": "Issenye",
    "lat": "-2",
    "lng": "34.33333"
  },
  {
    "country": "TZ",
    "name": "Isaka",
    "lat": "-3.9",
    "lng": "32.93333"
  },
  {
    "country": "TZ",
    "name": "Iringa",
    "lat": "-7.76667",
    "lng": "35.7"
  },
  {
    "country": "TZ",
    "name": "Ipinda",
    "lat": "-9.48333",
    "lng": "33.9"
  },
  {
    "country": "TZ",
    "name": "Inyonga",
    "lat": "-6.71667",
    "lng": "32.06667"
  },
  {
    "country": "TZ",
    "name": "Ilula",
    "lat": "-7.6766",
    "lng": "36.03658"
  },
  {
    "country": "TZ",
    "name": "Ilongero",
    "lat": "-4.66667",
    "lng": "34.86667"
  },
  {
    "country": "TZ",
    "name": "Ilembula",
    "lat": "-8.9",
    "lng": "34.58333"
  },
  {
    "country": "TZ",
    "name": "Ilembo",
    "lat": "-9.25",
    "lng": "33.38333"
  },
  {
    "country": "TZ",
    "name": "Ikwiriri",
    "lat": "-7.95618",
    "lng": "38.97164"
  },
  {
    "country": "TZ",
    "name": "Ikungi",
    "lat": "-5.13333",
    "lng": "34.76667"
  },
  {
    "country": "TZ",
    "name": "Igurusi",
    "lat": "-8.85",
    "lng": "33.85"
  },
  {
    "country": "TZ",
    "name": "Igurubi",
    "lat": "-4",
    "lng": "33.7"
  },
  {
    "country": "TZ",
    "name": "Igunga",
    "lat": "-4.28333",
    "lng": "33.88333"
  },
  {
    "country": "TZ",
    "name": "Igugunu",
    "lat": "-4.56667",
    "lng": "34.63333"
  },
  {
    "country": "TZ",
    "name": "Ifakara",
    "lat": "-8.13333",
    "lng": "36.68333"
  },
  {
    "country": "TZ",
    "name": "Hedaru",
    "lat": "-4.5",
    "lng": "37.9"
  },
  {
    "country": "TZ",
    "name": "Geita",
    "lat": "-2.8725",
    "lng": "32.2325"
  },
  {
    "country": "TZ",
    "name": "Geiro",
    "lat": "-6.15",
    "lng": "36.86667"
  },
  {
    "country": "TZ",
    "name": "Gamba",
    "lat": "-5.9",
    "lng": "39.3"
  },
  {
    "country": "TZ",
    "name": "Galappo",
    "lat": "-4.26667",
    "lng": "35.85"
  },
  {
    "country": "TZ",
    "name": "Endasak",
    "lat": "-4.41667",
    "lng": "35.51667"
  },
  {
    "country": "TZ",
    "name": "Dunda",
    "lat": "-8.11667",
    "lng": "34.25"
  },
  {
    "country": "TZ",
    "name": "Dongobesh",
    "lat": "-4.06667",
    "lng": "35.38333"
  },
  {
    "country": "TZ",
    "name": "Dodoma",
    "lat": "-6.17221",
    "lng": "35.73947"
  },
  {
    "country": "TZ",
    "name": "Dar es Salaam",
    "lat": "-6.82349",
    "lng": "39.26951"
  },
  {
    "country": "TZ",
    "name": "Dareda",
    "lat": "-4.21667",
    "lng": "35.55"
  },
  {
    "country": "TZ",
    "name": "Chimala",
    "lat": "-8.85637",
    "lng": "34.02393"
  },
  {
    "country": "TZ",
    "name": "Chato",
    "lat": "-2.63778",
    "lng": "31.76694"
  },
  {
    "country": "TZ",
    "name": "Chanika",
    "lat": "-5.41667",
    "lng": "38.01667"
  },
  {
    "country": "TZ",
    "name": "Chalinze",
    "lat": "-6.63784",
    "lng": "38.35396"
  },
  {
    "country": "TZ",
    "name": "Chala",
    "lat": "-7.58333",
    "lng": "31.26667"
  },
  {
    "country": "TZ",
    "name": "Chake Chake",
    "lat": "-5.24586",
    "lng": "39.76659"
  },
  {
    "country": "TZ",
    "name": "Butiama",
    "lat": "-1.76667",
    "lng": "33.96667"
  },
  {
    "country": "TZ",
    "name": "Buseresere",
    "lat": "-3.02361",
    "lng": "31.87472"
  },
  {
    "country": "TZ",
    "name": "Bungu",
    "lat": "-7.63369",
    "lng": "39.05818"
  },
  {
    "country": "TZ",
    "name": "Bunda",
    "lat": "-2.05",
    "lng": "33.86667"
  },
  {
    "country": "TZ",
    "name": "Bukonyo",
    "lat": "-1.95",
    "lng": "32.93333"
  },
  {
    "country": "TZ",
    "name": "Bukoba",
    "lat": "-1.33167",
    "lng": "31.81222"
  },
  {
    "country": "TZ",
    "name": "Bukene",
    "lat": "-4.23333",
    "lng": "32.88333"
  },
  {
    "country": "TZ",
    "name": "Bugene",
    "lat": "-1.59111",
    "lng": "31.14028"
  },
  {
    "country": "TZ",
    "name": "Bugarama",
    "lat": "-2.87056",
    "lng": "30.52806"
  },
  {
    "country": "TZ",
    "name": "Biharamulo",
    "lat": "-2.63194",
    "lng": "31.30889"
  },
  {
    "country": "TZ",
    "name": "Basotu",
    "lat": "-4.36667",
    "lng": "35.08333"
  },
  {
    "country": "TZ",
    "name": "Bashanet",
    "lat": "-4.23333",
    "lng": "35.41667"
  },
  {
    "country": "TZ",
    "name": "Bariadi",
    "lat": "-2.8",
    "lng": "33.98333"
  },
  {
    "country": "TZ",
    "name": "Bagamoyo",
    "lat": "-6.44222",
    "lng": "38.90422"
  },
  {
    "country": "TZ",
    "name": "Babati",
    "lat": "-4.21667",
    "lng": "35.75"
  },
  {
    "country": "TZ",
    "name": "Arusha",
    "lat": "-3.36667",
    "lng": "36.68333"
  },
  {
    "country": "TZ",
    "name": "Tingi",
    "lat": "-11.3",
    "lng": "35.03333"
  },
  {
    "country": "TZ",
    "name": "Tandahimba",
    "lat": "-10.75",
    "lng": "39.63333"
  },
  {
    "country": "TZ",
    "name": "Songea",
    "lat": "-10.68333",
    "lng": "35.65"
  },
  {
    "country": "TZ",
    "name": "Ruangwa",
    "lat": "-10.06667",
    "lng": "38.93333"
  },
  {
    "country": "TZ",
    "name": "Nyangao",
    "lat": "-10.33333",
    "lng": "39.28333"
  },
  {
    "country": "TZ",
    "name": "Newala Kisimani",
    "lat": "-10.95",
    "lng": "39.28333"
  },
  {
    "country": "TZ",
    "name": "Nanyamba",
    "lat": "-10.68333",
    "lng": "39.83333"
  },
  {
    "country": "TZ",
    "name": "Nanhyanga",
    "lat": "-10.8",
    "lng": "39.55"
  },
  {
    "country": "TZ",
    "name": "Nangomba",
    "lat": "-10.9",
    "lng": "38.5"
  },
  {
    "country": "TZ",
    "name": "Nanganga",
    "lat": "-10.38333",
    "lng": "39.15"
  },
  {
    "country": "TZ",
    "name": "Namikupa",
    "lat": "-10.83333",
    "lng": "39.6"
  },
  {
    "country": "TZ",
    "name": "Namalenga",
    "lat": "-10.95",
    "lng": "39.1"
  },
  {
    "country": "TZ",
    "name": "Nachingwea",
    "lat": "-10.3725",
    "lng": "38.76251"
  },
  {
    "country": "TZ",
    "name": "Mtwara",
    "lat": "-10.26667",
    "lng": "40.18333"
  },
  {
    "country": "TZ",
    "name": "Mtama",
    "lat": "-10.3",
    "lng": "39.36667"
  },
  {
    "country": "TZ",
    "name": "Mingoyo",
    "lat": "-10.10526",
    "lng": "39.61859"
  },
  {
    "country": "TZ",
    "name": "Mbinga",
    "lat": "-10.93333",
    "lng": "35.01667"
  },
  {
    "country": "TZ",
    "name": "Mbekenyera",
    "lat": "-10",
    "lng": "38.98333"
  },
  {
    "country": "TZ",
    "name": "Mbamba Bay",
    "lat": "-11.28333",
    "lng": "34.76667"
  },
  {
    "country": "TZ",
    "name": "Matiri",
    "lat": "-10.75",
    "lng": "34.9"
  },
  {
    "country": "TZ",
    "name": "Masuguru",
    "lat": "-11.36667",
    "lng": "38.41667"
  },
  {
    "country": "TZ",
    "name": "Masasi",
    "lat": "-10.71667",
    "lng": "38.8"
  },
  {
    "country": "TZ",
    "name": "Maposeni",
    "lat": "-10.58333",
    "lng": "35.4"
  },
  {
    "country": "TZ",
    "name": "Manda",
    "lat": "-10.46667",
    "lng": "34.58333"
  },
  {
    "country": "TZ",
    "name": "Mahuta",
    "lat": "-10.86667",
    "lng": "39.45"
  },
  {
    "country": "TZ",
    "name": "Madimba",
    "lat": "-10.4",
    "lng": "40.33333"
  },
  {
    "country": "TZ",
    "name": "Lulindi",
    "lat": "-10.81667",
    "lng": "39.13333"
  },
  {
    "country": "TZ",
    "name": "Lukuledi",
    "lat": "-10.56667",
    "lng": "38.8"
  },
  {
    "country": "TZ",
    "name": "Luchingu",
    "lat": "-10.9",
    "lng": "39.33333"
  },
  {
    "country": "TZ",
    "name": "Liuli",
    "lat": "-11.08333",
    "lng": "34.63333"
  },
  {
    "country": "TZ",
    "name": "Lindi",
    "lat": "-9.99709",
    "lng": "39.71649"
  },
  {
    "country": "TZ",
    "name": "Kitangari",
    "lat": "-10.65",
    "lng": "39.33333"
  },
  {
    "country": "TZ",
    "name": "Kitama",
    "lat": "-10.71667",
    "lng": "39.73333"
  },
  {
    "country": "TZ",
    "name": "Kigonsera",
    "lat": "-10.8",
    "lng": "35.05"
  },
  {
    "country": "TZ",
    "name": "Chiungutwa",
    "lat": "-10.88333",
    "lng": "38.98333"
  },
  {
    "country": "TZ",
    "name": "Merelani",
    "lat": "-3.56182",
    "lng": "36.97895"
  },
  {
    "country": "TZ",
    "name": "Nungwi",
    "lat": "-5.72651",
    "lng": "39.2987"
  },
  {
    "country": "TZ",
    "name": "Kisasa",
    "lat": "-6.17526",
    "lng": "35.79266"
  },
  {
    "country": "TZ",
    "name": "Mvomero",
    "lat": "-6.30122",
    "lng": "37.44398"
  },
  {
    "country": "UA",
    "name": "Olenevka",
    "lat": "45.38333",
    "lng": "32.53333"
  },
  {
    "country": "UA",
    "name": "Urzuf",
    "lat": "46.91562",
    "lng": "37.09961"
  },
  {
    "country": "UA",
    "name": "Lebedyn",
    "lat": "50.58518",
    "lng": "34.4849"
  },
  {
    "country": "UA",
    "name": "Staryy Dobrotvir",
    "lat": "50.23154",
    "lng": "24.37701"
  },
  {
    "country": "UA",
    "name": "Druzhkivka",
    "lat": "48.63013",
    "lng": "37.55259"
  },
  {
    "country": "UA",
    "name": "Zhydachiv",
    "lat": "49.38468",
    "lng": "24.14254"
  },
  {
    "country": "UA",
    "name": "Vasylivka",
    "lat": "47.43694",
    "lng": "35.27417"
  },
  {
    "country": "UA",
    "name": "Kovyl’noye",
    "lat": "45.69028",
    "lng": "33.52775"
  },
  {
    "country": "UA",
    "name": "Ivano-Frankove",
    "lat": "49.91978",
    "lng": "23.72913"
  },
  {
    "country": "UA",
    "name": "Zybiny",
    "lat": "45.23674",
    "lng": "34.64987"
  },
  {
    "country": "UA",
    "name": "Zvenihorodka",
    "lat": "49.07866",
    "lng": "30.96755"
  },
  {
    "country": "UA",
    "name": "Zuya",
    "lat": "45.05418",
    "lng": "34.32152"
  },
  {
    "country": "UA",
    "name": "Zuhres",
    "lat": "48.0114",
    "lng": "38.26444"
  },
  {
    "country": "UA",
    "name": "Zorkino",
    "lat": "45.54762",
    "lng": "34.71028"
  },
  {
    "country": "UA",
    "name": "Zoryns’k",
    "lat": "48.41194",
    "lng": "38.62361"
  },
  {
    "country": "UA",
    "name": "Zolotyy Potik",
    "lat": "48.9095",
    "lng": "25.33926"
  },
  {
    "country": "UA",
    "name": "Zolotoye Pole",
    "lat": "45.12774",
    "lng": "34.99148"
  },
  {
    "country": "UA",
    "name": "Zolotonosha",
    "lat": "49.66832",
    "lng": "32.04047"
  },
  {
    "country": "UA",
    "name": "Zolochiv",
    "lat": "50.27985",
    "lng": "35.98179"
  },
  {
    "country": "UA",
    "name": "Zolochiv",
    "lat": "49.80597",
    "lng": "24.89436"
  },
  {
    "country": "UA",
    "name": "Znomenka",
    "lat": "48.71278",
    "lng": "32.66472"
  },
  {
    "country": "UA",
    "name": "Zmiyiv",
    "lat": "49.67453",
    "lng": "36.34775"
  },
  {
    "country": "UA",
    "name": "Zlynka",
    "lat": "48.48521",
    "lng": "31.53906"
  },
  {
    "country": "UA",
    "name": "Zymohiria",
    "lat": "48.58528",
    "lng": "38.9375"
  },
  {
    "country": "UA",
    "name": "Zimino",
    "lat": "45.50797",
    "lng": "33.51431"
  },
  {
    "country": "UA",
    "name": "Zhytomyr",
    "lat": "50.26487",
    "lng": "28.67669"
  },
  {
    "country": "UA",
    "name": "Zhvanets",
    "lat": "48.54968",
    "lng": "26.48744"
  },
  {
    "country": "UA",
    "name": "Zhuravki",
    "lat": "45.12629",
    "lng": "35.21513"
  },
  {
    "country": "UA",
    "name": "Zhuravka",
    "lat": "50.48108",
    "lng": "32.5949"
  },
  {
    "country": "UA",
    "name": "Blahodatne",
    "lat": "50.66365",
    "lng": "24.24918"
  },
  {
    "country": "UA",
    "name": "Zhovkva",
    "lat": "50.05825",
    "lng": "23.9726"
  },
  {
    "country": "UA",
    "name": "Zhmerynka",
    "lat": "49.03705",
    "lng": "28.11201"
  },
  {
    "country": "UA",
    "name": "Zhemchuzhina",
    "lat": "45.27466",
    "lng": "34.65778"
  },
  {
    "country": "UA",
    "name": "Zhelyabovka",
    "lat": "45.39877",
    "lng": "34.75776"
  },
  {
    "country": "UA",
    "name": "Zhovti Vody",
    "lat": "48.34493",
    "lng": "33.50374"
  },
  {
    "country": "UA",
    "name": "Zhashkiv",
    "lat": "49.24545",
    "lng": "30.1102"
  },
  {
    "country": "UA",
    "name": "Zgurovka",
    "lat": "50.50276",
    "lng": "31.78492"
  },
  {
    "country": "UA",
    "name": "Zernovoye",
    "lat": "45.32364",
    "lng": "34.48099"
  },
  {
    "country": "UA",
    "name": "Zin’kiv",
    "lat": "50.20806",
    "lng": "34.36376"
  },
  {
    "country": "UA",
    "name": "Zemlyanichnoye",
    "lat": "44.97444",
    "lng": "34.83553"
  },
  {
    "country": "UA",
    "name": "Zelyonoye",
    "lat": "44.59583",
    "lng": "34.00921"
  },
  {
    "country": "UA",
    "name": "Zelenogorskoye",
    "lat": "45.01249",
    "lng": "34.46848"
  },
  {
    "country": "UA",
    "name": "Zdolbuniv",
    "lat": "50.5206",
    "lng": "26.24251"
  },
  {
    "country": "UA",
    "name": "Zdovbytsya",
    "lat": "50.49607",
    "lng": "26.24111"
  },
  {
    "country": "UA",
    "name": "Zboriv",
    "lat": "49.66484",
    "lng": "25.14097"
  },
  {
    "country": "UA",
    "name": "Zbarazh",
    "lat": "49.66357",
    "lng": "25.77616"
  },
  {
    "country": "UA",
    "name": "Zavetnoye",
    "lat": "45.32697",
    "lng": "34.80837"
  },
  {
    "country": "UA",
    "name": "Zavetnoye",
    "lat": "45.12305",
    "lng": "36.39965"
  },
  {
    "country": "UA",
    "name": "Zavet-Leninskiy",
    "lat": "45.86258",
    "lng": "34.3916"
  },
  {
    "country": "UA",
    "name": "Zavallya",
    "lat": "48.21354",
    "lng": "30.01558"
  },
  {
    "country": "UA",
    "name": "Karolino-Buhaz",
    "lat": "46.14492",
    "lng": "30.52609"
  },
  {
    "country": "UA",
    "name": "Zatoka",
    "lat": "46.07251",
    "lng": "30.46538"
  },
  {
    "country": "UA",
    "name": "Zatyshshya",
    "lat": "47.33351",
    "lng": "29.87327"
  },
  {
    "country": "UA",
    "name": "Zastavna",
    "lat": "48.52307",
    "lng": "25.84369"
  },
  {
    "country": "UA",
    "name": "Zorya",
    "lat": "45.9908",
    "lng": "29.69672"
  },
  {
    "country": "UA",
    "name": "Zarichchya",
    "lat": "48.52144",
    "lng": "24.64857"
  },
  {
    "country": "UA",
    "name": "Zarichne",
    "lat": "51.8126",
    "lng": "26.12902"
  },
  {
    "country": "UA",
    "name": "Zarechnoye",
    "lat": "45.73636",
    "lng": "34.48345"
  },
  {
    "country": "UA",
    "name": "Zarechnoye",
    "lat": "44.85048",
    "lng": "34.26426"
  },
  {
    "country": "UA",
    "name": "Zaporizhia",
    "lat": "47.82289",
    "lng": "35.19031"
  },
  {
    "country": "UA",
    "name": "Zaozyornoye",
    "lat": "45.15816",
    "lng": "33.27866"
  },
  {
    "country": "UA",
    "name": "Zaliztsi",
    "lat": "49.79188",
    "lng": "25.37297"
  },
  {
    "country": "UA",
    "name": "Zheleznyy Port",
    "lat": "46.11667",
    "lng": "32.28333"
  },
  {
    "country": "UA",
    "name": "Zaliznychne",
    "lat": "47.65238",
    "lng": "36.16524"
  },
  {
    "country": "UA",
    "name": "Zaliznychne",
    "lat": "45.7489",
    "lng": "28.61466"
  },
  {
    "country": "UA",
    "name": "Zalesnoye",
    "lat": "48.03104",
    "lng": "38.80934"
  },
  {
    "country": "UA",
    "name": "Zalishchyky",
    "lat": "48.64331",
    "lng": "25.73794"
  },
  {
    "country": "UA",
    "name": "Zakupne",
    "lat": "49.11944",
    "lng": "26.33756"
  },
  {
    "country": "UA",
    "name": "Zahvizdya",
    "lat": "48.91836",
    "lng": "24.65275"
  },
  {
    "country": "UA",
    "name": "Zagnitkiv",
    "lat": "48.04878",
    "lng": "28.89234"
  },
  {
    "country": "UA",
    "name": "Zachepylivka",
    "lat": "49.19385",
    "lng": "35.23943"
  },
  {
    "country": "UA",
    "name": "Zabolotiv",
    "lat": "48.47054",
    "lng": "25.28571"
  },
  {
    "country": "UA",
    "name": "Yuzhne",
    "lat": "46.62211",
    "lng": "31.10131"
  },
  {
    "country": "UA",
    "name": "Yur”yivka",
    "lat": "48.73748",
    "lng": "36.01987"
  },
  {
    "country": "UA",
    "name": "Yurkivka",
    "lat": "49.01082",
    "lng": "31.08797"
  },
  {
    "country": "UA",
    "name": "Yevpatoriya",
    "lat": "45.20091",
    "lng": "33.36655"
  },
  {
    "country": "UA",
    "name": "Yermakovo",
    "lat": "45.85364",
    "lng": "34.48644"
  },
  {
    "country": "UA",
    "name": "Yerky",
    "lat": "48.99062",
    "lng": "30.98818"
  },
  {
    "country": "UA",
    "name": "Yenakiyeve",
    "lat": "48.23331",
    "lng": "38.21137"
  },
  {
    "country": "UA",
    "name": "Yemil’chyne",
    "lat": "50.87349",
    "lng": "27.80604"
  },
  {
    "country": "UA",
    "name": "Yemelyanovka",
    "lat": "45.53287",
    "lng": "34.89624"
  },
  {
    "country": "UA",
    "name": "Yelyzavethradka",
    "lat": "48.80381",
    "lng": "32.4046"
  },
  {
    "country": "UA",
    "name": "Yelanets’",
    "lat": "47.69682",
    "lng": "31.85253"
  },
  {
    "country": "UA",
    "name": "Yavoriv",
    "lat": "49.93864",
    "lng": "23.38254"
  },
  {
    "country": "UA",
    "name": "Yats’kivka",
    "lat": "49.17996",
    "lng": "37.52379"
  },
  {
    "country": "UA",
    "name": "L’govskoye",
    "lat": "45.09801",
    "lng": "34.9577"
  },
  {
    "country": "UA",
    "name": "Yasinya",
    "lat": "48.27937",
    "lng": "24.36042"
  },
  {
    "country": "UA",
    "name": "Yasynuvata",
    "lat": "48.1298",
    "lng": "37.8594"
  },
  {
    "country": "UA",
    "name": "Yarmolyntsi",
    "lat": "49.19236",
    "lng": "26.83725"
  },
  {
    "country": "UA",
    "name": "Yarkoye Pole",
    "lat": "45.61293",
    "lng": "34.31834"
  },
  {
    "country": "UA",
    "name": "Yarkoye",
    "lat": "45.6912",
    "lng": "34.26323"
  },
  {
    "country": "UA",
    "name": "Yaremche",
    "lat": "48.45157",
    "lng": "24.55436"
  },
  {
    "country": "UA",
    "name": "Yampil’",
    "lat": "51.94765",
    "lng": "33.78759"
  },
  {
    "country": "UA",
    "name": "Yampil’",
    "lat": "48.93555",
    "lng": "37.95634"
  },
  {
    "country": "UA",
    "name": "Yampil’",
    "lat": "48.2424",
    "lng": "28.28195"
  },
  {
    "country": "UA",
    "name": "Yamnytsya",
    "lat": "48.98972",
    "lng": "24.7075"
  },
  {
    "country": "UA",
    "name": "Yalta",
    "lat": "46.96279",
    "lng": "37.27365"
  },
  {
    "country": "UA",
    "name": "Yalta",
    "lat": "44.50218",
    "lng": "34.16624"
  },
  {
    "country": "UA",
    "name": "Yahotyn",
    "lat": "50.27975",
    "lng": "31.76246"
  },
  {
    "country": "UA",
    "name": "Yahil’nytsya",
    "lat": "48.94248",
    "lng": "25.74375"
  },
  {
    "country": "UA",
    "name": "Yabluniv",
    "lat": "48.40418",
    "lng": "24.93874"
  },
  {
    "country": "UA",
    "name": "Yablunytsya",
    "lat": "48.31742",
    "lng": "24.48448"
  },
  {
    "country": "UA",
    "name": "Vyshchetarasivka",
    "lat": "47.56851",
    "lng": "34.88096"
  },
  {
    "country": "UA",
    "name": "Vysokopillya",
    "lat": "47.49187",
    "lng": "33.53061"
  },
  {
    "country": "UA",
    "name": "Vysokyy",
    "lat": "49.89156",
    "lng": "36.12175"
  },
  {
    "country": "UA",
    "name": "Vyshkovo",
    "lat": "48.04911",
    "lng": "23.42113"
  },
  {
    "country": "UA",
    "name": "Vyshhorod",
    "lat": "50.58476",
    "lng": "30.4898"
  },
  {
    "country": "UA",
    "name": "Dneprovka",
    "lat": "45.71373",
    "lng": "34.36256"
  },
  {
    "country": "UA",
    "name": "Vynohradiv",
    "lat": "48.14135",
    "lng": "23.02666"
  },
  {
    "country": "UA",
    "name": "Vylok",
    "lat": "48.10915",
    "lng": "22.83865"
  },
  {
    "country": "UA",
    "name": "Vylkove",
    "lat": "45.40214",
    "lng": "29.58595"
  },
  {
    "country": "UA",
    "name": "Vvedenka",
    "lat": "49.82372",
    "lng": "36.50264"
  },
  {
    "country": "UA",
    "name": "Vradiyivka",
    "lat": "47.86195",
    "lng": "30.59195"
  },
  {
    "country": "UA",
    "name": "Voznesensk",
    "lat": "47.56494",
    "lng": "31.33078"
  },
  {
    "country": "UA",
    "name": "Voznesenka",
    "lat": "46.87165",
    "lng": "35.46458"
  },
  {
    "country": "UA",
    "name": "Voyutychi",
    "lat": "49.55135",
    "lng": "23.10579"
  },
  {
    "country": "UA",
    "name": "Voykovo",
    "lat": "45.51222",
    "lng": "33.87482"
  },
  {
    "country": "UA",
    "name": "Voykovo",
    "lat": "45.38329",
    "lng": "36.43739"
  },
  {
    "country": "UA",
    "name": "Vorzel’",
    "lat": "50.5444",
    "lng": "30.15305"
  },
  {
    "country": "UA",
    "name": "Vorozhba",
    "lat": "51.17334",
    "lng": "34.21917"
  },
  {
    "country": "UA",
    "name": "Voronovytsya",
    "lat": "49.10954",
    "lng": "28.68078"
  },
  {
    "country": "UA",
    "name": "Voronkov",
    "lat": "50.22235",
    "lng": "30.89967"
  },
  {
    "country": "UA",
    "name": "Vorokhta",
    "lat": "48.28459",
    "lng": "24.56536"
  },
  {
    "country": "UA",
    "name": "Vorobyovo",
    "lat": "45.32895",
    "lng": "33.24654"
  },
  {
    "country": "UA",
    "name": "Volovets",
    "lat": "48.7109",
    "lng": "23.1851"
  },
  {
    "country": "UA",
    "name": "Voloka",
    "lat": "48.19225",
    "lng": "25.93074"
  },
  {
    "country": "UA",
    "name": "Khoroshiv",
    "lat": "50.59764",
    "lng": "28.443"
  },
  {
    "country": "UA",
    "name": "Nikol's’ke",
    "lat": "47.20533",
    "lng": "37.32139"
  },
  {
    "country": "UA",
    "name": "Volodarka",
    "lat": "49.52484",
    "lng": "29.91222"
  },
  {
    "country": "UA",
    "name": "Volochysk",
    "lat": "49.53748",
    "lng": "26.21568"
  },
  {
    "country": "UA",
    "name": "Vil’ne",
    "lat": "47.63645",
    "lng": "34.81387"
  },
  {
    "country": "UA",
    "name": "Volnovakha",
    "lat": "47.60103",
    "lng": "37.49674"
  },
  {
    "country": "UA",
    "name": "Vovchans’k",
    "lat": "50.29078",
    "lng": "36.94108"
  },
  {
    "country": "UA",
    "name": "Voinka",
    "lat": "45.8699",
    "lng": "33.99138"
  },
  {
    "country": "UA",
    "name": "Vodyane",
    "lat": "47.48746",
    "lng": "34.49235"
  },
  {
    "country": "UA",
    "name": "Vladislavovka",
    "lat": "45.16828",
    "lng": "35.37658"
  },
  {
    "country": "UA",
    "name": "Volodymyr-Volynskyi",
    "lat": "50.85253",
    "lng": "24.32364"
  },
  {
    "country": "UA",
    "name": "Volodymyrets’",
    "lat": "51.4213",
    "lng": "26.14469"
  },
  {
    "country": "UA",
    "name": "Vyzhnytsya",
    "lat": "48.24801",
    "lng": "25.19452"
  },
  {
    "country": "UA",
    "name": "Vyshneve",
    "lat": "50.38913",
    "lng": "30.3705"
  },
  {
    "country": "UA",
    "name": "Vyshneve",
    "lat": "48.43611",
    "lng": "33.91556"
  },
  {
    "country": "UA",
    "name": "Vishennoye",
    "lat": "45.14509",
    "lng": "34.59691"
  },
  {
    "country": "UA",
    "name": "Vishnyovka",
    "lat": "45.95966",
    "lng": "33.95289"
  },
  {
    "country": "UA",
    "name": "Vynohradove",
    "lat": "46.36957",
    "lng": "32.9398"
  },
  {
    "country": "UA",
    "name": "Vinogradovo",
    "lat": "45.39264",
    "lng": "33.64668"
  },
  {
    "country": "UA",
    "name": "Vynohradivka",
    "lat": "45.68119",
    "lng": "28.57138"
  },
  {
    "country": "UA",
    "name": "Vinogradnoye",
    "lat": "45.29332",
    "lng": "35.84451"
  },
  {
    "country": "UA",
    "name": "Vinogradnoye",
    "lat": "44.48149",
    "lng": "34.12973"
  },
  {
    "country": "UA",
    "name": "Vinnytsia",
    "lat": "49.23278",
    "lng": "28.48097"
  },
  {
    "country": "UA",
    "name": "Vinkivtsi",
    "lat": "49.03462",
    "lng": "27.23617"
  },
  {
    "country": "UA",
    "name": "Vil’nyans’k",
    "lat": "47.94381",
    "lng": "35.43539"
  },
  {
    "country": "UA",
    "name": "Vilino",
    "lat": "44.8456",
    "lng": "33.67161"
  },
  {
    "country": "UA",
    "name": "Veselynove",
    "lat": "47.35666",
    "lng": "31.23488"
  },
  {
    "country": "UA",
    "name": "Vesele",
    "lat": "47.01479",
    "lng": "34.91504"
  },
  {
    "country": "UA",
    "name": "Vesele",
    "lat": "44.85807",
    "lng": "34.87952"
  },
  {
    "country": "UA",
    "name": "Veselovka",
    "lat": "45.37733",
    "lng": "33.21385"
  },
  {
    "country": "UA",
    "name": "Verkhovyna",
    "lat": "48.15571",
    "lng": "24.79112"
  },
  {
    "country": "UA",
    "name": "Verkhorechye",
    "lat": "44.69738",
    "lng": "33.98696"
  },
  {
    "country": "UA",
    "name": "Verkhnya Syrovatka",
    "lat": "50.82902",
    "lng": "34.95861"
  },
  {
    "country": "UA",
    "name": "Verchnia Rozhanka",
    "lat": "48.7805",
    "lng": "23.51545"
  },
  {
    "country": "UA",
    "name": "Verkhnyaya Belka",
    "lat": "49.81575",
    "lng": "24.30328"
  },
  {
    "country": "UA",
    "name": "Verkhniachka",
    "lat": "48.82849",
    "lng": "30.03957"
  },
  {
    "country": "UA",
    "name": "Verkhniy Yasenov",
    "lat": "48.16156",
    "lng": "24.94532"
  },
  {
    "country": "UA",
    "name": "Verkhniy Rohachyk",
    "lat": "47.25053",
    "lng": "34.33797"
  },
  {
    "country": "UA",
    "name": "Verkhnie Synevydne",
    "lat": "49.10307",
    "lng": "23.59099"
  },
  {
    "country": "UA",
    "name": "Verkhnesadovoye",
    "lat": "44.68932",
    "lng": "33.70207"
  },
  {
    "country": "UA",
    "name": "Verkhn’odniprovs’k",
    "lat": "48.65242",
    "lng": "34.33457"
  },
  {
    "country": "UA",
    "name": "Veresayevo",
    "lat": "45.30551",
    "lng": "33.50004"
  },
  {
    "country": "UA",
    "name": "Verenchanka",
    "lat": "48.54653",
    "lng": "25.74533"
  },
  {
    "country": "UA",
    "name": "Verblyany",
    "lat": "50.04747",
    "lng": "23.42189"
  },
  {
    "country": "UA",
    "name": "Verbivka",
    "lat": "49.41667",
    "lng": "35.53333"
  },
  {
    "country": "UA",
    "name": "Vendychany",
    "lat": "48.61176",
    "lng": "27.79324"
  },
  {
    "country": "UA",
    "name": "Velykoploske",
    "lat": "47.01254",
    "lng": "29.67171"
  },
  {
    "country": "UA",
    "name": "Velyka Mykhaylivka",
    "lat": "47.07971",
    "lng": "29.85753"
  },
  {
    "country": "UA",
    "name": "Velykyy Klyuchiv",
    "lat": "48.47092",
    "lng": "24.94677"
  },
  {
    "country": "UA",
    "name": "Velyki Sorochyntsi",
    "lat": "50.02314",
    "lng": "33.94144"
  },
  {
    "country": "UA",
    "name": "Velyki Kopani",
    "lat": "46.48684",
    "lng": "32.97498"
  },
  {
    "country": "UA",
    "name": "Velikiye Borki",
    "lat": "49.52363",
    "lng": "25.75753"
  },
  {
    "country": "UA",
    "name": "Velykyy Burluk",
    "lat": "50.0617",
    "lng": "37.38373"
  },
  {
    "country": "UA",
    "name": "Velykyi Bereznyi",
    "lat": "48.88831",
    "lng": "22.46052"
  },
  {
    "country": "UA",
    "name": "Velyka Pysarivka",
    "lat": "50.4243",
    "lng": "35.47989"
  },
  {
    "country": "UA",
    "name": "Velyka Novosilka",
    "lat": "47.84531",
    "lng": "36.83534"
  },
  {
    "country": "UA",
    "name": "Velyka Lepetykha",
    "lat": "47.17572",
    "lng": "33.94362"
  },
  {
    "country": "UA",
    "name": "Velyka Dymerka",
    "lat": "50.59333",
    "lng": "30.90313"
  },
  {
    "country": "UA",
    "name": "Velyka Bilozerka",
    "lat": "47.27756",
    "lng": "34.70616"
  },
  {
    "country": "UA",
    "name": "Velyka Bahachka",
    "lat": "49.79116",
    "lng": "33.72258"
  },
  {
    "country": "UA",
    "name": "Velyka Oleksandrivka",
    "lat": "47.31969",
    "lng": "33.30373"
  },
  {
    "country": "UA",
    "name": "Vatutine",
    "lat": "49.01502",
    "lng": "31.06211"
  },
  {
    "country": "UA",
    "name": "Vasyshcheve",
    "lat": "49.82852",
    "lng": "36.32691"
  },
  {
    "country": "UA",
    "name": "Vasilyevka",
    "lat": "45.13938",
    "lng": "34.72291"
  },
  {
    "country": "UA",
    "name": "Vasyl’kivka",
    "lat": "48.20698",
    "lng": "36.02365"
  },
  {
    "country": "UA",
    "name": "Vasylkiv",
    "lat": "50.18693",
    "lng": "30.31346"
  },
  {
    "country": "UA",
    "name": "Vashkivtsi",
    "lat": "48.38491",
    "lng": "25.51023"
  },
  {
    "country": "UA",
    "name": "Vary",
    "lat": "48.12207",
    "lng": "22.71281"
  },
  {
    "country": "UA",
    "name": "Varvarivka",
    "lat": "49.53786",
    "lng": "35.20086"
  },
  {
    "country": "UA",
    "name": "Varva",
    "lat": "50.49503",
    "lng": "32.71968"
  },
  {
    "country": "UA",
    "name": "Vapnyarka",
    "lat": "48.53479",
    "lng": "28.74358"
  },
  {
    "country": "UA",
    "name": "Valky",
    "lat": "49.83597",
    "lng": "35.61223"
  },
  {
    "country": "UA",
    "name": "Batiovo",
    "lat": "48.36166",
    "lng": "22.3997"
  },
  {
    "country": "UA",
    "name": "Uzyn",
    "lat": "49.82619",
    "lng": "30.41487"
  },
  {
    "country": "UA",
    "name": "Uzhgorod",
    "lat": "48.61667",
    "lng": "22.3"
  },
  {
    "country": "UA",
    "name": "Uyutnoye",
    "lat": "45.19769",
    "lng": "33.29796"
  },
  {
    "country": "UA",
    "name": "Uvarovo",
    "lat": "45.2626",
    "lng": "35.66506"
  },
  {
    "country": "UA",
    "name": "Utkivka",
    "lat": "49.78583",
    "lng": "36.07528"
  },
  {
    "country": "UA",
    "name": "Ustynivka",
    "lat": "47.95507",
    "lng": "32.53674"
  },
  {
    "country": "UA",
    "name": "Uspenka",
    "lat": "48.39077",
    "lng": "39.16284"
  },
  {
    "country": "UA",
    "name": "Usatove",
    "lat": "46.53296",
    "lng": "30.6596"
  },
  {
    "country": "UA",
    "name": "Urozhaynoye",
    "lat": "45.33625",
    "lng": "35.06865"
  },
  {
    "country": "UA",
    "name": "Uralo-Kavkaz",
    "lat": "48.3211",
    "lng": "39.80302"
  },
  {
    "country": "UA",
    "name": "Nyzhni Petrivtsi",
    "lat": "48.02847",
    "lng": "25.72327"
  },
  {
    "country": "UA",
    "name": "Uman",
    "lat": "48.74838",
    "lng": "30.22184"
  },
  {
    "country": "UA",
    "name": "Blahovishchens’ke",
    "lat": "48.33105",
    "lng": "30.22702"
  },
  {
    "country": "UA",
    "name": "Ulychne",
    "lat": "49.23385",
    "lng": "23.65111"
  },
  {
    "country": "UA",
    "name": "Ulaniv",
    "lat": "49.69512",
    "lng": "28.13298"
  },
  {
    "country": "UA",
    "name": "Ukromnoye",
    "lat": "45.04272",
    "lng": "34.00312"
  },
  {
    "country": "UA",
    "name": "Ukrainka",
    "lat": "50.14317",
    "lng": "30.74612"
  },
  {
    "country": "UA",
    "name": "Ukrainka",
    "lat": "44.8873",
    "lng": "34.13973"
  },
  {
    "country": "UA",
    "name": "Uhryniv",
    "lat": "48.9552",
    "lng": "24.69292"
  },
  {
    "country": "UA",
    "name": "Uhniv",
    "lat": "50.36811",
    "lng": "23.74895"
  },
  {
    "country": "UA",
    "name": "Uglovoye",
    "lat": "44.82146",
    "lng": "33.60452"
  },
  {
    "country": "UA",
    "name": "Vuhlehirs’k",
    "lat": "48.31474",
    "lng": "38.27423"
  },
  {
    "country": "UA",
    "name": "Tyvriv",
    "lat": "49.01404",
    "lng": "28.50846"
  },
  {
    "country": "UA",
    "name": "Tysmenytsya",
    "lat": "48.90219",
    "lng": "24.84482"
  },
  {
    "country": "UA",
    "name": "Tysmenychany",
    "lat": "48.77168",
    "lng": "24.66626"
  },
  {
    "country": "UA",
    "name": "Tynne",
    "lat": "50.60145",
    "lng": "26.18486"
  },
  {
    "country": "UA",
    "name": "Tyachiv",
    "lat": "48.01179",
    "lng": "23.57061"
  },
  {
    "country": "UA",
    "name": "Turka",
    "lat": "49.15411",
    "lng": "23.02967"
  },
  {
    "country": "UA",
    "name": "Turiys’k",
    "lat": "51.08644",
    "lng": "24.52294"
  },
  {
    "country": "UA",
    "name": "Turgenevka",
    "lat": "44.69747",
    "lng": "33.83007"
  },
  {
    "country": "UA",
    "name": "Turbiv",
    "lat": "49.34788",
    "lng": "28.72117"
  },
  {
    "country": "UA",
    "name": "Tulchyn",
    "lat": "48.67448",
    "lng": "28.84641"
  },
  {
    "country": "UA",
    "name": "Tukhlia",
    "lat": "48.91218",
    "lng": "23.47303"
  },
  {
    "country": "UA",
    "name": "Tsyurupyns’k",
    "lat": "46.61842",
    "lng": "32.7189"
  },
  {
    "country": "UA",
    "name": "Tsybulevka",
    "lat": "48.38719",
    "lng": "29.10288"
  },
  {
    "country": "UA",
    "name": "Tsybli",
    "lat": "49.99484",
    "lng": "31.56281"
  },
  {
    "country": "UA",
    "name": "Tsvetochnoye",
    "lat": "45.08655",
    "lng": "34.38521"
  },
  {
    "country": "UA",
    "name": "Tsvetkovo",
    "lat": "49.15231",
    "lng": "31.53739"
  },
  {
    "country": "UA",
    "name": "Tsibulev",
    "lat": "49.07907",
    "lng": "29.84727"
  },
  {
    "country": "UA",
    "name": "Tselinnoye",
    "lat": "45.90633",
    "lng": "34.18063"
  },
  {
    "country": "UA",
    "name": "Tsarychanka",
    "lat": "48.93697",
    "lng": "34.4786"
  },
  {
    "country": "UA",
    "name": "Truskavets’",
    "lat": "49.27837",
    "lng": "23.50618"
  },
  {
    "country": "UA",
    "name": "Trostyanets’",
    "lat": "50.48478",
    "lng": "34.96567"
  },
  {
    "country": "UA",
    "name": "Trostyanets’",
    "lat": "48.50961",
    "lng": "29.23482"
  },
  {
    "country": "UA",
    "name": "Troyits’ke",
    "lat": "49.9145",
    "lng": "38.29277"
  },
  {
    "country": "UA",
    "name": "Trypillia",
    "lat": "50.11802",
    "lng": "30.78141"
  },
  {
    "country": "UA",
    "name": "Tr’okhizbenka",
    "lat": "48.75751",
    "lng": "38.96333"
  },
  {
    "country": "UA",
    "name": "Trebukhiv",
    "lat": "50.48432",
    "lng": "30.90304"
  },
  {
    "country": "UA",
    "name": "Toshkivka",
    "lat": "48.77914",
    "lng": "38.57903"
  },
  {
    "country": "UA",
    "name": "Torkanivka",
    "lat": "48.32462",
    "lng": "29.14746"
  },
  {
    "country": "UA",
    "name": "Chystyakove",
    "lat": "48.03876",
    "lng": "38.59685"
  },
  {
    "country": "UA",
    "name": "Topory",
    "lat": "49.65186",
    "lng": "29.31741"
  },
  {
    "country": "UA",
    "name": "Tomashpil’",
    "lat": "48.54256",
    "lng": "28.51684"
  },
  {
    "country": "UA",
    "name": "Tomakivka",
    "lat": "47.81569",
    "lng": "34.74137"
  },
  {
    "country": "UA",
    "name": "Tovste",
    "lat": "48.84663",
    "lng": "25.72621"
  },
  {
    "country": "UA",
    "name": "Tokmak",
    "lat": "47.25522",
    "lng": "35.71238"
  },
  {
    "country": "UA",
    "name": "Tokarevo",
    "lat": "45.28367",
    "lng": "35.15244"
  },
  {
    "country": "UA",
    "name": "Tlumach",
    "lat": "48.86403",
    "lng": "25.00325"
  },
  {
    "country": "UA",
    "name": "Tyshkivka",
    "lat": "48.49665",
    "lng": "30.94229"
  },
  {
    "country": "UA",
    "name": "Tymoshivka",
    "lat": "47.1841",
    "lng": "35.11625"
  },
  {
    "country": "UA",
    "name": "Tetiiv",
    "lat": "49.3767",
    "lng": "29.66474"
  },
  {
    "country": "UA",
    "name": "Terpinnya",
    "lat": "46.96942",
    "lng": "35.421"
  },
  {
    "country": "UA",
    "name": "Terny",
    "lat": "50.98916",
    "lng": "33.9707"
  },
  {
    "country": "UA",
    "name": "Terny",
    "lat": "49.09226",
    "lng": "37.96081"
  },
  {
    "country": "UA",
    "name": "Ternovka",
    "lat": "44.57922",
    "lng": "33.75105"
  },
  {
    "country": "UA",
    "name": "Ternuvate",
    "lat": "47.83049",
    "lng": "36.12761"
  },
  {
    "country": "UA",
    "name": "Ternopil",
    "lat": "49.55342",
    "lng": "25.58918"
  },
  {
    "country": "UA",
    "name": "Terebovlya",
    "lat": "49.30187",
    "lng": "25.70997"
  },
  {
    "country": "UA",
    "name": "Teplovka",
    "lat": "45.03239",
    "lng": "33.69588"
  },
  {
    "country": "UA",
    "name": "Teplyk",
    "lat": "48.66566",
    "lng": "29.74504"
  },
  {
    "country": "UA",
    "name": "Teofipol",
    "lat": "49.83818",
    "lng": "26.41433"
  },
  {
    "country": "UA",
    "name": "Maslovo",
    "lat": "45.79197",
    "lng": "34.36298"
  },
  {
    "country": "UA",
    "name": "Tenistoye",
    "lat": "44.74303",
    "lng": "33.66812"
  },
  {
    "country": "UA",
    "name": "Boykivske",
    "lat": "47.40994",
    "lng": "38.02476"
  },
  {
    "country": "UA",
    "name": "Tatarbunary",
    "lat": "45.83731",
    "lng": "29.61424"
  },
  {
    "country": "UA",
    "name": "Klepinino",
    "lat": "45.528",
    "lng": "34.18315"
  },
  {
    "country": "UA",
    "name": "Tarutyne",
    "lat": "46.18636",
    "lng": "29.15203"
  },
  {
    "country": "UA",
    "name": "Tarashcha",
    "lat": "49.55832",
    "lng": "30.49259"
  },
  {
    "country": "UA",
    "name": "Tarakaniv",
    "lat": "50.37961",
    "lng": "25.70843"
  },
  {
    "country": "UA",
    "name": "Tankovoye",
    "lat": "44.65829",
    "lng": "33.80929"
  },
  {
    "country": "UA",
    "name": "Sary-Bash",
    "lat": "45.57142",
    "lng": "33.78728"
  },
  {
    "country": "UA",
    "name": "Talne",
    "lat": "48.88877",
    "lng": "30.69482"
  },
  {
    "country": "UA",
    "name": "Talalayivka",
    "lat": "50.95783",
    "lng": "31.92085"
  },
  {
    "country": "UA",
    "name": "Talalayivka",
    "lat": "50.83913",
    "lng": "33.14374"
  },
  {
    "country": "UA",
    "name": "Tabachnoye",
    "lat": "45.61257",
    "lng": "34.61497"
  },
  {
    "country": "UA",
    "name": "Tabachnoye",
    "lat": "44.90175",
    "lng": "33.67638"
  },
  {
    "country": "UA",
    "name": "Syevyerodonets’k",
    "lat": "48.94832",
    "lng": "38.49166"
  },
  {
    "country": "UA",
    "name": "Svyatogorsk",
    "lat": "49.03333",
    "lng": "37.56667"
  },
  {
    "country": "UA",
    "name": "Svityaz’",
    "lat": "51.48211",
    "lng": "23.85904"
  },
  {
    "country": "UA",
    "name": "Svetloye",
    "lat": "45.6332",
    "lng": "34.66264"
  },
  {
    "country": "UA",
    "name": "Svitlovods’k",
    "lat": "49.04894",
    "lng": "33.24106"
  },
  {
    "country": "UA",
    "name": "Svetlodarsk",
    "lat": "48.43374",
    "lng": "38.22331"
  },
  {
    "country": "UA",
    "name": "Sverdlovs’k",
    "lat": "48.08964",
    "lng": "39.65243"
  },
  {
    "country": "UA",
    "name": "Svatove",
    "lat": "49.41029",
    "lng": "38.15035"
  },
  {
    "country": "UA",
    "name": "Svarychiv",
    "lat": "48.9622",
    "lng": "24.19658"
  },
  {
    "country": "UA",
    "name": "Svalyava",
    "lat": "48.54853",
    "lng": "22.99578"
  },
  {
    "country": "UA",
    "name": "Suvorovskoye",
    "lat": "45.25171",
    "lng": "33.37194"
  },
  {
    "country": "UA",
    "name": "Sutysky",
    "lat": "49.04245",
    "lng": "28.41733"
  },
  {
    "country": "UA",
    "name": "Susanino",
    "lat": "45.49898",
    "lng": "33.69854"
  },
  {
    "country": "UA",
    "name": "Surs’ko-Mykhaylivka",
    "lat": "48.27202",
    "lng": "34.72759"
  },
  {
    "country": "UA",
    "name": "Sumy",
    "lat": "50.9216",
    "lng": "34.80029"
  },
  {
    "country": "UA",
    "name": "Sukhovolya",
    "lat": "49.82426",
    "lng": "23.8377"
  },
  {
    "country": "UA",
    "name": "Sudova Vyshnya",
    "lat": "49.78892",
    "lng": "23.37218"
  },
  {
    "country": "UA",
    "name": "Sudak",
    "lat": "44.84924",
    "lng": "34.97471"
  },
  {
    "country": "UA",
    "name": "Subottsi",
    "lat": "48.65545",
    "lng": "32.52093"
  },
  {
    "country": "UA",
    "name": "Studenok",
    "lat": "49.09107",
    "lng": "37.48697"
  },
  {
    "country": "UA",
    "name": "Stryi",
    "lat": "49.26223",
    "lng": "23.85609"
  },
  {
    "country": "UA",
    "name": "Strogonovka",
    "lat": "44.9497",
    "lng": "34.17924"
  },
  {
    "country": "UA",
    "name": "Strabychovo",
    "lat": "48.39247",
    "lng": "22.54308"
  },
  {
    "country": "UA",
    "name": "Stizhkivs’ke",
    "lat": "48.11333",
    "lng": "38.4925"
  },
  {
    "country": "UA",
    "name": "Storozhnytsya",
    "lat": "48.60403",
    "lng": "22.23269"
  },
  {
    "country": "UA",
    "name": "Storozhynets’",
    "lat": "48.1643",
    "lng": "25.72029"
  },
  {
    "country": "UA",
    "name": "Stolbovoye",
    "lat": "45.3627",
    "lng": "33.49584"
  },
  {
    "country": "UA",
    "name": "Stetseva",
    "lat": "48.52767",
    "lng": "25.57572"
  },
  {
    "country": "UA",
    "name": "Botanicheskoye",
    "lat": "45.78656",
    "lng": "33.54856"
  },
  {
    "country": "UA",
    "name": "Stepnoye",
    "lat": "45.65212",
    "lng": "33.77441"
  },
  {
    "country": "UA",
    "name": "Stepanivka",
    "lat": "46.79489",
    "lng": "29.98684"
  },
  {
    "country": "UA",
    "name": "Stebnyk",
    "lat": "49.29416",
    "lng": "23.56357"
  },
  {
    "country": "UA",
    "name": "Steblëv",
    "lat": "49.40186",
    "lng": "31.09764"
  },
  {
    "country": "UA",
    "name": "Stayki",
    "lat": "50.07818",
    "lng": "30.9038"
  },
  {
    "country": "UA",
    "name": "Stavyshche",
    "lat": "50.40051",
    "lng": "29.52796"
  },
  {
    "country": "UA",
    "name": "Stavyshche",
    "lat": "49.39124",
    "lng": "30.19022"
  },
  {
    "country": "UA",
    "name": "Staryy Sambir",
    "lat": "49.43856",
    "lng": "23.00056"
  },
  {
    "country": "UA",
    "name": "Staryy Saltiv",
    "lat": "50.07619",
    "lng": "36.78852"
  },
  {
    "country": "UA",
    "name": "Staryy Merchyk",
    "lat": "49.98147",
    "lng": "35.75904"
  },
  {
    "country": "UA",
    "name": "Staryy Krym",
    "lat": "47.16146",
    "lng": "37.48934"
  },
  {
    "country": "UA",
    "name": "Stary Krym",
    "lat": "45.02887",
    "lng": "35.09174"
  },
  {
    "country": "UA",
    "name": "Stari Kuty",
    "lat": "48.27093",
    "lng": "25.17293"
  },
  {
    "country": "UA",
    "name": "Stari Bohorodchany",
    "lat": "48.83361",
    "lng": "24.5243"
  },
  {
    "country": "UA",
    "name": "Staroye Selo",
    "lat": "49.71037",
    "lng": "24.1895"
  },
  {
    "country": "UA",
    "name": "Starokostiantyniv",
    "lat": "49.75764",
    "lng": "27.20342"
  },
  {
    "country": "UA",
    "name": "Starokozache",
    "lat": "46.33722",
    "lng": "29.98528"
  },
  {
    "country": "UA",
    "name": "Starobesheve",
    "lat": "47.75038",
    "lng": "38.03051"
  },
  {
    "country": "UA",
    "name": "Starobil’s’k",
    "lat": "49.27832",
    "lng": "38.91069"
  },
  {
    "country": "UA",
    "name": "Starychi",
    "lat": "49.98001",
    "lng": "23.55848"
  },
  {
    "country": "UA",
    "name": "Temriuk",
    "lat": "47.26857",
    "lng": "36.98115"
  },
  {
    "country": "UA",
    "name": "Stara Vyzhivka",
    "lat": "51.43762",
    "lng": "24.43997"
  },
  {
    "country": "UA",
    "name": "Stara Syniava",
    "lat": "49.60318",
    "lng": "27.61909"
  },
  {
    "country": "UA",
    "name": "Stanislav",
    "lat": "46.56909",
    "lng": "32.14777"
  },
  {
    "country": "UA",
    "name": "Stanytsya Luhans’ka",
    "lat": "48.65433",
    "lng": "39.47943"
  },
  {
    "country": "UA",
    "name": "Stal’noye",
    "lat": "45.70814",
    "lng": "34.56238"
  },
  {
    "country": "UA",
    "name": "Stakhanovka",
    "lat": "45.37062",
    "lng": "33.94883"
  },
  {
    "country": "UA",
    "name": "Kadiyivka",
    "lat": "48.56818",
    "lng": "38.64352"
  },
  {
    "country": "UA",
    "name": "Serednye Vodyane",
    "lat": "47.98159",
    "lng": "23.91041"
  },
  {
    "country": "UA",
    "name": "Serednye",
    "lat": "48.54043",
    "lng": "22.50696"
  },
  {
    "country": "UA",
    "name": "Sribne",
    "lat": "50.66384",
    "lng": "32.91867"
  },
  {
    "country": "UA",
    "name": "Spas’ke",
    "lat": "48.66667",
    "lng": "35.05385"
  },
  {
    "country": "UA",
    "name": "Spas",
    "lat": "48.88992",
    "lng": "24.06293"
  },
  {
    "country": "UA",
    "name": "Sovetskiy",
    "lat": "45.34267",
    "lng": "34.92463"
  },
  {
    "country": "UA",
    "name": "Sosnytsya",
    "lat": "51.52387",
    "lng": "32.49985"
  },
  {
    "country": "UA",
    "name": "Solotvyno",
    "lat": "47.94604",
    "lng": "23.87035"
  },
  {
    "country": "UA",
    "name": "Solotvyn",
    "lat": "48.70212",
    "lng": "24.42212"
  },
  {
    "country": "UA",
    "name": "Solonka",
    "lat": "49.75621",
    "lng": "24.01028"
  },
  {
    "country": "UA",
    "name": "Solonytsivka",
    "lat": "49.99682",
    "lng": "36.03464"
  },
  {
    "country": "UA",
    "name": "Solnechnogorskoye",
    "lat": "44.74722",
    "lng": "34.53999"
  },
  {
    "country": "UA",
    "name": "Solnechnaya Dolina",
    "lat": "44.87185",
    "lng": "35.10622"
  },
  {
    "country": "UA",
    "name": "Solone",
    "lat": "48.20805",
    "lng": "34.87208"
  },
  {
    "country": "UA",
    "name": "Sokolinoye",
    "lat": "44.55041",
    "lng": "33.95897"
  },
  {
    "country": "UA",
    "name": "Ilyinka",
    "lat": "45.81784",
    "lng": "33.79482"
  },
  {
    "country": "UA",
    "name": "Sokyryany",
    "lat": "48.44747",
    "lng": "27.41678"
  },
  {
    "country": "UA",
    "name": "Sokal’",
    "lat": "50.47438",
    "lng": "24.28288"
  },
  {
    "country": "UA",
    "name": "Sofiyivka",
    "lat": "48.04865",
    "lng": "33.87618"
  },
  {
    "country": "UA",
    "name": "Sofyevka",
    "lat": "45.08985",
    "lng": "33.99887"
  },
  {
    "country": "UA",
    "name": "Sobolivka",
    "lat": "49.33604",
    "lng": "28.65096"
  },
  {
    "country": "UA",
    "name": "Sniatyn",
    "lat": "48.44692",
    "lng": "25.56937"
  },
  {
    "country": "UA",
    "name": "Snihurivka",
    "lat": "47.07579",
    "lng": "32.80516"
  },
  {
    "country": "UA",
    "name": "Snizhne",
    "lat": "48.02612",
    "lng": "38.77225"
  },
  {
    "country": "UA",
    "name": "Smila",
    "lat": "49.22242",
    "lng": "31.88714"
  },
  {
    "country": "UA",
    "name": "Sloviansk",
    "lat": "48.86667",
    "lng": "37.61667"
  },
  {
    "country": "UA",
    "name": "Slov`yanoserbsk",
    "lat": "48.69779",
    "lng": "38.98133"
  },
  {
    "country": "UA",
    "name": "Slobidka",
    "lat": "47.88694",
    "lng": "29.34611"
  },
  {
    "country": "UA",
    "name": "Sloboda",
    "lat": "51.19806",
    "lng": "33.60695"
  },
  {
    "country": "UA",
    "name": "Slavyanskoye",
    "lat": "45.72768",
    "lng": "33.32165"
  },
  {
    "country": "UA",
    "name": "Slavuta",
    "lat": "50.30155",
    "lng": "26.86506"
  },
  {
    "country": "UA",
    "name": "Slavske",
    "lat": "48.84734",
    "lng": "23.44587"
  },
  {
    "country": "UA",
    "name": "Slavnoye",
    "lat": "45.72176",
    "lng": "33.23689"
  },
  {
    "country": "UA",
    "name": "Slatyne",
    "lat": "50.21041",
    "lng": "36.15376"
  },
  {
    "country": "UA",
    "name": "Skvortsovo",
    "lat": "45.07542",
    "lng": "33.82084"
  },
  {
    "country": "UA",
    "name": "Skvyra",
    "lat": "49.73177",
    "lng": "29.66569"
  },
  {
    "country": "UA",
    "name": "Skole",
    "lat": "49.03717",
    "lng": "23.51346"
  },
  {
    "country": "UA",
    "name": "Skhidnytsya",
    "lat": "49.22827",
    "lng": "23.35016"
  },
  {
    "country": "UA",
    "name": "Skelivka",
    "lat": "49.53728",
    "lng": "22.96467"
  },
  {
    "country": "UA",
    "name": "Skalistoye",
    "lat": "44.81686",
    "lng": "33.97791"
  },
  {
    "country": "UA",
    "name": "Skalat",
    "lat": "49.42732",
    "lng": "25.97869"
  },
  {
    "country": "UA",
    "name": "Skala-Podil’s’ka",
    "lat": "48.85149",
    "lng": "26.19909"
  },
  {
    "country": "UA",
    "name": "Skadovs’k",
    "lat": "46.1161",
    "lng": "32.91124"
  },
  {
    "country": "UA",
    "name": "Sizovka",
    "lat": "45.34892",
    "lng": "33.87669"
  },
  {
    "country": "UA",
    "name": "Synevyrska Poliana",
    "lat": "48.58484",
    "lng": "23.6891"
  },
  {
    "country": "UA",
    "name": "Synevyr",
    "lat": "48.48745",
    "lng": "23.62575"
  },
  {
    "country": "UA",
    "name": "Synel’nykove",
    "lat": "48.32044",
    "lng": "35.51792"
  },
  {
    "country": "UA",
    "name": "Simferopol",
    "lat": "44.95719",
    "lng": "34.11079"
  },
  {
    "country": "UA",
    "name": "Simeiz",
    "lat": "44.40646",
    "lng": "34.00704"
  },
  {
    "country": "UA",
    "name": "Shumsk",
    "lat": "50.12157",
    "lng": "26.11424"
  },
  {
    "country": "UA",
    "name": "Shturmovoye",
    "lat": "44.56767",
    "lng": "33.62245"
  },
  {
    "country": "UA",
    "name": "Shpola",
    "lat": "49.00687",
    "lng": "31.39471"
  },
  {
    "country": "UA",
    "name": "Shostka",
    "lat": "51.86296",
    "lng": "33.4698"
  },
  {
    "country": "UA",
    "name": "Sholokhove",
    "lat": "47.69453",
    "lng": "34.03119"
  },
  {
    "country": "UA",
    "name": "Shklo",
    "lat": "49.95675",
    "lng": "23.54408"
  },
  {
    "country": "UA",
    "name": "Shyshaky",
    "lat": "49.88175",
    "lng": "34.01118"
  },
  {
    "country": "UA",
    "name": "Shyryayeve",
    "lat": "47.38052",
    "lng": "30.19638"
  },
  {
    "country": "UA",
    "name": "Shyroke",
    "lat": "47.95711",
    "lng": "38.2316"
  },
  {
    "country": "UA",
    "name": "Shyroke",
    "lat": "47.69173",
    "lng": "33.25715"
  },
  {
    "country": "UA",
    "name": "Pshenichnoye",
    "lat": "45.64627",
    "lng": "34.83767"
  },
  {
    "country": "UA",
    "name": "Shypyntsi",
    "lat": "48.37677",
    "lng": "25.74664"
  },
  {
    "country": "UA",
    "name": "Partizany",
    "lat": "45.14373",
    "lng": "35.15509"
  },
  {
    "country": "UA",
    "name": "Shevchenkove",
    "lat": "49.69585",
    "lng": "37.17348"
  },
  {
    "country": "UA",
    "name": "Shevchenkove",
    "lat": "46.86289",
    "lng": "32.20387"
  },
  {
    "country": "UA",
    "name": "Shevchenkove",
    "lat": "45.55604",
    "lng": "29.33357"
  },
  {
    "country": "UA",
    "name": "Sheshory",
    "lat": "48.33197",
    "lng": "24.98329"
  },
  {
    "country": "UA",
    "name": "Shepetivka",
    "lat": "50.18545",
    "lng": "27.06365"
  },
  {
    "country": "UA",
    "name": "Shelkovichnoye",
    "lat": "45.18748",
    "lng": "33.68807"
  },
  {
    "country": "UA",
    "name": "Shchors",
    "lat": "51.81865",
    "lng": "31.94504"
  },
  {
    "country": "UA",
    "name": "Shchyrets’",
    "lat": "49.65096",
    "lng": "23.87426"
  },
  {
    "country": "UA",
    "name": "Shcherbynivka",
    "lat": "48.39489",
    "lng": "37.79102"
  },
  {
    "country": "UA",
    "name": "Shchebetovka",
    "lat": "44.93821",
    "lng": "35.158"
  },
  {
    "country": "UA",
    "name": "Shats’k",
    "lat": "51.50208",
    "lng": "23.93806"
  },
  {
    "country": "UA",
    "name": "Sharhorod",
    "lat": "48.73835",
    "lng": "28.08497"
  },
  {
    "country": "UA",
    "name": "Shalyhyne",
    "lat": "51.57167",
    "lng": "34.12167"
  },
  {
    "country": "UA",
    "name": "Shakhtars’k",
    "lat": "48.05657",
    "lng": "38.43826"
  },
  {
    "country": "UA",
    "name": "Shabo",
    "lat": "46.13262",
    "lng": "30.38595"
  },
  {
    "country": "UA",
    "name": "Sivers’k",
    "lat": "48.86699",
    "lng": "38.10007"
  },
  {
    "country": "UA",
    "name": "Sevastopol",
    "lat": "44.58883",
    "lng": "33.5224"
  },
  {
    "country": "UA",
    "name": "Serpneve",
    "lat": "46.30094",
    "lng": "29.01958"
  },
  {
    "country": "UA",
    "name": "Serhiyivka",
    "lat": "46.0272",
    "lng": "30.37682"
  },
  {
    "country": "UA",
    "name": "Seredyna-Buda",
    "lat": "52.18903",
    "lng": "34.03639"
  },
  {
    "country": "UA",
    "name": "Serebryanka",
    "lat": "48.91917",
    "lng": "38.13494"
  },
  {
    "country": "UA",
    "name": "Serebryanka",
    "lat": "45.63937",
    "lng": "33.49632"
  },
  {
    "country": "UA",
    "name": "Serebriya",
    "lat": "48.45593",
    "lng": "27.71923"
  },
  {
    "country": "UA",
    "name": "Sencha",
    "lat": "50.25482",
    "lng": "33.34602"
  },
  {
    "country": "UA",
    "name": "Semisotka",
    "lat": "45.24676",
    "lng": "35.565"
  },
  {
    "country": "UA",
    "name": "Semypolky",
    "lat": "50.72627",
    "lng": "30.93441"
  },
  {
    "country": "UA",
    "name": "Simeykyne",
    "lat": "48.32643",
    "lng": "39.53366"
  },
  {
    "country": "UA",
    "name": "Semenivka",
    "lat": "52.17827",
    "lng": "32.58183"
  },
  {
    "country": "UA",
    "name": "Semenivka",
    "lat": "49.59031",
    "lng": "33.18049"
  },
  {
    "country": "UA",
    "name": "Selydove",
    "lat": "48.14708",
    "lng": "37.30032"
  },
  {
    "country": "UA",
    "name": "Silets’",
    "lat": "50.29712",
    "lng": "24.20462"
  },
  {
    "country": "UA",
    "name": "Syedove",
    "lat": "47.07678",
    "lng": "38.15602"
  },
  {
    "country": "UA",
    "name": "Sedniv",
    "lat": "51.64473",
    "lng": "31.56497"
  },
  {
    "country": "UA",
    "name": "Shchastya",
    "lat": "48.73963",
    "lng": "39.2323"
  },
  {
    "country": "UA",
    "name": "Savran",
    "lat": "48.13219",
    "lng": "30.08247"
  },
  {
    "country": "UA",
    "name": "Savyntsi",
    "lat": "49.40257",
    "lng": "37.06266"
  },
  {
    "country": "UA",
    "name": "Sarny",
    "lat": "51.33795",
    "lng": "26.60191"
  },
  {
    "country": "UA",
    "name": "Sarata",
    "lat": "46.01966",
    "lng": "29.66567"
  },
  {
    "country": "UA",
    "name": "Sambir",
    "lat": "49.5183",
    "lng": "23.19752"
  },
  {
    "country": "UA",
    "name": "Saki",
    "lat": "45.13424",
    "lng": "33.59996"
  },
  {
    "country": "UA",
    "name": "Sakhnovshchyna",
    "lat": "49.15166",
    "lng": "35.87198"
  },
  {
    "country": "UA",
    "name": "Sadzhavka",
    "lat": "48.56603",
    "lng": "24.7882"
  },
  {
    "country": "UA",
    "name": "Sadovoye",
    "lat": "45.31037",
    "lng": "34.6526"
  },
  {
    "country": "UA",
    "name": "Rzhyshchiv",
    "lat": "49.96886",
    "lng": "31.04628"
  },
  {
    "country": "UA",
    "name": "Rykhtychi",
    "lat": "49.38511",
    "lng": "23.55662"
  },
  {
    "country": "UA",
    "name": "Rybakivka",
    "lat": "46.61712",
    "lng": "31.34995"
  },
  {
    "country": "UA",
    "name": "Rybach'e",
    "lat": "44.77331",
    "lng": "34.59609"
  },
  {
    "country": "UA",
    "name": "Ruzhyn",
    "lat": "49.7228",
    "lng": "29.20455"
  },
  {
    "country": "UA",
    "name": "Russkaya Polyana",
    "lat": "49.417",
    "lng": "31.92009"
  },
  {
    "country": "UA",
    "name": "Rusakovka",
    "lat": "45.12369",
    "lng": "34.47458"
  },
  {
    "country": "UA",
    "name": "Rudne",
    "lat": "49.83333",
    "lng": "23.9"
  },
  {
    "country": "UA",
    "name": "Rudky",
    "lat": "49.65306",
    "lng": "23.48702"
  },
  {
    "country": "UA",
    "name": "Ruch’i",
    "lat": "45.78564",
    "lng": "33.66093"
  },
  {
    "country": "UA",
    "name": "Rubizhne",
    "lat": "49.01229",
    "lng": "38.37967"
  },
  {
    "country": "UA",
    "name": "Rozvadiv",
    "lat": "49.50323",
    "lng": "23.962"
  },
  {
    "country": "UA",
    "name": "Rozivka",
    "lat": "47.38484",
    "lng": "37.06792"
  },
  {
    "country": "UA",
    "name": "Rozivka",
    "lat": "46.9394",
    "lng": "35.77207"
  },
  {
    "country": "UA",
    "name": "Rozhnyativ",
    "lat": "48.93576",
    "lng": "24.16379"
  },
  {
    "country": "UA",
    "name": "Rozhniv",
    "lat": "48.36597",
    "lng": "25.2258"
  },
  {
    "country": "UA",
    "name": "Rozhyshche",
    "lat": "50.91542",
    "lng": "25.26906"
  },
  {
    "country": "UA",
    "name": "Rozdil",
    "lat": "49.46144",
    "lng": "24.0623"
  },
  {
    "country": "UA",
    "name": "Rozdil’na",
    "lat": "46.84334",
    "lng": "30.07919"
  },
  {
    "country": "UA",
    "name": "Rivne",
    "lat": "48.24742",
    "lng": "31.75432"
  },
  {
    "country": "UA",
    "name": "Roven’ky",
    "lat": "48.08331",
    "lng": "39.37764"
  },
  {
    "country": "UA",
    "name": "Roskoshnyy",
    "lat": "49.37087",
    "lng": "30.18471"
  },
  {
    "country": "UA",
    "name": "Rozkishne",
    "lat": "48.48959",
    "lng": "39.27881"
  },
  {
    "country": "UA",
    "name": "Roskoshnoye",
    "lat": "45.65187",
    "lng": "34.11552"
  },
  {
    "country": "UA",
    "name": "Ropcha",
    "lat": "48.11988",
    "lng": "25.77421"
  },
  {
    "country": "UA",
    "name": "Romodan",
    "lat": "49.99055",
    "lng": "33.32506"
  },
  {
    "country": "UA",
    "name": "Romny",
    "lat": "50.75104",
    "lng": "33.47471"
  },
  {
    "country": "UA",
    "name": "Romashkino",
    "lat": "45.25647",
    "lng": "33.25517"
  },
  {
    "country": "UA",
    "name": "Rokosovo",
    "lat": "48.21018",
    "lng": "23.17624"
  },
  {
    "country": "UA",
    "name": "Rokytne",
    "lat": "51.2796",
    "lng": "27.214"
  },
  {
    "country": "UA",
    "name": "Rohatyn",
    "lat": "49.409",
    "lng": "24.60927"
  },
  {
    "country": "UA",
    "name": "Rodnikovo",
    "lat": "45.04296",
    "lng": "33.95407"
  },
  {
    "country": "UA",
    "name": "Rodyns’ke",
    "lat": "48.35199",
    "lng": "37.20602"
  },
  {
    "country": "UA",
    "name": "Rodatychi",
    "lat": "49.79862",
    "lng": "23.53336"
  },
  {
    "country": "UA",
    "name": "Rivne",
    "lat": "50.62308",
    "lng": "26.22743"
  },
  {
    "country": "UA",
    "name": "Reshetylivka",
    "lat": "49.56501",
    "lng": "34.07815"
  },
  {
    "country": "UA",
    "name": "Ripky",
    "lat": "51.80105",
    "lng": "31.08383"
  },
  {
    "country": "UA",
    "name": "Reni",
    "lat": "45.45727",
    "lng": "28.29317"
  },
  {
    "country": "UA",
    "name": "Richky",
    "lat": "50.27706",
    "lng": "23.64617"
  },
  {
    "country": "UA",
    "name": "Rechka",
    "lat": "48.28034",
    "lng": "24.9333"
  },
  {
    "country": "UA",
    "name": "Razdol’noye",
    "lat": "45.77083",
    "lng": "33.48777"
  },
  {
    "country": "UA",
    "name": "Rava-Rus’ka",
    "lat": "50.23079",
    "lng": "23.62825"
  },
  {
    "country": "UA",
    "name": "Ratne",
    "lat": "51.6683",
    "lng": "24.5303"
  },
  {
    "country": "UA",
    "name": "Rozsypne",
    "lat": "48.14966",
    "lng": "38.57619"
  },
  {
    "country": "UA",
    "name": "Ralivka",
    "lat": "49.49982",
    "lng": "23.23739"
  },
  {
    "country": "UA",
    "name": "Rakiv Lis",
    "lat": "51.62174",
    "lng": "24.92427"
  },
  {
    "country": "UA",
    "name": "Rakoshyno",
    "lat": "48.46713",
    "lng": "22.59687"
  },
  {
    "country": "UA",
    "name": "Rokytne",
    "lat": "49.68665",
    "lng": "30.47384"
  },
  {
    "country": "UA",
    "name": "Rakhiv",
    "lat": "48.0526",
    "lng": "24.20089"
  },
  {
    "country": "UA",
    "name": "Radomyshl",
    "lat": "50.49613",
    "lng": "29.22911"
  },
  {
    "country": "UA",
    "name": "Radens’k",
    "lat": "46.5486",
    "lng": "32.92787"
  },
  {
    "country": "UA",
    "name": "Radekhiv",
    "lat": "50.28249",
    "lng": "24.64279"
  },
  {
    "country": "UA",
    "name": "Radcha",
    "lat": "48.85023",
    "lng": "24.65502"
  },
  {
    "country": "UA",
    "name": "Piatykhatky",
    "lat": "48.41333",
    "lng": "33.71056"
  },
  {
    "country": "UA",
    "name": "Pyatikhatka",
    "lat": "45.32347",
    "lng": "34.25516"
  },
  {
    "country": "UA",
    "name": "Putyvl’",
    "lat": "51.33745",
    "lng": "33.87066"
  },
  {
    "country": "UA",
    "name": "Putyla",
    "lat": "47.98869",
    "lng": "25.09455"
  },
  {
    "country": "UA",
    "name": "Pustomyty",
    "lat": "49.71532",
    "lng": "23.91295"
  },
  {
    "country": "UA",
    "name": "Pushkino",
    "lat": "45.20373",
    "lng": "34.97642"
  },
  {
    "country": "UA",
    "name": "Pukhivka",
    "lat": "50.6097",
    "lng": "30.7177"
  },
  {
    "country": "UA",
    "name": "Pryluky",
    "lat": "50.59323",
    "lng": "32.38761"
  },
  {
    "country": "UA",
    "name": "Prudyanka",
    "lat": "50.23606",
    "lng": "36.16835"
  },
  {
    "country": "UA",
    "name": "Prudy",
    "lat": "45.23922",
    "lng": "34.70217"
  },
  {
    "country": "UA",
    "name": "Prostornoye",
    "lat": "45.65597",
    "lng": "34.69837"
  },
  {
    "country": "UA",
    "name": "P'yatypill'ya",
    "lat": "48.0159",
    "lng": "38.09979"
  },
  {
    "country": "UA",
    "name": "Pryyutivka",
    "lat": "48.72094",
    "lng": "33.07078"
  },
  {
    "country": "UA",
    "name": "Pryvillya",
    "lat": "49.01501",
    "lng": "38.30457"
  },
  {
    "country": "UA",
    "name": "Privetnoye",
    "lat": "45.11969",
    "lng": "35.0596"
  },
  {
    "country": "UA",
    "name": "Privetnoye",
    "lat": "44.82145",
    "lng": "34.67935"
  },
  {
    "country": "UA",
    "name": "Pryshyb",
    "lat": "47.25927",
    "lng": "35.31953"
  },
  {
    "country": "UA",
    "name": "Priozyornoye",
    "lat": "45.2699",
    "lng": "36.33405"
  },
  {
    "country": "UA",
    "name": "Sartana",
    "lat": "47.17436",
    "lng": "37.69266"
  },
  {
    "country": "UA",
    "name": "Primorskiy",
    "lat": "45.11904",
    "lng": "35.48025"
  },
  {
    "country": "UA",
    "name": "Prymors’k",
    "lat": "46.73479",
    "lng": "36.34425"
  },
  {
    "country": "UA",
    "name": "Prykolotne",
    "lat": "50.16273",
    "lng": "37.34524"
  },
  {
    "country": "UA",
    "name": "Pryazovs’ke",
    "lat": "46.73426",
    "lng": "35.64251"
  },
  {
    "country": "UA",
    "name": "Preobrazhenka",
    "lat": "47.57194",
    "lng": "35.81667"
  },
  {
    "country": "UA",
    "name": "Pravda",
    "lat": "45.77903",
    "lng": "33.84649"
  },
  {
    "country": "UA",
    "name": "Potelych",
    "lat": "50.20804",
    "lng": "23.54674"
  },
  {
    "country": "UA",
    "name": "Poroshkovo",
    "lat": "48.66832",
    "lng": "22.75328"
  },
  {
    "country": "UA",
    "name": "Porohy",
    "lat": "48.68755",
    "lng": "24.26322"
  },
  {
    "country": "UA",
    "name": "Popil'nya",
    "lat": "49.96652",
    "lng": "29.44353"
  },
  {
    "country": "UA",
    "name": "Popasna",
    "lat": "48.63328",
    "lng": "38.37804"
  },
  {
    "country": "UA",
    "name": "Poninka",
    "lat": "50.18492",
    "lng": "27.53629"
  },
  {
    "country": "UA",
    "name": "Pomichna",
    "lat": "48.24222",
    "lng": "31.41583"
  },
  {
    "country": "UA",
    "name": "Pomoriany",
    "lat": "49.64092",
    "lng": "24.9307"
  },
  {
    "country": "UA",
    "name": "Polyanka",
    "lat": "50.25836",
    "lng": "27.68809"
  },
  {
    "country": "UA",
    "name": "Poltava",
    "lat": "49.59373",
    "lng": "34.54073"
  },
  {
    "country": "UA",
    "name": "Polonne",
    "lat": "50.12424",
    "lng": "27.51087"
  },
  {
    "country": "UA",
    "name": "Polohy",
    "lat": "47.48444",
    "lng": "36.25361"
  },
  {
    "country": "UA",
    "name": "Pokrovs’ke",
    "lat": "47.97852",
    "lng": "36.2256"
  },
  {
    "country": "UA",
    "name": "Pokotylivka",
    "lat": "49.91343",
    "lng": "36.17511"
  },
  {
    "country": "UA",
    "name": "Pohreby",
    "lat": "50.55453",
    "lng": "30.64455"
  },
  {
    "country": "UA",
    "name": "Pohrebyshche",
    "lat": "49.48639",
    "lng": "29.26361"
  },
  {
    "country": "UA",
    "name": "Pidvolochysk",
    "lat": "49.53472",
    "lng": "26.14585"
  },
  {
    "country": "UA",
    "name": "Pidvynohradiv",
    "lat": "48.13947",
    "lng": "22.97194"
  },
  {
    "country": "UA",
    "name": "Pidkamin’",
    "lat": "49.94599",
    "lng": "25.31672"
  },
  {
    "country": "UA",
    "name": "Pidhirtsi",
    "lat": "49.94611",
    "lng": "24.9795"
  },
  {
    "country": "UA",
    "name": "Pidhorodne",
    "lat": "48.57528",
    "lng": "35.1068"
  },
  {
    "country": "UA",
    "name": "Pidhorodna",
    "lat": "48.10704",
    "lng": "30.88953"
  },
  {
    "country": "UA",
    "name": "Pidhaytsi",
    "lat": "49.26853",
    "lng": "25.13341"
  },
  {
    "country": "UA",
    "name": "Pidbuzh",
    "lat": "49.33483",
    "lng": "23.24887"
  },
  {
    "country": "UA",
    "name": "Pochtovoye",
    "lat": "44.8354",
    "lng": "33.96159"
  },
  {
    "country": "UA",
    "name": "Pochaiv",
    "lat": "50.00509",
    "lng": "25.51183"
  },
  {
    "country": "UA",
    "name": "Pobugskoye",
    "lat": "48.16579",
    "lng": "30.59274"
  },
  {
    "country": "UA",
    "name": "Pobednoye",
    "lat": "45.70109",
    "lng": "34.44805"
  },
  {
    "country": "UA",
    "name": "Pnikut",
    "lat": "49.71104",
    "lng": "23.13826"
  },
  {
    "country": "UA",
    "name": "Pniv",
    "lat": "48.61783",
    "lng": "24.52872"
  },
  {
    "country": "UA",
    "name": "Plodovoye",
    "lat": "44.87156",
    "lng": "33.85615"
  },
  {
    "country": "UA",
    "name": "Koktebel",
    "lat": "44.96155",
    "lng": "35.2466"
  },
  {
    "country": "UA",
    "name": "Plakhtiyivka",
    "lat": "46.1006",
    "lng": "29.72169"
  },
  {
    "country": "UA",
    "name": "Pivdenne",
    "lat": "49.88315",
    "lng": "36.06785"
  },
  {
    "country": "UA",
    "name": "Pishcha",
    "lat": "51.60928",
    "lng": "23.82079"
  },
  {
    "country": "UA",
    "name": "Pyryatyn",
    "lat": "50.24242",
    "lng": "32.50621"
  },
  {
    "country": "UA",
    "name": "Pionerskoye",
    "lat": "44.88083",
    "lng": "34.20194"
  },
  {
    "country": "UA",
    "name": "Pylypets",
    "lat": "48.65899",
    "lng": "23.28346"
  },
  {
    "country": "UA",
    "name": "Petrivs’ke",
    "lat": "49.17695",
    "lng": "36.89999"
  },
  {
    "country": "UA",
    "name": "Petrove",
    "lat": "48.32467",
    "lng": "33.25617"
  },
  {
    "country": "UA",
    "name": "Petrovka",
    "lat": "45.49776",
    "lng": "34.28816"
  },
  {
    "country": "UA",
    "name": "Petropavlivka",
    "lat": "48.45643",
    "lng": "36.4367"
  },
  {
    "country": "UA",
    "name": "Kurisove",
    "lat": "46.96951",
    "lng": "30.95914"
  },
  {
    "country": "UA",
    "name": "Petrykivka",
    "lat": "48.72933",
    "lng": "34.63358"
  },
  {
    "country": "UA",
    "name": "Petrikov",
    "lat": "49.53122",
    "lng": "25.57901"
  },
  {
    "country": "UA",
    "name": "Petranka",
    "lat": "48.90246",
    "lng": "24.30347"
  },
  {
    "country": "UA",
    "name": "Piskivka",
    "lat": "50.69378",
    "lng": "29.61934"
  },
  {
    "country": "UA",
    "name": "Peschanoye",
    "lat": "44.84342",
    "lng": "33.60921"
  },
  {
    "country": "UA",
    "name": "Pishchanka",
    "lat": "48.20727",
    "lng": "28.88607"
  },
  {
    "country": "UA",
    "name": "Peschana",
    "lat": "48.12918",
    "lng": "29.73086"
  },
  {
    "country": "UA",
    "name": "Pervomayskoye",
    "lat": "45.71744",
    "lng": "33.85596"
  },
  {
    "country": "UA",
    "name": "Pervomays’kyy",
    "lat": "49.38742",
    "lng": "36.21471"
  },
  {
    "country": "UA",
    "name": "Pervomayskoye",
    "lat": "45.11207",
    "lng": "34.06478"
  },
  {
    "country": "UA",
    "name": "Pervomays’k",
    "lat": "48.62988",
    "lng": "38.54806"
  },
  {
    "country": "UA",
    "name": "Pervomays’k",
    "lat": "48.04433",
    "lng": "30.85073"
  },
  {
    "country": "UA",
    "name": "Pershotravneve",
    "lat": "51.39287",
    "lng": "28.86837"
  },
  {
    "country": "UA",
    "name": "Manhush",
    "lat": "47.05582",
    "lng": "37.31068"
  },
  {
    "country": "UA",
    "name": "Perovo",
    "lat": "44.92513",
    "lng": "34.05753"
  },
  {
    "country": "UA",
    "name": "Pereyaslav-Khmel’nyts’kyy",
    "lat": "50.06739",
    "lng": "31.44969"
  },
  {
    "country": "UA",
    "name": "Pereval’s’k",
    "lat": "48.43779",
    "lng": "38.84384"
  },
  {
    "country": "UA",
    "name": "Pereval'noye",
    "lat": "44.84838",
    "lng": "34.31271"
  },
  {
    "country": "UA",
    "name": "Peresichna",
    "lat": "50.02452",
    "lng": "35.97871"
  },
  {
    "country": "UA",
    "name": "Peremyshlyany",
    "lat": "49.66523",
    "lng": "24.55846"
  },
  {
    "country": "UA",
    "name": "Perehonivka",
    "lat": "48.53552",
    "lng": "30.51923"
  },
  {
    "country": "UA",
    "name": "Perechyn",
    "lat": "48.73616",
    "lng": "22.482"
  },
  {
    "country": "UA",
    "name": "Pechenizhyn",
    "lat": "48.51551",
    "lng": "24.89423"
  },
  {
    "country": "UA",
    "name": "Pechenihy",
    "lat": "49.87167",
    "lng": "36.93472"
  },
  {
    "country": "UA",
    "name": "Pavlysh",
    "lat": "48.91762",
    "lng": "33.35691"
  },
  {
    "country": "UA",
    "name": "Pavlivka",
    "lat": "49.60864",
    "lng": "38.70917"
  },
  {
    "country": "UA",
    "name": "Pavlovka",
    "lat": "49.44143",
    "lng": "28.45956"
  },
  {
    "country": "UA",
    "name": "Pavlohrad",
    "lat": "48.53426",
    "lng": "35.87098"
  },
  {
    "country": "UA",
    "name": "Pasichna",
    "lat": "48.57152",
    "lng": "24.43003"
  },
  {
    "country": "UA",
    "name": "Parutyne",
    "lat": "46.70538",
    "lng": "31.89709"
  },
  {
    "country": "UA",
    "name": "Partyzany",
    "lat": "46.33383",
    "lng": "34.75314"
  },
  {
    "country": "UA",
    "name": "Partizanskoye",
    "lat": "44.83379",
    "lng": "34.08465"
  },
  {
    "country": "UA",
    "name": "Makariv Yar",
    "lat": "48.57768",
    "lng": "39.71944"
  },
  {
    "country": "UA",
    "name": "Panyutyne",
    "lat": "48.93692",
    "lng": "36.27563"
  },
  {
    "country": "UA",
    "name": "Pantayivka",
    "lat": "48.674",
    "lng": "32.8841"
  },
  {
    "country": "UA",
    "name": "Ozerne",
    "lat": "50.17816",
    "lng": "28.73384"
  },
  {
    "country": "UA",
    "name": "Ozerne",
    "lat": "45.403",
    "lng": "28.67546"
  },
  {
    "country": "UA",
    "name": "Ozerna",
    "lat": "49.62891",
    "lng": "25.32895"
  },
  {
    "country": "UA",
    "name": "Ovruch",
    "lat": "51.3246",
    "lng": "28.80351"
  },
  {
    "country": "UA",
    "name": "Ovidiopol",
    "lat": "46.24998",
    "lng": "30.44127"
  },
  {
    "country": "UA",
    "name": "Otyniya",
    "lat": "48.73767",
    "lng": "24.86111"
  },
  {
    "country": "UA",
    "name": "Ostrovskoye",
    "lat": "45.74232",
    "lng": "34.06607"
  },
  {
    "country": "UA",
    "name": "Ostroh",
    "lat": "50.32942",
    "lng": "26.51425"
  },
  {
    "country": "UA",
    "name": "Oster",
    "lat": "50.9506",
    "lng": "30.88229"
  },
  {
    "country": "UA",
    "name": "Osypenko",
    "lat": "46.9136",
    "lng": "36.8253"
  },
  {
    "country": "UA",
    "name": "Orzhytsya",
    "lat": "49.7901",
    "lng": "32.69941"
  },
  {
    "country": "UA",
    "name": "Orlovskoye",
    "lat": "45.8107",
    "lng": "33.97308"
  },
  {
    "country": "UA",
    "name": "Orlinoye",
    "lat": "44.44685",
    "lng": "33.77588"
  },
  {
    "country": "UA",
    "name": "Orikhiv",
    "lat": "47.56731",
    "lng": "35.78575"
  },
  {
    "country": "UA",
    "name": "Ordzhonikidze",
    "lat": "47.66763",
    "lng": "34.05957"
  },
  {
    "country": "UA",
    "name": "Ordzhonikidze",
    "lat": "44.96401",
    "lng": "35.35576"
  },
  {
    "country": "UA",
    "name": "Orativ",
    "lat": "49.18889",
    "lng": "29.52697"
  },
  {
    "country": "UA",
    "name": "Oposhnya",
    "lat": "49.95652",
    "lng": "34.61226"
  },
  {
    "country": "UA",
    "name": "Onufriyivka",
    "lat": "48.90716",
    "lng": "33.44869"
  },
  {
    "country": "UA",
    "name": "Onokivtsi",
    "lat": "48.65763",
    "lng": "22.34183"
  },
  {
    "country": "UA",
    "name": "Olyka",
    "lat": "50.71855",
    "lng": "25.81251"
  },
  {
    "country": "UA",
    "name": "Ol'shanskoye",
    "lat": "47.18411",
    "lng": "31.79375"
  },
  {
    "country": "UA",
    "name": "Vil’shanka",
    "lat": "48.23604",
    "lng": "30.87608"
  },
  {
    "country": "UA",
    "name": "Olyshivka",
    "lat": "51.22266",
    "lng": "31.33314"
  },
  {
    "country": "UA",
    "name": "Olevs’k",
    "lat": "51.22482",
    "lng": "27.65228"
  },
  {
    "country": "UA",
    "name": "Olesko",
    "lat": "49.96233",
    "lng": "24.89336"
  },
  {
    "country": "UA",
    "name": "Oleshnyk",
    "lat": "48.16406",
    "lng": "22.96167"
  },
  {
    "country": "UA",
    "name": "Oleksandriya",
    "lat": "48.66961",
    "lng": "33.11593"
  },
  {
    "country": "UA",
    "name": "Oleksandrivka",
    "lat": "48.96336",
    "lng": "32.23492"
  },
  {
    "country": "UA",
    "name": "Okunevka",
    "lat": "45.36855",
    "lng": "32.76357"
  },
  {
    "country": "UA",
    "name": "Oktyabr’skoye",
    "lat": "45.65531",
    "lng": "33.94918"
  },
  {
    "country": "UA",
    "name": "Oktyabr'skoye",
    "lat": "45.36215",
    "lng": "36.36803"
  },
  {
    "country": "UA",
    "name": "Oktyabr’skoye",
    "lat": "45.28866",
    "lng": "34.13521"
  },
  {
    "country": "UA",
    "name": "Okhotskoye",
    "lat": "45.48612",
    "lng": "34.86401"
  },
  {
    "country": "UA",
    "name": "Okhotnikovo",
    "lat": "45.23985",
    "lng": "33.59405"
  },
  {
    "country": "UA",
    "name": "Odessa",
    "lat": "46.47747",
    "lng": "30.73262"
  },
  {
    "country": "UA",
    "name": "Ochakiv",
    "lat": "46.61283",
    "lng": "31.54982"
  },
  {
    "country": "UA",
    "name": "Obukhiv",
    "lat": "50.10689",
    "lng": "30.61848"
  },
  {
    "country": "UA",
    "name": "Obroshyne",
    "lat": "49.78333",
    "lng": "23.86667"
  },
  {
    "country": "UA",
    "name": "Obodivka",
    "lat": "48.40514",
    "lng": "29.24775"
  },
  {
    "country": "UA",
    "name": "Obertyn",
    "lat": "48.70032",
    "lng": "25.17012"
  },
  {
    "country": "UA",
    "name": "Nyrkiv",
    "lat": "48.81492",
    "lng": "25.59989"
  },
  {
    "country": "UA",
    "name": "Nuyno",
    "lat": "51.54628",
    "lng": "24.91018"
  },
  {
    "country": "UA",
    "name": "Novyy Yarychiv",
    "lat": "49.90444",
    "lng": "24.30523"
  },
  {
    "country": "UA",
    "name": "Novyy Svit",
    "lat": "47.80591",
    "lng": "38.02112"
  },
  {
    "country": "UA",
    "name": "Novy Svet",
    "lat": "44.83087",
    "lng": "34.9137"
  },
  {
    "country": "UA",
    "name": "Novyy Starodub",
    "lat": "48.5158",
    "lng": "33.17329"
  },
  {
    "country": "UA",
    "name": "Novi Troyany",
    "lat": "45.94275",
    "lng": "28.85628"
  },
  {
    "country": "UA",
    "name": "Novi Sanzhary",
    "lat": "49.34395",
    "lng": "34.31084"
  },
  {
    "country": "UA",
    "name": "Novi Petrivtsi",
    "lat": "50.62754",
    "lng": "30.4431"
  },
  {
    "country": "UA",
    "name": "Novi Bilokorovychi",
    "lat": "51.11548",
    "lng": "28.05463"
  },
  {
    "country": "UA",
    "name": "Novyy Buh",
    "lat": "47.69308",
    "lng": "32.5216"
  },
  {
    "country": "UA",
    "name": "Novozhilovka",
    "lat": "45.1596",
    "lng": "34.2327"
  },
  {
    "country": "UA",
    "name": "Nove Davydkovo",
    "lat": "48.44133",
    "lng": "22.62164"
  },
  {
    "country": "UA",
    "name": "Dubki",
    "lat": "44.93581",
    "lng": "34.02355"
  },
  {
    "country": "UA",
    "name": "Novovorontsovka",
    "lat": "47.50035",
    "lng": "33.91748"
  },
  {
    "country": "UA",
    "name": "Novovolyns’k",
    "lat": "50.72576",
    "lng": "24.16265"
  },
  {
    "country": "UA",
    "name": "Novovasylivka",
    "lat": "46.83021",
    "lng": "35.75136"
  },
  {
    "country": "UA",
    "name": "Novoukrayinka",
    "lat": "48.32635",
    "lng": "31.52852"
  },
  {
    "country": "UA",
    "name": "Novotroyits’ke",
    "lat": "46.3556",
    "lng": "34.33272"
  },
  {
    "country": "UA",
    "name": "Novostepnoye",
    "lat": "45.66206",
    "lng": "34.387"
  },
  {
    "country": "UA",
    "name": "Novoselovskoye",
    "lat": "45.44276",
    "lng": "33.59795"
  },
  {
    "country": "UA",
    "name": "Novoselivka",
    "lat": "49.0701",
    "lng": "37.69517"
  },
  {
    "country": "UA",
    "name": "Novosyolovka",
    "lat": "44.99377",
    "lng": "33.83525"
  },
  {
    "country": "UA",
    "name": "Novoselytsya",
    "lat": "50.0703",
    "lng": "27.51955"
  },
  {
    "country": "UA",
    "name": "Novoselytsya",
    "lat": "48.21931",
    "lng": "26.26531"
  },
  {
    "country": "UA",
    "name": "Novopskov",
    "lat": "49.5464",
    "lng": "39.08987"
  },
  {
    "country": "UA",
    "name": "Novopokrovka",
    "lat": "49.83349",
    "lng": "36.54771"
  },
  {
    "country": "UA",
    "name": "Novopokrovka",
    "lat": "48.05918",
    "lng": "34.60619"
  },
  {
    "country": "UA",
    "name": "Novopokrovka",
    "lat": "45.42198",
    "lng": "34.45052"
  },
  {
    "country": "UA",
    "name": "Poltavka",
    "lat": "45.35133",
    "lng": "34.18371"
  },
  {
    "country": "UA",
    "name": "Novopavlovka",
    "lat": "45.86634",
    "lng": "33.89018"
  },
  {
    "country": "UA",
    "name": "Novomykolayivka",
    "lat": "48.55625",
    "lng": "34.37399"
  },
  {
    "country": "UA",
    "name": "Novomykolayivka",
    "lat": "47.9781",
    "lng": "35.9102"
  },
  {
    "country": "UA",
    "name": "Novonikolayevka",
    "lat": "45.30855",
    "lng": "36.05749"
  },
  {
    "country": "UA",
    "name": "Novomoskovs’k",
    "lat": "48.63799",
    "lng": "35.24548"
  },
  {
    "country": "UA",
    "name": "Novomyrhorod",
    "lat": "48.78105",
    "lng": "31.64204"
  },
  {
    "country": "UA",
    "name": "Novokrymskoye",
    "lat": "45.78007",
    "lng": "34.15543"
  },
  {
    "country": "UA",
    "name": "Novoivanovka",
    "lat": "45.44914",
    "lng": "33.09833"
  },
  {
    "country": "UA",
    "name": "Novohrad-Volynskyi",
    "lat": "50.59412",
    "lng": "27.6165"
  },
  {
    "country": "UA",
    "name": "Novogrigoryevka",
    "lat": "45.452",
    "lng": "34.60378"
  },
  {
    "country": "UA",
    "name": "Novofedorivka",
    "lat": "46.17128",
    "lng": "32.31781"
  },
  {
    "country": "UA",
    "name": "Novodonets’ke",
    "lat": "48.63526",
    "lng": "36.98477"
  },
  {
    "country": "UA",
    "name": "Voskhod",
    "lat": "45.50999",
    "lng": "34.39355"
  },
  {
    "country": "UA",
    "name": "Novodnistrovs’k",
    "lat": "48.58303",
    "lng": "27.4407"
  },
  {
    "country": "UA",
    "name": "Novobohdanivka",
    "lat": "47.08524",
    "lng": "35.32945"
  },
  {
    "country": "UA",
    "name": "Novoazovs'k",
    "lat": "47.11389",
    "lng": "38.08599"
  },
  {
    "country": "UA",
    "name": "Novoaydar",
    "lat": "48.96391",
    "lng": "39.00583"
  },
  {
    "country": "UA",
    "name": "Novoarkhanhel’s’k",
    "lat": "48.65803",
    "lng": "30.81821"
  },
  {
    "country": "UA",
    "name": "Novoandreyevka",
    "lat": "45.19904",
    "lng": "34.09384"
  },
  {
    "country": "UA",
    "name": "Novooleksiyivka",
    "lat": "46.22472",
    "lng": "34.64031"
  },
  {
    "country": "UA",
    "name": "Novytsya",
    "lat": "48.96345",
    "lng": "24.33542"
  },
  {
    "country": "UA",
    "name": "Novhorod-Sivers’kyy",
    "lat": "52.00577",
    "lng": "33.2615"
  },
  {
    "country": "UA",
    "name": "Novhorodka",
    "lat": "48.36506",
    "lng": "32.65785"
  },
  {
    "country": "UA",
    "name": "Nove-Misto",
    "lat": "48.98113",
    "lng": "29.82813"
  },
  {
    "country": "UA",
    "name": "Nova Vodolaha",
    "lat": "49.71901",
    "lng": "35.86578"
  },
  {
    "country": "UA",
    "name": "Nova Praha",
    "lat": "48.56821",
    "lng": "32.90273"
  },
  {
    "country": "UA",
    "name": "Novopokrovka",
    "lat": "45.16517",
    "lng": "35.25304"
  },
  {
    "country": "UA",
    "name": "Nova Odesa",
    "lat": "47.30778",
    "lng": "31.78506"
  },
  {
    "country": "UA",
    "name": "Nova Mayachka",
    "lat": "46.59996",
    "lng": "33.22707"
  },
  {
    "country": "UA",
    "name": "Nova Kakhovka",
    "lat": "46.75451",
    "lng": "33.34864"
  },
  {
    "country": "UA",
    "name": "Novoestoniya",
    "lat": "45.4996",
    "lng": "34.24298"
  },
  {
    "country": "UA",
    "name": "Nova Borova",
    "lat": "50.69296",
    "lng": "28.63446"
  },
  {
    "country": "UA",
    "name": "Nova Ushytsya",
    "lat": "48.83716",
    "lng": "27.27434"
  },
  {
    "country": "UA",
    "name": "Nosivka",
    "lat": "50.93152",
    "lng": "31.58282"
  },
  {
    "country": "UA",
    "name": "Nyzy",
    "lat": "50.78281",
    "lng": "34.78441"
  },
  {
    "country": "UA",
    "name": "Nizhyn",
    "lat": "51.04801",
    "lng": "31.88688"
  },
  {
    "country": "UA",
    "name": "Nyzhnya Krynka",
    "lat": "48.1135",
    "lng": "38.16064"
  },
  {
    "country": "UA",
    "name": "Nyzhnya Duvanka",
    "lat": "49.58464",
    "lng": "38.17429"
  },
  {
    "country": "UA",
    "name": "Nyzhni Sirohozy",
    "lat": "46.84842",
    "lng": "34.38044"
  },
  {
    "country": "UA",
    "name": "Nyzhnye Selyshche",
    "lat": "48.19911",
    "lng": "23.44757"
  },
  {
    "country": "UA",
    "name": "Nizhnegorskiy",
    "lat": "45.44789",
    "lng": "34.73839"
  },
  {
    "country": "UA",
    "name": "Nikopol",
    "lat": "47.57119",
    "lng": "34.39637"
  },
  {
    "country": "UA",
    "name": "Mykolayivka",
    "lat": "47.54135",
    "lng": "30.75615"
  },
  {
    "country": "UA",
    "name": "Nikolayevka",
    "lat": "44.96213",
    "lng": "33.61061"
  },
  {
    "country": "UA",
    "name": "Nevyts’ke",
    "lat": "48.67472",
    "lng": "22.38813"
  },
  {
    "country": "UA",
    "name": "Netishyn",
    "lat": "50.34004",
    "lng": "26.64171"
  },
  {
    "country": "UA",
    "name": "Neresnytsya",
    "lat": "48.11814",
    "lng": "23.76588"
  },
  {
    "country": "UA",
    "name": "Nemyriv",
    "lat": "48.97076",
    "lng": "28.83779"
  },
  {
    "country": "UA",
    "name": "Nelipyno",
    "lat": "48.56101",
    "lng": "23.03146"
  },
  {
    "country": "UA",
    "name": "Nekrasovka",
    "lat": "45.44085",
    "lng": "34.98584"
  },
  {
    "country": "UA",
    "name": "Nedryhayliv",
    "lat": "50.83398",
    "lng": "33.87626"
  },
  {
    "country": "UA",
    "name": "Nebyliv",
    "lat": "48.81526",
    "lng": "24.21657"
  },
  {
    "country": "UA",
    "name": "Naydenovka",
    "lat": "45.27088",
    "lng": "34.44898"
  },
  {
    "country": "UA",
    "name": "Navaria",
    "lat": "49.74952",
    "lng": "23.92746"
  },
  {
    "country": "UA",
    "name": "Nasypnoe",
    "lat": "45.05285",
    "lng": "35.29415"
  },
  {
    "country": "UA",
    "name": "Narodychi",
    "lat": "51.20286",
    "lng": "29.08228"
  },
  {
    "country": "UA",
    "name": "Nadvirna",
    "lat": "48.6348",
    "lng": "24.56936"
  },
  {
    "country": "UA",
    "name": "Mysovoe",
    "lat": "45.44788",
    "lng": "35.83528"
  },
  {
    "country": "UA",
    "name": "Shchyolkino",
    "lat": "45.42985",
    "lng": "35.8225"
  },
  {
    "country": "UA",
    "name": "Mykolaiv",
    "lat": "49.52372",
    "lng": "23.98522"
  },
  {
    "country": "UA",
    "name": "Mykolayiv",
    "lat": "46.96591",
    "lng": "31.9974"
  },
  {
    "country": "UA",
    "name": "Muzhiyevo",
    "lat": "48.17959",
    "lng": "22.69943"
  },
  {
    "country": "UA",
    "name": "Muskatnoye",
    "lat": "45.46586",
    "lng": "34.54316"
  },
  {
    "country": "UA",
    "name": "Murovani Kurylivtsi",
    "lat": "48.72348",
    "lng": "27.51892"
  },
  {
    "country": "UA",
    "name": "Murovane",
    "lat": "49.52143",
    "lng": "22.9367"
  },
  {
    "country": "UA",
    "name": "Mukacheve",
    "lat": "48.43919",
    "lng": "22.71779"
  },
  {
    "country": "UA",
    "name": "Mostys'ka",
    "lat": "49.79467",
    "lng": "23.15077"
  },
  {
    "country": "UA",
    "name": "Mospyne",
    "lat": "47.89081",
    "lng": "38.06395"
  },
  {
    "country": "UA",
    "name": "Moshny",
    "lat": "49.51473",
    "lng": "31.74757"
  },
  {
    "country": "UA",
    "name": "Morskoye",
    "lat": "44.82593",
    "lng": "34.80314"
  },
  {
    "country": "UA",
    "name": "Morshyn",
    "lat": "49.15652",
    "lng": "23.87232"
  },
  {
    "country": "UA",
    "name": "Monastyrys’ka",
    "lat": "49.08909",
    "lng": "25.17327"
  },
  {
    "country": "UA",
    "name": "Monastyryshche",
    "lat": "48.9909",
    "lng": "29.8047"
  },
  {
    "country": "UA",
    "name": "Molodohvardiys’k",
    "lat": "48.34511",
    "lng": "39.65244"
  },
  {
    "country": "UA",
    "name": "Molodiya",
    "lat": "48.22326",
    "lng": "26.02139"
  },
  {
    "country": "UA",
    "name": "Molodizhne",
    "lat": "48.17732",
    "lng": "32.66015"
  },
  {
    "country": "UA",
    "name": "Molodyozhnoye",
    "lat": "45.00354",
    "lng": "34.05634"
  },
  {
    "country": "UA",
    "name": "Molochnoye",
    "lat": "45.1996",
    "lng": "33.22233"
  },
  {
    "country": "UA",
    "name": "Mohyliv-Podilskyi",
    "lat": "48.44598",
    "lng": "27.7982"
  },
  {
    "country": "UA",
    "name": "Mlyniv",
    "lat": "50.509",
    "lng": "25.61675"
  },
  {
    "country": "UA",
    "name": "Mleyev",
    "lat": "49.34434",
    "lng": "31.5339"
  },
  {
    "country": "UA",
    "name": "Mizoch",
    "lat": "50.4",
    "lng": "26.15"
  },
  {
    "country": "UA",
    "name": "Miusyns’k",
    "lat": "48.0775",
    "lng": "38.90364"
  },
  {
    "country": "UA",
    "name": "Mityayevo",
    "lat": "45.23423",
    "lng": "33.7015"
  },
  {
    "country": "UA",
    "name": "Mitrofanovka",
    "lat": "45.45114",
    "lng": "34.67883"
  },
  {
    "country": "UA",
    "name": "Mirovka",
    "lat": "49.93126",
    "lng": "30.62309"
  },
  {
    "country": "UA",
    "name": "Myronivka",
    "lat": "49.66007",
    "lng": "30.98225"
  },
  {
    "country": "UA",
    "name": "Mirny",
    "lat": "45.30788",
    "lng": "33.03501"
  },
  {
    "country": "UA",
    "name": "Myrhorod",
    "lat": "49.96854",
    "lng": "33.60886"
  },
  {
    "country": "UA",
    "name": "Mynay",
    "lat": "48.5888",
    "lng": "22.27502"
  },
  {
    "country": "UA",
    "name": "Milove",
    "lat": "49.37528",
    "lng": "40.13222"
  },
  {
    "country": "UA",
    "name": "Mikulintsy",
    "lat": "49.396",
    "lng": "25.60518"
  },
  {
    "country": "UA",
    "name": "Mykhaylivka",
    "lat": "47.27235",
    "lng": "35.22235"
  },
  {
    "country": "UA",
    "name": "Mikhaylovka",
    "lat": "45.52838",
    "lng": "34.64058"
  },
  {
    "country": "UA",
    "name": "Mikhaylovka",
    "lat": "45.11325",
    "lng": "33.61071"
  },
  {
    "country": "UA",
    "name": "Myhove",
    "lat": "48.15749",
    "lng": "25.37904"
  },
  {
    "country": "UA",
    "name": "Myhiya",
    "lat": "48.03719",
    "lng": "30.95153"
  },
  {
    "country": "UA",
    "name": "Michurinskoye",
    "lat": "45.0743",
    "lng": "34.70672"
  },
  {
    "country": "UA",
    "name": "Mezhvodnoye",
    "lat": "45.58751",
    "lng": "32.84501"
  },
  {
    "country": "UA",
    "name": "Velyki Mezhyrichi",
    "lat": "50.65431",
    "lng": "26.86626"
  },
  {
    "country": "UA",
    "name": "Chudey",
    "lat": "48.05247",
    "lng": "25.62208"
  },
  {
    "country": "UA",
    "name": "Mizhhirya",
    "lat": "48.52458",
    "lng": "23.50563"
  },
  {
    "country": "UA",
    "name": "Mezhova",
    "lat": "48.25318",
    "lng": "36.73468"
  },
  {
    "country": "UA",
    "name": "Mezenivka",
    "lat": "50.63486",
    "lng": "35.3134"
  },
  {
    "country": "UA",
    "name": "Merefa",
    "lat": "49.82302",
    "lng": "36.05069"
  },
  {
    "country": "UA",
    "name": "Zhuravlyovka",
    "lat": "45.1768",
    "lng": "33.9968"
  },
  {
    "country": "UA",
    "name": "Mena",
    "lat": "51.5217",
    "lng": "32.21568"
  },
  {
    "country": "UA",
    "name": "Melitopol",
    "lat": "46.84891",
    "lng": "35.36533"
  },
  {
    "country": "UA",
    "name": "Melioratyvne",
    "lat": "48.63009",
    "lng": "35.41558"
  },
  {
    "country": "UA",
    "name": "Melekyne",
    "lat": "46.95957",
    "lng": "37.39981"
  },
  {
    "country": "UA",
    "name": "Medzhybizh",
    "lat": "49.43748",
    "lng": "27.40487"
  },
  {
    "country": "UA",
    "name": "Medvedevo",
    "lat": "45.38597",
    "lng": "33.004"
  },
  {
    "country": "UA",
    "name": "Medvedevka",
    "lat": "45.88389",
    "lng": "34.55562"
  },
  {
    "country": "UA",
    "name": "Medenychi",
    "lat": "49.43055",
    "lng": "23.75073"
  },
  {
    "country": "UA",
    "name": "Mazanka",
    "lat": "45.0055",
    "lng": "34.25581"
  },
  {
    "country": "UA",
    "name": "Mayskoye",
    "lat": "45.59555",
    "lng": "34.55213"
  },
  {
    "country": "UA",
    "name": "Mayaky",
    "lat": "46.41748",
    "lng": "30.27413"
  },
  {
    "country": "UA",
    "name": "Matviyivka",
    "lat": "47.07473",
    "lng": "35.14444"
  },
  {
    "country": "UA",
    "name": "Massandra",
    "lat": "44.50958",
    "lng": "34.18817"
  },
  {
    "country": "UA",
    "name": "Mashivka",
    "lat": "49.44308",
    "lng": "34.86688"
  },
  {
    "country": "UA",
    "name": "Maryevka",
    "lat": "45.1133",
    "lng": "36.23992"
  },
  {
    "country": "UA",
    "name": "Marshintsy",
    "lat": "48.21751",
    "lng": "26.29133"
  },
  {
    "country": "UA",
    "name": "Markivka",
    "lat": "49.5229",
    "lng": "39.57055"
  },
  {
    "country": "UA",
    "name": "Markova",
    "lat": "48.67576",
    "lng": "24.41382"
  },
  {
    "country": "UA",
    "name": "Mariupol",
    "lat": "47.09514",
    "lng": "37.54131"
  },
  {
    "country": "UA",
    "name": "Mar'yinka",
    "lat": "47.94527",
    "lng": "37.50544"
  },
  {
    "country": "UA",
    "name": "Krinichnoye",
    "lat": "45.02428",
    "lng": "34.61202"
  },
  {
    "country": "UA",
    "name": "Marhanets’",
    "lat": "47.63543",
    "lng": "34.62769"
  },
  {
    "country": "UA",
    "name": "Marfovka",
    "lat": "45.19853",
    "lng": "36.09144"
  },
  {
    "country": "UA",
    "name": "Mar’yanovka",
    "lat": "45.44627",
    "lng": "34.29474"
  },
  {
    "country": "UA",
    "name": "Manyava",
    "lat": "48.65541",
    "lng": "24.37537"
  },
  {
    "country": "UA",
    "name": "Mankivka",
    "lat": "48.96349",
    "lng": "30.33366"
  },
  {
    "country": "UA",
    "name": "Manevychi",
    "lat": "51.29405",
    "lng": "25.53436"
  },
  {
    "country": "UA",
    "name": "Manchenky",
    "lat": "49.97982",
    "lng": "35.85835"
  },
  {
    "country": "UA",
    "name": "Maly Mayak",
    "lat": "44.61356",
    "lng": "34.36469"
  },
  {
    "country": "UA",
    "name": "Muromskoye",
    "lat": "45.09051",
    "lng": "34.849"
  },
  {
    "country": "UA",
    "name": "Malorechenskoye",
    "lat": "44.75888",
    "lng": "34.55789"
  },
  {
    "country": "UA",
    "name": "Malokaterynivka",
    "lat": "47.6555",
    "lng": "35.25649"
  },
  {
    "country": "UA",
    "name": "Malokakhovka",
    "lat": "46.78142",
    "lng": "33.4479"
  },
  {
    "country": "UA",
    "name": "Malyn",
    "lat": "50.77233",
    "lng": "29.23833"
  },
  {
    "country": "UA",
    "name": "Mala Vyska",
    "lat": "48.64308",
    "lng": "31.63657"
  },
  {
    "country": "UA",
    "name": "Mala Tokmachka",
    "lat": "47.53563",
    "lng": "35.89293"
  },
  {
    "country": "UA",
    "name": "Mala Danylivka",
    "lat": "50.06354",
    "lng": "36.16564"
  },
  {
    "country": "UA",
    "name": "Mala Bilozerka",
    "lat": "47.24737",
    "lng": "34.93457"
  },
  {
    "country": "UA",
    "name": "Yantarnoye",
    "lat": "45.43473",
    "lng": "34.22134"
  },
  {
    "country": "UA",
    "name": "Makiv",
    "lat": "48.79487",
    "lng": "26.69188"
  },
  {
    "country": "UA",
    "name": "Makiyivka",
    "lat": "48.04782",
    "lng": "37.92576"
  },
  {
    "country": "UA",
    "name": "Makariv",
    "lat": "50.46408",
    "lng": "29.81128"
  },
  {
    "country": "UA",
    "name": "Mahdalynivka",
    "lat": "48.92111",
    "lng": "34.91491"
  },
  {
    "country": "UA",
    "name": "Magazinka",
    "lat": "45.86312",
    "lng": "34.04969"
  },
  {
    "country": "UA",
    "name": "Liutizh",
    "lat": "50.6835",
    "lng": "30.39324"
  },
  {
    "country": "UA",
    "name": "Lyubotyn",
    "lat": "49.94691",
    "lng": "35.92907"
  },
  {
    "country": "UA",
    "name": "Liuboml",
    "lat": "51.22601",
    "lng": "24.03727"
  },
  {
    "country": "UA",
    "name": "Lyubymivka",
    "lat": "46.81063",
    "lng": "33.56862"
  },
  {
    "country": "UA",
    "name": "Lyubeshiv",
    "lat": "51.76535",
    "lng": "25.5142"
  },
  {
    "country": "UA",
    "name": "Lyubech",
    "lat": "51.7026",
    "lng": "30.65692"
  },
  {
    "country": "UA",
    "name": "Liubar",
    "lat": "49.92045",
    "lng": "27.75918"
  },
  {
    "country": "UA",
    "name": "Lysianka",
    "lat": "49.25229",
    "lng": "30.82946"
  },
  {
    "country": "UA",
    "name": "Lysa Hora",
    "lat": "48.17059",
    "lng": "31.10994"
  },
  {
    "country": "UA",
    "name": "Lviv",
    "lat": "49.83826",
    "lng": "24.02324"
  },
  {
    "country": "UA",
    "name": "Luzhany",
    "lat": "48.36492",
    "lng": "25.77173"
  },
  {
    "country": "UA",
    "name": "Lutuhyne",
    "lat": "48.40507",
    "lng": "39.22675"
  },
  {
    "country": "UA",
    "name": "Lutsk",
    "lat": "50.75932",
    "lng": "25.34244"
  },
  {
    "country": "UA",
    "name": "Lutovynivka",
    "lat": "49.23726",
    "lng": "33.9051"
  },
  {
    "country": "UA",
    "name": "Lukiv",
    "lat": "51.0521",
    "lng": "25.40059"
  },
  {
    "country": "UA",
    "name": "Luhansk",
    "lat": "48.56705",
    "lng": "39.31706"
  },
  {
    "country": "UA",
    "name": "Lugovoye",
    "lat": "45.23469",
    "lng": "35.72202"
  },
  {
    "country": "UA",
    "name": "Luhyny",
    "lat": "51.08203",
    "lng": "28.40057"
  },
  {
    "country": "UA",
    "name": "Luhans’ke",
    "lat": "48.44574",
    "lng": "38.26153"
  },
  {
    "country": "UA",
    "name": "Luchistoye",
    "lat": "44.73646",
    "lng": "34.40063"
  },
  {
    "country": "UA",
    "name": "Lubny",
    "lat": "50.01625",
    "lng": "32.99694"
  },
  {
    "country": "UA",
    "name": "Lozovoye",
    "lat": "44.906",
    "lng": "34.16414"
  },
  {
    "country": "UA",
    "name": "Lozova",
    "lat": "48.88937",
    "lng": "36.31755"
  },
  {
    "country": "UA",
    "name": "Lozuvatka",
    "lat": "48.0571",
    "lng": "33.28581"
  },
  {
    "country": "UA",
    "name": "Lozno-Oleksandrivka",
    "lat": "49.8391",
    "lng": "38.74098"
  },
  {
    "country": "UA",
    "name": "Lopukhiv",
    "lat": "48.36527",
    "lng": "23.96382"
  },
  {
    "country": "UA",
    "name": "Lopatyn",
    "lat": "50.22022",
    "lng": "24.84831"
  },
  {
    "country": "UA",
    "name": "Lokhvytsya",
    "lat": "50.36776",
    "lng": "33.26024"
  },
  {
    "country": "UA",
    "name": "Lokachi",
    "lat": "50.737",
    "lng": "24.64944"
  },
  {
    "country": "UA",
    "name": "Lobanovo",
    "lat": "45.77552",
    "lng": "34.24236"
  },
  {
    "country": "UA",
    "name": "Lyubashivka",
    "lat": "47.83716",
    "lng": "30.25976"
  },
  {
    "country": "UA",
    "name": "Livadia",
    "lat": "44.47021",
    "lng": "34.14272"
  },
  {
    "country": "UA",
    "name": "Litvinenkovo",
    "lat": "45.08648",
    "lng": "34.31107"
  },
  {
    "country": "UA",
    "name": "Lityn",
    "lat": "49.32509",
    "lng": "28.08094"
  },
  {
    "country": "UA",
    "name": "Lysychovo",
    "lat": "48.49677",
    "lng": "23.28992"
  },
  {
    "country": "UA",
    "name": "Lysychans’k",
    "lat": "48.90485",
    "lng": "38.44207"
  },
  {
    "country": "UA",
    "name": "Lypovets",
    "lat": "49.22964",
    "lng": "29.05555"
  },
  {
    "country": "UA",
    "name": "Lypova Dolyna",
    "lat": "50.56428",
    "lng": "33.79793"
  },
  {
    "country": "UA",
    "name": "Lypnyazhka",
    "lat": "48.44694",
    "lng": "31.07611"
  },
  {
    "country": "UA",
    "name": "Lypcha",
    "lat": "48.26107",
    "lng": "23.38336"
  },
  {
    "country": "UA",
    "name": "Lymanske",
    "lat": "46.6557",
    "lng": "29.96722"
  },
  {
    "country": "UA",
    "name": "Lyman",
    "lat": "49.59769",
    "lng": "36.4703"
  },
  {
    "country": "UA",
    "name": "Lykhivka",
    "lat": "48.68735",
    "lng": "33.92279"
  },
  {
    "country": "UA",
    "name": "Letychiv",
    "lat": "49.38263",
    "lng": "27.63051"
  },
  {
    "country": "UA",
    "name": "Lisovi Sorochyntsi",
    "lat": "50.6892",
    "lng": "32.32919"
  },
  {
    "country": "UA",
    "name": "Leninskoye",
    "lat": "45.26844",
    "lng": "34.05023"
  },
  {
    "country": "UA",
    "name": "Leninskoye",
    "lat": "45.25373",
    "lng": "35.91969"
  },
  {
    "country": "UA",
    "name": "Lenino",
    "lat": "45.29857",
    "lng": "35.77708"
  },
  {
    "country": "UA",
    "name": "Lenina",
    "lat": "48.42944",
    "lng": "39.14556"
  },
  {
    "country": "UA",
    "name": "Lebedyn",
    "lat": "48.96242",
    "lng": "31.52696"
  },
  {
    "country": "UA",
    "name": "Lazurne",
    "lat": "46.084",
    "lng": "32.52955"
  },
  {
    "country": "UA",
    "name": "Lazi",
    "lat": "48.06667",
    "lng": "24.23333"
  },
  {
    "country": "UA",
    "name": "Lazeshchyna",
    "lat": "48.26852",
    "lng": "24.4201"
  },
  {
    "country": "UA",
    "name": "Lanivtsi",
    "lat": "49.86328",
    "lng": "26.09082"
  },
  {
    "country": "UA",
    "name": "Lanchyn",
    "lat": "48.55781",
    "lng": "24.75622"
  },
  {
    "country": "UA",
    "name": "Ladyzhyn",
    "lat": "48.68496",
    "lng": "29.23679"
  },
  {
    "country": "UA",
    "name": "Ladan",
    "lat": "50.51959",
    "lng": "32.58178"
  },
  {
    "country": "UA",
    "name": "Kyiv",
    "lat": "50.45466",
    "lng": "30.5238"
  },
  {
    "country": "UA",
    "name": "Kvasy",
    "lat": "48.14973",
    "lng": "24.27995"
  },
  {
    "country": "UA",
    "name": "Kuybysheve",
    "lat": "47.358",
    "lng": "36.64908"
  },
  {
    "country": "UA",
    "name": "Kuibyshevo",
    "lat": "44.629",
    "lng": "33.86895"
  },
  {
    "country": "UA",
    "name": "Kuty",
    "lat": "48.25868",
    "lng": "25.17946"
  },
  {
    "country": "UA",
    "name": "Kuteynykove",
    "lat": "47.81227",
    "lng": "38.28822"
  },
  {
    "country": "UA",
    "name": "Kushuhum",
    "lat": "47.71278",
    "lng": "35.20917"
  },
  {
    "country": "UA",
    "name": "Kushnytsya",
    "lat": "48.43988",
    "lng": "23.25816"
  },
  {
    "country": "UA",
    "name": "Kurakhovo",
    "lat": "47.98522",
    "lng": "37.2821"
  },
  {
    "country": "UA",
    "name": "Kupjansk",
    "lat": "49.71055",
    "lng": "37.61517"
  },
  {
    "country": "UA",
    "name": "Kulynychi",
    "lat": "49.98178",
    "lng": "36.38283"
  },
  {
    "country": "UA",
    "name": "Kulykivka",
    "lat": "51.37345",
    "lng": "31.64661"
  },
  {
    "country": "UA",
    "name": "Kulykiv",
    "lat": "50.31424",
    "lng": "24.81757"
  },
  {
    "country": "UA",
    "name": "Kryzhopil’",
    "lat": "48.38289",
    "lng": "28.86622"
  },
  {
    "country": "UA",
    "name": "Kryzhanivka",
    "lat": "46.56167",
    "lng": "30.79487"
  },
  {
    "country": "UA",
    "name": "Kryvyi Rih",
    "lat": "47.90966",
    "lng": "33.38044"
  },
  {
    "country": "UA",
    "name": "Krymskoye",
    "lat": "45.18836",
    "lng": "33.80106"
  },
  {
    "country": "UA",
    "name": "Krymka",
    "lat": "45.70453",
    "lng": "34.18782"
  },
  {
    "country": "UA",
    "name": "Kruty",
    "lat": "51.05974",
    "lng": "32.10634"
  },
  {
    "country": "UA",
    "name": "Krolevets’",
    "lat": "51.54775",
    "lng": "33.38475"
  },
  {
    "country": "UA",
    "name": "Kryve Ozero",
    "lat": "47.95242",
    "lng": "30.34928"
  },
  {
    "country": "UA",
    "name": "Kryva Luka",
    "lat": "48.87382",
    "lng": "37.90327"
  },
  {
    "country": "UA",
    "name": "Kryva Hora",
    "lat": "51.38495",
    "lng": "30.19978"
  },
  {
    "country": "UA",
    "name": "Kryva",
    "lat": "48.17234",
    "lng": "23.23647"
  },
  {
    "country": "UA",
    "name": "Krinichnaya",
    "lat": "48.12899",
    "lng": "38.02597"
  },
  {
    "country": "UA",
    "name": "Krynychky",
    "lat": "48.37551",
    "lng": "34.46701"
  },
  {
    "country": "UA",
    "name": "Krest’yanovka",
    "lat": "45.72268",
    "lng": "33.93938"
  },
  {
    "country": "UA",
    "name": "Kripens’kyy",
    "lat": "48.07709",
    "lng": "39.058"
  },
  {
    "country": "UA",
    "name": "Tatariv",
    "lat": "48.34558",
    "lng": "24.57836"
  },
  {
    "country": "UA",
    "name": "Kreminna",
    "lat": "49.0495",
    "lng": "38.21792"
  },
  {
    "country": "UA",
    "name": "Kremenets",
    "lat": "50.09693",
    "lng": "25.72459"
  },
  {
    "country": "UA",
    "name": "Kremenchuk",
    "lat": "49.06802",
    "lng": "33.42041"
  },
  {
    "country": "UA",
    "name": "Krayneye",
    "lat": "45.22993",
    "lng": "33.83239"
  },
  {
    "country": "UA",
    "name": "Krasyatychi",
    "lat": "51.07636",
    "lng": "29.64899"
  },
  {
    "country": "UA",
    "name": "Krasnyi Mak",
    "lat": "44.64218",
    "lng": "33.7813"
  },
  {
    "country": "UA",
    "name": "Krasnyy Luch",
    "lat": "48.13954",
    "lng": "38.93715"
  },
  {
    "country": "UA",
    "name": "Lyman",
    "lat": "48.98837",
    "lng": "37.80225"
  },
  {
    "country": "UA",
    "name": "Krasnyy Kut",
    "lat": "48.20138",
    "lng": "38.79765"
  },
  {
    "country": "UA",
    "name": "Krasnoznamenka",
    "lat": "45.28676",
    "lng": "34.00036"
  },
  {
    "country": "UA",
    "name": "Krasne",
    "lat": "49.91447",
    "lng": "24.6134"
  },
  {
    "country": "UA",
    "name": "Krasne",
    "lat": "46.13088",
    "lng": "32.7691"
  },
  {
    "country": "UA",
    "name": "Krasnoyarskoye",
    "lat": "45.50661",
    "lng": "33.26641"
  },
  {
    "country": "UA",
    "name": "Krasnotorka",
    "lat": "48.68204",
    "lng": "37.53266"
  },
  {
    "country": "UA",
    "name": "Krasnosilka",
    "lat": "46.62258",
    "lng": "30.77421"
  },
  {
    "country": "UA",
    "name": "Krasnopillya",
    "lat": "50.77458",
    "lng": "35.25965"
  },
  {
    "country": "UA",
    "name": "Krasnoperekops’k",
    "lat": "45.95716",
    "lng": "33.7965"
  },
  {
    "country": "UA",
    "name": "Krasnopavlivka",
    "lat": "49.13643",
    "lng": "36.31911"
  },
  {
    "country": "UA",
    "name": "Krasnolesye",
    "lat": "44.83259",
    "lng": "34.23086"
  },
  {
    "country": "UA",
    "name": "Krasnokuts’k",
    "lat": "50.06602",
    "lng": "35.16275"
  },
  {
    "country": "UA",
    "name": "Krasnokamenka",
    "lat": "44.56383",
    "lng": "34.28877"
  },
  {
    "country": "UA",
    "name": "Krasnogvardeyskoye",
    "lat": "45.50271",
    "lng": "34.30134"
  },
  {
    "country": "UA",
    "name": "Krasnogvardeyskoye",
    "lat": "45.18348",
    "lng": "34.95066"
  },
  {
    "country": "UA",
    "name": "Krasnohrad",
    "lat": "49.38009",
    "lng": "35.44186"
  },
  {
    "country": "UA",
    "name": "Krasnogorka",
    "lat": "45.24513",
    "lng": "35.80739"
  },
  {
    "country": "UA",
    "name": "Krasnoflotskoye",
    "lat": "45.31572",
    "lng": "34.94756"
  },
  {
    "country": "UA",
    "name": "Teple",
    "lat": "48.31245",
    "lng": "39.56284"
  },
  {
    "country": "UA",
    "name": "Sorokyne",
    "lat": "48.29235",
    "lng": "39.73921"
  },
  {
    "country": "UA",
    "name": "Krasnoarmeyskoye",
    "lat": "45.99103",
    "lng": "34.03037"
  },
  {
    "country": "UA",
    "name": "Pokrovsk",
    "lat": "48.28198",
    "lng": "37.17585"
  },
  {
    "country": "UA",
    "name": "Krasnaya Zor’ka",
    "lat": "45.13432",
    "lng": "34.04015"
  },
  {
    "country": "UA",
    "name": "Krymskaya Roza",
    "lat": "45.05776",
    "lng": "34.35631"
  },
  {
    "country": "UA",
    "name": "Krasnaya Polyana",
    "lat": "45.48241",
    "lng": "32.9379"
  },
  {
    "country": "UA",
    "name": "Krasna",
    "lat": "48.57571",
    "lng": "24.70027"
  },
  {
    "country": "UA",
    "name": "Krasyliv",
    "lat": "49.65186",
    "lng": "26.97253"
  },
  {
    "country": "UA",
    "name": "Kramators’k",
    "lat": "48.72305",
    "lng": "37.55629"
  },
  {
    "country": "UA",
    "name": "Kozova",
    "lat": "49.43544",
    "lng": "25.15086"
  },
  {
    "country": "UA",
    "name": "Kozhanka",
    "lat": "49.97231",
    "lng": "29.76424"
  },
  {
    "country": "UA",
    "name": "Kozel’shchyna",
    "lat": "49.21682",
    "lng": "33.8481"
  },
  {
    "country": "UA",
    "name": "Kozelets’",
    "lat": "50.91334",
    "lng": "31.1214"
  },
  {
    "country": "UA",
    "name": "Kivsharivka",
    "lat": "49.63096",
    "lng": "37.68821"
  },
  {
    "country": "UA",
    "name": "Kovel",
    "lat": "51.21526",
    "lng": "24.70867"
  },
  {
    "country": "UA",
    "name": "Kotsyubyns’ke",
    "lat": "50.48836",
    "lng": "30.32957"
  },
  {
    "country": "UA",
    "name": "Podil’s’k",
    "lat": "47.75305",
    "lng": "29.53205"
  },
  {
    "country": "UA",
    "name": "Kotel’va",
    "lat": "50.06864",
    "lng": "34.75862"
  },
  {
    "country": "UA",
    "name": "Kotel’nikovo",
    "lat": "45.36584",
    "lng": "34.02575"
  },
  {
    "country": "UA",
    "name": "Kostyantynivka",
    "lat": "47.8266",
    "lng": "31.13551"
  },
  {
    "country": "UA",
    "name": "Kostryzhivka",
    "lat": "48.65455",
    "lng": "25.71316"
  },
  {
    "country": "UA",
    "name": "Kostopil’",
    "lat": "50.87841",
    "lng": "26.45192"
  },
  {
    "country": "UA",
    "name": "Kosiv",
    "lat": "48.31071",
    "lng": "25.09575"
  },
  {
    "country": "UA",
    "name": "Kosmach",
    "lat": "48.75089",
    "lng": "24.36731"
  },
  {
    "country": "UA",
    "name": "Kosmach",
    "lat": "48.32991",
    "lng": "24.82052"
  },
  {
    "country": "UA",
    "name": "Koson’",
    "lat": "48.25505",
    "lng": "22.45597"
  },
  {
    "country": "UA",
    "name": "Koryukivka",
    "lat": "51.76877",
    "lng": "32.24813"
  },
  {
    "country": "UA",
    "name": "Korsun-Shevchenkivskyi",
    "lat": "49.41894",
    "lng": "31.25865"
  },
  {
    "country": "UA",
    "name": "Korotych",
    "lat": "49.94737",
    "lng": "36.03736"
  },
  {
    "country": "UA",
    "name": "Korostyshiv",
    "lat": "50.31723",
    "lng": "29.0563"
  },
  {
    "country": "UA",
    "name": "Korosten’",
    "lat": "50.95937",
    "lng": "28.63855"
  },
  {
    "country": "UA",
    "name": "Korop",
    "lat": "51.56638",
    "lng": "32.95861"
  },
  {
    "country": "UA",
    "name": "Korolevo",
    "lat": "48.15247",
    "lng": "23.13659"
  },
  {
    "country": "UA",
    "name": "Kornyn",
    "lat": "50.0953",
    "lng": "29.53581"
  },
  {
    "country": "UA",
    "name": "Korniyivka",
    "lat": "50.41661",
    "lng": "31.46261"
  },
  {
    "country": "UA",
    "name": "Kormovoye",
    "lat": "45.50001",
    "lng": "33.61192"
  },
  {
    "country": "UA",
    "name": "Korets",
    "lat": "50.61655",
    "lng": "27.16055"
  },
  {
    "country": "UA",
    "name": "Koreiz",
    "lat": "44.43374",
    "lng": "34.08516"
  },
  {
    "country": "UA",
    "name": "Kopychyntsi",
    "lat": "49.10441",
    "lng": "25.91026"
  },
  {
    "country": "UA",
    "name": "Kopayhorod",
    "lat": "48.85917",
    "lng": "27.7969"
  },
  {
    "country": "UA",
    "name": "Kostyantynivka",
    "lat": "48.5277",
    "lng": "37.7069"
  },
  {
    "country": "UA",
    "name": "Kostyantynivka",
    "lat": "46.81673",
    "lng": "35.42287"
  },
  {
    "country": "UA",
    "name": "Konotop",
    "lat": "51.24032",
    "lng": "33.20263"
  },
  {
    "country": "UA",
    "name": "Kondratyevo",
    "lat": "45.63125",
    "lng": "34.47387"
  },
  {
    "country": "UA",
    "name": "Slobozhans’ke",
    "lat": "49.59701",
    "lng": "36.52618"
  },
  {
    "country": "UA",
    "name": "Kompaniyivka",
    "lat": "48.25115",
    "lng": "32.20795"
  },
  {
    "country": "UA",
    "name": "Dobroslav",
    "lat": "46.8128",
    "lng": "30.93934"
  },
  {
    "country": "UA",
    "name": "Komarno",
    "lat": "49.62739",
    "lng": "23.69952"
  },
  {
    "country": "UA",
    "name": "Kol’tsovo",
    "lat": "45.32807",
    "lng": "33.44992"
  },
  {
    "country": "UA",
    "name": "Koloski",
    "lat": "45.26936",
    "lng": "33.29386"
  },
  {
    "country": "UA",
    "name": "Koloniya Zastav’ye",
    "lat": "50.81667",
    "lng": "27.03333"
  },
  {
    "country": "UA",
    "name": "Kolomyia",
    "lat": "48.53115",
    "lng": "25.03649"
  },
  {
    "country": "UA",
    "name": "Kolomak",
    "lat": "49.83987",
    "lng": "35.30441"
  },
  {
    "country": "UA",
    "name": "Kolodeznoye",
    "lat": "45.22682",
    "lng": "34.33698"
  },
  {
    "country": "UA",
    "name": "Kolodenka",
    "lat": "50.58561",
    "lng": "26.31601"
  },
  {
    "country": "UA",
    "name": "Kolochava",
    "lat": "48.42851",
    "lng": "23.6959"
  },
  {
    "country": "UA",
    "name": "Kulevcha",
    "lat": "46.03034",
    "lng": "29.93614"
  },
  {
    "country": "UA",
    "name": "Kol’chugino",
    "lat": "44.94367",
    "lng": "33.78865"
  },
  {
    "country": "UA",
    "name": "Kodyma",
    "lat": "48.09875",
    "lng": "29.12463"
  },
  {
    "country": "UA",
    "name": "Kodra",
    "lat": "50.59488",
    "lng": "29.55873"
  },
  {
    "country": "UA",
    "name": "Kochetok",
    "lat": "49.88005",
    "lng": "36.73723"
  },
  {
    "country": "UA",
    "name": "Kobyzhcha",
    "lat": "50.82854",
    "lng": "31.50439"
  },
  {
    "country": "UA",
    "name": "Kobleve",
    "lat": "46.66499",
    "lng": "31.20804"
  },
  {
    "country": "UA",
    "name": "Kobelyaky",
    "lat": "49.14892",
    "lng": "34.19653"
  },
  {
    "country": "UA",
    "name": "Knyazhichi",
    "lat": "50.46275",
    "lng": "30.78369"
  },
  {
    "country": "UA",
    "name": "Klishkivtsi",
    "lat": "48.43161",
    "lng": "26.26231"
  },
  {
    "country": "UA",
    "name": "Klevan’",
    "lat": "50.74305",
    "lng": "25.97628"
  },
  {
    "country": "UA",
    "name": "Klenovyy",
    "lat": "48.11934",
    "lng": "39.4588"
  },
  {
    "country": "UA",
    "name": "Klembivka",
    "lat": "48.39037",
    "lng": "28.41092"
  },
  {
    "country": "UA",
    "name": "Klavdiyevo-Tarasove",
    "lat": "50.58416",
    "lng": "30.01134"
  },
  {
    "country": "UA",
    "name": "Kivertsi",
    "lat": "50.83425",
    "lng": "25.45821"
  },
  {
    "country": "UA",
    "name": "Kitsman’",
    "lat": "48.44357",
    "lng": "25.7668"
  },
  {
    "country": "UA",
    "name": "Shirokoye",
    "lat": "45.20029",
    "lng": "34.05069"
  },
  {
    "country": "UA",
    "name": "Kirovskoye",
    "lat": "45.54503",
    "lng": "33.07769"
  },
  {
    "country": "UA",
    "name": "Kirovskoye",
    "lat": "45.22967",
    "lng": "35.19987"
  },
  {
    "country": "UA",
    "name": "Zarichne",
    "lat": "49.0234",
    "lng": "37.93161"
  },
  {
    "country": "UA",
    "name": "Kirovs’k",
    "lat": "48.63751",
    "lng": "38.6428"
  },
  {
    "country": "UA",
    "name": "Kropyvnytskyi",
    "lat": "48.5132",
    "lng": "32.2597"
  },
  {
    "country": "UA",
    "name": "Kirovo",
    "lat": "45.22106",
    "lng": "35.84227"
  },
  {
    "country": "UA",
    "name": "Kyrylivka",
    "lat": "46.37592",
    "lng": "35.36753"
  },
  {
    "country": "UA",
    "name": "Kyrykivka",
    "lat": "50.36408",
    "lng": "35.1149"
  },
  {
    "country": "UA",
    "name": "Kiliya",
    "lat": "45.45518",
    "lng": "29.26367"
  },
  {
    "country": "UA",
    "name": "Khyriv",
    "lat": "49.53417",
    "lng": "22.85538"
  },
  {
    "country": "UA",
    "name": "Khust",
    "lat": "48.1793",
    "lng": "23.29909"
  },
  {
    "country": "UA",
    "name": "Khrystynivka",
    "lat": "48.82488",
    "lng": "29.96805"
  },
  {
    "country": "UA",
    "name": "Khotiv",
    "lat": "50.33069",
    "lng": "30.46836"
  },
  {
    "country": "UA",
    "name": "Khotyn",
    "lat": "48.50693",
    "lng": "26.49121"
  },
  {
    "country": "UA",
    "name": "Khorostkiv",
    "lat": "49.21114",
    "lng": "25.92165"
  },
  {
    "country": "UA",
    "name": "Khorosheve",
    "lat": "49.85413",
    "lng": "36.21704"
  },
  {
    "country": "UA",
    "name": "Khorol",
    "lat": "49.78367",
    "lng": "33.27833"
  },
  {
    "country": "UA",
    "name": "Kholmy",
    "lat": "51.87096",
    "lng": "32.60063"
  },
  {
    "country": "UA",
    "name": "Khodoriv",
    "lat": "49.40993",
    "lng": "24.3047"
  },
  {
    "country": "UA",
    "name": "Khmelnytskyi",
    "lat": "49.42161",
    "lng": "26.99653"
  },
  {
    "country": "UA",
    "name": "Khmilnyk",
    "lat": "49.55979",
    "lng": "27.95754"
  },
  {
    "country": "UA",
    "name": "Khymchyn",
    "lat": "48.38639",
    "lng": "25.14803"
  },
  {
    "country": "UA",
    "name": "Kherson",
    "lat": "46.65581",
    "lng": "32.6178"
  },
  {
    "country": "UA",
    "name": "Khartsyz’k",
    "lat": "48.04243",
    "lng": "38.14728"
  },
  {
    "country": "UA",
    "name": "Kharkiv",
    "lat": "49.98081",
    "lng": "36.25272"
  },
  {
    "country": "UA",
    "name": "Kerch",
    "lat": "45.3531",
    "lng": "36.47429"
  },
  {
    "country": "UA",
    "name": "Kel’mentsi",
    "lat": "48.46503",
    "lng": "26.83457"
  },
  {
    "country": "UA",
    "name": "Kehychivka",
    "lat": "49.28656",
    "lng": "35.76153"
  },
  {
    "country": "UA",
    "name": "Kozyatyn",
    "lat": "49.71431",
    "lng": "28.83385"
  },
  {
    "country": "UA",
    "name": "Kazanka",
    "lat": "47.84625",
    "lng": "32.82177"
  },
  {
    "country": "UA",
    "name": "Kozachi Laheri",
    "lat": "46.70372",
    "lng": "32.9776"
  },
  {
    "country": "UA",
    "name": "Kaydaki",
    "lat": "48.37678",
    "lng": "35.12398"
  },
  {
    "country": "UA",
    "name": "Katyuzhanka",
    "lat": "50.80595",
    "lng": "30.13763"
  },
  {
    "country": "UA",
    "name": "Katerynopil",
    "lat": "48.9553",
    "lng": "30.96823"
  },
  {
    "country": "UA",
    "name": "Karlivka",
    "lat": "49.45723",
    "lng": "35.12975"
  },
  {
    "country": "UA",
    "name": "Soledar",
    "lat": "48.67935",
    "lng": "38.08902"
  },
  {
    "country": "UA",
    "name": "Karapyshi",
    "lat": "49.64237",
    "lng": "30.79002"
  },
  {
    "country": "UA",
    "name": "Kapitanivka",
    "lat": "48.91719",
    "lng": "31.71671"
  },
  {
    "country": "UA",
    "name": "Kaniv",
    "lat": "49.75182",
    "lng": "31.46004"
  },
  {
    "country": "UA",
    "name": "Komysh-Zorya",
    "lat": "47.32755",
    "lng": "36.69298"
  },
  {
    "country": "UA",
    "name": "Komyshnya",
    "lat": "50.18359",
    "lng": "33.68269"
  },
  {
    "country": "UA",
    "name": "Kamyshevka Vtoraya",
    "lat": "46.23333",
    "lng": "29.83333"
  },
  {
    "country": "UA",
    "name": "Komyshuvakha",
    "lat": "47.71598",
    "lng": "35.52981"
  },
  {
    "country": "UA",
    "name": "Komyshany",
    "lat": "46.63716",
    "lng": "32.50719"
  },
  {
    "country": "UA",
    "name": "Kamianets-Podilskyi",
    "lat": "48.6845",
    "lng": "26.58559"
  },
  {
    "country": "UA",
    "name": "Kamennyye Potoki",
    "lat": "48.97974",
    "lng": "33.52638"
  },
  {
    "country": "UA",
    "name": "Millerovo",
    "lat": "48.16829",
    "lng": "39.16537"
  },
  {
    "country": "UA",
    "name": "Kamin-Kashyrskyi",
    "lat": "51.62412",
    "lng": "24.95864"
  },
  {
    "country": "UA",
    "name": "Kamenka-Na-Dnepre",
    "lat": "47.48481",
    "lng": "34.41146"
  },
  {
    "country": "UA",
    "name": "Kamionka Strumitowa",
    "lat": "50.10655",
    "lng": "24.34451"
  },
  {
    "country": "UA",
    "name": "Kamianka",
    "lat": "49.0318",
    "lng": "32.10396"
  },
  {
    "country": "UA",
    "name": "Kamianytsia",
    "lat": "48.69343",
    "lng": "22.3957"
  },
  {
    "country": "UA",
    "name": "Kalush",
    "lat": "49.01187",
    "lng": "24.37308"
  },
  {
    "country": "UA",
    "name": "Kalyny",
    "lat": "48.14078",
    "lng": "23.8738"
  },
  {
    "country": "UA",
    "name": "Kalynivka",
    "lat": "49.45389",
    "lng": "28.52608"
  },
  {
    "country": "UA",
    "name": "Kalinovka",
    "lat": "45.31658",
    "lng": "35.74643"
  },
  {
    "country": "UA",
    "name": "Kalinino",
    "lat": "45.74262",
    "lng": "33.77676"
  },
  {
    "country": "UA",
    "name": "Kalinino",
    "lat": "45.59521",
    "lng": "34.2203"
  },
  {
    "country": "UA",
    "name": "Kalcheva",
    "lat": "45.73746",
    "lng": "28.81441"
  },
  {
    "country": "UA",
    "name": "Kalanchak",
    "lat": "46.25623",
    "lng": "33.2907"
  },
  {
    "country": "UA",
    "name": "Mirnoye",
    "lat": "44.9833",
    "lng": "34.0616"
  },
  {
    "country": "UA",
    "name": "Kakhovka",
    "lat": "46.81371",
    "lng": "33.48698"
  },
  {
    "country": "UA",
    "name": "Kayiry",
    "lat": "46.94537",
    "lng": "33.70591"
  },
  {
    "country": "UA",
    "name": "Kaharlyk",
    "lat": "49.86233",
    "lng": "30.82815"
  },
  {
    "country": "UA",
    "name": "Kadubivtsi",
    "lat": "48.58337",
    "lng": "25.76871"
  },
  {
    "country": "UA",
    "name": "Kacha",
    "lat": "44.77635",
    "lng": "33.54387"
  },
  {
    "country": "UA",
    "name": "Izyumovka",
    "lat": "45.04437",
    "lng": "35.13717"
  },
  {
    "country": "UA",
    "name": "Izyum",
    "lat": "49.20875",
    "lng": "37.24849"
  },
  {
    "country": "UA",
    "name": "Izyaslav",
    "lat": "50.11947",
    "lng": "26.82125"
  },
  {
    "country": "UA",
    "name": "Izobil’noye",
    "lat": "45.57019",
    "lng": "34.94469"
  },
  {
    "country": "UA",
    "name": "Izobil’noye",
    "lat": "44.70276",
    "lng": "34.35357"
  },
  {
    "country": "UA",
    "name": "Izmayil",
    "lat": "45.34929",
    "lng": "28.84079"
  },
  {
    "country": "UA",
    "name": "Yizhivtsi",
    "lat": "48.03962",
    "lng": "25.66232"
  },
  {
    "country": "UA",
    "name": "Iza",
    "lat": "48.21525",
    "lng": "23.32867"
  },
  {
    "country": "UA",
    "name": "Ivanivka",
    "lat": "46.97569",
    "lng": "30.46998"
  },
  {
    "country": "UA",
    "name": "Ivanivka",
    "lat": "46.72082",
    "lng": "34.55298"
  },
  {
    "country": "UA",
    "name": "Ivanovka",
    "lat": "45.072",
    "lng": "33.6613"
  },
  {
    "country": "UA",
    "name": "Ivano-Frankivsk",
    "lat": "48.9215",
    "lng": "24.70972"
  },
  {
    "country": "UA",
    "name": "Ivankiv",
    "lat": "50.93865",
    "lng": "29.89426"
  },
  {
    "country": "UA",
    "name": "Ivanychi",
    "lat": "50.63879",
    "lng": "24.36003"
  },
  {
    "country": "UA",
    "name": "Ispas",
    "lat": "48.29734",
    "lng": "25.27406"
  },
  {
    "country": "UA",
    "name": "Ishun’",
    "lat": "45.92403",
    "lng": "33.82364"
  },
  {
    "country": "UA",
    "name": "Irshava",
    "lat": "48.31667",
    "lng": "23.03846"
  },
  {
    "country": "UA",
    "name": "Irpin",
    "lat": "50.52175",
    "lng": "30.25055"
  },
  {
    "country": "UA",
    "name": "Ilovays’k",
    "lat": "47.92498",
    "lng": "38.20235"
  },
  {
    "country": "UA",
    "name": "Chornomors’k",
    "lat": "46.30495",
    "lng": "30.65478"
  },
  {
    "country": "UA",
    "name": "Illintsi",
    "lat": "49.10479",
    "lng": "29.21773"
  },
  {
    "country": "UA",
    "name": "Ilychyovo",
    "lat": "45.28348",
    "lng": "35.73864"
  },
  {
    "country": "UA",
    "name": "Ilyichevo",
    "lat": "45.24524",
    "lng": "35.07127"
  },
  {
    "country": "UA",
    "name": "Ichnya",
    "lat": "50.86258",
    "lng": "32.39425"
  },
  {
    "country": "UA",
    "name": "Horodok",
    "lat": "49.16374",
    "lng": "26.58394"
  },
  {
    "country": "UA",
    "name": "Horlivka",
    "lat": "48.33576",
    "lng": "38.05325"
  },
  {
    "country": "UA",
    "name": "Hlyboka",
    "lat": "48.08971",
    "lng": "25.92933"
  },
  {
    "country": "UA",
    "name": "Hlukhiv",
    "lat": "51.67822",
    "lng": "33.9162"
  },
  {
    "country": "UA",
    "name": "Hvizd",
    "lat": "48.68517",
    "lng": "24.55055"
  },
  {
    "country": "UA",
    "name": "Gvardeyskoye",
    "lat": "45.58688",
    "lng": "33.97681"
  },
  {
    "country": "UA",
    "name": "Gvardeyskoye",
    "lat": "45.11692",
    "lng": "34.02188"
  },
  {
    "country": "UA",
    "name": "Huty",
    "lat": "50.13322",
    "lng": "35.34394"
  },
  {
    "country": "UA",
    "name": "Husiatyn",
    "lat": "49.0729",
    "lng": "26.1848"
  },
  {
    "country": "UA",
    "name": "Gurzuf",
    "lat": "44.54624",
    "lng": "34.27841"
  },
  {
    "country": "UA",
    "name": "Hupalivka",
    "lat": "49.11139",
    "lng": "34.73556"
  },
  {
    "country": "UA",
    "name": "Hulyaypole",
    "lat": "47.66389",
    "lng": "36.25633"
  },
  {
    "country": "UA",
    "name": "Hubynykha",
    "lat": "48.8098",
    "lng": "35.25602"
  },
  {
    "country": "UA",
    "name": "Grushevka",
    "lat": "45.02281",
    "lng": "34.97301"
  },
  {
    "country": "UA",
    "name": "Hryshkivtsi",
    "lat": "49.93529",
    "lng": "28.60383"
  },
  {
    "country": "UA",
    "name": "Grishino",
    "lat": "45.64219",
    "lng": "33.83098"
  },
  {
    "country": "UA",
    "name": "Hrymayliv",
    "lat": "49.33208",
    "lng": "26.01112"
  },
  {
    "country": "UA",
    "name": "Gresovskiy",
    "lat": "45.00804",
    "lng": "34.02657"
  },
  {
    "country": "UA",
    "name": "Hrebinka",
    "lat": "50.11712",
    "lng": "32.4361"
  },
  {
    "country": "UA",
    "name": "Hradyz’k",
    "lat": "49.23458",
    "lng": "33.13613"
  },
  {
    "country": "UA",
    "name": "Hostomel",
    "lat": "50.56841",
    "lng": "30.2651"
  },
  {
    "country": "UA",
    "name": "Hoshcha",
    "lat": "50.6003",
    "lng": "26.67435"
  },
  {
    "country": "UA",
    "name": "Hirs’ke",
    "lat": "48.73468",
    "lng": "38.49541"
  },
  {
    "country": "UA",
    "name": "Lesnovka",
    "lat": "45.1535",
    "lng": "33.61889"
  },
  {
    "country": "UA",
    "name": "Horokhiv",
    "lat": "50.50186",
    "lng": "24.76149"
  },
  {
    "country": "UA",
    "name": "Horodok",
    "lat": "49.78465",
    "lng": "23.64806"
  },
  {
    "country": "UA",
    "name": "Horodnya",
    "lat": "51.89085",
    "lng": "31.59741"
  },
  {
    "country": "UA",
    "name": "Horodnytsya",
    "lat": "50.80697",
    "lng": "27.31676"
  },
  {
    "country": "UA",
    "name": "Horodnye",
    "lat": "45.89083",
    "lng": "28.84833"
  },
  {
    "country": "UA",
    "name": "Horodyshche",
    "lat": "50.63965",
    "lng": "26.36573"
  },
  {
    "country": "UA",
    "name": "Horodyshche",
    "lat": "49.28489",
    "lng": "31.44513"
  },
  {
    "country": "UA",
    "name": "Horodenka",
    "lat": "48.67274",
    "lng": "25.50163"
  },
  {
    "country": "UA",
    "name": "Hornostayivka",
    "lat": "47.00777",
    "lng": "33.72899"
  },
  {
    "country": "UA",
    "name": "Gornostayevka",
    "lat": "45.27819",
    "lng": "36.18601"
  },
  {
    "country": "UA",
    "name": "Horinchovo",
    "lat": "48.27076",
    "lng": "23.43475"
  },
  {
    "country": "UA",
    "name": "Golubinka",
    "lat": "44.59382",
    "lng": "33.91521"
  },
  {
    "country": "UA",
    "name": "Holovyne",
    "lat": "50.47118",
    "lng": "28.8253"
  },
  {
    "country": "UA",
    "name": "Holovanivs’k",
    "lat": "48.384",
    "lng": "30.46131"
  },
  {
    "country": "UA",
    "name": "Hołoby",
    "lat": "51.08651",
    "lng": "25.00767"
  },
  {
    "country": "UA",
    "name": "Hola Prystan’",
    "lat": "46.52719",
    "lng": "32.52417"
  },
  {
    "country": "UA",
    "name": "Hnidyn",
    "lat": "50.32899",
    "lng": "30.71059"
  },
  {
    "country": "UA",
    "name": "Hlobyne",
    "lat": "49.38784",
    "lng": "33.25959"
  },
  {
    "country": "UA",
    "name": "Hlevakha",
    "lat": "50.27423",
    "lng": "30.32706"
  },
  {
    "country": "UA",
    "name": "Glazovka",
    "lat": "45.38792",
    "lng": "36.57965"
  },
  {
    "country": "UA",
    "name": "Heniches’k",
    "lat": "46.17592",
    "lng": "34.8034"
  },
  {
    "country": "UA",
    "name": "Hayvoron",
    "lat": "48.33958",
    "lng": "29.86791"
  },
  {
    "country": "UA",
    "name": "Haisyn",
    "lat": "48.81143",
    "lng": "29.38977"
  },
  {
    "country": "UA",
    "name": "Gaspra",
    "lat": "44.43364",
    "lng": "34.10297"
  },
  {
    "country": "UA",
    "name": "Halych",
    "lat": "49.12179",
    "lng": "24.72578"
  },
  {
    "country": "UA",
    "name": "Hadyach",
    "lat": "50.37112",
    "lng": "33.99099"
  },
  {
    "country": "UA",
    "name": "Zakharivka",
    "lat": "47.33232",
    "lng": "29.75903"
  },
  {
    "country": "UA",
    "name": "Shtormovoye",
    "lat": "45.26717",
    "lng": "33.08693"
  },
  {
    "country": "UA",
    "name": "Partenit",
    "lat": "44.578",
    "lng": "34.34464"
  },
  {
    "country": "UA",
    "name": "Sentianivka",
    "lat": "48.66863",
    "lng": "38.75444"
  },
  {
    "country": "UA",
    "name": "Frunze",
    "lat": "45.02688",
    "lng": "33.62956"
  },
  {
    "country": "UA",
    "name": "Frontovoye",
    "lat": "44.66737",
    "lng": "33.73841"
  },
  {
    "country": "UA",
    "name": "Foros",
    "lat": "44.39214",
    "lng": "33.78798"
  },
  {
    "country": "UA",
    "name": "Fontanka",
    "lat": "46.56646",
    "lng": "30.85965"
  },
  {
    "country": "UA",
    "name": "Filatovka",
    "lat": "46.08192",
    "lng": "33.7851"
  },
  {
    "country": "UA",
    "name": "Feodosiya",
    "lat": "45.03677",
    "lng": "35.37789"
  },
  {
    "country": "UA",
    "name": "Fastiv",
    "lat": "50.0767",
    "lng": "29.9177"
  },
  {
    "country": "UA",
    "name": "Eskhar",
    "lat": "49.79614",
    "lng": "36.59047"
  },
  {
    "country": "UA",
    "name": "Buran",
    "lat": "48.30003",
    "lng": "39.61526"
  },
  {
    "country": "UA",
    "name": "Energodar",
    "lat": "47.49865",
    "lng": "34.6574"
  },
  {
    "country": "UA",
    "name": "Dzvinogrud",
    "lat": "49.73333",
    "lng": "24.25"
  },
  {
    "country": "UA",
    "name": "Mirnovka",
    "lat": "45.69083",
    "lng": "34.30966"
  },
  {
    "country": "UA",
    "name": "Dzhankoy",
    "lat": "45.71168",
    "lng": "34.39274"
  },
  {
    "country": "UA",
    "name": "Romaniv",
    "lat": "50.14802",
    "lng": "27.93124"
  },
  {
    "country": "UA",
    "name": "Toretsk",
    "lat": "48.39869",
    "lng": "37.84787"
  },
  {
    "country": "UA",
    "name": "Demnya",
    "lat": "49.56738",
    "lng": "23.94607"
  },
  {
    "country": "UA",
    "name": "Dymer",
    "lat": "50.78647",
    "lng": "30.3026"
  },
  {
    "country": "UA",
    "name": "Dvorichna",
    "lat": "49.85019",
    "lng": "37.68262"
  },
  {
    "country": "UA",
    "name": "Dunayivtsi",
    "lat": "49.02078",
    "lng": "26.84122"
  },
  {
    "country": "UA",
    "name": "Dunaivtsi",
    "lat": "48.88909",
    "lng": "26.85636"
  },
  {
    "country": "UA",
    "name": "Duliby",
    "lat": "49.23134",
    "lng": "23.81532"
  },
  {
    "country": "UA",
    "name": "Dudchany",
    "lat": "47.18557",
    "lng": "33.7639"
  },
  {
    "country": "UA",
    "name": "Dubrovytsya",
    "lat": "51.57438",
    "lng": "26.56503"
  },
  {
    "country": "UA",
    "name": "Dubove",
    "lat": "48.17205",
    "lng": "23.88954"
  },
  {
    "country": "UA",
    "name": "Dubno",
    "lat": "50.41694",
    "lng": "25.73432"
  },
  {
    "country": "UA",
    "name": "Dublyany",
    "lat": "49.90411",
    "lng": "24.08637"
  },
  {
    "country": "UA",
    "name": "Dublyany",
    "lat": "49.49832",
    "lng": "23.38718"
  },
  {
    "country": "UA",
    "name": "Druzhba",
    "lat": "52.04545",
    "lng": "33.94517"
  },
  {
    "country": "UA",
    "name": "Druzhba",
    "lat": "49.04251",
    "lng": "25.45055"
  },
  {
    "country": "UA",
    "name": "Drohobych",
    "lat": "49.34991",
    "lng": "23.50561"
  },
  {
    "country": "UA",
    "name": "Drobysheve",
    "lat": "49.0416",
    "lng": "37.72962"
  },
  {
    "country": "UA",
    "name": "Drahovo",
    "lat": "48.23573",
    "lng": "23.54914"
  },
  {
    "country": "UA",
    "name": "Drabiv",
    "lat": "49.96029",
    "lng": "32.1407"
  },
  {
    "country": "UA",
    "name": "Dovbysh",
    "lat": "50.37332",
    "lng": "27.98742"
  },
  {
    "country": "UA",
    "name": "Donetsk",
    "lat": "48.023",
    "lng": "37.80224"
  },
  {
    "country": "UA",
    "name": "Domanivka",
    "lat": "47.63192",
    "lng": "30.98851"
  },
  {
    "country": "UA",
    "name": "Dolyna",
    "lat": "48.9733",
    "lng": "24.00944"
  },
  {
    "country": "UA",
    "name": "Dolyns'ka",
    "lat": "48.11041",
    "lng": "32.76449"
  },
  {
    "country": "UA",
    "name": "Dolinnoye",
    "lat": "44.7532",
    "lng": "33.77766"
  },
  {
    "country": "UA",
    "name": "Dovhe",
    "lat": "48.36527",
    "lng": "23.27904"
  },
  {
    "country": "UA",
    "name": "Dokuchayevs’k",
    "lat": "47.75046",
    "lng": "37.67936"
  },
  {
    "country": "UA",
    "name": "Dobryanka",
    "lat": "52.06314",
    "lng": "31.18567"
  },
  {
    "country": "UA",
    "name": "Dobrushino",
    "lat": "45.37441",
    "lng": "33.36547"
  },
  {
    "country": "UA",
    "name": "Dobroye",
    "lat": "44.86632",
    "lng": "34.22661"
  },
  {
    "country": "UA",
    "name": "Dobrovelychkivka",
    "lat": "48.38778",
    "lng": "31.18028"
  },
  {
    "country": "UA",
    "name": "Dobropillya",
    "lat": "48.46147",
    "lng": "37.08524"
  },
  {
    "country": "UA",
    "name": "Dobromyl’",
    "lat": "49.57193",
    "lng": "22.78629"
  },
  {
    "country": "UA",
    "name": "Dnipro",
    "lat": "48.4593",
    "lng": "35.03865"
  },
  {
    "country": "UA",
    "name": "Kamianske",
    "lat": "48.51134",
    "lng": "34.6021"
  },
  {
    "country": "UA",
    "name": "Dnipryany",
    "lat": "46.74631",
    "lng": "33.27288"
  },
  {
    "country": "UA",
    "name": "Dniprovka",
    "lat": "47.42945",
    "lng": "34.61805"
  },
  {
    "country": "UA",
    "name": "Dniprorudne",
    "lat": "47.38169",
    "lng": "34.97652"
  },
  {
    "country": "UA",
    "name": "Dmytrivka",
    "lat": "48.7969",
    "lng": "32.71645"
  },
  {
    "country": "UA",
    "name": "Dmitrovka",
    "lat": "45.48411",
    "lng": "35.0588"
  },
  {
    "country": "UA",
    "name": "Dmytrivka",
    "lat": "47.93611",
    "lng": "38.93661"
  },
  {
    "country": "UA",
    "name": "Oleksandriys’ke",
    "lat": "48.60767",
    "lng": "32.98347"
  },
  {
    "country": "UA",
    "name": "Dmytrivka",
    "lat": "45.97167",
    "lng": "28.98639"
  },
  {
    "country": "UA",
    "name": "Myrnohrad",
    "lat": "48.30523",
    "lng": "37.26091"
  },
  {
    "country": "UA",
    "name": "Dykan’ka",
    "lat": "49.82501",
    "lng": "34.52787"
  },
  {
    "country": "UA",
    "name": "Desna",
    "lat": "50.92731",
    "lng": "30.76048"
  },
  {
    "country": "UA",
    "name": "Derhachi",
    "lat": "50.10659",
    "lng": "36.12112"
  },
  {
    "country": "UA",
    "name": "Derazhnya",
    "lat": "49.2692",
    "lng": "27.43382"
  },
  {
    "country": "UA",
    "name": "Demydivka",
    "lat": "50.42814",
    "lng": "25.33619"
  },
  {
    "country": "UA",
    "name": "Delyatyn",
    "lat": "48.52354",
    "lng": "24.62466"
  },
  {
    "country": "UA",
    "name": "Dihtyari",
    "lat": "50.58264",
    "lng": "32.77012"
  },
  {
    "country": "UA",
    "name": "Debal’tseve",
    "lat": "48.34072",
    "lng": "38.4049"
  },
  {
    "country": "UA",
    "name": "Davydivka",
    "lat": "48.12099",
    "lng": "25.56461"
  },
  {
    "country": "UA",
    "name": "Dashiv",
    "lat": "49.00449",
    "lng": "29.42559"
  },
  {
    "country": "UA",
    "name": "Dalekoye",
    "lat": "45.66006",
    "lng": "33.08059"
  },
  {
    "country": "UA",
    "name": "Dachnoye",
    "lat": "44.88448",
    "lng": "34.98333"
  },
  {
    "country": "UA",
    "name": "Chutove",
    "lat": "49.71043",
    "lng": "35.16571"
  },
  {
    "country": "UA",
    "name": "Chulakivka",
    "lat": "46.35763",
    "lng": "32.3514"
  },
  {
    "country": "UA",
    "name": "Chuhuyiv",
    "lat": "49.83588",
    "lng": "36.68803"
  },
  {
    "country": "UA",
    "name": "Chudniv",
    "lat": "50.05204",
    "lng": "28.11745"
  },
  {
    "country": "UA",
    "name": "Chortkiv",
    "lat": "49.01709",
    "lng": "25.79804"
  },
  {
    "country": "UA",
    "name": "Chopovychi",
    "lat": "50.83325",
    "lng": "28.95334"
  },
  {
    "country": "UA",
    "name": "Chop",
    "lat": "48.43198",
    "lng": "22.20555"
  },
  {
    "country": "UA",
    "name": "Krasnoye",
    "lat": "45.13999",
    "lng": "34.09452"
  },
  {
    "country": "UA",
    "name": "Chkalovo",
    "lat": "45.60474",
    "lng": "34.83395"
  },
  {
    "country": "UA",
    "name": "Chistopolye",
    "lat": "45.36541",
    "lng": "36.18312"
  },
  {
    "country": "UA",
    "name": "Chisten’koye",
    "lat": "44.88152",
    "lng": "34.04716"
  },
  {
    "country": "UA",
    "name": "Chynadiyovo",
    "lat": "48.48179",
    "lng": "22.8217"
  },
  {
    "country": "UA",
    "name": "Chyhyryn",
    "lat": "49.08376",
    "lng": "32.65549"
  },
  {
    "country": "UA",
    "name": "Chervonyy Oskil",
    "lat": "49.17906",
    "lng": "37.42593"
  },
  {
    "country": "UA",
    "name": "Yesman’",
    "lat": "51.77006",
    "lng": "34.06729"
  },
  {
    "country": "UA",
    "name": "Chervone",
    "lat": "49.94975",
    "lng": "28.86874"
  },
  {
    "country": "UA",
    "name": "Chervonopartyzans’k",
    "lat": "48.07613",
    "lng": "39.79618"
  },
  {
    "country": "UA",
    "name": "Chervonohryhorivka",
    "lat": "47.62298",
    "lng": "34.53887"
  },
  {
    "country": "UA",
    "name": "Chervonohrad",
    "lat": "50.39105",
    "lng": "24.23514"
  },
  {
    "country": "UA",
    "name": "Pulyny",
    "lat": "50.46784",
    "lng": "28.2713"
  },
  {
    "country": "UA",
    "name": "Radyvyliv",
    "lat": "50.12994",
    "lng": "25.25576"
  },
  {
    "country": "UA",
    "name": "Chervona Sloboda",
    "lat": "49.3789",
    "lng": "32.14643"
  },
  {
    "country": "UA",
    "name": "Chortomlyk",
    "lat": "47.62315",
    "lng": "34.14198"
  },
  {
    "country": "UA",
    "name": "Chernyatyn",
    "lat": "48.66034",
    "lng": "25.44832"
  },
  {
    "country": "UA",
    "name": "Chornyanka",
    "lat": "46.65222",
    "lng": "33.35904"
  },
  {
    "country": "UA",
    "name": "Chernyakhivka",
    "lat": "50.21882",
    "lng": "31.93082"
  },
  {
    "country": "UA",
    "name": "Cherniakhiv",
    "lat": "50.45652",
    "lng": "28.67018"
  },
  {
    "country": "UA",
    "name": "Chornukhyne",
    "lat": "48.32339",
    "lng": "38.52272"
  },
  {
    "country": "UA",
    "name": "Chornukhy",
    "lat": "50.26732",
    "lng": "32.94196"
  },
  {
    "country": "UA",
    "name": "Chernozemnoye",
    "lat": "45.40808",
    "lng": "34.8199"
  },
  {
    "country": "UA",
    "name": "Chornorudka",
    "lat": "49.8464",
    "lng": "29.06062"
  },
  {
    "country": "UA",
    "name": "Chernopolye",
    "lat": "45.04399",
    "lng": "34.63916"
  },
  {
    "country": "UA",
    "name": "Chernomorskoye",
    "lat": "45.50657",
    "lng": "32.69776"
  },
  {
    "country": "UA",
    "name": "Chornoliztsi",
    "lat": "48.83034",
    "lng": "24.89576"
  },
  {
    "country": "UA",
    "name": "Chornobayivka",
    "lat": "46.69411",
    "lng": "32.55371"
  },
  {
    "country": "UA",
    "name": "Chornobay",
    "lat": "49.66644",
    "lng": "32.32932"
  },
  {
    "country": "UA",
    "name": "Cherniyiv",
    "lat": "48.85658",
    "lng": "24.71388"
  },
  {
    "country": "UA",
    "name": "Chernivtsi",
    "lat": "48.29149",
    "lng": "25.94034"
  },
  {
    "country": "UA",
    "name": "Chernihiv",
    "lat": "51.50551",
    "lng": "31.28487"
  },
  {
    "country": "UA",
    "name": "Chernihivka",
    "lat": "47.19992",
    "lng": "36.16148"
  },
  {
    "country": "UA",
    "name": "Chernivtsi",
    "lat": "48.54225",
    "lng": "28.11473"
  },
  {
    "country": "UA",
    "name": "Chernelytsya",
    "lat": "48.81207",
    "lng": "25.42477"
  },
  {
    "country": "UA",
    "name": "Cherkasy",
    "lat": "49.42854",
    "lng": "32.06207"
  },
  {
    "country": "UA",
    "name": "Chemerivtsi",
    "lat": "49.01179",
    "lng": "26.34203"
  },
  {
    "country": "UA",
    "name": "Chelyadinovo",
    "lat": "45.20729",
    "lng": "36.3762"
  },
  {
    "country": "UA",
    "name": "Chechelnyk",
    "lat": "48.21509",
    "lng": "29.36728"
  },
  {
    "country": "UA",
    "name": "Chaykino",
    "lat": "45.81111",
    "lng": "34.59538"
  },
  {
    "country": "UA",
    "name": "Chaykino",
    "lat": "45.08223",
    "lng": "34.08673"
  },
  {
    "country": "UA",
    "name": "Chasiv Yar",
    "lat": "48.59348",
    "lng": "37.85724"
  },
  {
    "country": "UA",
    "name": "Chaplynka",
    "lat": "46.36507",
    "lng": "33.54027"
  },
  {
    "country": "UA",
    "name": "Chapayeve",
    "lat": "49.36625",
    "lng": "35.87486"
  },
  {
    "country": "UA",
    "name": "Kalynove",
    "lat": "49.38179",
    "lng": "30.45137"
  },
  {
    "country": "UA",
    "name": "Viytivka",
    "lat": "48.42603",
    "lng": "29.54291"
  },
  {
    "country": "UA",
    "name": "Chapayevka",
    "lat": "47.47114",
    "lng": "36.34507"
  },
  {
    "country": "UA",
    "name": "Chapayevka",
    "lat": "45.28119",
    "lng": "34.89428"
  },
  {
    "country": "UA",
    "name": "Bytkiv",
    "lat": "48.62968",
    "lng": "24.47398"
  },
  {
    "country": "UA",
    "name": "Bystrytsya",
    "lat": "48.45931",
    "lng": "24.24545"
  },
  {
    "country": "UA",
    "name": "Chernyshevo",
    "lat": "45.78202",
    "lng": "33.42825"
  },
  {
    "country": "UA",
    "name": "Bykivka",
    "lat": "50.29285",
    "lng": "27.98314"
  },
  {
    "country": "UA",
    "name": "Bus’k",
    "lat": "49.96548",
    "lng": "24.61227"
  },
  {
    "country": "UA",
    "name": "Bushtyno",
    "lat": "48.05121",
    "lng": "23.48579"
  },
  {
    "country": "UA",
    "name": "Buryn’",
    "lat": "51.19912",
    "lng": "33.83523"
  },
  {
    "country": "UA",
    "name": "Burshtyn",
    "lat": "49.25867",
    "lng": "24.62777"
  },
  {
    "country": "UA",
    "name": "Pozharskoye",
    "lat": "44.93554",
    "lng": "33.87109"
  },
  {
    "country": "UA",
    "name": "Buky",
    "lat": "49.09583",
    "lng": "30.39641"
  },
  {
    "country": "UA",
    "name": "Budy",
    "lat": "49.89133",
    "lng": "36.02096"
  },
  {
    "country": "UA",
    "name": "Buchach",
    "lat": "49.06254",
    "lng": "25.38798"
  },
  {
    "country": "UA",
    "name": "Bucha",
    "lat": "50.54345",
    "lng": "30.21201"
  },
  {
    "country": "UA",
    "name": "Bryukhovychi",
    "lat": "49.90467",
    "lng": "23.95969"
  },
  {
    "country": "UA",
    "name": "Bryanka",
    "lat": "48.511",
    "lng": "38.67222"
  },
  {
    "country": "UA",
    "name": "Brusyliv",
    "lat": "50.28449",
    "lng": "29.52626"
  },
  {
    "country": "UA",
    "name": "Brovary",
    "lat": "50.51809",
    "lng": "30.80671"
  },
  {
    "country": "UA",
    "name": "Broska",
    "lat": "45.37327",
    "lng": "28.783"
  },
  {
    "country": "UA",
    "name": "Broshniv-Osada",
    "lat": "48.99621",
    "lng": "24.19748"
  },
  {
    "country": "UA",
    "name": "Brody",
    "lat": "50.08791",
    "lng": "25.15027"
  },
  {
    "country": "UA",
    "name": "Brylivka",
    "lat": "46.42476",
    "lng": "33.14721"
  },
  {
    "country": "UA",
    "name": "Bratslav",
    "lat": "48.82257",
    "lng": "28.9407"
  },
  {
    "country": "UA",
    "name": "Brats’ke",
    "lat": "47.8636",
    "lng": "31.58393"
  },
  {
    "country": "UA",
    "name": "Brailiv",
    "lat": "49.10986",
    "lng": "28.17459"
  },
  {
    "country": "UA",
    "name": "Boyarka",
    "lat": "50.31911",
    "lng": "30.29728"
  },
  {
    "country": "UA",
    "name": "Boyany",
    "lat": "48.27077",
    "lng": "26.12624"
  },
  {
    "country": "UA",
    "name": "Nikita",
    "lat": "44.51564",
    "lng": "34.2384"
  },
  {
    "country": "UA",
    "name": "Borzna",
    "lat": "51.25464",
    "lng": "32.4269"
  },
  {
    "country": "UA",
    "name": "Borshchiv",
    "lat": "48.80332",
    "lng": "26.04347"
  },
  {
    "country": "UA",
    "name": "Borova",
    "lat": "50.17625",
    "lng": "30.10429"
  },
  {
    "country": "UA",
    "name": "Borova",
    "lat": "49.3777",
    "lng": "37.62136"
  },
  {
    "country": "UA",
    "name": "Boromlya",
    "lat": "50.61839",
    "lng": "34.97042"
  },
  {
    "country": "UA",
    "name": "Borodianka",
    "lat": "50.64484",
    "lng": "29.9201"
  },
  {
    "country": "UA",
    "name": "Borodino",
    "lat": "46.3025",
    "lng": "29.24167"
  },
  {
    "country": "UA",
    "name": "Boryspil’",
    "lat": "50.35269",
    "lng": "30.95501"
  },
  {
    "country": "UA",
    "name": "Boryslav",
    "lat": "49.28672",
    "lng": "23.43238"
  },
  {
    "country": "UA",
    "name": "Bilshivtsi",
    "lat": "49.18333",
    "lng": "24.75"
  },
  {
    "country": "UA",
    "name": "Bolhrad",
    "lat": "45.68262",
    "lng": "28.61487"
  },
  {
    "country": "UA",
    "name": "Bolekhiv",
    "lat": "49.06607",
    "lng": "23.86435"
  },
  {
    "country": "UA",
    "name": "Bohuslav",
    "lat": "49.54939",
    "lng": "30.8744"
  },
  {
    "country": "UA",
    "name": "Bohorodchany",
    "lat": "48.807",
    "lng": "24.53834"
  },
  {
    "country": "UA",
    "name": "Bohodukhiv",
    "lat": "50.16466",
    "lng": "35.52765"
  },
  {
    "country": "UA",
    "name": "Bohdan",
    "lat": "48.04122",
    "lng": "24.35222"
  },
  {
    "country": "UA",
    "name": "Bogatoye",
    "lat": "45.02933",
    "lng": "34.76732"
  },
  {
    "country": "UA",
    "name": "Bobrynets",
    "lat": "48.05896",
    "lng": "32.16641"
  },
  {
    "country": "UA",
    "name": "Bobrovytsya",
    "lat": "50.74693",
    "lng": "31.3948"
  },
  {
    "country": "UA",
    "name": "Bibrka",
    "lat": "49.64093",
    "lng": "24.28874"
  },
  {
    "country": "UA",
    "name": "Bobovo",
    "lat": "48.07166",
    "lng": "22.89585"
  },
  {
    "country": "UA",
    "name": "Blyznyuky",
    "lat": "48.85775",
    "lng": "36.55505"
  },
  {
    "country": "UA",
    "name": "Blizhneye",
    "lat": "45.05694",
    "lng": "35.33056"
  },
  {
    "country": "UA",
    "name": "Blahodatne",
    "lat": "47.87928",
    "lng": "38.48492"
  },
  {
    "country": "UA",
    "name": "Blahodatne",
    "lat": "47.70013",
    "lng": "37.41898"
  },
  {
    "country": "UA",
    "name": "Biryukove",
    "lat": "47.95631",
    "lng": "39.73843"
  },
  {
    "country": "UA",
    "name": "Bilhorod-Dnistrovskyi",
    "lat": "46.1952",
    "lng": "30.34938"
  },
  {
    "country": "UA",
    "name": "Bila Tserkva",
    "lat": "49.80939",
    "lng": "30.11209"
  },
  {
    "country": "UA",
    "name": "Bezimenne",
    "lat": "47.10716",
    "lng": "37.93815"
  },
  {
    "country": "UA",
    "name": "Bezlyudivka",
    "lat": "49.87547",
    "lng": "36.26539"
  },
  {
    "country": "UA",
    "name": "Donskoye",
    "lat": "45.04509",
    "lng": "34.21413"
  },
  {
    "country": "UA",
    "name": "Bershad",
    "lat": "48.36782",
    "lng": "29.51726"
  },
  {
    "country": "UA",
    "name": "Beryslav",
    "lat": "46.84152",
    "lng": "33.42838"
  },
  {
    "country": "UA",
    "name": "Berezovo",
    "lat": "48.30943",
    "lng": "23.474"
  },
  {
    "country": "UA",
    "name": "Berezivka",
    "lat": "49.43935",
    "lng": "35.70736"
  },
  {
    "country": "UA",
    "name": "Berezivka",
    "lat": "47.20429",
    "lng": "30.9078"
  },
  {
    "country": "UA",
    "name": "Berezovka",
    "lat": "45.57471",
    "lng": "33.34397"
  },
  {
    "country": "UA",
    "name": "Berezne",
    "lat": "51.00094",
    "lng": "26.75106"
  },
  {
    "country": "UA",
    "name": "Bereznyky",
    "lat": "48.51407",
    "lng": "23.21982"
  },
  {
    "country": "UA",
    "name": "Bereznehuvate",
    "lat": "47.30783",
    "lng": "32.84993"
  },
  {
    "country": "UA",
    "name": "Berezna",
    "lat": "51.5716",
    "lng": "31.78456"
  },
  {
    "country": "UA",
    "name": "Berezyne",
    "lat": "46.22968",
    "lng": "29.20436"
  },
  {
    "country": "UA",
    "name": "Бережани",
    "lat": "49.45",
    "lng": "24.93333"
  },
  {
    "country": "UA",
    "name": "Berezanka",
    "lat": "46.85262",
    "lng": "31.38802"
  },
  {
    "country": "UA",
    "name": "Berestechko",
    "lat": "50.36047",
    "lng": "25.11071"
  },
  {
    "country": "UA",
    "name": "Berehove",
    "lat": "48.20555",
    "lng": "22.64418"
  },
  {
    "country": "UA",
    "name": "Beregovoye",
    "lat": "45.0947",
    "lng": "35.43385"
  },
  {
    "country": "UA",
    "name": "Berehomet",
    "lat": "48.17882",
    "lng": "25.34855"
  },
  {
    "country": "UA",
    "name": "Velyki Berehy",
    "lat": "48.23187",
    "lng": "22.74591"
  },
  {
    "country": "UA",
    "name": "Berdychiv",
    "lat": "49.89928",
    "lng": "28.60235"
  },
  {
    "country": "UA",
    "name": "Berdyansk",
    "lat": "46.76644",
    "lng": "36.79872"
  },
  {
    "country": "UA",
    "name": "Belz",
    "lat": "50.38226",
    "lng": "24.00642"
  },
  {
    "country": "UA",
    "name": "Bili Oslavy",
    "lat": "48.48722",
    "lng": "24.70078"
  },
  {
    "country": "UA",
    "name": "Bilyayivka",
    "lat": "46.48319",
    "lng": "30.21678"
  },
  {
    "country": "UA",
    "name": "Bilozerka",
    "lat": "46.6248",
    "lng": "32.44251"
  },
  {
    "country": "UA",
    "name": "Bile",
    "lat": "48.49523",
    "lng": "39.05051"
  },
  {
    "country": "UA",
    "name": "Bilovods'k",
    "lat": "49.20846",
    "lng": "39.58975"
  },
  {
    "country": "UA",
    "name": "Bilopillya",
    "lat": "51.15016",
    "lng": "34.31287"
  },
  {
    "country": "UA",
    "name": "Bilokurakyne",
    "lat": "49.5341",
    "lng": "38.73067"
  },
  {
    "country": "UA",
    "name": "Inkerman",
    "lat": "44.61391",
    "lng": "33.6098"
  },
  {
    "country": "UA",
    "name": "Lyakhovtsy",
    "lat": "50.00263",
    "lng": "26.42824"
  },
  {
    "country": "UA",
    "name": "Belogorsk",
    "lat": "45.05462",
    "lng": "34.60185"
  },
  {
    "country": "UA",
    "name": "Bilohorivka",
    "lat": "48.92503",
    "lng": "38.24822"
  },
  {
    "country": "UA",
    "name": "Bilky",
    "lat": "48.31503",
    "lng": "23.13248"
  },
  {
    "country": "UA",
    "name": "Bilyts’ke",
    "lat": "48.40642",
    "lng": "37.18111"
  },
  {
    "country": "UA",
    "name": "Belinskoye",
    "lat": "45.37465",
    "lng": "36.08212"
  },
  {
    "country": "UA",
    "name": "Bila Krynytsya",
    "lat": "50.63982",
    "lng": "29.47041"
  },
  {
    "country": "UA",
    "name": "Belaya",
    "lat": "49.029",
    "lng": "25.77059"
  },
  {
    "country": "UA",
    "name": "Bekhtery",
    "lat": "46.2479",
    "lng": "32.29123"
  },
  {
    "country": "UA",
    "name": "Bazaliya",
    "lat": "49.71267",
    "lng": "26.47331"
  },
  {
    "country": "UA",
    "name": "Bayrachky",
    "lat": "48.392",
    "lng": "38.60174"
  },
  {
    "country": "UA",
    "name": "Trudovoye",
    "lat": "45.23797",
    "lng": "33.75836"
  },
  {
    "country": "UA",
    "name": "Baturyn",
    "lat": "51.34567",
    "lng": "32.87794"
  },
  {
    "country": "UA",
    "name": "Batal’noye",
    "lat": "45.19402",
    "lng": "35.61583"
  },
  {
    "country": "UA",
    "name": "Bashtanka",
    "lat": "47.40719",
    "lng": "32.43868"
  },
  {
    "country": "UA",
    "name": "Baryshivka",
    "lat": "50.36098",
    "lng": "31.32173"
  },
  {
    "country": "UA",
    "name": "Barvinkove",
    "lat": "48.9097",
    "lng": "37.02051"
  },
  {
    "country": "UA",
    "name": "Baranivka",
    "lat": "50.29691",
    "lng": "27.6622"
  },
  {
    "country": "UA",
    "name": "Sinitsyno",
    "lat": "45.23862",
    "lng": "35.24659"
  },
  {
    "country": "UA",
    "name": "Bar",
    "lat": "49.07717",
    "lng": "27.68256"
  },
  {
    "country": "UA",
    "name": "Banyliv",
    "lat": "48.36612",
    "lng": "25.34549"
  },
  {
    "country": "UA",
    "name": "Balta",
    "lat": "47.93548",
    "lng": "29.61982"
  },
  {
    "country": "UA",
    "name": "Balky",
    "lat": "47.38336",
    "lng": "34.94396"
  },
  {
    "country": "UA",
    "name": "Zaritcha",
    "lat": "49.71667",
    "lng": "29.23333"
  },
  {
    "country": "UA",
    "name": "Balakliya",
    "lat": "49.4627",
    "lng": "36.85951"
  },
  {
    "country": "UA",
    "name": "Balaklava",
    "lat": "44.51118",
    "lng": "33.59942"
  },
  {
    "country": "UA",
    "name": "Bakhmach",
    "lat": "51.20093",
    "lng": "32.77451"
  },
  {
    "country": "UA",
    "name": "Bakhmach",
    "lat": "51.18144",
    "lng": "32.83463"
  },
  {
    "country": "UA",
    "name": "Bakhchysarai",
    "lat": "44.75525",
    "lng": "33.85782"
  },
  {
    "country": "UA",
    "name": "Bagerovo",
    "lat": "45.37417",
    "lng": "36.29705"
  },
  {
    "country": "UA",
    "name": "Babanka",
    "lat": "48.70971",
    "lng": "30.44827"
  },
  {
    "country": "UA",
    "name": "Azovskoye",
    "lat": "45.58604",
    "lng": "34.5668"
  },
  {
    "country": "UA",
    "name": "Abrikosovo",
    "lat": "45.69236",
    "lng": "34.10156"
  },
  {
    "country": "UA",
    "name": "Avdiyivka",
    "lat": "51.7766",
    "lng": "32.79988"
  },
  {
    "country": "UA",
    "name": "Avdiyivka",
    "lat": "48.13989",
    "lng": "37.74255"
  },
  {
    "country": "UA",
    "name": "Auly",
    "lat": "48.5666",
    "lng": "34.46111"
  },
  {
    "country": "UA",
    "name": "Ostanino",
    "lat": "45.32731",
    "lng": "35.91295"
  },
  {
    "country": "UA",
    "name": "Askaniya-Nova",
    "lat": "46.45135",
    "lng": "33.86889"
  },
  {
    "country": "UA",
    "name": "Artsyz",
    "lat": "45.99194",
    "lng": "29.41824"
  },
  {
    "country": "UA",
    "name": "Bakhmut",
    "lat": "48.59559",
    "lng": "37.99987"
  },
  {
    "country": "UA",
    "name": "Artemivs’k",
    "lat": "48.44061",
    "lng": "38.732"
  },
  {
    "country": "UA",
    "name": "Aromatnoye",
    "lat": "45.03678",
    "lng": "34.39921"
  },
  {
    "country": "UA",
    "name": "Armyansk",
    "lat": "46.10919",
    "lng": "33.69206"
  },
  {
    "country": "UA",
    "name": "Arbuzynka",
    "lat": "47.90972",
    "lng": "31.31963"
  },
  {
    "country": "UA",
    "name": "Apostolove",
    "lat": "47.66003",
    "lng": "33.71369"
  },
  {
    "country": "UA",
    "name": "Antratsyt",
    "lat": "48.11503",
    "lng": "39.09128"
  },
  {
    "country": "UA",
    "name": "Antoniny",
    "lat": "49.80974",
    "lng": "26.87714"
  },
  {
    "country": "UA",
    "name": "Andrushky",
    "lat": "49.88195",
    "lng": "29.34349"
  },
  {
    "country": "UA",
    "name": "Andrushivka",
    "lat": "50.02288",
    "lng": "29.02023"
  },
  {
    "country": "UA",
    "name": "Ananyiv Pershyi",
    "lat": "47.72106",
    "lng": "29.94502"
  },
  {
    "country": "UA",
    "name": "Amvrosiyivka",
    "lat": "47.79348",
    "lng": "38.47768"
  },
  {
    "country": "UA",
    "name": "Amurskoye",
    "lat": "45.27822",
    "lng": "34.12823"
  },
  {
    "country": "UA",
    "name": "Alushta",
    "lat": "44.67728",
    "lng": "34.4097"
  },
  {
    "country": "UA",
    "name": "Alupka",
    "lat": "44.41808",
    "lng": "34.04531"
  },
  {
    "country": "UA",
    "name": "Alekseyevka",
    "lat": "45.58194",
    "lng": "33.6298"
  },
  {
    "country": "UA",
    "name": "Oleksandrivka",
    "lat": "48.70837",
    "lng": "36.91561"
  },
  {
    "country": "UA",
    "name": "Oleksandrivka",
    "lat": "46.83826",
    "lng": "32.76116"
  },
  {
    "country": "UA",
    "name": "Oleksandrivka",
    "lat": "46.32893",
    "lng": "30.63481"
  },
  {
    "country": "UA",
    "name": "Aleksandrovka",
    "lat": "45.57654",
    "lng": "34.09947"
  },
  {
    "country": "UA",
    "name": "Alchevs’k",
    "lat": "48.46893",
    "lng": "38.81669"
  },
  {
    "country": "UA",
    "name": "Andreyevka",
    "lat": "44.81663",
    "lng": "33.56313"
  },
  {
    "country": "UA",
    "name": "Yakymivka",
    "lat": "46.69972",
    "lng": "35.15916"
  },
  {
    "country": "UA",
    "name": "Akimovka",
    "lat": "45.51981",
    "lng": "34.82438"
  },
  {
    "country": "UA",
    "name": "Okhtyrka",
    "lat": "50.31036",
    "lng": "34.89879"
  },
  {
    "country": "UA",
    "name": "Agrarnoye",
    "lat": "45.01596",
    "lng": "34.05725"
  },
  {
    "country": "UA",
    "name": "Lekarstvennoye",
    "lat": "44.94194",
    "lng": "33.82229"
  },
  {
    "country": "UA",
    "name": "Aeroflotskiy",
    "lat": "45.01816",
    "lng": "33.99961"
  },
  {
    "country": "UA",
    "name": "Adzhamka",
    "lat": "48.54245",
    "lng": "32.53542"
  },
  {
    "country": "UA",
    "name": "Abrikosovka",
    "lat": "45.10759",
    "lng": "35.10139"
  },
  {
    "country": "UA",
    "name": "Malynivka",
    "lat": "49.81667",
    "lng": "36.73333"
  },
  {
    "country": "UA",
    "name": "Kopashnovo",
    "lat": "48.2197",
    "lng": "23.48457"
  },
  {
    "country": "UA",
    "name": "Narkevychi",
    "lat": "49.51717",
    "lng": "26.64178"
  },
  {
    "country": "UA",
    "name": "Kirove",
    "lat": "47.65311",
    "lng": "35.69512"
  },
  {
    "country": "UA",
    "name": "Novosel’skoye",
    "lat": "45.50357",
    "lng": "32.7225"
  },
  {
    "country": "UA",
    "name": "Orekhovo",
    "lat": "45.12944",
    "lng": "33.6318"
  },
  {
    "country": "UA",
    "name": "Okny",
    "lat": "47.54044",
    "lng": "29.46001"
  },
  {
    "country": "UA",
    "name": "Kuchurhan",
    "lat": "47.16302",
    "lng": "29.78937"
  },
  {
    "country": "UA",
    "name": "Smyga",
    "lat": "50.2391",
    "lng": "25.76575"
  },
  {
    "country": "UA",
    "name": "Tayirove",
    "lat": "46.36313",
    "lng": "30.64891"
  },
  {
    "country": "UA",
    "name": "Teplodar",
    "lat": "46.50585",
    "lng": "30.32521"
  },
  {
    "country": "UA",
    "name": "Horishni Plavni",
    "lat": "49.01018",
    "lng": "33.63567"
  },
  {
    "country": "UA",
    "name": "Slavutych",
    "lat": "51.5225",
    "lng": "30.71806"
  },
  {
    "country": "UA",
    "name": "Orzhiv",
    "lat": "50.8",
    "lng": "26.12"
  },
  {
    "country": "UA",
    "name": "Kurskoye",
    "lat": "45.02908",
    "lng": "34.93623"
  },
  {
    "country": "UA",
    "name": "Rovnoye",
    "lat": "45.35134",
    "lng": "34.3523"
  },
  {
    "country": "UA",
    "name": "Kashtanovoye",
    "lat": "44.8321",
    "lng": "34.05912"
  },
  {
    "country": "UA",
    "name": "Levadki",
    "lat": "44.87083",
    "lng": "34.04278"
  },
  {
    "country": "UA",
    "name": "Beloglinka",
    "lat": "44.9949",
    "lng": "34.04167"
  },
  {
    "country": "UA",
    "name": "Komsomol’skoye",
    "lat": "45.019",
    "lng": "34.03049"
  },
  {
    "country": "UA",
    "name": "Malen’koye",
    "lat": "45.07585",
    "lng": "33.99942"
  },
  {
    "country": "UA",
    "name": "Solnechnoye",
    "lat": "45.04767",
    "lng": "34.0838"
  },
  {
    "country": "UA",
    "name": "Fontany",
    "lat": "44.89717",
    "lng": "34.07297"
  },
  {
    "country": "UA",
    "name": "Zalesye",
    "lat": "44.88687",
    "lng": "34.10168"
  },
  {
    "country": "UA",
    "name": "Konstantinovka",
    "lat": "44.85511",
    "lng": "34.12069"
  },
  {
    "country": "UA",
    "name": "Urozhaynoye",
    "lat": "45.04522",
    "lng": "34.13511"
  },
  {
    "country": "UA",
    "name": "Trudovoye",
    "lat": "44.99133",
    "lng": "34.20311"
  },
  {
    "country": "UA",
    "name": "Mel’nichnoye",
    "lat": "45.19885",
    "lng": "34.42012"
  },
  {
    "country": "UA",
    "name": "Drofino",
    "lat": "45.28629",
    "lng": "34.61589"
  },
  {
    "country": "UA",
    "name": "Kostochkovka",
    "lat": "45.31747",
    "lng": "34.67418"
  },
  {
    "country": "UA",
    "name": "Razdol’noye",
    "lat": "45.36161",
    "lng": "34.85482"
  },
  {
    "country": "UA",
    "name": "Nekrasovo",
    "lat": "45.42453",
    "lng": "34.28545"
  },
  {
    "country": "UA",
    "name": "Uvarovka",
    "lat": "45.45108",
    "lng": "34.78812"
  },
  {
    "country": "UA",
    "name": "Listvennoye",
    "lat": "45.48086",
    "lng": "34.81087"
  },
  {
    "country": "UA",
    "name": "Vol’noye",
    "lat": "45.5657",
    "lng": "34.3036"
  },
  {
    "country": "UA",
    "name": "Roshchino",
    "lat": "45.60916",
    "lng": "34.37992"
  },
  {
    "country": "UA",
    "name": "Suvorovo",
    "lat": "46.08865",
    "lng": "33.688"
  },
  {
    "country": "UA",
    "name": "Izumrudnoye",
    "lat": "45.73704",
    "lng": "34.41299"
  },
  {
    "country": "UA",
    "name": "Kholmovka",
    "lat": "44.6583",
    "lng": "33.75456"
  },
  {
    "country": "UA",
    "name": "Pakharevka",
    "lat": "45.83472",
    "lng": "34.16129"
  },
  {
    "country": "UA",
    "name": "Luganskoye",
    "lat": "45.8019",
    "lng": "34.23786"
  },
  {
    "country": "UA",
    "name": "Yasnopolyanskoye",
    "lat": "45.94097",
    "lng": "34.35262"
  },
  {
    "country": "UA",
    "name": "Novoozyornoye",
    "lat": "45.38314",
    "lng": "33.11715"
  },
  {
    "country": "UA",
    "name": "Chernovo",
    "lat": "45.50833",
    "lng": "33.93397"
  },
  {
    "country": "UA",
    "name": "Kukushkino",
    "lat": "45.71924",
    "lng": "33.3903"
  },
  {
    "country": "UA",
    "name": "Senokosnoye",
    "lat": "45.73277",
    "lng": "33.51552"
  },
  {
    "country": "UA",
    "name": "Bratskoye",
    "lat": "45.8317",
    "lng": "33.92151"
  },
  {
    "country": "UA",
    "name": "Sovkhoznoye",
    "lat": "45.96005",
    "lng": "33.77155"
  },
  {
    "country": "UA",
    "name": "Pochetnoye",
    "lat": "45.99495",
    "lng": "33.76588"
  },
  {
    "country": "UA",
    "name": "Kamenolomnya",
    "lat": "45.24804",
    "lng": "33.41773"
  },
  {
    "country": "UA",
    "name": "Vladimirovka",
    "lat": "45.1476",
    "lng": "33.57583"
  },
  {
    "country": "UA",
    "name": "Geroyskoye",
    "lat": "45.13857",
    "lng": "33.74675"
  },
  {
    "country": "UA",
    "name": "Zhuravli",
    "lat": "45.25246",
    "lng": "33.64104"
  },
  {
    "country": "UA",
    "name": "Zernovoye",
    "lat": "45.28838",
    "lng": "33.86414"
  },
  {
    "country": "UA",
    "name": "Chervonoye",
    "lat": "45.12294",
    "lng": "33.68662"
  },
  {
    "country": "UA",
    "name": "Novofedorovka",
    "lat": "45.09473",
    "lng": "33.57211"
  },
  {
    "country": "UA",
    "name": "Shkol’noye",
    "lat": "45.05758",
    "lng": "33.89737"
  },
  {
    "country": "UA",
    "name": "Vinnitskoye",
    "lat": "44.98129",
    "lng": "33.7392"
  },
  {
    "country": "UA",
    "name": "Prudovoye",
    "lat": "44.90424",
    "lng": "33.78114"
  },
  {
    "country": "UA",
    "name": "Kashtany",
    "lat": "44.8676",
    "lng": "33.78995"
  },
  {
    "country": "UA",
    "name": "Aromatnoye",
    "lat": "44.80373",
    "lng": "33.87005"
  },
  {
    "country": "UA",
    "name": "Solnechniy",
    "lat": "44.78677",
    "lng": "33.61786"
  },
  {
    "country": "UA",
    "name": "Polyushko",
    "lat": "44.74219",
    "lng": "33.58913"
  },
  {
    "country": "UA",
    "name": "Zheleznodorozhnoye",
    "lat": "44.7171",
    "lng": "33.80417"
  },
  {
    "country": "UA",
    "name": "Denyshi",
    "lat": "50.21415",
    "lng": "28.40395"
  },
  {
    "country": "UA",
    "name": "Stepove",
    "lat": "46.70385",
    "lng": "30.07919"
  },
  {
    "country": "UA",
    "name": "Pervomayskoye",
    "lat": "45.06191",
    "lng": "35.16395"
  },
  {
    "country": "UA",
    "name": "Yuzhnoukrains'k",
    "lat": "47.81777",
    "lng": "31.18263"
  },
  {
    "country": "UA",
    "name": "Varash",
    "lat": "51.3509",
    "lng": "25.84738"
  },
  {
    "country": "UA",
    "name": "Mizhhir'ya",
    "lat": "48.51876",
    "lng": "23.50233"
  },
  {
    "country": "UA",
    "name": "Kremidivka",
    "lat": "46.73351",
    "lng": "30.78472"
  },
  {
    "country": "UA",
    "name": "Kulykiv",
    "lat": "49.97954",
    "lng": "24.07817"
  },
  {
    "country": "UA",
    "name": "Hlyns'k",
    "lat": "50.06033",
    "lng": "23.89956"
  },
  {
    "country": "UA",
    "name": "Novoyavorivs'k",
    "lat": "49.93023",
    "lng": "23.57357"
  },
  {
    "country": "UA",
    "name": "Sofiyivska Borschagivka",
    "lat": "50.41005",
    "lng": "30.36724"
  },
  {
    "country": "UA",
    "name": "Motovylivka",
    "lat": "50.15821",
    "lng": "30.07421"
  },
  {
    "country": "UA",
    "name": "Kriukivschina",
    "lat": "50.37153",
    "lng": "30.36861"
  },
  {
    "country": "UA",
    "name": "Horenka",
    "lat": "50.55731",
    "lng": "30.33217"
  },
  {
    "country": "UA",
    "name": "Chabany",
    "lat": "50.34071",
    "lng": "30.42356"
  },
  {
    "country": "UA",
    "name": "Kirove",
    "lat": "50.3689",
    "lng": "31.12066"
  },
  {
    "country": "UA",
    "name": "Prolisky",
    "lat": "50.39118",
    "lng": "30.78"
  },
  {
    "country": "UA",
    "name": "Sovkhoznoye",
    "lat": "45.03061",
    "lng": "34.01068"
  },
  {
    "country": "UA",
    "name": "Ivanovka",
    "lat": "45.3743",
    "lng": "34.72013"
  },
  {
    "country": "UA",
    "name": "Krasnokamenka",
    "lat": "44.92446",
    "lng": "35.0754"
  },
  {
    "country": "UA",
    "name": "Partyzans’ke",
    "lat": "48.5868",
    "lng": "34.80948"
  },
  {
    "country": "UA",
    "name": "Salhany",
    "lat": "46.14881",
    "lng": "30.34601"
  },
  {
    "country": "UA",
    "name": "Aviatorske",
    "lat": "48.36714",
    "lng": "35.08132"
  },
  {
    "country": "UA",
    "name": "Sakharnaya Golovka",
    "lat": "44.58362",
    "lng": "33.64383"
  },
  {
    "country": "UA",
    "name": "Yarkoye Pole",
    "lat": "45.20581",
    "lng": "35.19848"
  },
  {
    "country": "UA",
    "name": "Smotrych",
    "lat": "48.66149",
    "lng": "26.56031"
  },
  {
    "country": "UA",
    "name": "Glybochek",
    "lat": "48.86686",
    "lng": "30.79897"
  },
  {
    "country": "UA",
    "name": "Nova Pryluka",
    "lat": "49.37488",
    "lng": "28.69955"
  },
  {
    "country": "UA",
    "name": "Husiatyn",
    "lat": "49.07015",
    "lng": "26.22299"
  },
  {
    "country": "UA",
    "name": "Horodok",
    "lat": "50.59483",
    "lng": "29.4607"
  },
  {
    "country": "UG",
    "name": "Zombo",
    "lat": "2.51355",
    "lng": "30.90909"
  },
  {
    "country": "UG",
    "name": "Yumbe",
    "lat": "3.46506",
    "lng": "31.24689"
  },
  {
    "country": "UG",
    "name": "Wobulenzi",
    "lat": "0.72833",
    "lng": "32.51222"
  },
  {
    "country": "UG",
    "name": "Wakiso",
    "lat": "0.40444",
    "lng": "32.45944"
  },
  {
    "country": "UG",
    "name": "Tororo",
    "lat": "0.69299",
    "lng": "34.18085"
  },
  {
    "country": "UG",
    "name": "Soroti",
    "lat": "1.71464",
    "lng": "33.61113"
  },
  {
    "country": "UG",
    "name": "Sironko",
    "lat": "1.23132",
    "lng": "34.24773"
  },
  {
    "country": "UG",
    "name": "Serere",
    "lat": "1.49417",
    "lng": "33.45528"
  },
  {
    "country": "UG",
    "name": "Sembabule",
    "lat": "-0.07722",
    "lng": "31.45667"
  },
  {
    "country": "UG",
    "name": "Rukungiri",
    "lat": "-0.84111",
    "lng": "29.94194"
  },
  {
    "country": "UG",
    "name": "Rubirizi",
    "lat": "-0.29889",
    "lng": "30.13361"
  },
  {
    "country": "UG",
    "name": "Rubanda",
    "lat": "-1.18833",
    "lng": "29.84611"
  },
  {
    "country": "UG",
    "name": "Rakai",
    "lat": "-0.72",
    "lng": "31.48389"
  },
  {
    "country": "UG",
    "name": "Pallisa",
    "lat": "1.145",
    "lng": "33.70944"
  },
  {
    "country": "UG",
    "name": "Paidha",
    "lat": "2.41669",
    "lng": "30.98551"
  },
  {
    "country": "UG",
    "name": "Pader Palwo",
    "lat": "2.80056",
    "lng": "33.135"
  },
  {
    "country": "UG",
    "name": "Nyachera",
    "lat": "-0.9",
    "lng": "30.41667"
  },
  {
    "country": "UG",
    "name": "Ntungamo",
    "lat": "-0.88333",
    "lng": "29.65"
  },
  {
    "country": "UG",
    "name": "Ntungamo",
    "lat": "-0.87944",
    "lng": "30.26417"
  },
  {
    "country": "UG",
    "name": "Ntoroko",
    "lat": "1.04111",
    "lng": "30.48111"
  },
  {
    "country": "UG",
    "name": "Nsika",
    "lat": "-0.358",
    "lng": "30.43136"
  },
  {
    "country": "UG",
    "name": "Njeru",
    "lat": "0.44166",
    "lng": "33.17917"
  },
  {
    "country": "UG",
    "name": "Ngora",
    "lat": "1.43139",
    "lng": "33.77722"
  },
  {
    "country": "UG",
    "name": "Nebbi",
    "lat": "2.47826",
    "lng": "31.08893"
  },
  {
    "country": "UG",
    "name": "Namutumba",
    "lat": "0.83611",
    "lng": "33.68611"
  },
  {
    "country": "UG",
    "name": "Namasuba",
    "lat": "0.68944",
    "lng": "32.42139"
  },
  {
    "country": "UG",
    "name": "Nakasongola",
    "lat": "1.30889",
    "lng": "32.45639"
  },
  {
    "country": "UG",
    "name": "Nakaseke",
    "lat": "0.75167",
    "lng": "32.385"
  },
  {
    "country": "UG",
    "name": "Mukono",
    "lat": "0.35333",
    "lng": "32.75528"
  },
  {
    "country": "UG",
    "name": "Muhororo",
    "lat": "0.93806",
    "lng": "30.75944"
  },
  {
    "country": "UG",
    "name": "Mubende",
    "lat": "0.55849",
    "lng": "31.39489"
  },
  {
    "country": "UG",
    "name": "Mpigi",
    "lat": "0.225",
    "lng": "32.31361"
  },
  {
    "country": "UG",
    "name": "Moyo",
    "lat": "3.66088",
    "lng": "31.72474"
  },
  {
    "country": "UG",
    "name": "Moroto",
    "lat": "2.53453",
    "lng": "34.66659"
  },
  {
    "country": "UG",
    "name": "Mityana",
    "lat": "0.4175",
    "lng": "32.02278"
  },
  {
    "country": "UG",
    "name": "Mitoma",
    "lat": "-0.68417",
    "lng": "30.07"
  },
  {
    "country": "UG",
    "name": "Mbarara",
    "lat": "-0.60467",
    "lng": "30.64851"
  },
  {
    "country": "UG",
    "name": "Mbale",
    "lat": "1.08209",
    "lng": "34.17503"
  },
  {
    "country": "UG",
    "name": "Mayuge",
    "lat": "0.45972",
    "lng": "33.48028"
  },
  {
    "country": "UG",
    "name": "Masindi Port",
    "lat": "1.69606",
    "lng": "32.08608"
  },
  {
    "country": "UG",
    "name": "Masindi",
    "lat": "1.67444",
    "lng": "31.715"
  },
  {
    "country": "UG",
    "name": "Masaka",
    "lat": "-0.33379",
    "lng": "31.73409"
  },
  {
    "country": "UG",
    "name": "Maracha",
    "lat": "3.27042",
    "lng": "30.95532"
  },
  {
    "country": "UG",
    "name": "Lyantonde",
    "lat": "-0.40306",
    "lng": "31.15722"
  },
  {
    "country": "UG",
    "name": "Lwengo",
    "lat": "-0.41611",
    "lng": "31.40806"
  },
  {
    "country": "UG",
    "name": "Luwero",
    "lat": "0.84917",
    "lng": "32.47306"
  },
  {
    "country": "UG",
    "name": "Lugazi",
    "lat": "0.36788",
    "lng": "32.9376"
  },
  {
    "country": "UG",
    "name": "Lira",
    "lat": "2.2499",
    "lng": "32.89985"
  },
  {
    "country": "UG",
    "name": "Kyotera",
    "lat": "-0.61556",
    "lng": "31.5175"
  },
  {
    "country": "UG",
    "name": "Kyenjojo",
    "lat": "0.63278",
    "lng": "30.62139"
  },
  {
    "country": "UG",
    "name": "Kyegegwa",
    "lat": "0.50222",
    "lng": "31.04139"
  },
  {
    "country": "UG",
    "name": "Kumi",
    "lat": "1.46083",
    "lng": "33.93611"
  },
  {
    "country": "UG",
    "name": "Kotido",
    "lat": "2.98056",
    "lng": "34.13306"
  },
  {
    "country": "UG",
    "name": "Koboko",
    "lat": "3.41364",
    "lng": "30.95994"
  },
  {
    "country": "UG",
    "name": "Kitgum",
    "lat": "3.27833",
    "lng": "32.88667"
  },
  {
    "country": "UG",
    "name": "Kisoro",
    "lat": "-1.28538",
    "lng": "29.68497"
  },
  {
    "country": "UG",
    "name": "Kiryandongo",
    "lat": "1.87633",
    "lng": "32.06225"
  },
  {
    "country": "UG",
    "name": "Kiruhura",
    "lat": "-0.19664",
    "lng": "30.84446"
  },
  {
    "country": "UG",
    "name": "Kireka",
    "lat": "0.3475",
    "lng": "32.64917"
  },
  {
    "country": "UG",
    "name": "Kilembe",
    "lat": "0.19835",
    "lng": "30.01302"
  },
  {
    "country": "UG",
    "name": "Kigorobya",
    "lat": "1.6162",
    "lng": "31.3089"
  },
  {
    "country": "UG",
    "name": "Kibuku",
    "lat": "1.04333",
    "lng": "33.7975"
  },
  {
    "country": "UG",
    "name": "Kiboga",
    "lat": "0.91611",
    "lng": "31.77417"
  },
  {
    "country": "UG",
    "name": "Kibingo",
    "lat": "-0.62602",
    "lng": "30.43594"
  },
  {
    "country": "UG",
    "name": "Kibale",
    "lat": "0.8",
    "lng": "31.06667"
  },
  {
    "country": "UG",
    "name": "Kayunga",
    "lat": "0.7025",
    "lng": "32.88861"
  },
  {
    "country": "UG",
    "name": "Katakwi",
    "lat": "1.89111",
    "lng": "33.96611"
  },
  {
    "country": "UG",
    "name": "Kasese",
    "lat": "0.18333",
    "lng": "30.08333"
  },
  {
    "country": "UG",
    "name": "Kasaali",
    "lat": "-0.61667",
    "lng": "31.55"
  },
  {
    "country": "UG",
    "name": "Kapchorwa",
    "lat": "1.40096",
    "lng": "34.45038"
  },
  {
    "country": "UG",
    "name": "Kanungu",
    "lat": "-0.9575",
    "lng": "29.78972"
  },
  {
    "country": "UG",
    "name": "Kanoni",
    "lat": "0.17722",
    "lng": "31.88111"
  },
  {
    "country": "UG",
    "name": "Kamwenge",
    "lat": "0.1866",
    "lng": "30.45393"
  },
  {
    "country": "UG",
    "name": "Kamuli",
    "lat": "0.94722",
    "lng": "33.11972"
  },
  {
    "country": "UG",
    "name": "Kampala",
    "lat": "0.31628",
    "lng": "32.58219"
  },
  {
    "country": "UG",
    "name": "Kalungu",
    "lat": "-0.16969",
    "lng": "31.75847"
  },
  {
    "country": "UG",
    "name": "Kaliro",
    "lat": "0.89444",
    "lng": "33.49944"
  },
  {
    "country": "UG",
    "name": "Kalangala",
    "lat": "-0.30889",
    "lng": "32.225"
  },
  {
    "country": "UG",
    "name": "Kakumiro",
    "lat": "0.78056",
    "lng": "31.32361"
  },
  {
    "country": "UG",
    "name": "Kajansi",
    "lat": "0.21548",
    "lng": "32.53453"
  },
  {
    "country": "UG",
    "name": "Kagadi",
    "lat": "0.93778",
    "lng": "30.80889"
  },
  {
    "country": "UG",
    "name": "Kaberamaido",
    "lat": "1.73889",
    "lng": "33.15944"
  },
  {
    "country": "UG",
    "name": "Kabale",
    "lat": "-1.24857",
    "lng": "29.98993"
  },
  {
    "country": "UG",
    "name": "Kaabong",
    "lat": "3.48361",
    "lng": "34.14917"
  },
  {
    "country": "UG",
    "name": "Jinja",
    "lat": "0.43902",
    "lng": "33.20317"
  },
  {
    "country": "UG",
    "name": "Iganga",
    "lat": "0.60917",
    "lng": "33.46861"
  },
  {
    "country": "UG",
    "name": "Ibanda",
    "lat": "-0.13398",
    "lng": "30.49616"
  },
  {
    "country": "UG",
    "name": "Hoima",
    "lat": "1.43314",
    "lng": "31.35241"
  },
  {
    "country": "UG",
    "name": "Gulu",
    "lat": "2.77457",
    "lng": "32.29899"
  },
  {
    "country": "UG",
    "name": "Gombe",
    "lat": "0.20333",
    "lng": "32.08806"
  },
  {
    "country": "UG",
    "name": "Fort Portal",
    "lat": "0.66174",
    "lng": "30.2748"
  },
  {
    "country": "UG",
    "name": "Entebbe",
    "lat": "0.05621",
    "lng": "32.47949"
  },
  {
    "country": "UG",
    "name": "Dokolo",
    "lat": "1.89833",
    "lng": "33.1775"
  },
  {
    "country": "UG",
    "name": "Byakabanda",
    "lat": "-0.7425",
    "lng": "31.40639"
  },
  {
    "country": "UG",
    "name": "Bwizibwera",
    "lat": "-0.59167",
    "lng": "30.62861"
  },
  {
    "country": "UG",
    "name": "Bweyogerere",
    "lat": "0.35773",
    "lng": "32.66332"
  },
  {
    "country": "UG",
    "name": "Buyende",
    "lat": "1.15167",
    "lng": "33.155"
  },
  {
    "country": "UG",
    "name": "Buwenge",
    "lat": "0.64996",
    "lng": "33.17128"
  },
  {
    "country": "UG",
    "name": "Butebo",
    "lat": "1.19417",
    "lng": "33.92222"
  },
  {
    "country": "UG",
    "name": "Butaleja",
    "lat": "0.91194",
    "lng": "33.95111"
  },
  {
    "country": "UG",
    "name": "Busia",
    "lat": "0.46588",
    "lng": "34.09221"
  },
  {
    "country": "UG",
    "name": "Bushenyi",
    "lat": "-0.53695",
    "lng": "30.18579"
  },
  {
    "country": "UG",
    "name": "Busembatia",
    "lat": "0.77725",
    "lng": "33.62364"
  },
  {
    "country": "UG",
    "name": "Bundibugyo",
    "lat": "0.71117",
    "lng": "30.06469"
  },
  {
    "country": "UG",
    "name": "Bulisa",
    "lat": "2.11781",
    "lng": "31.41163"
  },
  {
    "country": "UG",
    "name": "Bulambuli",
    "lat": "1.16667",
    "lng": "34.38333"
  },
  {
    "country": "UG",
    "name": "Bukwa",
    "lat": "1.25917",
    "lng": "34.75389"
  },
  {
    "country": "UG",
    "name": "Bukomansimbi",
    "lat": "-0.15778",
    "lng": "31.60417"
  },
  {
    "country": "UG",
    "name": "Bukedea",
    "lat": "1.31694",
    "lng": "34.05056"
  },
  {
    "country": "UG",
    "name": "Buikwe",
    "lat": "0.3375",
    "lng": "33.01056"
  },
  {
    "country": "UG",
    "name": "Bugiri",
    "lat": "0.57139",
    "lng": "33.74167"
  },
  {
    "country": "UG",
    "name": "Bugembe",
    "lat": "0.48213",
    "lng": "33.24065"
  },
  {
    "country": "UG",
    "name": "Bududa",
    "lat": "1.01118",
    "lng": "34.33112"
  },
  {
    "country": "UG",
    "name": "Budaka",
    "lat": "1.00389",
    "lng": "33.92556"
  },
  {
    "country": "UG",
    "name": "Binyin",
    "lat": "1.41667",
    "lng": "34.53333"
  },
  {
    "country": "UG",
    "name": "Arua",
    "lat": "3.02013",
    "lng": "30.91105"
  },
  {
    "country": "UG",
    "name": "Apac",
    "lat": "1.97556",
    "lng": "32.53861"
  },
  {
    "country": "UG",
    "name": "Amuria",
    "lat": "2.00361",
    "lng": "33.65111"
  },
  {
    "country": "UG",
    "name": "Amudat",
    "lat": "1.95",
    "lng": "34.95"
  },
  {
    "country": "UG",
    "name": "Amolatar",
    "lat": "1.61556",
    "lng": "32.83972"
  },
  {
    "country": "UG",
    "name": "Alebtong",
    "lat": "2.24472",
    "lng": "33.25472"
  },
  {
    "country": "UG",
    "name": "Adjumani",
    "lat": "3.37786",
    "lng": "31.7909"
  },
  {
    "country": "UG",
    "name": "Abim",
    "lat": "2.70167",
    "lng": "33.67611"
  },
  {
    "country": "UG",
    "name": "Nakapiripirit",
    "lat": "1.91667",
    "lng": "34.78333"
  },
  {
    "country": "UG",
    "name": "Pader",
    "lat": "3.05",
    "lng": "33.21667"
  },
  {
    "country": "UG",
    "name": "Margherita",
    "lat": "0.41861",
    "lng": "29.89111"
  },
  {
    "country": "UG",
    "name": "Nwoya",
    "lat": "2.63422",
    "lng": "32.00106"
  },
  {
    "country": "UG",
    "name": "Isingiro",
    "lat": "-0.86864",
    "lng": "30.83019"
  },
  {
    "country": "UG",
    "name": "Manafwa",
    "lat": "0.97842",
    "lng": "34.3743"
  },
  {
    "country": "UG",
    "name": "Oyam",
    "lat": "2.235",
    "lng": "32.38495"
  },
  {
    "country": "UG",
    "name": "Amuru",
    "lat": "2.81388",
    "lng": "31.93868"
  },
  {
    "country": "UG",
    "name": "Namayingo",
    "lat": "0.23983",
    "lng": "33.88491"
  },
  {
    "country": "UG",
    "name": "Kitamilo",
    "lat": "0.22215",
    "lng": "33.20608"
  },
  {
    "country": "UG",
    "name": "Kyankwanzi",
    "lat": "1.20061",
    "lng": "31.80063"
  },
  {
    "country": "UG",
    "name": "Kole",
    "lat": "2.40015",
    "lng": "32.80034"
  },
  {
    "country": "UG",
    "name": "Otuke",
    "lat": "2.50038",
    "lng": "33.50065"
  },
  {
    "country": "UG",
    "name": "Napak",
    "lat": "2.25139",
    "lng": "34.25012"
  },
  {
    "country": "UG",
    "name": "Luuka Town",
    "lat": "0.70076",
    "lng": "33.3002"
  },
  {
    "country": "UG",
    "name": "Buhweju",
    "lat": "-0.35027",
    "lng": "30.30029"
  },
  {
    "country": "UG",
    "name": "Agago",
    "lat": "2.83383",
    "lng": "33.33361"
  },
  {
    "country": "UG",
    "name": "Lamwo",
    "lat": "3.52972",
    "lng": "32.8016"
  },
  {
    "country": "UG",
    "name": "Kampala Central Division",
    "lat": "0.32467",
    "lng": "32.5747"
  },
  {
    "country": "US",
    "name": "Bay Minette",
    "lat": "30.88296",
    "lng": "-87.77305"
  },
  {
    "country": "US",
    "name": "Edna",
    "lat": "28.97859",
    "lng": "-96.64609"
  },
  {
    "country": "US",
    "name": "Bayou La Batre",
    "lat": "30.40352",
    "lng": "-88.24852"
  },
  {
    "country": "US",
    "name": "Henderson",
    "lat": "32.15322",
    "lng": "-94.79938"
  },
  {
    "country": "US",
    "name": "Natalia",
    "lat": "29.18968",
    "lng": "-98.86253"
  },
  {
    "country": "US",
    "name": "Bear Creek",
    "lat": "34.27482",
    "lng": "-87.70058"
  },
  {
    "country": "US",
    "name": "Fort Hunt",
    "lat": "38.73289",
    "lng": "-77.05803"
  },
  {
    "country": "US",
    "name": "Yorktown",
    "lat": "37.23876",
    "lng": "-76.50967"
  },
  {
    "country": "US",
    "name": "Brighton",
    "lat": "33.43428",
    "lng": "-86.94721"
  },
  {
    "country": "US",
    "name": "Ocean View",
    "lat": "38.54511",
    "lng": "-75.08907"
  },
  {
    "country": "US",
    "name": "Berry",
    "lat": "33.65983",
    "lng": "-87.60001"
  },
  {
    "country": "US",
    "name": "Trinity",
    "lat": "28.18085",
    "lng": "-82.68177"
  },
  {
    "country": "US",
    "name": "Villas",
    "lat": "26.55035",
    "lng": "-81.8687"
  },
  {
    "country": "US",
    "name": "Bessemer",
    "lat": "33.40178",
    "lng": "-86.95444"
  },
  {
    "country": "US",
    "name": "Aurora",
    "lat": "39.057",
    "lng": "-84.90134"
  },
  {
    "country": "US",
    "name": "New Pekin",
    "lat": "38.50506",
    "lng": "-86.01692"
  },
  {
    "country": "US",
    "name": "Stockton",
    "lat": "39.43807",
    "lng": "-99.2651"
  },
  {
    "country": "US",
    "name": "Paducah",
    "lat": "37.08339",
    "lng": "-88.60005"
  },
  {
    "country": "US",
    "name": "Monticello",
    "lat": "32.59653",
    "lng": "-91.394"
  },
  {
    "country": "US",
    "name": "Red Chute",
    "lat": "32.55598",
    "lng": "-93.61323"
  },
  {
    "country": "US",
    "name": "Jessup",
    "lat": "39.14927",
    "lng": "-76.77525"
  },
  {
    "country": "US",
    "name": "Birmingham",
    "lat": "33.52066",
    "lng": "-86.80249"
  },
  {
    "country": "US",
    "name": "Delhi Hills",
    "lat": "39.09284",
    "lng": "-84.61272"
  },
  {
    "country": "US",
    "name": "Turpin Hills",
    "lat": "39.11006",
    "lng": "-84.37994"
  },
  {
    "country": "US",
    "name": "Lugoff",
    "lat": "34.22737",
    "lng": "-80.68925"
  },
  {
    "country": "US",
    "name": "Blountsville",
    "lat": "34.08149",
    "lng": "-86.5911"
  },
  {
    "country": "US",
    "name": "Blue Ridge",
    "lat": "32.49264",
    "lng": "-86.19052"
  },
  {
    "country": "US",
    "name": "Buda",
    "lat": "30.08521",
    "lng": "-97.84028"
  },
  {
    "country": "US",
    "name": "Boaz",
    "lat": "34.20065",
    "lng": "-86.16637"
  },
  {
    "country": "US",
    "name": "Brent",
    "lat": "32.93735",
    "lng": "-87.16472"
  },
  {
    "country": "US",
    "name": "Brewton",
    "lat": "31.10518",
    "lng": "-87.07219"
  },
  {
    "country": "US",
    "name": "Bridgeport",
    "lat": "34.94758",
    "lng": "-85.71442"
  },
  {
    "country": "US",
    "name": "Brook Highland",
    "lat": "33.43566",
    "lng": "-86.67388"
  },
  {
    "country": "US",
    "name": "Brookside",
    "lat": "33.63788",
    "lng": "-86.91666"
  },
  {
    "country": "US",
    "name": "Brookwood",
    "lat": "33.25567",
    "lng": "-87.32083"
  },
  {
    "country": "US",
    "name": "Brundidge",
    "lat": "31.72016",
    "lng": "-85.81606"
  },
  {
    "country": "US",
    "name": "Butler",
    "lat": "32.08959",
    "lng": "-88.22197"
  },
  {
    "country": "US",
    "name": "Bynum",
    "lat": "33.61316",
    "lng": "-85.96108"
  },
  {
    "country": "US",
    "name": "Cahaba Heights",
    "lat": "33.464",
    "lng": "-86.73193"
  },
  {
    "country": "US",
    "name": "Calera",
    "lat": "33.1029",
    "lng": "-86.7536"
  },
  {
    "country": "US",
    "name": "Camden",
    "lat": "31.99098",
    "lng": "-87.29055"
  },
  {
    "country": "US",
    "name": "Carbon Hill",
    "lat": "33.89177",
    "lng": "-87.52612"
  },
  {
    "country": "US",
    "name": "Carrollton",
    "lat": "33.26169",
    "lng": "-88.09503"
  },
  {
    "country": "US",
    "name": "Cedar Bluff",
    "lat": "34.22009",
    "lng": "-85.60774"
  },
  {
    "country": "US",
    "name": "Center Point",
    "lat": "33.64566",
    "lng": "-86.6836"
  },
  {
    "country": "US",
    "name": "Centre",
    "lat": "34.15204",
    "lng": "-85.67885"
  },
  {
    "country": "US",
    "name": "Centreville",
    "lat": "32.9462",
    "lng": "-87.11669"
  },
  {
    "country": "US",
    "name": "Chalkville",
    "lat": "33.65316",
    "lng": "-86.64777"
  },
  {
    "country": "US",
    "name": "Chatom",
    "lat": "31.46517",
    "lng": "-88.25446"
  },
  {
    "country": "US",
    "name": "Chelsea",
    "lat": "33.34011",
    "lng": "-86.63026"
  },
  {
    "country": "US",
    "name": "Cherokee",
    "lat": "34.75703",
    "lng": "-87.97281"
  },
  {
    "country": "US",
    "name": "Chickasaw",
    "lat": "30.7638",
    "lng": "-88.07472"
  },
  {
    "country": "US",
    "name": "Childersburg",
    "lat": "33.27817",
    "lng": "-86.35498"
  },
  {
    "country": "US",
    "name": "Choccolocco",
    "lat": "33.65927",
    "lng": "-85.70357"
  },
  {
    "country": "US",
    "name": "Citronelle",
    "lat": "31.09073",
    "lng": "-88.22806"
  },
  {
    "country": "US",
    "name": "Clanton",
    "lat": "32.83874",
    "lng": "-86.62943"
  },
  {
    "country": "US",
    "name": "Clay",
    "lat": "33.7026",
    "lng": "-86.59971"
  },
  {
    "country": "US",
    "name": "Clayton",
    "lat": "31.87822",
    "lng": "-85.44966"
  },
  {
    "country": "US",
    "name": "Cleveland",
    "lat": "33.99093",
    "lng": "-86.57749"
  },
  {
    "country": "US",
    "name": "Clio",
    "lat": "31.70878",
    "lng": "-85.6105"
  },
  {
    "country": "US",
    "name": "Coaling",
    "lat": "33.15901",
    "lng": "-87.34083"
  },
  {
    "country": "US",
    "name": "Collinsville",
    "lat": "34.26398",
    "lng": "-85.86053"
  },
  {
    "country": "US",
    "name": "Columbiana",
    "lat": "33.17817",
    "lng": "-86.60721"
  },
  {
    "country": "US",
    "name": "Concord",
    "lat": "33.46761",
    "lng": "-87.03111"
  },
  {
    "country": "US",
    "name": "Coosada",
    "lat": "32.49791",
    "lng": "-86.33136"
  },
  {
    "country": "US",
    "name": "Cordova",
    "lat": "33.75983",
    "lng": "-87.18333"
  },
  {
    "country": "US",
    "name": "Cottonwood",
    "lat": "31.04879",
    "lng": "-85.30493"
  },
  {
    "country": "US",
    "name": "Cowarts",
    "lat": "31.20018",
    "lng": "-85.30465"
  },
  {
    "country": "US",
    "name": "Creola",
    "lat": "30.89185",
    "lng": "-88.03972"
  },
  {
    "country": "US",
    "name": "Crossville",
    "lat": "34.28759",
    "lng": "-85.99414"
  },
  {
    "country": "US",
    "name": "Cullman",
    "lat": "34.17482",
    "lng": "-86.84361"
  },
  {
    "country": "US",
    "name": "Dadeville",
    "lat": "32.83124",
    "lng": "-85.76357"
  },
  {
    "country": "US",
    "name": "Daleville",
    "lat": "31.31017",
    "lng": "-85.71299"
  },
  {
    "country": "US",
    "name": "Danville",
    "lat": "34.41454",
    "lng": "-87.08751"
  },
  {
    "country": "US",
    "name": "Daphne",
    "lat": "30.60353",
    "lng": "-87.9036"
  },
  {
    "country": "US",
    "name": "Dauphin Island",
    "lat": "30.25548",
    "lng": "-88.10972"
  },
  {
    "country": "US",
    "name": "Deatsville",
    "lat": "32.60819",
    "lng": "-86.39581"
  },
  {
    "country": "US",
    "name": "Decatur",
    "lat": "34.60593",
    "lng": "-86.98334"
  },
  {
    "country": "US",
    "name": "Demopolis",
    "lat": "32.51764",
    "lng": "-87.8364"
  },
  {
    "country": "US",
    "name": "Dora",
    "lat": "33.72872",
    "lng": "-87.09028"
  },
  {
    "country": "US",
    "name": "Dothan",
    "lat": "31.22323",
    "lng": "-85.39049"
  },
  {
    "country": "US",
    "name": "Double Springs",
    "lat": "34.14637",
    "lng": "-87.40247"
  },
  {
    "country": "US",
    "name": "East Brewton",
    "lat": "31.09323",
    "lng": "-87.06275"
  },
  {
    "country": "US",
    "name": "East Florence",
    "lat": "34.80953",
    "lng": "-87.64947"
  },
  {
    "country": "US",
    "name": "Eclectic",
    "lat": "32.63541",
    "lng": "-86.03441"
  },
  {
    "country": "US",
    "name": "Elberta",
    "lat": "30.41436",
    "lng": "-87.59776"
  },
  {
    "country": "US",
    "name": "Enterprise",
    "lat": "31.31517",
    "lng": "-85.85522"
  },
  {
    "country": "US",
    "name": "Eufaula",
    "lat": "31.89127",
    "lng": "-85.14549"
  },
  {
    "country": "US",
    "name": "Eutaw",
    "lat": "32.84059",
    "lng": "-87.88762"
  },
  {
    "country": "US",
    "name": "Evergreen",
    "lat": "31.4335",
    "lng": "-86.95692"
  },
  {
    "country": "US",
    "name": "Fairfield",
    "lat": "33.48594",
    "lng": "-86.91194"
  },
  {
    "country": "US",
    "name": "Fairhope",
    "lat": "30.52297",
    "lng": "-87.90333"
  },
  {
    "country": "US",
    "name": "Falkville",
    "lat": "34.36843",
    "lng": "-86.90862"
  },
  {
    "country": "US",
    "name": "Fayette",
    "lat": "33.68455",
    "lng": "-87.83085"
  },
  {
    "country": "US",
    "name": "Fayetteville",
    "lat": "33.14567",
    "lng": "-86.40581"
  },
  {
    "country": "US",
    "name": "Flint City",
    "lat": "34.52315",
    "lng": "-86.97029"
  },
  {
    "country": "US",
    "name": "Florala",
    "lat": "31.00518",
    "lng": "-86.328"
  },
  {
    "country": "US",
    "name": "Florence",
    "lat": "34.79981",
    "lng": "-87.67725"
  },
  {
    "country": "US",
    "name": "Flomaton",
    "lat": "31.00018",
    "lng": "-87.26081"
  },
  {
    "country": "US",
    "name": "Foley",
    "lat": "30.40659",
    "lng": "-87.6836"
  },
  {
    "country": "US",
    "name": "Forestdale",
    "lat": "33.57011",
    "lng": "-86.89638"
  },
  {
    "country": "US",
    "name": "Fort Deposit",
    "lat": "31.98459",
    "lng": "-86.57859"
  },
  {
    "country": "US",
    "name": "Fort Payne",
    "lat": "34.44425",
    "lng": "-85.71969"
  },
  {
    "country": "US",
    "name": "Frisco City",
    "lat": "31.4335",
    "lng": "-87.40138"
  },
  {
    "country": "US",
    "name": "Fultondale",
    "lat": "33.60483",
    "lng": "-86.79388"
  },
  {
    "country": "US",
    "name": "Fyffe",
    "lat": "34.44676",
    "lng": "-85.90414"
  },
  {
    "country": "US",
    "name": "Gadsden",
    "lat": "34.01434",
    "lng": "-86.00639"
  },
  {
    "country": "US",
    "name": "Gardendale",
    "lat": "33.6601",
    "lng": "-86.81277"
  },
  {
    "country": "US",
    "name": "Geneva",
    "lat": "31.03296",
    "lng": "-85.86382"
  },
  {
    "country": "US",
    "name": "Georgiana",
    "lat": "31.6371",
    "lng": "-86.74192"
  },
  {
    "country": "US",
    "name": "Glencoe",
    "lat": "33.95704",
    "lng": "-85.93247"
  },
  {
    "country": "US",
    "name": "Good Hope",
    "lat": "34.11593",
    "lng": "-86.86361"
  },
  {
    "country": "US",
    "name": "Goodwater",
    "lat": "33.06567",
    "lng": "-86.0533"
  },
  {
    "country": "US",
    "name": "Gordo",
    "lat": "33.32012",
    "lng": "-87.9028"
  },
  {
    "country": "US",
    "name": "Grand Bay",
    "lat": "30.47631",
    "lng": "-88.34223"
  },
  {
    "country": "US",
    "name": "Grayson Valley",
    "lat": "33.64816",
    "lng": "-86.63943"
  },
  {
    "country": "US",
    "name": "Graysville",
    "lat": "33.62066",
    "lng": "-86.97138"
  },
  {
    "country": "US",
    "name": "Greensboro",
    "lat": "32.70415",
    "lng": "-87.5955"
  },
  {
    "country": "US",
    "name": "Greenville",
    "lat": "31.8296",
    "lng": "-86.61775"
  },
  {
    "country": "US",
    "name": "Grove Hill",
    "lat": "31.70877",
    "lng": "-87.77722"
  },
  {
    "country": "US",
    "name": "Guin",
    "lat": "33.96566",
    "lng": "-87.91475"
  },
  {
    "country": "US",
    "name": "Gulf Shores",
    "lat": "30.24604",
    "lng": "-87.70082"
  },
  {
    "country": "US",
    "name": "Guntersville",
    "lat": "34.35823",
    "lng": "-86.29446"
  },
  {
    "country": "US",
    "name": "Hackleburg",
    "lat": "34.27732",
    "lng": "-87.82864"
  },
  {
    "country": "US",
    "name": "Haleyville",
    "lat": "34.22649",
    "lng": "-87.62141"
  },
  {
    "country": "US",
    "name": "Hamilton",
    "lat": "34.14232",
    "lng": "-87.98864"
  },
  {
    "country": "US",
    "name": "Hanceville",
    "lat": "34.06065",
    "lng": "-86.7675"
  },
  {
    "country": "US",
    "name": "Harpersville",
    "lat": "33.344",
    "lng": "-86.43804"
  },
  {
    "country": "US",
    "name": "Hartford",
    "lat": "31.1024",
    "lng": "-85.69688"
  },
  {
    "country": "US",
    "name": "Hartselle",
    "lat": "34.44343",
    "lng": "-86.93528"
  },
  {
    "country": "US",
    "name": "Harvest",
    "lat": "34.85564",
    "lng": "-86.75083"
  },
  {
    "country": "US",
    "name": "Hayden",
    "lat": "33.8926",
    "lng": "-86.75777"
  },
  {
    "country": "US",
    "name": "Hayneville",
    "lat": "32.18403",
    "lng": "-86.58025"
  },
  {
    "country": "US",
    "name": "Hazel Green",
    "lat": "34.93231",
    "lng": "-86.57194"
  },
  {
    "country": "US",
    "name": "Headland",
    "lat": "31.35128",
    "lng": "-85.34216"
  },
  {
    "country": "US",
    "name": "Heflin",
    "lat": "33.64899",
    "lng": "-85.58746"
  },
  {
    "country": "US",
    "name": "Helena",
    "lat": "33.29622",
    "lng": "-86.8436"
  },
  {
    "country": "US",
    "name": "Henagar",
    "lat": "34.63508",
    "lng": "-85.76719"
  },
  {
    "country": "US",
    "name": "Hokes Bluff",
    "lat": "33.99815",
    "lng": "-85.86636"
  },
  {
    "country": "US",
    "name": "Holt",
    "lat": "33.23401",
    "lng": "-87.48445"
  },
  {
    "country": "US",
    "name": "Holtville",
    "lat": "32.63624",
    "lng": "-86.32664"
  },
  {
    "country": "US",
    "name": "Homewood",
    "lat": "33.47177",
    "lng": "-86.80082"
  },
  {
    "country": "US",
    "name": "Hoover",
    "lat": "33.40539",
    "lng": "-86.81138"
  },
  {
    "country": "US",
    "name": "Hueytown",
    "lat": "33.45122",
    "lng": "-86.99666"
  },
  {
    "country": "US",
    "name": "Huguley",
    "lat": "32.83457",
    "lng": "-85.22966"
  },
  {
    "country": "US",
    "name": "Huntsville",
    "lat": "34.7304",
    "lng": "-86.58594"
  },
  {
    "country": "US",
    "name": "Indian Springs Village",
    "lat": "33.35539",
    "lng": "-86.75443"
  },
  {
    "country": "US",
    "name": "Inverness",
    "lat": "32.01488",
    "lng": "-85.74606"
  },
  {
    "country": "US",
    "name": "Irondale",
    "lat": "33.53816",
    "lng": "-86.70721"
  },
  {
    "country": "US",
    "name": "Jackson",
    "lat": "31.50905",
    "lng": "-87.89444"
  },
  {
    "country": "US",
    "name": "Jacksonville",
    "lat": "33.81382",
    "lng": "-85.7613"
  },
  {
    "country": "US",
    "name": "Jasper",
    "lat": "33.83122",
    "lng": "-87.27751"
  },
  {
    "country": "US",
    "name": "Jemison",
    "lat": "32.95985",
    "lng": "-86.74665"
  },
  {
    "country": "US",
    "name": "Kimberly",
    "lat": "33.77344",
    "lng": "-86.81388"
  },
  {
    "country": "US",
    "name": "Kinsey",
    "lat": "31.29906",
    "lng": "-85.34438"
  },
  {
    "country": "US",
    "name": "Ladonia",
    "lat": "32.4682",
    "lng": "-85.0791"
  },
  {
    "country": "US",
    "name": "Lafayette",
    "lat": "32.89985",
    "lng": "-85.40106"
  },
  {
    "country": "US",
    "name": "Lake Purdy",
    "lat": "33.43011",
    "lng": "-86.68054"
  },
  {
    "country": "US",
    "name": "Lake View",
    "lat": "33.28067",
    "lng": "-87.1375"
  },
  {
    "country": "US",
    "name": "Lanett",
    "lat": "32.86874",
    "lng": "-85.1905"
  },
  {
    "country": "US",
    "name": "Leeds",
    "lat": "33.54816",
    "lng": "-86.54443"
  },
  {
    "country": "US",
    "name": "Leesburg",
    "lat": "34.17982",
    "lng": "-85.76136"
  },
  {
    "country": "US",
    "name": "Level Plains",
    "lat": "31.29962",
    "lng": "-85.77799"
  },
  {
    "country": "US",
    "name": "Linden",
    "lat": "32.30625",
    "lng": "-87.79807"
  },
  {
    "country": "US",
    "name": "Lincoln",
    "lat": "33.61316",
    "lng": "-86.11831"
  },
  {
    "country": "US",
    "name": "Lineville",
    "lat": "33.31067",
    "lng": "-85.75441"
  },
  {
    "country": "US",
    "name": "Lipscomb",
    "lat": "33.42566",
    "lng": "-86.92666"
  },
  {
    "country": "US",
    "name": "Livingston",
    "lat": "32.5843",
    "lng": "-88.18725"
  },
  {
    "country": "US",
    "name": "Locust Fork",
    "lat": "33.9076",
    "lng": "-86.61527"
  },
  {
    "country": "US",
    "name": "Loxley",
    "lat": "30.61825",
    "lng": "-87.75305"
  },
  {
    "country": "US",
    "name": "Luverne",
    "lat": "31.71655",
    "lng": "-86.26385"
  },
  {
    "country": "US",
    "name": "Madison",
    "lat": "34.69926",
    "lng": "-86.74833"
  },
  {
    "country": "US",
    "name": "Malvern",
    "lat": "31.13934",
    "lng": "-85.5191"
  },
  {
    "country": "US",
    "name": "Marbury",
    "lat": "32.70124",
    "lng": "-86.47109"
  },
  {
    "country": "US",
    "name": "Margaret",
    "lat": "33.68621",
    "lng": "-86.47498"
  },
  {
    "country": "US",
    "name": "Marion",
    "lat": "32.63235",
    "lng": "-87.31917"
  },
  {
    "country": "US",
    "name": "Meadowbrook",
    "lat": "33.40205",
    "lng": "-86.69665"
  },
  {
    "country": "US",
    "name": "Meridianville",
    "lat": "34.85148",
    "lng": "-86.57222"
  },
  {
    "country": "US",
    "name": "Midfield",
    "lat": "33.4615",
    "lng": "-86.90888"
  },
  {
    "country": "US",
    "name": "Midland City",
    "lat": "31.31906",
    "lng": "-85.49382"
  },
  {
    "country": "US",
    "name": "Mignon",
    "lat": "33.18345",
    "lng": "-86.26109"
  },
  {
    "country": "US",
    "name": "Millbrook",
    "lat": "32.47986",
    "lng": "-86.36192"
  },
  {
    "country": "US",
    "name": "Minor",
    "lat": "33.53733",
    "lng": "-86.94055"
  },
  {
    "country": "US",
    "name": "Mobile",
    "lat": "30.69436",
    "lng": "-88.04305"
  },
  {
    "country": "US",
    "name": "Monroeville",
    "lat": "31.52794",
    "lng": "-87.32471"
  },
  {
    "country": "US",
    "name": "Montevallo",
    "lat": "33.10067",
    "lng": "-86.86416"
  },
  {
    "country": "US",
    "name": "Montgomery",
    "lat": "32.36681",
    "lng": "-86.29997"
  },
  {
    "country": "US",
    "name": "Moody",
    "lat": "33.59094",
    "lng": "-86.49082"
  },
  {
    "country": "US",
    "name": "Moores Mill",
    "lat": "34.84398",
    "lng": "-86.51832"
  },
  {
    "country": "US",
    "name": "Morris",
    "lat": "33.74816",
    "lng": "-86.8086"
  },
  {
    "country": "US",
    "name": "Moulton",
    "lat": "34.48121",
    "lng": "-87.29335"
  },
  {
    "country": "US",
    "name": "Moundville",
    "lat": "32.99762",
    "lng": "-87.63001"
  },
  {
    "country": "US",
    "name": "Mount Olive",
    "lat": "33.67094",
    "lng": "-86.8561"
  },
  {
    "country": "US",
    "name": "Mount Vernon",
    "lat": "31.08518",
    "lng": "-88.01333"
  },
  {
    "country": "US",
    "name": "Mountain Brook",
    "lat": "33.50094",
    "lng": "-86.75221"
  },
  {
    "country": "US",
    "name": "Munford",
    "lat": "33.52983",
    "lng": "-85.9508"
  },
  {
    "country": "US",
    "name": "Muscle Shoals",
    "lat": "34.74481",
    "lng": "-87.66753"
  },
  {
    "country": "US",
    "name": "New Brockton",
    "lat": "31.38572",
    "lng": "-85.92939"
  },
  {
    "country": "US",
    "name": "New Hope",
    "lat": "34.53712",
    "lng": "-86.39426"
  },
  {
    "country": "US",
    "name": "New Market",
    "lat": "34.91003",
    "lng": "-86.42779"
  },
  {
    "country": "US",
    "name": "Newton",
    "lat": "31.33517",
    "lng": "-85.60521"
  },
  {
    "country": "US",
    "name": "North Bibb",
    "lat": "33.20401",
    "lng": "-87.15305"
  },
  {
    "country": "US",
    "name": "Northport",
    "lat": "33.22901",
    "lng": "-87.57723"
  },
  {
    "country": "US",
    "name": "Odenville",
    "lat": "33.67732",
    "lng": "-86.39665"
  },
  {
    "country": "US",
    "name": "Ohatchee",
    "lat": "33.78343",
    "lng": "-86.00247"
  },
  {
    "country": "US",
    "name": "Opelika",
    "lat": "32.64541",
    "lng": "-85.37828"
  },
  {
    "country": "US",
    "name": "Oneonta",
    "lat": "33.94815",
    "lng": "-86.47276"
  },
  {
    "country": "US",
    "name": "Opp",
    "lat": "31.28267",
    "lng": "-86.25551"
  },
  {
    "country": "US",
    "name": "Orange Beach",
    "lat": "30.29437",
    "lng": "-87.57359"
  },
  {
    "country": "US",
    "name": "Owens Cross Roads",
    "lat": "34.58815",
    "lng": "-86.45888"
  },
  {
    "country": "US",
    "name": "Oxford",
    "lat": "33.61427",
    "lng": "-85.83496"
  },
  {
    "country": "US",
    "name": "Ozark",
    "lat": "31.45906",
    "lng": "-85.64049"
  },
  {
    "country": "US",
    "name": "Pelham",
    "lat": "33.28567",
    "lng": "-86.80999"
  },
  {
    "country": "US",
    "name": "Pell City",
    "lat": "33.58621",
    "lng": "-86.28609"
  },
  {
    "country": "US",
    "name": "Phenix City",
    "lat": "32.47098",
    "lng": "-85.00077"
  },
  {
    "country": "US",
    "name": "Phil Campbell",
    "lat": "34.35093",
    "lng": "-87.70642"
  },
  {
    "country": "US",
    "name": "Piedmont",
    "lat": "33.92455",
    "lng": "-85.61135"
  },
  {
    "country": "US",
    "name": "Pike Road",
    "lat": "32.28431",
    "lng": "-86.10302"
  },
  {
    "country": "US",
    "name": "Pine Level",
    "lat": "32.58374",
    "lng": "-86.46553"
  },
  {
    "country": "US",
    "name": "Pinson",
    "lat": "33.68899",
    "lng": "-86.68332"
  },
  {
    "country": "US",
    "name": "Pleasant Grove",
    "lat": "33.49094",
    "lng": "-86.97027"
  },
  {
    "country": "US",
    "name": "Point Clear",
    "lat": "30.47408",
    "lng": "-87.91916"
  },
  {
    "country": "US",
    "name": "Prattville",
    "lat": "32.46402",
    "lng": "-86.4597"
  },
  {
    "country": "US",
    "name": "Priceville",
    "lat": "34.52509",
    "lng": "-86.89473"
  },
  {
    "country": "US",
    "name": "Prichard",
    "lat": "30.7388",
    "lng": "-88.07889"
  },
  {
    "country": "US",
    "name": "Ragland",
    "lat": "33.74454",
    "lng": "-86.15581"
  },
  {
    "country": "US",
    "name": "Rainbow City",
    "lat": "33.95482",
    "lng": "-86.04192"
  },
  {
    "country": "US",
    "name": "Rainsville",
    "lat": "34.49425",
    "lng": "-85.84775"
  },
  {
    "country": "US",
    "name": "Red Bay",
    "lat": "34.43982",
    "lng": "-88.14087"
  },
  {
    "country": "US",
    "name": "Reform",
    "lat": "33.37845",
    "lng": "-88.0153"
  },
  {
    "country": "US",
    "name": "Rehobeth",
    "lat": "31.12296",
    "lng": "-85.45271"
  },
  {
    "country": "US",
    "name": "Riverside",
    "lat": "33.60621",
    "lng": "-86.20442"
  },
  {
    "country": "US",
    "name": "Roanoke",
    "lat": "33.15123",
    "lng": "-85.37217"
  },
  {
    "country": "US",
    "name": "Robertsdale",
    "lat": "30.5538",
    "lng": "-87.71193"
  },
  {
    "country": "US",
    "name": "Rock Creek",
    "lat": "33.47705",
    "lng": "-87.08027"
  },
  {
    "country": "US",
    "name": "Rockford",
    "lat": "32.88957",
    "lng": "-86.21969"
  },
  {
    "country": "US",
    "name": "Rogersville",
    "lat": "34.82578",
    "lng": "-87.29676"
  },
  {
    "country": "US",
    "name": "Russellville",
    "lat": "34.50787",
    "lng": "-87.72864"
  },
  {
    "country": "US",
    "name": "Saks",
    "lat": "33.69871",
    "lng": "-85.83969"
  },
  {
    "country": "US",
    "name": "Samson",
    "lat": "31.11295",
    "lng": "-86.04605"
  },
  {
    "country": "US",
    "name": "Saraland",
    "lat": "30.82074",
    "lng": "-88.07056"
  },
  {
    "country": "US",
    "name": "Sardis City",
    "lat": "34.17426",
    "lng": "-86.12275"
  },
  {
    "country": "US",
    "name": "Satsuma",
    "lat": "30.85324",
    "lng": "-88.05611"
  },
  {
    "country": "US",
    "name": "Scottsboro",
    "lat": "34.67231",
    "lng": "-86.03415"
  },
  {
    "country": "US",
    "name": "Selma",
    "lat": "32.40736",
    "lng": "-87.0211"
  },
  {
    "country": "US",
    "name": "Semmes",
    "lat": "30.77824",
    "lng": "-88.25917"
  },
  {
    "country": "US",
    "name": "Sheffield",
    "lat": "34.76509",
    "lng": "-87.69864"
  },
  {
    "country": "US",
    "name": "Shelby",
    "lat": "33.1104",
    "lng": "-86.58415"
  },
  {
    "country": "US",
    "name": "Slocomb",
    "lat": "31.10823",
    "lng": "-85.59438"
  },
  {
    "country": "US",
    "name": "Smiths Station",
    "lat": "32.54014",
    "lng": "-85.09855"
  },
  {
    "country": "US",
    "name": "Smoke Rise",
    "lat": "33.89177",
    "lng": "-86.82027"
  },
  {
    "country": "US",
    "name": "Southside",
    "lat": "33.92454",
    "lng": "-86.02247"
  },
  {
    "country": "US",
    "name": "Spanish Fort",
    "lat": "30.67491",
    "lng": "-87.91527"
  },
  {
    "country": "US",
    "name": "Springville",
    "lat": "33.77505",
    "lng": "-86.47191"
  },
  {
    "country": "US",
    "name": "Steele",
    "lat": "33.93982",
    "lng": "-86.20164"
  },
  {
    "country": "US",
    "name": "Stevenson",
    "lat": "34.86869",
    "lng": "-85.83942"
  },
  {
    "country": "US",
    "name": "Stewartville",
    "lat": "33.07929",
    "lng": "-86.24442"
  },
  {
    "country": "US",
    "name": "Sulligent",
    "lat": "33.90177",
    "lng": "-88.13448"
  },
  {
    "country": "US",
    "name": "Sumiton",
    "lat": "33.75566",
    "lng": "-87.05"
  },
  {
    "country": "US",
    "name": "Summerdale",
    "lat": "30.4877",
    "lng": "-87.69971"
  },
  {
    "country": "US",
    "name": "Sylacauga",
    "lat": "33.17317",
    "lng": "-86.25164"
  },
  {
    "country": "US",
    "name": "Sylvan Springs",
    "lat": "33.51566",
    "lng": "-87.01499"
  },
  {
    "country": "US",
    "name": "Sylvania",
    "lat": "34.56231",
    "lng": "-85.81247"
  },
  {
    "country": "US",
    "name": "Talladega",
    "lat": "33.43594",
    "lng": "-86.1058"
  },
  {
    "country": "US",
    "name": "Tallassee",
    "lat": "32.53597",
    "lng": "-85.89329"
  },
  {
    "country": "US",
    "name": "Tarrant",
    "lat": "33.58344",
    "lng": "-86.77277"
  },
  {
    "country": "US",
    "name": "Taylor",
    "lat": "31.1649",
    "lng": "-85.46827"
  },
  {
    "country": "US",
    "name": "Taylor",
    "lat": "31.97543",
    "lng": "-86.2333"
  },
  {
    "country": "US",
    "name": "Theodore",
    "lat": "30.54769",
    "lng": "-88.17528"
  },
  {
    "country": "US",
    "name": "Thomasville",
    "lat": "31.91349",
    "lng": "-87.73584"
  },
  {
    "country": "US",
    "name": "Thorsby",
    "lat": "32.91568",
    "lng": "-86.71582"
  },
  {
    "country": "US",
    "name": "Tillmans Corner",
    "lat": "30.59019",
    "lng": "-88.17084"
  },
  {
    "country": "US",
    "name": "Town Creek",
    "lat": "34.6812",
    "lng": "-87.40613"
  },
  {
    "country": "US",
    "name": "Trinity",
    "lat": "34.60676",
    "lng": "-87.08835"
  },
  {
    "country": "US",
    "name": "Troy",
    "lat": "31.80877",
    "lng": "-85.96995"
  },
  {
    "country": "US",
    "name": "Trussville",
    "lat": "33.61983",
    "lng": "-86.60888"
  },
  {
    "country": "US",
    "name": "Tuscaloosa",
    "lat": "33.20984",
    "lng": "-87.56917"
  },
  {
    "country": "US",
    "name": "Tuscumbia",
    "lat": "34.7312",
    "lng": "-87.70253"
  },
  {
    "country": "US",
    "name": "Tuskegee",
    "lat": "32.42415",
    "lng": "-85.69096"
  },
  {
    "country": "US",
    "name": "Union Springs",
    "lat": "32.14432",
    "lng": "-85.71495"
  },
  {
    "country": "US",
    "name": "Uniontown",
    "lat": "32.44958",
    "lng": "-87.51417"
  },
  {
    "country": "US",
    "name": "Valley",
    "lat": "32.81874",
    "lng": "-85.17939"
  },
  {
    "country": "US",
    "name": "Valley Grande",
    "lat": "32.50902",
    "lng": "-86.98749"
  },
  {
    "country": "US",
    "name": "Vandiver",
    "lat": "33.47066",
    "lng": "-86.51332"
  },
  {
    "country": "US",
    "name": "Vance",
    "lat": "33.17428",
    "lng": "-87.23361"
  },
  {
    "country": "US",
    "name": "Vernon",
    "lat": "33.75705",
    "lng": "-88.10892"
  },
  {
    "country": "US",
    "name": "Vestavia Hills",
    "lat": "33.44872",
    "lng": "-86.78777"
  },
  {
    "country": "US",
    "name": "Vincent",
    "lat": "33.38455",
    "lng": "-86.41192"
  },
  {
    "country": "US",
    "name": "Warrior",
    "lat": "33.81427",
    "lng": "-86.80944"
  },
  {
    "country": "US",
    "name": "Weaver",
    "lat": "33.75205",
    "lng": "-85.81135"
  },
  {
    "country": "US",
    "name": "Webb",
    "lat": "31.26045",
    "lng": "-85.27327"
  },
  {
    "country": "US",
    "name": "Wedowee",
    "lat": "33.309",
    "lng": "-85.48467"
  },
  {
    "country": "US",
    "name": "West Blocton",
    "lat": "33.11817",
    "lng": "-87.125"
  },
  {
    "country": "US",
    "name": "Westover",
    "lat": "33.34955",
    "lng": "-86.53582"
  },
  {
    "country": "US",
    "name": "Wetumpka",
    "lat": "32.54374",
    "lng": "-86.21191"
  },
  {
    "country": "US",
    "name": "Whitesboro",
    "lat": "34.16343",
    "lng": "-86.06942"
  },
  {
    "country": "US",
    "name": "Wilsonville",
    "lat": "33.23428",
    "lng": "-86.48359"
  },
  {
    "country": "US",
    "name": "Winfield",
    "lat": "33.92899",
    "lng": "-87.81725"
  },
  {
    "country": "US",
    "name": "Woodstock",
    "lat": "33.20678",
    "lng": "-87.15"
  },
  {
    "country": "US",
    "name": "York",
    "lat": "32.48625",
    "lng": "-88.29642"
  },
  {
    "country": "US",
    "name": "Alexander",
    "lat": "34.62954",
    "lng": "-92.44127"
  },
  {
    "country": "US",
    "name": "Alma",
    "lat": "35.47787",
    "lng": "-94.22188"
  },
  {
    "country": "US",
    "name": "Arkadelphia",
    "lat": "34.12093",
    "lng": "-93.05378"
  },
  {
    "country": "US",
    "name": "Arkansas City",
    "lat": "33.60872",
    "lng": "-91.20678"
  },
  {
    "country": "US",
    "name": "Ash Flat",
    "lat": "36.22396",
    "lng": "-91.60848"
  },
  {
    "country": "US",
    "name": "Ashdown",
    "lat": "33.67429",
    "lng": "-94.13131"
  },
  {
    "country": "US",
    "name": "Atkins",
    "lat": "35.24647",
    "lng": "-92.93656"
  },
  {
    "country": "US",
    "name": "Augusta",
    "lat": "35.28231",
    "lng": "-91.36541"
  },
  {
    "country": "US",
    "name": "Austin",
    "lat": "34.99842",
    "lng": "-91.98376"
  },
  {
    "country": "US",
    "name": "Bald Knob",
    "lat": "35.30981",
    "lng": "-91.56791"
  },
  {
    "country": "US",
    "name": "Barling",
    "lat": "35.32565",
    "lng": "-94.3016"
  },
  {
    "country": "US",
    "name": "Batesville",
    "lat": "35.7698",
    "lng": "-91.64097"
  },
  {
    "country": "US",
    "name": "Bay",
    "lat": "35.7423",
    "lng": "-90.56233"
  },
  {
    "country": "US",
    "name": "Beebe",
    "lat": "35.07064",
    "lng": "-91.87959"
  },
  {
    "country": "US",
    "name": "Bella Vista",
    "lat": "36.4807",
    "lng": "-94.27134"
  },
  {
    "country": "US",
    "name": "Benton",
    "lat": "34.56454",
    "lng": "-92.58683"
  },
  {
    "country": "US",
    "name": "Bentonville",
    "lat": "36.37285",
    "lng": "-94.20882"
  },
  {
    "country": "US",
    "name": "Berryville",
    "lat": "36.36479",
    "lng": "-93.56797"
  },
  {
    "country": "US",
    "name": "Bethel Heights",
    "lat": "36.21424",
    "lng": "-94.12937"
  },
  {
    "country": "US",
    "name": "Blytheville",
    "lat": "35.9273",
    "lng": "-89.91898"
  },
  {
    "country": "US",
    "name": "Bono",
    "lat": "35.90868",
    "lng": "-90.80262"
  },
  {
    "country": "US",
    "name": "Booneville",
    "lat": "35.14009",
    "lng": "-93.92159"
  },
  {
    "country": "US",
    "name": "Brinkley",
    "lat": "34.88787",
    "lng": "-91.19457"
  },
  {
    "country": "US",
    "name": "Brookland",
    "lat": "35.90007",
    "lng": "-90.58205"
  },
  {
    "country": "US",
    "name": "Bryant",
    "lat": "34.59593",
    "lng": "-92.48905"
  },
  {
    "country": "US",
    "name": "Bull Shoals",
    "lat": "36.38396",
    "lng": "-92.58155"
  },
  {
    "country": "US",
    "name": "Cabot",
    "lat": "34.97453",
    "lng": "-92.01653"
  },
  {
    "country": "US",
    "name": "Calico Rock",
    "lat": "36.11951",
    "lng": "-92.13599"
  },
  {
    "country": "US",
    "name": "Camden",
    "lat": "33.58456",
    "lng": "-92.83433"
  },
  {
    "country": "US",
    "name": "Caraway",
    "lat": "35.75813",
    "lng": "-90.32232"
  },
  {
    "country": "US",
    "name": "Carlisle",
    "lat": "34.78315",
    "lng": "-91.74652"
  },
  {
    "country": "US",
    "name": "Cave City",
    "lat": "35.94174",
    "lng": "-91.54847"
  },
  {
    "country": "US",
    "name": "Cave Springs",
    "lat": "36.26341",
    "lng": "-94.23187"
  },
  {
    "country": "US",
    "name": "Cedarville",
    "lat": "35.56981",
    "lng": "-94.36688"
  },
  {
    "country": "US",
    "name": "Centerton",
    "lat": "36.3598",
    "lng": "-94.28521"
  },
  {
    "country": "US",
    "name": "Charleston",
    "lat": "35.29704",
    "lng": "-94.03632"
  },
  {
    "country": "US",
    "name": "Cherokee Village",
    "lat": "36.29784",
    "lng": "-91.51597"
  },
  {
    "country": "US",
    "name": "Clarendon",
    "lat": "34.69315",
    "lng": "-91.31374"
  },
  {
    "country": "US",
    "name": "Clarksville",
    "lat": "35.47147",
    "lng": "-93.46657"
  },
  {
    "country": "US",
    "name": "Clinton",
    "lat": "35.59147",
    "lng": "-92.46044"
  },
  {
    "country": "US",
    "name": "Coal Hill",
    "lat": "35.43731",
    "lng": "-93.67297"
  },
  {
    "country": "US",
    "name": "Conway",
    "lat": "35.0887",
    "lng": "-92.4421"
  },
  {
    "country": "US",
    "name": "Corning",
    "lat": "36.40784",
    "lng": "-90.57983"
  },
  {
    "country": "US",
    "name": "Crossett",
    "lat": "33.12818",
    "lng": "-91.96124"
  },
  {
    "country": "US",
    "name": "Danville",
    "lat": "35.05398",
    "lng": "-93.39352"
  },
  {
    "country": "US",
    "name": "Dardanelle",
    "lat": "35.22314",
    "lng": "-93.15795"
  },
  {
    "country": "US",
    "name": "De Queen",
    "lat": "34.03789",
    "lng": "-94.34132"
  },
  {
    "country": "US",
    "name": "De Witt",
    "lat": "34.29288",
    "lng": "-91.3379"
  },
  {
    "country": "US",
    "name": "Decatur",
    "lat": "36.33591",
    "lng": "-94.46077"
  },
  {
    "country": "US",
    "name": "Dermott",
    "lat": "33.52539",
    "lng": "-91.43595"
  },
  {
    "country": "US",
    "name": "Des Arc",
    "lat": "34.97704",
    "lng": "-91.49513"
  },
  {
    "country": "US",
    "name": "Diaz",
    "lat": "35.63841",
    "lng": "-91.26513"
  },
  {
    "country": "US",
    "name": "Dierks",
    "lat": "34.11928",
    "lng": "-94.01658"
  },
  {
    "country": "US",
    "name": "Dover",
    "lat": "35.40147",
    "lng": "-93.11434"
  },
  {
    "country": "US",
    "name": "Dumas",
    "lat": "33.88705",
    "lng": "-91.49179"
  },
  {
    "country": "US",
    "name": "Earle",
    "lat": "35.27509",
    "lng": "-90.46677"
  },
  {
    "country": "US",
    "name": "East End",
    "lat": "34.55065",
    "lng": "-92.34099"
  },
  {
    "country": "US",
    "name": "El Dorado",
    "lat": "33.20763",
    "lng": "-92.66627"
  },
  {
    "country": "US",
    "name": "Elkins",
    "lat": "36.00147",
    "lng": "-94.00825"
  },
  {
    "country": "US",
    "name": "Elm Springs",
    "lat": "36.20619",
    "lng": "-94.23437"
  },
  {
    "country": "US",
    "name": "England",
    "lat": "34.54426",
    "lng": "-91.96903"
  },
  {
    "country": "US",
    "name": "Eudora",
    "lat": "33.10957",
    "lng": "-91.26206"
  },
  {
    "country": "US",
    "name": "Eureka Springs",
    "lat": "36.40118",
    "lng": "-93.73797"
  },
  {
    "country": "US",
    "name": "Fairfield Bay",
    "lat": "35.59424",
    "lng": "-92.27793"
  },
  {
    "country": "US",
    "name": "Farmington",
    "lat": "36.04202",
    "lng": "-94.24715"
  },
  {
    "country": "US",
    "name": "Fayetteville",
    "lat": "36.06258",
    "lng": "-94.15743"
  },
  {
    "country": "US",
    "name": "Flippin",
    "lat": "36.27896",
    "lng": "-92.59711"
  },
  {
    "country": "US",
    "name": "Fordyce",
    "lat": "33.81372",
    "lng": "-92.41293"
  },
  {
    "country": "US",
    "name": "Forrest City",
    "lat": "35.00815",
    "lng": "-90.78983"
  },
  {
    "country": "US",
    "name": "Fort Smith",
    "lat": "35.38592",
    "lng": "-94.39855"
  },
  {
    "country": "US",
    "name": "Gassville",
    "lat": "36.28312",
    "lng": "-92.49405"
  },
  {
    "country": "US",
    "name": "Gentry",
    "lat": "36.26758",
    "lng": "-94.48466"
  },
  {
    "country": "US",
    "name": "Gibson",
    "lat": "34.88426",
    "lng": "-92.2357"
  },
  {
    "country": "US",
    "name": "Glenwood",
    "lat": "34.32677",
    "lng": "-93.55074"
  },
  {
    "country": "US",
    "name": "Gosnell",
    "lat": "35.95979",
    "lng": "-89.97203"
  },
  {
    "country": "US",
    "name": "Goshen",
    "lat": "36.10119",
    "lng": "-93.99131"
  },
  {
    "country": "US",
    "name": "Gravel Ridge",
    "lat": "34.86842",
    "lng": "-92.1907"
  },
  {
    "country": "US",
    "name": "Gravette",
    "lat": "36.42202",
    "lng": "-94.45355"
  },
  {
    "country": "US",
    "name": "Green Forest",
    "lat": "36.33535",
    "lng": "-93.43602"
  },
  {
    "country": "US",
    "name": "Greenbrier",
    "lat": "35.23397",
    "lng": "-92.38765"
  },
  {
    "country": "US",
    "name": "Greenland",
    "lat": "35.99425",
    "lng": "-94.1752"
  },
  {
    "country": "US",
    "name": "Greenwood",
    "lat": "35.21565",
    "lng": "-94.25577"
  },
  {
    "country": "US",
    "name": "Gurdon",
    "lat": "33.92094",
    "lng": "-93.15406"
  },
  {
    "country": "US",
    "name": "Hamburg",
    "lat": "33.22818",
    "lng": "-91.79763"
  },
  {
    "country": "US",
    "name": "Hampton",
    "lat": "33.53789",
    "lng": "-92.46988"
  },
  {
    "country": "US",
    "name": "Harrisburg",
    "lat": "35.56425",
    "lng": "-90.71678"
  },
  {
    "country": "US",
    "name": "Harrison",
    "lat": "36.22979",
    "lng": "-93.10768"
  },
  {
    "country": "US",
    "name": "Haskell",
    "lat": "34.50148",
    "lng": "-92.63655"
  },
  {
    "country": "US",
    "name": "Hazen",
    "lat": "34.78093",
    "lng": "-91.58097"
  },
  {
    "country": "US",
    "name": "Heber Springs",
    "lat": "35.49147",
    "lng": "-92.03126"
  },
  {
    "country": "US",
    "name": "Helena",
    "lat": "34.52955",
    "lng": "-90.59177"
  },
  {
    "country": "US",
    "name": "Highland",
    "lat": "36.2759",
    "lng": "-91.52403"
  },
  {
    "country": "US",
    "name": "Holiday Island",
    "lat": "36.48535",
    "lng": "-93.73214"
  },
  {
    "country": "US",
    "name": "Hope",
    "lat": "33.66706",
    "lng": "-93.59157"
  },
  {
    "country": "US",
    "name": "Horatio",
    "lat": "33.93845",
    "lng": "-94.35715"
  },
  {
    "country": "US",
    "name": "Horseshoe Bend",
    "lat": "36.22923",
    "lng": "-91.76431"
  },
  {
    "country": "US",
    "name": "Hot Springs",
    "lat": "34.5037",
    "lng": "-93.05518"
  },
  {
    "country": "US",
    "name": "Hot Springs Village",
    "lat": "34.67204",
    "lng": "-92.99879"
  },
  {
    "country": "US",
    "name": "Hoxie",
    "lat": "36.05035",
    "lng": "-90.97512"
  },
  {
    "country": "US",
    "name": "Hughes",
    "lat": "34.94926",
    "lng": "-90.47149"
  },
  {
    "country": "US",
    "name": "Huntsville",
    "lat": "36.08619",
    "lng": "-93.7413"
  },
  {
    "country": "US",
    "name": "Jacksonville",
    "lat": "34.8662",
    "lng": "-92.11015"
  },
  {
    "country": "US",
    "name": "Jasper",
    "lat": "36.00813",
    "lng": "-93.18657"
  },
  {
    "country": "US",
    "name": "Johnson",
    "lat": "36.13286",
    "lng": "-94.16548"
  },
  {
    "country": "US",
    "name": "Jonesboro",
    "lat": "35.8423",
    "lng": "-90.70428"
  },
  {
    "country": "US",
    "name": "Judsonia",
    "lat": "35.27009",
    "lng": "-91.63986"
  },
  {
    "country": "US",
    "name": "Kensett",
    "lat": "35.23175",
    "lng": "-91.66764"
  },
  {
    "country": "US",
    "name": "Lake City",
    "lat": "35.81619",
    "lng": "-90.43427"
  },
  {
    "country": "US",
    "name": "Lake Hamilton",
    "lat": "34.42453",
    "lng": "-93.09518"
  },
  {
    "country": "US",
    "name": "Lake Village",
    "lat": "33.32873",
    "lng": "-91.28178"
  },
  {
    "country": "US",
    "name": "Lamar",
    "lat": "35.44064",
    "lng": "-93.38796"
  },
  {
    "country": "US",
    "name": "Landmark",
    "lat": "34.6112",
    "lng": "-92.3196"
  },
  {
    "country": "US",
    "name": "Lavaca",
    "lat": "35.3362",
    "lng": "-94.17326"
  },
  {
    "country": "US",
    "name": "Leachville",
    "lat": "35.93591",
    "lng": "-90.25788"
  },
  {
    "country": "US",
    "name": "Lepanto",
    "lat": "35.61119",
    "lng": "-90.32982"
  },
  {
    "country": "US",
    "name": "Lewisville",
    "lat": "33.35846",
    "lng": "-93.57768"
  },
  {
    "country": "US",
    "name": "Lincoln",
    "lat": "35.94953",
    "lng": "-94.42355"
  },
  {
    "country": "US",
    "name": "Little Flock",
    "lat": "36.38591",
    "lng": "-94.1352"
  },
  {
    "country": "US",
    "name": "Little Rock",
    "lat": "34.74648",
    "lng": "-92.28959"
  },
  {
    "country": "US",
    "name": "London",
    "lat": "35.32897",
    "lng": "-93.25296"
  },
  {
    "country": "US",
    "name": "Lonoke",
    "lat": "34.78398",
    "lng": "-91.89986"
  },
  {
    "country": "US",
    "name": "Lowell",
    "lat": "36.25535",
    "lng": "-94.13076"
  },
  {
    "country": "US",
    "name": "Luxora",
    "lat": "35.75619",
    "lng": "-89.92814"
  },
  {
    "country": "US",
    "name": "Magnolia",
    "lat": "33.26707",
    "lng": "-93.23933"
  },
  {
    "country": "US",
    "name": "Malvern",
    "lat": "34.36231",
    "lng": "-92.81295"
  },
  {
    "country": "US",
    "name": "Manila",
    "lat": "35.88007",
    "lng": "-90.16704"
  },
  {
    "country": "US",
    "name": "Mansfield",
    "lat": "35.05954",
    "lng": "-94.25271"
  },
  {
    "country": "US",
    "name": "Marianna",
    "lat": "34.77371",
    "lng": "-90.75761"
  },
  {
    "country": "US",
    "name": "Marion",
    "lat": "35.21453",
    "lng": "-90.19648"
  },
  {
    "country": "US",
    "name": "Marked Tree",
    "lat": "35.53286",
    "lng": "-90.42066"
  },
  {
    "country": "US",
    "name": "Marmaduke",
    "lat": "36.18701",
    "lng": "-90.38316"
  },
  {
    "country": "US",
    "name": "Marshall",
    "lat": "35.90896",
    "lng": "-92.63127"
  },
  {
    "country": "US",
    "name": "Marvell",
    "lat": "34.55566",
    "lng": "-90.91289"
  },
  {
    "country": "US",
    "name": "Maumelle",
    "lat": "34.86676",
    "lng": "-92.40432"
  },
  {
    "country": "US",
    "name": "Mayflower",
    "lat": "34.95703",
    "lng": "-92.42738"
  },
  {
    "country": "US",
    "name": "McAlmont",
    "lat": "34.80842",
    "lng": "-92.18181"
  },
  {
    "country": "US",
    "name": "McCrory",
    "lat": "35.2562",
    "lng": "-91.20012"
  },
  {
    "country": "US",
    "name": "McGehee",
    "lat": "33.629",
    "lng": "-91.39956"
  },
  {
    "country": "US",
    "name": "Melbourne",
    "lat": "36.05951",
    "lng": "-91.90848"
  },
  {
    "country": "US",
    "name": "Mena",
    "lat": "34.58622",
    "lng": "-94.23966"
  },
  {
    "country": "US",
    "name": "Midway",
    "lat": "36.38534",
    "lng": "-92.46183"
  },
  {
    "country": "US",
    "name": "Mineral Springs",
    "lat": "33.87512",
    "lng": "-93.9138"
  },
  {
    "country": "US",
    "name": "Monette",
    "lat": "35.89063",
    "lng": "-90.34427"
  },
  {
    "country": "US",
    "name": "Monticello",
    "lat": "33.629",
    "lng": "-91.79096"
  },
  {
    "country": "US",
    "name": "Morrilton",
    "lat": "35.15092",
    "lng": "-92.74405"
  },
  {
    "country": "US",
    "name": "Mount Ida",
    "lat": "34.55676",
    "lng": "-93.63408"
  },
  {
    "country": "US",
    "name": "Mountain View",
    "lat": "35.86841",
    "lng": "-92.11765"
  },
  {
    "country": "US",
    "name": "Mountain Home",
    "lat": "36.33534",
    "lng": "-92.38516"
  },
  {
    "country": "US",
    "name": "Mulberry",
    "lat": "35.50064",
    "lng": "-94.05159"
  },
  {
    "country": "US",
    "name": "Murfreesboro",
    "lat": "34.06233",
    "lng": "-93.6899"
  },
  {
    "country": "US",
    "name": "Nashville",
    "lat": "33.94567",
    "lng": "-93.84713"
  },
  {
    "country": "US",
    "name": "Newark",
    "lat": "35.70174",
    "lng": "-91.44152"
  },
  {
    "country": "US",
    "name": "Newport",
    "lat": "35.6048",
    "lng": "-91.2818"
  },
  {
    "country": "US",
    "name": "North Crossett",
    "lat": "33.16568",
    "lng": "-91.94152"
  },
  {
    "country": "US",
    "name": "North Little Rock",
    "lat": "34.76954",
    "lng": "-92.26709"
  },
  {
    "country": "US",
    "name": "Ola",
    "lat": "35.03231",
    "lng": "-93.22323"
  },
  {
    "country": "US",
    "name": "Osceola",
    "lat": "35.70508",
    "lng": "-89.96953"
  },
  {
    "country": "US",
    "name": "Ozark",
    "lat": "35.48703",
    "lng": "-93.8277"
  },
  {
    "country": "US",
    "name": "Paragould",
    "lat": "36.0584",
    "lng": "-90.49733"
  },
  {
    "country": "US",
    "name": "Paris",
    "lat": "35.29203",
    "lng": "-93.72992"
  },
  {
    "country": "US",
    "name": "Parkin",
    "lat": "35.26342",
    "lng": "-90.57122"
  },
  {
    "country": "US",
    "name": "Pea Ridge",
    "lat": "33.92066",
    "lng": "-91.33679"
  },
  {
    "country": "US",
    "name": "Pea Ridge",
    "lat": "36.45396",
    "lng": "-94.1152"
  },
  {
    "country": "US",
    "name": "Perryville",
    "lat": "35.00481",
    "lng": "-92.80267"
  },
  {
    "country": "US",
    "name": "Piggott",
    "lat": "36.38284",
    "lng": "-90.19065"
  },
  {
    "country": "US",
    "name": "Pine Bluff",
    "lat": "34.22843",
    "lng": "-92.0032"
  },
  {
    "country": "US",
    "name": "Piney",
    "lat": "34.50314",
    "lng": "-93.12602"
  },
  {
    "country": "US",
    "name": "Pocahontas",
    "lat": "36.26146",
    "lng": "-90.97123"
  },
  {
    "country": "US",
    "name": "Pottsville",
    "lat": "35.24814",
    "lng": "-93.04906"
  },
  {
    "country": "US",
    "name": "Prairie Creek",
    "lat": "36.34202",
    "lng": "-94.06187"
  },
  {
    "country": "US",
    "name": "Prairie Grove",
    "lat": "35.97591",
    "lng": "-94.31771"
  },
  {
    "country": "US",
    "name": "Prescott",
    "lat": "33.80261",
    "lng": "-93.38101"
  },
  {
    "country": "US",
    "name": "Rector",
    "lat": "36.26312",
    "lng": "-90.2926"
  },
  {
    "country": "US",
    "name": "Redfield",
    "lat": "34.4451",
    "lng": "-92.1832"
  },
  {
    "country": "US",
    "name": "Rison",
    "lat": "33.95843",
    "lng": "-92.19015"
  },
  {
    "country": "US",
    "name": "Rockwell",
    "lat": "34.46426",
    "lng": "-93.13379"
  },
  {
    "country": "US",
    "name": "Rogers",
    "lat": "36.33202",
    "lng": "-94.11854"
  },
  {
    "country": "US",
    "name": "Russellville",
    "lat": "35.27842",
    "lng": "-93.13379"
  },
  {
    "country": "US",
    "name": "Salem",
    "lat": "36.37118",
    "lng": "-91.82265"
  },
  {
    "country": "US",
    "name": "Salem",
    "lat": "34.62898",
    "lng": "-92.55822"
  },
  {
    "country": "US",
    "name": "Searcy",
    "lat": "35.25064",
    "lng": "-91.73625"
  },
  {
    "country": "US",
    "name": "Shannon Hills",
    "lat": "34.62009",
    "lng": "-92.39543"
  },
  {
    "country": "US",
    "name": "Sheridan",
    "lat": "34.30704",
    "lng": "-92.40127"
  },
  {
    "country": "US",
    "name": "Siloam Springs",
    "lat": "36.18814",
    "lng": "-94.5405"
  },
  {
    "country": "US",
    "name": "Smackover",
    "lat": "33.36485",
    "lng": "-92.72488"
  },
  {
    "country": "US",
    "name": "Southside",
    "lat": "35.69841",
    "lng": "-91.62347"
  },
  {
    "country": "US",
    "name": "Springdale",
    "lat": "36.18674",
    "lng": "-94.12881"
  },
  {
    "country": "US",
    "name": "Stamps",
    "lat": "33.3654",
    "lng": "-93.49518"
  },
  {
    "country": "US",
    "name": "Star City",
    "lat": "33.94288",
    "lng": "-91.84347"
  },
  {
    "country": "US",
    "name": "Stuttgart",
    "lat": "34.50037",
    "lng": "-91.55263"
  },
  {
    "country": "US",
    "name": "Sulphur Springs",
    "lat": "34.18065",
    "lng": "-92.12348"
  },
  {
    "country": "US",
    "name": "Texarkana",
    "lat": "33.44179",
    "lng": "-94.03769"
  },
  {
    "country": "US",
    "name": "Tontitown",
    "lat": "36.17786",
    "lng": "-94.23354"
  },
  {
    "country": "US",
    "name": "Trumann",
    "lat": "35.67369",
    "lng": "-90.50733"
  },
  {
    "country": "US",
    "name": "Tuckerman",
    "lat": "35.73063",
    "lng": "-91.19846"
  },
  {
    "country": "US",
    "name": "Van Buren",
    "lat": "35.43676",
    "lng": "-94.34827"
  },
  {
    "country": "US",
    "name": "Vilonia",
    "lat": "35.08398",
    "lng": "-92.20793"
  },
  {
    "country": "US",
    "name": "Waldo",
    "lat": "33.35151",
    "lng": "-93.29573"
  },
  {
    "country": "US",
    "name": "Waldron",
    "lat": "34.89843",
    "lng": "-94.09076"
  },
  {
    "country": "US",
    "name": "Walnut Ridge",
    "lat": "36.0684",
    "lng": "-90.95595"
  },
  {
    "country": "US",
    "name": "Ward",
    "lat": "35.03036",
    "lng": "-91.95042"
  },
  {
    "country": "US",
    "name": "Warren",
    "lat": "33.61261",
    "lng": "-92.06458"
  },
  {
    "country": "US",
    "name": "West Crossett",
    "lat": "33.14096",
    "lng": "-91.99402"
  },
  {
    "country": "US",
    "name": "West Fork",
    "lat": "35.92425",
    "lng": "-94.18854"
  },
  {
    "country": "US",
    "name": "West Helena",
    "lat": "34.55066",
    "lng": "-90.64177"
  },
  {
    "country": "US",
    "name": "West Memphis",
    "lat": "35.14648",
    "lng": "-90.18454"
  },
  {
    "country": "US",
    "name": "White Hall",
    "lat": "34.27399",
    "lng": "-92.09098"
  },
  {
    "country": "US",
    "name": "Wrightsville",
    "lat": "34.60232",
    "lng": "-92.21681"
  },
  {
    "country": "US",
    "name": "Wynne",
    "lat": "35.22453",
    "lng": "-90.78678"
  },
  {
    "country": "US",
    "name": "Yellville",
    "lat": "36.22618",
    "lng": "-92.68489"
  },
  {
    "country": "US",
    "name": "Chevy Chase",
    "lat": "38.964",
    "lng": "-77.06776"
  },
  {
    "country": "US",
    "name": "Washington, D.C.",
    "lat": "38.89511",
    "lng": "-77.03637"
  },
  {
    "country": "US",
    "name": "Bear",
    "lat": "39.62928",
    "lng": "-75.65826"
  },
  {
    "country": "US",
    "name": "Bellefonte",
    "lat": "39.76622",
    "lng": "-75.50936"
  },
  {
    "country": "US",
    "name": "Bethany Beach",
    "lat": "38.53956",
    "lng": "-75.05518"
  },
  {
    "country": "US",
    "name": "Blades",
    "lat": "38.63567",
    "lng": "-75.60993"
  },
  {
    "country": "US",
    "name": "Bridgeville",
    "lat": "38.74261",
    "lng": "-75.60437"
  },
  {
    "country": "US",
    "name": "Brookside",
    "lat": "39.66706",
    "lng": "-75.72688"
  },
  {
    "country": "US",
    "name": "Camden",
    "lat": "39.11345",
    "lng": "-75.54187"
  },
  {
    "country": "US",
    "name": "Cheswold",
    "lat": "39.21928",
    "lng": "-75.58576"
  },
  {
    "country": "US",
    "name": "Claymont",
    "lat": "39.80067",
    "lng": "-75.45964"
  },
  {
    "country": "US",
    "name": "Clayton",
    "lat": "39.29067",
    "lng": "-75.63437"
  },
  {
    "country": "US",
    "name": "Delaware City",
    "lat": "39.57789",
    "lng": "-75.58881"
  },
  {
    "country": "US",
    "name": "Delmar",
    "lat": "38.45651",
    "lng": "-75.57715"
  },
  {
    "country": "US",
    "name": "Dover",
    "lat": "39.15817",
    "lng": "-75.52437"
  },
  {
    "country": "US",
    "name": "Edgemoor",
    "lat": "39.75011",
    "lng": "-75.49964"
  },
  {
    "country": "US",
    "name": "Elsmere",
    "lat": "39.73928",
    "lng": "-75.59798"
  },
  {
    "country": "US",
    "name": "Felton",
    "lat": "39.00845",
    "lng": "-75.57798"
  },
  {
    "country": "US",
    "name": "Georgetown",
    "lat": "38.69011",
    "lng": "-75.38547"
  },
  {
    "country": "US",
    "name": "Glasgow",
    "lat": "39.60483",
    "lng": "-75.74521"
  },
  {
    "country": "US",
    "name": "Greenville",
    "lat": "39.779",
    "lng": "-75.59826"
  },
  {
    "country": "US",
    "name": "Greenwood",
    "lat": "38.80706",
    "lng": "-75.59132"
  },
  {
    "country": "US",
    "name": "Harrington",
    "lat": "38.92372",
    "lng": "-75.5777"
  },
  {
    "country": "US",
    "name": "Highland Acres",
    "lat": "39.12095",
    "lng": "-75.52187"
  },
  {
    "country": "US",
    "name": "Hockessin",
    "lat": "39.78761",
    "lng": "-75.6966"
  },
  {
    "country": "US",
    "name": "Kent Acres",
    "lat": "39.13178",
    "lng": "-75.52492"
  },
  {
    "country": "US",
    "name": "Laurel",
    "lat": "38.5565",
    "lng": "-75.57131"
  },
  {
    "country": "US",
    "name": "Lewes",
    "lat": "38.77456",
    "lng": "-75.13935"
  },
  {
    "country": "US",
    "name": "Long Neck",
    "lat": "38.62011",
    "lng": "-75.15074"
  },
  {
    "country": "US",
    "name": "Middletown",
    "lat": "39.44956",
    "lng": "-75.71632"
  },
  {
    "country": "US",
    "name": "Milford",
    "lat": "38.91261",
    "lng": "-75.42797"
  },
  {
    "country": "US",
    "name": "Millsboro",
    "lat": "38.5915",
    "lng": "-75.2913"
  },
  {
    "country": "US",
    "name": "Milton",
    "lat": "38.77761",
    "lng": "-75.30991"
  },
  {
    "country": "US",
    "name": "New Castle",
    "lat": "39.66206",
    "lng": "-75.56631"
  },
  {
    "country": "US",
    "name": "Newark",
    "lat": "39.68372",
    "lng": "-75.74966"
  },
  {
    "country": "US",
    "name": "Newport",
    "lat": "39.71372",
    "lng": "-75.60937"
  },
  {
    "country": "US",
    "name": "North Star",
    "lat": "39.76122",
    "lng": "-75.7191"
  },
  {
    "country": "US",
    "name": "Pike Creek",
    "lat": "39.73095",
    "lng": "-75.7041"
  },
  {
    "country": "US",
    "name": "Pike Creek Valley",
    "lat": "39.73622",
    "lng": "-75.69827"
  },
  {
    "country": "US",
    "name": "Rehoboth Beach",
    "lat": "38.72095",
    "lng": "-75.07601"
  },
  {
    "country": "US",
    "name": "Riverview",
    "lat": "39.0265",
    "lng": "-75.51076"
  },
  {
    "country": "US",
    "name": "Rodney Village",
    "lat": "39.13206",
    "lng": "-75.53242"
  },
  {
    "country": "US",
    "name": "Seaford",
    "lat": "38.64123",
    "lng": "-75.61104"
  },
  {
    "country": "US",
    "name": "Selbyville",
    "lat": "38.46039",
    "lng": "-75.22074"
  },
  {
    "country": "US",
    "name": "Smyrna",
    "lat": "39.29983",
    "lng": "-75.60465"
  },
  {
    "country": "US",
    "name": "Townsend",
    "lat": "39.39511",
    "lng": "-75.6916"
  },
  {
    "country": "US",
    "name": "Wilmington",
    "lat": "39.74595",
    "lng": "-75.54659"
  },
  {
    "country": "US",
    "name": "Wilmington Manor",
    "lat": "39.68678",
    "lng": "-75.58437"
  },
  {
    "country": "US",
    "name": "Wyoming",
    "lat": "39.11817",
    "lng": "-75.55881"
  },
  {
    "country": "US",
    "name": "Alachua",
    "lat": "29.75163",
    "lng": "-82.42483"
  },
  {
    "country": "US",
    "name": "Allapattah",
    "lat": "25.81454",
    "lng": "-80.22394"
  },
  {
    "country": "US",
    "name": "Altamonte Springs",
    "lat": "28.66111",
    "lng": "-81.36562"
  },
  {
    "country": "US",
    "name": "Alturas",
    "lat": "27.87169",
    "lng": "-81.71508"
  },
  {
    "country": "US",
    "name": "Alva",
    "lat": "26.71562",
    "lng": "-81.61008"
  },
  {
    "country": "US",
    "name": "Andover",
    "lat": "25.96843",
    "lng": "-80.21283"
  },
  {
    "country": "US",
    "name": "Anna Maria",
    "lat": "27.53115",
    "lng": "-82.73343"
  },
  {
    "country": "US",
    "name": "Apalachicola",
    "lat": "29.726",
    "lng": "-84.9856"
  },
  {
    "country": "US",
    "name": "Apollo Beach",
    "lat": "27.77308",
    "lng": "-82.40759"
  },
  {
    "country": "US",
    "name": "Apopka",
    "lat": "28.67617",
    "lng": "-81.51186"
  },
  {
    "country": "US",
    "name": "Arcadia",
    "lat": "27.21588",
    "lng": "-81.85842"
  },
  {
    "country": "US",
    "name": "Archer",
    "lat": "29.52997",
    "lng": "-82.519"
  },
  {
    "country": "US",
    "name": "Asbury Lake",
    "lat": "30.04913",
    "lng": "-81.82149"
  },
  {
    "country": "US",
    "name": "Astatula",
    "lat": "28.70972",
    "lng": "-81.73285"
  },
  {
    "country": "US",
    "name": "Astor",
    "lat": "29.16248",
    "lng": "-81.52535"
  },
  {
    "country": "US",
    "name": "Atlantic Beach",
    "lat": "30.33441",
    "lng": "-81.3987"
  },
  {
    "country": "US",
    "name": "Atlantis",
    "lat": "26.5909",
    "lng": "-80.10088"
  },
  {
    "country": "US",
    "name": "Auburndale",
    "lat": "28.0653",
    "lng": "-81.78869"
  },
  {
    "country": "US",
    "name": "Aventura",
    "lat": "25.95648",
    "lng": "-80.13921"
  },
  {
    "country": "US",
    "name": "Avon Park",
    "lat": "27.59587",
    "lng": "-81.50619"
  },
  {
    "country": "US",
    "name": "Azalea Park",
    "lat": "28.54111",
    "lng": "-81.30062"
  },
  {
    "country": "US",
    "name": "Babson Park",
    "lat": "27.83197",
    "lng": "-81.5223"
  },
  {
    "country": "US",
    "name": "Bagdad",
    "lat": "30.5988",
    "lng": "-87.03223"
  },
  {
    "country": "US",
    "name": "Bal Harbour",
    "lat": "25.89176",
    "lng": "-80.12699"
  },
  {
    "country": "US",
    "name": "Baldwin",
    "lat": "30.30274",
    "lng": "-81.97539"
  },
  {
    "country": "US",
    "name": "Balm",
    "lat": "27.75947",
    "lng": "-82.2612"
  },
  {
    "country": "US",
    "name": "Bartow",
    "lat": "27.89641",
    "lng": "-81.84314"
  },
  {
    "country": "US",
    "name": "Bay Harbor Islands",
    "lat": "25.88759",
    "lng": "-80.13116"
  },
  {
    "country": "US",
    "name": "Bay Hill",
    "lat": "28.46806",
    "lng": "-81.51618"
  },
  {
    "country": "US",
    "name": "Bay Pines",
    "lat": "27.81419",
    "lng": "-82.77816"
  },
  {
    "country": "US",
    "name": "Bayonet Point",
    "lat": "28.32667",
    "lng": "-82.68343"
  },
  {
    "country": "US",
    "name": "Bayshore Gardens",
    "lat": "27.42532",
    "lng": "-82.59038"
  },
  {
    "country": "US",
    "name": "Beacon Square",
    "lat": "28.20862",
    "lng": "-82.75538"
  },
  {
    "country": "US",
    "name": "Bee Ridge",
    "lat": "27.28394",
    "lng": "-82.48065"
  },
  {
    "country": "US",
    "name": "Belle Glade",
    "lat": "26.68451",
    "lng": "-80.66756"
  },
  {
    "country": "US",
    "name": "Belle Glade Camp",
    "lat": "26.65757",
    "lng": "-80.68284"
  },
  {
    "country": "US",
    "name": "Belle Isle",
    "lat": "28.45834",
    "lng": "-81.35924"
  },
  {
    "country": "US",
    "name": "Belleair",
    "lat": "27.93585",
    "lng": "-82.80621"
  },
  {
    "country": "US",
    "name": "Belleair Beach",
    "lat": "27.92308",
    "lng": "-82.84316"
  },
  {
    "country": "US",
    "name": "Belleair Bluffs",
    "lat": "27.92141",
    "lng": "-82.81705"
  },
  {
    "country": "US",
    "name": "Belleview",
    "lat": "29.05526",
    "lng": "-82.06231"
  },
  {
    "country": "US",
    "name": "Bellview",
    "lat": "30.46159",
    "lng": "-87.31497"
  },
  {
    "country": "US",
    "name": "Beverly Hills",
    "lat": "28.91692",
    "lng": "-82.45815"
  },
  {
    "country": "US",
    "name": "Big Coppitt Key",
    "lat": "24.59653",
    "lng": "-81.66009"
  },
  {
    "country": "US",
    "name": "Big Pine Key",
    "lat": "24.66987",
    "lng": "-81.35397"
  },
  {
    "country": "US",
    "name": "Biscayne Park",
    "lat": "25.8826",
    "lng": "-80.1806"
  },
  {
    "country": "US",
    "name": "Bithlo",
    "lat": "28.55472",
    "lng": "-81.10645"
  },
  {
    "country": "US",
    "name": "Black Diamond",
    "lat": "28.91248",
    "lng": "-82.48593"
  },
  {
    "country": "US",
    "name": "Bloomingdale",
    "lat": "27.89364",
    "lng": "-82.24037"
  },
  {
    "country": "US",
    "name": "Blountstown",
    "lat": "30.44379",
    "lng": "-85.04744"
  },
  {
    "country": "US",
    "name": "Boca Del Mar",
    "lat": "26.34508",
    "lng": "-80.14671"
  },
  {
    "country": "US",
    "name": "Boca Pointe",
    "lat": "26.33313",
    "lng": "-80.15949"
  },
  {
    "country": "US",
    "name": "Boca Raton",
    "lat": "26.35869",
    "lng": "-80.0831"
  },
  {
    "country": "US",
    "name": "Bokeelia",
    "lat": "26.70563",
    "lng": "-82.15898"
  },
  {
    "country": "US",
    "name": "Bonifay",
    "lat": "30.79186",
    "lng": "-85.67965"
  },
  {
    "country": "US",
    "name": "Bonita Springs",
    "lat": "26.33981",
    "lng": "-81.7787"
  },
  {
    "country": "US",
    "name": "Bowling Green",
    "lat": "27.63837",
    "lng": "-81.82397"
  },
  {
    "country": "US",
    "name": "Boyette",
    "lat": "27.81753",
    "lng": "-82.22259"
  },
  {
    "country": "US",
    "name": "Boynton Beach",
    "lat": "26.52535",
    "lng": "-80.06643"
  },
  {
    "country": "US",
    "name": "Bradenton",
    "lat": "27.49893",
    "lng": "-82.57482"
  },
  {
    "country": "US",
    "name": "Bradenton Beach",
    "lat": "27.46698",
    "lng": "-82.70399"
  },
  {
    "country": "US",
    "name": "Brandon",
    "lat": "27.9378",
    "lng": "-82.28592"
  },
  {
    "country": "US",
    "name": "Brent",
    "lat": "30.46881",
    "lng": "-87.23608"
  },
  {
    "country": "US",
    "name": "Bristol",
    "lat": "30.43247",
    "lng": "-84.97702"
  },
  {
    "country": "US",
    "name": "Broadview Park",
    "lat": "26.09953",
    "lng": "-80.20866"
  },
  {
    "country": "US",
    "name": "Bronson",
    "lat": "29.44774",
    "lng": "-82.64233"
  },
  {
    "country": "US",
    "name": "Brookridge",
    "lat": "28.5511",
    "lng": "-82.49204"
  },
  {
    "country": "US",
    "name": "Brooksville",
    "lat": "28.55554",
    "lng": "-82.38991"
  },
  {
    "country": "US",
    "name": "Broward Estates",
    "lat": "26.12564",
    "lng": "-80.19338"
  },
  {
    "country": "US",
    "name": "Brownsville",
    "lat": "25.82176",
    "lng": "-80.24116"
  },
  {
    "country": "US",
    "name": "Buckhead Ridge",
    "lat": "27.13033",
    "lng": "-80.89367"
  },
  {
    "country": "US",
    "name": "Buckingham",
    "lat": "26.67507",
    "lng": "-81.73203"
  },
  {
    "country": "US",
    "name": "Buenaventura Lakes",
    "lat": "28.33584",
    "lng": "-81.35313"
  },
  {
    "country": "US",
    "name": "Bunche Park",
    "lat": "25.92065",
    "lng": "-80.23699"
  },
  {
    "country": "US",
    "name": "Bunnell",
    "lat": "29.46609",
    "lng": "-81.25784"
  },
  {
    "country": "US",
    "name": "Burnt Store Marina",
    "lat": "26.76507",
    "lng": "-82.05092"
  },
  {
    "country": "US",
    "name": "Bushnell",
    "lat": "28.66499",
    "lng": "-82.11286"
  },
  {
    "country": "US",
    "name": "Butler Beach",
    "lat": "29.7983",
    "lng": "-81.26701"
  },
  {
    "country": "US",
    "name": "Callahan",
    "lat": "30.56218",
    "lng": "-81.83066"
  },
  {
    "country": "US",
    "name": "Callaway",
    "lat": "30.15298",
    "lng": "-85.56993"
  },
  {
    "country": "US",
    "name": "Campbell",
    "lat": "28.2589",
    "lng": "-81.45646"
  },
  {
    "country": "US",
    "name": "Cantonment",
    "lat": "30.60853",
    "lng": "-87.33998"
  },
  {
    "country": "US",
    "name": "Cape Canaveral",
    "lat": "28.40584",
    "lng": "-80.60477"
  },
  {
    "country": "US",
    "name": "Cape Coral",
    "lat": "26.56285",
    "lng": "-81.94953"
  },
  {
    "country": "US",
    "name": "Carol City",
    "lat": "25.94065",
    "lng": "-80.2456"
  },
  {
    "country": "US",
    "name": "Carrabelle",
    "lat": "29.85326",
    "lng": "-84.66435"
  },
  {
    "country": "US",
    "name": "Carrollwood",
    "lat": "28.05002",
    "lng": "-82.49287"
  },
  {
    "country": "US",
    "name": "Carrollwood Village",
    "lat": "28.06752",
    "lng": "-82.52093"
  },
  {
    "country": "US",
    "name": "Carver Ranches",
    "lat": "25.98842",
    "lng": "-80.19227"
  },
  {
    "country": "US",
    "name": "Casselberry",
    "lat": "28.67778",
    "lng": "-81.32785"
  },
  {
    "country": "US",
    "name": "Cedar Grove",
    "lat": "30.17103",
    "lng": "-85.6252"
  },
  {
    "country": "US",
    "name": "Celebration",
    "lat": "28.32529",
    "lng": "-81.53313"
  },
  {
    "country": "US",
    "name": "Center Hill",
    "lat": "28.64999",
    "lng": "-81.99258"
  },
  {
    "country": "US",
    "name": "Century",
    "lat": "30.97324",
    "lng": "-87.26386"
  },
  {
    "country": "US",
    "name": "Charlotte Harbor",
    "lat": "26.95839",
    "lng": "-82.06703"
  },
  {
    "country": "US",
    "name": "Charlotte Park",
    "lat": "26.91006",
    "lng": "-82.05398"
  },
  {
    "country": "US",
    "name": "Chattahoochee",
    "lat": "30.70546",
    "lng": "-84.84574"
  },
  {
    "country": "US",
    "name": "Cheval",
    "lat": "28.14862",
    "lng": "-82.51454"
  },
  {
    "country": "US",
    "name": "Chiefland",
    "lat": "29.47496",
    "lng": "-82.85984"
  },
  {
    "country": "US",
    "name": "Chipley",
    "lat": "30.78186",
    "lng": "-85.53854"
  },
  {
    "country": "US",
    "name": "Christmas",
    "lat": "28.53639",
    "lng": "-81.01756"
  },
  {
    "country": "US",
    "name": "Chuluota",
    "lat": "28.64194",
    "lng": "-81.1234"
  },
  {
    "country": "US",
    "name": "Citra",
    "lat": "29.41192",
    "lng": "-82.10982"
  },
  {
    "country": "US",
    "name": "Citrus Hills",
    "lat": "28.88831",
    "lng": "-82.4326"
  },
  {
    "country": "US",
    "name": "Citrus Park",
    "lat": "28.07835",
    "lng": "-82.56982"
  },
  {
    "country": "US",
    "name": "Citrus Ridge",
    "lat": "28.33385",
    "lng": "-81.64232"
  },
  {
    "country": "US",
    "name": "Citrus Springs",
    "lat": "28.99748",
    "lng": "-82.47065"
  },
  {
    "country": "US",
    "name": "Clarcona",
    "lat": "28.61278",
    "lng": "-81.49868"
  },
  {
    "country": "US",
    "name": "Clearwater",
    "lat": "27.96585",
    "lng": "-82.8001"
  },
  {
    "country": "US",
    "name": "Clermont",
    "lat": "28.54944",
    "lng": "-81.77285"
  },
  {
    "country": "US",
    "name": "Clewiston",
    "lat": "26.75423",
    "lng": "-80.93368"
  },
  {
    "country": "US",
    "name": "Cleveland",
    "lat": "26.96173",
    "lng": "-81.98398"
  },
  {
    "country": "US",
    "name": "Cocoa",
    "lat": "28.38612",
    "lng": "-80.742"
  },
  {
    "country": "US",
    "name": "Cocoa Beach",
    "lat": "28.32055",
    "lng": "-80.60922"
  },
  {
    "country": "US",
    "name": "Coconut Creek",
    "lat": "26.25175",
    "lng": "-80.17894"
  },
  {
    "country": "US",
    "name": "Coconut Grove",
    "lat": "25.7126",
    "lng": "-80.25699"
  },
  {
    "country": "US",
    "name": "Combee Settlement",
    "lat": "28.05835",
    "lng": "-81.90536"
  },
  {
    "country": "US",
    "name": "Conway",
    "lat": "28.50278",
    "lng": "-81.33062"
  },
  {
    "country": "US",
    "name": "Cooper City",
    "lat": "26.05731",
    "lng": "-80.27172"
  },
  {
    "country": "US",
    "name": "Coral Gables",
    "lat": "25.72149",
    "lng": "-80.26838"
  },
  {
    "country": "US",
    "name": "Coral Springs",
    "lat": "26.27119",
    "lng": "-80.2706"
  },
  {
    "country": "US",
    "name": "Coral Terrace",
    "lat": "25.74593",
    "lng": "-80.3045"
  },
  {
    "country": "US",
    "name": "Cortez",
    "lat": "27.46921",
    "lng": "-82.68621"
  },
  {
    "country": "US",
    "name": "Country Walk",
    "lat": "25.63399",
    "lng": "-80.43228"
  },
  {
    "country": "US",
    "name": "Country Club",
    "lat": "25.94815",
    "lng": "-80.317"
  },
  {
    "country": "US",
    "name": "Crawfordville",
    "lat": "30.17604",
    "lng": "-84.37518"
  },
  {
    "country": "US",
    "name": "Crescent City",
    "lat": "29.43025",
    "lng": "-81.51063"
  },
  {
    "country": "US",
    "name": "Crestview",
    "lat": "30.76213",
    "lng": "-86.57051"
  },
  {
    "country": "US",
    "name": "Crooked Lake Park",
    "lat": "27.82919",
    "lng": "-81.58397"
  },
  {
    "country": "US",
    "name": "Cross City",
    "lat": "29.63465",
    "lng": "-83.12694"
  },
  {
    "country": "US",
    "name": "Crystal Lake",
    "lat": "28.03558",
    "lng": "-81.90841"
  },
  {
    "country": "US",
    "name": "Crystal River",
    "lat": "28.90248",
    "lng": "-82.5926"
  },
  {
    "country": "US",
    "name": "Crystal Springs",
    "lat": "28.1814",
    "lng": "-82.15758"
  },
  {
    "country": "US",
    "name": "Cudjoe Key",
    "lat": "24.67153",
    "lng": "-81.49842"
  },
  {
    "country": "US",
    "name": "Cutler",
    "lat": "25.6151",
    "lng": "-80.31061"
  },
  {
    "country": "US",
    "name": "Cutler Ridge",
    "lat": "25.58066",
    "lng": "-80.34672"
  },
  {
    "country": "US",
    "name": "Cypress Gardens",
    "lat": "27.99391",
    "lng": "-81.69008"
  },
  {
    "country": "US",
    "name": "Cypress Lake",
    "lat": "26.53813",
    "lng": "-81.89925"
  },
  {
    "country": "US",
    "name": "Cypress Quarters",
    "lat": "27.25199",
    "lng": "-80.81395"
  },
  {
    "country": "US",
    "name": "Dade City",
    "lat": "28.36472",
    "lng": "-82.19592"
  },
  {
    "country": "US",
    "name": "Dania Beach",
    "lat": "26.05231",
    "lng": "-80.14393"
  },
  {
    "country": "US",
    "name": "Davenport",
    "lat": "28.1614",
    "lng": "-81.60174"
  },
  {
    "country": "US",
    "name": "Davie",
    "lat": "26.06287",
    "lng": "-80.2331"
  },
  {
    "country": "US",
    "name": "Daytona Beach",
    "lat": "29.21081",
    "lng": "-81.02283"
  },
  {
    "country": "US",
    "name": "Daytona Beach Shores",
    "lat": "29.17609",
    "lng": "-80.98283"
  },
  {
    "country": "US",
    "name": "DeFuniak Springs",
    "lat": "30.72102",
    "lng": "-86.11522"
  },
  {
    "country": "US",
    "name": "DeLand",
    "lat": "29.02832",
    "lng": "-81.30312"
  },
  {
    "country": "US",
    "name": "De Leon Springs",
    "lat": "29.11989",
    "lng": "-81.35286"
  },
  {
    "country": "US",
    "name": "DeBary",
    "lat": "28.88305",
    "lng": "-81.30868"
  },
  {
    "country": "US",
    "name": "Deerfield Beach",
    "lat": "26.31841",
    "lng": "-80.09977"
  },
  {
    "country": "US",
    "name": "Delray Beach",
    "lat": "26.46146",
    "lng": "-80.07282"
  },
  {
    "country": "US",
    "name": "Deltona",
    "lat": "28.90054",
    "lng": "-81.26367"
  },
  {
    "country": "US",
    "name": "Desoto Lakes",
    "lat": "27.37143",
    "lng": "-82.48982"
  },
  {
    "country": "US",
    "name": "Destin",
    "lat": "30.39353",
    "lng": "-86.49578"
  },
  {
    "country": "US",
    "name": "Doctor Phillips",
    "lat": "28.44945",
    "lng": "-81.49229"
  },
  {
    "country": "US",
    "name": "Doral",
    "lat": "25.81954",
    "lng": "-80.35533"
  },
  {
    "country": "US",
    "name": "Dover",
    "lat": "27.99419",
    "lng": "-82.21953"
  },
  {
    "country": "US",
    "name": "Dundee",
    "lat": "28.02252",
    "lng": "-81.61924"
  },
  {
    "country": "US",
    "name": "Dunedin",
    "lat": "28.0199",
    "lng": "-82.77323"
  },
  {
    "country": "US",
    "name": "Dunnellon",
    "lat": "29.04914",
    "lng": "-82.46093"
  },
  {
    "country": "US",
    "name": "Eagle Lake",
    "lat": "27.97836",
    "lng": "-81.75647"
  },
  {
    "country": "US",
    "name": "East Lake",
    "lat": "28.11085",
    "lng": "-82.69482"
  },
  {
    "country": "US",
    "name": "East Milton",
    "lat": "30.61519",
    "lng": "-87.02163"
  },
  {
    "country": "US",
    "name": "East Palatka",
    "lat": "29.6583",
    "lng": "-81.59841"
  },
  {
    "country": "US",
    "name": "East Pensacola Heights",
    "lat": "30.42881",
    "lng": "-87.17997"
  },
  {
    "country": "US",
    "name": "East Perrine",
    "lat": "25.60872",
    "lng": "-80.33894"
  },
  {
    "country": "US",
    "name": "Eastpoint",
    "lat": "29.7366",
    "lng": "-84.87852"
  },
  {
    "country": "US",
    "name": "Eatonville",
    "lat": "28.61472",
    "lng": "-81.38062"
  },
  {
    "country": "US",
    "name": "Edgewater",
    "lat": "28.98888",
    "lng": "-80.90228"
  },
  {
    "country": "US",
    "name": "Edgewood",
    "lat": "28.48612",
    "lng": "-81.37229"
  },
  {
    "country": "US",
    "name": "Eglin Village",
    "lat": "30.46298",
    "lng": "-86.5394"
  },
  {
    "country": "US",
    "name": "Egypt Lake-Leto",
    "lat": "28.01769",
    "lng": "-82.50619"
  },
  {
    "country": "US",
    "name": "El Portal",
    "lat": "25.85537",
    "lng": "-80.1931"
  },
  {
    "country": "US",
    "name": "Elfers",
    "lat": "28.21668",
    "lng": "-82.72232"
  },
  {
    "country": "US",
    "name": "Ellenton",
    "lat": "27.52171",
    "lng": "-82.5276"
  },
  {
    "country": "US",
    "name": "Englewood",
    "lat": "26.96201",
    "lng": "-82.3526"
  },
  {
    "country": "US",
    "name": "Ensley",
    "lat": "30.51881",
    "lng": "-87.27275"
  },
  {
    "country": "US",
    "name": "Estero",
    "lat": "26.43814",
    "lng": "-81.80675"
  },
  {
    "country": "US",
    "name": "Eustis",
    "lat": "28.85277",
    "lng": "-81.68535"
  },
  {
    "country": "US",
    "name": "Fairview Shores",
    "lat": "28.59111",
    "lng": "-81.39424"
  },
  {
    "country": "US",
    "name": "Feather Sound",
    "lat": "27.90079",
    "lng": "-82.67349"
  },
  {
    "country": "US",
    "name": "Fellsmere",
    "lat": "27.76781",
    "lng": "-80.60144"
  },
  {
    "country": "US",
    "name": "Fern Park",
    "lat": "28.64916",
    "lng": "-81.35118"
  },
  {
    "country": "US",
    "name": "Fernandina Beach",
    "lat": "30.66968",
    "lng": "-81.46259"
  },
  {
    "country": "US",
    "name": "Ferry Pass",
    "lat": "30.5102",
    "lng": "-87.21247"
  },
  {
    "country": "US",
    "name": "Fish Hawk",
    "lat": "27.85058",
    "lng": "-82.21092"
  },
  {
    "country": "US",
    "name": "Five Points",
    "lat": "30.20912",
    "lng": "-82.63735"
  },
  {
    "country": "US",
    "name": "Flagami",
    "lat": "25.76232",
    "lng": "-80.31616"
  },
  {
    "country": "US",
    "name": "Flagler Beach",
    "lat": "29.47498",
    "lng": "-81.127"
  },
  {
    "country": "US",
    "name": "Fleming Island",
    "lat": "30.0933",
    "lng": "-81.71898"
  },
  {
    "country": "US",
    "name": "Floral City",
    "lat": "28.74999",
    "lng": "-82.29676"
  },
  {
    "country": "US",
    "name": "Florida City",
    "lat": "25.44789",
    "lng": "-80.47922"
  },
  {
    "country": "US",
    "name": "Florida Ridge",
    "lat": "27.58031",
    "lng": "-80.38672"
  },
  {
    "country": "US",
    "name": "Forest City",
    "lat": "28.66678",
    "lng": "-81.44334"
  },
  {
    "country": "US",
    "name": "Fort Lauderdale",
    "lat": "26.12231",
    "lng": "-80.14338"
  },
  {
    "country": "US",
    "name": "Fort Meade",
    "lat": "27.75225",
    "lng": "-81.80175"
  },
  {
    "country": "US",
    "name": "Fort Myers",
    "lat": "26.62168",
    "lng": "-81.84059"
  },
  {
    "country": "US",
    "name": "Fort Myers Beach",
    "lat": "26.45271",
    "lng": "-81.95011"
  },
  {
    "country": "US",
    "name": "Fort Myers Shores",
    "lat": "26.70924",
    "lng": "-81.74592"
  },
  {
    "country": "US",
    "name": "Fort Pierce",
    "lat": "27.44671",
    "lng": "-80.32561"
  },
  {
    "country": "US",
    "name": "Fort Walton Beach",
    "lat": "30.42059",
    "lng": "-86.61707"
  },
  {
    "country": "US",
    "name": "Fountainebleau",
    "lat": "25.77288",
    "lng": "-80.34783"
  },
  {
    "country": "US",
    "name": "Freeport",
    "lat": "30.49825",
    "lng": "-86.13605"
  },
  {
    "country": "US",
    "name": "Frostproof",
    "lat": "27.74586",
    "lng": "-81.53063"
  },
  {
    "country": "US",
    "name": "Fruit Cove",
    "lat": "30.11107",
    "lng": "-81.64176"
  },
  {
    "country": "US",
    "name": "Fruitland Park",
    "lat": "28.86138",
    "lng": "-81.90647"
  },
  {
    "country": "US",
    "name": "Fruitville",
    "lat": "27.32977",
    "lng": "-82.4576"
  },
  {
    "country": "US",
    "name": "Fuller Heights",
    "lat": "27.90919",
    "lng": "-81.99814"
  },
  {
    "country": "US",
    "name": "Fussels Corner",
    "lat": "28.05419",
    "lng": "-81.86064"
  },
  {
    "country": "US",
    "name": "Gainesville",
    "lat": "29.65163",
    "lng": "-82.32483"
  },
  {
    "country": "US",
    "name": "Gandy",
    "lat": "27.8685",
    "lng": "-82.61612"
  },
  {
    "country": "US",
    "name": "Gateway",
    "lat": "26.57757",
    "lng": "-81.75036"
  },
  {
    "country": "US",
    "name": "Geneva",
    "lat": "28.73972",
    "lng": "-81.11506"
  },
  {
    "country": "US",
    "name": "Gibsonia",
    "lat": "28.11474",
    "lng": "-81.97369"
  },
  {
    "country": "US",
    "name": "Gibsonton",
    "lat": "27.85364",
    "lng": "-82.38259"
  },
  {
    "country": "US",
    "name": "Gifford",
    "lat": "27.67531",
    "lng": "-80.40922"
  },
  {
    "country": "US",
    "name": "Gladeview",
    "lat": "25.83926",
    "lng": "-80.2356"
  },
  {
    "country": "US",
    "name": "Glencoe",
    "lat": "29.02582",
    "lng": "-80.972"
  },
  {
    "country": "US",
    "name": "Glenvar Heights",
    "lat": "25.7076",
    "lng": "-80.32561"
  },
  {
    "country": "US",
    "name": "Golden Gate",
    "lat": "26.18787",
    "lng": "-81.69509"
  },
  {
    "country": "US",
    "name": "Golden Glades",
    "lat": "25.91176",
    "lng": "-80.20033"
  },
  {
    "country": "US",
    "name": "Goldenrod",
    "lat": "28.61028",
    "lng": "-81.28868"
  },
  {
    "country": "US",
    "name": "Gonzalez",
    "lat": "30.58158",
    "lng": "-87.29136"
  },
  {
    "country": "US",
    "name": "Gotha",
    "lat": "28.52778",
    "lng": "-81.52313"
  },
  {
    "country": "US",
    "name": "Goulding",
    "lat": "30.44298",
    "lng": "-87.22247"
  },
  {
    "country": "US",
    "name": "Goulds",
    "lat": "25.56261",
    "lng": "-80.38228"
  },
  {
    "country": "US",
    "name": "Graceville",
    "lat": "30.95685",
    "lng": "-85.5166"
  },
  {
    "country": "US",
    "name": "Green Cove Springs",
    "lat": "29.99191",
    "lng": "-81.67815"
  },
  {
    "country": "US",
    "name": "Greenacres City",
    "lat": "26.62368",
    "lng": "-80.12532"
  },
  {
    "country": "US",
    "name": "Gretna",
    "lat": "30.61714",
    "lng": "-84.65991"
  },
  {
    "country": "US",
    "name": "Grove City",
    "lat": "26.91423",
    "lng": "-82.32704"
  },
  {
    "country": "US",
    "name": "Groveland",
    "lat": "28.55805",
    "lng": "-81.85119"
  },
  {
    "country": "US",
    "name": "Gulf Breeze",
    "lat": "30.35714",
    "lng": "-87.16386"
  },
  {
    "country": "US",
    "name": "Gulf Gate Estates",
    "lat": "27.25173",
    "lng": "-82.51471"
  },
  {
    "country": "US",
    "name": "Gulfport",
    "lat": "27.74836",
    "lng": "-82.70343"
  },
  {
    "country": "US",
    "name": "Haines City",
    "lat": "28.1145",
    "lng": "-81.62009"
  },
  {
    "country": "US",
    "name": "Hallandale Beach",
    "lat": "25.9812",
    "lng": "-80.14838"
  },
  {
    "country": "US",
    "name": "Harbor Bluffs",
    "lat": "27.90947",
    "lng": "-82.8276"
  },
  {
    "country": "US",
    "name": "Harbour Heights",
    "lat": "26.99089",
    "lng": "-82.00231"
  },
  {
    "country": "US",
    "name": "Harlem",
    "lat": "26.73757",
    "lng": "-80.9509"
  },
  {
    "country": "US",
    "name": "Harlem Heights",
    "lat": "26.51619",
    "lng": "-81.92787"
  },
  {
    "country": "US",
    "name": "Havana",
    "lat": "30.62381",
    "lng": "-84.41463"
  },
  {
    "country": "US",
    "name": "Haverhill",
    "lat": "26.69118",
    "lng": "-80.12004"
  },
  {
    "country": "US",
    "name": "Hawthorne",
    "lat": "29.59191",
    "lng": "-82.08732"
  },
  {
    "country": "US",
    "name": "Hawthorne",
    "lat": "28.76138",
    "lng": "-81.87091"
  },
  {
    "country": "US",
    "name": "Heathrow",
    "lat": "28.76333",
    "lng": "-81.37225"
  },
  {
    "country": "US",
    "name": "Hernando",
    "lat": "28.89998",
    "lng": "-82.37454"
  },
  {
    "country": "US",
    "name": "Hernando Beach",
    "lat": "28.46944",
    "lng": "-82.65927"
  },
  {
    "country": "US",
    "name": "Hialeah",
    "lat": "25.8576",
    "lng": "-80.27811"
  },
  {
    "country": "US",
    "name": "Hialeah Gardens",
    "lat": "25.8651",
    "lng": "-80.3245"
  },
  {
    "country": "US",
    "name": "High Springs",
    "lat": "29.82691",
    "lng": "-82.59678"
  },
  {
    "country": "US",
    "name": "Highland Beach",
    "lat": "26.39952",
    "lng": "-80.0656"
  },
  {
    "country": "US",
    "name": "Highland City",
    "lat": "27.9653",
    "lng": "-81.87786"
  },
  {
    "country": "US",
    "name": "Hiland Park",
    "lat": "30.20103",
    "lng": "-85.62687"
  },
  {
    "country": "US",
    "name": "Hill 'n Dale",
    "lat": "28.51972",
    "lng": "-82.29926"
  },
  {
    "country": "US",
    "name": "Hilliard",
    "lat": "30.69107",
    "lng": "-81.91733"
  },
  {
    "country": "US",
    "name": "Hillsboro Beach",
    "lat": "26.29397",
    "lng": "-80.07893"
  },
  {
    "country": "US",
    "name": "Hobe Sound",
    "lat": "27.0595",
    "lng": "-80.13643"
  },
  {
    "country": "US",
    "name": "Holden Heights",
    "lat": "28.49667",
    "lng": "-81.38785"
  },
  {
    "country": "US",
    "name": "Holiday",
    "lat": "28.18779",
    "lng": "-82.73955"
  },
  {
    "country": "US",
    "name": "Holley",
    "lat": "30.44686",
    "lng": "-86.90691"
  },
  {
    "country": "US",
    "name": "Holly Hill",
    "lat": "29.24359",
    "lng": "-81.03756"
  },
  {
    "country": "US",
    "name": "Hollywood",
    "lat": "26.0112",
    "lng": "-80.14949"
  },
  {
    "country": "US",
    "name": "Holmes Beach",
    "lat": "27.49532",
    "lng": "-82.71093"
  },
  {
    "country": "US",
    "name": "Homestead",
    "lat": "25.46872",
    "lng": "-80.47756"
  },
  {
    "country": "US",
    "name": "Homosassa",
    "lat": "28.78137",
    "lng": "-82.6151"
  },
  {
    "country": "US",
    "name": "Homosassa Springs",
    "lat": "28.80359",
    "lng": "-82.57593"
  },
  {
    "country": "US",
    "name": "Howey-in-the-Hills",
    "lat": "28.71694",
    "lng": "-81.77341"
  },
  {
    "country": "US",
    "name": "Hudson",
    "lat": "28.36445",
    "lng": "-82.69343"
  },
  {
    "country": "US",
    "name": "Hunters Creek",
    "lat": "28.36056",
    "lng": "-81.42229"
  },
  {
    "country": "US",
    "name": "Hypoluxo",
    "lat": "26.56646",
    "lng": "-80.05337"
  },
  {
    "country": "US",
    "name": "Immokalee",
    "lat": "26.41869",
    "lng": "-81.4173"
  },
  {
    "country": "US",
    "name": "Indialantic",
    "lat": "28.08946",
    "lng": "-80.56561"
  },
  {
    "country": "US",
    "name": "Indian Harbour Beach",
    "lat": "28.1489",
    "lng": "-80.58839"
  },
  {
    "country": "US",
    "name": "Indian River Estates",
    "lat": "27.36449",
    "lng": "-80.30977"
  },
  {
    "country": "US",
    "name": "Indian River Shores",
    "lat": "27.7167",
    "lng": "-80.38422"
  },
  {
    "country": "US",
    "name": "Indian Rocks Beach",
    "lat": "27.8753",
    "lng": "-82.85122"
  },
  {
    "country": "US",
    "name": "Indian Shores",
    "lat": "27.8628",
    "lng": "-82.84844"
  },
  {
    "country": "US",
    "name": "Indiantown",
    "lat": "27.02728",
    "lng": "-80.48561"
  },
  {
    "country": "US",
    "name": "Inglis",
    "lat": "29.03025",
    "lng": "-82.66872"
  },
  {
    "country": "US",
    "name": "Interlachen",
    "lat": "29.62421",
    "lng": "-81.89256"
  },
  {
    "country": "US",
    "name": "Inverness",
    "lat": "28.83582",
    "lng": "-82.33037"
  },
  {
    "country": "US",
    "name": "Inwood",
    "lat": "28.03697",
    "lng": "-81.76508"
  },
  {
    "country": "US",
    "name": "Iona",
    "lat": "26.52036",
    "lng": "-81.96398"
  },
  {
    "country": "US",
    "name": "Islamorada",
    "lat": "24.9243",
    "lng": "-80.62784"
  },
  {
    "country": "US",
    "name": "Ives Estates",
    "lat": "25.96231",
    "lng": "-80.17671"
  },
  {
    "country": "US",
    "name": "Jacksonville",
    "lat": "30.33218",
    "lng": "-81.65565"
  },
  {
    "country": "US",
    "name": "Jacksonville Beach",
    "lat": "30.29469",
    "lng": "-81.39314"
  },
  {
    "country": "US",
    "name": "Jan-Phyl Village",
    "lat": "28.01474",
    "lng": "-81.77175"
  },
  {
    "country": "US",
    "name": "Jasmine Estates",
    "lat": "28.29306",
    "lng": "-82.6901"
  },
  {
    "country": "US",
    "name": "Jasper",
    "lat": "30.51827",
    "lng": "-82.94819"
  },
  {
    "country": "US",
    "name": "Jensen Beach",
    "lat": "27.25449",
    "lng": "-80.22977"
  },
  {
    "country": "US",
    "name": "June Park",
    "lat": "28.07224",
    "lng": "-80.68006"
  },
  {
    "country": "US",
    "name": "Juno Beach",
    "lat": "26.87978",
    "lng": "-80.05337"
  },
  {
    "country": "US",
    "name": "Jupiter",
    "lat": "26.93422",
    "lng": "-80.09421"
  },
  {
    "country": "US",
    "name": "Kathleen",
    "lat": "28.12085",
    "lng": "-82.02314"
  },
  {
    "country": "US",
    "name": "Kendale Lakes",
    "lat": "25.70816",
    "lng": "-80.407"
  },
  {
    "country": "US",
    "name": "Kendall",
    "lat": "25.67927",
    "lng": "-80.31727"
  },
  {
    "country": "US",
    "name": "Kendall Green",
    "lat": "26.25397",
    "lng": "-80.12393"
  },
  {
    "country": "US",
    "name": "Kenneth City",
    "lat": "27.81558",
    "lng": "-82.7201"
  },
  {
    "country": "US",
    "name": "Kensington Park",
    "lat": "27.35949",
    "lng": "-82.49649"
  },
  {
    "country": "US",
    "name": "Key Biscayne",
    "lat": "25.69371",
    "lng": "-80.16282"
  },
  {
    "country": "US",
    "name": "Key Largo",
    "lat": "25.08652",
    "lng": "-80.44728"
  },
  {
    "country": "US",
    "name": "Key West",
    "lat": "24.55524",
    "lng": "-81.78163"
  },
  {
    "country": "US",
    "name": "Keystone",
    "lat": "28.15585",
    "lng": "-82.62121"
  },
  {
    "country": "US",
    "name": "Keystone Heights",
    "lat": "29.78608",
    "lng": "-82.03149"
  },
  {
    "country": "US",
    "name": "Kings Point",
    "lat": "26.44535",
    "lng": "-80.13977"
  },
  {
    "country": "US",
    "name": "Kissimmee",
    "lat": "28.30468",
    "lng": "-81.41667"
  },
  {
    "country": "US",
    "name": "LaBelle",
    "lat": "26.76173",
    "lng": "-81.43841"
  },
  {
    "country": "US",
    "name": "Lacoochee",
    "lat": "28.46583",
    "lng": "-82.17203"
  },
  {
    "country": "US",
    "name": "Lady Lake",
    "lat": "28.91749",
    "lng": "-81.92286"
  },
  {
    "country": "US",
    "name": "Laguna Beach",
    "lat": "30.23965",
    "lng": "-85.9241"
  },
  {
    "country": "US",
    "name": "Lake Alfred",
    "lat": "28.09196",
    "lng": "-81.72341"
  },
  {
    "country": "US",
    "name": "Lake Belvedere Estates",
    "lat": "26.68923",
    "lng": "-80.13338"
  },
  {
    "country": "US",
    "name": "Lake Butler",
    "lat": "30.02274",
    "lng": "-82.33956"
  },
  {
    "country": "US",
    "name": "Lake Butler",
    "lat": "28.50167",
    "lng": "-81.54091"
  },
  {
    "country": "US",
    "name": "Lake City",
    "lat": "30.18968",
    "lng": "-82.63929"
  },
  {
    "country": "US",
    "name": "Lake Clarke Shores",
    "lat": "26.64534",
    "lng": "-80.07588"
  },
  {
    "country": "US",
    "name": "Lake Forest",
    "lat": "25.97759",
    "lng": "-80.1831"
  },
  {
    "country": "US",
    "name": "Lake Hamilton",
    "lat": "28.04446",
    "lng": "-81.62785"
  },
  {
    "country": "US",
    "name": "Lake Helen",
    "lat": "28.98082",
    "lng": "-81.23339"
  },
  {
    "country": "US",
    "name": "Lake Lorraine",
    "lat": "30.44159",
    "lng": "-86.56523"
  },
  {
    "country": "US",
    "name": "Lake Lucerne",
    "lat": "25.96509",
    "lng": "-80.24144"
  },
  {
    "country": "US",
    "name": "Lake Magdalene",
    "lat": "28.07418",
    "lng": "-82.47176"
  },
  {
    "country": "US",
    "name": "Lake Panasoffkee",
    "lat": "28.75582",
    "lng": "-82.09481"
  },
  {
    "country": "US",
    "name": "Lake Park",
    "lat": "26.80034",
    "lng": "-80.06643"
  },
  {
    "country": "US",
    "name": "Lake Placid",
    "lat": "27.35197",
    "lng": "-81.32631"
  },
  {
    "country": "US",
    "name": "Lake Sarasota",
    "lat": "27.29255",
    "lng": "-82.4376"
  },
  {
    "country": "US",
    "name": "Lake Mary",
    "lat": "28.75888",
    "lng": "-81.31784"
  },
  {
    "country": "US",
    "name": "Lake Wales",
    "lat": "27.90141",
    "lng": "-81.58591"
  },
  {
    "country": "US",
    "name": "Lake Worth",
    "lat": "26.61708",
    "lng": "-80.07231"
  },
  {
    "country": "US",
    "name": "Lake Worth Corridor",
    "lat": "26.61649",
    "lng": "-80.10102"
  },
  {
    "country": "US",
    "name": "Lakeland",
    "lat": "28.03947",
    "lng": "-81.9498"
  },
  {
    "country": "US",
    "name": "Lakeland Highlands",
    "lat": "27.95975",
    "lng": "-81.95008"
  },
  {
    "country": "US",
    "name": "Lakes by the Bay",
    "lat": "25.57233",
    "lng": "-80.32533"
  },
  {
    "country": "US",
    "name": "Lakeside",
    "lat": "30.12996",
    "lng": "-81.76815"
  },
  {
    "country": "US",
    "name": "Lakewood Park",
    "lat": "27.54309",
    "lng": "-80.40227"
  },
  {
    "country": "US",
    "name": "Lakewood Park",
    "lat": "27.48143",
    "lng": "-80.37422"
  },
  {
    "country": "US",
    "name": "Land O' Lakes",
    "lat": "28.2189",
    "lng": "-82.45759"
  },
  {
    "country": "US",
    "name": "Lantana",
    "lat": "26.58674",
    "lng": "-80.05199"
  },
  {
    "country": "US",
    "name": "Largo",
    "lat": "27.90979",
    "lng": "-82.78842"
  },
  {
    "country": "US",
    "name": "Lauderdale Lakes",
    "lat": "26.16647",
    "lng": "-80.20838"
  },
  {
    "country": "US",
    "name": "Lauderdale-by-the-Sea",
    "lat": "26.19203",
    "lng": "-80.09643"
  },
  {
    "country": "US",
    "name": "Lauderhill",
    "lat": "26.14036",
    "lng": "-80.21338"
  },
  {
    "country": "US",
    "name": "Laurel",
    "lat": "27.14378",
    "lng": "-82.46158"
  },
  {
    "country": "US",
    "name": "Lealman",
    "lat": "27.82114",
    "lng": "-82.67927"
  },
  {
    "country": "US",
    "name": "Lecanto",
    "lat": "28.85165",
    "lng": "-82.4876"
  },
  {
    "country": "US",
    "name": "Leesburg",
    "lat": "28.81082",
    "lng": "-81.87786"
  },
  {
    "country": "US",
    "name": "Lehigh Acres",
    "lat": "26.62535",
    "lng": "-81.6248"
  },
  {
    "country": "US",
    "name": "Leisure City",
    "lat": "25.49539",
    "lng": "-80.42922"
  },
  {
    "country": "US",
    "name": "Lely",
    "lat": "26.10065",
    "lng": "-81.72842"
  },
  {
    "country": "US",
    "name": "Lely Resort",
    "lat": "26.08093",
    "lng": "-81.69786"
  },
  {
    "country": "US",
    "name": "Lighthouse Point",
    "lat": "26.27564",
    "lng": "-80.08727"
  },
  {
    "country": "US",
    "name": "Limestone Creek",
    "lat": "26.94284",
    "lng": "-80.14115"
  },
  {
    "country": "US",
    "name": "Live Oak",
    "lat": "30.29495",
    "lng": "-82.98402"
  },
  {
    "country": "US",
    "name": "Lochmoor Waterway Estates",
    "lat": "26.64424",
    "lng": "-81.90981"
  },
  {
    "country": "US",
    "name": "Lockhart",
    "lat": "28.61944",
    "lng": "-81.44257"
  },
  {
    "country": "US",
    "name": "Longboat Key",
    "lat": "27.41254",
    "lng": "-82.65899"
  },
  {
    "country": "US",
    "name": "Longwood",
    "lat": "28.70305",
    "lng": "-81.3384"
  },
  {
    "country": "US",
    "name": "Loughman",
    "lat": "28.24196",
    "lng": "-81.56674"
  },
  {
    "country": "US",
    "name": "Lower Grand Lagoon",
    "lat": "30.14409",
    "lng": "-85.75076"
  },
  {
    "country": "US",
    "name": "Loxahatchee Groves",
    "lat": "26.68368",
    "lng": "-80.27977"
  },
  {
    "country": "US",
    "name": "Lutz",
    "lat": "28.15112",
    "lng": "-82.46148"
  },
  {
    "country": "US",
    "name": "Lynn Haven",
    "lat": "30.24548",
    "lng": "-85.64826"
  },
  {
    "country": "US",
    "name": "Macclenny",
    "lat": "30.28218",
    "lng": "-82.12206"
  },
  {
    "country": "US",
    "name": "Madeira Beach",
    "lat": "27.79808",
    "lng": "-82.79732"
  },
  {
    "country": "US",
    "name": "Madison",
    "lat": "30.46938",
    "lng": "-83.41293"
  },
  {
    "country": "US",
    "name": "Maitland",
    "lat": "28.62778",
    "lng": "-81.36312"
  },
  {
    "country": "US",
    "name": "Malabar",
    "lat": "28.00363",
    "lng": "-80.56561"
  },
  {
    "country": "US",
    "name": "Malone",
    "lat": "30.95769",
    "lng": "-85.16215"
  },
  {
    "country": "US",
    "name": "Manasota Key",
    "lat": "26.92534",
    "lng": "-82.35204"
  },
  {
    "country": "US",
    "name": "Manatee Road",
    "lat": "29.51302",
    "lng": "-82.91429"
  },
  {
    "country": "US",
    "name": "Mango",
    "lat": "27.97974",
    "lng": "-82.30648"
  },
  {
    "country": "US",
    "name": "Mangonia Park",
    "lat": "26.76034",
    "lng": "-80.07365"
  },
  {
    "country": "US",
    "name": "Marathon",
    "lat": "24.71375",
    "lng": "-81.09035"
  },
  {
    "country": "US",
    "name": "Marco",
    "lat": "25.9726",
    "lng": "-81.72898"
  },
  {
    "country": "US",
    "name": "Marco Island",
    "lat": "25.94121",
    "lng": "-81.71842"
  },
  {
    "country": "US",
    "name": "Margate",
    "lat": "26.24453",
    "lng": "-80.20644"
  },
  {
    "country": "US",
    "name": "Marianna",
    "lat": "30.77436",
    "lng": "-85.22687"
  },
  {
    "country": "US",
    "name": "Mary Esther",
    "lat": "30.41015",
    "lng": "-86.66509"
  },
  {
    "country": "US",
    "name": "Masaryktown",
    "lat": "28.44167",
    "lng": "-82.45704"
  },
  {
    "country": "US",
    "name": "Mascotte",
    "lat": "28.57833",
    "lng": "-81.88675"
  },
  {
    "country": "US",
    "name": "Mayo",
    "lat": "30.053",
    "lng": "-83.17486"
  },
  {
    "country": "US",
    "name": "McGregor",
    "lat": "26.56091",
    "lng": "-81.91453"
  },
  {
    "country": "US",
    "name": "Meadow Woods",
    "lat": "28.38556",
    "lng": "-81.36646"
  },
  {
    "country": "US",
    "name": "Medulla",
    "lat": "27.9678",
    "lng": "-81.97342"
  },
  {
    "country": "US",
    "name": "Melbourne",
    "lat": "28.08363",
    "lng": "-80.60811"
  },
  {
    "country": "US",
    "name": "Melbourne Beach",
    "lat": "28.06835",
    "lng": "-80.56033"
  },
  {
    "country": "US",
    "name": "Melrose Park",
    "lat": "26.11342",
    "lng": "-80.19338"
  },
  {
    "country": "US",
    "name": "Memphis",
    "lat": "27.53587",
    "lng": "-82.56121"
  },
  {
    "country": "US",
    "name": "Merritt Island",
    "lat": "28.53917",
    "lng": "-80.672"
  },
  {
    "country": "US",
    "name": "Mexico Beach",
    "lat": "29.94809",
    "lng": "-85.41995"
  },
  {
    "country": "US",
    "name": "Miami",
    "lat": "25.77427",
    "lng": "-80.19366"
  },
  {
    "country": "US",
    "name": "Miami Beach",
    "lat": "25.79065",
    "lng": "-80.13005"
  },
  {
    "country": "US",
    "name": "Miami Gardens",
    "lat": "25.97981",
    "lng": "-80.20255"
  },
  {
    "country": "US",
    "name": "Miami Gardens",
    "lat": "25.94204",
    "lng": "-80.2456"
  },
  {
    "country": "US",
    "name": "Miami Lakes",
    "lat": "25.90871",
    "lng": "-80.30866"
  },
  {
    "country": "US",
    "name": "Miami Shores",
    "lat": "25.86315",
    "lng": "-80.19283"
  },
  {
    "country": "US",
    "name": "Miami Springs",
    "lat": "25.82232",
    "lng": "-80.2895"
  },
  {
    "country": "US",
    "name": "Micco",
    "lat": "27.88058",
    "lng": "-80.50033"
  },
  {
    "country": "US",
    "name": "Midway",
    "lat": "30.49548",
    "lng": "-84.45435"
  },
  {
    "country": "US",
    "name": "Midway",
    "lat": "28.79027",
    "lng": "-81.2309"
  },
  {
    "country": "US",
    "name": "Middleburg",
    "lat": "30.06885",
    "lng": "-81.86038"
  },
  {
    "country": "US",
    "name": "Milton",
    "lat": "30.63241",
    "lng": "-87.03969"
  },
  {
    "country": "US",
    "name": "Mims",
    "lat": "28.66527",
    "lng": "-80.84478"
  },
  {
    "country": "US",
    "name": "Minneola",
    "lat": "28.57444",
    "lng": "-81.74619"
  },
  {
    "country": "US",
    "name": "Miramar",
    "lat": "25.98731",
    "lng": "-80.23227"
  },
  {
    "country": "US",
    "name": "Miramar Beach",
    "lat": "30.37437",
    "lng": "-86.35856"
  },
  {
    "country": "US",
    "name": "Molino",
    "lat": "30.72408",
    "lng": "-87.31414"
  },
  {
    "country": "US",
    "name": "Monticello",
    "lat": "30.54515",
    "lng": "-83.8713"
  },
  {
    "country": "US",
    "name": "Montverde",
    "lat": "28.60028",
    "lng": "-81.67396"
  },
  {
    "country": "US",
    "name": "Moore Haven",
    "lat": "26.83312",
    "lng": "-81.09312"
  },
  {
    "country": "US",
    "name": "Mount Dora",
    "lat": "28.80249",
    "lng": "-81.64452"
  },
  {
    "country": "US",
    "name": "Mount Plymouth",
    "lat": "28.80805",
    "lng": "-81.53313"
  },
  {
    "country": "US",
    "name": "Mulberry",
    "lat": "27.8953",
    "lng": "-81.97342"
  },
  {
    "country": "US",
    "name": "Myrtle Grove",
    "lat": "30.42103",
    "lng": "-87.30747"
  },
  {
    "country": "US",
    "name": "Naples",
    "lat": "26.14234",
    "lng": "-81.79596"
  },
  {
    "country": "US",
    "name": "Naples Manor",
    "lat": "26.0887",
    "lng": "-81.7262"
  },
  {
    "country": "US",
    "name": "Naples Park",
    "lat": "26.26175",
    "lng": "-81.80925"
  },
  {
    "country": "US",
    "name": "Naranja",
    "lat": "25.51816",
    "lng": "-80.42283"
  },
  {
    "country": "US",
    "name": "Navarre",
    "lat": "30.40159",
    "lng": "-86.86357"
  },
  {
    "country": "US",
    "name": "Neptune Beach",
    "lat": "30.31191",
    "lng": "-81.39647"
  },
  {
    "country": "US",
    "name": "New Port Richey",
    "lat": "28.24418",
    "lng": "-82.71927"
  },
  {
    "country": "US",
    "name": "New Smyrna Beach",
    "lat": "29.02582",
    "lng": "-80.927"
  },
  {
    "country": "US",
    "name": "Newberry",
    "lat": "29.64635",
    "lng": "-82.6065"
  },
  {
    "country": "US",
    "name": "Niceville",
    "lat": "30.51686",
    "lng": "-86.48217"
  },
  {
    "country": "US",
    "name": "Nocatee",
    "lat": "27.16033",
    "lng": "-81.88231"
  },
  {
    "country": "US",
    "name": "Nokomis",
    "lat": "27.11922",
    "lng": "-82.44426"
  },
  {
    "country": "US",
    "name": "Norland",
    "lat": "25.94898",
    "lng": "-80.21227"
  },
  {
    "country": "US",
    "name": "North Andrews Gardens",
    "lat": "26.19147",
    "lng": "-80.14421"
  },
  {
    "country": "US",
    "name": "North Bay Village",
    "lat": "25.84621",
    "lng": "-80.15394"
  },
  {
    "country": "US",
    "name": "North Brooksville",
    "lat": "28.57305",
    "lng": "-82.40815"
  },
  {
    "country": "US",
    "name": "North DeLand",
    "lat": "29.04943",
    "lng": "-81.29812"
  },
  {
    "country": "US",
    "name": "North Fort Myers",
    "lat": "26.66729",
    "lng": "-81.88009"
  },
  {
    "country": "US",
    "name": "North Key Largo",
    "lat": "25.26734",
    "lng": "-80.32339"
  },
  {
    "country": "US",
    "name": "North Lauderdale",
    "lat": "26.2173",
    "lng": "-80.22588"
  },
  {
    "country": "US",
    "name": "North Miami",
    "lat": "25.89009",
    "lng": "-80.18671"
  },
  {
    "country": "US",
    "name": "North Miami Beach",
    "lat": "25.93315",
    "lng": "-80.16255"
  },
  {
    "country": "US",
    "name": "North Palm Beach",
    "lat": "26.81756",
    "lng": "-80.08199"
  },
  {
    "country": "US",
    "name": "North Port",
    "lat": "27.04422",
    "lng": "-82.23593"
  },
  {
    "country": "US",
    "name": "North Redington Beach",
    "lat": "27.81614",
    "lng": "-82.82066"
  },
  {
    "country": "US",
    "name": "North River Shores",
    "lat": "27.21755",
    "lng": "-80.26977"
  },
  {
    "country": "US",
    "name": "North Sarasota",
    "lat": "27.37393",
    "lng": "-82.51843"
  },
  {
    "country": "US",
    "name": "Oak Hill",
    "lat": "28.86443",
    "lng": "-80.8545"
  },
  {
    "country": "US",
    "name": "Oak Ridge",
    "lat": "28.47112",
    "lng": "-81.42452"
  },
  {
    "country": "US",
    "name": "Oakland",
    "lat": "28.555",
    "lng": "-81.63313"
  },
  {
    "country": "US",
    "name": "Oakland Park",
    "lat": "26.17231",
    "lng": "-80.13199"
  },
  {
    "country": "US",
    "name": "Ocala",
    "lat": "29.1872",
    "lng": "-82.14009"
  },
  {
    "country": "US",
    "name": "Ocean City",
    "lat": "30.44103",
    "lng": "-86.61356"
  },
  {
    "country": "US",
    "name": "Ocean Ridge",
    "lat": "26.52702",
    "lng": "-80.04837"
  },
  {
    "country": "US",
    "name": "Ocoee",
    "lat": "28.56917",
    "lng": "-81.54396"
  },
  {
    "country": "US",
    "name": "Odessa",
    "lat": "28.1939",
    "lng": "-82.59176"
  },
  {
    "country": "US",
    "name": "Ojus",
    "lat": "25.94843",
    "lng": "-80.1506"
  },
  {
    "country": "US",
    "name": "Okeechobee",
    "lat": "27.24393",
    "lng": "-80.82978"
  },
  {
    "country": "US",
    "name": "Oldsmar",
    "lat": "28.03418",
    "lng": "-82.6651"
  },
  {
    "country": "US",
    "name": "Olga",
    "lat": "26.71896",
    "lng": "-81.7123"
  },
  {
    "country": "US",
    "name": "Olympia Heights",
    "lat": "25.72677",
    "lng": "-80.35533"
  },
  {
    "country": "US",
    "name": "Opa-locka",
    "lat": "25.90232",
    "lng": "-80.25033"
  },
  {
    "country": "US",
    "name": "Orange City",
    "lat": "28.94888",
    "lng": "-81.29867"
  },
  {
    "country": "US",
    "name": "Orange Park",
    "lat": "30.16607",
    "lng": "-81.70648"
  },
  {
    "country": "US",
    "name": "Orangetree",
    "lat": "26.29286",
    "lng": "-81.58842"
  },
  {
    "country": "US",
    "name": "Oriole Beach",
    "lat": "30.37381",
    "lng": "-87.09136"
  },
  {
    "country": "US",
    "name": "Orlando",
    "lat": "28.53834",
    "lng": "-81.37924"
  },
  {
    "country": "US",
    "name": "Orlovista",
    "lat": "28.53834",
    "lng": "-81.46035"
  },
  {
    "country": "US",
    "name": "Ormond Beach",
    "lat": "29.28581",
    "lng": "-81.05589"
  },
  {
    "country": "US",
    "name": "Ormond-by-the-Sea",
    "lat": "29.34914",
    "lng": "-81.06645"
  },
  {
    "country": "US",
    "name": "Osprey",
    "lat": "27.19616",
    "lng": "-82.49037"
  },
  {
    "country": "US",
    "name": "Oviedo",
    "lat": "28.67",
    "lng": "-81.20812"
  },
  {
    "country": "US",
    "name": "Pace",
    "lat": "30.59936",
    "lng": "-87.16108"
  },
  {
    "country": "US",
    "name": "Pahokee",
    "lat": "26.82006",
    "lng": "-80.66534"
  },
  {
    "country": "US",
    "name": "Palatka",
    "lat": "29.64858",
    "lng": "-81.63758"
  },
  {
    "country": "US",
    "name": "Palm Aire",
    "lat": "26.20619",
    "lng": "-80.19171"
  },
  {
    "country": "US",
    "name": "Palm Bay",
    "lat": "28.03446",
    "lng": "-80.58866"
  },
  {
    "country": "US",
    "name": "Palm Beach",
    "lat": "26.70562",
    "lng": "-80.03643"
  },
  {
    "country": "US",
    "name": "Palm Beach Gardens",
    "lat": "26.82339",
    "lng": "-80.13865"
  },
  {
    "country": "US",
    "name": "Palm Beach Shores",
    "lat": "26.77812",
    "lng": "-80.0356"
  },
  {
    "country": "US",
    "name": "Palm City",
    "lat": "27.16783",
    "lng": "-80.26616"
  },
  {
    "country": "US",
    "name": "Palm Coast",
    "lat": "29.58497",
    "lng": "-81.20784"
  },
  {
    "country": "US",
    "name": "Palm Harbor",
    "lat": "28.07807",
    "lng": "-82.76371"
  },
  {
    "country": "US",
    "name": "Palm Springs",
    "lat": "26.6359",
    "lng": "-80.09615"
  },
  {
    "country": "US",
    "name": "Palm Springs North",
    "lat": "25.9351",
    "lng": "-80.33383"
  },
  {
    "country": "US",
    "name": "Palm Valley",
    "lat": "30.17746",
    "lng": "-81.38758"
  },
  {
    "country": "US",
    "name": "Palmetto",
    "lat": "27.52143",
    "lng": "-82.57232"
  },
  {
    "country": "US",
    "name": "Palmetto Bay",
    "lat": "25.62177",
    "lng": "-80.32477"
  },
  {
    "country": "US",
    "name": "Palmetto Estates",
    "lat": "25.62149",
    "lng": "-80.362"
  },
  {
    "country": "US",
    "name": "Palmona Park",
    "lat": "26.68646",
    "lng": "-81.89648"
  },
  {
    "country": "US",
    "name": "Panama City",
    "lat": "30.15946",
    "lng": "-85.65983"
  },
  {
    "country": "US",
    "name": "Panama City Beach",
    "lat": "30.17659",
    "lng": "-85.80549"
  },
  {
    "country": "US",
    "name": "Paradise Heights",
    "lat": "28.62361",
    "lng": "-81.54396"
  },
  {
    "country": "US",
    "name": "Parker",
    "lat": "30.13104",
    "lng": "-85.60326"
  },
  {
    "country": "US",
    "name": "Parkland",
    "lat": "26.31008",
    "lng": "-80.23727"
  },
  {
    "country": "US",
    "name": "Pebble Creek",
    "lat": "28.14835",
    "lng": "-82.34565"
  },
  {
    "country": "US",
    "name": "Pelican Bay",
    "lat": "26.2312",
    "lng": "-81.80564"
  },
  {
    "country": "US",
    "name": "Pembroke Park",
    "lat": "25.98787",
    "lng": "-80.17477"
  },
  {
    "country": "US",
    "name": "Pembroke Pines",
    "lat": "26.00315",
    "lng": "-80.22394"
  },
  {
    "country": "US",
    "name": "Pensacola",
    "lat": "30.42131",
    "lng": "-87.21691"
  },
  {
    "country": "US",
    "name": "Perry",
    "lat": "30.11766",
    "lng": "-83.58274"
  },
  {
    "country": "US",
    "name": "Pierson",
    "lat": "29.23942",
    "lng": "-81.46563"
  },
  {
    "country": "US",
    "name": "Pine Castle",
    "lat": "28.47195",
    "lng": "-81.36785"
  },
  {
    "country": "US",
    "name": "Pine Hills",
    "lat": "28.55778",
    "lng": "-81.4534"
  },
  {
    "country": "US",
    "name": "Pine Island Center",
    "lat": "26.61369",
    "lng": "-82.11815"
  },
  {
    "country": "US",
    "name": "Pine Island Ridge",
    "lat": "26.09481",
    "lng": "-80.27394"
  },
  {
    "country": "US",
    "name": "Pine Manor",
    "lat": "26.57285",
    "lng": "-81.87814"
  },
  {
    "country": "US",
    "name": "Pine Ridge",
    "lat": "28.93831",
    "lng": "-82.47343"
  },
  {
    "country": "US",
    "name": "Pine Ridge",
    "lat": "26.23064",
    "lng": "-81.79592"
  },
  {
    "country": "US",
    "name": "Pinecrest",
    "lat": "25.66705",
    "lng": "-80.30811"
  },
  {
    "country": "US",
    "name": "Pinellas Park",
    "lat": "27.8428",
    "lng": "-82.69954"
  },
  {
    "country": "US",
    "name": "Pinewood",
    "lat": "25.86898",
    "lng": "-80.21699"
  },
  {
    "country": "US",
    "name": "Placid Lakes",
    "lat": "27.24144",
    "lng": "-81.40702"
  },
  {
    "country": "US",
    "name": "Plant City",
    "lat": "28.01888",
    "lng": "-82.11469"
  },
  {
    "country": "US",
    "name": "Plantation",
    "lat": "26.13421",
    "lng": "-80.23184"
  },
  {
    "country": "US",
    "name": "Plantation",
    "lat": "24.97624",
    "lng": "-80.55228"
  },
  {
    "country": "US",
    "name": "Plantation",
    "lat": "27.06811",
    "lng": "-82.37287"
  },
  {
    "country": "US",
    "name": "Plantation Mobile Home Park",
    "lat": "26.70312",
    "lng": "-80.13227"
  },
  {
    "country": "US",
    "name": "Poinciana",
    "lat": "28.14029",
    "lng": "-81.45841"
  },
  {
    "country": "US",
    "name": "Point Baker",
    "lat": "30.69019",
    "lng": "-87.05358"
  },
  {
    "country": "US",
    "name": "Polk City",
    "lat": "28.18251",
    "lng": "-81.82397"
  },
  {
    "country": "US",
    "name": "Pompano Beach",
    "lat": "26.23786",
    "lng": "-80.12477"
  },
  {
    "country": "US",
    "name": "Pompano Beach Highlands",
    "lat": "26.28286",
    "lng": "-80.10699"
  },
  {
    "country": "US",
    "name": "Ponce Inlet",
    "lat": "29.09637",
    "lng": "-80.937"
  },
  {
    "country": "US",
    "name": "Ponte Vedra Beach",
    "lat": "30.23969",
    "lng": "-81.38564"
  },
  {
    "country": "US",
    "name": "Port Charlotte",
    "lat": "26.97617",
    "lng": "-82.09064"
  },
  {
    "country": "US",
    "name": "Port LaBelle",
    "lat": "26.75645",
    "lng": "-81.40508"
  },
  {
    "country": "US",
    "name": "Port Orange",
    "lat": "29.13832",
    "lng": "-80.99561"
  },
  {
    "country": "US",
    "name": "Port Richey",
    "lat": "28.27168",
    "lng": "-82.71955"
  },
  {
    "country": "US",
    "name": "Port Saint Joe",
    "lat": "29.81188",
    "lng": "-85.30297"
  },
  {
    "country": "US",
    "name": "Port Saint John",
    "lat": "28.47695",
    "lng": "-80.78867"
  },
  {
    "country": "US",
    "name": "Port Saint Lucie",
    "lat": "27.29393",
    "lng": "-80.35033"
  },
  {
    "country": "US",
    "name": "Port Salerno",
    "lat": "27.14422",
    "lng": "-80.2006"
  },
  {
    "country": "US",
    "name": "Pretty Bayou",
    "lat": "30.19659",
    "lng": "-85.6966"
  },
  {
    "country": "US",
    "name": "Princeton",
    "lat": "25.53844",
    "lng": "-80.40894"
  },
  {
    "country": "US",
    "name": "Progress Village",
    "lat": "27.9003",
    "lng": "-82.36454"
  },
  {
    "country": "US",
    "name": "Punta Gorda",
    "lat": "26.92978",
    "lng": "-82.04537"
  },
  {
    "country": "US",
    "name": "Punta Gorda Isles",
    "lat": "26.91756",
    "lng": "-82.07842"
  },
  {
    "country": "US",
    "name": "Punta Rassa",
    "lat": "26.48786",
    "lng": "-82.01231"
  },
  {
    "country": "US",
    "name": "Quincy",
    "lat": "30.58714",
    "lng": "-84.58325"
  },
  {
    "country": "US",
    "name": "Redington Beach",
    "lat": "27.80864",
    "lng": "-82.81121"
  },
  {
    "country": "US",
    "name": "Redington Shores",
    "lat": "27.82614",
    "lng": "-82.82899"
  },
  {
    "country": "US",
    "name": "Richmond Heights",
    "lat": "25.63149",
    "lng": "-80.36894"
  },
  {
    "country": "US",
    "name": "Richmond West",
    "lat": "25.6105",
    "lng": "-80.42971"
  },
  {
    "country": "US",
    "name": "Ridge Manor",
    "lat": "28.5075",
    "lng": "-82.17036"
  },
  {
    "country": "US",
    "name": "Ridge Wood Heights",
    "lat": "27.28727",
    "lng": "-82.51315"
  },
  {
    "country": "US",
    "name": "Ridgecrest",
    "lat": "27.8975",
    "lng": "-82.80529"
  },
  {
    "country": "US",
    "name": "River Park",
    "lat": "27.31421",
    "lng": "-80.34727"
  },
  {
    "country": "US",
    "name": "Riverview",
    "lat": "27.86614",
    "lng": "-82.32648"
  },
  {
    "country": "US",
    "name": "Riviera Beach",
    "lat": "26.77534",
    "lng": "-80.0581"
  },
  {
    "country": "US",
    "name": "Rock Island",
    "lat": "26.15509",
    "lng": "-80.17699"
  },
  {
    "country": "US",
    "name": "Rockledge",
    "lat": "28.35084",
    "lng": "-80.72533"
  },
  {
    "country": "US",
    "name": "Roseland",
    "lat": "27.83586",
    "lng": "-80.49311"
  },
  {
    "country": "US",
    "name": "Rotonda West",
    "lat": "26.88368",
    "lng": "-82.29009"
  },
  {
    "country": "US",
    "name": "Royal Palm Beach",
    "lat": "26.7084",
    "lng": "-80.2306"
  },
  {
    "country": "US",
    "name": "Royal Palm Estates",
    "lat": "26.68173",
    "lng": "-80.12504"
  },
  {
    "country": "US",
    "name": "Ruskin",
    "lat": "27.72086",
    "lng": "-82.43315"
  },
  {
    "country": "US",
    "name": "Safety Harbor",
    "lat": "27.99085",
    "lng": "-82.69316"
  },
  {
    "country": "US",
    "name": "Saint Augustine",
    "lat": "29.89469",
    "lng": "-81.31452"
  },
  {
    "country": "US",
    "name": "Saint Augustine Beach",
    "lat": "29.85053",
    "lng": "-81.26535"
  },
  {
    "country": "US",
    "name": "Saint Augustine Shores",
    "lat": "29.8108",
    "lng": "-81.31035"
  },
  {
    "country": "US",
    "name": "Saint Cloud",
    "lat": "28.2489",
    "lng": "-81.28118"
  },
  {
    "country": "US",
    "name": "Saint George",
    "lat": "28.05641",
    "lng": "-82.72788"
  },
  {
    "country": "US",
    "name": "Saint James City",
    "lat": "26.49758",
    "lng": "-82.07843"
  },
  {
    "country": "US",
    "name": "Saint Leo",
    "lat": "28.33723",
    "lng": "-82.25842"
  },
  {
    "country": "US",
    "name": "Saint Pete Beach",
    "lat": "27.72531",
    "lng": "-82.74121"
  },
  {
    "country": "US",
    "name": "St. Petersburg",
    "lat": "27.77086",
    "lng": "-82.67927"
  },
  {
    "country": "US",
    "name": "Samoset",
    "lat": "27.46948",
    "lng": "-82.54149"
  },
  {
    "country": "US",
    "name": "San Antonio",
    "lat": "28.33611",
    "lng": "-82.27453"
  },
  {
    "country": "US",
    "name": "San Carlos Park",
    "lat": "26.4673",
    "lng": "-81.80147"
  },
  {
    "country": "US",
    "name": "Sanibel",
    "lat": "26.44897",
    "lng": "-82.02231"
  },
  {
    "country": "US",
    "name": "Sanford",
    "lat": "28.80055",
    "lng": "-81.27312"
  },
  {
    "country": "US",
    "name": "Sarasota",
    "lat": "27.33643",
    "lng": "-82.53065"
  },
  {
    "country": "US",
    "name": "Sarasota Springs",
    "lat": "27.30894",
    "lng": "-82.47954"
  },
  {
    "country": "US",
    "name": "Satellite Beach",
    "lat": "28.17612",
    "lng": "-80.59005"
  },
  {
    "country": "US",
    "name": "Sawgrass",
    "lat": "30.19274",
    "lng": "-81.37064"
  },
  {
    "country": "US",
    "name": "Schall Circle",
    "lat": "26.71562",
    "lng": "-80.11504"
  },
  {
    "country": "US",
    "name": "Scott Lake",
    "lat": "25.94148",
    "lng": "-80.23199"
  },
  {
    "country": "US",
    "name": "Seaside",
    "lat": "30.32103",
    "lng": "-86.14161"
  },
  {
    "country": "US",
    "name": "Sebastian",
    "lat": "27.81641",
    "lng": "-80.47061"
  },
  {
    "country": "US",
    "name": "Sebring",
    "lat": "27.49559",
    "lng": "-81.44091"
  },
  {
    "country": "US",
    "name": "Seffner",
    "lat": "27.98363",
    "lng": "-82.27565"
  },
  {
    "country": "US",
    "name": "Seminole",
    "lat": "27.83975",
    "lng": "-82.79121"
  },
  {
    "country": "US",
    "name": "Seminole Manor",
    "lat": "26.58368",
    "lng": "-80.10032"
  },
  {
    "country": "US",
    "name": "Sewall's Point",
    "lat": "27.19949",
    "lng": "-80.20227"
  },
  {
    "country": "US",
    "name": "Shady Hills",
    "lat": "28.41",
    "lng": "-82.54288"
  },
  {
    "country": "US",
    "name": "Sharpes",
    "lat": "28.43223",
    "lng": "-80.76005"
  },
  {
    "country": "US",
    "name": "Siesta Key",
    "lat": "27.26785",
    "lng": "-82.54526"
  },
  {
    "country": "US",
    "name": "Silver Lake",
    "lat": "28.84193",
    "lng": "-81.79841"
  },
  {
    "country": "US",
    "name": "Silver Springs Shores",
    "lat": "29.10442",
    "lng": "-82.02064"
  },
  {
    "country": "US",
    "name": "Sky Lake",
    "lat": "28.45723",
    "lng": "-81.39146"
  },
  {
    "country": "US",
    "name": "Sneads",
    "lat": "30.70801",
    "lng": "-84.92552"
  },
  {
    "country": "US",
    "name": "South Bay",
    "lat": "26.66396",
    "lng": "-80.71617"
  },
  {
    "country": "US",
    "name": "South Beach",
    "lat": "27.59115",
    "lng": "-80.34422"
  },
  {
    "country": "US",
    "name": "South Bradenton",
    "lat": "27.4631",
    "lng": "-82.58176"
  },
  {
    "country": "US",
    "name": "South Apopka",
    "lat": "28.66194",
    "lng": "-81.50952"
  },
  {
    "country": "US",
    "name": "South Brooksville",
    "lat": "28.53582",
    "lng": "-82.38403"
  },
  {
    "country": "US",
    "name": "South Daytona",
    "lat": "29.16582",
    "lng": "-81.0045"
  },
  {
    "country": "US",
    "name": "South Gate Ridge",
    "lat": "27.28644",
    "lng": "-82.49676"
  },
  {
    "country": "US",
    "name": "South Highpoint",
    "lat": "27.91697",
    "lng": "-82.71288"
  },
  {
    "country": "US",
    "name": "South Miami",
    "lat": "25.7076",
    "lng": "-80.29338"
  },
  {
    "country": "US",
    "name": "South Miami Heights",
    "lat": "25.59761",
    "lng": "-80.38061"
  },
  {
    "country": "US",
    "name": "South Palm Beach",
    "lat": "26.58896",
    "lng": "-80.03865"
  },
  {
    "country": "US",
    "name": "South Pasadena",
    "lat": "27.75503",
    "lng": "-82.7376"
  },
  {
    "country": "US",
    "name": "South Patrick Shores",
    "lat": "28.20223",
    "lng": "-80.6095"
  },
  {
    "country": "US",
    "name": "South Sarasota",
    "lat": "27.28616",
    "lng": "-82.53288"
  },
  {
    "country": "US",
    "name": "South Venice",
    "lat": "27.05311",
    "lng": "-82.42426"
  },
  {
    "country": "US",
    "name": "Southchase",
    "lat": "28.39306",
    "lng": "-81.3834"
  },
  {
    "country": "US",
    "name": "Southgate",
    "lat": "27.3081",
    "lng": "-82.50982"
  },
  {
    "country": "US",
    "name": "Southwest Ranches",
    "lat": "26.0587",
    "lng": "-80.33727"
  },
  {
    "country": "US",
    "name": "Spring Hill",
    "lat": "28.47688",
    "lng": "-82.52546"
  },
  {
    "country": "US",
    "name": "Springfield",
    "lat": "30.15326",
    "lng": "-85.61132"
  },
  {
    "country": "US",
    "name": "Starke",
    "lat": "29.94413",
    "lng": "-82.10983"
  },
  {
    "country": "US",
    "name": "Steinhatchee",
    "lat": "29.67106",
    "lng": "-83.38764"
  },
  {
    "country": "US",
    "name": "Stock Island",
    "lat": "24.56709",
    "lng": "-81.73842"
  },
  {
    "country": "US",
    "name": "Stuart",
    "lat": "27.19755",
    "lng": "-80.25283"
  },
  {
    "country": "US",
    "name": "Sugarmill Woods",
    "lat": "28.73221",
    "lng": "-82.50621"
  },
  {
    "country": "US",
    "name": "Sun City Center",
    "lat": "27.71809",
    "lng": "-82.35176"
  },
  {
    "country": "US",
    "name": "Suncoast Estates",
    "lat": "26.71174",
    "lng": "-81.86897"
  },
  {
    "country": "US",
    "name": "Sunny Isles Beach",
    "lat": "25.95065",
    "lng": "-80.12282"
  },
  {
    "country": "US",
    "name": "Sunrise",
    "lat": "26.13397",
    "lng": "-80.1131"
  },
  {
    "country": "US",
    "name": "Sunset",
    "lat": "25.70594",
    "lng": "-80.35228"
  },
  {
    "country": "US",
    "name": "Sunshine Ranches",
    "lat": "26.04592",
    "lng": "-80.32894"
  },
  {
    "country": "US",
    "name": "Surfside",
    "lat": "25.87843",
    "lng": "-80.1256"
  },
  {
    "country": "US",
    "name": "Sweetwater",
    "lat": "25.76343",
    "lng": "-80.37311"
  },
  {
    "country": "US",
    "name": "Taft",
    "lat": "28.42973",
    "lng": "-81.36507"
  },
  {
    "country": "US",
    "name": "Tallahassee",
    "lat": "30.43826",
    "lng": "-84.28073"
  },
  {
    "country": "US",
    "name": "Tamarac",
    "lat": "26.21286",
    "lng": "-80.24977"
  },
  {
    "country": "US",
    "name": "Tamiami",
    "lat": "25.75871",
    "lng": "-80.39839"
  },
  {
    "country": "US",
    "name": "Tampa",
    "lat": "27.94752",
    "lng": "-82.45843"
  },
  {
    "country": "US",
    "name": "Tangelo Park",
    "lat": "28.45584",
    "lng": "-81.4459"
  },
  {
    "country": "US",
    "name": "Tangerine",
    "lat": "28.76499",
    "lng": "-81.63063"
  },
  {
    "country": "US",
    "name": "Tarpon Springs",
    "lat": "28.14612",
    "lng": "-82.75677"
  },
  {
    "country": "US",
    "name": "Tavares",
    "lat": "28.80416",
    "lng": "-81.72563"
  },
  {
    "country": "US",
    "name": "Tavernier",
    "lat": "25.01152",
    "lng": "-80.51506"
  },
  {
    "country": "US",
    "name": "Taylor Creek",
    "lat": "27.21671",
    "lng": "-80.7895"
  },
  {
    "country": "US",
    "name": "Tedder",
    "lat": "26.28425",
    "lng": "-80.12227"
  },
  {
    "country": "US",
    "name": "Temple Terrace",
    "lat": "28.0353",
    "lng": "-82.38926"
  },
  {
    "country": "US",
    "name": "Tequesta",
    "lat": "26.96811",
    "lng": "-80.12865"
  },
  {
    "country": "US",
    "name": "Terra Mar",
    "lat": "26.21619",
    "lng": "-80.09532"
  },
  {
    "country": "US",
    "name": "The Crossings",
    "lat": "25.67066",
    "lng": "-80.40117"
  },
  {
    "country": "US",
    "name": "The Hammocks",
    "lat": "25.67149",
    "lng": "-80.4445"
  },
  {
    "country": "US",
    "name": "The Meadows",
    "lat": "27.36171",
    "lng": "-82.46898"
  },
  {
    "country": "US",
    "name": "The Villages",
    "lat": "28.93408",
    "lng": "-81.95994"
  },
  {
    "country": "US",
    "name": "Thonotosassa",
    "lat": "28.06141",
    "lng": "-82.30231"
  },
  {
    "country": "US",
    "name": "Three Lakes",
    "lat": "25.64205",
    "lng": "-80.39839"
  },
  {
    "country": "US",
    "name": "Three Oaks",
    "lat": "26.47008",
    "lng": "-81.79397"
  },
  {
    "country": "US",
    "name": "Tice",
    "lat": "26.67479",
    "lng": "-81.81508"
  },
  {
    "country": "US",
    "name": "Tierra Verde",
    "lat": "27.69197",
    "lng": "-82.72343"
  },
  {
    "country": "US",
    "name": "Tiger Point",
    "lat": "30.37853",
    "lng": "-87.05552"
  },
  {
    "country": "US",
    "name": "Timber Pines",
    "lat": "28.47028",
    "lng": "-82.60316"
  },
  {
    "country": "US",
    "name": "Titusville",
    "lat": "28.61222",
    "lng": "-80.80755"
  },
  {
    "country": "US",
    "name": "Town 'n' Country",
    "lat": "28.01057",
    "lng": "-82.57732"
  },
  {
    "country": "US",
    "name": "Treasure Island",
    "lat": "27.76919",
    "lng": "-82.76899"
  },
  {
    "country": "US",
    "name": "Trenton",
    "lat": "29.61329",
    "lng": "-82.81762"
  },
  {
    "country": "US",
    "name": "Twin Lakes",
    "lat": "26.18092",
    "lng": "-80.16005"
  },
  {
    "country": "US",
    "name": "Umatilla",
    "lat": "28.92943",
    "lng": "-81.66563"
  },
  {
    "country": "US",
    "name": "Union Park",
    "lat": "28.56806",
    "lng": "-81.28618"
  },
  {
    "country": "US",
    "name": "University Park",
    "lat": "25.74649",
    "lng": "-80.36755"
  },
  {
    "country": "US",
    "name": "Upper Grand Lagoon",
    "lat": "30.16326",
    "lng": "-85.74076"
  },
  {
    "country": "US",
    "name": "Valparaiso",
    "lat": "30.50853",
    "lng": "-86.50273"
  },
  {
    "country": "US",
    "name": "Valrico",
    "lat": "27.93789",
    "lng": "-82.23644"
  },
  {
    "country": "US",
    "name": "Vamo",
    "lat": "27.222",
    "lng": "-82.49787"
  },
  {
    "country": "US",
    "name": "Venice",
    "lat": "27.09978",
    "lng": "-82.45426"
  },
  {
    "country": "US",
    "name": "Venice Gardens",
    "lat": "27.07311",
    "lng": "-82.4076"
  },
  {
    "country": "US",
    "name": "Vero Beach",
    "lat": "27.63864",
    "lng": "-80.39727"
  },
  {
    "country": "US",
    "name": "Villages of Oriole",
    "lat": "26.4623",
    "lng": "-80.15282"
  },
  {
    "country": "US",
    "name": "Villano Beach",
    "lat": "29.93858",
    "lng": "-81.30202"
  },
  {
    "country": "US",
    "name": "Vineyards",
    "lat": "26.22373",
    "lng": "-81.72798"
  },
  {
    "country": "US",
    "name": "Virginia Gardens",
    "lat": "25.81038",
    "lng": "-80.30227"
  },
  {
    "country": "US",
    "name": "Wabasso Beach",
    "lat": "27.76475",
    "lng": "-80.39894"
  },
  {
    "country": "US",
    "name": "Wahneta",
    "lat": "27.9528",
    "lng": "-81.72702"
  },
  {
    "country": "US",
    "name": "Waldo",
    "lat": "29.78969",
    "lng": "-82.16732"
  },
  {
    "country": "US",
    "name": "Wallace",
    "lat": "30.67741",
    "lng": "-87.17997"
  },
  {
    "country": "US",
    "name": "Warm Mineral Springs",
    "lat": "27.05978",
    "lng": "-82.26009"
  },
  {
    "country": "US",
    "name": "Warrington",
    "lat": "30.38409",
    "lng": "-87.27497"
  },
  {
    "country": "US",
    "name": "Washington Park",
    "lat": "26.13259",
    "lng": "-80.18116"
  },
  {
    "country": "US",
    "name": "Watertown",
    "lat": "30.19245",
    "lng": "-82.61457"
  },
  {
    "country": "US",
    "name": "Wauchula",
    "lat": "27.54726",
    "lng": "-81.81147"
  },
  {
    "country": "US",
    "name": "Wedgefield",
    "lat": "28.48778",
    "lng": "-81.07729"
  },
  {
    "country": "US",
    "name": "Weeki Wachee Gardens",
    "lat": "28.53361",
    "lng": "-82.62954"
  },
  {
    "country": "US",
    "name": "Wekiwa Springs",
    "lat": "28.69861",
    "lng": "-81.42563"
  },
  {
    "country": "US",
    "name": "Wellborn",
    "lat": "30.23106",
    "lng": "-82.81957"
  },
  {
    "country": "US",
    "name": "Wellington",
    "lat": "26.65868",
    "lng": "-80.24144"
  },
  {
    "country": "US",
    "name": "Wesley Chapel",
    "lat": "28.23973",
    "lng": "-82.32787"
  },
  {
    "country": "US",
    "name": "West Bradenton",
    "lat": "27.50254",
    "lng": "-82.61399"
  },
  {
    "country": "US",
    "name": "Westchase",
    "lat": "28.05502",
    "lng": "-82.60982"
  },
  {
    "country": "US",
    "name": "West DeLand",
    "lat": "29.01582",
    "lng": "-81.33312"
  },
  {
    "country": "US",
    "name": "West Gate",
    "lat": "26.70257",
    "lng": "-80.0981"
  },
  {
    "country": "US",
    "name": "West Hollywood",
    "lat": "26.02065",
    "lng": "-80.18394"
  },
  {
    "country": "US",
    "name": "West Little River",
    "lat": "25.85704",
    "lng": "-80.23699"
  },
  {
    "country": "US",
    "name": "West Melbourne",
    "lat": "28.07168",
    "lng": "-80.65339"
  },
  {
    "country": "US",
    "name": "West Miami",
    "lat": "25.76343",
    "lng": "-80.29616"
  },
  {
    "country": "US",
    "name": "West Palm Beach",
    "lat": "26.71534",
    "lng": "-80.05337"
  },
  {
    "country": "US",
    "name": "West Park",
    "lat": "25.98454",
    "lng": "-80.19894"
  },
  {
    "country": "US",
    "name": "West Pensacola",
    "lat": "30.42659",
    "lng": "-87.27969"
  },
  {
    "country": "US",
    "name": "West Perrine",
    "lat": "25.60594",
    "lng": "-80.36283"
  },
  {
    "country": "US",
    "name": "West Samoset",
    "lat": "27.46948",
    "lng": "-82.55676"
  },
  {
    "country": "US",
    "name": "West Vero Corridor",
    "lat": "27.63775",
    "lng": "-80.48576"
  },
  {
    "country": "US",
    "name": "West and East Lealman",
    "lat": "27.81993",
    "lng": "-82.68944"
  },
  {
    "country": "US",
    "name": "Westchester",
    "lat": "25.75482",
    "lng": "-80.32727"
  },
  {
    "country": "US",
    "name": "Weston",
    "lat": "26.10037",
    "lng": "-80.39977"
  },
  {
    "country": "US",
    "name": "Westview",
    "lat": "25.88204",
    "lng": "-80.24199"
  },
  {
    "country": "US",
    "name": "Westwood Lake",
    "lat": "25.72927",
    "lng": "-80.37283"
  },
  {
    "country": "US",
    "name": "Wewahitchka",
    "lat": "30.1127",
    "lng": "-85.20047"
  },
  {
    "country": "US",
    "name": "Whiskey Creek",
    "lat": "26.57258",
    "lng": "-81.89009"
  },
  {
    "country": "US",
    "name": "White City",
    "lat": "27.37393",
    "lng": "-80.33394"
  },
  {
    "country": "US",
    "name": "Whitfield",
    "lat": "27.41171",
    "lng": "-82.56593"
  },
  {
    "country": "US",
    "name": "Wildwood",
    "lat": "28.86542",
    "lng": "-82.04058"
  },
  {
    "country": "US",
    "name": "Williamsburg",
    "lat": "28.41445",
    "lng": "-81.44285"
  },
  {
    "country": "US",
    "name": "Williston",
    "lat": "29.38747",
    "lng": "-82.44677"
  },
  {
    "country": "US",
    "name": "Williston Highlands",
    "lat": "29.34052",
    "lng": "-82.5415"
  },
  {
    "country": "US",
    "name": "Willow Oak",
    "lat": "27.91614",
    "lng": "-82.01786"
  },
  {
    "country": "US",
    "name": "Wilton Manors",
    "lat": "26.16036",
    "lng": "-80.13893"
  },
  {
    "country": "US",
    "name": "Wimauma",
    "lat": "27.71253",
    "lng": "-82.29898"
  },
  {
    "country": "US",
    "name": "Windermere",
    "lat": "28.49556",
    "lng": "-81.5348"
  },
  {
    "country": "US",
    "name": "Winston",
    "lat": "28.03169",
    "lng": "-82.01481"
  },
  {
    "country": "US",
    "name": "Winter Beach",
    "lat": "27.7192",
    "lng": "-80.42061"
  },
  {
    "country": "US",
    "name": "Winter Garden",
    "lat": "28.56528",
    "lng": "-81.58618"
  },
  {
    "country": "US",
    "name": "Winter Haven",
    "lat": "28.02224",
    "lng": "-81.73286"
  },
  {
    "country": "US",
    "name": "Winter Park",
    "lat": "28.6",
    "lng": "-81.33924"
  },
  {
    "country": "US",
    "name": "Winter Springs",
    "lat": "28.69889",
    "lng": "-81.30812"
  },
  {
    "country": "US",
    "name": "Woodlawn Beach",
    "lat": "30.38825",
    "lng": "-86.9908"
  },
  {
    "country": "US",
    "name": "Woodville",
    "lat": "30.31409",
    "lng": "-84.2474"
  },
  {
    "country": "US",
    "name": "Wright",
    "lat": "30.45575",
    "lng": "-86.63829"
  },
  {
    "country": "US",
    "name": "Yalaha",
    "lat": "28.7386",
    "lng": "-81.80869"
  },
  {
    "country": "US",
    "name": "Youngstown",
    "lat": "30.36436",
    "lng": "-85.43826"
  },
  {
    "country": "US",
    "name": "Yulee",
    "lat": "30.6319",
    "lng": "-81.60649"
  },
  {
    "country": "US",
    "name": "Zellwood",
    "lat": "28.73111",
    "lng": "-81.60118"
  },
  {
    "country": "US",
    "name": "Zephyrhills",
    "lat": "28.23362",
    "lng": "-82.18119"
  },
  {
    "country": "US",
    "name": "Zolfo Springs",
    "lat": "27.49337",
    "lng": "-81.79592"
  },
  {
    "country": "US",
    "name": "Abbeville",
    "lat": "31.99212",
    "lng": "-83.30682"
  },
  {
    "country": "US",
    "name": "Acworth",
    "lat": "34.06635",
    "lng": "-84.67837"
  },
  {
    "country": "US",
    "name": "Adairsville",
    "lat": "34.3687",
    "lng": "-84.93411"
  },
  {
    "country": "US",
    "name": "Adel",
    "lat": "31.13727",
    "lng": "-83.42408"
  },
  {
    "country": "US",
    "name": "Alamo",
    "lat": "32.14712",
    "lng": "-82.77792"
  },
  {
    "country": "US",
    "name": "Albany",
    "lat": "31.57851",
    "lng": "-84.15574"
  },
  {
    "country": "US",
    "name": "Alma",
    "lat": "31.53937",
    "lng": "-82.46236"
  },
  {
    "country": "US",
    "name": "Alpharetta",
    "lat": "34.07538",
    "lng": "-84.29409"
  },
  {
    "country": "US",
    "name": "Alto",
    "lat": "34.46732",
    "lng": "-83.57378"
  },
  {
    "country": "US",
    "name": "Americus",
    "lat": "32.07239",
    "lng": "-84.23269"
  },
  {
    "country": "US",
    "name": "Appling",
    "lat": "33.54608",
    "lng": "-82.3173"
  },
  {
    "country": "US",
    "name": "Aragon",
    "lat": "34.04565",
    "lng": "-85.05606"
  },
  {
    "country": "US",
    "name": "Arcade",
    "lat": "34.07789",
    "lng": "-83.56155"
  },
  {
    "country": "US",
    "name": "Arlington",
    "lat": "31.4399",
    "lng": "-84.72492"
  },
  {
    "country": "US",
    "name": "Ashburn",
    "lat": "31.70601",
    "lng": "-83.65322"
  },
  {
    "country": "US",
    "name": "Athens",
    "lat": "33.96095",
    "lng": "-83.37794"
  },
  {
    "country": "US",
    "name": "Atlanta",
    "lat": "33.749",
    "lng": "-84.38798"
  },
  {
    "country": "US",
    "name": "Auburn",
    "lat": "34.01372",
    "lng": "-83.82768"
  },
  {
    "country": "US",
    "name": "Augusta",
    "lat": "33.47097",
    "lng": "-81.97484"
  },
  {
    "country": "US",
    "name": "Austell",
    "lat": "33.81261",
    "lng": "-84.63438"
  },
  {
    "country": "US",
    "name": "Avondale Estates",
    "lat": "33.77149",
    "lng": "-84.26714"
  },
  {
    "country": "US",
    "name": "Bainbridge",
    "lat": "30.9038",
    "lng": "-84.57547"
  },
  {
    "country": "US",
    "name": "Baldwin",
    "lat": "34.49177",
    "lng": "-83.53739"
  },
  {
    "country": "US",
    "name": "Ball Ground",
    "lat": "34.33815",
    "lng": "-84.37659"
  },
  {
    "country": "US",
    "name": "Barnesville",
    "lat": "33.05457",
    "lng": "-84.15575"
  },
  {
    "country": "US",
    "name": "Baxley",
    "lat": "31.77825",
    "lng": "-82.34846"
  },
  {
    "country": "US",
    "name": "Belvedere Park",
    "lat": "33.75483",
    "lng": "-84.26742"
  },
  {
    "country": "US",
    "name": "Berkeley Lake",
    "lat": "33.98371",
    "lng": "-84.18658"
  },
  {
    "country": "US",
    "name": "Blackshear",
    "lat": "31.30605",
    "lng": "-82.24207"
  },
  {
    "country": "US",
    "name": "Blairsville",
    "lat": "34.8762",
    "lng": "-83.95824"
  },
  {
    "country": "US",
    "name": "Blakely",
    "lat": "31.37768",
    "lng": "-84.93409"
  },
  {
    "country": "US",
    "name": "Bloomingdale",
    "lat": "32.13242",
    "lng": "-81.299"
  },
  {
    "country": "US",
    "name": "Blue Ridge",
    "lat": "34.86397",
    "lng": "-84.32409"
  },
  {
    "country": "US",
    "name": "Bogart",
    "lat": "33.94928",
    "lng": "-83.53461"
  },
  {
    "country": "US",
    "name": "Bonanza",
    "lat": "33.46567",
    "lng": "-84.33659"
  },
  {
    "country": "US",
    "name": "Boston",
    "lat": "30.79186",
    "lng": "-83.78989"
  },
  {
    "country": "US",
    "name": "Bowdon",
    "lat": "33.53789",
    "lng": "-85.25328"
  },
  {
    "country": "US",
    "name": "Braselton",
    "lat": "34.10927",
    "lng": "-83.76267"
  },
  {
    "country": "US",
    "name": "Bremen",
    "lat": "33.72122",
    "lng": "-85.1455"
  },
  {
    "country": "US",
    "name": "Brookhaven",
    "lat": "33.85844",
    "lng": "-84.3402"
  },
  {
    "country": "US",
    "name": "Brooklet",
    "lat": "32.37963",
    "lng": "-81.66317"
  },
  {
    "country": "US",
    "name": "Broxton",
    "lat": "31.62519",
    "lng": "-82.88681"
  },
  {
    "country": "US",
    "name": "Brunswick",
    "lat": "31.14995",
    "lng": "-81.49149"
  },
  {
    "country": "US",
    "name": "Buchanan",
    "lat": "33.8026",
    "lng": "-85.18856"
  },
  {
    "country": "US",
    "name": "Buena Vista",
    "lat": "32.31904",
    "lng": "-84.51714"
  },
  {
    "country": "US",
    "name": "Buford",
    "lat": "34.12066",
    "lng": "-84.00435"
  },
  {
    "country": "US",
    "name": "Butler",
    "lat": "32.55709",
    "lng": "-84.23825"
  },
  {
    "country": "US",
    "name": "Byron",
    "lat": "32.65376",
    "lng": "-83.75963"
  },
  {
    "country": "US",
    "name": "Cairo",
    "lat": "30.87751",
    "lng": "-84.20214"
  },
  {
    "country": "US",
    "name": "Calhoun",
    "lat": "34.50259",
    "lng": "-84.95105"
  },
  {
    "country": "US",
    "name": "Camilla",
    "lat": "31.23129",
    "lng": "-84.21046"
  },
  {
    "country": "US",
    "name": "Canton",
    "lat": "34.23676",
    "lng": "-84.49076"
  },
  {
    "country": "US",
    "name": "Carnesville",
    "lat": "34.36983",
    "lng": "-83.23516"
  },
  {
    "country": "US",
    "name": "Carrollton",
    "lat": "33.58011",
    "lng": "-85.07661"
  },
  {
    "country": "US",
    "name": "Cartersville",
    "lat": "34.16533",
    "lng": "-84.80231"
  },
  {
    "country": "US",
    "name": "Cave Spring",
    "lat": "34.1076",
    "lng": "-85.33634"
  },
  {
    "country": "US",
    "name": "Cedartown",
    "lat": "34.01123",
    "lng": "-85.25593"
  },
  {
    "country": "US",
    "name": "Centerville",
    "lat": "32.63014",
    "lng": "-83.68963"
  },
  {
    "country": "US",
    "name": "Chamblee",
    "lat": "33.89205",
    "lng": "-84.29881"
  },
  {
    "country": "US",
    "name": "Chatsworth",
    "lat": "34.76591",
    "lng": "-84.76994"
  },
  {
    "country": "US",
    "name": "Chattanooga Valley",
    "lat": "34.93285",
    "lng": "-85.35551"
  },
  {
    "country": "US",
    "name": "Chester",
    "lat": "32.39378",
    "lng": "-83.15293"
  },
  {
    "country": "US",
    "name": "Chickamauga",
    "lat": "34.87119",
    "lng": "-85.29079"
  },
  {
    "country": "US",
    "name": "Clarkesville",
    "lat": "34.6126",
    "lng": "-83.52489"
  },
  {
    "country": "US",
    "name": "Clarkston",
    "lat": "33.80955",
    "lng": "-84.23964"
  },
  {
    "country": "US",
    "name": "Claxton",
    "lat": "32.16158",
    "lng": "-81.904"
  },
  {
    "country": "US",
    "name": "Clayton",
    "lat": "34.87815",
    "lng": "-83.40099"
  },
  {
    "country": "US",
    "name": "Cleveland",
    "lat": "34.59704",
    "lng": "-83.76324"
  },
  {
    "country": "US",
    "name": "Cochran",
    "lat": "32.38683",
    "lng": "-83.35461"
  },
  {
    "country": "US",
    "name": "College Park",
    "lat": "33.65344",
    "lng": "-84.44937"
  },
  {
    "country": "US",
    "name": "Colquitt",
    "lat": "31.17129",
    "lng": "-84.73325"
  },
  {
    "country": "US",
    "name": "Columbus",
    "lat": "32.46098",
    "lng": "-84.98771"
  },
  {
    "country": "US",
    "name": "Comer",
    "lat": "34.06372",
    "lng": "-83.12543"
  },
  {
    "country": "US",
    "name": "Commerce",
    "lat": "34.204",
    "lng": "-83.45711"
  },
  {
    "country": "US",
    "name": "Conley",
    "lat": "33.64483",
    "lng": "-84.32576"
  },
  {
    "country": "US",
    "name": "Conyers",
    "lat": "33.66761",
    "lng": "-84.01769"
  },
  {
    "country": "US",
    "name": "Cordele",
    "lat": "31.96351",
    "lng": "-83.78239"
  },
  {
    "country": "US",
    "name": "Cornelia",
    "lat": "34.51149",
    "lng": "-83.52712"
  },
  {
    "country": "US",
    "name": "Country Club Estates",
    "lat": "33.98928",
    "lng": "-83.4096"
  },
  {
    "country": "US",
    "name": "Country Club Estates",
    "lat": "31.21273",
    "lng": "-81.46427"
  },
  {
    "country": "US",
    "name": "Covington",
    "lat": "33.59678",
    "lng": "-83.86018"
  },
  {
    "country": "US",
    "name": "Crawfordville",
    "lat": "33.55402",
    "lng": "-82.89598"
  },
  {
    "country": "US",
    "name": "Cumming",
    "lat": "34.20732",
    "lng": "-84.14019"
  },
  {
    "country": "US",
    "name": "Cusseta",
    "lat": "32.30543",
    "lng": "-84.7727"
  },
  {
    "country": "US",
    "name": "Cuthbert",
    "lat": "31.77127",
    "lng": "-84.78937"
  },
  {
    "country": "US",
    "name": "Dacula",
    "lat": "33.98872",
    "lng": "-83.89796"
  },
  {
    "country": "US",
    "name": "Dahlonega",
    "lat": "34.53259",
    "lng": "-83.98491"
  },
  {
    "country": "US",
    "name": "Dalton",
    "lat": "34.7698",
    "lng": "-84.97022"
  },
  {
    "country": "US",
    "name": "Dallas",
    "lat": "33.92371",
    "lng": "-84.84077"
  },
  {
    "country": "US",
    "name": "Danielsville",
    "lat": "34.12428",
    "lng": "-83.22126"
  },
  {
    "country": "US",
    "name": "Darien",
    "lat": "31.37023",
    "lng": "-81.43399"
  },
  {
    "country": "US",
    "name": "Davisboro",
    "lat": "32.97904",
    "lng": "-82.60791"
  },
  {
    "country": "US",
    "name": "Dawson",
    "lat": "31.77382",
    "lng": "-84.448"
  },
  {
    "country": "US",
    "name": "Dawsonville",
    "lat": "34.42121",
    "lng": "-84.11908"
  },
  {
    "country": "US",
    "name": "Decatur",
    "lat": "33.77483",
    "lng": "-84.29631"
  },
  {
    "country": "US",
    "name": "Deenwood",
    "lat": "31.22201",
    "lng": "-82.38725"
  },
  {
    "country": "US",
    "name": "Demorest",
    "lat": "34.5651",
    "lng": "-83.54517"
  },
  {
    "country": "US",
    "name": "Dock Junction",
    "lat": "31.20245",
    "lng": "-81.51677"
  },
  {
    "country": "US",
    "name": "Donalsonville",
    "lat": "31.04046",
    "lng": "-84.87909"
  },
  {
    "country": "US",
    "name": "Doraville",
    "lat": "33.89816",
    "lng": "-84.28326"
  },
  {
    "country": "US",
    "name": "Douglas",
    "lat": "31.50881",
    "lng": "-82.84987"
  },
  {
    "country": "US",
    "name": "Douglasville",
    "lat": "33.7515",
    "lng": "-84.74771"
  },
  {
    "country": "US",
    "name": "Druid Hills",
    "lat": "33.78038",
    "lng": "-84.33604"
  },
  {
    "country": "US",
    "name": "Dublin",
    "lat": "32.54044",
    "lng": "-82.90375"
  },
  {
    "country": "US",
    "name": "Duluth",
    "lat": "34.00288",
    "lng": "-84.14464"
  },
  {
    "country": "US",
    "name": "Dunwoody",
    "lat": "33.94621",
    "lng": "-84.33465"
  },
  {
    "country": "US",
    "name": "East Dublin",
    "lat": "32.54822",
    "lng": "-82.87181"
  },
  {
    "country": "US",
    "name": "East Griffin",
    "lat": "33.24373",
    "lng": "-84.22881"
  },
  {
    "country": "US",
    "name": "East Point",
    "lat": "33.67955",
    "lng": "-84.43937"
  },
  {
    "country": "US",
    "name": "East Newnan",
    "lat": "33.35067",
    "lng": "-84.7766"
  },
  {
    "country": "US",
    "name": "Eastman",
    "lat": "32.19767",
    "lng": "-83.17765"
  },
  {
    "country": "US",
    "name": "Eatonton",
    "lat": "33.3268",
    "lng": "-83.3885"
  },
  {
    "country": "US",
    "name": "Edison",
    "lat": "31.55823",
    "lng": "-84.73825"
  },
  {
    "country": "US",
    "name": "Elberton",
    "lat": "34.11159",
    "lng": "-82.86863"
  },
  {
    "country": "US",
    "name": "Ellaville",
    "lat": "32.23821",
    "lng": "-84.30908"
  },
  {
    "country": "US",
    "name": "Ellijay",
    "lat": "34.69481",
    "lng": "-84.48215"
  },
  {
    "country": "US",
    "name": "Emerson",
    "lat": "34.12704",
    "lng": "-84.75549"
  },
  {
    "country": "US",
    "name": "Enigma",
    "lat": "31.41297",
    "lng": "-83.32905"
  },
  {
    "country": "US",
    "name": "Euharlee",
    "lat": "34.14482",
    "lng": "-84.933"
  },
  {
    "country": "US",
    "name": "Evans",
    "lat": "33.53375",
    "lng": "-82.13067"
  },
  {
    "country": "US",
    "name": "Experiment",
    "lat": "33.26539",
    "lng": "-84.28159"
  },
  {
    "country": "US",
    "name": "Fair Oaks",
    "lat": "33.91649",
    "lng": "-84.54465"
  },
  {
    "country": "US",
    "name": "Fairburn",
    "lat": "33.56706",
    "lng": "-84.58104"
  },
  {
    "country": "US",
    "name": "Fairview",
    "lat": "34.94563",
    "lng": "-85.2844"
  },
  {
    "country": "US",
    "name": "Fayetteville",
    "lat": "33.44873",
    "lng": "-84.45493"
  },
  {
    "country": "US",
    "name": "Fitzgerald",
    "lat": "31.71491",
    "lng": "-83.25265"
  },
  {
    "country": "US",
    "name": "Flowery Branch",
    "lat": "34.1851",
    "lng": "-83.92518"
  },
  {
    "country": "US",
    "name": "Folkston",
    "lat": "30.83095",
    "lng": "-82.01131"
  },
  {
    "country": "US",
    "name": "Forest Park",
    "lat": "33.62205",
    "lng": "-84.36909"
  },
  {
    "country": "US",
    "name": "Forsyth",
    "lat": "33.0343",
    "lng": "-83.93824"
  },
  {
    "country": "US",
    "name": "Fort Gaines",
    "lat": "31.60924",
    "lng": "-85.04933"
  },
  {
    "country": "US",
    "name": "Fort Oglethorpe",
    "lat": "34.94896",
    "lng": "-85.2569"
  },
  {
    "country": "US",
    "name": "Fort Valley",
    "lat": "32.55376",
    "lng": "-83.88741"
  },
  {
    "country": "US",
    "name": "Franklin",
    "lat": "33.27762",
    "lng": "-85.098"
  },
  {
    "country": "US",
    "name": "Franklin Springs",
    "lat": "34.28483",
    "lng": "-83.14432"
  },
  {
    "country": "US",
    "name": "Gainesville",
    "lat": "34.29788",
    "lng": "-83.82407"
  },
  {
    "country": "US",
    "name": "Garden City",
    "lat": "32.11437",
    "lng": "-81.154"
  },
  {
    "country": "US",
    "name": "Georgetown",
    "lat": "31.98326",
    "lng": "-81.22733"
  },
  {
    "country": "US",
    "name": "Georgetown",
    "lat": "31.88461",
    "lng": "-85.10743"
  },
  {
    "country": "US",
    "name": "Gibson",
    "lat": "33.23348",
    "lng": "-82.59541"
  },
  {
    "country": "US",
    "name": "Glennville",
    "lat": "31.93659",
    "lng": "-81.92845"
  },
  {
    "country": "US",
    "name": "Gordon",
    "lat": "32.88209",
    "lng": "-83.33238"
  },
  {
    "country": "US",
    "name": "Grantville",
    "lat": "33.23484",
    "lng": "-84.83577"
  },
  {
    "country": "US",
    "name": "Gray",
    "lat": "33.00958",
    "lng": "-83.53378"
  },
  {
    "country": "US",
    "name": "Grayson",
    "lat": "33.89427",
    "lng": "-83.95574"
  },
  {
    "country": "US",
    "name": "Greensboro",
    "lat": "33.57568",
    "lng": "-83.18238"
  },
  {
    "country": "US",
    "name": "Greenville",
    "lat": "33.02874",
    "lng": "-84.71298"
  },
  {
    "country": "US",
    "name": "Gresham Park",
    "lat": "33.70344",
    "lng": "-84.31437"
  },
  {
    "country": "US",
    "name": "Griffin",
    "lat": "33.24678",
    "lng": "-84.26409"
  },
  {
    "country": "US",
    "name": "Grovetown",
    "lat": "33.45042",
    "lng": "-82.19818"
  },
  {
    "country": "US",
    "name": "Gumlog",
    "lat": "34.49177",
    "lng": "-83.09654"
  },
  {
    "country": "US",
    "name": "Guyton",
    "lat": "32.3363",
    "lng": "-81.3915"
  },
  {
    "country": "US",
    "name": "Hahira",
    "lat": "30.99131",
    "lng": "-83.37266"
  },
  {
    "country": "US",
    "name": "Hamilton",
    "lat": "32.75791",
    "lng": "-84.87493"
  },
  {
    "country": "US",
    "name": "Hampton",
    "lat": "33.38706",
    "lng": "-84.28298"
  },
  {
    "country": "US",
    "name": "Hannahs Mill",
    "lat": "32.93291",
    "lng": "-84.34936"
  },
  {
    "country": "US",
    "name": "Hapeville",
    "lat": "33.66011",
    "lng": "-84.4102"
  },
  {
    "country": "US",
    "name": "Hardwick",
    "lat": "33.0682",
    "lng": "-83.22349"
  },
  {
    "country": "US",
    "name": "Harlem",
    "lat": "33.41458",
    "lng": "-82.31262"
  },
  {
    "country": "US",
    "name": "Hartwell",
    "lat": "34.35288",
    "lng": "-82.93209"
  },
  {
    "country": "US",
    "name": "Hawkinsville",
    "lat": "32.28377",
    "lng": "-83.47212"
  },
  {
    "country": "US",
    "name": "Hazlehurst",
    "lat": "31.86963",
    "lng": "-82.5943"
  },
  {
    "country": "US",
    "name": "Helena",
    "lat": "32.07379",
    "lng": "-82.91459"
  },
  {
    "country": "US",
    "name": "Hephzibah",
    "lat": "33.31403",
    "lng": "-82.09679"
  },
  {
    "country": "US",
    "name": "Hiawassee",
    "lat": "34.94926",
    "lng": "-83.75739"
  },
  {
    "country": "US",
    "name": "Hinesville",
    "lat": "31.84688",
    "lng": "-81.59595"
  },
  {
    "country": "US",
    "name": "Hiram",
    "lat": "33.87566",
    "lng": "-84.76216"
  },
  {
    "country": "US",
    "name": "Hogansville",
    "lat": "33.17318",
    "lng": "-84.91494"
  },
  {
    "country": "US",
    "name": "Holly Springs",
    "lat": "34.17399",
    "lng": "-84.50132"
  },
  {
    "country": "US",
    "name": "Homer",
    "lat": "34.33372",
    "lng": "-83.49905"
  },
  {
    "country": "US",
    "name": "Homerville",
    "lat": "31.0366",
    "lng": "-82.74708"
  },
  {
    "country": "US",
    "name": "Hoschton",
    "lat": "34.0965",
    "lng": "-83.76128"
  },
  {
    "country": "US",
    "name": "Indian Springs",
    "lat": "33.24262",
    "lng": "-83.92074"
  },
  {
    "country": "US",
    "name": "Indian Springs",
    "lat": "34.95785",
    "lng": "-85.1644"
  },
  {
    "country": "US",
    "name": "Irondale",
    "lat": "33.48067",
    "lng": "-84.35881"
  },
  {
    "country": "US",
    "name": "Irwinton",
    "lat": "32.81126",
    "lng": "-83.17265"
  },
  {
    "country": "US",
    "name": "Isle of Hope",
    "lat": "31.98188",
    "lng": "-81.06094"
  },
  {
    "country": "US",
    "name": "Jackson",
    "lat": "33.29457",
    "lng": "-83.96602"
  },
  {
    "country": "US",
    "name": "Jasper",
    "lat": "34.46787",
    "lng": "-84.42909"
  },
  {
    "country": "US",
    "name": "Jefferson",
    "lat": "34.11705",
    "lng": "-83.57239"
  },
  {
    "country": "US",
    "name": "Jefferson",
    "lat": "33.4493",
    "lng": "-83.31155"
  },
  {
    "country": "US",
    "name": "Jeffersonville",
    "lat": "32.68765",
    "lng": "-83.34656"
  },
  {
    "country": "US",
    "name": "Jesup",
    "lat": "31.60785",
    "lng": "-81.88634"
  },
  {
    "country": "US",
    "name": "Jonesboro",
    "lat": "33.5215",
    "lng": "-84.35381"
  },
  {
    "country": "US",
    "name": "Kennesaw",
    "lat": "34.02343",
    "lng": "-84.61549"
  },
  {
    "country": "US",
    "name": "Kingsland",
    "lat": "30.79996",
    "lng": "-81.68983"
  },
  {
    "country": "US",
    "name": "Knoxville",
    "lat": "32.72431",
    "lng": "-83.99769"
  },
  {
    "country": "US",
    "name": "LaGrange",
    "lat": "33.03929",
    "lng": "-85.03133"
  },
  {
    "country": "US",
    "name": "LaFayette",
    "lat": "34.7048",
    "lng": "-85.2819"
  },
  {
    "country": "US",
    "name": "Lake City",
    "lat": "33.6065",
    "lng": "-84.3352"
  },
  {
    "country": "US",
    "name": "Lakeland",
    "lat": "31.04104",
    "lng": "-83.07515"
  },
  {
    "country": "US",
    "name": "Lakeview",
    "lat": "34.97924",
    "lng": "-85.25884"
  },
  {
    "country": "US",
    "name": "Lakeview Estates",
    "lat": "33.70678",
    "lng": "-84.03158"
  },
  {
    "country": "US",
    "name": "Lavonia",
    "lat": "34.43594",
    "lng": "-83.10682"
  },
  {
    "country": "US",
    "name": "Lawrenceville",
    "lat": "33.95621",
    "lng": "-83.98796"
  },
  {
    "country": "US",
    "name": "Leesburg",
    "lat": "31.73212",
    "lng": "-84.17074"
  },
  {
    "country": "US",
    "name": "Lexington",
    "lat": "33.86984",
    "lng": "-83.11182"
  },
  {
    "country": "US",
    "name": "Lilburn",
    "lat": "33.8901",
    "lng": "-84.14297"
  },
  {
    "country": "US",
    "name": "Lincolnton",
    "lat": "33.79235",
    "lng": "-82.47902"
  },
  {
    "country": "US",
    "name": "Lindale",
    "lat": "34.18676",
    "lng": "-85.17467"
  },
  {
    "country": "US",
    "name": "Lithia Springs",
    "lat": "33.794",
    "lng": "-84.66049"
  },
  {
    "country": "US",
    "name": "Lithonia",
    "lat": "33.71233",
    "lng": "-84.10519"
  },
  {
    "country": "US",
    "name": "Locust Grove",
    "lat": "33.34595",
    "lng": "-84.10908"
  },
  {
    "country": "US",
    "name": "Loganville",
    "lat": "33.839",
    "lng": "-83.90074"
  },
  {
    "country": "US",
    "name": "Lookout Mountain",
    "lat": "34.97758",
    "lng": "-85.35774"
  },
  {
    "country": "US",
    "name": "Louisville",
    "lat": "33.00154",
    "lng": "-82.41124"
  },
  {
    "country": "US",
    "name": "Lovejoy",
    "lat": "33.43622",
    "lng": "-84.31437"
  },
  {
    "country": "US",
    "name": "Ludowici",
    "lat": "31.70799",
    "lng": "-81.74234"
  },
  {
    "country": "US",
    "name": "Lula",
    "lat": "34.3876",
    "lng": "-83.66629"
  },
  {
    "country": "US",
    "name": "Lumber City",
    "lat": "31.92935",
    "lng": "-82.67958"
  },
  {
    "country": "US",
    "name": "Lumpkin",
    "lat": "32.05099",
    "lng": "-84.79909"
  },
  {
    "country": "US",
    "name": "Lyons",
    "lat": "32.20435",
    "lng": "-82.32179"
  },
  {
    "country": "US",
    "name": "Mableton",
    "lat": "33.81872",
    "lng": "-84.58243"
  },
  {
    "country": "US",
    "name": "Macon",
    "lat": "32.84069",
    "lng": "-83.6324"
  },
  {
    "country": "US",
    "name": "Madison",
    "lat": "33.59568",
    "lng": "-83.46794"
  },
  {
    "country": "US",
    "name": "Manchester",
    "lat": "32.85985",
    "lng": "-84.61993"
  },
  {
    "country": "US",
    "name": "Marietta",
    "lat": "33.9526",
    "lng": "-84.54993"
  },
  {
    "country": "US",
    "name": "Marshallville",
    "lat": "32.45626",
    "lng": "-83.94019"
  },
  {
    "country": "US",
    "name": "Martinez",
    "lat": "33.51736",
    "lng": "-82.07567"
  },
  {
    "country": "US",
    "name": "Maysville",
    "lat": "34.25288",
    "lng": "-83.56155"
  },
  {
    "country": "US",
    "name": "McCaysville",
    "lat": "34.98619",
    "lng": "-84.37131"
  },
  {
    "country": "US",
    "name": "McDonough",
    "lat": "33.44734",
    "lng": "-84.14686"
  },
  {
    "country": "US",
    "name": "McRae",
    "lat": "32.06795",
    "lng": "-82.9007"
  },
  {
    "country": "US",
    "name": "Meigs",
    "lat": "31.07241",
    "lng": "-84.08907"
  },
  {
    "country": "US",
    "name": "Metter",
    "lat": "32.39712",
    "lng": "-82.06012"
  },
  {
    "country": "US",
    "name": "Midway",
    "lat": "31.80577",
    "lng": "-81.43066"
  },
  {
    "country": "US",
    "name": "Milledgeville",
    "lat": "33.08014",
    "lng": "-83.2321"
  },
  {
    "country": "US",
    "name": "Millen",
    "lat": "32.80405",
    "lng": "-81.94928"
  },
  {
    "country": "US",
    "name": "Monroe",
    "lat": "33.79484",
    "lng": "-83.71323"
  },
  {
    "country": "US",
    "name": "Montezuma",
    "lat": "32.30516",
    "lng": "-84.02741"
  },
  {
    "country": "US",
    "name": "Montgomery",
    "lat": "31.94049",
    "lng": "-81.12205"
  },
  {
    "country": "US",
    "name": "Monticello",
    "lat": "33.30485",
    "lng": "-83.68323"
  },
  {
    "country": "US",
    "name": "Morgan",
    "lat": "31.53767",
    "lng": "-84.59936"
  },
  {
    "country": "US",
    "name": "Morrow",
    "lat": "33.58317",
    "lng": "-84.33937"
  },
  {
    "country": "US",
    "name": "Mount Airy",
    "lat": "34.51871",
    "lng": "-83.50073"
  },
  {
    "country": "US",
    "name": "Moultrie",
    "lat": "31.17991",
    "lng": "-83.78906"
  },
  {
    "country": "US",
    "name": "Mount Vernon",
    "lat": "32.17851",
    "lng": "-82.59458"
  },
  {
    "country": "US",
    "name": "Mount Zion",
    "lat": "33.63428",
    "lng": "-85.18717"
  },
  {
    "country": "US",
    "name": "Mount Zion",
    "lat": "33.36125",
    "lng": "-83.00765"
  },
  {
    "country": "US",
    "name": "Mountain City",
    "lat": "34.91815",
    "lng": "-83.38544"
  },
  {
    "country": "US",
    "name": "Mountain Park",
    "lat": "33.84427",
    "lng": "-84.12936"
  },
  {
    "country": "US",
    "name": "Nahunta",
    "lat": "31.20439",
    "lng": "-81.98123"
  },
  {
    "country": "US",
    "name": "Nashville",
    "lat": "31.20742",
    "lng": "-83.25015"
  },
  {
    "country": "US",
    "name": "Nelson",
    "lat": "34.38204",
    "lng": "-84.37103"
  },
  {
    "country": "US",
    "name": "Newnan",
    "lat": "33.38067",
    "lng": "-84.79966"
  },
  {
    "country": "US",
    "name": "Newton",
    "lat": "31.31296",
    "lng": "-84.33574"
  },
  {
    "country": "US",
    "name": "Nicholls",
    "lat": "31.51742",
    "lng": "-82.63486"
  },
  {
    "country": "US",
    "name": "Nicholson",
    "lat": "34.114",
    "lng": "-83.43155"
  },
  {
    "country": "US",
    "name": "Norcross",
    "lat": "33.94121",
    "lng": "-84.21353"
  },
  {
    "country": "US",
    "name": "North Atlanta",
    "lat": "33.8651",
    "lng": "-84.33659"
  },
  {
    "country": "US",
    "name": "North Decatur",
    "lat": "33.79038",
    "lng": "-84.30603"
  },
  {
    "country": "US",
    "name": "North Druid Hills",
    "lat": "33.81677",
    "lng": "-84.31326"
  },
  {
    "country": "US",
    "name": "Oakwood",
    "lat": "34.2276",
    "lng": "-83.88435"
  },
  {
    "country": "US",
    "name": "Oakwood",
    "lat": "33.54817",
    "lng": "-83.97435"
  },
  {
    "country": "US",
    "name": "Ocilla",
    "lat": "31.59447",
    "lng": "-83.2513"
  },
  {
    "country": "US",
    "name": "Oglethorpe",
    "lat": "32.29377",
    "lng": "-84.06102"
  },
  {
    "country": "US",
    "name": "Omega",
    "lat": "31.34102",
    "lng": "-83.5935"
  },
  {
    "country": "US",
    "name": "Oxford",
    "lat": "33.619",
    "lng": "-83.86741"
  },
  {
    "country": "US",
    "name": "Palmetto",
    "lat": "33.51789",
    "lng": "-84.66965"
  },
  {
    "country": "US",
    "name": "Panthersville",
    "lat": "33.70733",
    "lng": "-84.27187"
  },
  {
    "country": "US",
    "name": "Peachtree City",
    "lat": "33.39678",
    "lng": "-84.59576"
  },
  {
    "country": "US",
    "name": "Peachtree Corners",
    "lat": "33.9701",
    "lng": "-84.22159"
  },
  {
    "country": "US",
    "name": "Pearson",
    "lat": "31.2977",
    "lng": "-82.85237"
  },
  {
    "country": "US",
    "name": "Pelham",
    "lat": "31.12802",
    "lng": "-84.15304"
  },
  {
    "country": "US",
    "name": "Pembroke",
    "lat": "32.13634",
    "lng": "-81.62348"
  },
  {
    "country": "US",
    "name": "Perry",
    "lat": "32.45821",
    "lng": "-83.73157"
  },
  {
    "country": "US",
    "name": "Pine Mountain",
    "lat": "33.67594",
    "lng": "-84.11492"
  },
  {
    "country": "US",
    "name": "Pine Mountain",
    "lat": "32.86485",
    "lng": "-84.8541"
  },
  {
    "country": "US",
    "name": "Pooler",
    "lat": "32.11548",
    "lng": "-81.24706"
  },
  {
    "country": "US",
    "name": "Port Wentworth",
    "lat": "32.14909",
    "lng": "-81.16317"
  },
  {
    "country": "US",
    "name": "Porterdale",
    "lat": "33.57511",
    "lng": "-83.8938"
  },
  {
    "country": "US",
    "name": "Powder Springs",
    "lat": "33.85955",
    "lng": "-84.68382"
  },
  {
    "country": "US",
    "name": "Preston",
    "lat": "32.06599",
    "lng": "-84.53742"
  },
  {
    "country": "US",
    "name": "Putney",
    "lat": "31.47018",
    "lng": "-84.11768"
  },
  {
    "country": "US",
    "name": "Quitman",
    "lat": "30.78492",
    "lng": "-83.55988"
  },
  {
    "country": "US",
    "name": "Raoul",
    "lat": "34.44954",
    "lng": "-83.59434"
  },
  {
    "country": "US",
    "name": "Ray City",
    "lat": "31.07464",
    "lng": "-83.19932"
  },
  {
    "country": "US",
    "name": "Redan",
    "lat": "33.74538",
    "lng": "-84.13158"
  },
  {
    "country": "US",
    "name": "Reed Creek",
    "lat": "34.44594",
    "lng": "-82.92487"
  },
  {
    "country": "US",
    "name": "Reidsville",
    "lat": "32.08686",
    "lng": "-82.1179"
  },
  {
    "country": "US",
    "name": "Remerton",
    "lat": "30.84409",
    "lng": "-83.31043"
  },
  {
    "country": "US",
    "name": "Reynolds",
    "lat": "32.55987",
    "lng": "-84.0963"
  },
  {
    "country": "US",
    "name": "Richland",
    "lat": "32.08793",
    "lng": "-84.66742"
  },
  {
    "country": "US",
    "name": "Richmond Hill",
    "lat": "31.93827",
    "lng": "-81.30344"
  },
  {
    "country": "US",
    "name": "Rincon",
    "lat": "32.29603",
    "lng": "-81.23539"
  },
  {
    "country": "US",
    "name": "Ringgold",
    "lat": "34.91591",
    "lng": "-85.10912"
  },
  {
    "country": "US",
    "name": "Riverdale",
    "lat": "33.57261",
    "lng": "-84.41326"
  },
  {
    "country": "US",
    "name": "Rochelle",
    "lat": "31.95101",
    "lng": "-83.45627"
  },
  {
    "country": "US",
    "name": "Rockmart",
    "lat": "34.0026",
    "lng": "-85.04161"
  },
  {
    "country": "US",
    "name": "Rome",
    "lat": "34.25704",
    "lng": "-85.16467"
  },
  {
    "country": "US",
    "name": "Roswell",
    "lat": "34.02316",
    "lng": "-84.36159"
  },
  {
    "country": "US",
    "name": "Rossville",
    "lat": "34.98313",
    "lng": "-85.28607"
  },
  {
    "country": "US",
    "name": "Royston",
    "lat": "34.28705",
    "lng": "-83.11015"
  },
  {
    "country": "US",
    "name": "Russell",
    "lat": "33.97872",
    "lng": "-83.70017"
  },
  {
    "country": "US",
    "name": "Rydal",
    "lat": "34.33537",
    "lng": "-84.71549"
  },
  {
    "country": "US",
    "name": "St. Marys",
    "lat": "30.73051",
    "lng": "-81.54649"
  },
  {
    "country": "US",
    "name": "Saint Simon Mills",
    "lat": "31.17079",
    "lng": "-81.40732"
  },
  {
    "country": "US",
    "name": "Saint Simons Island",
    "lat": "31.15051",
    "lng": "-81.36954"
  },
  {
    "country": "US",
    "name": "Sandersville",
    "lat": "32.98154",
    "lng": "-82.81014"
  },
  {
    "country": "US",
    "name": "Sandy Springs",
    "lat": "33.92427",
    "lng": "-84.37854"
  },
  {
    "country": "US",
    "name": "Sardis",
    "lat": "32.79652",
    "lng": "-84.63881"
  },
  {
    "country": "US",
    "name": "Savannah",
    "lat": "32.08354",
    "lng": "-81.09983"
  },
  {
    "country": "US",
    "name": "Scottdale",
    "lat": "33.78983",
    "lng": "-84.26409"
  },
  {
    "country": "US",
    "name": "Senoia",
    "lat": "33.30234",
    "lng": "-84.55382"
  },
  {
    "country": "US",
    "name": "Shannon",
    "lat": "34.33676",
    "lng": "-85.07134"
  },
  {
    "country": "US",
    "name": "Shannon",
    "lat": "33.40456",
    "lng": "-84.46826"
  },
  {
    "country": "US",
    "name": "Skidaway Island",
    "lat": "31.93494",
    "lng": "-81.04705"
  },
  {
    "country": "US",
    "name": "Smyrna",
    "lat": "33.88399",
    "lng": "-84.51438"
  },
  {
    "country": "US",
    "name": "Snellville",
    "lat": "33.85733",
    "lng": "-84.01991"
  },
  {
    "country": "US",
    "name": "Social Circle",
    "lat": "33.65623",
    "lng": "-83.71823"
  },
  {
    "country": "US",
    "name": "Soperton",
    "lat": "32.37712",
    "lng": "-82.59236"
  },
  {
    "country": "US",
    "name": "Sparks",
    "lat": "31.16686",
    "lng": "-83.43738"
  },
  {
    "country": "US",
    "name": "Sparks",
    "lat": "33.08793",
    "lng": "-82.73764"
  },
  {
    "country": "US",
    "name": "Sparta",
    "lat": "33.2757",
    "lng": "-82.97626"
  },
  {
    "country": "US",
    "name": "Springfield",
    "lat": "32.37241",
    "lng": "-81.3115"
  },
  {
    "country": "US",
    "name": "Statenville",
    "lat": "30.70327",
    "lng": "-83.02764"
  },
  {
    "country": "US",
    "name": "Statesboro",
    "lat": "32.44879",
    "lng": "-81.78317"
  },
  {
    "country": "US",
    "name": "Statham",
    "lat": "33.96511",
    "lng": "-83.59655"
  },
  {
    "country": "US",
    "name": "Stockbridge",
    "lat": "33.54428",
    "lng": "-84.23381"
  },
  {
    "country": "US",
    "name": "Stone Mountain",
    "lat": "33.80816",
    "lng": "-84.1702"
  },
  {
    "country": "US",
    "name": "Sugar Hill",
    "lat": "34.10649",
    "lng": "-84.03352"
  },
  {
    "country": "US",
    "name": "Summerville",
    "lat": "34.48064",
    "lng": "-85.34773"
  },
  {
    "country": "US",
    "name": "Sunnyside",
    "lat": "31.23938",
    "lng": "-82.34207"
  },
  {
    "country": "US",
    "name": "Suwanee",
    "lat": "34.05149",
    "lng": "-84.0713"
  },
  {
    "country": "US",
    "name": "Swainsboro",
    "lat": "32.59739",
    "lng": "-82.33374"
  },
  {
    "country": "US",
    "name": "Sylvania",
    "lat": "32.75044",
    "lng": "-81.63678"
  },
  {
    "country": "US",
    "name": "Sylvester",
    "lat": "31.53092",
    "lng": "-83.83693"
  },
  {
    "country": "US",
    "name": "Talbotton",
    "lat": "32.67764",
    "lng": "-84.53937"
  },
  {
    "country": "US",
    "name": "Tallapoosa",
    "lat": "33.74455",
    "lng": "-85.28801"
  },
  {
    "country": "US",
    "name": "Temple",
    "lat": "33.73705",
    "lng": "-85.03244"
  },
  {
    "country": "US",
    "name": "Tennille",
    "lat": "32.93599",
    "lng": "-82.81153"
  },
  {
    "country": "US",
    "name": "Thomasville",
    "lat": "30.83658",
    "lng": "-83.97878"
  },
  {
    "country": "US",
    "name": "Thomaston",
    "lat": "32.88819",
    "lng": "-84.32659"
  },
  {
    "country": "US",
    "name": "Thomson",
    "lat": "33.47069",
    "lng": "-82.50457"
  },
  {
    "country": "US",
    "name": "Thunderbolt",
    "lat": "32.03354",
    "lng": "-81.04983"
  },
  {
    "country": "US",
    "name": "Tifton",
    "lat": "31.45046",
    "lng": "-83.5085"
  },
  {
    "country": "US",
    "name": "Toccoa",
    "lat": "34.57732",
    "lng": "-83.33239"
  },
  {
    "country": "US",
    "name": "Trenton",
    "lat": "34.87202",
    "lng": "-85.50913"
  },
  {
    "country": "US",
    "name": "Trion",
    "lat": "34.54397",
    "lng": "-85.31051"
  },
  {
    "country": "US",
    "name": "Tucker",
    "lat": "33.85455",
    "lng": "-84.21714"
  },
  {
    "country": "US",
    "name": "Twin City",
    "lat": "32.58294",
    "lng": "-82.15512"
  },
  {
    "country": "US",
    "name": "Tybee Island",
    "lat": "32.00022",
    "lng": "-80.84567"
  },
  {
    "country": "US",
    "name": "Tyrone",
    "lat": "33.47123",
    "lng": "-84.59715"
  },
  {
    "country": "US",
    "name": "Unadilla",
    "lat": "32.26155",
    "lng": "-83.73657"
  },
  {
    "country": "US",
    "name": "Union City",
    "lat": "33.58706",
    "lng": "-84.54243"
  },
  {
    "country": "US",
    "name": "Union Point",
    "lat": "33.61568",
    "lng": "-83.0746"
  },
  {
    "country": "US",
    "name": "Unionville",
    "lat": "31.43491",
    "lng": "-83.50961"
  },
  {
    "country": "US",
    "name": "Valdosta",
    "lat": "30.83334",
    "lng": "-83.28032"
  },
  {
    "country": "US",
    "name": "Varnell",
    "lat": "34.90119",
    "lng": "-84.97383"
  },
  {
    "country": "US",
    "name": "Vidalia",
    "lat": "32.21769",
    "lng": "-82.41346"
  },
  {
    "country": "US",
    "name": "Vienna",
    "lat": "32.09156",
    "lng": "-83.79545"
  },
  {
    "country": "US",
    "name": "Villa Rica",
    "lat": "33.73205",
    "lng": "-84.91911"
  },
  {
    "country": "US",
    "name": "Vinings",
    "lat": "33.86483",
    "lng": "-84.46437"
  },
  {
    "country": "US",
    "name": "Wadley",
    "lat": "32.86682",
    "lng": "-82.40402"
  },
  {
    "country": "US",
    "name": "Walnut Grove",
    "lat": "33.74261",
    "lng": "-83.8524"
  },
  {
    "country": "US",
    "name": "Walthourville",
    "lat": "31.7741",
    "lng": "-81.63261"
  },
  {
    "country": "US",
    "name": "Warner Robins",
    "lat": "32.61574",
    "lng": "-83.62664"
  },
  {
    "country": "US",
    "name": "Warrenton",
    "lat": "33.40708",
    "lng": "-82.66208"
  },
  {
    "country": "US",
    "name": "Washington",
    "lat": "33.73679",
    "lng": "-82.73931"
  },
  {
    "country": "US",
    "name": "Watkinsville",
    "lat": "33.8629",
    "lng": "-83.40877"
  },
  {
    "country": "US",
    "name": "Waycross",
    "lat": "31.21368",
    "lng": "-82.3557"
  },
  {
    "country": "US",
    "name": "Waynesboro",
    "lat": "33.08987",
    "lng": "-82.01567"
  },
  {
    "country": "US",
    "name": "West Point",
    "lat": "32.87791",
    "lng": "-85.18327"
  },
  {
    "country": "US",
    "name": "West Point",
    "lat": "32.79347",
    "lng": "-83.80741"
  },
  {
    "country": "US",
    "name": "Whitemarsh Island",
    "lat": "32.02882",
    "lng": "-81.01678"
  },
  {
    "country": "US",
    "name": "Willacoochee",
    "lat": "31.34076",
    "lng": "-83.04598"
  },
  {
    "country": "US",
    "name": "Wilmington Island",
    "lat": "32.00355",
    "lng": "-80.97372"
  },
  {
    "country": "US",
    "name": "Winder",
    "lat": "33.99261",
    "lng": "-83.72017"
  },
  {
    "country": "US",
    "name": "Winterville",
    "lat": "33.96706",
    "lng": "-83.27821"
  },
  {
    "country": "US",
    "name": "Woodbine",
    "lat": "30.96396",
    "lng": "-81.72416"
  },
  {
    "country": "US",
    "name": "Woodstock",
    "lat": "34.10149",
    "lng": "-84.51938"
  },
  {
    "country": "US",
    "name": "Wrens",
    "lat": "33.20765",
    "lng": "-82.39179"
  },
  {
    "country": "US",
    "name": "Wrightsville",
    "lat": "32.72933",
    "lng": "-82.71986"
  },
  {
    "country": "US",
    "name": "Young Harris",
    "lat": "34.93315",
    "lng": "-83.84712"
  },
  {
    "country": "US",
    "name": "Zebulon",
    "lat": "33.10235",
    "lng": "-84.3427"
  },
  {
    "country": "US",
    "name": "Albers",
    "lat": "38.54338",
    "lng": "-89.61231"
  },
  {
    "country": "US",
    "name": "Albion",
    "lat": "38.37755",
    "lng": "-88.05615"
  },
  {
    "country": "US",
    "name": "Alorton",
    "lat": "38.58977",
    "lng": "-90.12011"
  },
  {
    "country": "US",
    "name": "Altamont",
    "lat": "39.06199",
    "lng": "-88.74811"
  },
  {
    "country": "US",
    "name": "Alton",
    "lat": "38.8906",
    "lng": "-90.18428"
  },
  {
    "country": "US",
    "name": "Anna",
    "lat": "37.46033",
    "lng": "-89.24703"
  },
  {
    "country": "US",
    "name": "Arcola",
    "lat": "39.68476",
    "lng": "-88.30644"
  },
  {
    "country": "US",
    "name": "Arthur",
    "lat": "39.71476",
    "lng": "-88.47228"
  },
  {
    "country": "US",
    "name": "Ashland",
    "lat": "39.88783",
    "lng": "-90.00789"
  },
  {
    "country": "US",
    "name": "Assumption",
    "lat": "39.52032",
    "lng": "-89.04897"
  },
  {
    "country": "US",
    "name": "Athens",
    "lat": "39.96088",
    "lng": "-89.72399"
  },
  {
    "country": "US",
    "name": "Atwood",
    "lat": "39.79948",
    "lng": "-88.46228"
  },
  {
    "country": "US",
    "name": "Auburn",
    "lat": "39.59172",
    "lng": "-89.74649"
  },
  {
    "country": "US",
    "name": "Aviston",
    "lat": "38.60672",
    "lng": "-89.60759"
  },
  {
    "country": "US",
    "name": "Barry",
    "lat": "39.69421",
    "lng": "-91.03902"
  },
  {
    "country": "US",
    "name": "Beckemeyer",
    "lat": "38.6056",
    "lng": "-89.43592"
  },
  {
    "country": "US",
    "name": "Bement",
    "lat": "39.92198",
    "lng": "-88.57201"
  },
  {
    "country": "US",
    "name": "Benld",
    "lat": "39.09282",
    "lng": "-89.80398"
  },
  {
    "country": "US",
    "name": "Benton",
    "lat": "37.99672",
    "lng": "-88.92007"
  },
  {
    "country": "US",
    "name": "Bethalto",
    "lat": "38.90921",
    "lng": "-90.04066"
  },
  {
    "country": "US",
    "name": "Bethany",
    "lat": "39.64559",
    "lng": "-88.73813"
  },
  {
    "country": "US",
    "name": "Belleville",
    "lat": "38.52005",
    "lng": "-89.98399"
  },
  {
    "country": "US",
    "name": "Blue Mound",
    "lat": "39.70115",
    "lng": "-89.12314"
  },
  {
    "country": "US",
    "name": "Breese",
    "lat": "38.6106",
    "lng": "-89.52703"
  },
  {
    "country": "US",
    "name": "Bridgeport",
    "lat": "38.70588",
    "lng": "-87.76003"
  },
  {
    "country": "US",
    "name": "Brighton",
    "lat": "39.03977",
    "lng": "-90.14066"
  },
  {
    "country": "US",
    "name": "Bunker Hill",
    "lat": "39.04282",
    "lng": "-89.95177"
  },
  {
    "country": "US",
    "name": "Cahokia",
    "lat": "38.57088",
    "lng": "-90.19011"
  },
  {
    "country": "US",
    "name": "Cairo",
    "lat": "37.00533",
    "lng": "-89.17646"
  },
  {
    "country": "US",
    "name": "Cambria",
    "lat": "37.78144",
    "lng": "-89.11925"
  },
  {
    "country": "US",
    "name": "Carbondale",
    "lat": "37.72727",
    "lng": "-89.21675"
  },
  {
    "country": "US",
    "name": "Carlinville",
    "lat": "39.27977",
    "lng": "-89.88177"
  },
  {
    "country": "US",
    "name": "Carlyle",
    "lat": "38.61033",
    "lng": "-89.37258"
  },
  {
    "country": "US",
    "name": "Carmi",
    "lat": "38.09088",
    "lng": "-88.15865"
  },
  {
    "country": "US",
    "name": "Carrier Mills",
    "lat": "37.68422",
    "lng": "-88.63283"
  },
  {
    "country": "US",
    "name": "Carrollton",
    "lat": "39.30227",
    "lng": "-90.40706"
  },
  {
    "country": "US",
    "name": "Carterville",
    "lat": "37.76005",
    "lng": "-89.0773"
  },
  {
    "country": "US",
    "name": "Casey",
    "lat": "39.2992",
    "lng": "-87.99253"
  },
  {
    "country": "US",
    "name": "Caseyville",
    "lat": "38.63672",
    "lng": "-90.02566"
  },
  {
    "country": "US",
    "name": "Central City",
    "lat": "38.54894",
    "lng": "-89.12701"
  },
  {
    "country": "US",
    "name": "Centralia",
    "lat": "38.52505",
    "lng": "-89.1334"
  },
  {
    "country": "US",
    "name": "Centreville",
    "lat": "38.58338",
    "lng": "-90.12511"
  },
  {
    "country": "US",
    "name": "Cerro Gordo",
    "lat": "39.89059",
    "lng": "-88.72813"
  },
  {
    "country": "US",
    "name": "Charleston",
    "lat": "39.49615",
    "lng": "-88.17615"
  },
  {
    "country": "US",
    "name": "Chatham",
    "lat": "39.67616",
    "lng": "-89.70454"
  },
  {
    "country": "US",
    "name": "Chester",
    "lat": "37.91366",
    "lng": "-89.82205"
  },
  {
    "country": "US",
    "name": "Chrisman",
    "lat": "39.80365",
    "lng": "-87.67364"
  },
  {
    "country": "US",
    "name": "Christopher",
    "lat": "37.97255",
    "lng": "-89.05341"
  },
  {
    "country": "US",
    "name": "Cobden",
    "lat": "37.53144",
    "lng": "-89.25342"
  },
  {
    "country": "US",
    "name": "Collinsville",
    "lat": "38.67033",
    "lng": "-89.98455"
  },
  {
    "country": "US",
    "name": "Columbia",
    "lat": "38.44366",
    "lng": "-90.20122"
  },
  {
    "country": "US",
    "name": "Crainville",
    "lat": "37.75199",
    "lng": "-89.06785"
  },
  {
    "country": "US",
    "name": "De Soto",
    "lat": "37.81755",
    "lng": "-89.22786"
  },
  {
    "country": "US",
    "name": "Decatur",
    "lat": "39.84031",
    "lng": "-88.9548"
  },
  {
    "country": "US",
    "name": "Divernon",
    "lat": "39.56561",
    "lng": "-89.65732"
  },
  {
    "country": "US",
    "name": "Du Quoin",
    "lat": "38.01144",
    "lng": "-89.23619"
  },
  {
    "country": "US",
    "name": "Dupo",
    "lat": "38.51616",
    "lng": "-90.21039"
  },
  {
    "country": "US",
    "name": "East Alton",
    "lat": "38.88033",
    "lng": "-90.11122"
  },
  {
    "country": "US",
    "name": "East Saint Louis",
    "lat": "38.6245",
    "lng": "-90.15094"
  },
  {
    "country": "US",
    "name": "Edinburg",
    "lat": "39.65727",
    "lng": "-89.38953"
  },
  {
    "country": "US",
    "name": "Edwardsville",
    "lat": "38.81144",
    "lng": "-89.95316"
  },
  {
    "country": "US",
    "name": "Effingham",
    "lat": "39.12004",
    "lng": "-88.54338"
  },
  {
    "country": "US",
    "name": "Eldorado",
    "lat": "37.81366",
    "lng": "-88.4381"
  },
  {
    "country": "US",
    "name": "Elizabethtown",
    "lat": "37.44588",
    "lng": "-88.30504"
  },
  {
    "country": "US",
    "name": "Energy",
    "lat": "37.77394",
    "lng": "-89.02646"
  },
  {
    "country": "US",
    "name": "Fairfield",
    "lat": "38.37894",
    "lng": "-88.35977"
  },
  {
    "country": "US",
    "name": "Fairmont City",
    "lat": "38.64977",
    "lng": "-90.09316"
  },
  {
    "country": "US",
    "name": "Fairview Heights",
    "lat": "38.58894",
    "lng": "-89.99038"
  },
  {
    "country": "US",
    "name": "Flora",
    "lat": "38.66894",
    "lng": "-88.4856"
  },
  {
    "country": "US",
    "name": "Forsyth",
    "lat": "39.93254",
    "lng": "-88.95119"
  },
  {
    "country": "US",
    "name": "Freeburg",
    "lat": "38.42755",
    "lng": "-89.91371"
  },
  {
    "country": "US",
    "name": "Georgetown",
    "lat": "39.97531",
    "lng": "-87.63585"
  },
  {
    "country": "US",
    "name": "Germantown",
    "lat": "38.55366",
    "lng": "-89.53842"
  },
  {
    "country": "US",
    "name": "Gillespie",
    "lat": "39.12977",
    "lng": "-89.81954"
  },
  {
    "country": "US",
    "name": "Glen Carbon",
    "lat": "38.74838",
    "lng": "-89.98316"
  },
  {
    "country": "US",
    "name": "Girard",
    "lat": "39.44644",
    "lng": "-89.78093"
  },
  {
    "country": "US",
    "name": "Godfrey",
    "lat": "38.9556",
    "lng": "-90.18678"
  },
  {
    "country": "US",
    "name": "Golconda",
    "lat": "37.36727",
    "lng": "-88.48643"
  },
  {
    "country": "US",
    "name": "Goreville",
    "lat": "37.5545",
    "lng": "-88.97229"
  },
  {
    "country": "US",
    "name": "Grandview",
    "lat": "39.81644",
    "lng": "-89.61871"
  },
  {
    "country": "US",
    "name": "Granite City",
    "lat": "38.70144",
    "lng": "-90.14872"
  },
  {
    "country": "US",
    "name": "Grayville",
    "lat": "38.25755",
    "lng": "-87.99364"
  },
  {
    "country": "US",
    "name": "Greenfield",
    "lat": "39.34366",
    "lng": "-90.21261"
  },
  {
    "country": "US",
    "name": "Greenup",
    "lat": "39.24782",
    "lng": "-88.16337"
  },
  {
    "country": "US",
    "name": "Greenville",
    "lat": "38.89227",
    "lng": "-89.41314"
  },
  {
    "country": "US",
    "name": "Griggsville",
    "lat": "39.70894",
    "lng": "-90.72457"
  },
  {
    "country": "US",
    "name": "Hardin",
    "lat": "39.15671",
    "lng": "-90.6179"
  },
  {
    "country": "US",
    "name": "Harrisburg",
    "lat": "37.73838",
    "lng": "-88.54061"
  },
  {
    "country": "US",
    "name": "Harristown",
    "lat": "39.85393",
    "lng": "-89.08397"
  },
  {
    "country": "US",
    "name": "Hartford",
    "lat": "38.83338",
    "lng": "-90.09594"
  },
  {
    "country": "US",
    "name": "Herrin",
    "lat": "37.80311",
    "lng": "-89.02757"
  },
  {
    "country": "US",
    "name": "Highland",
    "lat": "38.73949",
    "lng": "-89.6712"
  },
  {
    "country": "US",
    "name": "Hillsboro",
    "lat": "39.16128",
    "lng": "-89.4954"
  },
  {
    "country": "US",
    "name": "Holiday Shores",
    "lat": "38.92199",
    "lng": "-89.94066"
  },
  {
    "country": "US",
    "name": "Ina",
    "lat": "38.15116",
    "lng": "-88.90396"
  },
  {
    "country": "US",
    "name": "Jacksonville",
    "lat": "39.73394",
    "lng": "-90.22901"
  },
  {
    "country": "US",
    "name": "Jerome",
    "lat": "39.76755",
    "lng": "-89.68066"
  },
  {
    "country": "US",
    "name": "Jerseyville",
    "lat": "39.12005",
    "lng": "-90.32845"
  },
  {
    "country": "US",
    "name": "Johnston City",
    "lat": "37.82061",
    "lng": "-88.92757"
  },
  {
    "country": "US",
    "name": "Jonesboro",
    "lat": "37.45172",
    "lng": "-89.26814"
  },
  {
    "country": "US",
    "name": "Kincaid",
    "lat": "39.58866",
    "lng": "-89.41454"
  },
  {
    "country": "US",
    "name": "Lawrenceville",
    "lat": "38.72921",
    "lng": "-87.68169"
  },
  {
    "country": "US",
    "name": "Lebanon",
    "lat": "38.60394",
    "lng": "-89.80732"
  },
  {
    "country": "US",
    "name": "Leland Grove",
    "lat": "39.777",
    "lng": "-89.67927"
  },
  {
    "country": "US",
    "name": "Litchfield",
    "lat": "39.17533",
    "lng": "-89.65426"
  },
  {
    "country": "US",
    "name": "Long Creek",
    "lat": "39.81198",
    "lng": "-88.84757"
  },
  {
    "country": "US",
    "name": "Louisville",
    "lat": "38.77227",
    "lng": "-88.50255"
  },
  {
    "country": "US",
    "name": "Lovington",
    "lat": "39.71559",
    "lng": "-88.63256"
  },
  {
    "country": "US",
    "name": "Macon",
    "lat": "39.71282",
    "lng": "-88.99702"
  },
  {
    "country": "US",
    "name": "Madison",
    "lat": "38.68255",
    "lng": "-90.15705"
  },
  {
    "country": "US",
    "name": "Marion",
    "lat": "37.73061",
    "lng": "-88.93313"
  },
  {
    "country": "US",
    "name": "Marissa",
    "lat": "38.25005",
    "lng": "-89.7501"
  },
  {
    "country": "US",
    "name": "Marshall",
    "lat": "39.39143",
    "lng": "-87.69364"
  },
  {
    "country": "US",
    "name": "Martinsville",
    "lat": "39.33559",
    "lng": "-87.88198"
  },
  {
    "country": "US",
    "name": "Maryville",
    "lat": "38.72366",
    "lng": "-89.95593"
  },
  {
    "country": "US",
    "name": "Mascoutah",
    "lat": "38.49033",
    "lng": "-89.79315"
  },
  {
    "country": "US",
    "name": "Mattoon",
    "lat": "39.48309",
    "lng": "-88.37283"
  },
  {
    "country": "US",
    "name": "McLeansboro",
    "lat": "38.09338",
    "lng": "-88.53561"
  },
  {
    "country": "US",
    "name": "Meredosia",
    "lat": "39.83116",
    "lng": "-90.55957"
  },
  {
    "country": "US",
    "name": "Metropolis",
    "lat": "37.15117",
    "lng": "-88.732"
  },
  {
    "country": "US",
    "name": "Millstadt",
    "lat": "38.46144",
    "lng": "-90.09178"
  },
  {
    "country": "US",
    "name": "Mitchell",
    "lat": "38.76199",
    "lng": "-90.08538"
  },
  {
    "country": "US",
    "name": "Morrisonville",
    "lat": "39.42005",
    "lng": "-89.45565"
  },
  {
    "country": "US",
    "name": "Mound City",
    "lat": "37.08533",
    "lng": "-89.16257"
  },
  {
    "country": "US",
    "name": "Mount Carmel",
    "lat": "38.41088",
    "lng": "-87.76142"
  },
  {
    "country": "US",
    "name": "Mount Olive",
    "lat": "39.07227",
    "lng": "-89.72731"
  },
  {
    "country": "US",
    "name": "Mount Sterling",
    "lat": "39.98727",
    "lng": "-90.76346"
  },
  {
    "country": "US",
    "name": "Mount Vernon",
    "lat": "38.31727",
    "lng": "-88.90312"
  },
  {
    "country": "US",
    "name": "Mount Zion",
    "lat": "39.77143",
    "lng": "-88.87424"
  },
  {
    "country": "US",
    "name": "Moweaqua",
    "lat": "39.62476",
    "lng": "-89.01897"
  },
  {
    "country": "US",
    "name": "Murphysboro",
    "lat": "37.7645",
    "lng": "-89.33509"
  },
  {
    "country": "US",
    "name": "Nashville",
    "lat": "38.34366",
    "lng": "-89.38064"
  },
  {
    "country": "US",
    "name": "Neoga",
    "lat": "39.31948",
    "lng": "-88.45283"
  },
  {
    "country": "US",
    "name": "New Athens",
    "lat": "38.32644",
    "lng": "-89.87705"
  },
  {
    "country": "US",
    "name": "New Baden",
    "lat": "38.53505",
    "lng": "-89.70065"
  },
  {
    "country": "US",
    "name": "New Berlin",
    "lat": "39.72533",
    "lng": "-89.91066"
  },
  {
    "country": "US",
    "name": "Nokomis",
    "lat": "39.30116",
    "lng": "-89.28508"
  },
  {
    "country": "US",
    "name": "Norris City",
    "lat": "37.98116",
    "lng": "-88.32921"
  },
  {
    "country": "US",
    "name": "O'Fallon",
    "lat": "38.59227",
    "lng": "-89.91121"
  },
  {
    "country": "US",
    "name": "Oblong",
    "lat": "39.00199",
    "lng": "-87.90892"
  },
  {
    "country": "US",
    "name": "Odin",
    "lat": "38.61727",
    "lng": "-89.05229"
  },
  {
    "country": "US",
    "name": "Okawville",
    "lat": "38.43422",
    "lng": "-89.55037"
  },
  {
    "country": "US",
    "name": "Olney",
    "lat": "38.73088",
    "lng": "-88.08532"
  },
  {
    "country": "US",
    "name": "Palestine",
    "lat": "39.00365",
    "lng": "-87.6128"
  },
  {
    "country": "US",
    "name": "Pana",
    "lat": "39.38893",
    "lng": "-89.08008"
  },
  {
    "country": "US",
    "name": "Paris",
    "lat": "39.61115",
    "lng": "-87.69614"
  },
  {
    "country": "US",
    "name": "Pawnee",
    "lat": "39.59172",
    "lng": "-89.58037"
  },
  {
    "country": "US",
    "name": "Payson",
    "lat": "39.81699",
    "lng": "-91.24237"
  },
  {
    "country": "US",
    "name": "Pinckneyville",
    "lat": "38.08033",
    "lng": "-89.38203"
  },
  {
    "country": "US",
    "name": "Pittsfield",
    "lat": "39.60783",
    "lng": "-90.80513"
  },
  {
    "country": "US",
    "name": "Pontoon Beach",
    "lat": "38.73172",
    "lng": "-90.08038"
  },
  {
    "country": "US",
    "name": "Quincy",
    "lat": "39.9356",
    "lng": "-91.40987"
  },
  {
    "country": "US",
    "name": "Ramsey",
    "lat": "39.14449",
    "lng": "-89.10868"
  },
  {
    "country": "US",
    "name": "Red Bud",
    "lat": "38.21172",
    "lng": "-89.99427"
  },
  {
    "country": "US",
    "name": "Riverton",
    "lat": "39.84422",
    "lng": "-89.53954"
  },
  {
    "country": "US",
    "name": "Robinson",
    "lat": "39.00532",
    "lng": "-87.73919"
  },
  {
    "country": "US",
    "name": "Rochester",
    "lat": "39.74949",
    "lng": "-89.53176"
  },
  {
    "country": "US",
    "name": "Roodhouse",
    "lat": "39.48394",
    "lng": "-90.37151"
  },
  {
    "country": "US",
    "name": "Rosewood Heights",
    "lat": "38.88783",
    "lng": "-90.08483"
  },
  {
    "country": "US",
    "name": "Rosiclare",
    "lat": "37.42366",
    "lng": "-88.34615"
  },
  {
    "country": "US",
    "name": "Roxana",
    "lat": "38.84838",
    "lng": "-90.07622"
  },
  {
    "country": "US",
    "name": "Royalton",
    "lat": "37.87699",
    "lng": "-89.11452"
  },
  {
    "country": "US",
    "name": "Saint Elmo",
    "lat": "39.02727",
    "lng": "-88.84811"
  },
  {
    "country": "US",
    "name": "Saint Jacob",
    "lat": "38.71394",
    "lng": "-89.76815"
  },
  {
    "country": "US",
    "name": "Salem",
    "lat": "38.62699",
    "lng": "-88.94562"
  },
  {
    "country": "US",
    "name": "Sandoval",
    "lat": "38.6156",
    "lng": "-89.11423"
  },
  {
    "country": "US",
    "name": "Sesser",
    "lat": "38.09172",
    "lng": "-89.05035"
  },
  {
    "country": "US",
    "name": "Shawneetown",
    "lat": "37.7131",
    "lng": "-88.1867"
  },
  {
    "country": "US",
    "name": "Shelbyville",
    "lat": "39.40643",
    "lng": "-88.79007"
  },
  {
    "country": "US",
    "name": "Sherman",
    "lat": "39.89366",
    "lng": "-89.60482"
  },
  {
    "country": "US",
    "name": "Shiloh",
    "lat": "38.56144",
    "lng": "-89.89732"
  },
  {
    "country": "US",
    "name": "Smithton",
    "lat": "38.40866",
    "lng": "-89.99205"
  },
  {
    "country": "US",
    "name": "South Jacksonville",
    "lat": "39.70866",
    "lng": "-90.22818"
  },
  {
    "country": "US",
    "name": "South Roxana",
    "lat": "38.82949",
    "lng": "-90.06288"
  },
  {
    "country": "US",
    "name": "Southern View",
    "lat": "39.75727",
    "lng": "-89.65371"
  },
  {
    "country": "US",
    "name": "Sparta",
    "lat": "38.12311",
    "lng": "-89.70177"
  },
  {
    "country": "US",
    "name": "Springfield",
    "lat": "39.80172",
    "lng": "-89.64371"
  },
  {
    "country": "US",
    "name": "Staunton",
    "lat": "39.01227",
    "lng": "-89.79121"
  },
  {
    "country": "US",
    "name": "Steeleville",
    "lat": "38.00727",
    "lng": "-89.65843"
  },
  {
    "country": "US",
    "name": "Sullivan",
    "lat": "39.59948",
    "lng": "-88.60784"
  },
  {
    "country": "US",
    "name": "Sumner",
    "lat": "38.71699",
    "lng": "-87.86142"
  },
  {
    "country": "US",
    "name": "Swansea",
    "lat": "38.53394",
    "lng": "-89.98899"
  },
  {
    "country": "US",
    "name": "Taylorville",
    "lat": "39.54894",
    "lng": "-89.29453"
  },
  {
    "country": "US",
    "name": "Teutopolis",
    "lat": "39.1331",
    "lng": "-88.47199"
  },
  {
    "country": "US",
    "name": "Toledo",
    "lat": "39.27365",
    "lng": "-88.24365"
  },
  {
    "country": "US",
    "name": "Tolono",
    "lat": "39.98614",
    "lng": "-88.25894"
  },
  {
    "country": "US",
    "name": "Trenton",
    "lat": "38.6056",
    "lng": "-89.68204"
  },
  {
    "country": "US",
    "name": "Troy",
    "lat": "38.72921",
    "lng": "-89.88315"
  },
  {
    "country": "US",
    "name": "Tuscola",
    "lat": "39.7992",
    "lng": "-88.2831"
  },
  {
    "country": "US",
    "name": "Upper Alton",
    "lat": "38.91144",
    "lng": "-90.15066"
  },
  {
    "country": "US",
    "name": "Valmeyer",
    "lat": "38.30561",
    "lng": "-90.27651"
  },
  {
    "country": "US",
    "name": "Vandalia",
    "lat": "38.9606",
    "lng": "-89.09368"
  },
  {
    "country": "US",
    "name": "Venice",
    "lat": "38.67227",
    "lng": "-90.16983"
  },
  {
    "country": "US",
    "name": "Vienna",
    "lat": "37.41533",
    "lng": "-88.89784"
  },
  {
    "country": "US",
    "name": "Villa Grove",
    "lat": "39.86281",
    "lng": "-88.16227"
  },
  {
    "country": "US",
    "name": "Virden",
    "lat": "39.50089",
    "lng": "-89.76787"
  },
  {
    "country": "US",
    "name": "Virginia",
    "lat": "39.95116",
    "lng": "-90.21234"
  },
  {
    "country": "US",
    "name": "Wamac",
    "lat": "38.50894",
    "lng": "-89.14063"
  },
  {
    "country": "US",
    "name": "Warrensburg",
    "lat": "39.93282",
    "lng": "-89.06203"
  },
  {
    "country": "US",
    "name": "Washington Park",
    "lat": "38.63505",
    "lng": "-90.09289"
  },
  {
    "country": "US",
    "name": "Waterloo",
    "lat": "38.33589",
    "lng": "-90.14983"
  },
  {
    "country": "US",
    "name": "Wayne City",
    "lat": "38.34533",
    "lng": "-88.58783"
  },
  {
    "country": "US",
    "name": "Waverly",
    "lat": "39.59172",
    "lng": "-89.95288"
  },
  {
    "country": "US",
    "name": "West Frankfort",
    "lat": "37.89783",
    "lng": "-88.93146"
  },
  {
    "country": "US",
    "name": "White Hall",
    "lat": "39.43699",
    "lng": "-90.40318"
  },
  {
    "country": "US",
    "name": "Williamsville",
    "lat": "39.95422",
    "lng": "-89.54871"
  },
  {
    "country": "US",
    "name": "Winchester",
    "lat": "39.62977",
    "lng": "-90.45624"
  },
  {
    "country": "US",
    "name": "Windsor",
    "lat": "39.44087",
    "lng": "-88.59478"
  },
  {
    "country": "US",
    "name": "Wood River",
    "lat": "38.86116",
    "lng": "-90.09761"
  },
  {
    "country": "US",
    "name": "Worden",
    "lat": "38.93144",
    "lng": "-89.83899"
  },
  {
    "country": "US",
    "name": "Zeigler",
    "lat": "37.89949",
    "lng": "-89.05202"
  },
  {
    "country": "US",
    "name": "Austin",
    "lat": "38.75839",
    "lng": "-85.80803"
  },
  {
    "country": "US",
    "name": "Avon",
    "lat": "39.76282",
    "lng": "-86.39972"
  },
  {
    "country": "US",
    "name": "Bargersville",
    "lat": "39.52088",
    "lng": "-86.16777"
  },
  {
    "country": "US",
    "name": "Batesville",
    "lat": "39.30005",
    "lng": "-85.22218"
  },
  {
    "country": "US",
    "name": "Bedford",
    "lat": "38.86116",
    "lng": "-86.48721"
  },
  {
    "country": "US",
    "name": "Beech Grove",
    "lat": "39.72199",
    "lng": "-86.08998"
  },
  {
    "country": "US",
    "name": "Bicknell",
    "lat": "38.77421",
    "lng": "-87.30779"
  },
  {
    "country": "US",
    "name": "Bloomfield",
    "lat": "39.02699",
    "lng": "-86.93751"
  },
  {
    "country": "US",
    "name": "Bloomington",
    "lat": "39.16533",
    "lng": "-86.52639"
  },
  {
    "country": "US",
    "name": "Boonville",
    "lat": "38.04921",
    "lng": "-87.27417"
  },
  {
    "country": "US",
    "name": "Brazil",
    "lat": "39.52365",
    "lng": "-87.12502"
  },
  {
    "country": "US",
    "name": "Bright",
    "lat": "39.21839",
    "lng": "-84.85606"
  },
  {
    "country": "US",
    "name": "Broad Ripple",
    "lat": "39.86671",
    "lng": "-86.14165"
  },
  {
    "country": "US",
    "name": "Brooklyn",
    "lat": "39.53921",
    "lng": "-86.36916"
  },
  {
    "country": "US",
    "name": "Brookville",
    "lat": "39.42311",
    "lng": "-85.01274"
  },
  {
    "country": "US",
    "name": "Brownsburg",
    "lat": "39.84338",
    "lng": "-86.39777"
  },
  {
    "country": "US",
    "name": "Brownstown",
    "lat": "38.87894",
    "lng": "-86.04192"
  },
  {
    "country": "US",
    "name": "Cambridge City",
    "lat": "39.81255",
    "lng": "-85.17163"
  },
  {
    "country": "US",
    "name": "Cannelton",
    "lat": "37.91144",
    "lng": "-86.74443"
  },
  {
    "country": "US",
    "name": "Carmel",
    "lat": "39.97837",
    "lng": "-86.11804"
  },
  {
    "country": "US",
    "name": "Cayuga",
    "lat": "39.94865",
    "lng": "-87.45974"
  },
  {
    "country": "US",
    "name": "Centerville",
    "lat": "39.81782",
    "lng": "-84.99635"
  },
  {
    "country": "US",
    "name": "Chandler",
    "lat": "38.04171",
    "lng": "-87.36806"
  },
  {
    "country": "US",
    "name": "Charlestown",
    "lat": "38.45312",
    "lng": "-85.67024"
  },
  {
    "country": "US",
    "name": "Clarksville",
    "lat": "38.29674",
    "lng": "-85.75996"
  },
  {
    "country": "US",
    "name": "Clermont",
    "lat": "39.80977",
    "lng": "-86.32249"
  },
  {
    "country": "US",
    "name": "Clinton",
    "lat": "39.65698",
    "lng": "-87.39807"
  },
  {
    "country": "US",
    "name": "Cloverdale",
    "lat": "39.51477",
    "lng": "-86.7939"
  },
  {
    "country": "US",
    "name": "Columbus",
    "lat": "39.20144",
    "lng": "-85.92138"
  },
  {
    "country": "US",
    "name": "Connersville",
    "lat": "39.64116",
    "lng": "-85.14107"
  },
  {
    "country": "US",
    "name": "Corydon",
    "lat": "38.21201",
    "lng": "-86.12192"
  },
  {
    "country": "US",
    "name": "Country Squire Lakes",
    "lat": "39.03478",
    "lng": "-85.69858"
  },
  {
    "country": "US",
    "name": "Crothersville",
    "lat": "38.80061",
    "lng": "-85.84164"
  },
  {
    "country": "US",
    "name": "Cumberland",
    "lat": "39.77615",
    "lng": "-85.9572"
  },
  {
    "country": "US",
    "name": "Dale",
    "lat": "38.16894",
    "lng": "-86.99"
  },
  {
    "country": "US",
    "name": "Danville",
    "lat": "39.7606",
    "lng": "-86.52639"
  },
  {
    "country": "US",
    "name": "Darmstadt",
    "lat": "38.09921",
    "lng": "-87.57891"
  },
  {
    "country": "US",
    "name": "Dillsboro",
    "lat": "39.01783",
    "lng": "-85.05884"
  },
  {
    "country": "US",
    "name": "Edinburgh",
    "lat": "39.35422",
    "lng": "-85.96666"
  },
  {
    "country": "US",
    "name": "Ellettsville",
    "lat": "39.23393",
    "lng": "-86.625"
  },
  {
    "country": "US",
    "name": "English",
    "lat": "38.3345",
    "lng": "-86.46415"
  },
  {
    "country": "US",
    "name": "Evansville",
    "lat": "37.97476",
    "lng": "-87.55585"
  },
  {
    "country": "US",
    "name": "Fairview Park",
    "lat": "39.68031",
    "lng": "-87.41752"
  },
  {
    "country": "US",
    "name": "Farmersburg",
    "lat": "39.24865",
    "lng": "-87.38196"
  },
  {
    "country": "US",
    "name": "Ferdinand",
    "lat": "38.22394",
    "lng": "-86.86222"
  },
  {
    "country": "US",
    "name": "Fishers",
    "lat": "39.95559",
    "lng": "-86.01387"
  },
  {
    "country": "US",
    "name": "Fort Branch",
    "lat": "38.25116",
    "lng": "-87.58113"
  },
  {
    "country": "US",
    "name": "Fortville",
    "lat": "39.93226",
    "lng": "-85.84804"
  },
  {
    "country": "US",
    "name": "French Lick",
    "lat": "38.54894",
    "lng": "-86.61999"
  },
  {
    "country": "US",
    "name": "Galena",
    "lat": "38.35173",
    "lng": "-85.94164"
  },
  {
    "country": "US",
    "name": "Geneva",
    "lat": "39.39172",
    "lng": "-85.71998"
  },
  {
    "country": "US",
    "name": "Georgetown",
    "lat": "38.29451",
    "lng": "-85.97552"
  },
  {
    "country": "US",
    "name": "Greencastle",
    "lat": "39.64449",
    "lng": "-86.86473"
  },
  {
    "country": "US",
    "name": "Greendale",
    "lat": "39.11256",
    "lng": "-84.86412"
  },
  {
    "country": "US",
    "name": "Greenfield",
    "lat": "39.78504",
    "lng": "-85.76942"
  },
  {
    "country": "US",
    "name": "Greensburg",
    "lat": "39.33727",
    "lng": "-85.48358"
  },
  {
    "country": "US",
    "name": "Greenwood",
    "lat": "39.61366",
    "lng": "-86.10665"
  },
  {
    "country": "US",
    "name": "Hagerstown",
    "lat": "39.91116",
    "lng": "-85.16163"
  },
  {
    "country": "US",
    "name": "Hanover",
    "lat": "38.71423",
    "lng": "-85.47357"
  },
  {
    "country": "US",
    "name": "Haubstadt",
    "lat": "38.20504",
    "lng": "-87.57419"
  },
  {
    "country": "US",
    "name": "Henryville",
    "lat": "38.54173",
    "lng": "-85.76774"
  },
  {
    "country": "US",
    "name": "Hidden Valley",
    "lat": "39.16228",
    "lng": "-84.84301"
  },
  {
    "country": "US",
    "name": "Highland",
    "lat": "38.03976",
    "lng": "-87.57307"
  },
  {
    "country": "US",
    "name": "Hope",
    "lat": "39.30394",
    "lng": "-85.77137"
  },
  {
    "country": "US",
    "name": "Huntingburg",
    "lat": "38.29894",
    "lng": "-86.955"
  },
  {
    "country": "US",
    "name": "Indianapolis",
    "lat": "39.76838",
    "lng": "-86.15804"
  },
  {
    "country": "US",
    "name": "Ingalls",
    "lat": "39.95699",
    "lng": "-85.80526"
  },
  {
    "country": "US",
    "name": "Jasonville",
    "lat": "39.1631",
    "lng": "-87.19918"
  },
  {
    "country": "US",
    "name": "Jasper",
    "lat": "38.39144",
    "lng": "-86.93111"
  },
  {
    "country": "US",
    "name": "Jeffersonville",
    "lat": "38.27757",
    "lng": "-85.73718"
  },
  {
    "country": "US",
    "name": "Knightstown",
    "lat": "39.7956",
    "lng": "-85.52636"
  },
  {
    "country": "US",
    "name": "Lawrence",
    "lat": "39.83865",
    "lng": "-86.02526"
  },
  {
    "country": "US",
    "name": "Lawrenceburg",
    "lat": "39.09089",
    "lng": "-84.84995"
  },
  {
    "country": "US",
    "name": "Liberty",
    "lat": "39.6356",
    "lng": "-84.93107"
  },
  {
    "country": "US",
    "name": "Linton",
    "lat": "39.03477",
    "lng": "-87.16585"
  },
  {
    "country": "US",
    "name": "Loogootee",
    "lat": "38.67699",
    "lng": "-86.91417"
  },
  {
    "country": "US",
    "name": "Madison",
    "lat": "38.73589",
    "lng": "-85.37996"
  },
  {
    "country": "US",
    "name": "Martinsville",
    "lat": "39.42783",
    "lng": "-86.42833"
  },
  {
    "country": "US",
    "name": "McCordsville",
    "lat": "39.9081",
    "lng": "-85.92276"
  },
  {
    "country": "US",
    "name": "Melody Hill",
    "lat": "38.02615",
    "lng": "-87.51585"
  },
  {
    "country": "US",
    "name": "Meridian Hills",
    "lat": "39.89004",
    "lng": "-86.15721"
  },
  {
    "country": "US",
    "name": "Middlebury",
    "lat": "39.26421",
    "lng": "-87.1189"
  },
  {
    "country": "US",
    "name": "Milan",
    "lat": "39.12117",
    "lng": "-85.13135"
  },
  {
    "country": "US",
    "name": "Mitchell",
    "lat": "38.73283",
    "lng": "-86.4736"
  },
  {
    "country": "US",
    "name": "Monrovia",
    "lat": "39.57894",
    "lng": "-86.48222"
  },
  {
    "country": "US",
    "name": "Mooresville",
    "lat": "39.61282",
    "lng": "-86.37416"
  },
  {
    "country": "US",
    "name": "Morristown",
    "lat": "39.67338",
    "lng": "-85.69859"
  },
  {
    "country": "US",
    "name": "Mount Vernon",
    "lat": "37.93227",
    "lng": "-87.89503"
  },
  {
    "country": "US",
    "name": "Nashville",
    "lat": "39.20727",
    "lng": "-86.2511"
  },
  {
    "country": "US",
    "name": "New Albany",
    "lat": "38.28562",
    "lng": "-85.82413"
  },
  {
    "country": "US",
    "name": "New Castle",
    "lat": "39.92894",
    "lng": "-85.37025"
  },
  {
    "country": "US",
    "name": "New Palestine",
    "lat": "39.72199",
    "lng": "-85.88915"
  },
  {
    "country": "US",
    "name": "New Whiteland",
    "lat": "39.5581",
    "lng": "-86.09526"
  },
  {
    "country": "US",
    "name": "Newburgh",
    "lat": "37.94449",
    "lng": "-87.40529"
  },
  {
    "country": "US",
    "name": "Newport",
    "lat": "39.8842",
    "lng": "-87.40863"
  },
  {
    "country": "US",
    "name": "North Madison",
    "lat": "38.76784",
    "lng": "-85.39663"
  },
  {
    "country": "US",
    "name": "North Terre Haute",
    "lat": "39.52781",
    "lng": "-87.3603"
  },
  {
    "country": "US",
    "name": "North Vernon",
    "lat": "39.00617",
    "lng": "-85.62358"
  },
  {
    "country": "US",
    "name": "Oak Park",
    "lat": "38.30562",
    "lng": "-85.69635"
  },
  {
    "country": "US",
    "name": "Oakland City",
    "lat": "38.33866",
    "lng": "-87.34501"
  },
  {
    "country": "US",
    "name": "Odon",
    "lat": "38.84283",
    "lng": "-86.9914"
  },
  {
    "country": "US",
    "name": "Oolitic",
    "lat": "38.90088",
    "lng": "-86.52527"
  },
  {
    "country": "US",
    "name": "Orleans",
    "lat": "38.66172",
    "lng": "-86.45166"
  },
  {
    "country": "US",
    "name": "Osgood",
    "lat": "39.12922",
    "lng": "-85.29163"
  },
  {
    "country": "US",
    "name": "Owensville",
    "lat": "38.27199",
    "lng": "-87.6878"
  },
  {
    "country": "US",
    "name": "Paoli",
    "lat": "38.55617",
    "lng": "-86.46832"
  },
  {
    "country": "US",
    "name": "Pendleton",
    "lat": "39.99754",
    "lng": "-85.74664"
  },
  {
    "country": "US",
    "name": "Petersburg",
    "lat": "38.49199",
    "lng": "-87.27862"
  },
  {
    "country": "US",
    "name": "Pittsboro",
    "lat": "39.86393",
    "lng": "-86.46694"
  },
  {
    "country": "US",
    "name": "Plainfield",
    "lat": "39.70421",
    "lng": "-86.39944"
  },
  {
    "country": "US",
    "name": "Poseyville",
    "lat": "38.17004",
    "lng": "-87.78308"
  },
  {
    "country": "US",
    "name": "Princes Lakes",
    "lat": "39.35366",
    "lng": "-86.09805"
  },
  {
    "country": "US",
    "name": "Princeton",
    "lat": "38.35532",
    "lng": "-87.56752"
  },
  {
    "country": "US",
    "name": "Richmond",
    "lat": "39.82894",
    "lng": "-84.89024"
  },
  {
    "country": "US",
    "name": "Rising Sun",
    "lat": "38.9495",
    "lng": "-84.85384"
  },
  {
    "country": "US",
    "name": "Rockport",
    "lat": "39.88087",
    "lng": "-87.2789"
  },
  {
    "country": "US",
    "name": "Rockville",
    "lat": "39.76254",
    "lng": "-87.22918"
  },
  {
    "country": "US",
    "name": "Rockport",
    "lat": "37.88311",
    "lng": "-87.04944"
  },
  {
    "country": "US",
    "name": "Rushville",
    "lat": "39.60921",
    "lng": "-85.44636"
  },
  {
    "country": "US",
    "name": "Saint Paul",
    "lat": "39.4281",
    "lng": "-85.62831"
  },
  {
    "country": "US",
    "name": "Salem",
    "lat": "38.60561",
    "lng": "-86.10109"
  },
  {
    "country": "US",
    "name": "Santa Claus",
    "lat": "38.12005",
    "lng": "-86.91416"
  },
  {
    "country": "US",
    "name": "Scottsburg",
    "lat": "38.68561",
    "lng": "-85.77025"
  },
  {
    "country": "US",
    "name": "Seelyville",
    "lat": "39.49198",
    "lng": "-87.26724"
  },
  {
    "country": "US",
    "name": "Sellersburg",
    "lat": "38.39812",
    "lng": "-85.75496"
  },
  {
    "country": "US",
    "name": "Seymour",
    "lat": "38.95922",
    "lng": "-85.89025"
  },
  {
    "country": "US",
    "name": "Shelbyville",
    "lat": "39.52144",
    "lng": "-85.77692"
  },
  {
    "country": "US",
    "name": "Shelburn",
    "lat": "39.17837",
    "lng": "-87.39363"
  },
  {
    "country": "US",
    "name": "Shoals",
    "lat": "38.66644",
    "lng": "-86.79111"
  },
  {
    "country": "US",
    "name": "Southport",
    "lat": "39.66505",
    "lng": "-86.12776"
  },
  {
    "country": "US",
    "name": "Speedway",
    "lat": "39.80227",
    "lng": "-86.26721"
  },
  {
    "country": "US",
    "name": "Spencer",
    "lat": "39.28671",
    "lng": "-86.76251"
  },
  {
    "country": "US",
    "name": "Sullivan",
    "lat": "39.09532",
    "lng": "-87.40585"
  },
  {
    "country": "US",
    "name": "Sunman",
    "lat": "39.237",
    "lng": "-85.09468"
  },
  {
    "country": "US",
    "name": "Tell City",
    "lat": "37.95144",
    "lng": "-86.76777"
  },
  {
    "country": "US",
    "name": "Terre Haute",
    "lat": "39.4667",
    "lng": "-87.41391"
  },
  {
    "country": "US",
    "name": "Trafalgar",
    "lat": "39.41616",
    "lng": "-86.15082"
  },
  {
    "country": "US",
    "name": "Versailles",
    "lat": "39.072",
    "lng": "-85.2519"
  },
  {
    "country": "US",
    "name": "Vevay",
    "lat": "38.74784",
    "lng": "-85.06717"
  },
  {
    "country": "US",
    "name": "Vincennes",
    "lat": "38.67727",
    "lng": "-87.52863"
  },
  {
    "country": "US",
    "name": "Warren Park",
    "lat": "39.78199",
    "lng": "-86.05026"
  },
  {
    "country": "US",
    "name": "Washington",
    "lat": "38.65922",
    "lng": "-87.17279"
  },
  {
    "country": "US",
    "name": "Waterloo",
    "lat": "39.56255",
    "lng": "-86.19749"
  },
  {
    "country": "US",
    "name": "West Terre Haute",
    "lat": "39.46504",
    "lng": "-87.45002"
  },
  {
    "country": "US",
    "name": "Westport",
    "lat": "39.17589",
    "lng": "-85.57303"
  },
  {
    "country": "US",
    "name": "Whiteland",
    "lat": "39.55005",
    "lng": "-86.07971"
  },
  {
    "country": "US",
    "name": "Whitestown",
    "lat": "39.99726",
    "lng": "-86.34583"
  },
  {
    "country": "US",
    "name": "Worthington",
    "lat": "39.12504",
    "lng": "-86.97945"
  },
  {
    "country": "US",
    "name": "Zionsville",
    "lat": "39.95087",
    "lng": "-86.26194"
  },
  {
    "country": "US",
    "name": "Abilene",
    "lat": "38.91722",
    "lng": "-97.21391"
  },
  {
    "country": "US",
    "name": "Alma",
    "lat": "39.01667",
    "lng": "-96.28916"
  },
  {
    "country": "US",
    "name": "Altamont",
    "lat": "37.19034",
    "lng": "-95.29719"
  },
  {
    "country": "US",
    "name": "Andover",
    "lat": "37.7139",
    "lng": "-97.13643"
  },
  {
    "country": "US",
    "name": "Anthony",
    "lat": "37.15336",
    "lng": "-98.03117"
  },
  {
    "country": "US",
    "name": "Arkansas City",
    "lat": "37.06197",
    "lng": "-97.03837"
  },
  {
    "country": "US",
    "name": "Arma",
    "lat": "37.54394",
    "lng": "-94.70024"
  },
  {
    "country": "US",
    "name": "Ashland",
    "lat": "37.18864",
    "lng": "-99.76568"
  },
  {
    "country": "US",
    "name": "Atchison",
    "lat": "39.56305",
    "lng": "-95.12164"
  },
  {
    "country": "US",
    "name": "Auburn",
    "lat": "38.90611",
    "lng": "-95.8161"
  },
  {
    "country": "US",
    "name": "Augusta",
    "lat": "37.68668",
    "lng": "-96.9767"
  },
  {
    "country": "US",
    "name": "Baldwin City",
    "lat": "38.77501",
    "lng": "-95.18636"
  },
  {
    "country": "US",
    "name": "Basehor",
    "lat": "39.14167",
    "lng": "-94.93858"
  },
  {
    "country": "US",
    "name": "Baxter Springs",
    "lat": "37.02368",
    "lng": "-94.7355"
  },
  {
    "country": "US",
    "name": "Bellaire",
    "lat": "37.76251",
    "lng": "-97.26699"
  },
  {
    "country": "US",
    "name": "Belle Plaine",
    "lat": "37.39391",
    "lng": "-97.28115"
  },
  {
    "country": "US",
    "name": "Belleville",
    "lat": "39.82445",
    "lng": "-97.63254"
  },
  {
    "country": "US",
    "name": "Beloit",
    "lat": "39.45612",
    "lng": "-98.10616"
  },
  {
    "country": "US",
    "name": "Bonner Springs",
    "lat": "39.05973",
    "lng": "-94.88358"
  },
  {
    "country": "US",
    "name": "Buhler",
    "lat": "38.13445",
    "lng": "-97.77005"
  },
  {
    "country": "US",
    "name": "Burlington",
    "lat": "38.19447",
    "lng": "-95.74276"
  },
  {
    "country": "US",
    "name": "Caldwell",
    "lat": "37.03225",
    "lng": "-97.60699"
  },
  {
    "country": "US",
    "name": "Caney",
    "lat": "37.01146",
    "lng": "-95.93526"
  },
  {
    "country": "US",
    "name": "Carbondale",
    "lat": "38.81862",
    "lng": "-95.68915"
  },
  {
    "country": "US",
    "name": "Chanute",
    "lat": "37.67921",
    "lng": "-95.4572"
  },
  {
    "country": "US",
    "name": "Chapman",
    "lat": "38.97222",
    "lng": "-97.02251"
  },
  {
    "country": "US",
    "name": "Cheney",
    "lat": "37.63001",
    "lng": "-97.78255"
  },
  {
    "country": "US",
    "name": "Cherryvale",
    "lat": "37.27034",
    "lng": "-95.55248"
  },
  {
    "country": "US",
    "name": "Chetopa",
    "lat": "37.03729",
    "lng": "-95.08996"
  },
  {
    "country": "US",
    "name": "Clay Center",
    "lat": "37.51946",
    "lng": "-96.77114"
  },
  {
    "country": "US",
    "name": "Clay Center",
    "lat": "39.37694",
    "lng": "-97.12474"
  },
  {
    "country": "US",
    "name": "Clearwater",
    "lat": "37.5028",
    "lng": "-97.50449"
  },
  {
    "country": "US",
    "name": "Coffeyville",
    "lat": "37.0373",
    "lng": "-95.61637"
  },
  {
    "country": "US",
    "name": "Coldwater",
    "lat": "37.26891",
    "lng": "-99.32678"
  },
  {
    "country": "US",
    "name": "Columbus",
    "lat": "37.16923",
    "lng": "-94.84412"
  },
  {
    "country": "US",
    "name": "Colwich",
    "lat": "37.77918",
    "lng": "-97.53644"
  },
  {
    "country": "US",
    "name": "Concordia",
    "lat": "39.57084",
    "lng": "-97.66254"
  },
  {
    "country": "US",
    "name": "Conway Springs",
    "lat": "37.3903",
    "lng": "-97.64227"
  },
  {
    "country": "US",
    "name": "Cottonwood Falls",
    "lat": "38.37224",
    "lng": "-96.54278"
  },
  {
    "country": "US",
    "name": "Council Grove",
    "lat": "38.66112",
    "lng": "-96.49195"
  },
  {
    "country": "US",
    "name": "De Soto",
    "lat": "38.97917",
    "lng": "-94.96858"
  },
  {
    "country": "US",
    "name": "Derby",
    "lat": "37.54557",
    "lng": "-97.26893"
  },
  {
    "country": "US",
    "name": "Douglass",
    "lat": "37.51946",
    "lng": "-97.01281"
  },
  {
    "country": "US",
    "name": "Edgerton",
    "lat": "38.76473",
    "lng": "-95.00802"
  },
  {
    "country": "US",
    "name": "Edwardsville",
    "lat": "39.06112",
    "lng": "-94.81968"
  },
  {
    "country": "US",
    "name": "El Dorado",
    "lat": "37.81724",
    "lng": "-96.86225"
  },
  {
    "country": "US",
    "name": "Ellinwood",
    "lat": "38.35557",
    "lng": "-98.58091"
  },
  {
    "country": "US",
    "name": "Ellis",
    "lat": "38.93807",
    "lng": "-99.56067"
  },
  {
    "country": "US",
    "name": "Ellsworth",
    "lat": "38.73056",
    "lng": "-98.22811"
  },
  {
    "country": "US",
    "name": "Elwood",
    "lat": "39.75555",
    "lng": "-94.87247"
  },
  {
    "country": "US",
    "name": "Emporia",
    "lat": "38.4039",
    "lng": "-96.18166"
  },
  {
    "country": "US",
    "name": "Erie",
    "lat": "37.56811",
    "lng": "-95.24331"
  },
  {
    "country": "US",
    "name": "Eureka",
    "lat": "37.82392",
    "lng": "-96.28917"
  },
  {
    "country": "US",
    "name": "Eudora",
    "lat": "38.94334",
    "lng": "-95.09858"
  },
  {
    "country": "US",
    "name": "Fairway",
    "lat": "39.02223",
    "lng": "-94.6319"
  },
  {
    "country": "US",
    "name": "Fort Scott",
    "lat": "37.83976",
    "lng": "-94.7083"
  },
  {
    "country": "US",
    "name": "Fredonia",
    "lat": "37.53394",
    "lng": "-95.82665"
  },
  {
    "country": "US",
    "name": "Galena",
    "lat": "37.0759",
    "lng": "-94.63967"
  },
  {
    "country": "US",
    "name": "Frontenac",
    "lat": "37.4556",
    "lng": "-94.68913"
  },
  {
    "country": "US",
    "name": "Gardner",
    "lat": "38.81084",
    "lng": "-94.92719"
  },
  {
    "country": "US",
    "name": "Garnett",
    "lat": "38.28058",
    "lng": "-95.24192"
  },
  {
    "country": "US",
    "name": "Girard",
    "lat": "37.51116",
    "lng": "-94.83802"
  },
  {
    "country": "US",
    "name": "Goddard",
    "lat": "37.65974",
    "lng": "-97.57533"
  },
  {
    "country": "US",
    "name": "Grandview Plaza",
    "lat": "39.02916",
    "lng": "-96.78917"
  },
  {
    "country": "US",
    "name": "Great Bend",
    "lat": "38.36446",
    "lng": "-98.76481"
  },
  {
    "country": "US",
    "name": "Greensburg",
    "lat": "37.6028",
    "lng": "-99.29261"
  },
  {
    "country": "US",
    "name": "Halstead",
    "lat": "38.0014",
    "lng": "-97.50865"
  },
  {
    "country": "US",
    "name": "Harper",
    "lat": "37.28669",
    "lng": "-98.02589"
  },
  {
    "country": "US",
    "name": "Haven",
    "lat": "37.8989",
    "lng": "-97.78283"
  },
  {
    "country": "US",
    "name": "Hays",
    "lat": "38.87918",
    "lng": "-99.32677"
  },
  {
    "country": "US",
    "name": "Haysville",
    "lat": "37.56446",
    "lng": "-97.35227"
  },
  {
    "country": "US",
    "name": "Herington",
    "lat": "38.67112",
    "lng": "-96.94251"
  },
  {
    "country": "US",
    "name": "Hesston",
    "lat": "38.13834",
    "lng": "-97.43143"
  },
  {
    "country": "US",
    "name": "Hiawatha",
    "lat": "39.8525",
    "lng": "-95.53582"
  },
  {
    "country": "US",
    "name": "Highland",
    "lat": "39.85972",
    "lng": "-95.2697"
  },
  {
    "country": "US",
    "name": "Hill City",
    "lat": "39.36473",
    "lng": "-99.84206"
  },
  {
    "country": "US",
    "name": "Hillsboro",
    "lat": "38.35196",
    "lng": "-97.20447"
  },
  {
    "country": "US",
    "name": "Hoisington",
    "lat": "38.51807",
    "lng": "-98.77814"
  },
  {
    "country": "US",
    "name": "Holton",
    "lat": "39.46527",
    "lng": "-95.73637"
  },
  {
    "country": "US",
    "name": "Horton",
    "lat": "39.66056",
    "lng": "-95.52637"
  },
  {
    "country": "US",
    "name": "Howard",
    "lat": "37.47031",
    "lng": "-96.26361"
  },
  {
    "country": "US",
    "name": "Humboldt",
    "lat": "37.8106",
    "lng": "-95.43693"
  },
  {
    "country": "US",
    "name": "Hutchinson",
    "lat": "38.06084",
    "lng": "-97.92977"
  },
  {
    "country": "US",
    "name": "Independence",
    "lat": "37.22424",
    "lng": "-95.70831"
  },
  {
    "country": "US",
    "name": "Inman",
    "lat": "38.23195",
    "lng": "-97.77338"
  },
  {
    "country": "US",
    "name": "Iola",
    "lat": "37.92448",
    "lng": "-95.39998"
  },
  {
    "country": "US",
    "name": "Jetmore",
    "lat": "38.08446",
    "lng": "-99.89346"
  },
  {
    "country": "US",
    "name": "Junction City",
    "lat": "39.02861",
    "lng": "-96.8314"
  },
  {
    "country": "US",
    "name": "Kansas City",
    "lat": "39.11417",
    "lng": "-94.62746"
  },
  {
    "country": "US",
    "name": "Kechi",
    "lat": "37.79585",
    "lng": "-97.27949"
  },
  {
    "country": "US",
    "name": "Kingman",
    "lat": "37.64585",
    "lng": "-98.11367"
  },
  {
    "country": "US",
    "name": "Kinsley",
    "lat": "37.92307",
    "lng": "-99.40984"
  },
  {
    "country": "US",
    "name": "Kiowa",
    "lat": "37.01725",
    "lng": "-98.48535"
  },
  {
    "country": "US",
    "name": "La Crosse",
    "lat": "38.5314",
    "lng": "-99.30872"
  },
  {
    "country": "US",
    "name": "La Cygne",
    "lat": "38.35002",
    "lng": "-94.76135"
  },
  {
    "country": "US",
    "name": "Lansing",
    "lat": "39.24861",
    "lng": "-94.90024"
  },
  {
    "country": "US",
    "name": "Larned",
    "lat": "38.18057",
    "lng": "-99.09871"
  },
  {
    "country": "US",
    "name": "Lawrence",
    "lat": "38.97167",
    "lng": "-95.23525"
  },
  {
    "country": "US",
    "name": "Leavenworth",
    "lat": "39.31111",
    "lng": "-94.92246"
  },
  {
    "country": "US",
    "name": "Leawood",
    "lat": "38.96667",
    "lng": "-94.6169"
  },
  {
    "country": "US",
    "name": "Lenexa",
    "lat": "38.95362",
    "lng": "-94.73357"
  },
  {
    "country": "US",
    "name": "Lincoln",
    "lat": "39.04084",
    "lng": "-98.14477"
  },
  {
    "country": "US",
    "name": "Lindsborg",
    "lat": "38.57362",
    "lng": "-97.67448"
  },
  {
    "country": "US",
    "name": "Louisburg",
    "lat": "38.61946",
    "lng": "-94.68079"
  },
  {
    "country": "US",
    "name": "Lyndon",
    "lat": "38.61001",
    "lng": "-95.68443"
  },
  {
    "country": "US",
    "name": "Lyons",
    "lat": "38.34501",
    "lng": "-98.20173"
  },
  {
    "country": "US",
    "name": "Maize",
    "lat": "37.77918",
    "lng": "-97.46727"
  },
  {
    "country": "US",
    "name": "Manhattan",
    "lat": "39.18361",
    "lng": "-96.57167"
  },
  {
    "country": "US",
    "name": "Mankato",
    "lat": "39.78723",
    "lng": "-98.21005"
  },
  {
    "country": "US",
    "name": "Marion",
    "lat": "38.34835",
    "lng": "-97.01725"
  },
  {
    "country": "US",
    "name": "Marysville",
    "lat": "39.84111",
    "lng": "-96.64724"
  },
  {
    "country": "US",
    "name": "McPherson",
    "lat": "38.37084",
    "lng": "-97.66421"
  },
  {
    "country": "US",
    "name": "Medicine Lodge",
    "lat": "37.28113",
    "lng": "-98.58036"
  },
  {
    "country": "US",
    "name": "Merriam",
    "lat": "39.02362",
    "lng": "-94.69357"
  },
  {
    "country": "US",
    "name": "Minneapolis",
    "lat": "39.12194",
    "lng": "-97.7067"
  },
  {
    "country": "US",
    "name": "Mission",
    "lat": "39.02778",
    "lng": "-94.65579"
  },
  {
    "country": "US",
    "name": "Mission Hills",
    "lat": "39.01778",
    "lng": "-94.6169"
  },
  {
    "country": "US",
    "name": "Mound City",
    "lat": "38.14281",
    "lng": "-94.81357"
  },
  {
    "country": "US",
    "name": "Moundridge",
    "lat": "38.20307",
    "lng": "-97.51921"
  },
  {
    "country": "US",
    "name": "Mulvane",
    "lat": "37.47446",
    "lng": "-97.24393"
  },
  {
    "country": "US",
    "name": "Neodesha",
    "lat": "37.41839",
    "lng": "-95.68026"
  },
  {
    "country": "US",
    "name": "Ness City",
    "lat": "38.45279",
    "lng": "-99.90651"
  },
  {
    "country": "US",
    "name": "Newton",
    "lat": "38.04668",
    "lng": "-97.34504"
  },
  {
    "country": "US",
    "name": "Nickerson",
    "lat": "38.14723",
    "lng": "-98.08367"
  },
  {
    "country": "US",
    "name": "North Newton",
    "lat": "38.07223",
    "lng": "-97.34559"
  },
  {
    "country": "US",
    "name": "Norton",
    "lat": "39.83389",
    "lng": "-99.89151"
  },
  {
    "country": "US",
    "name": "Ogden",
    "lat": "39.11111",
    "lng": "-96.70612"
  },
  {
    "country": "US",
    "name": "Olathe",
    "lat": "38.8814",
    "lng": "-94.81913"
  },
  {
    "country": "US",
    "name": "Osage City",
    "lat": "38.6339",
    "lng": "-95.82582"
  },
  {
    "country": "US",
    "name": "Osawatomie",
    "lat": "38.49724",
    "lng": "-94.95052"
  },
  {
    "country": "US",
    "name": "Osborne",
    "lat": "39.43914",
    "lng": "-98.69624"
  },
  {
    "country": "US",
    "name": "Oskaloosa",
    "lat": "39.21528",
    "lng": "-95.31275"
  },
  {
    "country": "US",
    "name": "Oswego",
    "lat": "37.16757",
    "lng": "-95.10996"
  },
  {
    "country": "US",
    "name": "Ottawa",
    "lat": "38.61557",
    "lng": "-95.26775"
  },
  {
    "country": "US",
    "name": "Overbrook",
    "lat": "38.78056",
    "lng": "-95.5572"
  },
  {
    "country": "US",
    "name": "Overland Park",
    "lat": "38.98223",
    "lng": "-94.67079"
  },
  {
    "country": "US",
    "name": "Oxford",
    "lat": "37.27419",
    "lng": "-97.16893"
  },
  {
    "country": "US",
    "name": "Paola",
    "lat": "38.57224",
    "lng": "-94.87913"
  },
  {
    "country": "US",
    "name": "Park City",
    "lat": "37.80001",
    "lng": "-97.31838"
  },
  {
    "country": "US",
    "name": "Parsons",
    "lat": "37.34034",
    "lng": "-95.26108"
  },
  {
    "country": "US",
    "name": "Peabody",
    "lat": "38.16946",
    "lng": "-97.1067"
  },
  {
    "country": "US",
    "name": "Phillipsburg",
    "lat": "39.75612",
    "lng": "-99.32399"
  },
  {
    "country": "US",
    "name": "Pittsburg",
    "lat": "37.41088",
    "lng": "-94.70496"
  },
  {
    "country": "US",
    "name": "Plainville",
    "lat": "39.23473",
    "lng": "-99.29816"
  },
  {
    "country": "US",
    "name": "Pleasanton",
    "lat": "38.17781",
    "lng": "-94.71135"
  },
  {
    "country": "US",
    "name": "Prairie Village",
    "lat": "38.99167",
    "lng": "-94.63357"
  },
  {
    "country": "US",
    "name": "Pratt",
    "lat": "37.64391",
    "lng": "-98.73759"
  },
  {
    "country": "US",
    "name": "Roeland Park",
    "lat": "39.03751",
    "lng": "-94.63218"
  },
  {
    "country": "US",
    "name": "Rose Hill",
    "lat": "37.55835",
    "lng": "-97.13504"
  },
  {
    "country": "US",
    "name": "Rossville",
    "lat": "39.13611",
    "lng": "-95.95166"
  },
  {
    "country": "US",
    "name": "Russell",
    "lat": "38.89527",
    "lng": "-98.86103"
  },
  {
    "country": "US",
    "name": "Sabetha",
    "lat": "39.90222",
    "lng": "-95.80082"
  },
  {
    "country": "US",
    "name": "Saint John",
    "lat": "38.00224",
    "lng": "-98.76009"
  },
  {
    "country": "US",
    "name": "Saint Marys",
    "lat": "39.19416",
    "lng": "-96.0711"
  },
  {
    "country": "US",
    "name": "Saint Marys",
    "lat": "37.70668",
    "lng": "-97.64005"
  },
  {
    "country": "US",
    "name": "Salina",
    "lat": "38.84028",
    "lng": "-97.61142"
  },
  {
    "country": "US",
    "name": "Sedan",
    "lat": "37.12672",
    "lng": "-96.18694"
  },
  {
    "country": "US",
    "name": "Sedgwick",
    "lat": "37.91668",
    "lng": "-97.42254"
  },
  {
    "country": "US",
    "name": "Seneca",
    "lat": "39.83416",
    "lng": "-96.06417"
  },
  {
    "country": "US",
    "name": "Shawnee",
    "lat": "39.04167",
    "lng": "-94.72024"
  },
  {
    "country": "US",
    "name": "Silver Lake",
    "lat": "39.10417",
    "lng": "-95.8586"
  },
  {
    "country": "US",
    "name": "Smith Center",
    "lat": "39.77918",
    "lng": "-98.78507"
  },
  {
    "country": "US",
    "name": "Solomon",
    "lat": "38.91944",
    "lng": "-97.37114"
  },
  {
    "country": "US",
    "name": "South Hutchinson",
    "lat": "38.02807",
    "lng": "-97.94033"
  },
  {
    "country": "US",
    "name": "Spring Hill",
    "lat": "38.74306",
    "lng": "-94.82552"
  },
  {
    "country": "US",
    "name": "Sterling",
    "lat": "38.21001",
    "lng": "-98.20701"
  },
  {
    "country": "US",
    "name": "Tonganoxie",
    "lat": "39.10972",
    "lng": "-95.08775"
  },
  {
    "country": "US",
    "name": "Towanda",
    "lat": "37.79752",
    "lng": "-96.99976"
  },
  {
    "country": "US",
    "name": "Topeka",
    "lat": "39.04833",
    "lng": "-95.67804"
  },
  {
    "country": "US",
    "name": "Troy",
    "lat": "39.78305",
    "lng": "-95.08997"
  },
  {
    "country": "US",
    "name": "Valley Center",
    "lat": "37.83473",
    "lng": "-97.37338"
  },
  {
    "country": "US",
    "name": "Valley Falls",
    "lat": "39.34333",
    "lng": "-95.46025"
  },
  {
    "country": "US",
    "name": "Victoria",
    "lat": "38.85279",
    "lng": "-99.1476"
  },
  {
    "country": "US",
    "name": "WaKeeney",
    "lat": "39.02501",
    "lng": "-99.87957"
  },
  {
    "country": "US",
    "name": "Wamego",
    "lat": "39.20194",
    "lng": "-96.305"
  },
  {
    "country": "US",
    "name": "Washington",
    "lat": "39.81806",
    "lng": "-97.05086"
  },
  {
    "country": "US",
    "name": "Wathena",
    "lat": "39.75916",
    "lng": "-94.94969"
  },
  {
    "country": "US",
    "name": "Wellington",
    "lat": "37.2653",
    "lng": "-97.37171"
  },
  {
    "country": "US",
    "name": "Wellsville",
    "lat": "38.71834",
    "lng": "-95.08164"
  },
  {
    "country": "US",
    "name": "Westmoreland",
    "lat": "39.39389",
    "lng": "-96.41361"
  },
  {
    "country": "US",
    "name": "Westwood",
    "lat": "39.04056",
    "lng": "-94.6169"
  },
  {
    "country": "US",
    "name": "Wichita",
    "lat": "37.69224",
    "lng": "-97.33754"
  },
  {
    "country": "US",
    "name": "Winfield",
    "lat": "37.23975",
    "lng": "-96.99559"
  },
  {
    "country": "US",
    "name": "Yates Center",
    "lat": "37.88115",
    "lng": "-95.73332"
  },
  {
    "country": "US",
    "name": "Albany",
    "lat": "36.6909",
    "lng": "-85.13468"
  },
  {
    "country": "US",
    "name": "Alexandria",
    "lat": "38.95951",
    "lng": "-84.38799"
  },
  {
    "country": "US",
    "name": "Anchorage",
    "lat": "38.26674",
    "lng": "-85.53302"
  },
  {
    "country": "US",
    "name": "Annville",
    "lat": "37.31925",
    "lng": "-83.97048"
  },
  {
    "country": "US",
    "name": "Ashland",
    "lat": "38.47841",
    "lng": "-82.63794"
  },
  {
    "country": "US",
    "name": "Auburn",
    "lat": "36.86421",
    "lng": "-86.71027"
  },
  {
    "country": "US",
    "name": "Audubon Park",
    "lat": "38.20396",
    "lng": "-85.72524"
  },
  {
    "country": "US",
    "name": "Augusta",
    "lat": "38.77174",
    "lng": "-84.00576"
  },
  {
    "country": "US",
    "name": "Barbourmeade",
    "lat": "38.29729",
    "lng": "-85.60329"
  },
  {
    "country": "US",
    "name": "Barbourville",
    "lat": "36.86648",
    "lng": "-83.88881"
  },
  {
    "country": "US",
    "name": "Bardstown",
    "lat": "37.80923",
    "lng": "-85.4669"
  },
  {
    "country": "US",
    "name": "Bardwell",
    "lat": "36.87061",
    "lng": "-89.00979"
  },
  {
    "country": "US",
    "name": "Beattyville",
    "lat": "37.57175",
    "lng": "-83.70686"
  },
  {
    "country": "US",
    "name": "Beaver Dam",
    "lat": "37.40199",
    "lng": "-86.87583"
  },
  {
    "country": "US",
    "name": "Bedford",
    "lat": "38.59256",
    "lng": "-85.31773"
  },
  {
    "country": "US",
    "name": "Beechwood Village",
    "lat": "38.25479",
    "lng": "-85.63135"
  },
  {
    "country": "US",
    "name": "Bellevue",
    "lat": "39.10645",
    "lng": "-84.47883"
  },
  {
    "country": "US",
    "name": "Benton",
    "lat": "36.85728",
    "lng": "-88.35031"
  },
  {
    "country": "US",
    "name": "Berea",
    "lat": "37.56869",
    "lng": "-84.29632"
  },
  {
    "country": "US",
    "name": "Bloomfield",
    "lat": "37.91034",
    "lng": "-85.31662"
  },
  {
    "country": "US",
    "name": "Booneville",
    "lat": "37.4762",
    "lng": "-83.67491"
  },
  {
    "country": "US",
    "name": "Bowling Green",
    "lat": "36.99032",
    "lng": "-86.4436"
  },
  {
    "country": "US",
    "name": "Brandenburg",
    "lat": "37.99896",
    "lng": "-86.16941"
  },
  {
    "country": "US",
    "name": "Breckinridge Center",
    "lat": "37.68282",
    "lng": "-87.86308"
  },
  {
    "country": "US",
    "name": "Brodhead",
    "lat": "37.40425",
    "lng": "-84.41383"
  },
  {
    "country": "US",
    "name": "Brooks",
    "lat": "38.06118",
    "lng": "-85.70968"
  },
  {
    "country": "US",
    "name": "Brooksville",
    "lat": "38.68257",
    "lng": "-84.06576"
  },
  {
    "country": "US",
    "name": "Brownsville",
    "lat": "37.19255",
    "lng": "-86.26775"
  },
  {
    "country": "US",
    "name": "Buckner",
    "lat": "38.38368",
    "lng": "-85.43996"
  },
  {
    "country": "US",
    "name": "Buechel",
    "lat": "38.19507",
    "lng": "-85.6519"
  },
  {
    "country": "US",
    "name": "Burkesville",
    "lat": "36.79034",
    "lng": "-85.37052"
  },
  {
    "country": "US",
    "name": "Burlington",
    "lat": "39.02756",
    "lng": "-84.72411"
  },
  {
    "country": "US",
    "name": "Cadiz",
    "lat": "36.86505",
    "lng": "-87.8353"
  },
  {
    "country": "US",
    "name": "Calhoun",
    "lat": "37.53894",
    "lng": "-87.25833"
  },
  {
    "country": "US",
    "name": "Calvert City",
    "lat": "37.03339",
    "lng": "-88.35004"
  },
  {
    "country": "US",
    "name": "Camargo",
    "lat": "37.99425",
    "lng": "-83.8877"
  },
  {
    "country": "US",
    "name": "Campbellsville",
    "lat": "37.3434",
    "lng": "-85.34191"
  },
  {
    "country": "US",
    "name": "Campton",
    "lat": "37.73425",
    "lng": "-83.54741"
  },
  {
    "country": "US",
    "name": "Carlisle",
    "lat": "38.31202",
    "lng": "-84.02743"
  },
  {
    "country": "US",
    "name": "Carrollton",
    "lat": "38.6809",
    "lng": "-85.1794"
  },
  {
    "country": "US",
    "name": "Catlettsburg",
    "lat": "38.4048",
    "lng": "-82.60044"
  },
  {
    "country": "US",
    "name": "Cave City",
    "lat": "37.13672",
    "lng": "-85.95692"
  },
  {
    "country": "US",
    "name": "Central City",
    "lat": "37.29393",
    "lng": "-87.12333"
  },
  {
    "country": "US",
    "name": "Claryville",
    "lat": "38.91923",
    "lng": "-84.39549"
  },
  {
    "country": "US",
    "name": "Clay",
    "lat": "37.47671",
    "lng": "-87.82002"
  },
  {
    "country": "US",
    "name": "Clay City",
    "lat": "37.85925",
    "lng": "-83.91853"
  },
  {
    "country": "US",
    "name": "Clinton",
    "lat": "36.66728",
    "lng": "-88.9934"
  },
  {
    "country": "US",
    "name": "Cloverport",
    "lat": "37.83339",
    "lng": "-86.63276"
  },
  {
    "country": "US",
    "name": "Coal Run Village",
    "lat": "37.51316",
    "lng": "-82.55849"
  },
  {
    "country": "US",
    "name": "Cold Spring",
    "lat": "39.02173",
    "lng": "-84.43994"
  },
  {
    "country": "US",
    "name": "Coldstream",
    "lat": "38.31479",
    "lng": "-85.52385"
  },
  {
    "country": "US",
    "name": "Columbia",
    "lat": "37.10284",
    "lng": "-85.30635"
  },
  {
    "country": "US",
    "name": "Corbin",
    "lat": "36.9487",
    "lng": "-84.09688"
  },
  {
    "country": "US",
    "name": "Covington",
    "lat": "39.08367",
    "lng": "-84.50855"
  },
  {
    "country": "US",
    "name": "Crescent Springs",
    "lat": "39.05145",
    "lng": "-84.58161"
  },
  {
    "country": "US",
    "name": "Crestview Hills",
    "lat": "39.02728",
    "lng": "-84.58494"
  },
  {
    "country": "US",
    "name": "Crestwood",
    "lat": "38.32424",
    "lng": "-85.47246"
  },
  {
    "country": "US",
    "name": "Crittenden",
    "lat": "38.78284",
    "lng": "-84.60522"
  },
  {
    "country": "US",
    "name": "Cumberland",
    "lat": "36.97815",
    "lng": "-82.9885"
  },
  {
    "country": "US",
    "name": "Cynthiana",
    "lat": "38.39035",
    "lng": "-84.2941"
  },
  {
    "country": "US",
    "name": "Danville",
    "lat": "37.64563",
    "lng": "-84.77217"
  },
  {
    "country": "US",
    "name": "Dawson Springs",
    "lat": "37.16727",
    "lng": "-87.69251"
  },
  {
    "country": "US",
    "name": "Dayton",
    "lat": "39.11284",
    "lng": "-84.47272"
  },
  {
    "country": "US",
    "name": "Dixon",
    "lat": "37.51782",
    "lng": "-87.69029"
  },
  {
    "country": "US",
    "name": "Douglass Hills",
    "lat": "38.23785",
    "lng": "-85.55274"
  },
  {
    "country": "US",
    "name": "Dry Ridge",
    "lat": "38.68201",
    "lng": "-84.58994"
  },
  {
    "country": "US",
    "name": "Earlington",
    "lat": "37.27421",
    "lng": "-87.51194"
  },
  {
    "country": "US",
    "name": "Eddyville",
    "lat": "37.0945",
    "lng": "-88.0803"
  },
  {
    "country": "US",
    "name": "Edgewood",
    "lat": "39.01867",
    "lng": "-84.58189"
  },
  {
    "country": "US",
    "name": "Edmonton",
    "lat": "36.98006",
    "lng": "-85.61219"
  },
  {
    "country": "US",
    "name": "Elizabethtown",
    "lat": "37.69395",
    "lng": "-85.85913"
  },
  {
    "country": "US",
    "name": "Elk Creek",
    "lat": "38.10034",
    "lng": "-85.37107"
  },
  {
    "country": "US",
    "name": "Elkfork",
    "lat": "37.96481",
    "lng": "-83.13295"
  },
  {
    "country": "US",
    "name": "Elkton",
    "lat": "36.81004",
    "lng": "-87.15417"
  },
  {
    "country": "US",
    "name": "Elsmere",
    "lat": "39.01256",
    "lng": "-84.60467"
  },
  {
    "country": "US",
    "name": "Eminence",
    "lat": "38.37007",
    "lng": "-85.18051"
  },
  {
    "country": "US",
    "name": "Erlanger",
    "lat": "39.01673",
    "lng": "-84.60078"
  },
  {
    "country": "US",
    "name": "Fairdale",
    "lat": "38.10507",
    "lng": "-85.75885"
  },
  {
    "country": "US",
    "name": "Falmouth",
    "lat": "38.67674",
    "lng": "-84.33021"
  },
  {
    "country": "US",
    "name": "Fern Creek",
    "lat": "38.15979",
    "lng": "-85.58774"
  },
  {
    "country": "US",
    "name": "Flatwoods",
    "lat": "38.52258",
    "lng": "-82.71711"
  },
  {
    "country": "US",
    "name": "Flemingsburg",
    "lat": "38.4223",
    "lng": "-83.73381"
  },
  {
    "country": "US",
    "name": "Florence",
    "lat": "38.99895",
    "lng": "-84.62661"
  },
  {
    "country": "US",
    "name": "Fort Mitchell",
    "lat": "39.0595",
    "lng": "-84.54744"
  },
  {
    "country": "US",
    "name": "Fort Thomas",
    "lat": "39.07506",
    "lng": "-84.44716"
  },
  {
    "country": "US",
    "name": "Fort Wright",
    "lat": "39.05173",
    "lng": "-84.53411"
  },
  {
    "country": "US",
    "name": "Francisville",
    "lat": "39.10506",
    "lng": "-84.72439"
  },
  {
    "country": "US",
    "name": "Frankfort",
    "lat": "38.20091",
    "lng": "-84.87328"
  },
  {
    "country": "US",
    "name": "Franklin",
    "lat": "36.72226",
    "lng": "-86.57722"
  },
  {
    "country": "US",
    "name": "Frenchburg",
    "lat": "37.95092",
    "lng": "-83.62575"
  },
  {
    "country": "US",
    "name": "Fulton",
    "lat": "36.50423",
    "lng": "-88.87423"
  },
  {
    "country": "US",
    "name": "Georgetown",
    "lat": "38.2098",
    "lng": "-84.55883"
  },
  {
    "country": "US",
    "name": "Glasgow",
    "lat": "36.99588",
    "lng": "-85.91192"
  },
  {
    "country": "US",
    "name": "Graymoor-Devondale",
    "lat": "38.27313",
    "lng": "-85.62302"
  },
  {
    "country": "US",
    "name": "Grayson",
    "lat": "38.33258",
    "lng": "-82.9485"
  },
  {
    "country": "US",
    "name": "Greensburg",
    "lat": "37.26089",
    "lng": "-85.49885"
  },
  {
    "country": "US",
    "name": "Greenup",
    "lat": "38.57313",
    "lng": "-82.83017"
  },
  {
    "country": "US",
    "name": "Greenville",
    "lat": "37.20115",
    "lng": "-87.17889"
  },
  {
    "country": "US",
    "name": "Guthrie",
    "lat": "36.64838",
    "lng": "-87.16639"
  },
  {
    "country": "US",
    "name": "Hardinsburg",
    "lat": "37.78006",
    "lng": "-86.46053"
  },
  {
    "country": "US",
    "name": "Harlan",
    "lat": "36.84314",
    "lng": "-83.32185"
  },
  {
    "country": "US",
    "name": "Harrodsburg",
    "lat": "37.7623",
    "lng": "-84.84329"
  },
  {
    "country": "US",
    "name": "Hartford",
    "lat": "37.45116",
    "lng": "-86.90916"
  },
  {
    "country": "US",
    "name": "Hawesville",
    "lat": "37.90006",
    "lng": "-86.75499"
  },
  {
    "country": "US",
    "name": "Hazard",
    "lat": "37.24954",
    "lng": "-83.19323"
  },
  {
    "country": "US",
    "name": "Hebron",
    "lat": "39.06589",
    "lng": "-84.70106"
  },
  {
    "country": "US",
    "name": "Hebron Estates",
    "lat": "38.04951",
    "lng": "-85.66607"
  },
  {
    "country": "US",
    "name": "Henderson",
    "lat": "37.83615",
    "lng": "-87.59001"
  },
  {
    "country": "US",
    "name": "Hendron",
    "lat": "37.0395",
    "lng": "-88.62922"
  },
  {
    "country": "US",
    "name": "Hickman",
    "lat": "36.57117",
    "lng": "-89.18618"
  },
  {
    "country": "US",
    "name": "Highland Heights",
    "lat": "39.03312",
    "lng": "-84.45189"
  },
  {
    "country": "US",
    "name": "Highview",
    "lat": "38.14285",
    "lng": "-85.62413"
  },
  {
    "country": "US",
    "name": "Hillview",
    "lat": "38.06979",
    "lng": "-85.68551"
  },
  {
    "country": "US",
    "name": "Hindman",
    "lat": "37.33593",
    "lng": "-82.98044"
  },
  {
    "country": "US",
    "name": "Hodgenville",
    "lat": "37.57395",
    "lng": "-85.73996"
  },
  {
    "country": "US",
    "name": "Hopkinsville",
    "lat": "36.86561",
    "lng": "-87.49117"
  },
  {
    "country": "US",
    "name": "Horse Cave",
    "lat": "37.1795",
    "lng": "-85.90692"
  },
  {
    "country": "US",
    "name": "Hurstbourne Acres",
    "lat": "38.22118",
    "lng": "-85.58913"
  },
  {
    "country": "US",
    "name": "Hurstbourne",
    "lat": "38.23813",
    "lng": "-85.58829"
  },
  {
    "country": "US",
    "name": "Hyden",
    "lat": "37.16093",
    "lng": "-83.37324"
  },
  {
    "country": "US",
    "name": "Independence",
    "lat": "38.94312",
    "lng": "-84.54411"
  },
  {
    "country": "US",
    "name": "Indian Hills",
    "lat": "38.27257",
    "lng": "-85.66274"
  },
  {
    "country": "US",
    "name": "Indian Hills Cherokee Section",
    "lat": "38.27951",
    "lng": "-85.64996"
  },
  {
    "country": "US",
    "name": "Inez",
    "lat": "37.86648",
    "lng": "-82.53876"
  },
  {
    "country": "US",
    "name": "Ironville",
    "lat": "38.45647",
    "lng": "-82.69238"
  },
  {
    "country": "US",
    "name": "Irvine",
    "lat": "37.70064",
    "lng": "-83.97381"
  },
  {
    "country": "US",
    "name": "Irvington",
    "lat": "37.88034",
    "lng": "-86.28386"
  },
  {
    "country": "US",
    "name": "Jackson",
    "lat": "37.55315",
    "lng": "-83.38351"
  },
  {
    "country": "US",
    "name": "Jackson",
    "lat": "37.82508",
    "lng": "-84.87079"
  },
  {
    "country": "US",
    "name": "Jamestown",
    "lat": "36.98479",
    "lng": "-85.06301"
  },
  {
    "country": "US",
    "name": "Jeffersontown",
    "lat": "38.19424",
    "lng": "-85.5644"
  },
  {
    "country": "US",
    "name": "Jeffersonville",
    "lat": "37.97369",
    "lng": "-83.84186"
  },
  {
    "country": "US",
    "name": "Jenkins",
    "lat": "37.17344",
    "lng": "-82.63099"
  },
  {
    "country": "US",
    "name": "Junction City",
    "lat": "37.58674",
    "lng": "-84.79384"
  },
  {
    "country": "US",
    "name": "Knottsville",
    "lat": "37.77172",
    "lng": "-86.90416"
  },
  {
    "country": "US",
    "name": "La Center",
    "lat": "37.07672",
    "lng": "-88.97368"
  },
  {
    "country": "US",
    "name": "La Grange",
    "lat": "38.40757",
    "lng": "-85.37885"
  },
  {
    "country": "US",
    "name": "Lakeside Park",
    "lat": "39.03562",
    "lng": "-84.56911"
  },
  {
    "country": "US",
    "name": "Lancaster",
    "lat": "37.61952",
    "lng": "-84.578"
  },
  {
    "country": "US",
    "name": "Lawrenceburg",
    "lat": "38.0373",
    "lng": "-84.89662"
  },
  {
    "country": "US",
    "name": "Lebanon",
    "lat": "37.56979",
    "lng": "-85.25274"
  },
  {
    "country": "US",
    "name": "Lebanon Junction",
    "lat": "37.83451",
    "lng": "-85.7319"
  },
  {
    "country": "US",
    "name": "Ledbetter",
    "lat": "37.04756",
    "lng": "-88.47699"
  },
  {
    "country": "US",
    "name": "Leitchfield",
    "lat": "37.48005",
    "lng": "-86.29386"
  },
  {
    "country": "US",
    "name": "Lewisport",
    "lat": "37.937",
    "lng": "-86.90221"
  },
  {
    "country": "US",
    "name": "Lexington",
    "lat": "37.98869",
    "lng": "-84.47772"
  },
  {
    "country": "US",
    "name": "Lexington-Fayette",
    "lat": "38.0498",
    "lng": "-84.45855"
  },
  {
    "country": "US",
    "name": "Liberty",
    "lat": "37.31841",
    "lng": "-84.9394"
  },
  {
    "country": "US",
    "name": "Livermore",
    "lat": "37.4931",
    "lng": "-87.13194"
  },
  {
    "country": "US",
    "name": "London",
    "lat": "37.12898",
    "lng": "-84.08326"
  },
  {
    "country": "US",
    "name": "Louisa",
    "lat": "38.11425",
    "lng": "-82.60321"
  },
  {
    "country": "US",
    "name": "Louisville",
    "lat": "38.25424",
    "lng": "-85.75941"
  },
  {
    "country": "US",
    "name": "Ludlow",
    "lat": "39.09256",
    "lng": "-84.54744"
  },
  {
    "country": "US",
    "name": "Lyndon",
    "lat": "38.25674",
    "lng": "-85.60163"
  },
  {
    "country": "US",
    "name": "Madisonville",
    "lat": "37.3281",
    "lng": "-87.49889"
  },
  {
    "country": "US",
    "name": "Manchester",
    "lat": "37.1537",
    "lng": "-83.76186"
  },
  {
    "country": "US",
    "name": "Marion",
    "lat": "37.33283",
    "lng": "-88.08113"
  },
  {
    "country": "US",
    "name": "Masonville",
    "lat": "37.67505",
    "lng": "-87.03472"
  },
  {
    "country": "US",
    "name": "Massac",
    "lat": "37.01672",
    "lng": "-88.73061"
  },
  {
    "country": "US",
    "name": "Mayfield",
    "lat": "36.74172",
    "lng": "-88.63672"
  },
  {
    "country": "US",
    "name": "Maysville",
    "lat": "38.64119",
    "lng": "-83.74437"
  },
  {
    "country": "US",
    "name": "McKee",
    "lat": "37.43036",
    "lng": "-83.99798"
  },
  {
    "country": "US",
    "name": "Meads",
    "lat": "38.41258",
    "lng": "-82.70905"
  },
  {
    "country": "US",
    "name": "Middlesboro",
    "lat": "36.60842",
    "lng": "-83.71658"
  },
  {
    "country": "US",
    "name": "Middletown",
    "lat": "38.24535",
    "lng": "-85.53885"
  },
  {
    "country": "US",
    "name": "Midway",
    "lat": "38.15091",
    "lng": "-84.68383"
  },
  {
    "country": "US",
    "name": "Heritage Creek",
    "lat": "38.12368",
    "lng": "-85.71968"
  },
  {
    "country": "US",
    "name": "Monticello",
    "lat": "36.82979",
    "lng": "-84.84911"
  },
  {
    "country": "US",
    "name": "Monticello",
    "lat": "37.9923",
    "lng": "-84.55022"
  },
  {
    "country": "US",
    "name": "Morehead",
    "lat": "38.18397",
    "lng": "-83.43268"
  },
  {
    "country": "US",
    "name": "Morehead",
    "lat": "37.27115",
    "lng": "-87.17638"
  },
  {
    "country": "US",
    "name": "Morganfield",
    "lat": "37.68338",
    "lng": "-87.91669"
  },
  {
    "country": "US",
    "name": "Morgantown",
    "lat": "37.2256",
    "lng": "-86.6836"
  },
  {
    "country": "US",
    "name": "Mount Olivet",
    "lat": "38.53146",
    "lng": "-84.03687"
  },
  {
    "country": "US",
    "name": "Mount Sterling",
    "lat": "38.05647",
    "lng": "-83.94326"
  },
  {
    "country": "US",
    "name": "Mount Vernon",
    "lat": "38.02563",
    "lng": "-84.49522"
  },
  {
    "country": "US",
    "name": "Mount Vernon",
    "lat": "37.35286",
    "lng": "-84.34049"
  },
  {
    "country": "US",
    "name": "Mount Washington",
    "lat": "38.05006",
    "lng": "-85.54579"
  },
  {
    "country": "US",
    "name": "Munfordville",
    "lat": "37.27228",
    "lng": "-85.89108"
  },
  {
    "country": "US",
    "name": "Murray",
    "lat": "36.61033",
    "lng": "-88.31476"
  },
  {
    "country": "US",
    "name": "New Castle",
    "lat": "38.4334",
    "lng": "-85.16968"
  },
  {
    "country": "US",
    "name": "Newburg",
    "lat": "38.16007",
    "lng": "-85.65968"
  },
  {
    "country": "US",
    "name": "Newport",
    "lat": "39.09145",
    "lng": "-84.49578"
  },
  {
    "country": "US",
    "name": "Nicholasville",
    "lat": "37.88063",
    "lng": "-84.573"
  },
  {
    "country": "US",
    "name": "North Corbin",
    "lat": "36.96064",
    "lng": "-84.09326"
  },
  {
    "country": "US",
    "name": "Northfield",
    "lat": "38.28701",
    "lng": "-85.64107"
  },
  {
    "country": "US",
    "name": "Nortonville",
    "lat": "37.19088",
    "lng": "-87.45278"
  },
  {
    "country": "US",
    "name": "Oak Grove",
    "lat": "36.66505",
    "lng": "-87.44279"
  },
  {
    "country": "US",
    "name": "Oak Grove",
    "lat": "37.34421",
    "lng": "-86.75471"
  },
  {
    "country": "US",
    "name": "Oakbrook",
    "lat": "38.99978",
    "lng": "-84.68522"
  },
  {
    "country": "US",
    "name": "Okolona",
    "lat": "38.14118",
    "lng": "-85.68774"
  },
  {
    "country": "US",
    "name": "Olive Hill",
    "lat": "38.30008",
    "lng": "-83.17407"
  },
  {
    "country": "US",
    "name": "Orchard Grass Hills",
    "lat": "38.32368",
    "lng": "-85.52135"
  },
  {
    "country": "US",
    "name": "Owensboro",
    "lat": "37.77422",
    "lng": "-87.11333"
  },
  {
    "country": "US",
    "name": "Owenton",
    "lat": "38.53672",
    "lng": "-84.84338"
  },
  {
    "country": "US",
    "name": "Owingsville",
    "lat": "38.1448",
    "lng": "-83.76408"
  },
  {
    "country": "US",
    "name": "Paintsville",
    "lat": "37.81454",
    "lng": "-82.80711"
  },
  {
    "country": "US",
    "name": "Park Hills",
    "lat": "39.07145",
    "lng": "-84.53217"
  },
  {
    "country": "US",
    "name": "Paris",
    "lat": "38.2098",
    "lng": "-84.25299"
  },
  {
    "country": "US",
    "name": "Pewee Valley",
    "lat": "38.31062",
    "lng": "-85.48746"
  },
  {
    "country": "US",
    "name": "Pikeville",
    "lat": "37.47927",
    "lng": "-82.51876"
  },
  {
    "country": "US",
    "name": "Pine Knot",
    "lat": "36.65091",
    "lng": "-84.43855"
  },
  {
    "country": "US",
    "name": "Pineville",
    "lat": "36.76203",
    "lng": "-83.69492"
  },
  {
    "country": "US",
    "name": "Pioneer Village",
    "lat": "38.06062",
    "lng": "-85.67774"
  },
  {
    "country": "US",
    "name": "Plano",
    "lat": "36.88032",
    "lng": "-86.41832"
  },
  {
    "country": "US",
    "name": "Pleasure Ridge Park",
    "lat": "38.14535",
    "lng": "-85.8583"
  },
  {
    "country": "US",
    "name": "Prestonsburg",
    "lat": "37.66565",
    "lng": "-82.77155"
  },
  {
    "country": "US",
    "name": "Princeton",
    "lat": "37.10922",
    "lng": "-87.88196"
  },
  {
    "country": "US",
    "name": "Prospect",
    "lat": "38.34507",
    "lng": "-85.61552"
  },
  {
    "country": "US",
    "name": "Providence",
    "lat": "38.57451",
    "lng": "-85.22107"
  },
  {
    "country": "US",
    "name": "Providence",
    "lat": "37.39755",
    "lng": "-87.76279"
  },
  {
    "country": "US",
    "name": "Raceland",
    "lat": "38.54008",
    "lng": "-82.7285"
  },
  {
    "country": "US",
    "name": "Radcliff",
    "lat": "37.84035",
    "lng": "-85.94913"
  },
  {
    "country": "US",
    "name": "Reidland",
    "lat": "37.01756",
    "lng": "-88.53143"
  },
  {
    "country": "US",
    "name": "Richmond",
    "lat": "37.74786",
    "lng": "-84.29465"
  },
  {
    "country": "US",
    "name": "Russell",
    "lat": "38.5173",
    "lng": "-82.69766"
  },
  {
    "country": "US",
    "name": "Russell Springs",
    "lat": "37.05618",
    "lng": "-85.08857"
  },
  {
    "country": "US",
    "name": "Russellville",
    "lat": "36.84532",
    "lng": "-86.88722"
  },
  {
    "country": "US",
    "name": "Ryland Heights",
    "lat": "38.95756",
    "lng": "-84.463"
  },
  {
    "country": "US",
    "name": "Saint Matthews",
    "lat": "38.25285",
    "lng": "-85.65579"
  },
  {
    "country": "US",
    "name": "Saint Regis Park",
    "lat": "38.22674",
    "lng": "-85.61663"
  },
  {
    "country": "US",
    "name": "Salyersville",
    "lat": "37.75259",
    "lng": "-83.06878"
  },
  {
    "country": "US",
    "name": "Sandy Hook",
    "lat": "38.08647",
    "lng": "-83.12628"
  },
  {
    "country": "US",
    "name": "Scottsville",
    "lat": "36.75338",
    "lng": "-86.19054"
  },
  {
    "country": "US",
    "name": "Sebree",
    "lat": "37.60699",
    "lng": "-87.52862"
  },
  {
    "country": "US",
    "name": "Shelbyville",
    "lat": "38.21201",
    "lng": "-85.22357"
  },
  {
    "country": "US",
    "name": "Shepherdsville",
    "lat": "37.9884",
    "lng": "-85.71579"
  },
  {
    "country": "US",
    "name": "Shively",
    "lat": "38.20007",
    "lng": "-85.82274"
  },
  {
    "country": "US",
    "name": "Silver Grove",
    "lat": "39.03451",
    "lng": "-84.39022"
  },
  {
    "country": "US",
    "name": "Simpsonville",
    "lat": "38.22257",
    "lng": "-85.35523"
  },
  {
    "country": "US",
    "name": "Smithland",
    "lat": "37.13894",
    "lng": "-88.40337"
  },
  {
    "country": "US",
    "name": "Somerset",
    "lat": "37.09202",
    "lng": "-84.60411"
  },
  {
    "country": "US",
    "name": "South Shore",
    "lat": "38.72091",
    "lng": "-82.95823"
  },
  {
    "country": "US",
    "name": "Southgate",
    "lat": "39.072",
    "lng": "-84.47272"
  },
  {
    "country": "US",
    "name": "Springfield",
    "lat": "37.68534",
    "lng": "-85.22218"
  },
  {
    "country": "US",
    "name": "Saint Dennis",
    "lat": "38.1884",
    "lng": "-85.8458"
  },
  {
    "country": "US",
    "name": "Stanford",
    "lat": "37.53119",
    "lng": "-84.66189"
  },
  {
    "country": "US",
    "name": "Stanton",
    "lat": "37.84564",
    "lng": "-83.85825"
  },
  {
    "country": "US",
    "name": "Stearns",
    "lat": "36.69897",
    "lng": "-84.47744"
  },
  {
    "country": "US",
    "name": "Sturgis",
    "lat": "37.54671",
    "lng": "-87.98391"
  },
  {
    "country": "US",
    "name": "Taylor Mill",
    "lat": "38.99756",
    "lng": "-84.49633"
  },
  {
    "country": "US",
    "name": "Taylorsville",
    "lat": "38.03173",
    "lng": "-85.34245"
  },
  {
    "country": "US",
    "name": "Tompkinsville",
    "lat": "36.70228",
    "lng": "-85.69164"
  },
  {
    "country": "US",
    "name": "Union",
    "lat": "38.9459",
    "lng": "-84.6805"
  },
  {
    "country": "US",
    "name": "Van Lear",
    "lat": "37.77121",
    "lng": "-82.75794"
  },
  {
    "country": "US",
    "name": "Valley Station",
    "lat": "38.11118",
    "lng": "-85.87024"
  },
  {
    "country": "US",
    "name": "Vanceburg",
    "lat": "38.59924",
    "lng": "-83.3188"
  },
  {
    "country": "US",
    "name": "Verona",
    "lat": "38.8184",
    "lng": "-84.66078"
  },
  {
    "country": "US",
    "name": "Versailles",
    "lat": "38.05258",
    "lng": "-84.72995"
  },
  {
    "country": "US",
    "name": "Villa Hills",
    "lat": "39.06339",
    "lng": "-84.593"
  },
  {
    "country": "US",
    "name": "Vine Grove",
    "lat": "37.81007",
    "lng": "-85.98135"
  },
  {
    "country": "US",
    "name": "Walton",
    "lat": "38.87562",
    "lng": "-84.61022"
  },
  {
    "country": "US",
    "name": "Warsaw",
    "lat": "38.7834",
    "lng": "-84.90162"
  },
  {
    "country": "US",
    "name": "Watterson Park",
    "lat": "38.19229",
    "lng": "-85.68329"
  },
  {
    "country": "US",
    "name": "West Buechel",
    "lat": "38.19701",
    "lng": "-85.66329"
  },
  {
    "country": "US",
    "name": "West Liberty",
    "lat": "37.92148",
    "lng": "-83.25962"
  },
  {
    "country": "US",
    "name": "Westwood",
    "lat": "38.48314",
    "lng": "-82.66988"
  },
  {
    "country": "US",
    "name": "Whitesburg",
    "lat": "37.11843",
    "lng": "-82.82683"
  },
  {
    "country": "US",
    "name": "Whitley City",
    "lat": "36.72341",
    "lng": "-84.47049"
  },
  {
    "country": "US",
    "name": "Wickliffe",
    "lat": "36.96478",
    "lng": "-89.08923"
  },
  {
    "country": "US",
    "name": "Wilder",
    "lat": "39.05645",
    "lng": "-84.48689"
  },
  {
    "country": "US",
    "name": "Williamsburg",
    "lat": "36.74342",
    "lng": "-84.15966"
  },
  {
    "country": "US",
    "name": "Williamstown",
    "lat": "38.63812",
    "lng": "-84.5605"
  },
  {
    "country": "US",
    "name": "Wilmore",
    "lat": "37.86202",
    "lng": "-84.66161"
  },
  {
    "country": "US",
    "name": "Winchester",
    "lat": "37.99008",
    "lng": "-84.17965"
  },
  {
    "country": "US",
    "name": "Windy Hills",
    "lat": "38.27396",
    "lng": "-85.63441"
  },
  {
    "country": "US",
    "name": "Worthington",
    "lat": "38.54841",
    "lng": "-82.72433"
  },
  {
    "country": "US",
    "name": "Worthington Hills",
    "lat": "38.30896",
    "lng": "-85.5269"
  },
  {
    "country": "US",
    "name": "Worthington",
    "lat": "38.31562",
    "lng": "-85.56163"
  },
  {
    "country": "US",
    "name": "Wurtland",
    "lat": "38.55036",
    "lng": "-82.77794"
  },
  {
    "country": "US",
    "name": "Abbeville",
    "lat": "29.97465",
    "lng": "-92.13429"
  },
  {
    "country": "US",
    "name": "Abita Springs",
    "lat": "30.47864",
    "lng": "-90.04008"
  },
  {
    "country": "US",
    "name": "Addis",
    "lat": "30.3538",
    "lng": "-91.26539"
  },
  {
    "country": "US",
    "name": "Albany",
    "lat": "30.50436",
    "lng": "-90.58231"
  },
  {
    "country": "US",
    "name": "Alexandria",
    "lat": "31.31129",
    "lng": "-92.44514"
  },
  {
    "country": "US",
    "name": "Ama",
    "lat": "29.95215",
    "lng": "-90.29647"
  },
  {
    "country": "US",
    "name": "Amelia",
    "lat": "29.66632",
    "lng": "-91.10204"
  },
  {
    "country": "US",
    "name": "Amite",
    "lat": "30.72657",
    "lng": "-90.50898"
  },
  {
    "country": "US",
    "name": "Arabi",
    "lat": "29.95437",
    "lng": "-90.00535"
  },
  {
    "country": "US",
    "name": "Arcadia",
    "lat": "32.54904",
    "lng": "-92.92016"
  },
  {
    "country": "US",
    "name": "Arnaudville",
    "lat": "30.3977",
    "lng": "-91.93151"
  },
  {
    "country": "US",
    "name": "Avondale",
    "lat": "29.91298",
    "lng": "-90.20369"
  },
  {
    "country": "US",
    "name": "Baker",
    "lat": "30.58824",
    "lng": "-91.16816"
  },
  {
    "country": "US",
    "name": "Baldwin",
    "lat": "29.83798",
    "lng": "-91.54428"
  },
  {
    "country": "US",
    "name": "Ball",
    "lat": "31.41546",
    "lng": "-92.4118"
  },
  {
    "country": "US",
    "name": "Banks Springs",
    "lat": "32.0821",
    "lng": "-92.09291"
  },
  {
    "country": "US",
    "name": "Barataria",
    "lat": "29.72327",
    "lng": "-90.12369"
  },
  {
    "country": "US",
    "name": "Basile",
    "lat": "30.4852",
    "lng": "-92.59597"
  },
  {
    "country": "US",
    "name": "Bastrop",
    "lat": "32.77828",
    "lng": "-91.91144"
  },
  {
    "country": "US",
    "name": "Baton Rouge",
    "lat": "30.45075",
    "lng": "-91.15455"
  },
  {
    "country": "US",
    "name": "Bawcomville",
    "lat": "32.47042",
    "lng": "-92.16736"
  },
  {
    "country": "US",
    "name": "Bayou Cane",
    "lat": "29.6241",
    "lng": "-90.7512"
  },
  {
    "country": "US",
    "name": "Bayou Gauche",
    "lat": "29.78743",
    "lng": "-90.41314"
  },
  {
    "country": "US",
    "name": "Bayou Vista",
    "lat": "29.68965",
    "lng": "-91.27094"
  },
  {
    "country": "US",
    "name": "Belle Chasse",
    "lat": "29.85493",
    "lng": "-89.99063"
  },
  {
    "country": "US",
    "name": "Belle Rose",
    "lat": "30.05048",
    "lng": "-91.04149"
  },
  {
    "country": "US",
    "name": "Benton",
    "lat": "32.69487",
    "lng": "-93.74185"
  },
  {
    "country": "US",
    "name": "Bernice",
    "lat": "32.82209",
    "lng": "-92.65793"
  },
  {
    "country": "US",
    "name": "Berwick",
    "lat": "29.69465",
    "lng": "-91.21899"
  },
  {
    "country": "US",
    "name": "Blanchard",
    "lat": "32.58098",
    "lng": "-93.89268"
  },
  {
    "country": "US",
    "name": "Bogalusa",
    "lat": "30.79102",
    "lng": "-89.84869"
  },
  {
    "country": "US",
    "name": "Bossier City",
    "lat": "32.51599",
    "lng": "-93.73212"
  },
  {
    "country": "US",
    "name": "Bourg",
    "lat": "29.55355",
    "lng": "-90.60231"
  },
  {
    "country": "US",
    "name": "Boutte",
    "lat": "29.90243",
    "lng": "-90.38814"
  },
  {
    "country": "US",
    "name": "Breaux Bridge",
    "lat": "30.27353",
    "lng": "-91.89928"
  },
  {
    "country": "US",
    "name": "Bridge City",
    "lat": "29.93326",
    "lng": "-90.17007"
  },
  {
    "country": "US",
    "name": "Broussard",
    "lat": "30.14715",
    "lng": "-91.96123"
  },
  {
    "country": "US",
    "name": "Brownsfield",
    "lat": "30.54658",
    "lng": "-91.12066"
  },
  {
    "country": "US",
    "name": "Brownsville",
    "lat": "32.48709",
    "lng": "-92.1543"
  },
  {
    "country": "US",
    "name": "Brusly",
    "lat": "30.39436",
    "lng": "-91.25372"
  },
  {
    "country": "US",
    "name": "Bunkie",
    "lat": "30.95325",
    "lng": "-92.18263"
  },
  {
    "country": "US",
    "name": "Cade",
    "lat": "30.08742",
    "lng": "-91.9054"
  },
  {
    "country": "US",
    "name": "Cameron",
    "lat": "29.79772",
    "lng": "-93.32515"
  },
  {
    "country": "US",
    "name": "Campti",
    "lat": "31.8935",
    "lng": "-93.11822"
  },
  {
    "country": "US",
    "name": "Carencro",
    "lat": "30.31714",
    "lng": "-92.04901"
  },
  {
    "country": "US",
    "name": "Carlyss",
    "lat": "30.16882",
    "lng": "-93.37599"
  },
  {
    "country": "US",
    "name": "Carville",
    "lat": "30.21742",
    "lng": "-91.09621"
  },
  {
    "country": "US",
    "name": "Catahoula",
    "lat": "30.21464",
    "lng": "-91.709"
  },
  {
    "country": "US",
    "name": "Cecilia",
    "lat": "30.33714",
    "lng": "-91.85317"
  },
  {
    "country": "US",
    "name": "Central",
    "lat": "30.55435",
    "lng": "-91.03677"
  },
  {
    "country": "US",
    "name": "Chackbay",
    "lat": "29.88354",
    "lng": "-90.79732"
  },
  {
    "country": "US",
    "name": "Chalmette",
    "lat": "29.94296",
    "lng": "-89.96537"
  },
  {
    "country": "US",
    "name": "Charenton",
    "lat": "29.88159",
    "lng": "-91.52511"
  },
  {
    "country": "US",
    "name": "Chauvin",
    "lat": "29.43855",
    "lng": "-90.59537"
  },
  {
    "country": "US",
    "name": "Church Point",
    "lat": "30.40298",
    "lng": "-92.21513"
  },
  {
    "country": "US",
    "name": "Claiborne",
    "lat": "32.51598",
    "lng": "-92.1918"
  },
  {
    "country": "US",
    "name": "Clarks",
    "lat": "32.02655",
    "lng": "-92.13903"
  },
  {
    "country": "US",
    "name": "Clinton",
    "lat": "30.86574",
    "lng": "-91.01566"
  },
  {
    "country": "US",
    "name": "Colfax",
    "lat": "31.51906",
    "lng": "-92.70682"
  },
  {
    "country": "US",
    "name": "Columbia",
    "lat": "32.10516",
    "lng": "-92.07791"
  },
  {
    "country": "US",
    "name": "Convent",
    "lat": "30.02076",
    "lng": "-90.82982"
  },
  {
    "country": "US",
    "name": "Cottonport",
    "lat": "30.98408",
    "lng": "-92.05346"
  },
  {
    "country": "US",
    "name": "Covington",
    "lat": "30.47549",
    "lng": "-90.10042"
  },
  {
    "country": "US",
    "name": "Coushatta",
    "lat": "32.01488",
    "lng": "-93.34212"
  },
  {
    "country": "US",
    "name": "Crowley",
    "lat": "30.21409",
    "lng": "-92.37458"
  },
  {
    "country": "US",
    "name": "Cullen",
    "lat": "32.96903",
    "lng": "-93.45073"
  },
  {
    "country": "US",
    "name": "Cut Off",
    "lat": "29.54272",
    "lng": "-90.33814"
  },
  {
    "country": "US",
    "name": "DeQuincy",
    "lat": "30.45048",
    "lng": "-93.43322"
  },
  {
    "country": "US",
    "name": "DeRidder",
    "lat": "30.84631",
    "lng": "-93.28905"
  },
  {
    "country": "US",
    "name": "Delcambre",
    "lat": "29.94826",
    "lng": "-91.98873"
  },
  {
    "country": "US",
    "name": "Delhi",
    "lat": "32.45764",
    "lng": "-91.49317"
  },
  {
    "country": "US",
    "name": "Denham Springs",
    "lat": "30.4874",
    "lng": "-90.95753"
  },
  {
    "country": "US",
    "name": "Des Allemands",
    "lat": "29.82382",
    "lng": "-90.47508"
  },
  {
    "country": "US",
    "name": "Destrehan",
    "lat": "29.94322",
    "lng": "-90.35345"
  },
  {
    "country": "US",
    "name": "Deville",
    "lat": "31.3574",
    "lng": "-92.16541"
  },
  {
    "country": "US",
    "name": "Donaldsonville",
    "lat": "30.10103",
    "lng": "-90.99288"
  },
  {
    "country": "US",
    "name": "Dulac",
    "lat": "29.38883",
    "lng": "-90.71398"
  },
  {
    "country": "US",
    "name": "Duson",
    "lat": "30.23576",
    "lng": "-92.1854"
  },
  {
    "country": "US",
    "name": "Eastwood",
    "lat": "32.55626",
    "lng": "-93.56712"
  },
  {
    "country": "US",
    "name": "Eden Isle",
    "lat": "30.22853",
    "lng": "-89.79867"
  },
  {
    "country": "US",
    "name": "Edgard",
    "lat": "30.04326",
    "lng": "-90.56009"
  },
  {
    "country": "US",
    "name": "Elmwood",
    "lat": "29.95659",
    "lng": "-90.1898"
  },
  {
    "country": "US",
    "name": "Elton",
    "lat": "30.48131",
    "lng": "-92.6957"
  },
  {
    "country": "US",
    "name": "Erath",
    "lat": "29.95826",
    "lng": "-92.03596"
  },
  {
    "country": "US",
    "name": "Erwinville",
    "lat": "30.53102",
    "lng": "-91.40789"
  },
  {
    "country": "US",
    "name": "Estelle",
    "lat": "29.84576",
    "lng": "-90.10674"
  },
  {
    "country": "US",
    "name": "Eunice",
    "lat": "30.49437",
    "lng": "-92.41763"
  },
  {
    "country": "US",
    "name": "Farmerville",
    "lat": "32.77347",
    "lng": "-92.4057"
  },
  {
    "country": "US",
    "name": "Ferriday",
    "lat": "31.63017",
    "lng": "-91.55456"
  },
  {
    "country": "US",
    "name": "Franklin",
    "lat": "29.79604",
    "lng": "-91.5015"
  },
  {
    "country": "US",
    "name": "Franklinton",
    "lat": "30.84731",
    "lng": "-90.15527"
  },
  {
    "country": "US",
    "name": "French Settlement",
    "lat": "30.29599",
    "lng": "-90.7963"
  },
  {
    "country": "US",
    "name": "Galliano",
    "lat": "29.44216",
    "lng": "-90.29925"
  },
  {
    "country": "US",
    "name": "Gardere",
    "lat": "30.34575",
    "lng": "-91.14011"
  },
  {
    "country": "US",
    "name": "Garyville",
    "lat": "30.05604",
    "lng": "-90.61926"
  },
  {
    "country": "US",
    "name": "Glenmora",
    "lat": "30.97658",
    "lng": "-92.58514"
  },
  {
    "country": "US",
    "name": "Golden Meadow",
    "lat": "29.37911",
    "lng": "-90.26008"
  },
  {
    "country": "US",
    "name": "Gonzales",
    "lat": "30.23853",
    "lng": "-90.9201"
  },
  {
    "country": "US",
    "name": "Grambling",
    "lat": "32.52765",
    "lng": "-92.71404"
  },
  {
    "country": "US",
    "name": "Gramercy",
    "lat": "30.04742",
    "lng": "-90.68981"
  },
  {
    "country": "US",
    "name": "Grand Isle",
    "lat": "29.23662",
    "lng": "-89.98729"
  },
  {
    "country": "US",
    "name": "Grand Point",
    "lat": "30.06131",
    "lng": "-90.75343"
  },
  {
    "country": "US",
    "name": "Gray",
    "lat": "29.69771",
    "lng": "-90.78648"
  },
  {
    "country": "US",
    "name": "Greensburg",
    "lat": "30.83074",
    "lng": "-90.67176"
  },
  {
    "country": "US",
    "name": "Greenwood",
    "lat": "32.44293",
    "lng": "-93.97296"
  },
  {
    "country": "US",
    "name": "Greenwood",
    "lat": "30.54491",
    "lng": "-91.10677"
  },
  {
    "country": "US",
    "name": "Gretna",
    "lat": "29.91465",
    "lng": "-90.05396"
  },
  {
    "country": "US",
    "name": "Gueydan",
    "lat": "30.02604",
    "lng": "-92.50847"
  },
  {
    "country": "US",
    "name": "Hackberry",
    "lat": "29.99605",
    "lng": "-93.3421"
  },
  {
    "country": "US",
    "name": "Hahnville",
    "lat": "29.97659",
    "lng": "-90.40897"
  },
  {
    "country": "US",
    "name": "Hammond",
    "lat": "30.50463",
    "lng": "-90.46293"
  },
  {
    "country": "US",
    "name": "Harahan",
    "lat": "29.94048",
    "lng": "-90.20313"
  },
  {
    "country": "US",
    "name": "Harrisonburg",
    "lat": "31.77211",
    "lng": "-91.82152"
  },
  {
    "country": "US",
    "name": "Harvey",
    "lat": "29.90354",
    "lng": "-90.07729"
  },
  {
    "country": "US",
    "name": "Haughton",
    "lat": "32.53265",
    "lng": "-93.50406"
  },
  {
    "country": "US",
    "name": "Haynesville",
    "lat": "32.96208",
    "lng": "-93.14016"
  },
  {
    "country": "US",
    "name": "Henderson",
    "lat": "30.31325",
    "lng": "-91.79039"
  },
  {
    "country": "US",
    "name": "Homer",
    "lat": "32.79192",
    "lng": "-93.05503"
  },
  {
    "country": "US",
    "name": "Houma",
    "lat": "29.59577",
    "lng": "-90.71953"
  },
  {
    "country": "US",
    "name": "Independence",
    "lat": "30.63551",
    "lng": "-90.50335"
  },
  {
    "country": "US",
    "name": "Inniswold",
    "lat": "30.40491",
    "lng": "-91.08344"
  },
  {
    "country": "US",
    "name": "Iota",
    "lat": "30.33131",
    "lng": "-92.49569"
  },
  {
    "country": "US",
    "name": "Iowa",
    "lat": "30.23687",
    "lng": "-93.01376"
  },
  {
    "country": "US",
    "name": "Jackson",
    "lat": "30.8374",
    "lng": "-91.21761"
  },
  {
    "country": "US",
    "name": "Jean Lafitte",
    "lat": "29.73604",
    "lng": "-90.12674"
  },
  {
    "country": "US",
    "name": "Jeanerette",
    "lat": "29.91104",
    "lng": "-91.66345"
  },
  {
    "country": "US",
    "name": "Jefferson",
    "lat": "29.96604",
    "lng": "-90.15313"
  },
  {
    "country": "US",
    "name": "Jena",
    "lat": "31.68323",
    "lng": "-92.13374"
  },
  {
    "country": "US",
    "name": "Jennings",
    "lat": "30.22243",
    "lng": "-92.65708"
  },
  {
    "country": "US",
    "name": "Jonesboro",
    "lat": "32.24127",
    "lng": "-92.71599"
  },
  {
    "country": "US",
    "name": "Jonesville",
    "lat": "31.62656",
    "lng": "-91.81818"
  },
  {
    "country": "US",
    "name": "Kaplan",
    "lat": "29.99798",
    "lng": "-92.28485"
  },
  {
    "country": "US",
    "name": "Kenner",
    "lat": "29.99409",
    "lng": "-90.24174"
  },
  {
    "country": "US",
    "name": "Kentwood",
    "lat": "30.93824",
    "lng": "-90.50898"
  },
  {
    "country": "US",
    "name": "Killian",
    "lat": "30.35881",
    "lng": "-90.5862"
  },
  {
    "country": "US",
    "name": "Kinder",
    "lat": "30.48548",
    "lng": "-92.8507"
  },
  {
    "country": "US",
    "name": "Krotz Springs",
    "lat": "30.53686",
    "lng": "-91.75289"
  },
  {
    "country": "US",
    "name": "Labadieville",
    "lat": "29.83743",
    "lng": "-90.95621"
  },
  {
    "country": "US",
    "name": "Lacombe",
    "lat": "30.31353",
    "lng": "-89.94313"
  },
  {
    "country": "US",
    "name": "Lafayette",
    "lat": "30.22409",
    "lng": "-92.01984"
  },
  {
    "country": "US",
    "name": "Lake Arthur",
    "lat": "30.08076",
    "lng": "-92.67153"
  },
  {
    "country": "US",
    "name": "Lake Charles",
    "lat": "30.21309",
    "lng": "-93.2044"
  },
  {
    "country": "US",
    "name": "Lake Providence",
    "lat": "32.80499",
    "lng": "-91.17098"
  },
  {
    "country": "US",
    "name": "Lakeshore",
    "lat": "32.53514",
    "lng": "-92.02958"
  },
  {
    "country": "US",
    "name": "Laplace",
    "lat": "30.06698",
    "lng": "-90.48147"
  },
  {
    "country": "US",
    "name": "Larose",
    "lat": "29.57244",
    "lng": "-90.38175"
  },
  {
    "country": "US",
    "name": "Lawtell",
    "lat": "30.51853",
    "lng": "-92.18485"
  },
  {
    "country": "US",
    "name": "Lecompte",
    "lat": "31.09463",
    "lng": "-92.40041"
  },
  {
    "country": "US",
    "name": "Leesville",
    "lat": "31.14352",
    "lng": "-93.261"
  },
  {
    "country": "US",
    "name": "Leonville",
    "lat": "30.47047",
    "lng": "-91.97845"
  },
  {
    "country": "US",
    "name": "Livingston",
    "lat": "30.50213",
    "lng": "-90.74787"
  },
  {
    "country": "US",
    "name": "Livonia",
    "lat": "30.55908",
    "lng": "-91.55594"
  },
  {
    "country": "US",
    "name": "Lockport",
    "lat": "29.64605",
    "lng": "-90.53925"
  },
  {
    "country": "US",
    "name": "Lockport Heights",
    "lat": "29.65049",
    "lng": "-90.54647"
  },
  {
    "country": "US",
    "name": "Logansport",
    "lat": "31.97545",
    "lng": "-93.99797"
  },
  {
    "country": "US",
    "name": "Luling",
    "lat": "29.93215",
    "lng": "-90.36647"
  },
  {
    "country": "US",
    "name": "Lutcher",
    "lat": "30.04048",
    "lng": "-90.69898"
  },
  {
    "country": "US",
    "name": "Mamou",
    "lat": "30.63381",
    "lng": "-92.4193"
  },
  {
    "country": "US",
    "name": "Mandeville",
    "lat": "30.35825",
    "lng": "-90.06563"
  },
  {
    "country": "US",
    "name": "Mansfield",
    "lat": "32.03766",
    "lng": "-93.70018"
  },
  {
    "country": "US",
    "name": "Mansura",
    "lat": "31.05797",
    "lng": "-92.04901"
  },
  {
    "country": "US",
    "name": "Many",
    "lat": "31.56878",
    "lng": "-93.48406"
  },
  {
    "country": "US",
    "name": "Maringouin",
    "lat": "30.4913",
    "lng": "-91.51955"
  },
  {
    "country": "US",
    "name": "Marksville",
    "lat": "31.12797",
    "lng": "-92.06624"
  },
  {
    "country": "US",
    "name": "Marrero",
    "lat": "29.89937",
    "lng": "-90.10035"
  },
  {
    "country": "US",
    "name": "Mathews",
    "lat": "29.68632",
    "lng": "-90.54675"
  },
  {
    "country": "US",
    "name": "Maurice",
    "lat": "30.10854",
    "lng": "-92.12457"
  },
  {
    "country": "US",
    "name": "Melville",
    "lat": "30.69297",
    "lng": "-91.744"
  },
  {
    "country": "US",
    "name": "Meraux",
    "lat": "29.93017",
    "lng": "-89.91623"
  },
  {
    "country": "US",
    "name": "Merrydale",
    "lat": "30.5013",
    "lng": "-91.10844"
  },
  {
    "country": "US",
    "name": "Merryville",
    "lat": "30.75437",
    "lng": "-93.54045"
  },
  {
    "country": "US",
    "name": "Metairie",
    "lat": "29.98409",
    "lng": "-90.15285"
  },
  {
    "country": "US",
    "name": "Metairie Terrace",
    "lat": "29.97854",
    "lng": "-90.16396"
  },
  {
    "country": "US",
    "name": "Midway",
    "lat": "31.69212",
    "lng": "-92.15236"
  },
  {
    "country": "US",
    "name": "Milton",
    "lat": "30.10381",
    "lng": "-92.07651"
  },
  {
    "country": "US",
    "name": "Minden",
    "lat": "32.61543",
    "lng": "-93.28684"
  },
  {
    "country": "US",
    "name": "Minorca",
    "lat": "31.57933",
    "lng": "-91.48179"
  },
  {
    "country": "US",
    "name": "Monroe",
    "lat": "32.50931",
    "lng": "-92.1193"
  },
  {
    "country": "US",
    "name": "Montegut",
    "lat": "30.07076",
    "lng": "-90.50203"
  },
  {
    "country": "US",
    "name": "Montegut",
    "lat": "29.47439",
    "lng": "-90.55703"
  },
  {
    "country": "US",
    "name": "Monticello",
    "lat": "30.48908",
    "lng": "-91.04872"
  },
  {
    "country": "US",
    "name": "Montz",
    "lat": "30.00687",
    "lng": "-90.46869"
  },
  {
    "country": "US",
    "name": "Morgan City",
    "lat": "29.69937",
    "lng": "-91.20677"
  },
  {
    "country": "US",
    "name": "Moss Bluff",
    "lat": "30.3027",
    "lng": "-93.19071"
  },
  {
    "country": "US",
    "name": "Napoleonville",
    "lat": "29.94048",
    "lng": "-91.02482"
  },
  {
    "country": "US",
    "name": "Natalbany",
    "lat": "30.54622",
    "lng": "-90.48619"
  },
  {
    "country": "US",
    "name": "Natchitoches",
    "lat": "31.76072",
    "lng": "-93.08627"
  },
  {
    "country": "US",
    "name": "New Iberia",
    "lat": "30.00354",
    "lng": "-91.81873"
  },
  {
    "country": "US",
    "name": "New Llano",
    "lat": "31.11491",
    "lng": "-93.27155"
  },
  {
    "country": "US",
    "name": "New Orleans",
    "lat": "29.95465",
    "lng": "-90.07507"
  },
  {
    "country": "US",
    "name": "New Roads",
    "lat": "30.70157",
    "lng": "-91.43622"
  },
  {
    "country": "US",
    "name": "New Sarpy",
    "lat": "29.97817",
    "lng": "-90.38963"
  },
  {
    "country": "US",
    "name": "Newellton",
    "lat": "32.07265",
    "lng": "-91.24095"
  },
  {
    "country": "US",
    "name": "Norco",
    "lat": "29.99909",
    "lng": "-90.4123"
  },
  {
    "country": "US",
    "name": "North Vacherie",
    "lat": "29.99687",
    "lng": "-90.70565"
  },
  {
    "country": "US",
    "name": "Oak Grove",
    "lat": "32.86096",
    "lng": "-91.38845"
  },
  {
    "country": "US",
    "name": "Oak Hills Place",
    "lat": "30.35992",
    "lng": "-91.0876"
  },
  {
    "country": "US",
    "name": "Oakdale",
    "lat": "30.81603",
    "lng": "-92.66042"
  },
  {
    "country": "US",
    "name": "Oberlin",
    "lat": "30.6202",
    "lng": "-92.76265"
  },
  {
    "country": "US",
    "name": "Old Jefferson",
    "lat": "30.38269",
    "lng": "-91.01705"
  },
  {
    "country": "US",
    "name": "Olla",
    "lat": "31.90294",
    "lng": "-92.24319"
  },
  {
    "country": "US",
    "name": "Opelousas",
    "lat": "30.53353",
    "lng": "-92.08151"
  },
  {
    "country": "US",
    "name": "Ossun",
    "lat": "30.27603",
    "lng": "-92.11235"
  },
  {
    "country": "US",
    "name": "Paradis",
    "lat": "29.87965",
    "lng": "-90.43397"
  },
  {
    "country": "US",
    "name": "Patterson",
    "lat": "29.69326",
    "lng": "-91.30205"
  },
  {
    "country": "US",
    "name": "Paulina",
    "lat": "30.02631",
    "lng": "-90.71315"
  },
  {
    "country": "US",
    "name": "Pearl River",
    "lat": "30.37603",
    "lng": "-89.7484"
  },
  {
    "country": "US",
    "name": "Pierre Part",
    "lat": "29.9652",
    "lng": "-91.20316"
  },
  {
    "country": "US",
    "name": "Pine Prairie",
    "lat": "30.78381",
    "lng": "-92.42541"
  },
  {
    "country": "US",
    "name": "Pineville",
    "lat": "31.3224",
    "lng": "-92.4343"
  },
  {
    "country": "US",
    "name": "Plaquemine",
    "lat": "30.28908",
    "lng": "-91.23427"
  },
  {
    "country": "US",
    "name": "Ponchatoula",
    "lat": "30.4388",
    "lng": "-90.44148"
  },
  {
    "country": "US",
    "name": "Port Allen",
    "lat": "30.45214",
    "lng": "-91.21011"
  },
  {
    "country": "US",
    "name": "Port Barre",
    "lat": "30.5602",
    "lng": "-91.95401"
  },
  {
    "country": "US",
    "name": "Port Sulphur",
    "lat": "29.48049",
    "lng": "-89.69395"
  },
  {
    "country": "US",
    "name": "Poydras",
    "lat": "29.86937",
    "lng": "-89.88895"
  },
  {
    "country": "US",
    "name": "Prairieville",
    "lat": "30.30297",
    "lng": "-90.97205"
  },
  {
    "country": "US",
    "name": "Presquille",
    "lat": "29.56383",
    "lng": "-90.6462"
  },
  {
    "country": "US",
    "name": "Prien",
    "lat": "30.18187",
    "lng": "-93.27377"
  },
  {
    "country": "US",
    "name": "Raceland",
    "lat": "29.72743",
    "lng": "-90.59898"
  },
  {
    "country": "US",
    "name": "Rayne",
    "lat": "30.23493",
    "lng": "-92.26846"
  },
  {
    "country": "US",
    "name": "Rayville",
    "lat": "32.47736",
    "lng": "-91.75485"
  },
  {
    "country": "US",
    "name": "Reserve",
    "lat": "30.05381",
    "lng": "-90.55175"
  },
  {
    "country": "US",
    "name": "Richwood",
    "lat": "32.44876",
    "lng": "-92.08486"
  },
  {
    "country": "US",
    "name": "Ringgold",
    "lat": "32.32849",
    "lng": "-93.27989"
  },
  {
    "country": "US",
    "name": "River Ridge",
    "lat": "29.9602",
    "lng": "-90.21563"
  },
  {
    "country": "US",
    "name": "Roseland",
    "lat": "30.76491",
    "lng": "-90.51176"
  },
  {
    "country": "US",
    "name": "Rosepine",
    "lat": "30.91991",
    "lng": "-93.28239"
  },
  {
    "country": "US",
    "name": "Ruston",
    "lat": "32.52321",
    "lng": "-92.63793"
  },
  {
    "country": "US",
    "name": "Saint Francisville",
    "lat": "30.7799",
    "lng": "-91.3765"
  },
  {
    "country": "US",
    "name": "Saint Gabriel",
    "lat": "30.2577",
    "lng": "-91.09927"
  },
  {
    "country": "US",
    "name": "Saint Joseph",
    "lat": "31.91849",
    "lng": "-91.23345"
  },
  {
    "country": "US",
    "name": "Saint Martinville",
    "lat": "30.1252",
    "lng": "-91.83345"
  },
  {
    "country": "US",
    "name": "Saint Rose",
    "lat": "29.94687",
    "lng": "-90.32313"
  },
  {
    "country": "US",
    "name": "Schriever",
    "lat": "29.74215",
    "lng": "-90.81037"
  },
  {
    "country": "US",
    "name": "Scott",
    "lat": "30.23576",
    "lng": "-92.09457"
  },
  {
    "country": "US",
    "name": "Shenandoah",
    "lat": "30.4013",
    "lng": "-91.00094"
  },
  {
    "country": "US",
    "name": "Shreveport",
    "lat": "32.52515",
    "lng": "-93.75018"
  },
  {
    "country": "US",
    "name": "Sibley",
    "lat": "32.53932",
    "lng": "-93.29628"
  },
  {
    "country": "US",
    "name": "Simmesport",
    "lat": "30.98352",
    "lng": "-91.80012"
  },
  {
    "country": "US",
    "name": "Slidell",
    "lat": "30.27519",
    "lng": "-89.78117"
  },
  {
    "country": "US",
    "name": "Sorrento",
    "lat": "30.18436",
    "lng": "-90.85926"
  },
  {
    "country": "US",
    "name": "South Vacherie",
    "lat": "29.92743",
    "lng": "-90.69981"
  },
  {
    "country": "US",
    "name": "Springhill",
    "lat": "33.00597",
    "lng": "-93.46684"
  },
  {
    "country": "US",
    "name": "Sterlington",
    "lat": "32.69625",
    "lng": "-92.08597"
  },
  {
    "country": "US",
    "name": "Stonewall",
    "lat": "32.28183",
    "lng": "-93.82407"
  },
  {
    "country": "US",
    "name": "Sulphur",
    "lat": "30.23659",
    "lng": "-93.37738"
  },
  {
    "country": "US",
    "name": "Sunset",
    "lat": "30.41131",
    "lng": "-92.06845"
  },
  {
    "country": "US",
    "name": "Supreme",
    "lat": "29.85937",
    "lng": "-90.98121"
  },
  {
    "country": "US",
    "name": "Swartz",
    "lat": "32.56875",
    "lng": "-91.98513"
  },
  {
    "country": "US",
    "name": "Tallulah",
    "lat": "32.40848",
    "lng": "-91.18678"
  },
  {
    "country": "US",
    "name": "Terrytown",
    "lat": "29.91021",
    "lng": "-90.03257"
  },
  {
    "country": "US",
    "name": "Thibodaux",
    "lat": "29.79576",
    "lng": "-90.82287"
  },
  {
    "country": "US",
    "name": "Timberlane",
    "lat": "29.87743",
    "lng": "-90.03202"
  },
  {
    "country": "US",
    "name": "Urania",
    "lat": "31.86378",
    "lng": "-92.29597"
  },
  {
    "country": "US",
    "name": "Vidalia",
    "lat": "31.56544",
    "lng": "-91.42595"
  },
  {
    "country": "US",
    "name": "Vienna Bend",
    "lat": "31.73239",
    "lng": "-93.041"
  },
  {
    "country": "US",
    "name": "Village Saint George",
    "lat": "30.36214",
    "lng": "-91.06733"
  },
  {
    "country": "US",
    "name": "Ville Platte",
    "lat": "30.68797",
    "lng": "-92.27152"
  },
  {
    "country": "US",
    "name": "Vinton",
    "lat": "30.19076",
    "lng": "-93.58127"
  },
  {
    "country": "US",
    "name": "Violet",
    "lat": "29.89576",
    "lng": "-89.89784"
  },
  {
    "country": "US",
    "name": "Vivian",
    "lat": "32.87153",
    "lng": "-93.9874"
  },
  {
    "country": "US",
    "name": "Waggaman",
    "lat": "29.91854",
    "lng": "-90.21091"
  },
  {
    "country": "US",
    "name": "Walker",
    "lat": "30.48797",
    "lng": "-90.86149"
  },
  {
    "country": "US",
    "name": "Watson",
    "lat": "30.57574",
    "lng": "-90.95316"
  },
  {
    "country": "US",
    "name": "Welsh",
    "lat": "30.23604",
    "lng": "-92.82265"
  },
  {
    "country": "US",
    "name": "West Ferriday",
    "lat": "31.64044",
    "lng": "-91.57318"
  },
  {
    "country": "US",
    "name": "West Monroe",
    "lat": "32.51848",
    "lng": "-92.14764"
  },
  {
    "country": "US",
    "name": "Westlake",
    "lat": "30.24215",
    "lng": "-93.25071"
  },
  {
    "country": "US",
    "name": "Westwego",
    "lat": "29.90604",
    "lng": "-90.1423"
  },
  {
    "country": "US",
    "name": "Westminster",
    "lat": "30.4138",
    "lng": "-91.0876"
  },
  {
    "country": "US",
    "name": "White Castle",
    "lat": "30.16992",
    "lng": "-91.14705"
  },
  {
    "country": "US",
    "name": "Winnfield",
    "lat": "31.92558",
    "lng": "-92.64131"
  },
  {
    "country": "US",
    "name": "Winnsboro",
    "lat": "32.16321",
    "lng": "-91.72068"
  },
  {
    "country": "US",
    "name": "Woodmere",
    "lat": "29.85798",
    "lng": "-90.08035"
  },
  {
    "country": "US",
    "name": "Woodworth",
    "lat": "31.14658",
    "lng": "-92.49736"
  },
  {
    "country": "US",
    "name": "Zachary",
    "lat": "30.64852",
    "lng": "-91.1565"
  },
  {
    "country": "US",
    "name": "Youngsville",
    "lat": "30.09965",
    "lng": "-91.99012"
  },
  {
    "country": "US",
    "name": "Zwolle",
    "lat": "31.63156",
    "lng": "-93.64407"
  },
  {
    "country": "US",
    "name": "Aberdeen",
    "lat": "39.50956",
    "lng": "-76.16412"
  },
  {
    "country": "US",
    "name": "Accokeek",
    "lat": "38.66762",
    "lng": "-77.02831"
  },
  {
    "country": "US",
    "name": "Adamstown",
    "lat": "39.31094",
    "lng": "-77.47471"
  },
  {
    "country": "US",
    "name": "Adelphi",
    "lat": "39.00317",
    "lng": "-76.97192"
  },
  {
    "country": "US",
    "name": "Algonquin",
    "lat": "38.5829",
    "lng": "-76.10577"
  },
  {
    "country": "US",
    "name": "Annapolis",
    "lat": "38.97845",
    "lng": "-76.49218"
  },
  {
    "country": "US",
    "name": "Arbutus",
    "lat": "39.25455",
    "lng": "-76.69997"
  },
  {
    "country": "US",
    "name": "Arden on the Severn",
    "lat": "39.06594",
    "lng": "-76.57885"
  },
  {
    "country": "US",
    "name": "Arnold",
    "lat": "39.03206",
    "lng": "-76.50274"
  },
  {
    "country": "US",
    "name": "Aspen Hill",
    "lat": "39.07955",
    "lng": "-77.07303"
  },
  {
    "country": "US",
    "name": "Baden",
    "lat": "38.65928",
    "lng": "-76.77775"
  },
  {
    "country": "US",
    "name": "Baltimore",
    "lat": "39.29038",
    "lng": "-76.61219"
  },
  {
    "country": "US",
    "name": "Baltimore Highlands",
    "lat": "39.23316",
    "lng": "-76.63663"
  },
  {
    "country": "US",
    "name": "Ballenger Creek",
    "lat": "39.3726",
    "lng": "-77.43526"
  },
  {
    "country": "US",
    "name": "Bartonsville",
    "lat": "39.3926",
    "lng": "-77.35804"
  },
  {
    "country": "US",
    "name": "Bel Air",
    "lat": "39.53594",
    "lng": "-76.34829"
  },
  {
    "country": "US",
    "name": "Bel Air",
    "lat": "39.57314",
    "lng": "-78.84974"
  },
  {
    "country": "US",
    "name": "Beltsville",
    "lat": "39.03483",
    "lng": "-76.90747"
  },
  {
    "country": "US",
    "name": "Bennsville",
    "lat": "38.60929",
    "lng": "-77.0122"
  },
  {
    "country": "US",
    "name": "Berlin",
    "lat": "38.32262",
    "lng": "-75.21769"
  },
  {
    "country": "US",
    "name": "Berwyn Heights",
    "lat": "38.994",
    "lng": "-76.91053"
  },
  {
    "country": "US",
    "name": "Bethesda",
    "lat": "38.98067",
    "lng": "-77.10026"
  },
  {
    "country": "US",
    "name": "Bladensburg",
    "lat": "38.93928",
    "lng": "-76.93386"
  },
  {
    "country": "US",
    "name": "Boonsboro",
    "lat": "39.50621",
    "lng": "-77.65249"
  },
  {
    "country": "US",
    "name": "Bowie",
    "lat": "38.94278",
    "lng": "-76.73028"
  },
  {
    "country": "US",
    "name": "Bowleys Quarters",
    "lat": "39.33539",
    "lng": "-76.39024"
  },
  {
    "country": "US",
    "name": "Bowling Green",
    "lat": "39.6237",
    "lng": "-78.80446"
  },
  {
    "country": "US",
    "name": "Braddock Heights",
    "lat": "39.41871",
    "lng": "-77.5036"
  },
  {
    "country": "US",
    "name": "Brandywine",
    "lat": "38.69678",
    "lng": "-76.84775"
  },
  {
    "country": "US",
    "name": "Brentwood",
    "lat": "38.94317",
    "lng": "-76.95664"
  },
  {
    "country": "US",
    "name": "Brock Hall",
    "lat": "38.85011",
    "lng": "-76.76108"
  },
  {
    "country": "US",
    "name": "Brooklyn Park",
    "lat": "39.22844",
    "lng": "-76.61636"
  },
  {
    "country": "US",
    "name": "Brookmont",
    "lat": "38.94206",
    "lng": "-77.12026"
  },
  {
    "country": "US",
    "name": "Brunswick",
    "lat": "39.31427",
    "lng": "-77.62777"
  },
  {
    "country": "US",
    "name": "Bryans Road",
    "lat": "38.62706",
    "lng": "-77.07303"
  },
  {
    "country": "US",
    "name": "Buckeystown",
    "lat": "39.33482",
    "lng": "-77.43165"
  },
  {
    "country": "US",
    "name": "Burtonsville",
    "lat": "39.11122",
    "lng": "-76.93248"
  },
  {
    "country": "US",
    "name": "Cabin John",
    "lat": "38.97539",
    "lng": "-77.15803"
  },
  {
    "country": "US",
    "name": "California",
    "lat": "38.3004",
    "lng": "-76.50745"
  },
  {
    "country": "US",
    "name": "Calverton",
    "lat": "39.05761",
    "lng": "-76.93581"
  },
  {
    "country": "US",
    "name": "Cambridge",
    "lat": "38.56317",
    "lng": "-76.07883"
  },
  {
    "country": "US",
    "name": "Camp Springs",
    "lat": "38.804",
    "lng": "-76.90664"
  },
  {
    "country": "US",
    "name": "Cape Saint Claire",
    "lat": "39.04317",
    "lng": "-76.44496"
  },
  {
    "country": "US",
    "name": "Capitol Heights",
    "lat": "38.88511",
    "lng": "-76.91581"
  },
  {
    "country": "US",
    "name": "Carney",
    "lat": "39.39427",
    "lng": "-76.52358"
  },
  {
    "country": "US",
    "name": "Catonsville",
    "lat": "39.27205",
    "lng": "-76.73192"
  },
  {
    "country": "US",
    "name": "Cavetown",
    "lat": "39.64426",
    "lng": "-77.58582"
  },
  {
    "country": "US",
    "name": "Centreville",
    "lat": "39.04178",
    "lng": "-76.06633"
  },
  {
    "country": "US",
    "name": "Charlestown",
    "lat": "39.26816",
    "lng": "-76.70525"
  },
  {
    "country": "US",
    "name": "Charlestown",
    "lat": "39.57373",
    "lng": "-75.97495"
  },
  {
    "country": "US",
    "name": "Charlotte Hall",
    "lat": "38.48096",
    "lng": "-76.77802"
  },
  {
    "country": "US",
    "name": "Chesapeake Beach",
    "lat": "38.68623",
    "lng": "-76.53468"
  },
  {
    "country": "US",
    "name": "Chesapeake Ranch Estates",
    "lat": "38.34624",
    "lng": "-76.41773"
  },
  {
    "country": "US",
    "name": "Chester",
    "lat": "38.97539",
    "lng": "-76.2894"
  },
  {
    "country": "US",
    "name": "Chestertown",
    "lat": "39.209",
    "lng": "-76.06661"
  },
  {
    "country": "US",
    "name": "Cheverly",
    "lat": "38.92817",
    "lng": "-76.91581"
  },
  {
    "country": "US",
    "name": "Chevy Chase",
    "lat": "39.00287",
    "lng": "-77.07115"
  },
  {
    "country": "US",
    "name": "Chevy Chase Village",
    "lat": "38.96928",
    "lng": "-77.07887"
  },
  {
    "country": "US",
    "name": "Chillum",
    "lat": "38.96372",
    "lng": "-76.99081"
  },
  {
    "country": "US",
    "name": "Clarksburg",
    "lat": "39.23872",
    "lng": "-77.27943"
  },
  {
    "country": "US",
    "name": "Clover Hill",
    "lat": "39.45621",
    "lng": "-77.42887"
  },
  {
    "country": "US",
    "name": "Cloverly",
    "lat": "39.10816",
    "lng": "-76.99775"
  },
  {
    "country": "US",
    "name": "Clinton",
    "lat": "38.76511",
    "lng": "-76.89831"
  },
  {
    "country": "US",
    "name": "Cockeysville",
    "lat": "39.48122",
    "lng": "-76.64386"
  },
  {
    "country": "US",
    "name": "Colesville",
    "lat": "39.07566",
    "lng": "-77.00192"
  },
  {
    "country": "US",
    "name": "College Park",
    "lat": "38.98067",
    "lng": "-76.93692"
  },
  {
    "country": "US",
    "name": "Colmar Manor",
    "lat": "38.93317",
    "lng": "-76.94581"
  },
  {
    "country": "US",
    "name": "Columbia",
    "lat": "39.24038",
    "lng": "-76.83942"
  },
  {
    "country": "US",
    "name": "Coral Hills",
    "lat": "38.87039",
    "lng": "-76.92108"
  },
  {
    "country": "US",
    "name": "Cottage City",
    "lat": "38.93817",
    "lng": "-76.94831"
  },
  {
    "country": "US",
    "name": "Cresaptown",
    "lat": "39.59287",
    "lng": "-78.83335"
  },
  {
    "country": "US",
    "name": "Crofton",
    "lat": "39.00178",
    "lng": "-76.68747"
  },
  {
    "country": "US",
    "name": "Crisfield",
    "lat": "37.98346",
    "lng": "-75.85382"
  },
  {
    "country": "US",
    "name": "Croom",
    "lat": "38.75262",
    "lng": "-76.76386"
  },
  {
    "country": "US",
    "name": "Crownsville",
    "lat": "39.02844",
    "lng": "-76.60135"
  },
  {
    "country": "US",
    "name": "Cumberland",
    "lat": "39.65287",
    "lng": "-78.76252"
  },
  {
    "country": "US",
    "name": "Damascus",
    "lat": "39.28844",
    "lng": "-77.20387"
  },
  {
    "country": "US",
    "name": "Darnestown",
    "lat": "39.10344",
    "lng": "-77.29082"
  },
  {
    "country": "US",
    "name": "Davidsonville",
    "lat": "38.92289",
    "lng": "-76.6283"
  },
  {
    "country": "US",
    "name": "Deale",
    "lat": "38.77651",
    "lng": "-76.55524"
  },
  {
    "country": "US",
    "name": "Denton",
    "lat": "38.88456",
    "lng": "-75.82716"
  },
  {
    "country": "US",
    "name": "Derwood",
    "lat": "39.11733",
    "lng": "-77.16109"
  },
  {
    "country": "US",
    "name": "District Heights",
    "lat": "38.85761",
    "lng": "-76.88942"
  },
  {
    "country": "US",
    "name": "Drum Point",
    "lat": "38.32679",
    "lng": "-76.42606"
  },
  {
    "country": "US",
    "name": "Dundalk",
    "lat": "39.25066",
    "lng": "-76.52052"
  },
  {
    "country": "US",
    "name": "Dunkirk",
    "lat": "38.72178",
    "lng": "-76.66052"
  },
  {
    "country": "US",
    "name": "Dunkirk Town Center",
    "lat": "38.72039",
    "lng": "-76.65857"
  },
  {
    "country": "US",
    "name": "East Riverdale",
    "lat": "38.96206",
    "lng": "-76.92192"
  },
  {
    "country": "US",
    "name": "Easton",
    "lat": "38.77428",
    "lng": "-76.07633"
  },
  {
    "country": "US",
    "name": "Edgemere",
    "lat": "39.24205",
    "lng": "-76.44802"
  },
  {
    "country": "US",
    "name": "Edgewater",
    "lat": "38.95706",
    "lng": "-76.54996"
  },
  {
    "country": "US",
    "name": "Edgewood",
    "lat": "39.41872",
    "lng": "-76.2944"
  },
  {
    "country": "US",
    "name": "Edmonston",
    "lat": "38.94678",
    "lng": "-76.93109"
  },
  {
    "country": "US",
    "name": "Eldersburg",
    "lat": "39.40371",
    "lng": "-76.95026"
  },
  {
    "country": "US",
    "name": "Elkton",
    "lat": "39.60678",
    "lng": "-75.83327"
  },
  {
    "country": "US",
    "name": "Elkridge",
    "lat": "39.21261",
    "lng": "-76.71358"
  },
  {
    "country": "US",
    "name": "Ellicott City",
    "lat": "39.26733",
    "lng": "-76.79831"
  },
  {
    "country": "US",
    "name": "Emmitsburg",
    "lat": "39.70454",
    "lng": "-77.32693"
  },
  {
    "country": "US",
    "name": "Essex",
    "lat": "39.30927",
    "lng": "-76.47496"
  },
  {
    "country": "US",
    "name": "Fairland",
    "lat": "39.07622",
    "lng": "-76.95775"
  },
  {
    "country": "US",
    "name": "Fairmount Heights",
    "lat": "38.90095",
    "lng": "-76.91553"
  },
  {
    "country": "US",
    "name": "Fallston",
    "lat": "39.51455",
    "lng": "-76.41107"
  },
  {
    "country": "US",
    "name": "Federalsburg",
    "lat": "38.69428",
    "lng": "-75.77216"
  },
  {
    "country": "US",
    "name": "Ferndale",
    "lat": "39.18316",
    "lng": "-76.64024"
  },
  {
    "country": "US",
    "name": "Forest Glen",
    "lat": "39.01455",
    "lng": "-77.0547"
  },
  {
    "country": "US",
    "name": "Forest Heights",
    "lat": "38.80956",
    "lng": "-76.99803"
  },
  {
    "country": "US",
    "name": "Forestville",
    "lat": "38.84511",
    "lng": "-76.87497"
  },
  {
    "country": "US",
    "name": "Fort George G Mead Junction",
    "lat": "39.12594",
    "lng": "-76.78914"
  },
  {
    "country": "US",
    "name": "Fort Washington",
    "lat": "38.70734",
    "lng": "-77.02303"
  },
  {
    "country": "US",
    "name": "Four Corners",
    "lat": "39.02039",
    "lng": "-77.01275"
  },
  {
    "country": "US",
    "name": "Frederick",
    "lat": "39.41427",
    "lng": "-77.41054"
  },
  {
    "country": "US",
    "name": "Friendly",
    "lat": "38.75178",
    "lng": "-76.97859"
  },
  {
    "country": "US",
    "name": "Friendship Village",
    "lat": "38.96289",
    "lng": "-77.08887"
  },
  {
    "country": "US",
    "name": "Frostburg",
    "lat": "39.65814",
    "lng": "-78.92836"
  },
  {
    "country": "US",
    "name": "Fruitland",
    "lat": "38.32206",
    "lng": "-75.6202"
  },
  {
    "country": "US",
    "name": "Fulton",
    "lat": "39.15094",
    "lng": "-76.92303"
  },
  {
    "country": "US",
    "name": "Gaithersburg",
    "lat": "39.14344",
    "lng": "-77.20137"
  },
  {
    "country": "US",
    "name": "Gambrills",
    "lat": "39.06705",
    "lng": "-76.66524"
  },
  {
    "country": "US",
    "name": "Garrett Park",
    "lat": "39.03816",
    "lng": "-77.09303"
  },
  {
    "country": "US",
    "name": "Garrison",
    "lat": "39.40594",
    "lng": "-76.76053"
  },
  {
    "country": "US",
    "name": "Germantown",
    "lat": "39.17316",
    "lng": "-77.27165"
  },
  {
    "country": "US",
    "name": "Glassmanor",
    "lat": "38.819",
    "lng": "-76.99859"
  },
  {
    "country": "US",
    "name": "Glen Burnie",
    "lat": "39.16261",
    "lng": "-76.62469"
  },
  {
    "country": "US",
    "name": "Glenarden",
    "lat": "38.92928",
    "lng": "-76.86164"
  },
  {
    "country": "US",
    "name": "Glenmont",
    "lat": "39.05789",
    "lng": "-77.0497"
  },
  {
    "country": "US",
    "name": "Glenn Dale",
    "lat": "38.98761",
    "lng": "-76.82053"
  },
  {
    "country": "US",
    "name": "Goddard",
    "lat": "38.98955",
    "lng": "-76.85331"
  },
  {
    "country": "US",
    "name": "Golden Beach",
    "lat": "38.48985",
    "lng": "-76.68218"
  },
  {
    "country": "US",
    "name": "Grasonville",
    "lat": "38.95817",
    "lng": "-76.21023"
  },
  {
    "country": "US",
    "name": "Green Haven",
    "lat": "39.13955",
    "lng": "-76.54774"
  },
  {
    "country": "US",
    "name": "Green Valley",
    "lat": "39.30927",
    "lng": "-77.29721"
  },
  {
    "country": "US",
    "name": "Greenbelt",
    "lat": "39.00455",
    "lng": "-76.87553"
  },
  {
    "country": "US",
    "name": "Greensboro",
    "lat": "38.97372",
    "lng": "-75.80493"
  },
  {
    "country": "US",
    "name": "Hagerstown",
    "lat": "39.64176",
    "lng": "-77.71999"
  },
  {
    "country": "US",
    "name": "Halfway",
    "lat": "39.62065",
    "lng": "-77.75888"
  },
  {
    "country": "US",
    "name": "Hampstead",
    "lat": "39.60483",
    "lng": "-76.84998"
  },
  {
    "country": "US",
    "name": "Hampton",
    "lat": "39.42288",
    "lng": "-76.58469"
  },
  {
    "country": "US",
    "name": "Hancock",
    "lat": "39.69898",
    "lng": "-78.17973"
  },
  {
    "country": "US",
    "name": "Hanover",
    "lat": "39.19289",
    "lng": "-76.72414"
  },
  {
    "country": "US",
    "name": "Queen Anne",
    "lat": "38.89872",
    "lng": "-76.6783"
  },
  {
    "country": "US",
    "name": "Havre de Grace",
    "lat": "39.54928",
    "lng": "-76.09162"
  },
  {
    "country": "US",
    "name": "Hebron",
    "lat": "38.42012",
    "lng": "-75.68771"
  },
  {
    "country": "US",
    "name": "Herald Harbor",
    "lat": "39.05372",
    "lng": "-76.56913"
  },
  {
    "country": "US",
    "name": "Highfield-Cascade",
    "lat": "39.71616",
    "lng": "-77.48282"
  },
  {
    "country": "US",
    "name": "Highland",
    "lat": "39.179",
    "lng": "-76.95748"
  },
  {
    "country": "US",
    "name": "Hillandale",
    "lat": "39.0265",
    "lng": "-76.97414"
  },
  {
    "country": "US",
    "name": "Hillcrest Heights",
    "lat": "38.83289",
    "lng": "-76.95942"
  },
  {
    "country": "US",
    "name": "Hillsmere Shores",
    "lat": "38.94011",
    "lng": "-76.49496"
  },
  {
    "country": "US",
    "name": "Hughesville",
    "lat": "38.53262",
    "lng": "-76.78386"
  },
  {
    "country": "US",
    "name": "Hunt Valley",
    "lat": "39.49983",
    "lng": "-76.64108"
  },
  {
    "country": "US",
    "name": "Huntingtown",
    "lat": "38.61595",
    "lng": "-76.61302"
  },
  {
    "country": "US",
    "name": "Huntingtown Town Center",
    "lat": "38.62095",
    "lng": "-76.61607"
  },
  {
    "country": "US",
    "name": "Hurlock",
    "lat": "38.62428",
    "lng": "-75.85438"
  },
  {
    "country": "US",
    "name": "Hyattsville",
    "lat": "38.95594",
    "lng": "-76.94553"
  },
  {
    "country": "US",
    "name": "Ilchester",
    "lat": "39.25094",
    "lng": "-76.76469"
  },
  {
    "country": "US",
    "name": "Indian Head",
    "lat": "38.60012",
    "lng": "-77.1622"
  },
  {
    "country": "US",
    "name": "Jarrettsville",
    "lat": "39.60455",
    "lng": "-76.47774"
  },
  {
    "country": "US",
    "name": "Jefferson",
    "lat": "39.36205",
    "lng": "-77.53165"
  },
  {
    "country": "US",
    "name": "Joppatowne",
    "lat": "39.45789",
    "lng": "-76.35524"
  },
  {
    "country": "US",
    "name": "Keedysville",
    "lat": "39.48621",
    "lng": "-77.69971"
  },
  {
    "country": "US",
    "name": "Kemp Mill",
    "lat": "39.039",
    "lng": "-77.01914"
  },
  {
    "country": "US",
    "name": "Kensington",
    "lat": "39.02567",
    "lng": "-77.07637"
  },
  {
    "country": "US",
    "name": "Kettering",
    "lat": "38.88456",
    "lng": "-76.81469"
  },
  {
    "country": "US",
    "name": "Kingstown",
    "lat": "39.20483",
    "lng": "-76.05133"
  },
  {
    "country": "US",
    "name": "Kingsville",
    "lat": "39.44872",
    "lng": "-76.41774"
  },
  {
    "country": "US",
    "name": "La Plata",
    "lat": "38.52929",
    "lng": "-76.97525"
  },
  {
    "country": "US",
    "name": "La Vale",
    "lat": "39.65564",
    "lng": "-78.81058"
  },
  {
    "country": "US",
    "name": "Lake Arbor",
    "lat": "38.90789",
    "lng": "-76.82969"
  },
  {
    "country": "US",
    "name": "Lake Shore",
    "lat": "39.10705",
    "lng": "-76.48496"
  },
  {
    "country": "US",
    "name": "Landover",
    "lat": "38.934",
    "lng": "-76.89664"
  },
  {
    "country": "US",
    "name": "Landover Hills",
    "lat": "38.94317",
    "lng": "-76.8922"
  },
  {
    "country": "US",
    "name": "Langley Park",
    "lat": "38.98872",
    "lng": "-76.98136"
  },
  {
    "country": "US",
    "name": "Lanham",
    "lat": "38.96875",
    "lng": "-76.8634"
  },
  {
    "country": "US",
    "name": "Lansdowne",
    "lat": "39.24511",
    "lng": "-76.66052"
  },
  {
    "country": "US",
    "name": "Largo",
    "lat": "38.89761",
    "lng": "-76.83025"
  },
  {
    "country": "US",
    "name": "Laurel",
    "lat": "39.09928",
    "lng": "-76.84831"
  },
  {
    "country": "US",
    "name": "Layhill",
    "lat": "39.09233",
    "lng": "-77.04442"
  },
  {
    "country": "US",
    "name": "Leonardtown",
    "lat": "38.29124",
    "lng": "-76.63579"
  },
  {
    "country": "US",
    "name": "Lexington Park",
    "lat": "38.26679",
    "lng": "-76.45384"
  },
  {
    "country": "US",
    "name": "Linganore",
    "lat": "39.44038",
    "lng": "-77.20804"
  },
  {
    "country": "US",
    "name": "Linthicum",
    "lat": "39.20511",
    "lng": "-76.65275"
  },
  {
    "country": "US",
    "name": "Lochearn",
    "lat": "39.34066",
    "lng": "-76.72219"
  },
  {
    "country": "US",
    "name": "Lonaconing",
    "lat": "39.56592",
    "lng": "-78.9803"
  },
  {
    "country": "US",
    "name": "Londontowne",
    "lat": "38.93345",
    "lng": "-76.54941"
  },
  {
    "country": "US",
    "name": "Long Beach",
    "lat": "38.46096",
    "lng": "-76.46884"
  },
  {
    "country": "US",
    "name": "Lusby",
    "lat": "38.41068",
    "lng": "-76.45523"
  },
  {
    "country": "US",
    "name": "Lutherville",
    "lat": "39.42122",
    "lng": "-76.62608"
  },
  {
    "country": "US",
    "name": "Manchester",
    "lat": "39.66121",
    "lng": "-76.88498"
  },
  {
    "country": "US",
    "name": "Marlboro Meadows",
    "lat": "38.83622",
    "lng": "-76.71497"
  },
  {
    "country": "US",
    "name": "Marlow Heights",
    "lat": "38.83345",
    "lng": "-76.95164"
  },
  {
    "country": "US",
    "name": "Marlton",
    "lat": "38.77373",
    "lng": "-76.78997"
  },
  {
    "country": "US",
    "name": "Maryland City",
    "lat": "39.09205",
    "lng": "-76.81775"
  },
  {
    "country": "US",
    "name": "Maugansville",
    "lat": "39.69287",
    "lng": "-77.74472"
  },
  {
    "country": "US",
    "name": "Mayo",
    "lat": "38.88761",
    "lng": "-76.5119"
  },
  {
    "country": "US",
    "name": "Mays Chapel",
    "lat": "39.43316",
    "lng": "-76.64941"
  },
  {
    "country": "US",
    "name": "Mechanicsville",
    "lat": "38.4429",
    "lng": "-76.74385"
  },
  {
    "country": "US",
    "name": "Mellwood",
    "lat": "38.81039",
    "lng": "-76.82414"
  },
  {
    "country": "US",
    "name": "Middle River",
    "lat": "39.33427",
    "lng": "-76.43941"
  },
  {
    "country": "US",
    "name": "Middletown",
    "lat": "39.44371",
    "lng": "-77.54471"
  },
  {
    "country": "US",
    "name": "Milford Mill",
    "lat": "39.34788",
    "lng": "-76.76997"
  },
  {
    "country": "US",
    "name": "Mitchellville",
    "lat": "38.92511",
    "lng": "-76.74275"
  },
  {
    "country": "US",
    "name": "Montgomery Village",
    "lat": "39.17677",
    "lng": "-77.19526"
  },
  {
    "country": "US",
    "name": "Morningside",
    "lat": "38.83011",
    "lng": "-76.89136"
  },
  {
    "country": "US",
    "name": "Mount Airy",
    "lat": "39.37621",
    "lng": "-77.1547"
  },
  {
    "country": "US",
    "name": "Mount Rainier",
    "lat": "38.9415",
    "lng": "-76.96498"
  },
  {
    "country": "US",
    "name": "Mountain Lake Park",
    "lat": "39.39843",
    "lng": "-79.38171"
  },
  {
    "country": "US",
    "name": "Myersville",
    "lat": "39.5051",
    "lng": "-77.56638"
  },
  {
    "country": "US",
    "name": "New Carrollton",
    "lat": "38.96983",
    "lng": "-76.87997"
  },
  {
    "country": "US",
    "name": "New Windsor",
    "lat": "39.54205",
    "lng": "-77.10804"
  },
  {
    "country": "US",
    "name": "North Beach",
    "lat": "38.70734",
    "lng": "-76.53107"
  },
  {
    "country": "US",
    "name": "North Bel Air",
    "lat": "39.53983",
    "lng": "-76.35496"
  },
  {
    "country": "US",
    "name": "North Bethesda",
    "lat": "39.04455",
    "lng": "-77.11887"
  },
  {
    "country": "US",
    "name": "North East",
    "lat": "39.60011",
    "lng": "-75.94133"
  },
  {
    "country": "US",
    "name": "North Kensington",
    "lat": "39.03039",
    "lng": "-77.07248"
  },
  {
    "country": "US",
    "name": "North Laurel",
    "lat": "39.139",
    "lng": "-76.87053"
  },
  {
    "country": "US",
    "name": "North Potomac",
    "lat": "39.08289",
    "lng": "-77.26498"
  },
  {
    "country": "US",
    "name": "Oakland",
    "lat": "39.40787",
    "lng": "-79.40671"
  },
  {
    "country": "US",
    "name": "Ocean City",
    "lat": "38.3365",
    "lng": "-75.08491"
  },
  {
    "country": "US",
    "name": "Ocean Pines",
    "lat": "38.39539",
    "lng": "-75.15574"
  },
  {
    "country": "US",
    "name": "Odenton",
    "lat": "39.084",
    "lng": "-76.70025"
  },
  {
    "country": "US",
    "name": "Olney",
    "lat": "39.15316",
    "lng": "-77.06692"
  },
  {
    "country": "US",
    "name": "Overlea",
    "lat": "39.36344",
    "lng": "-76.52052"
  },
  {
    "country": "US",
    "name": "Owings",
    "lat": "38.71762",
    "lng": "-76.60135"
  },
  {
    "country": "US",
    "name": "Owings Mills",
    "lat": "39.41955",
    "lng": "-76.78025"
  },
  {
    "country": "US",
    "name": "Oxon Hill",
    "lat": "38.80345",
    "lng": "-76.9897"
  },
  {
    "country": "US",
    "name": "Parkville",
    "lat": "39.37733",
    "lng": "-76.53969"
  },
  {
    "country": "US",
    "name": "Parole",
    "lat": "38.97956",
    "lng": "-76.53052"
  },
  {
    "country": "US",
    "name": "Pasadena",
    "lat": "39.10733",
    "lng": "-76.57108"
  },
  {
    "country": "US",
    "name": "Perry Hall",
    "lat": "39.41261",
    "lng": "-76.46357"
  },
  {
    "country": "US",
    "name": "Perryman",
    "lat": "39.46955",
    "lng": "-76.2044"
  },
  {
    "country": "US",
    "name": "Perryville",
    "lat": "39.56011",
    "lng": "-76.07134"
  },
  {
    "country": "US",
    "name": "Pikesville",
    "lat": "39.37427",
    "lng": "-76.72247"
  },
  {
    "country": "US",
    "name": "Pittsville",
    "lat": "38.39539",
    "lng": "-75.41297"
  },
  {
    "country": "US",
    "name": "Pleasant Hills",
    "lat": "39.47955",
    "lng": "-76.39413"
  },
  {
    "country": "US",
    "name": "Pocomoke City",
    "lat": "38.07568",
    "lng": "-75.56798"
  },
  {
    "country": "US",
    "name": "Point of Rocks",
    "lat": "39.27594",
    "lng": "-77.53915"
  },
  {
    "country": "US",
    "name": "Poolesville",
    "lat": "39.14594",
    "lng": "-77.41693"
  },
  {
    "country": "US",
    "name": "Potomac",
    "lat": "39.01817",
    "lng": "-77.20859"
  },
  {
    "country": "US",
    "name": "Potomac Heights",
    "lat": "38.60873",
    "lng": "-77.14053"
  },
  {
    "country": "US",
    "name": "Potomac Park",
    "lat": "39.61176",
    "lng": "-78.80585"
  },
  {
    "country": "US",
    "name": "Prince Frederick",
    "lat": "38.5404",
    "lng": "-76.5844"
  },
  {
    "country": "US",
    "name": "Princess Anne",
    "lat": "38.2029",
    "lng": "-75.69243"
  },
  {
    "country": "US",
    "name": "Pumphrey",
    "lat": "39.21733",
    "lng": "-76.63719"
  },
  {
    "country": "US",
    "name": "Randallstown",
    "lat": "39.36733",
    "lng": "-76.79525"
  },
  {
    "country": "US",
    "name": "Redland",
    "lat": "39.14539",
    "lng": "-77.14415"
  },
  {
    "country": "US",
    "name": "Reisterstown",
    "lat": "39.46976",
    "lng": "-76.8319"
  },
  {
    "country": "US",
    "name": "Ridgely",
    "lat": "38.94789",
    "lng": "-75.88438"
  },
  {
    "country": "US",
    "name": "Rising Sun",
    "lat": "39.69789",
    "lng": "-76.06273"
  },
  {
    "country": "US",
    "name": "Riva",
    "lat": "38.95206",
    "lng": "-76.57802"
  },
  {
    "country": "US",
    "name": "Riverdale Park",
    "lat": "38.96344",
    "lng": "-76.93164"
  },
  {
    "country": "US",
    "name": "Riverside",
    "lat": "39.47372",
    "lng": "-76.24134"
  },
  {
    "country": "US",
    "name": "Riverside",
    "lat": "39.17344",
    "lng": "-76.88525"
  },
  {
    "country": "US",
    "name": "Riviera Beach",
    "lat": "39.16678",
    "lng": "-76.50802"
  },
  {
    "country": "US",
    "name": "Robinwood",
    "lat": "38.95428",
    "lng": "-76.51468"
  },
  {
    "country": "US",
    "name": "Robinwood",
    "lat": "39.63704",
    "lng": "-77.65694"
  },
  {
    "country": "US",
    "name": "Rock Hall",
    "lat": "39.13817",
    "lng": "-76.23495"
  },
  {
    "country": "US",
    "name": "Rockville",
    "lat": "39.084",
    "lng": "-77.15276"
  },
  {
    "country": "US",
    "name": "Rosaryville",
    "lat": "38.75678",
    "lng": "-76.80969"
  },
  {
    "country": "US",
    "name": "Rosedale",
    "lat": "39.32011",
    "lng": "-76.51552"
  },
  {
    "country": "US",
    "name": "Rossmoor",
    "lat": "39.10372",
    "lng": "-77.07109"
  },
  {
    "country": "US",
    "name": "Rossville",
    "lat": "39.33844",
    "lng": "-76.47968"
  },
  {
    "country": "US",
    "name": "Saint Charles",
    "lat": "38.60317",
    "lng": "-76.93858"
  },
  {
    "country": "US",
    "name": "Saint James",
    "lat": "39.5626",
    "lng": "-77.75805"
  },
  {
    "country": "US",
    "name": "Saint Michaels",
    "lat": "38.78512",
    "lng": "-76.22439"
  },
  {
    "country": "US",
    "name": "Salisbury",
    "lat": "38.36067",
    "lng": "-75.59937"
  },
  {
    "country": "US",
    "name": "Savage",
    "lat": "39.13789",
    "lng": "-76.82386"
  },
  {
    "country": "US",
    "name": "Scaggsville",
    "lat": "39.14511",
    "lng": "-76.90025"
  },
  {
    "country": "US",
    "name": "Seabrook",
    "lat": "38.96805",
    "lng": "-76.84658"
  },
  {
    "country": "US",
    "name": "Seat Pleasant",
    "lat": "38.89622",
    "lng": "-76.90664"
  },
  {
    "country": "US",
    "name": "Selby-on-the-Bay",
    "lat": "38.91622",
    "lng": "-76.52246"
  },
  {
    "country": "US",
    "name": "Severn",
    "lat": "39.13705",
    "lng": "-76.6983"
  },
  {
    "country": "US",
    "name": "Severna Park",
    "lat": "39.07039",
    "lng": "-76.54524"
  },
  {
    "country": "US",
    "name": "Shady Side",
    "lat": "38.84178",
    "lng": "-76.51218"
  },
  {
    "country": "US",
    "name": "Silver Hill",
    "lat": "38.84178",
    "lng": "-76.94581"
  },
  {
    "country": "US",
    "name": "Silver Spring",
    "lat": "38.99067",
    "lng": "-77.02609"
  },
  {
    "country": "US",
    "name": "Smithsburg",
    "lat": "39.65482",
    "lng": "-77.57277"
  },
  {
    "country": "US",
    "name": "Snow Hill",
    "lat": "38.17706",
    "lng": "-75.3927"
  },
  {
    "country": "US",
    "name": "Solomons",
    "lat": "38.31846",
    "lng": "-76.45412"
  },
  {
    "country": "US",
    "name": "Somerset",
    "lat": "38.96594",
    "lng": "-77.09609"
  },
  {
    "country": "US",
    "name": "South Bel Air",
    "lat": "39.53316",
    "lng": "-76.33746"
  },
  {
    "country": "US",
    "name": "South Gate",
    "lat": "39.129",
    "lng": "-76.6258"
  },
  {
    "country": "US",
    "name": "South Kensington",
    "lat": "39.019",
    "lng": "-77.07998"
  },
  {
    "country": "US",
    "name": "South Laurel",
    "lat": "39.06983",
    "lng": "-76.85025"
  },
  {
    "country": "US",
    "name": "Spencerville",
    "lat": "39.11427",
    "lng": "-76.97831"
  },
  {
    "country": "US",
    "name": "Spring Ridge",
    "lat": "39.40149",
    "lng": "-77.35248"
  },
  {
    "country": "US",
    "name": "Springdale",
    "lat": "38.93761",
    "lng": "-76.83886"
  },
  {
    "country": "US",
    "name": "Stevensville",
    "lat": "38.98067",
    "lng": "-76.3144"
  },
  {
    "country": "US",
    "name": "Suitland",
    "lat": "38.84872",
    "lng": "-76.92386"
  },
  {
    "country": "US",
    "name": "Sykesville",
    "lat": "39.37371",
    "lng": "-76.96776"
  },
  {
    "country": "US",
    "name": "Takoma Park",
    "lat": "38.97789",
    "lng": "-77.00748"
  },
  {
    "country": "US",
    "name": "Taneytown",
    "lat": "39.65788",
    "lng": "-77.17443"
  },
  {
    "country": "US",
    "name": "Temple Hills",
    "lat": "38.814",
    "lng": "-76.94553"
  },
  {
    "country": "US",
    "name": "Thurmont",
    "lat": "39.62371",
    "lng": "-77.41082"
  },
  {
    "country": "US",
    "name": "Timonium",
    "lat": "39.43705",
    "lng": "-76.61969"
  },
  {
    "country": "US",
    "name": "Towson",
    "lat": "39.4015",
    "lng": "-76.60191"
  },
  {
    "country": "US",
    "name": "Trappe",
    "lat": "38.65845",
    "lng": "-76.058"
  },
  {
    "country": "US",
    "name": "Travilah",
    "lat": "39.069",
    "lng": "-77.26304"
  },
  {
    "country": "US",
    "name": "University Park",
    "lat": "38.97039",
    "lng": "-76.94192"
  },
  {
    "country": "US",
    "name": "Upper Marlboro",
    "lat": "38.81595",
    "lng": "-76.74969"
  },
  {
    "country": "US",
    "name": "Urbana",
    "lat": "39.32594",
    "lng": "-77.35137"
  },
  {
    "country": "US",
    "name": "Waldorf",
    "lat": "38.62456",
    "lng": "-76.93914"
  },
  {
    "country": "US",
    "name": "Walker Mill",
    "lat": "38.87539",
    "lng": "-76.88831"
  },
  {
    "country": "US",
    "name": "Walkersville",
    "lat": "39.48621",
    "lng": "-77.35193"
  },
  {
    "country": "US",
    "name": "West Elkridge",
    "lat": "39.20705",
    "lng": "-76.72692"
  },
  {
    "country": "US",
    "name": "West Laurel",
    "lat": "39.10122",
    "lng": "-76.8997"
  },
  {
    "country": "US",
    "name": "West Ocean City",
    "lat": "38.3315",
    "lng": "-75.10685"
  },
  {
    "country": "US",
    "name": "Westernport",
    "lat": "39.48537",
    "lng": "-79.04475"
  },
  {
    "country": "US",
    "name": "Westminster",
    "lat": "39.57538",
    "lng": "-76.99581"
  },
  {
    "country": "US",
    "name": "Westphalia",
    "lat": "38.84539",
    "lng": "-76.81108"
  },
  {
    "country": "US",
    "name": "Wheaton",
    "lat": "39.03983",
    "lng": "-77.05526"
  },
  {
    "country": "US",
    "name": "White Marsh",
    "lat": "39.38372",
    "lng": "-76.43218"
  },
  {
    "country": "US",
    "name": "White Oak",
    "lat": "39.03983",
    "lng": "-76.99303"
  },
  {
    "country": "US",
    "name": "Williamsport",
    "lat": "39.60065",
    "lng": "-77.82055"
  },
  {
    "country": "US",
    "name": "Woodlawn",
    "lat": "39.32288",
    "lng": "-76.72803"
  },
  {
    "country": "US",
    "name": "Woodlawn",
    "lat": "38.94956",
    "lng": "-76.89136"
  },
  {
    "country": "US",
    "name": "Woodmore",
    "lat": "38.92122",
    "lng": "-76.80303"
  },
  {
    "country": "US",
    "name": "Woodsboro",
    "lat": "39.53316",
    "lng": "-77.31471"
  },
  {
    "country": "US",
    "name": "Adrian",
    "lat": "38.39752",
    "lng": "-94.35162"
  },
  {
    "country": "US",
    "name": "Advance",
    "lat": "37.10455",
    "lng": "-89.90953"
  },
  {
    "country": "US",
    "name": "Affton",
    "lat": "38.55061",
    "lng": "-90.33317"
  },
  {
    "country": "US",
    "name": "Albany",
    "lat": "39.22334",
    "lng": "-94.11328"
  },
  {
    "country": "US",
    "name": "Alton",
    "lat": "36.69423",
    "lng": "-91.3993"
  },
  {
    "country": "US",
    "name": "Anderson",
    "lat": "36.65063",
    "lng": "-94.44355"
  },
  {
    "country": "US",
    "name": "Appleton City",
    "lat": "38.19058",
    "lng": "-94.02939"
  },
  {
    "country": "US",
    "name": "Archie",
    "lat": "38.48168",
    "lng": "-94.35439"
  },
  {
    "country": "US",
    "name": "Arnold",
    "lat": "38.43283",
    "lng": "-90.37762"
  },
  {
    "country": "US",
    "name": "Ash Grove",
    "lat": "37.31533",
    "lng": "-93.5852"
  },
  {
    "country": "US",
    "name": "Ashland",
    "lat": "38.77448",
    "lng": "-92.25713"
  },
  {
    "country": "US",
    "name": "Aurora",
    "lat": "36.97089",
    "lng": "-93.71798"
  },
  {
    "country": "US",
    "name": "Ava",
    "lat": "36.952",
    "lng": "-92.66045"
  },
  {
    "country": "US",
    "name": "Ballwin",
    "lat": "38.59505",
    "lng": "-90.54623"
  },
  {
    "country": "US",
    "name": "Barnhart",
    "lat": "38.34422",
    "lng": "-90.39345"
  },
  {
    "country": "US",
    "name": "Battlefield",
    "lat": "37.11561",
    "lng": "-93.37019"
  },
  {
    "country": "US",
    "name": "Bel-Nor",
    "lat": "38.702",
    "lng": "-90.31678"
  },
  {
    "country": "US",
    "name": "Bel-Ridge",
    "lat": "38.7095",
    "lng": "-90.32539"
  },
  {
    "country": "US",
    "name": "Belle",
    "lat": "38.28588",
    "lng": "-91.72044"
  },
  {
    "country": "US",
    "name": "Bellefontaine Neighbors",
    "lat": "38.74033",
    "lng": "-90.2265"
  },
  {
    "country": "US",
    "name": "Belton",
    "lat": "38.81195",
    "lng": "-94.5319"
  },
  {
    "country": "US",
    "name": "Benton",
    "lat": "37.09783",
    "lng": "-89.56258"
  },
  {
    "country": "US",
    "name": "Berkeley",
    "lat": "38.7545",
    "lng": "-90.33123"
  },
  {
    "country": "US",
    "name": "Bernie",
    "lat": "36.66894",
    "lng": "-89.9687"
  },
  {
    "country": "US",
    "name": "Billings",
    "lat": "37.06755",
    "lng": "-93.55214"
  },
  {
    "country": "US",
    "name": "Bismarck",
    "lat": "37.76922",
    "lng": "-90.62485"
  },
  {
    "country": "US",
    "name": "Black Jack",
    "lat": "38.79338",
    "lng": "-90.26733"
  },
  {
    "country": "US",
    "name": "Bloomfield",
    "lat": "36.88589",
    "lng": "-89.92926"
  },
  {
    "country": "US",
    "name": "Blue Springs",
    "lat": "39.01695",
    "lng": "-94.28161"
  },
  {
    "country": "US",
    "name": "Bolivar",
    "lat": "37.61448",
    "lng": "-93.41047"
  },
  {
    "country": "US",
    "name": "Bonne Terre",
    "lat": "37.92311",
    "lng": "-90.5554"
  },
  {
    "country": "US",
    "name": "Boonville",
    "lat": "38.97364",
    "lng": "-92.74324"
  },
  {
    "country": "US",
    "name": "Bourbon",
    "lat": "38.15477",
    "lng": "-91.24403"
  },
  {
    "country": "US",
    "name": "Bowling Green",
    "lat": "39.34199",
    "lng": "-91.19514"
  },
  {
    "country": "US",
    "name": "Branson",
    "lat": "36.64367",
    "lng": "-93.21851"
  },
  {
    "country": "US",
    "name": "Breckenridge Hills",
    "lat": "38.7145",
    "lng": "-90.36734"
  },
  {
    "country": "US",
    "name": "Brentwood",
    "lat": "38.61755",
    "lng": "-90.34928"
  },
  {
    "country": "US",
    "name": "Bridgeton",
    "lat": "38.767",
    "lng": "-90.41151"
  },
  {
    "country": "US",
    "name": "Brookfield",
    "lat": "39.78447",
    "lng": "-93.07353"
  },
  {
    "country": "US",
    "name": "Buckner",
    "lat": "39.13251",
    "lng": "-94.19856"
  },
  {
    "country": "US",
    "name": "Buffalo",
    "lat": "37.64393",
    "lng": "-93.09241"
  },
  {
    "country": "US",
    "name": "Butler",
    "lat": "38.25863",
    "lng": "-94.33051"
  },
  {
    "country": "US",
    "name": "Byrnes Mill",
    "lat": "38.43783",
    "lng": "-90.58179"
  },
  {
    "country": "US",
    "name": "Cabool",
    "lat": "37.12394",
    "lng": "-92.10127"
  },
  {
    "country": "US",
    "name": "California",
    "lat": "38.62753",
    "lng": "-92.56658"
  },
  {
    "country": "US",
    "name": "Calverton Park",
    "lat": "38.76477",
    "lng": "-90.31373"
  },
  {
    "country": "US",
    "name": "Camdenton",
    "lat": "38.00809",
    "lng": "-92.74463"
  },
  {
    "country": "US",
    "name": "Cameron",
    "lat": "39.74028",
    "lng": "-94.24106"
  },
  {
    "country": "US",
    "name": "Campbell",
    "lat": "36.49339",
    "lng": "-90.07509"
  },
  {
    "country": "US",
    "name": "Cape Girardeau",
    "lat": "37.30588",
    "lng": "-89.51815"
  },
  {
    "country": "US",
    "name": "Carl Junction",
    "lat": "37.17672",
    "lng": "-94.56551"
  },
  {
    "country": "US",
    "name": "Carrollton",
    "lat": "39.35835",
    "lng": "-93.49577"
  },
  {
    "country": "US",
    "name": "Carterville",
    "lat": "37.14923",
    "lng": "-94.443"
  },
  {
    "country": "US",
    "name": "Carthage",
    "lat": "37.17645",
    "lng": "-94.31022"
  },
  {
    "country": "US",
    "name": "Caruthersville",
    "lat": "36.19312",
    "lng": "-89.65564"
  },
  {
    "country": "US",
    "name": "Cassville",
    "lat": "36.67701",
    "lng": "-93.86881"
  },
  {
    "country": "US",
    "name": "Castle Point",
    "lat": "38.75811",
    "lng": "-90.24817"
  },
  {
    "country": "US",
    "name": "Cedar Hill",
    "lat": "38.35339",
    "lng": "-90.64124"
  },
  {
    "country": "US",
    "name": "Centerville",
    "lat": "37.43505",
    "lng": "-90.95846"
  },
  {
    "country": "US",
    "name": "Centralia",
    "lat": "39.21032",
    "lng": "-92.13795"
  },
  {
    "country": "US",
    "name": "Chaffee",
    "lat": "37.18005",
    "lng": "-89.65509"
  },
  {
    "country": "US",
    "name": "Charlack",
    "lat": "38.70255",
    "lng": "-90.34345"
  },
  {
    "country": "US",
    "name": "Charleston",
    "lat": "36.92089",
    "lng": "-89.35063"
  },
  {
    "country": "US",
    "name": "Chesterfield",
    "lat": "38.66311",
    "lng": "-90.57707"
  },
  {
    "country": "US",
    "name": "Chillicothe",
    "lat": "39.79529",
    "lng": "-93.55244"
  },
  {
    "country": "US",
    "name": "Clarkson Valley",
    "lat": "38.61839",
    "lng": "-90.58929"
  },
  {
    "country": "US",
    "name": "Clarkton",
    "lat": "36.45173",
    "lng": "-89.96704"
  },
  {
    "country": "US",
    "name": "Claycomo",
    "lat": "39.2025",
    "lng": "-94.49245"
  },
  {
    "country": "US",
    "name": "Clayton",
    "lat": "38.64255",
    "lng": "-90.32373"
  },
  {
    "country": "US",
    "name": "Clever",
    "lat": "37.03033",
    "lng": "-93.47297"
  },
  {
    "country": "US",
    "name": "Clinton",
    "lat": "38.36863",
    "lng": "-93.77827"
  },
  {
    "country": "US",
    "name": "Cole Camp",
    "lat": "38.46002",
    "lng": "-93.2027"
  },
  {
    "country": "US",
    "name": "Columbia",
    "lat": "38.95171",
    "lng": "-92.33407"
  },
  {
    "country": "US",
    "name": "Concord",
    "lat": "38.5245",
    "lng": "-90.35734"
  },
  {
    "country": "US",
    "name": "Concordia",
    "lat": "38.98335",
    "lng": "-93.56855"
  },
  {
    "country": "US",
    "name": "Cool Valley",
    "lat": "38.72783",
    "lng": "-90.31011"
  },
  {
    "country": "US",
    "name": "Cottleville",
    "lat": "38.74616",
    "lng": "-90.65401"
  },
  {
    "country": "US",
    "name": "Country Club Hills",
    "lat": "38.72088",
    "lng": "-90.27484"
  },
  {
    "country": "US",
    "name": "Country Club Village",
    "lat": "39.83222",
    "lng": "-94.82163"
  },
  {
    "country": "US",
    "name": "Crane",
    "lat": "36.90534",
    "lng": "-93.57158"
  },
  {
    "country": "US",
    "name": "Crestwood",
    "lat": "38.557",
    "lng": "-90.38178"
  },
  {
    "country": "US",
    "name": "Creve Coeur",
    "lat": "38.66089",
    "lng": "-90.42262"
  },
  {
    "country": "US",
    "name": "Crocker",
    "lat": "37.94893",
    "lng": "-92.26378"
  },
  {
    "country": "US",
    "name": "Crystal City",
    "lat": "38.22117",
    "lng": "-90.37901"
  },
  {
    "country": "US",
    "name": "Cuba",
    "lat": "38.06282",
    "lng": "-91.40348"
  },
  {
    "country": "US",
    "name": "Dardenne Prairie",
    "lat": "38.7695",
    "lng": "-90.72902"
  },
  {
    "country": "US",
    "name": "De Soto",
    "lat": "38.1395",
    "lng": "-90.55513"
  },
  {
    "country": "US",
    "name": "Dellwood",
    "lat": "38.7495",
    "lng": "-90.28567"
  },
  {
    "country": "US",
    "name": "Des Peres",
    "lat": "38.60089",
    "lng": "-90.4329"
  },
  {
    "country": "US",
    "name": "Desloge",
    "lat": "37.87088",
    "lng": "-90.52735"
  },
  {
    "country": "US",
    "name": "Dexter",
    "lat": "36.79589",
    "lng": "-89.95787"
  },
  {
    "country": "US",
    "name": "Dixon",
    "lat": "37.99171",
    "lng": "-92.09378"
  },
  {
    "country": "US",
    "name": "Doniphan",
    "lat": "36.62089",
    "lng": "-90.82346"
  },
  {
    "country": "US",
    "name": "Duenweg",
    "lat": "37.08367",
    "lng": "-94.41356"
  },
  {
    "country": "US",
    "name": "Duquesne",
    "lat": "37.07673",
    "lng": "-94.45939"
  },
  {
    "country": "US",
    "name": "East Independence",
    "lat": "39.09556",
    "lng": "-94.35523"
  },
  {
    "country": "US",
    "name": "East Prairie",
    "lat": "36.77978",
    "lng": "-89.38563"
  },
  {
    "country": "US",
    "name": "El Dorado Springs",
    "lat": "37.87698",
    "lng": "-94.02133"
  },
  {
    "country": "US",
    "name": "Eldon",
    "lat": "38.34836",
    "lng": "-92.58158"
  },
  {
    "country": "US",
    "name": "Ellisville",
    "lat": "38.59255",
    "lng": "-90.58707"
  },
  {
    "country": "US",
    "name": "Elsberry",
    "lat": "39.16672",
    "lng": "-90.78096"
  },
  {
    "country": "US",
    "name": "Elvins",
    "lat": "37.83672",
    "lng": "-90.5329"
  },
  {
    "country": "US",
    "name": "Eminence",
    "lat": "37.1506",
    "lng": "-91.35764"
  },
  {
    "country": "US",
    "name": "Esther",
    "lat": "37.85033",
    "lng": "-90.49874"
  },
  {
    "country": "US",
    "name": "Eureka",
    "lat": "38.50255",
    "lng": "-90.6279"
  },
  {
    "country": "US",
    "name": "Excelsior Springs",
    "lat": "39.33917",
    "lng": "-94.22606"
  },
  {
    "country": "US",
    "name": "Fair Grove",
    "lat": "37.38393",
    "lng": "-93.1513"
  },
  {
    "country": "US",
    "name": "Farmington",
    "lat": "37.78088",
    "lng": "-90.42179"
  },
  {
    "country": "US",
    "name": "Fayette",
    "lat": "39.14587",
    "lng": "-92.68379"
  },
  {
    "country": "US",
    "name": "Fenton",
    "lat": "38.51311",
    "lng": "-90.43595"
  },
  {
    "country": "US",
    "name": "Ferguson",
    "lat": "38.74422",
    "lng": "-90.30539"
  },
  {
    "country": "US",
    "name": "Festus",
    "lat": "38.22061",
    "lng": "-90.39595"
  },
  {
    "country": "US",
    "name": "Flat River",
    "lat": "37.85005",
    "lng": "-90.51679"
  },
  {
    "country": "US",
    "name": "Florissant",
    "lat": "38.78922",
    "lng": "-90.32261"
  },
  {
    "country": "US",
    "name": "Forsyth",
    "lat": "36.68506",
    "lng": "-93.1199"
  },
  {
    "country": "US",
    "name": "Four Seasons",
    "lat": "38.19809",
    "lng": "-92.71102"
  },
  {
    "country": "US",
    "name": "Fredericktown",
    "lat": "37.55978",
    "lng": "-90.29401"
  },
  {
    "country": "US",
    "name": "Frontenac",
    "lat": "38.63561",
    "lng": "-90.41512"
  },
  {
    "country": "US",
    "name": "Fulton",
    "lat": "38.84671",
    "lng": "-91.94796"
  },
  {
    "country": "US",
    "name": "Gainesville",
    "lat": "36.60312",
    "lng": "-92.42822"
  },
  {
    "country": "US",
    "name": "Galena",
    "lat": "36.80534",
    "lng": "-93.46658"
  },
  {
    "country": "US",
    "name": "Gallatin",
    "lat": "39.91445",
    "lng": "-93.96217"
  },
  {
    "country": "US",
    "name": "Garden City",
    "lat": "38.56112",
    "lng": "-94.19133"
  },
  {
    "country": "US",
    "name": "Gerald",
    "lat": "38.39977",
    "lng": "-91.33071"
  },
  {
    "country": "US",
    "name": "Gideon",
    "lat": "36.45201",
    "lng": "-89.91926"
  },
  {
    "country": "US",
    "name": "Gladstone",
    "lat": "39.20389",
    "lng": "-94.55468"
  },
  {
    "country": "US",
    "name": "Glasgow Village",
    "lat": "38.75366",
    "lng": "-90.19844"
  },
  {
    "country": "US",
    "name": "Glasgow",
    "lat": "39.22725",
    "lng": "-92.84658"
  },
  {
    "country": "US",
    "name": "Glendale",
    "lat": "38.59589",
    "lng": "-90.37706"
  },
  {
    "country": "US",
    "name": "Goodman",
    "lat": "36.74174",
    "lng": "-94.39911"
  },
  {
    "country": "US",
    "name": "Gower",
    "lat": "39.61083",
    "lng": "-94.5994"
  },
  {
    "country": "US",
    "name": "Grain Valley",
    "lat": "39.01501",
    "lng": "-94.19856"
  },
  {
    "country": "US",
    "name": "Granby",
    "lat": "36.91923",
    "lng": "-94.25522"
  },
  {
    "country": "US",
    "name": "Grandview",
    "lat": "38.88584",
    "lng": "-94.53301"
  },
  {
    "country": "US",
    "name": "Gray Summit",
    "lat": "38.48978",
    "lng": "-90.8168"
  },
  {
    "country": "US",
    "name": "Green Park",
    "lat": "38.52366",
    "lng": "-90.33845"
  },
  {
    "country": "US",
    "name": "Greenfield",
    "lat": "37.41532",
    "lng": "-93.84104"
  },
  {
    "country": "US",
    "name": "Greenville",
    "lat": "37.12727",
    "lng": "-90.45011"
  },
  {
    "country": "US",
    "name": "Greenwood",
    "lat": "38.85168",
    "lng": "-94.34384"
  },
  {
    "country": "US",
    "name": "Hallsville",
    "lat": "39.11699",
    "lng": "-92.22074"
  },
  {
    "country": "US",
    "name": "Hamilton",
    "lat": "39.74362",
    "lng": "-93.99827"
  },
  {
    "country": "US",
    "name": "Hanley Hills",
    "lat": "38.68588",
    "lng": "-90.32373"
  },
  {
    "country": "US",
    "name": "Hannibal",
    "lat": "39.70838",
    "lng": "-91.35848"
  },
  {
    "country": "US",
    "name": "Harrisonville",
    "lat": "38.65334",
    "lng": "-94.34884"
  },
  {
    "country": "US",
    "name": "Hartville",
    "lat": "37.25088",
    "lng": "-92.51044"
  },
  {
    "country": "US",
    "name": "Hayti",
    "lat": "36.23368",
    "lng": "-89.74953"
  },
  {
    "country": "US",
    "name": "Hazelwood",
    "lat": "38.77144",
    "lng": "-90.37095"
  },
  {
    "country": "US",
    "name": "Herculaneum",
    "lat": "38.26839",
    "lng": "-90.38012"
  },
  {
    "country": "US",
    "name": "Hermann",
    "lat": "38.70421",
    "lng": "-91.43738"
  },
  {
    "country": "US",
    "name": "Hermitage",
    "lat": "37.94142",
    "lng": "-93.31631"
  },
  {
    "country": "US",
    "name": "Higginsville",
    "lat": "39.07251",
    "lng": "-93.71716"
  },
  {
    "country": "US",
    "name": "High Ridge",
    "lat": "38.45894",
    "lng": "-90.53651"
  },
  {
    "country": "US",
    "name": "Hillsboro",
    "lat": "38.23228",
    "lng": "-90.5629"
  },
  {
    "country": "US",
    "name": "Hillsdale",
    "lat": "38.68338",
    "lng": "-90.284"
  },
  {
    "country": "US",
    "name": "Holden",
    "lat": "38.71418",
    "lng": "-93.99133"
  },
  {
    "country": "US",
    "name": "Hollister",
    "lat": "36.62117",
    "lng": "-93.21546"
  },
  {
    "country": "US",
    "name": "Holts Summit",
    "lat": "38.64032",
    "lng": "-92.12241"
  },
  {
    "country": "US",
    "name": "Houston",
    "lat": "37.32616",
    "lng": "-91.95599"
  },
  {
    "country": "US",
    "name": "Humansville",
    "lat": "37.79448",
    "lng": "-93.57798"
  },
  {
    "country": "US",
    "name": "Huntsville",
    "lat": "39.44059",
    "lng": "-92.54518"
  },
  {
    "country": "US",
    "name": "Imperial",
    "lat": "38.36978",
    "lng": "-90.37845"
  },
  {
    "country": "US",
    "name": "Independence",
    "lat": "39.09112",
    "lng": "-94.41551"
  },
  {
    "country": "US",
    "name": "Ironton",
    "lat": "37.59727",
    "lng": "-90.62734"
  },
  {
    "country": "US",
    "name": "Jackson",
    "lat": "37.38227",
    "lng": "-89.66621"
  },
  {
    "country": "US",
    "name": "Jefferson City",
    "lat": "38.5767",
    "lng": "-92.17352"
  },
  {
    "country": "US",
    "name": "Jennings",
    "lat": "38.71922",
    "lng": "-90.26039"
  },
  {
    "country": "US",
    "name": "Joplin",
    "lat": "37.08423",
    "lng": "-94.51328"
  },
  {
    "country": "US",
    "name": "Kansas City",
    "lat": "39.09973",
    "lng": "-94.57857"
  },
  {
    "country": "US",
    "name": "Kearney",
    "lat": "39.36778",
    "lng": "-94.36217"
  },
  {
    "country": "US",
    "name": "Kennett",
    "lat": "36.23618",
    "lng": "-90.05565"
  },
  {
    "country": "US",
    "name": "Keytesville",
    "lat": "39.43447",
    "lng": "-92.93825"
  },
  {
    "country": "US",
    "name": "Kimberling City",
    "lat": "36.6334",
    "lng": "-93.41685"
  },
  {
    "country": "US",
    "name": "Kingston",
    "lat": "39.64417",
    "lng": "-94.03855"
  },
  {
    "country": "US",
    "name": "Kirkwood",
    "lat": "38.58339",
    "lng": "-90.40678"
  },
  {
    "country": "US",
    "name": "Kissee Mills",
    "lat": "36.68367",
    "lng": "-93.0499"
  },
  {
    "country": "US",
    "name": "Knob Noster",
    "lat": "38.76668",
    "lng": "-93.55855"
  },
  {
    "country": "US",
    "name": "La Monte",
    "lat": "38.77418",
    "lng": "-93.42521"
  },
  {
    "country": "US",
    "name": "Ladue",
    "lat": "38.64977",
    "lng": "-90.38067"
  },
  {
    "country": "US",
    "name": "Lake Lotawana",
    "lat": "38.92306",
    "lng": "-94.24411"
  },
  {
    "country": "US",
    "name": "Lake Ozark",
    "lat": "38.19864",
    "lng": "-92.6388"
  },
  {
    "country": "US",
    "name": "Lake Saint Louis",
    "lat": "38.79755",
    "lng": "-90.78568"
  },
  {
    "country": "US",
    "name": "Lake Winnebago",
    "lat": "38.8314",
    "lng": "-94.35856"
  },
  {
    "country": "US",
    "name": "Lakeshire",
    "lat": "38.53866",
    "lng": "-90.33512"
  },
  {
    "country": "US",
    "name": "Lamar",
    "lat": "37.49505",
    "lng": "-94.27661"
  },
  {
    "country": "US",
    "name": "Lathrop",
    "lat": "39.54834",
    "lng": "-94.32995"
  },
  {
    "country": "US",
    "name": "Lawson",
    "lat": "39.43834",
    "lng": "-94.20411"
  },
  {
    "country": "US",
    "name": "Leadwood",
    "lat": "37.86727",
    "lng": "-90.59318"
  },
  {
    "country": "US",
    "name": "Lebanon",
    "lat": "37.6806",
    "lng": "-92.66379"
  },
  {
    "country": "US",
    "name": "Lee's Summit",
    "lat": "38.91084",
    "lng": "-94.38217"
  },
  {
    "country": "US",
    "name": "Lemay",
    "lat": "38.53339",
    "lng": "-90.27928"
  },
  {
    "country": "US",
    "name": "Lexington",
    "lat": "39.18473",
    "lng": "-93.87994"
  },
  {
    "country": "US",
    "name": "Liberty",
    "lat": "39.24611",
    "lng": "-94.41912"
  },
  {
    "country": "US",
    "name": "Licking",
    "lat": "37.49949",
    "lng": "-91.8571"
  },
  {
    "country": "US",
    "name": "Lilbourn",
    "lat": "36.59228",
    "lng": "-89.61536"
  },
  {
    "country": "US",
    "name": "Lincoln",
    "lat": "38.39086",
    "lng": "-93.33465"
  },
  {
    "country": "US",
    "name": "Linneus",
    "lat": "39.87863",
    "lng": "-93.18882"
  },
  {
    "country": "US",
    "name": "Lone Jack",
    "lat": "38.87084",
    "lng": "-94.17383"
  },
  {
    "country": "US",
    "name": "Louisiana",
    "lat": "39.44894",
    "lng": "-91.05153"
  },
  {
    "country": "US",
    "name": "Macon",
    "lat": "39.74226",
    "lng": "-92.47269"
  },
  {
    "country": "US",
    "name": "Malden",
    "lat": "36.557",
    "lng": "-89.96648"
  },
  {
    "country": "US",
    "name": "Manchester",
    "lat": "38.597",
    "lng": "-90.50929"
  },
  {
    "country": "US",
    "name": "Mansfield",
    "lat": "37.10672",
    "lng": "-92.58072"
  },
  {
    "country": "US",
    "name": "Maplewood",
    "lat": "38.61255",
    "lng": "-90.32456"
  },
  {
    "country": "US",
    "name": "Marble Hill",
    "lat": "37.30589",
    "lng": "-89.97038"
  },
  {
    "country": "US",
    "name": "Marceline",
    "lat": "39.71197",
    "lng": "-92.94825"
  },
  {
    "country": "US",
    "name": "Marionville",
    "lat": "37.00311",
    "lng": "-93.63742"
  },
  {
    "country": "US",
    "name": "Marlborough",
    "lat": "38.57033",
    "lng": "-90.33706"
  },
  {
    "country": "US",
    "name": "Marshall",
    "lat": "39.12308",
    "lng": "-93.19687"
  },
  {
    "country": "US",
    "name": "Marshfield",
    "lat": "37.33866",
    "lng": "-92.90712"
  },
  {
    "country": "US",
    "name": "Marthasville",
    "lat": "38.62838",
    "lng": "-91.05764"
  },
  {
    "country": "US",
    "name": "Maryland Heights",
    "lat": "38.71311",
    "lng": "-90.42984"
  },
  {
    "country": "US",
    "name": "Maysville",
    "lat": "39.88917",
    "lng": "-94.3619"
  },
  {
    "country": "US",
    "name": "Mehlville",
    "lat": "38.50839",
    "lng": "-90.32289"
  },
  {
    "country": "US",
    "name": "Merriam Woods",
    "lat": "36.71395",
    "lng": "-93.16185"
  },
  {
    "country": "US",
    "name": "Mexico",
    "lat": "39.16976",
    "lng": "-91.88295"
  },
  {
    "country": "US",
    "name": "Moberly",
    "lat": "39.41837",
    "lng": "-92.43824"
  },
  {
    "country": "US",
    "name": "Moline Acres",
    "lat": "38.74699",
    "lng": "-90.24011"
  },
  {
    "country": "US",
    "name": "Monett",
    "lat": "36.92895",
    "lng": "-93.92771"
  },
  {
    "country": "US",
    "name": "Monroe City",
    "lat": "39.65365",
    "lng": "-91.73461"
  },
  {
    "country": "US",
    "name": "Montgomery City",
    "lat": "38.97754",
    "lng": "-91.50488"
  },
  {
    "country": "US",
    "name": "Moscow Mills",
    "lat": "38.94783",
    "lng": "-90.91819"
  },
  {
    "country": "US",
    "name": "Mount Vernon",
    "lat": "37.10367",
    "lng": "-93.81854"
  },
  {
    "country": "US",
    "name": "Mountain Grove",
    "lat": "37.13061",
    "lng": "-92.26349"
  },
  {
    "country": "US",
    "name": "Mountain View",
    "lat": "36.99533",
    "lng": "-91.70376"
  },
  {
    "country": "US",
    "name": "Murphy",
    "lat": "38.49033",
    "lng": "-90.48707"
  },
  {
    "country": "US",
    "name": "Neosho",
    "lat": "36.86896",
    "lng": "-94.368"
  },
  {
    "country": "US",
    "name": "Nevada",
    "lat": "37.83921",
    "lng": "-94.35467"
  },
  {
    "country": "US",
    "name": "New Franklin",
    "lat": "39.01725",
    "lng": "-92.73741"
  },
  {
    "country": "US",
    "name": "New Haven",
    "lat": "38.60838",
    "lng": "-91.21904"
  },
  {
    "country": "US",
    "name": "New London",
    "lat": "39.58532",
    "lng": "-91.40098"
  },
  {
    "country": "US",
    "name": "New Madrid",
    "lat": "36.58645",
    "lng": "-89.52785"
  },
  {
    "country": "US",
    "name": "Nixa",
    "lat": "37.04339",
    "lng": "-93.29435"
  },
  {
    "country": "US",
    "name": "Noel",
    "lat": "36.54563",
    "lng": "-94.48522"
  },
  {
    "country": "US",
    "name": "Normandy",
    "lat": "38.72088",
    "lng": "-90.29734"
  },
  {
    "country": "US",
    "name": "North Kansas City",
    "lat": "39.13",
    "lng": "-94.56218"
  },
  {
    "country": "US",
    "name": "Northwoods",
    "lat": "38.70422",
    "lng": "-90.28345"
  },
  {
    "country": "US",
    "name": "O'Fallon",
    "lat": "38.81061",
    "lng": "-90.69985"
  },
  {
    "country": "US",
    "name": "Oak Grove",
    "lat": "39.00501",
    "lng": "-94.12939"
  },
  {
    "country": "US",
    "name": "Oakland",
    "lat": "38.57644",
    "lng": "-90.38567"
  },
  {
    "country": "US",
    "name": "Oakville",
    "lat": "38.47005",
    "lng": "-90.30456"
  },
  {
    "country": "US",
    "name": "Odessa",
    "lat": "38.99917",
    "lng": "-93.95356"
  },
  {
    "country": "US",
    "name": "Olivette",
    "lat": "38.66533",
    "lng": "-90.37595"
  },
  {
    "country": "US",
    "name": "Oran",
    "lat": "37.08505",
    "lng": "-89.65536"
  },
  {
    "country": "US",
    "name": "Oregon",
    "lat": "39.98694",
    "lng": "-95.14498"
  },
  {
    "country": "US",
    "name": "Oronogo",
    "lat": "37.18839",
    "lng": "-94.47023"
  },
  {
    "country": "US",
    "name": "Osage Beach",
    "lat": "38.12956",
    "lng": "-92.65277"
  },
  {
    "country": "US",
    "name": "Osceola",
    "lat": "38.0467",
    "lng": "-93.70438"
  },
  {
    "country": "US",
    "name": "Overland",
    "lat": "38.70116",
    "lng": "-90.36234"
  },
  {
    "country": "US",
    "name": "Owensville",
    "lat": "38.3456",
    "lng": "-91.50155"
  },
  {
    "country": "US",
    "name": "Ozark",
    "lat": "37.02089",
    "lng": "-93.20602"
  },
  {
    "country": "US",
    "name": "Pacific",
    "lat": "38.482",
    "lng": "-90.74152"
  },
  {
    "country": "US",
    "name": "Pagedale",
    "lat": "38.68338",
    "lng": "-90.30761"
  },
  {
    "country": "US",
    "name": "Palmyra",
    "lat": "39.79421",
    "lng": "-91.52321"
  },
  {
    "country": "US",
    "name": "Paris",
    "lat": "39.48087",
    "lng": "-92.00128"
  },
  {
    "country": "US",
    "name": "Park Hills",
    "lat": "37.85422",
    "lng": "-90.51818"
  },
  {
    "country": "US",
    "name": "Parkville",
    "lat": "39.195",
    "lng": "-94.68218"
  },
  {
    "country": "US",
    "name": "Peculiar",
    "lat": "38.71918",
    "lng": "-94.45856"
  },
  {
    "country": "US",
    "name": "Perryville",
    "lat": "37.72422",
    "lng": "-89.86122"
  },
  {
    "country": "US",
    "name": "Pevely",
    "lat": "38.28339",
    "lng": "-90.39512"
  },
  {
    "country": "US",
    "name": "Piedmont",
    "lat": "37.15449",
    "lng": "-90.69567"
  },
  {
    "country": "US",
    "name": "Pierce City",
    "lat": "36.9459",
    "lng": "-94.00021"
  },
  {
    "country": "US",
    "name": "Pine Lawn",
    "lat": "38.69588",
    "lng": "-90.27511"
  },
  {
    "country": "US",
    "name": "Pineville",
    "lat": "36.59452",
    "lng": "-94.3841"
  },
  {
    "country": "US",
    "name": "Platte City",
    "lat": "39.37028",
    "lng": "-94.78246"
  },
  {
    "country": "US",
    "name": "Plattsburg",
    "lat": "39.56555",
    "lng": "-94.44801"
  },
  {
    "country": "US",
    "name": "Pleasant Hill",
    "lat": "38.78751",
    "lng": "-94.26939"
  },
  {
    "country": "US",
    "name": "Pleasant Valley",
    "lat": "39.21639",
    "lng": "-94.48412"
  },
  {
    "country": "US",
    "name": "Poplar Bluff",
    "lat": "36.757",
    "lng": "-90.39289"
  },
  {
    "country": "US",
    "name": "Portageville",
    "lat": "36.42534",
    "lng": "-89.69953"
  },
  {
    "country": "US",
    "name": "Potosi",
    "lat": "37.93644",
    "lng": "-90.78791"
  },
  {
    "country": "US",
    "name": "Purdy",
    "lat": "36.81729",
    "lng": "-93.92076"
  },
  {
    "country": "US",
    "name": "Raymore",
    "lat": "38.80195",
    "lng": "-94.45273"
  },
  {
    "country": "US",
    "name": "Raytown",
    "lat": "39.00862",
    "lng": "-94.46356"
  },
  {
    "country": "US",
    "name": "Republic",
    "lat": "37.12005",
    "lng": "-93.48019"
  },
  {
    "country": "US",
    "name": "Rich Hill",
    "lat": "38.09642",
    "lng": "-94.36106"
  },
  {
    "country": "US",
    "name": "Richland",
    "lat": "37.85698",
    "lng": "-92.40434"
  },
  {
    "country": "US",
    "name": "Richmond",
    "lat": "39.27862",
    "lng": "-93.97689"
  },
  {
    "country": "US",
    "name": "Richmond Heights",
    "lat": "38.62866",
    "lng": "-90.31956"
  },
  {
    "country": "US",
    "name": "Riverside",
    "lat": "38.28672",
    "lng": "-90.38012"
  },
  {
    "country": "US",
    "name": "Riverside",
    "lat": "39.1775",
    "lng": "-94.61301"
  },
  {
    "country": "US",
    "name": "Riverview",
    "lat": "38.27586",
    "lng": "-93.06964"
  },
  {
    "country": "US",
    "name": "Riverview",
    "lat": "38.74783",
    "lng": "-90.2115"
  },
  {
    "country": "US",
    "name": "Rock Hill",
    "lat": "38.60755",
    "lng": "-90.37845"
  },
  {
    "country": "US",
    "name": "Rogersville",
    "lat": "37.117",
    "lng": "-93.05573"
  },
  {
    "country": "US",
    "name": "Rolla",
    "lat": "37.95143",
    "lng": "-91.77127"
  },
  {
    "country": "US",
    "name": "Saint Ann",
    "lat": "38.72727",
    "lng": "-90.38317"
  },
  {
    "country": "US",
    "name": "Saint Charles",
    "lat": "38.78394",
    "lng": "-90.48123"
  },
  {
    "country": "US",
    "name": "Saint Clair",
    "lat": "38.34533",
    "lng": "-90.98097"
  },
  {
    "country": "US",
    "name": "Saint George",
    "lat": "38.53672",
    "lng": "-90.31484"
  },
  {
    "country": "US",
    "name": "Saint James",
    "lat": "37.99726",
    "lng": "-91.61432"
  },
  {
    "country": "US",
    "name": "Saint John",
    "lat": "38.71484",
    "lng": "-90.34627"
  },
  {
    "country": "US",
    "name": "Saint Johns",
    "lat": "38.71338",
    "lng": "-90.34317"
  },
  {
    "country": "US",
    "name": "Saint Joseph",
    "lat": "39.76861",
    "lng": "-94.84663"
  },
  {
    "country": "US",
    "name": "St. Louis",
    "lat": "38.62727",
    "lng": "-90.19789"
  },
  {
    "country": "US",
    "name": "Saint Martins",
    "lat": "38.5942",
    "lng": "-92.33713"
  },
  {
    "country": "US",
    "name": "Saint Paul",
    "lat": "38.86144",
    "lng": "-90.74179"
  },
  {
    "country": "US",
    "name": "Saint Peters",
    "lat": "38.80033",
    "lng": "-90.62651"
  },
  {
    "country": "US",
    "name": "Saint Robert",
    "lat": "37.8281",
    "lng": "-92.17767"
  },
  {
    "country": "US",
    "name": "Sainte Genevieve",
    "lat": "37.98144",
    "lng": "-90.04178"
  },
  {
    "country": "US",
    "name": "Salem",
    "lat": "37.6456",
    "lng": "-91.53598"
  },
  {
    "country": "US",
    "name": "Salisbury",
    "lat": "39.42392",
    "lng": "-92.80158"
  },
  {
    "country": "US",
    "name": "Sappington",
    "lat": "38.537",
    "lng": "-90.37984"
  },
  {
    "country": "US",
    "name": "Sarcoxie",
    "lat": "37.06923",
    "lng": "-94.1166"
  },
  {
    "country": "US",
    "name": "Savannah",
    "lat": "39.94166",
    "lng": "-94.83025"
  },
  {
    "country": "US",
    "name": "Scott City",
    "lat": "37.21672",
    "lng": "-89.52453"
  },
  {
    "country": "US",
    "name": "Sedalia",
    "lat": "38.70446",
    "lng": "-93.22826"
  },
  {
    "country": "US",
    "name": "Senath",
    "lat": "36.13423",
    "lng": "-90.15982"
  },
  {
    "country": "US",
    "name": "Seneca",
    "lat": "36.84146",
    "lng": "-94.61106"
  },
  {
    "country": "US",
    "name": "Seymour",
    "lat": "37.14644",
    "lng": "-92.76878"
  },
  {
    "country": "US",
    "name": "Shelbina",
    "lat": "39.69393",
    "lng": "-92.04295"
  },
  {
    "country": "US",
    "name": "Shelbyville",
    "lat": "39.80587",
    "lng": "-92.04156"
  },
  {
    "country": "US",
    "name": "Shell Knob",
    "lat": "36.63229",
    "lng": "-93.63436"
  },
  {
    "country": "US",
    "name": "Shrewsbury",
    "lat": "38.59033",
    "lng": "-90.33678"
  },
  {
    "country": "US",
    "name": "Sikeston",
    "lat": "36.87672",
    "lng": "-89.58786"
  },
  {
    "country": "US",
    "name": "Slater",
    "lat": "39.21808",
    "lng": "-93.06909"
  },
  {
    "country": "US",
    "name": "Smithville",
    "lat": "39.38694",
    "lng": "-94.58107"
  },
  {
    "country": "US",
    "name": "Spanish Lake",
    "lat": "38.78783",
    "lng": "-90.21594"
  },
  {
    "country": "US",
    "name": "Sparta",
    "lat": "37.00116",
    "lng": "-93.08157"
  },
  {
    "country": "US",
    "name": "Springfield",
    "lat": "37.21533",
    "lng": "-93.29824"
  },
  {
    "country": "US",
    "name": "Steele",
    "lat": "36.08396",
    "lng": "-89.82925"
  },
  {
    "country": "US",
    "name": "Steelville",
    "lat": "37.9681",
    "lng": "-91.35487"
  },
  {
    "country": "US",
    "name": "Stockton",
    "lat": "37.69893",
    "lng": "-93.79604"
  },
  {
    "country": "US",
    "name": "Stover",
    "lat": "38.44086",
    "lng": "-92.99187"
  },
  {
    "country": "US",
    "name": "Strafford",
    "lat": "37.26838",
    "lng": "-93.11713"
  },
  {
    "country": "US",
    "name": "Sugar Creek",
    "lat": "39.10973",
    "lng": "-94.44467"
  },
  {
    "country": "US",
    "name": "Sullivan",
    "lat": "38.2081",
    "lng": "-91.16042"
  },
  {
    "country": "US",
    "name": "Sunset Hills",
    "lat": "38.53894",
    "lng": "-90.40734"
  },
  {
    "country": "US",
    "name": "Sweet Springs",
    "lat": "38.96363",
    "lng": "-93.41493"
  },
  {
    "country": "US",
    "name": "Taos",
    "lat": "38.50643",
    "lng": "-92.07101"
  },
  {
    "country": "US",
    "name": "Terre du Lac",
    "lat": "37.91172",
    "lng": "-90.62541"
  },
  {
    "country": "US",
    "name": "Thayer",
    "lat": "36.52451",
    "lng": "-91.5382"
  },
  {
    "country": "US",
    "name": "Tipton",
    "lat": "38.65558",
    "lng": "-92.77992"
  },
  {
    "country": "US",
    "name": "Town and Country",
    "lat": "38.61228",
    "lng": "-90.46345"
  },
  {
    "country": "US",
    "name": "Troy",
    "lat": "38.97949",
    "lng": "-90.9807"
  },
  {
    "country": "US",
    "name": "Tuscumbia",
    "lat": "38.23309",
    "lng": "-92.45852"
  },
  {
    "country": "US",
    "name": "Union",
    "lat": "38.45005",
    "lng": "-91.00848"
  },
  {
    "country": "US",
    "name": "University City",
    "lat": "38.65588",
    "lng": "-90.30928"
  },
  {
    "country": "US",
    "name": "Valley Park",
    "lat": "38.54922",
    "lng": "-90.49262"
  },
  {
    "country": "US",
    "name": "Van Buren",
    "lat": "36.99561",
    "lng": "-91.01457"
  },
  {
    "country": "US",
    "name": "Vandalia",
    "lat": "39.31087",
    "lng": "-91.48849"
  },
  {
    "country": "US",
    "name": "Velda Village",
    "lat": "38.69005",
    "lng": "-90.29428"
  },
  {
    "country": "US",
    "name": "Velda Village Hills",
    "lat": "38.69061",
    "lng": "-90.28734"
  },
  {
    "country": "US",
    "name": "Versailles",
    "lat": "38.43141",
    "lng": "-92.84103"
  },
  {
    "country": "US",
    "name": "Vienna",
    "lat": "38.18671",
    "lng": "-91.94711"
  },
  {
    "country": "US",
    "name": "Vinita Park",
    "lat": "38.69005",
    "lng": "-90.34262"
  },
  {
    "country": "US",
    "name": "Wardsville",
    "lat": "38.48892",
    "lng": "-92.17435"
  },
  {
    "country": "US",
    "name": "Warrensburg",
    "lat": "38.76279",
    "lng": "-93.73605"
  },
  {
    "country": "US",
    "name": "Warrenton",
    "lat": "38.81144",
    "lng": "-91.14154"
  },
  {
    "country": "US",
    "name": "Warsaw",
    "lat": "38.24308",
    "lng": "-93.38187"
  },
  {
    "country": "US",
    "name": "Warson Woods",
    "lat": "38.60727",
    "lng": "-90.38345"
  },
  {
    "country": "US",
    "name": "Washington",
    "lat": "38.55811",
    "lng": "-91.01209"
  },
  {
    "country": "US",
    "name": "Waynesville",
    "lat": "37.82865",
    "lng": "-92.20072"
  },
  {
    "country": "US",
    "name": "Weatherby Lake",
    "lat": "39.23778",
    "lng": "-94.69607"
  },
  {
    "country": "US",
    "name": "Webb City",
    "lat": "37.14645",
    "lng": "-94.463"
  },
  {
    "country": "US",
    "name": "Webster Groves",
    "lat": "38.59255",
    "lng": "-90.35734"
  },
  {
    "country": "US",
    "name": "Weldon Spring",
    "lat": "38.71339",
    "lng": "-90.68929"
  },
  {
    "country": "US",
    "name": "Wellston",
    "lat": "38.67283",
    "lng": "-90.29928"
  },
  {
    "country": "US",
    "name": "Wellsville",
    "lat": "39.07198",
    "lng": "-91.57016"
  },
  {
    "country": "US",
    "name": "Wentzville",
    "lat": "38.81144",
    "lng": "-90.85291"
  },
  {
    "country": "US",
    "name": "West Plains",
    "lat": "36.72812",
    "lng": "-91.85237"
  },
  {
    "country": "US",
    "name": "Weston",
    "lat": "39.41111",
    "lng": "-94.90163"
  },
  {
    "country": "US",
    "name": "Wildwood",
    "lat": "38.58283",
    "lng": "-90.6629"
  },
  {
    "country": "US",
    "name": "Willard",
    "lat": "37.30505",
    "lng": "-93.42853"
  },
  {
    "country": "US",
    "name": "Willow Springs",
    "lat": "36.99228",
    "lng": "-91.96987"
  },
  {
    "country": "US",
    "name": "Winchester",
    "lat": "38.59033",
    "lng": "-90.5279"
  },
  {
    "country": "US",
    "name": "Windsor",
    "lat": "38.53224",
    "lng": "-93.52215"
  },
  {
    "country": "US",
    "name": "Winfield",
    "lat": "38.99727",
    "lng": "-90.73846"
  },
  {
    "country": "US",
    "name": "Winona",
    "lat": "37.00977",
    "lng": "-91.32347"
  },
  {
    "country": "US",
    "name": "Woodson Terrace",
    "lat": "38.72505",
    "lng": "-90.35845"
  },
  {
    "country": "US",
    "name": "Wright City",
    "lat": "38.82755",
    "lng": "-91.02014"
  },
  {
    "country": "US",
    "name": "Aberdeen",
    "lat": "33.82511",
    "lng": "-88.54366"
  },
  {
    "country": "US",
    "name": "Ackerman",
    "lat": "33.31012",
    "lng": "-89.17284"
  },
  {
    "country": "US",
    "name": "Amory",
    "lat": "33.98428",
    "lng": "-88.4881"
  },
  {
    "country": "US",
    "name": "Arnold Line",
    "lat": "31.33517",
    "lng": "-89.3734"
  },
  {
    "country": "US",
    "name": "Ashland",
    "lat": "34.83287",
    "lng": "-89.1759"
  },
  {
    "country": "US",
    "name": "Baldwyn",
    "lat": "34.50954",
    "lng": "-88.63533"
  },
  {
    "country": "US",
    "name": "Batesville",
    "lat": "34.3115",
    "lng": "-89.94426"
  },
  {
    "country": "US",
    "name": "Bay Saint Louis",
    "lat": "30.30881",
    "lng": "-89.33005"
  },
  {
    "country": "US",
    "name": "Bay Springs",
    "lat": "31.97904",
    "lng": "-89.28728"
  },
  {
    "country": "US",
    "name": "Beechwood",
    "lat": "32.32765",
    "lng": "-90.82677"
  },
  {
    "country": "US",
    "name": "Belmont",
    "lat": "31.56877",
    "lng": "-88.48391"
  },
  {
    "country": "US",
    "name": "Belmont",
    "lat": "34.50982",
    "lng": "-88.20921"
  },
  {
    "country": "US",
    "name": "Belzoni",
    "lat": "33.18429",
    "lng": "-90.48926"
  },
  {
    "country": "US",
    "name": "Biloxi",
    "lat": "30.39603",
    "lng": "-88.88531"
  },
  {
    "country": "US",
    "name": "Booneville",
    "lat": "34.65815",
    "lng": "-88.56672"
  },
  {
    "country": "US",
    "name": "Brandon",
    "lat": "32.2732",
    "lng": "-89.98592"
  },
  {
    "country": "US",
    "name": "Brookhaven",
    "lat": "31.57906",
    "lng": "-90.44065"
  },
  {
    "country": "US",
    "name": "Brooksville",
    "lat": "33.23457",
    "lng": "-88.58227"
  },
  {
    "country": "US",
    "name": "Bruce",
    "lat": "33.99206",
    "lng": "-89.34896"
  },
  {
    "country": "US",
    "name": "Bude",
    "lat": "31.46295",
    "lng": "-90.8501"
  },
  {
    "country": "US",
    "name": "Byhalia",
    "lat": "34.87232",
    "lng": "-89.69064"
  },
  {
    "country": "US",
    "name": "Byram",
    "lat": "32.17932",
    "lng": "-90.24537"
  },
  {
    "country": "US",
    "name": "Caledonia",
    "lat": "33.68289",
    "lng": "-88.32448"
  },
  {
    "country": "US",
    "name": "Calhoun City",
    "lat": "33.85539",
    "lng": "-89.31146"
  },
  {
    "country": "US",
    "name": "Canton",
    "lat": "32.61264",
    "lng": "-90.03675"
  },
  {
    "country": "US",
    "name": "Carriere",
    "lat": "30.61686",
    "lng": "-89.65256"
  },
  {
    "country": "US",
    "name": "Carrollton",
    "lat": "33.50818",
    "lng": "-89.92036"
  },
  {
    "country": "US",
    "name": "Carthage",
    "lat": "32.73264",
    "lng": "-89.53618"
  },
  {
    "country": "US",
    "name": "Centreville",
    "lat": "31.08962",
    "lng": "-91.06844"
  },
  {
    "country": "US",
    "name": "Charleston",
    "lat": "34.00678",
    "lng": "-90.05676"
  },
  {
    "country": "US",
    "name": "Clarksdale",
    "lat": "34.20011",
    "lng": "-90.57093"
  },
  {
    "country": "US",
    "name": "Cleary",
    "lat": "32.16543",
    "lng": "-90.18064"
  },
  {
    "country": "US",
    "name": "Cleveland",
    "lat": "33.744",
    "lng": "-90.72482"
  },
  {
    "country": "US",
    "name": "Clinton",
    "lat": "32.34153",
    "lng": "-90.32176"
  },
  {
    "country": "US",
    "name": "Coldwater",
    "lat": "32.71486",
    "lng": "-89.21423"
  },
  {
    "country": "US",
    "name": "Coldwater",
    "lat": "34.69177",
    "lng": "-89.97731"
  },
  {
    "country": "US",
    "name": "Collins",
    "lat": "31.64544",
    "lng": "-89.55535"
  },
  {
    "country": "US",
    "name": "Collinsville",
    "lat": "32.49792",
    "lng": "-88.84588"
  },
  {
    "country": "US",
    "name": "Columbus",
    "lat": "33.49567",
    "lng": "-88.42726"
  },
  {
    "country": "US",
    "name": "Columbia",
    "lat": "31.25184",
    "lng": "-89.83758"
  },
  {
    "country": "US",
    "name": "Como",
    "lat": "34.51066",
    "lng": "-89.93981"
  },
  {
    "country": "US",
    "name": "Conehatta",
    "lat": "32.45125",
    "lng": "-89.28534"
  },
  {
    "country": "US",
    "name": "Corinth",
    "lat": "34.93425",
    "lng": "-88.52227"
  },
  {
    "country": "US",
    "name": "Crystal Springs",
    "lat": "31.98738",
    "lng": "-90.35704"
  },
  {
    "country": "US",
    "name": "D'Iberville",
    "lat": "30.42631",
    "lng": "-88.89086"
  },
  {
    "country": "US",
    "name": "De Kalb",
    "lat": "32.76763",
    "lng": "-88.65088"
  },
  {
    "country": "US",
    "name": "De Lisle",
    "lat": "30.37936",
    "lng": "-89.26449"
  },
  {
    "country": "US",
    "name": "Decatur",
    "lat": "32.43903",
    "lng": "-89.10839"
  },
  {
    "country": "US",
    "name": "Derma",
    "lat": "33.85567",
    "lng": "-89.28452"
  },
  {
    "country": "US",
    "name": "Diamondhead",
    "lat": "30.39464",
    "lng": "-89.36394"
  },
  {
    "country": "US",
    "name": "Drew",
    "lat": "33.80956",
    "lng": "-90.52648"
  },
  {
    "country": "US",
    "name": "Duck Hill",
    "lat": "33.63318",
    "lng": "-89.71119"
  },
  {
    "country": "US",
    "name": "Durant",
    "lat": "33.07513",
    "lng": "-89.85453"
  },
  {
    "country": "US",
    "name": "Edwards",
    "lat": "32.33015",
    "lng": "-90.60565"
  },
  {
    "country": "US",
    "name": "Ellisville",
    "lat": "31.60405",
    "lng": "-89.19561"
  },
  {
    "country": "US",
    "name": "Escatawpa",
    "lat": "30.44048",
    "lng": "-88.54363"
  },
  {
    "country": "US",
    "name": "Eupora",
    "lat": "33.54068",
    "lng": "-89.26701"
  },
  {
    "country": "US",
    "name": "Farmington",
    "lat": "34.93009",
    "lng": "-88.45227"
  },
  {
    "country": "US",
    "name": "Fayette",
    "lat": "31.71155",
    "lng": "-91.06066"
  },
  {
    "country": "US",
    "name": "Flora",
    "lat": "32.5432",
    "lng": "-90.30926"
  },
  {
    "country": "US",
    "name": "Florence",
    "lat": "32.15348",
    "lng": "-90.1312"
  },
  {
    "country": "US",
    "name": "Flowood",
    "lat": "32.30959",
    "lng": "-90.13898"
  },
  {
    "country": "US",
    "name": "Forest",
    "lat": "32.36459",
    "lng": "-89.47423"
  },
  {
    "country": "US",
    "name": "Friars Point",
    "lat": "34.36677",
    "lng": "-90.6376"
  },
  {
    "country": "US",
    "name": "Fulton",
    "lat": "34.27399",
    "lng": "-88.40921"
  },
  {
    "country": "US",
    "name": "Gautier",
    "lat": "30.38575",
    "lng": "-88.61169"
  },
  {
    "country": "US",
    "name": "Glendale",
    "lat": "31.36462",
    "lng": "-89.30617"
  },
  {
    "country": "US",
    "name": "Goodman",
    "lat": "32.97013",
    "lng": "-89.91231"
  },
  {
    "country": "US",
    "name": "Greenville",
    "lat": "33.41012",
    "lng": "-91.06177"
  },
  {
    "country": "US",
    "name": "Greenwood",
    "lat": "33.51623",
    "lng": "-90.17953"
  },
  {
    "country": "US",
    "name": "Grenada",
    "lat": "33.769",
    "lng": "-89.80842"
  },
  {
    "country": "US",
    "name": "Gulf Hills",
    "lat": "30.43048",
    "lng": "-88.84225"
  },
  {
    "country": "US",
    "name": "Gulf Park Estates",
    "lat": "30.39187",
    "lng": "-88.76114"
  },
  {
    "country": "US",
    "name": "Gulfport",
    "lat": "30.36742",
    "lng": "-89.09282"
  },
  {
    "country": "US",
    "name": "Guntown",
    "lat": "34.44316",
    "lng": "-88.65978"
  },
  {
    "country": "US",
    "name": "Hattiesburg",
    "lat": "31.32712",
    "lng": "-89.29034"
  },
  {
    "country": "US",
    "name": "Hazlehurst",
    "lat": "31.86044",
    "lng": "-90.39593"
  },
  {
    "country": "US",
    "name": "Helena",
    "lat": "30.49464",
    "lng": "-88.49585"
  },
  {
    "country": "US",
    "name": "Hernando",
    "lat": "34.82399",
    "lng": "-89.9937"
  },
  {
    "country": "US",
    "name": "Hickory Hills",
    "lat": "30.45687",
    "lng": "-88.63919"
  },
  {
    "country": "US",
    "name": "Hillsboro",
    "lat": "32.45931",
    "lng": "-89.51146"
  },
  {
    "country": "US",
    "name": "Hollandale",
    "lat": "33.16901",
    "lng": "-90.85399"
  },
  {
    "country": "US",
    "name": "Holly Springs",
    "lat": "31.31573",
    "lng": "-89.97786"
  },
  {
    "country": "US",
    "name": "Holly Springs",
    "lat": "34.7676",
    "lng": "-89.44869"
  },
  {
    "country": "US",
    "name": "Horn Lake",
    "lat": "34.95537",
    "lng": "-90.03481"
  },
  {
    "country": "US",
    "name": "Houston",
    "lat": "33.89845",
    "lng": "-88.99923"
  },
  {
    "country": "US",
    "name": "Hurley",
    "lat": "30.66103",
    "lng": "-88.49418"
  },
  {
    "country": "US",
    "name": "Indianola",
    "lat": "33.45095",
    "lng": "-90.65509"
  },
  {
    "country": "US",
    "name": "Itta Bena",
    "lat": "33.49512",
    "lng": "-90.31981"
  },
  {
    "country": "US",
    "name": "Iuka",
    "lat": "34.81176",
    "lng": "-88.19004"
  },
  {
    "country": "US",
    "name": "Jackson",
    "lat": "32.29876",
    "lng": "-90.18481"
  },
  {
    "country": "US",
    "name": "Jonestown",
    "lat": "34.31955",
    "lng": "-90.45565"
  },
  {
    "country": "US",
    "name": "Kearney Park",
    "lat": "32.58903",
    "lng": "-90.31537"
  },
  {
    "country": "US",
    "name": "Kiln",
    "lat": "30.40908",
    "lng": "-89.43505"
  },
  {
    "country": "US",
    "name": "Kosciusko",
    "lat": "33.058",
    "lng": "-89.58956"
  },
  {
    "country": "US",
    "name": "Lambert",
    "lat": "34.20178",
    "lng": "-90.28343"
  },
  {
    "country": "US",
    "name": "Latimer",
    "lat": "30.53464",
    "lng": "-88.8667"
  },
  {
    "country": "US",
    "name": "Laurel",
    "lat": "31.69405",
    "lng": "-89.13061"
  },
  {
    "country": "US",
    "name": "Leakesville",
    "lat": "31.15574",
    "lng": "-88.5578"
  },
  {
    "country": "US",
    "name": "Leland",
    "lat": "33.40539",
    "lng": "-90.8976"
  },
  {
    "country": "US",
    "name": "Lexington",
    "lat": "33.11318",
    "lng": "-90.05314"
  },
  {
    "country": "US",
    "name": "Liberty",
    "lat": "31.15823",
    "lng": "-90.81232"
  },
  {
    "country": "US",
    "name": "Long Beach",
    "lat": "30.35048",
    "lng": "-89.15282"
  },
  {
    "country": "US",
    "name": "Louisville",
    "lat": "33.12374",
    "lng": "-89.05506"
  },
  {
    "country": "US",
    "name": "Lucedale",
    "lat": "30.92519",
    "lng": "-88.59002"
  },
  {
    "country": "US",
    "name": "Lumberton",
    "lat": "31.00129",
    "lng": "-89.45229"
  },
  {
    "country": "US",
    "name": "Lyman",
    "lat": "30.49474",
    "lng": "-89.12561"
  },
  {
    "country": "US",
    "name": "Lynchburg",
    "lat": "34.96232",
    "lng": "-90.09593"
  },
  {
    "country": "US",
    "name": "Lynchburg",
    "lat": "32.44014",
    "lng": "-90.54899"
  },
  {
    "country": "US",
    "name": "Macon",
    "lat": "33.1054",
    "lng": "-88.56088"
  },
  {
    "country": "US",
    "name": "Madison",
    "lat": "32.46181",
    "lng": "-90.11536"
  },
  {
    "country": "US",
    "name": "Magee",
    "lat": "31.87377",
    "lng": "-89.73369"
  },
  {
    "country": "US",
    "name": "Magnolia",
    "lat": "31.14323",
    "lng": "-90.45871"
  },
  {
    "country": "US",
    "name": "Mantachie",
    "lat": "34.32427",
    "lng": "-88.49116"
  },
  {
    "country": "US",
    "name": "Marion",
    "lat": "32.41736",
    "lng": "-88.64782"
  },
  {
    "country": "US",
    "name": "Marks",
    "lat": "34.25683",
    "lng": "-90.27298"
  },
  {
    "country": "US",
    "name": "Mayersville",
    "lat": "32.90207",
    "lng": "-91.05122"
  },
  {
    "country": "US",
    "name": "McComb",
    "lat": "31.24379",
    "lng": "-90.45315"
  },
  {
    "country": "US",
    "name": "Meadville",
    "lat": "31.47239",
    "lng": "-90.89677"
  },
  {
    "country": "US",
    "name": "Mendenhall",
    "lat": "31.96182",
    "lng": "-89.87008"
  },
  {
    "country": "US",
    "name": "Meridian",
    "lat": "32.36431",
    "lng": "-88.70366"
  },
  {
    "country": "US",
    "name": "Metcalfe",
    "lat": "33.454",
    "lng": "-91.00733"
  },
  {
    "country": "US",
    "name": "Mikoma",
    "lat": "33.95039",
    "lng": "-90.28398"
  },
  {
    "country": "US",
    "name": "Monticello",
    "lat": "31.55378",
    "lng": "-90.10731"
  },
  {
    "country": "US",
    "name": "Moorhead",
    "lat": "33.45012",
    "lng": "-90.50564"
  },
  {
    "country": "US",
    "name": "Morgantown",
    "lat": "31.57267",
    "lng": "-91.34761"
  },
  {
    "country": "US",
    "name": "Morton",
    "lat": "32.35376",
    "lng": "-89.65452"
  },
  {
    "country": "US",
    "name": "Moss Point",
    "lat": "30.41159",
    "lng": "-88.53446"
  },
  {
    "country": "US",
    "name": "Mound Bayou",
    "lat": "33.87817",
    "lng": "-90.72732"
  },
  {
    "country": "US",
    "name": "Natchez",
    "lat": "31.56044",
    "lng": "-91.40317"
  },
  {
    "country": "US",
    "name": "Nellieburg",
    "lat": "32.40681",
    "lng": "-88.77727"
  },
  {
    "country": "US",
    "name": "Nettleton",
    "lat": "34.089",
    "lng": "-88.62227"
  },
  {
    "country": "US",
    "name": "New Albany",
    "lat": "34.49427",
    "lng": "-89.00784"
  },
  {
    "country": "US",
    "name": "New Augusta",
    "lat": "31.20263",
    "lng": "-89.03668"
  },
  {
    "country": "US",
    "name": "New Hope",
    "lat": "33.46817",
    "lng": "-88.3267"
  },
  {
    "country": "US",
    "name": "Newton",
    "lat": "32.32126",
    "lng": "-89.16339"
  },
  {
    "country": "US",
    "name": "Nicholson",
    "lat": "30.47714",
    "lng": "-89.69367"
  },
  {
    "country": "US",
    "name": "North Tunica",
    "lat": "34.70093",
    "lng": "-90.37815"
  },
  {
    "country": "US",
    "name": "Ocean Springs",
    "lat": "30.41131",
    "lng": "-88.82781"
  },
  {
    "country": "US",
    "name": "Okolona",
    "lat": "34.00178",
    "lng": "-88.75533"
  },
  {
    "country": "US",
    "name": "Olive Branch",
    "lat": "34.96176",
    "lng": "-89.82953"
  },
  {
    "country": "US",
    "name": "Oxford",
    "lat": "34.3665",
    "lng": "-89.51925"
  },
  {
    "country": "US",
    "name": "Pascagoula",
    "lat": "30.36576",
    "lng": "-88.55613"
  },
  {
    "country": "US",
    "name": "Pass Christian",
    "lat": "30.31575",
    "lng": "-89.24754"
  },
  {
    "country": "US",
    "name": "Pearl",
    "lat": "32.27459",
    "lng": "-90.13203"
  },
  {
    "country": "US",
    "name": "Pearl River",
    "lat": "32.78347",
    "lng": "-89.22784"
  },
  {
    "country": "US",
    "name": "Pearlington",
    "lat": "30.24658",
    "lng": "-89.61117"
  },
  {
    "country": "US",
    "name": "Pelahatchie",
    "lat": "32.31292",
    "lng": "-89.79841"
  },
  {
    "country": "US",
    "name": "Petal",
    "lat": "31.34656",
    "lng": "-89.26006"
  },
  {
    "country": "US",
    "name": "Philadelphia",
    "lat": "32.77152",
    "lng": "-89.11673"
  },
  {
    "country": "US",
    "name": "Picayune",
    "lat": "30.52556",
    "lng": "-89.67788"
  },
  {
    "country": "US",
    "name": "Pickens",
    "lat": "32.88374",
    "lng": "-89.97147"
  },
  {
    "country": "US",
    "name": "Pittsboro",
    "lat": "33.94039",
    "lng": "-89.33757"
  },
  {
    "country": "US",
    "name": "Plantersville",
    "lat": "34.21344",
    "lng": "-88.6645"
  },
  {
    "country": "US",
    "name": "Pontotoc",
    "lat": "34.24788",
    "lng": "-88.99867"
  },
  {
    "country": "US",
    "name": "Poplarville",
    "lat": "30.84019",
    "lng": "-89.53423"
  },
  {
    "country": "US",
    "name": "Port Gibson",
    "lat": "31.96099",
    "lng": "-90.98399"
  },
  {
    "country": "US",
    "name": "Prentiss",
    "lat": "31.5985",
    "lng": "-89.86702"
  },
  {
    "country": "US",
    "name": "Purvis",
    "lat": "31.14324",
    "lng": "-89.40979"
  },
  {
    "country": "US",
    "name": "Quitman",
    "lat": "32.04015",
    "lng": "-88.7281"
  },
  {
    "country": "US",
    "name": "Raleigh",
    "lat": "32.03349",
    "lng": "-89.52229"
  },
  {
    "country": "US",
    "name": "Rawls Springs",
    "lat": "31.38073",
    "lng": "-89.37145"
  },
  {
    "country": "US",
    "name": "Raymond",
    "lat": "32.25931",
    "lng": "-90.4226"
  },
  {
    "country": "US",
    "name": "Richland",
    "lat": "32.23904",
    "lng": "-90.15842"
  },
  {
    "country": "US",
    "name": "Richton",
    "lat": "31.34934",
    "lng": "-88.94005"
  },
  {
    "country": "US",
    "name": "Ridgeland",
    "lat": "32.42848",
    "lng": "-90.13231"
  },
  {
    "country": "US",
    "name": "Ripley",
    "lat": "34.72982",
    "lng": "-88.95062"
  },
  {
    "country": "US",
    "name": "Rolling Fork",
    "lat": "32.90652",
    "lng": "-90.87816"
  },
  {
    "country": "US",
    "name": "Ruleville",
    "lat": "33.72595",
    "lng": "-90.55148"
  },
  {
    "country": "US",
    "name": "Saltillo",
    "lat": "34.37649",
    "lng": "-88.68172"
  },
  {
    "country": "US",
    "name": "Sardis",
    "lat": "34.43705",
    "lng": "-89.91592"
  },
  {
    "country": "US",
    "name": "Saucier",
    "lat": "30.63575",
    "lng": "-89.13504"
  },
  {
    "country": "US",
    "name": "Senatobia",
    "lat": "34.6176",
    "lng": "-89.9687"
  },
  {
    "country": "US",
    "name": "Shannon",
    "lat": "34.11622",
    "lng": "-88.71172"
  },
  {
    "country": "US",
    "name": "Sharon",
    "lat": "31.7896",
    "lng": "-89.09867"
  },
  {
    "country": "US",
    "name": "Shelby",
    "lat": "33.95094",
    "lng": "-90.76788"
  },
  {
    "country": "US",
    "name": "Southaven",
    "lat": "34.98898",
    "lng": "-90.01259"
  },
  {
    "country": "US",
    "name": "Saint Martin",
    "lat": "30.43798",
    "lng": "-88.86809"
  },
  {
    "country": "US",
    "name": "Starkville",
    "lat": "33.45049",
    "lng": "-88.81961"
  },
  {
    "country": "US",
    "name": "Stonewall",
    "lat": "32.13181",
    "lng": "-88.79338"
  },
  {
    "country": "US",
    "name": "Summit",
    "lat": "31.28379",
    "lng": "-90.46843"
  },
  {
    "country": "US",
    "name": "Sumrall",
    "lat": "31.41739",
    "lng": "-89.54229"
  },
  {
    "country": "US",
    "name": "Sunflower",
    "lat": "33.5429",
    "lng": "-90.53703"
  },
  {
    "country": "US",
    "name": "Taylorsville",
    "lat": "31.8296",
    "lng": "-89.42812"
  },
  {
    "country": "US",
    "name": "Tchula",
    "lat": "33.1829",
    "lng": "-90.22286"
  },
  {
    "country": "US",
    "name": "Terry",
    "lat": "32.09626",
    "lng": "-90.29426"
  },
  {
    "country": "US",
    "name": "Tunica",
    "lat": "34.68455",
    "lng": "-90.38288"
  },
  {
    "country": "US",
    "name": "Tupelo",
    "lat": "34.25807",
    "lng": "-88.70464"
  },
  {
    "country": "US",
    "name": "Tutwiler",
    "lat": "34.01483",
    "lng": "-90.43176"
  },
  {
    "country": "US",
    "name": "Tylertown",
    "lat": "31.11601",
    "lng": "-90.14203"
  },
  {
    "country": "US",
    "name": "Union",
    "lat": "32.57153",
    "lng": "-89.12145"
  },
  {
    "country": "US",
    "name": "University",
    "lat": "34.36594",
    "lng": "-89.52536"
  },
  {
    "country": "US",
    "name": "Vancleave",
    "lat": "30.54047",
    "lng": "-88.68752"
  },
  {
    "country": "US",
    "name": "Vardaman",
    "lat": "33.87567",
    "lng": "-89.17729"
  },
  {
    "country": "US",
    "name": "Verona",
    "lat": "34.19427",
    "lng": "-88.71977"
  },
  {
    "country": "US",
    "name": "Vicksburg",
    "lat": "32.35265",
    "lng": "-90.87788"
  },
  {
    "country": "US",
    "name": "Wade",
    "lat": "30.64242",
    "lng": "-88.56974"
  },
  {
    "country": "US",
    "name": "Walls",
    "lat": "34.95824",
    "lng": "-90.15256"
  },
  {
    "country": "US",
    "name": "Walnut Grove",
    "lat": "32.59042",
    "lng": "-89.4584"
  },
  {
    "country": "US",
    "name": "Walthall",
    "lat": "33.60734",
    "lng": "-89.27729"
  },
  {
    "country": "US",
    "name": "Water Valley",
    "lat": "34.1515",
    "lng": "-89.63147"
  },
  {
    "country": "US",
    "name": "Waveland",
    "lat": "30.28686",
    "lng": "-89.37616"
  },
  {
    "country": "US",
    "name": "Waynesboro",
    "lat": "31.67488",
    "lng": "-88.64615"
  },
  {
    "country": "US",
    "name": "Wesson",
    "lat": "31.70128",
    "lng": "-90.39759"
  },
  {
    "country": "US",
    "name": "West Gulfport",
    "lat": "30.40409",
    "lng": "-89.0942"
  },
  {
    "country": "US",
    "name": "West Hattiesburg",
    "lat": "31.31906",
    "lng": "-89.37506"
  },
  {
    "country": "US",
    "name": "West Point",
    "lat": "33.60762",
    "lng": "-88.65033"
  },
  {
    "country": "US",
    "name": "Wiggins",
    "lat": "30.85824",
    "lng": "-89.13533"
  },
  {
    "country": "US",
    "name": "Winona",
    "lat": "33.48207",
    "lng": "-89.72814"
  },
  {
    "country": "US",
    "name": "Woodville",
    "lat": "31.10462",
    "lng": "-91.29956"
  },
  {
    "country": "US",
    "name": "Yazoo City",
    "lat": "32.85513",
    "lng": "-90.40565"
  },
  {
    "country": "US",
    "name": "Aberdeen",
    "lat": "35.13155",
    "lng": "-79.42948"
  },
  {
    "country": "US",
    "name": "Advance",
    "lat": "35.94125",
    "lng": "-80.40922"
  },
  {
    "country": "US",
    "name": "Ahoskie",
    "lat": "36.28682",
    "lng": "-76.98468"
  },
  {
    "country": "US",
    "name": "Albemarle",
    "lat": "35.35014",
    "lng": "-80.20006"
  },
  {
    "country": "US",
    "name": "Andrews",
    "lat": "35.20175",
    "lng": "-83.82407"
  },
  {
    "country": "US",
    "name": "Angier",
    "lat": "35.5071",
    "lng": "-78.73918"
  },
  {
    "country": "US",
    "name": "Apex",
    "lat": "35.73265",
    "lng": "-78.85029"
  },
  {
    "country": "US",
    "name": "Archdale",
    "lat": "35.91458",
    "lng": "-79.97198"
  },
  {
    "country": "US",
    "name": "Archer Lodge",
    "lat": "35.69404",
    "lng": "-78.37556"
  },
  {
    "country": "US",
    "name": "Asheboro",
    "lat": "35.70791",
    "lng": "-79.81364"
  },
  {
    "country": "US",
    "name": "Asheville",
    "lat": "35.60095",
    "lng": "-82.55402"
  },
  {
    "country": "US",
    "name": "Atlantic Beach",
    "lat": "34.69905",
    "lng": "-76.74021"
  },
  {
    "country": "US",
    "name": "Avery Creek",
    "lat": "35.46345",
    "lng": "-82.58262"
  },
  {
    "country": "US",
    "name": "Ayden",
    "lat": "35.47266",
    "lng": "-77.41552"
  },
  {
    "country": "US",
    "name": "Badin",
    "lat": "35.40597",
    "lng": "-80.11672"
  },
  {
    "country": "US",
    "name": "Bakersville",
    "lat": "36.01567",
    "lng": "-82.15874"
  },
  {
    "country": "US",
    "name": "Balfour",
    "lat": "35.34651",
    "lng": "-82.47206"
  },
  {
    "country": "US",
    "name": "Banner Elk",
    "lat": "36.16318",
    "lng": "-81.8715"
  },
  {
    "country": "US",
    "name": "Barker Heights",
    "lat": "35.31123",
    "lng": "-82.44401"
  },
  {
    "country": "US",
    "name": "Bayboro",
    "lat": "35.14294",
    "lng": "-76.77021"
  },
  {
    "country": "US",
    "name": "Bayshore",
    "lat": "34.28961",
    "lng": "-77.78748"
  },
  {
    "country": "US",
    "name": "Beaufort",
    "lat": "34.71822",
    "lng": "-76.66382"
  },
  {
    "country": "US",
    "name": "Belhaven",
    "lat": "35.54017",
    "lng": "-76.62299"
  },
  {
    "country": "US",
    "name": "Belmont",
    "lat": "35.24292",
    "lng": "-81.0373"
  },
  {
    "country": "US",
    "name": "Belville",
    "lat": "34.23073",
    "lng": "-77.96582"
  },
  {
    "country": "US",
    "name": "Benson",
    "lat": "35.38211",
    "lng": "-78.54862"
  },
  {
    "country": "US",
    "name": "Bent Creek",
    "lat": "35.509",
    "lng": "-82.6079"
  },
  {
    "country": "US",
    "name": "Bermuda Run",
    "lat": "36.00375",
    "lng": "-80.422"
  },
  {
    "country": "US",
    "name": "Bessemer City",
    "lat": "35.28486",
    "lng": "-81.28397"
  },
  {
    "country": "US",
    "name": "Bethel",
    "lat": "35.8071",
    "lng": "-77.37886"
  },
  {
    "country": "US",
    "name": "Bethlehem",
    "lat": "35.82569",
    "lng": "-81.30703"
  },
  {
    "country": "US",
    "name": "Beulaville",
    "lat": "34.92378",
    "lng": "-77.77387"
  },
  {
    "country": "US",
    "name": "Biltmore Forest",
    "lat": "35.53372",
    "lng": "-82.52846"
  },
  {
    "country": "US",
    "name": "Biscoe",
    "lat": "35.35986",
    "lng": "-79.77976"
  },
  {
    "country": "US",
    "name": "Black Mountain",
    "lat": "35.6179",
    "lng": "-82.32123"
  },
  {
    "country": "US",
    "name": "Bladenboro",
    "lat": "34.53878",
    "lng": "-78.78752"
  },
  {
    "country": "US",
    "name": "Blowing Rock",
    "lat": "36.13513",
    "lng": "-81.67761"
  },
  {
    "country": "US",
    "name": "Boiling Spring Lakes",
    "lat": "34.03045",
    "lng": "-78.06721"
  },
  {
    "country": "US",
    "name": "Boiling Springs",
    "lat": "35.25429",
    "lng": "-81.66704"
  },
  {
    "country": "US",
    "name": "Bolivia",
    "lat": "34.06767",
    "lng": "-78.14833"
  },
  {
    "country": "US",
    "name": "Boone",
    "lat": "36.21679",
    "lng": "-81.67455"
  },
  {
    "country": "US",
    "name": "Boonville",
    "lat": "36.23264",
    "lng": "-80.70812"
  },
  {
    "country": "US",
    "name": "Brevard",
    "lat": "35.23345",
    "lng": "-82.73429"
  },
  {
    "country": "US",
    "name": "Brices Creek",
    "lat": "35.05599",
    "lng": "-77.08773"
  },
  {
    "country": "US",
    "name": "Broad Creek",
    "lat": "34.72072",
    "lng": "-76.93633"
  },
  {
    "country": "US",
    "name": "Broadway",
    "lat": "35.45793",
    "lng": "-79.05308"
  },
  {
    "country": "US",
    "name": "Brogden",
    "lat": "35.29266",
    "lng": "-78.03443"
  },
  {
    "country": "US",
    "name": "Brunswick",
    "lat": "34.28684",
    "lng": "-78.70113"
  },
  {
    "country": "US",
    "name": "Bryson City",
    "lat": "35.43127",
    "lng": "-83.44944"
  },
  {
    "country": "US",
    "name": "Buies Creek",
    "lat": "35.41322",
    "lng": "-78.73557"
  },
  {
    "country": "US",
    "name": "Burgaw",
    "lat": "34.55211",
    "lng": "-77.9261"
  },
  {
    "country": "US",
    "name": "Burlington",
    "lat": "36.09569",
    "lng": "-79.4378"
  },
  {
    "country": "US",
    "name": "Burnsville",
    "lat": "35.11237",
    "lng": "-80.24451"
  },
  {
    "country": "US",
    "name": "Burnsville",
    "lat": "35.91734",
    "lng": "-82.30096"
  },
  {
    "country": "US",
    "name": "Butner",
    "lat": "36.13209",
    "lng": "-78.75667"
  },
  {
    "country": "US",
    "name": "Buxton",
    "lat": "35.26768",
    "lng": "-75.54237"
  },
  {
    "country": "US",
    "name": "Cajahs Mountain",
    "lat": "35.83485",
    "lng": "-81.54148"
  },
  {
    "country": "US",
    "name": "Calabash",
    "lat": "33.89073",
    "lng": "-78.56834"
  },
  {
    "country": "US",
    "name": "Camden",
    "lat": "36.32849",
    "lng": "-76.17188"
  },
  {
    "country": "US",
    "name": "Canton",
    "lat": "35.53288",
    "lng": "-82.83736"
  },
  {
    "country": "US",
    "name": "Cape Carteret",
    "lat": "34.69155",
    "lng": "-77.063"
  },
  {
    "country": "US",
    "name": "Carolina Beach",
    "lat": "34.03517",
    "lng": "-77.8936"
  },
  {
    "country": "US",
    "name": "Carolina Shores",
    "lat": "33.90101",
    "lng": "-78.58057"
  },
  {
    "country": "US",
    "name": "Carrboro",
    "lat": "35.91014",
    "lng": "-79.07529"
  },
  {
    "country": "US",
    "name": "Carthage",
    "lat": "35.34599",
    "lng": "-79.41697"
  },
  {
    "country": "US",
    "name": "Cary",
    "lat": "35.79154",
    "lng": "-78.78112"
  },
  {
    "country": "US",
    "name": "Castle Hayne",
    "lat": "34.35572",
    "lng": "-77.89999"
  },
  {
    "country": "US",
    "name": "Cedar Point",
    "lat": "34.68766",
    "lng": "-77.07245"
  },
  {
    "country": "US",
    "name": "Chadbourn",
    "lat": "34.32211",
    "lng": "-78.82697"
  },
  {
    "country": "US",
    "name": "Chapel Hill",
    "lat": "35.9132",
    "lng": "-79.05584"
  },
  {
    "country": "US",
    "name": "Charlotte",
    "lat": "35.22709",
    "lng": "-80.84313"
  },
  {
    "country": "US",
    "name": "Cherokee",
    "lat": "35.47427",
    "lng": "-83.31487"
  },
  {
    "country": "US",
    "name": "Cherryville",
    "lat": "35.37874",
    "lng": "-81.37897"
  },
  {
    "country": "US",
    "name": "China Grove",
    "lat": "35.56931",
    "lng": "-80.58173"
  },
  {
    "country": "US",
    "name": "Claremont",
    "lat": "35.71458",
    "lng": "-81.14619"
  },
  {
    "country": "US",
    "name": "Clayton",
    "lat": "35.65071",
    "lng": "-78.45639"
  },
  {
    "country": "US",
    "name": "Clemmons",
    "lat": "36.02153",
    "lng": "-80.382"
  },
  {
    "country": "US",
    "name": "Clinton",
    "lat": "34.99795",
    "lng": "-78.32333"
  },
  {
    "country": "US",
    "name": "Clyde",
    "lat": "35.53344",
    "lng": "-82.91069"
  },
  {
    "country": "US",
    "name": "Coats",
    "lat": "35.40794",
    "lng": "-78.67196"
  },
  {
    "country": "US",
    "name": "Columbia",
    "lat": "35.91766",
    "lng": "-76.25215"
  },
  {
    "country": "US",
    "name": "Columbus",
    "lat": "35.25317",
    "lng": "-82.19706"
  },
  {
    "country": "US",
    "name": "Concord",
    "lat": "35.40888",
    "lng": "-80.58158"
  },
  {
    "country": "US",
    "name": "Connelly Springs",
    "lat": "35.74291",
    "lng": "-81.51343"
  },
  {
    "country": "US",
    "name": "Conover",
    "lat": "35.70652",
    "lng": "-81.21869"
  },
  {
    "country": "US",
    "name": "Cordova",
    "lat": "34.91293",
    "lng": "-79.822"
  },
  {
    "country": "US",
    "name": "Cornelius",
    "lat": "35.4868",
    "lng": "-80.86007"
  },
  {
    "country": "US",
    "name": "Cove Creek",
    "lat": "35.60649",
    "lng": "-83.01125"
  },
  {
    "country": "US",
    "name": "Cramerton",
    "lat": "35.23875",
    "lng": "-81.07508"
  },
  {
    "country": "US",
    "name": "Creedmoor",
    "lat": "36.12237",
    "lng": "-78.68611"
  },
  {
    "country": "US",
    "name": "Cricket",
    "lat": "36.17152",
    "lng": "-81.19398"
  },
  {
    "country": "US",
    "name": "Cullowhee",
    "lat": "35.31371",
    "lng": "-83.17653"
  },
  {
    "country": "US",
    "name": "Currituck",
    "lat": "36.44988",
    "lng": "-76.01548"
  },
  {
    "country": "US",
    "name": "Dallas",
    "lat": "35.31653",
    "lng": "-81.17619"
  },
  {
    "country": "US",
    "name": "Dana",
    "lat": "35.32928",
    "lng": "-82.3754"
  },
  {
    "country": "US",
    "name": "Danbury",
    "lat": "36.4093",
    "lng": "-80.20588"
  },
  {
    "country": "US",
    "name": "Davidson",
    "lat": "35.50233",
    "lng": "-80.83912"
  },
  {
    "country": "US",
    "name": "Denton",
    "lat": "35.63347",
    "lng": "-80.11588"
  },
  {
    "country": "US",
    "name": "Denver",
    "lat": "35.53125",
    "lng": "-81.0298"
  },
  {
    "country": "US",
    "name": "Dobson",
    "lat": "36.39569",
    "lng": "-80.72257"
  },
  {
    "country": "US",
    "name": "Drexel",
    "lat": "35.75791",
    "lng": "-81.60426"
  },
  {
    "country": "US",
    "name": "Dunn",
    "lat": "35.30627",
    "lng": "-78.6089"
  },
  {
    "country": "US",
    "name": "Durham",
    "lat": "35.99403",
    "lng": "-78.89862"
  },
  {
    "country": "US",
    "name": "East Flat Rock",
    "lat": "35.28012",
    "lng": "-82.42206"
  },
  {
    "country": "US",
    "name": "East Rockingham",
    "lat": "34.91821",
    "lng": "-79.76256"
  },
  {
    "country": "US",
    "name": "East Spencer",
    "lat": "35.68181",
    "lng": "-80.43228"
  },
  {
    "country": "US",
    "name": "Eastover",
    "lat": "35.1",
    "lng": "-78.8"
  },
  {
    "country": "US",
    "name": "Eden",
    "lat": "36.48847",
    "lng": "-79.7667"
  },
  {
    "country": "US",
    "name": "Edenton",
    "lat": "36.05794",
    "lng": "-76.60772"
  },
  {
    "country": "US",
    "name": "Edneyville",
    "lat": "35.39401",
    "lng": "-82.34095"
  },
  {
    "country": "US",
    "name": "Elizabeth City",
    "lat": "36.2946",
    "lng": "-76.25105"
  },
  {
    "country": "US",
    "name": "Elizabethtown",
    "lat": "34.62934",
    "lng": "-78.60529"
  },
  {
    "country": "US",
    "name": "Elkin",
    "lat": "36.2443",
    "lng": "-80.8484"
  },
  {
    "country": "US",
    "name": "Ellerbe",
    "lat": "35.07126",
    "lng": "-79.76144"
  },
  {
    "country": "US",
    "name": "Elm City",
    "lat": "35.80655",
    "lng": "-77.86332"
  },
  {
    "country": "US",
    "name": "Elon",
    "lat": "36.10291",
    "lng": "-79.50669"
  },
  {
    "country": "US",
    "name": "Elroy",
    "lat": "35.34266",
    "lng": "-77.90859"
  },
  {
    "country": "US",
    "name": "Emerald Isle",
    "lat": "34.67794",
    "lng": "-76.95078"
  },
  {
    "country": "US",
    "name": "Enfield",
    "lat": "36.18099",
    "lng": "-77.66664"
  },
  {
    "country": "US",
    "name": "Enochville",
    "lat": "35.52986",
    "lng": "-80.66812"
  },
  {
    "country": "US",
    "name": "Erwin",
    "lat": "35.32683",
    "lng": "-78.67613"
  },
  {
    "country": "US",
    "name": "Etowah",
    "lat": "35.31762",
    "lng": "-82.59429"
  },
  {
    "country": "US",
    "name": "Fairfield Harbour",
    "lat": "35.07655",
    "lng": "-76.96356"
  },
  {
    "country": "US",
    "name": "Fairmont",
    "lat": "34.49683",
    "lng": "-79.1142"
  },
  {
    "country": "US",
    "name": "Fairplains",
    "lat": "36.19847",
    "lng": "-81.15286"
  },
  {
    "country": "US",
    "name": "Fairview",
    "lat": "35.51401",
    "lng": "-82.39595"
  },
  {
    "country": "US",
    "name": "Fairview",
    "lat": "35.13848",
    "lng": "-80.53757"
  },
  {
    "country": "US",
    "name": "Farmville",
    "lat": "35.57071",
    "lng": "-79.22002"
  },
  {
    "country": "US",
    "name": "Farmville",
    "lat": "35.59544",
    "lng": "-77.58525"
  },
  {
    "country": "US",
    "name": "Fearrington Village",
    "lat": "35.80376",
    "lng": "-79.09029"
  },
  {
    "country": "US",
    "name": "Fayetteville",
    "lat": "35.05266",
    "lng": "-78.87836"
  },
  {
    "country": "US",
    "name": "Flat Rock",
    "lat": "35.27123",
    "lng": "-82.44151"
  },
  {
    "country": "US",
    "name": "Flat Rock",
    "lat": "36.51236",
    "lng": "-80.56978"
  },
  {
    "country": "US",
    "name": "Fletcher",
    "lat": "35.43067",
    "lng": "-82.50123"
  },
  {
    "country": "US",
    "name": "Forest City",
    "lat": "35.33401",
    "lng": "-81.8651"
  },
  {
    "country": "US",
    "name": "Forest Oaks",
    "lat": "35.98819",
    "lng": "-79.70614"
  },
  {
    "country": "US",
    "name": "Foscoe",
    "lat": "36.16179",
    "lng": "-81.76566"
  },
  {
    "country": "US",
    "name": "Four Oaks",
    "lat": "35.44488",
    "lng": "-78.42695"
  },
  {
    "country": "US",
    "name": "Franklin",
    "lat": "35.18232",
    "lng": "-83.38154"
  },
  {
    "country": "US",
    "name": "Franklin",
    "lat": "35.72125",
    "lng": "-80.49895"
  },
  {
    "country": "US",
    "name": "Franklinton",
    "lat": "36.10182",
    "lng": "-78.45805"
  },
  {
    "country": "US",
    "name": "Franklinville",
    "lat": "35.74375",
    "lng": "-79.69225"
  },
  {
    "country": "US",
    "name": "Fremont",
    "lat": "35.54544",
    "lng": "-77.97471"
  },
  {
    "country": "US",
    "name": "Fruitland",
    "lat": "35.39651",
    "lng": "-82.39317"
  },
  {
    "country": "US",
    "name": "Fuquay-Varina",
    "lat": "35.58432",
    "lng": "-78.80001"
  },
  {
    "country": "US",
    "name": "Gamewell",
    "lat": "35.8693",
    "lng": "-81.59621"
  },
  {
    "country": "US",
    "name": "Garner",
    "lat": "35.71126",
    "lng": "-78.61417"
  },
  {
    "country": "US",
    "name": "Gastonia",
    "lat": "35.26208",
    "lng": "-81.1873"
  },
  {
    "country": "US",
    "name": "Gatesville",
    "lat": "36.40349",
    "lng": "-76.75301"
  },
  {
    "country": "US",
    "name": "Gaston",
    "lat": "36.50043",
    "lng": "-77.64498"
  },
  {
    "country": "US",
    "name": "Gibsonville",
    "lat": "36.10569",
    "lng": "-79.54225"
  },
  {
    "country": "US",
    "name": "Glen Alpine",
    "lat": "35.72902",
    "lng": "-81.77927"
  },
  {
    "country": "US",
    "name": "Glen Raven",
    "lat": "36.11319",
    "lng": "-79.47641"
  },
  {
    "country": "US",
    "name": "Goldsboro",
    "lat": "35.38488",
    "lng": "-77.99277"
  },
  {
    "country": "US",
    "name": "Gorman",
    "lat": "36.03653",
    "lng": "-78.82334"
  },
  {
    "country": "US",
    "name": "Graham",
    "lat": "36.06903",
    "lng": "-79.40058"
  },
  {
    "country": "US",
    "name": "Granite Falls",
    "lat": "35.79652",
    "lng": "-81.43065"
  },
  {
    "country": "US",
    "name": "Granite Quarry",
    "lat": "35.61236",
    "lng": "-80.44673"
  },
  {
    "country": "US",
    "name": "Green Level",
    "lat": "36.12097",
    "lng": "-79.34419"
  },
  {
    "country": "US",
    "name": "Green Level",
    "lat": "35.78209",
    "lng": "-78.9039"
  },
  {
    "country": "US",
    "name": "Greensboro",
    "lat": "36.07264",
    "lng": "-79.79198"
  },
  {
    "country": "US",
    "name": "Greenville",
    "lat": "35.61266",
    "lng": "-77.36635"
  },
  {
    "country": "US",
    "name": "Grifton",
    "lat": "35.37266",
    "lng": "-77.43746"
  },
  {
    "country": "US",
    "name": "Half Moon",
    "lat": "34.826",
    "lng": "-77.45941"
  },
  {
    "country": "US",
    "name": "Halifax",
    "lat": "36.32849",
    "lng": "-77.58942"
  },
  {
    "country": "US",
    "name": "Hamlet",
    "lat": "34.88488",
    "lng": "-79.69422"
  },
  {
    "country": "US",
    "name": "Hampstead",
    "lat": "34.36767",
    "lng": "-77.71053"
  },
  {
    "country": "US",
    "name": "Harkers Island",
    "lat": "34.69516",
    "lng": "-76.55937"
  },
  {
    "country": "US",
    "name": "Harrisburg",
    "lat": "35.32395",
    "lng": "-80.65784"
  },
  {
    "country": "US",
    "name": "Havelock",
    "lat": "34.87905",
    "lng": "-76.90133"
  },
  {
    "country": "US",
    "name": "Haw River",
    "lat": "36.09153",
    "lng": "-79.36419"
  },
  {
    "country": "US",
    "name": "Hayesville",
    "lat": "35.0462",
    "lng": "-83.81795"
  },
  {
    "country": "US",
    "name": "Hays",
    "lat": "36.24985",
    "lng": "-81.11564"
  },
  {
    "country": "US",
    "name": "Hazelwood",
    "lat": "35.46871",
    "lng": "-83.00403"
  },
  {
    "country": "US",
    "name": "Hemby Bridge",
    "lat": "35.10371",
    "lng": "-80.62798"
  },
  {
    "country": "US",
    "name": "Henderson",
    "lat": "36.32959",
    "lng": "-78.39916"
  },
  {
    "country": "US",
    "name": "Hendersonville",
    "lat": "35.31873",
    "lng": "-82.46095"
  },
  {
    "country": "US",
    "name": "Hertford",
    "lat": "36.19016",
    "lng": "-76.46605"
  },
  {
    "country": "US",
    "name": "Hickory",
    "lat": "35.73319",
    "lng": "-81.3412"
  },
  {
    "country": "US",
    "name": "High Point",
    "lat": "35.95569",
    "lng": "-80.00532"
  },
  {
    "country": "US",
    "name": "Hildebran",
    "lat": "35.71402",
    "lng": "-81.42203"
  },
  {
    "country": "US",
    "name": "Hillsborough",
    "lat": "36.07542",
    "lng": "-79.09973"
  },
  {
    "country": "US",
    "name": "Holly Ridge",
    "lat": "34.49544",
    "lng": "-77.55497"
  },
  {
    "country": "US",
    "name": "Holly Springs",
    "lat": "35.65127",
    "lng": "-78.83362"
  },
  {
    "country": "US",
    "name": "Hoopers Creek",
    "lat": "35.439",
    "lng": "-82.46679"
  },
  {
    "country": "US",
    "name": "Hope Mills",
    "lat": "34.97044",
    "lng": "-78.94531"
  },
  {
    "country": "US",
    "name": "Horse Shoe",
    "lat": "35.34317",
    "lng": "-82.55651"
  },
  {
    "country": "US",
    "name": "Hudson",
    "lat": "35.84846",
    "lng": "-81.49593"
  },
  {
    "country": "US",
    "name": "Huntersville",
    "lat": "35.41069",
    "lng": "-80.84285"
  },
  {
    "country": "US",
    "name": "Icard",
    "lat": "35.72735",
    "lng": "-81.47065"
  },
  {
    "country": "US",
    "name": "Indian Trail",
    "lat": "35.07681",
    "lng": "-80.66924"
  },
  {
    "country": "US",
    "name": "Jackson",
    "lat": "36.3896",
    "lng": "-77.42136"
  },
  {
    "country": "US",
    "name": "Jacksonville",
    "lat": "34.75405",
    "lng": "-77.43024"
  },
  {
    "country": "US",
    "name": "James City",
    "lat": "35.08877",
    "lng": "-77.03495"
  },
  {
    "country": "US",
    "name": "Jamestown",
    "lat": "35.9943",
    "lng": "-79.93531"
  },
  {
    "country": "US",
    "name": "Jefferson",
    "lat": "36.4204",
    "lng": "-81.47344"
  },
  {
    "country": "US",
    "name": "Jonesville",
    "lat": "36.2393",
    "lng": "-80.84452"
  },
  {
    "country": "US",
    "name": "Kannapolis",
    "lat": "35.48736",
    "lng": "-80.62173"
  },
  {
    "country": "US",
    "name": "Kenansville",
    "lat": "34.96239",
    "lng": "-77.96221"
  },
  {
    "country": "US",
    "name": "Kenly",
    "lat": "35.59627",
    "lng": "-78.12416"
  },
  {
    "country": "US",
    "name": "Kernersville",
    "lat": "36.11986",
    "lng": "-80.07365"
  },
  {
    "country": "US",
    "name": "Kill Devil Hills",
    "lat": "36.03072",
    "lng": "-75.67601"
  },
  {
    "country": "US",
    "name": "King",
    "lat": "36.28069",
    "lng": "-80.35922"
  },
  {
    "country": "US",
    "name": "Kings Grant",
    "lat": "34.26295",
    "lng": "-77.8636"
  },
  {
    "country": "US",
    "name": "Kings Mountain",
    "lat": "35.24513",
    "lng": "-81.34119"
  },
  {
    "country": "US",
    "name": "Kinston",
    "lat": "35.26266",
    "lng": "-77.58164"
  },
  {
    "country": "US",
    "name": "Kitty Hawk",
    "lat": "36.06461",
    "lng": "-75.70573"
  },
  {
    "country": "US",
    "name": "Knightdale",
    "lat": "35.78765",
    "lng": "-78.48056"
  },
  {
    "country": "US",
    "name": "Kure Beach",
    "lat": "33.99684",
    "lng": "-77.90721"
  },
  {
    "country": "US",
    "name": "La Grange",
    "lat": "35.30683",
    "lng": "-77.78803"
  },
  {
    "country": "US",
    "name": "Lake Junaluska",
    "lat": "35.52788",
    "lng": "-82.95958"
  },
  {
    "country": "US",
    "name": "Lake Lure",
    "lat": "35.4279",
    "lng": "-82.20483"
  },
  {
    "country": "US",
    "name": "Lake Norman of Catawba",
    "lat": "35.5868",
    "lng": "-80.95952"
  },
  {
    "country": "US",
    "name": "Lake Park",
    "lat": "35.08626",
    "lng": "-80.63507"
  },
  {
    "country": "US",
    "name": "Lake Waccamaw",
    "lat": "34.31906",
    "lng": "-78.50001"
  },
  {
    "country": "US",
    "name": "Landis",
    "lat": "35.54569",
    "lng": "-80.6109"
  },
  {
    "country": "US",
    "name": "Laurel Hill",
    "lat": "34.80905",
    "lng": "-79.54783"
  },
  {
    "country": "US",
    "name": "Laurel Park",
    "lat": "35.31373",
    "lng": "-82.49345"
  },
  {
    "country": "US",
    "name": "Laurinburg",
    "lat": "34.77405",
    "lng": "-79.46282"
  },
  {
    "country": "US",
    "name": "Leland",
    "lat": "34.25628",
    "lng": "-78.04471"
  },
  {
    "country": "US",
    "name": "Lenoir",
    "lat": "35.91402",
    "lng": "-81.53898"
  },
  {
    "country": "US",
    "name": "Lewisville",
    "lat": "36.09708",
    "lng": "-80.41922"
  },
  {
    "country": "US",
    "name": "Lexington",
    "lat": "35.82403",
    "lng": "-80.25338"
  },
  {
    "country": "US",
    "name": "Liberty",
    "lat": "35.85347",
    "lng": "-79.57169"
  },
  {
    "country": "US",
    "name": "Lillington",
    "lat": "35.39933",
    "lng": "-78.81585"
  },
  {
    "country": "US",
    "name": "Lincolnton",
    "lat": "35.47375",
    "lng": "-81.25453"
  },
  {
    "country": "US",
    "name": "Locust",
    "lat": "35.25987",
    "lng": "-80.42534"
  },
  {
    "country": "US",
    "name": "Long Beach",
    "lat": "33.91045",
    "lng": "-78.11777"
  },
  {
    "country": "US",
    "name": "Longview",
    "lat": "35.7293",
    "lng": "-81.38342"
  },
  {
    "country": "US",
    "name": "Louisburg",
    "lat": "36.09904",
    "lng": "-78.30111"
  },
  {
    "country": "US",
    "name": "Lowell",
    "lat": "35.26792",
    "lng": "-81.10285"
  },
  {
    "country": "US",
    "name": "Lowesville",
    "lat": "35.41708",
    "lng": "-81.01119"
  },
  {
    "country": "US",
    "name": "Lucama",
    "lat": "35.64544",
    "lng": "-78.00971"
  },
  {
    "country": "US",
    "name": "Lumberton",
    "lat": "34.61834",
    "lng": "-79.01045"
  },
  {
    "country": "US",
    "name": "Madison",
    "lat": "36.38542",
    "lng": "-79.95949"
  },
  {
    "country": "US",
    "name": "Maggie Valley",
    "lat": "35.51816",
    "lng": "-83.09764"
  },
  {
    "country": "US",
    "name": "Maiden",
    "lat": "35.57569",
    "lng": "-81.21175"
  },
  {
    "country": "US",
    "name": "Manteo",
    "lat": "35.90823",
    "lng": "-75.67573"
  },
  {
    "country": "US",
    "name": "Mar-Mac",
    "lat": "35.33488",
    "lng": "-78.05582"
  },
  {
    "country": "US",
    "name": "Marion",
    "lat": "35.68401",
    "lng": "-82.00927"
  },
  {
    "country": "US",
    "name": "Mars Hill",
    "lat": "35.8265",
    "lng": "-82.5493"
  },
  {
    "country": "US",
    "name": "Marshall",
    "lat": "35.79733",
    "lng": "-82.68403"
  },
  {
    "country": "US",
    "name": "Marshville",
    "lat": "34.98849",
    "lng": "-80.36701"
  },
  {
    "country": "US",
    "name": "Marvin",
    "lat": "34.99182",
    "lng": "-80.81479"
  },
  {
    "country": "US",
    "name": "Masonboro",
    "lat": "34.17934",
    "lng": "-77.84748"
  },
  {
    "country": "US",
    "name": "Matthews",
    "lat": "35.11681",
    "lng": "-80.72368"
  },
  {
    "country": "US",
    "name": "Maury",
    "lat": "35.48211",
    "lng": "-77.58608"
  },
  {
    "country": "US",
    "name": "Maxton",
    "lat": "34.73516",
    "lng": "-79.34893"
  },
  {
    "country": "US",
    "name": "Mayodan",
    "lat": "36.41236",
    "lng": "-79.96699"
  },
  {
    "country": "US",
    "name": "Maysville",
    "lat": "34.90488",
    "lng": "-77.23134"
  },
  {
    "country": "US",
    "name": "McLeansville",
    "lat": "36.10736",
    "lng": "-79.65864"
  },
  {
    "country": "US",
    "name": "Mebane",
    "lat": "36.09597",
    "lng": "-79.26696"
  },
  {
    "country": "US",
    "name": "Midland",
    "lat": "35.22737",
    "lng": "-80.50062"
  },
  {
    "country": "US",
    "name": "Midway",
    "lat": "35.95347",
    "lng": "-80.2181"
  },
  {
    "country": "US",
    "name": "Millers Creek",
    "lat": "36.1893",
    "lng": "-81.23759"
  },
  {
    "country": "US",
    "name": "Mills River",
    "lat": "35.38845",
    "lng": "-82.56679"
  },
  {
    "country": "US",
    "name": "Mineral Springs",
    "lat": "34.93793",
    "lng": "-80.66868"
  },
  {
    "country": "US",
    "name": "Mint Hill",
    "lat": "35.17959",
    "lng": "-80.64729"
  },
  {
    "country": "US",
    "name": "Mocksville",
    "lat": "35.89403",
    "lng": "-80.56145"
  },
  {
    "country": "US",
    "name": "Monroe",
    "lat": "34.98543",
    "lng": "-80.54951"
  },
  {
    "country": "US",
    "name": "Mooresville",
    "lat": "35.58486",
    "lng": "-80.81007"
  },
  {
    "country": "US",
    "name": "Moravian Falls",
    "lat": "36.0968",
    "lng": "-81.18231"
  },
  {
    "country": "US",
    "name": "Morehead City",
    "lat": "34.72294",
    "lng": "-76.72604"
  },
  {
    "country": "US",
    "name": "Morganton",
    "lat": "35.74541",
    "lng": "-81.68482"
  },
  {
    "country": "US",
    "name": "Morrisville",
    "lat": "35.82348",
    "lng": "-78.82556"
  },
  {
    "country": "US",
    "name": "Mount Airy",
    "lat": "36.4993",
    "lng": "-80.60729"
  },
  {
    "country": "US",
    "name": "Mount Gilead",
    "lat": "35.21487",
    "lng": "-80.00228"
  },
  {
    "country": "US",
    "name": "Mount Holly",
    "lat": "35.29819",
    "lng": "-81.01591"
  },
  {
    "country": "US",
    "name": "Mount Olive",
    "lat": "35.19655",
    "lng": "-78.06638"
  },
  {
    "country": "US",
    "name": "Mount Pleasant",
    "lat": "35.39931",
    "lng": "-80.4359"
  },
  {
    "country": "US",
    "name": "Mountain Home",
    "lat": "35.36956",
    "lng": "-82.4929"
  },
  {
    "country": "US",
    "name": "Mountain View",
    "lat": "35.68319",
    "lng": "-81.36898"
  },
  {
    "country": "US",
    "name": "Moyock",
    "lat": "36.5246",
    "lng": "-76.17827"
  },
  {
    "country": "US",
    "name": "Mulberry",
    "lat": "36.23958",
    "lng": "-81.18064"
  },
  {
    "country": "US",
    "name": "Murfreesboro",
    "lat": "36.44238",
    "lng": "-77.09858"
  },
  {
    "country": "US",
    "name": "Murphy",
    "lat": "35.08758",
    "lng": "-84.03463"
  },
  {
    "country": "US",
    "name": "Murraysville",
    "lat": "34.29572",
    "lng": "-77.84748"
  },
  {
    "country": "US",
    "name": "Myrtle Grove",
    "lat": "34.13462",
    "lng": "-77.88165"
  },
  {
    "country": "US",
    "name": "Nags Head",
    "lat": "35.95739",
    "lng": "-75.62406"
  },
  {
    "country": "US",
    "name": "Nashville",
    "lat": "35.9746",
    "lng": "-77.96554"
  },
  {
    "country": "US",
    "name": "Navassa",
    "lat": "34.25545",
    "lng": "-78.00749"
  },
  {
    "country": "US",
    "name": "Neuse Forest",
    "lat": "34.96377",
    "lng": "-76.94467"
  },
  {
    "country": "US",
    "name": "New Bern",
    "lat": "35.10849",
    "lng": "-77.04411"
  },
  {
    "country": "US",
    "name": "Newland",
    "lat": "36.08735",
    "lng": "-81.92734"
  },
  {
    "country": "US",
    "name": "Newport",
    "lat": "34.78655",
    "lng": "-76.85911"
  },
  {
    "country": "US",
    "name": "Newton",
    "lat": "35.66986",
    "lng": "-81.22147"
  },
  {
    "country": "US",
    "name": "Norlina",
    "lat": "36.4457",
    "lng": "-78.19833"
  },
  {
    "country": "US",
    "name": "North Wilkesboro",
    "lat": "36.15847",
    "lng": "-81.14758"
  },
  {
    "country": "US",
    "name": "Northlakes",
    "lat": "35.7818",
    "lng": "-81.37509"
  },
  {
    "country": "US",
    "name": "Norwood",
    "lat": "35.21959",
    "lng": "-80.11895"
  },
  {
    "country": "US",
    "name": "Oak Island",
    "lat": "33.91656",
    "lng": "-78.16111"
  },
  {
    "country": "US",
    "name": "Oak Ridge",
    "lat": "36.17347",
    "lng": "-79.98893"
  },
  {
    "country": "US",
    "name": "Oakboro",
    "lat": "35.2257",
    "lng": "-80.32895"
  },
  {
    "country": "US",
    "name": "Ogden",
    "lat": "34.27239",
    "lng": "-77.81859"
  },
  {
    "country": "US",
    "name": "Oxford",
    "lat": "36.3107",
    "lng": "-78.59083"
  },
  {
    "country": "US",
    "name": "Pembroke",
    "lat": "34.68016",
    "lng": "-79.19504"
  },
  {
    "country": "US",
    "name": "Pilot Mountain",
    "lat": "36.38653",
    "lng": "-80.4695"
  },
  {
    "country": "US",
    "name": "Pine Knoll Shores",
    "lat": "34.69738",
    "lng": "-76.81327"
  },
  {
    "country": "US",
    "name": "Pine Level",
    "lat": "35.51322",
    "lng": "-78.24444"
  },
  {
    "country": "US",
    "name": "Pinebluff",
    "lat": "35.10988",
    "lng": "-79.47226"
  },
  {
    "country": "US",
    "name": "Pinehurst",
    "lat": "35.19543",
    "lng": "-79.46948"
  },
  {
    "country": "US",
    "name": "Pinetops",
    "lat": "35.78849",
    "lng": "-77.63775"
  },
  {
    "country": "US",
    "name": "Pineville",
    "lat": "35.0832",
    "lng": "-80.8923"
  },
  {
    "country": "US",
    "name": "Piney Green",
    "lat": "34.716",
    "lng": "-77.32024"
  },
  {
    "country": "US",
    "name": "Pittsboro",
    "lat": "35.72015",
    "lng": "-79.17724"
  },
  {
    "country": "US",
    "name": "Plain View",
    "lat": "35.2485",
    "lng": "-78.55529"
  },
  {
    "country": "US",
    "name": "Pleasant Garden",
    "lat": "35.96208",
    "lng": "-79.76225"
  },
  {
    "country": "US",
    "name": "Pleasant Hill",
    "lat": "35.87347",
    "lng": "-79.48169"
  },
  {
    "country": "US",
    "name": "Plymouth",
    "lat": "35.86683",
    "lng": "-76.74856"
  },
  {
    "country": "US",
    "name": "Polkton",
    "lat": "35.00765",
    "lng": "-80.20089"
  },
  {
    "country": "US",
    "name": "Princeton",
    "lat": "35.46599",
    "lng": "-78.16055"
  },
  {
    "country": "US",
    "name": "Princeville",
    "lat": "35.8896",
    "lng": "-77.53219"
  },
  {
    "country": "US",
    "name": "Pumpkin Center",
    "lat": "35.5193",
    "lng": "-81.14119"
  },
  {
    "country": "US",
    "name": "Pumpkin Center",
    "lat": "34.79155",
    "lng": "-77.37246"
  },
  {
    "country": "US",
    "name": "Raeford",
    "lat": "34.981",
    "lng": "-79.2242"
  },
  {
    "country": "US",
    "name": "Raleigh",
    "lat": "35.7721",
    "lng": "-78.63861"
  },
  {
    "country": "US",
    "name": "Ramseur",
    "lat": "35.73347",
    "lng": "-79.65253"
  },
  {
    "country": "US",
    "name": "Randleman",
    "lat": "35.81791",
    "lng": "-79.80309"
  },
  {
    "country": "US",
    "name": "Ranlo",
    "lat": "35.28625",
    "lng": "-81.13035"
  },
  {
    "country": "US",
    "name": "Red Oak",
    "lat": "36.03849",
    "lng": "-77.90637"
  },
  {
    "country": "US",
    "name": "Red Springs",
    "lat": "34.81516",
    "lng": "-79.18309"
  },
  {
    "country": "US",
    "name": "Reidsville",
    "lat": "36.35486",
    "lng": "-79.66447"
  },
  {
    "country": "US",
    "name": "Rhodhiss",
    "lat": "35.77402",
    "lng": "-81.4312"
  },
  {
    "country": "US",
    "name": "Richlands",
    "lat": "34.89933",
    "lng": "-77.54663"
  },
  {
    "country": "US",
    "name": "River Bend",
    "lat": "35.06905",
    "lng": "-77.1469"
  },
  {
    "country": "US",
    "name": "River Road",
    "lat": "35.50683",
    "lng": "-76.99078"
  },
  {
    "country": "US",
    "name": "Roanoke Rapids",
    "lat": "36.46154",
    "lng": "-77.65415"
  },
  {
    "country": "US",
    "name": "Robbins",
    "lat": "35.43403",
    "lng": "-79.58697"
  },
  {
    "country": "US",
    "name": "Robbinsville",
    "lat": "35.32287",
    "lng": "-83.8074"
  },
  {
    "country": "US",
    "name": "Robersonville",
    "lat": "35.82516",
    "lng": "-77.24913"
  },
  {
    "country": "US",
    "name": "Rockfish",
    "lat": "34.99266",
    "lng": "-79.06614"
  },
  {
    "country": "US",
    "name": "Rockingham",
    "lat": "34.93932",
    "lng": "-79.77395"
  },
  {
    "country": "US",
    "name": "Rockwell",
    "lat": "35.55125",
    "lng": "-80.40645"
  },
  {
    "country": "US",
    "name": "Rocky Point",
    "lat": "34.43517",
    "lng": "-77.88776"
  },
  {
    "country": "US",
    "name": "Rocky Mount",
    "lat": "35.93821",
    "lng": "-77.79053"
  },
  {
    "country": "US",
    "name": "Rolesville",
    "lat": "35.92321",
    "lng": "-78.4575"
  },
  {
    "country": "US",
    "name": "Rose Hill",
    "lat": "34.82822",
    "lng": "-78.02304"
  },
  {
    "country": "US",
    "name": "Roseboro",
    "lat": "34.95295",
    "lng": "-78.50862"
  },
  {
    "country": "US",
    "name": "Rowland",
    "lat": "34.53655",
    "lng": "-79.29143"
  },
  {
    "country": "US",
    "name": "Roxboro",
    "lat": "36.39375",
    "lng": "-78.98279"
  },
  {
    "country": "US",
    "name": "Royal Pines",
    "lat": "35.47511",
    "lng": "-82.51595"
  },
  {
    "country": "US",
    "name": "Rural Hall",
    "lat": "36.24042",
    "lng": "-80.29338"
  },
  {
    "country": "US",
    "name": "Rutherford College",
    "lat": "35.74846",
    "lng": "-81.52259"
  },
  {
    "country": "US",
    "name": "Rutherfordton",
    "lat": "35.36929",
    "lng": "-81.95677"
  },
  {
    "country": "US",
    "name": "Saint James",
    "lat": "33.92934",
    "lng": "-78.11638"
  },
  {
    "country": "US",
    "name": "Saint Pauls",
    "lat": "34.80655",
    "lng": "-78.97114"
  },
  {
    "country": "US",
    "name": "Salem",
    "lat": "35.69874",
    "lng": "-81.69704"
  },
  {
    "country": "US",
    "name": "Salisbury",
    "lat": "35.67097",
    "lng": "-80.47423"
  },
  {
    "country": "US",
    "name": "Sanford",
    "lat": "35.47988",
    "lng": "-79.1803"
  },
  {
    "country": "US",
    "name": "Sawmills",
    "lat": "35.82485",
    "lng": "-81.47454"
  },
  {
    "country": "US",
    "name": "Saxapahaw",
    "lat": "35.94736",
    "lng": "-79.32196"
  },
  {
    "country": "US",
    "name": "Scotland Neck",
    "lat": "36.1296",
    "lng": "-77.42025"
  },
  {
    "country": "US",
    "name": "Sea Breeze",
    "lat": "34.06323",
    "lng": "-77.89137"
  },
  {
    "country": "US",
    "name": "Seagate",
    "lat": "34.20934",
    "lng": "-77.84359"
  },
  {
    "country": "US",
    "name": "Selma",
    "lat": "35.53655",
    "lng": "-78.28444"
  },
  {
    "country": "US",
    "name": "Seven Lakes",
    "lat": "35.27849",
    "lng": "-79.56448"
  },
  {
    "country": "US",
    "name": "Shallotte",
    "lat": "33.97323",
    "lng": "-78.38584"
  },
  {
    "country": "US",
    "name": "Sharpsburg",
    "lat": "35.8671",
    "lng": "-77.82915"
  },
  {
    "country": "US",
    "name": "Shelby",
    "lat": "35.29235",
    "lng": "-81.53565"
  },
  {
    "country": "US",
    "name": "Sherrills Ford",
    "lat": "35.62041",
    "lng": "-80.98647"
  },
  {
    "country": "US",
    "name": "Siler City",
    "lat": "35.72347",
    "lng": "-79.46224"
  },
  {
    "country": "US",
    "name": "Silver Lake",
    "lat": "34.14878",
    "lng": "-77.9136"
  },
  {
    "country": "US",
    "name": "Skippers Corner",
    "lat": "34.346",
    "lng": "-77.90249"
  },
  {
    "country": "US",
    "name": "Smithfield",
    "lat": "35.50849",
    "lng": "-78.33945"
  },
  {
    "country": "US",
    "name": "Sneads Ferry",
    "lat": "34.55267",
    "lng": "-77.39718"
  },
  {
    "country": "US",
    "name": "Snow Hill",
    "lat": "35.45155",
    "lng": "-77.68109"
  },
  {
    "country": "US",
    "name": "South Gastonia",
    "lat": "35.2193",
    "lng": "-81.20563"
  },
  {
    "country": "US",
    "name": "South Henderson",
    "lat": "36.3082",
    "lng": "-78.40666"
  },
  {
    "country": "US",
    "name": "South Rosemary",
    "lat": "36.45154",
    "lng": "-77.6972"
  },
  {
    "country": "US",
    "name": "Southern Pines",
    "lat": "35.17405",
    "lng": "-79.39225"
  },
  {
    "country": "US",
    "name": "Southern Shores",
    "lat": "36.13905",
    "lng": "-75.73157"
  },
  {
    "country": "US",
    "name": "Southmont",
    "lat": "35.66792",
    "lng": "-80.267"
  },
  {
    "country": "US",
    "name": "Southport",
    "lat": "33.92156",
    "lng": "-78.02027"
  },
  {
    "country": "US",
    "name": "Sparta",
    "lat": "36.50541",
    "lng": "-81.12092"
  },
  {
    "country": "US",
    "name": "Spencer",
    "lat": "35.69236",
    "lng": "-80.43478"
  },
  {
    "country": "US",
    "name": "Spindale",
    "lat": "35.36012",
    "lng": "-81.92927"
  },
  {
    "country": "US",
    "name": "Spring Hope",
    "lat": "35.94515",
    "lng": "-78.11193"
  },
  {
    "country": "US",
    "name": "Spring Lake",
    "lat": "35.16794",
    "lng": "-78.97281"
  },
  {
    "country": "US",
    "name": "Spruce Pine",
    "lat": "35.9154",
    "lng": "-82.06456"
  },
  {
    "country": "US",
    "name": "Saint Stephens",
    "lat": "35.76458",
    "lng": "-81.27314"
  },
  {
    "country": "US",
    "name": "Stallings",
    "lat": "35.0907",
    "lng": "-80.68618"
  },
  {
    "country": "US",
    "name": "Stanfield",
    "lat": "35.23348",
    "lng": "-80.42701"
  },
  {
    "country": "US",
    "name": "Stanley",
    "lat": "35.35903",
    "lng": "-81.09702"
  },
  {
    "country": "US",
    "name": "Statesville",
    "lat": "35.78264",
    "lng": "-80.8873"
  },
  {
    "country": "US",
    "name": "Stedman",
    "lat": "35.0135",
    "lng": "-78.69391"
  },
  {
    "country": "US",
    "name": "Stokesdale",
    "lat": "36.23708",
    "lng": "-79.97948"
  },
  {
    "country": "US",
    "name": "Stoneville",
    "lat": "36.46653",
    "lng": "-79.90698"
  },
  {
    "country": "US",
    "name": "Stony Point",
    "lat": "35.86347",
    "lng": "-81.0473"
  },
  {
    "country": "US",
    "name": "Summerfield",
    "lat": "36.20875",
    "lng": "-79.90476"
  },
  {
    "country": "US",
    "name": "Sunset Beach",
    "lat": "33.88073",
    "lng": "-78.51223"
  },
  {
    "country": "US",
    "name": "Surf City",
    "lat": "34.42711",
    "lng": "-77.54608"
  },
  {
    "country": "US",
    "name": "Swannanoa",
    "lat": "35.59789",
    "lng": "-82.39984"
  },
  {
    "country": "US",
    "name": "Swanquarter",
    "lat": "35.40628",
    "lng": "-76.32909"
  },
  {
    "country": "US",
    "name": "Swansboro",
    "lat": "34.68766",
    "lng": "-77.11912"
  },
  {
    "country": "US",
    "name": "Swepsonville",
    "lat": "36.02125",
    "lng": "-79.36141"
  },
  {
    "country": "US",
    "name": "Sylva",
    "lat": "35.37371",
    "lng": "-83.22598"
  },
  {
    "country": "US",
    "name": "Tabor City",
    "lat": "34.14878",
    "lng": "-78.87669"
  },
  {
    "country": "US",
    "name": "Tarboro",
    "lat": "35.89682",
    "lng": "-77.5358"
  },
  {
    "country": "US",
    "name": "Taylorsville",
    "lat": "35.9218",
    "lng": "-81.17647"
  },
  {
    "country": "US",
    "name": "Thomasville",
    "lat": "35.88264",
    "lng": "-80.08199"
  },
  {
    "country": "US",
    "name": "Thurmond",
    "lat": "36.36652",
    "lng": "-80.92841"
  },
  {
    "country": "US",
    "name": "Toast",
    "lat": "36.50041",
    "lng": "-80.62645"
  },
  {
    "country": "US",
    "name": "Tobaccoville",
    "lat": "36.23819",
    "lng": "-80.37144"
  },
  {
    "country": "US",
    "name": "Trent Woods",
    "lat": "35.0821",
    "lng": "-77.08634"
  },
  {
    "country": "US",
    "name": "Trenton",
    "lat": "35.0671",
    "lng": "-77.35274"
  },
  {
    "country": "US",
    "name": "Trinity",
    "lat": "35.89458",
    "lng": "-79.99087"
  },
  {
    "country": "US",
    "name": "Troutman",
    "lat": "35.70069",
    "lng": "-80.88813"
  },
  {
    "country": "US",
    "name": "Troy",
    "lat": "35.35847",
    "lng": "-79.89449"
  },
  {
    "country": "US",
    "name": "Tryon",
    "lat": "35.20817",
    "lng": "-82.23845"
  },
  {
    "country": "US",
    "name": "Tryon",
    "lat": "35.33986",
    "lng": "-81.32203"
  },
  {
    "country": "US",
    "name": "Tyro",
    "lat": "35.80903",
    "lng": "-80.37283"
  },
  {
    "country": "US",
    "name": "Unionville",
    "lat": "35.08737",
    "lng": "-80.50896"
  },
  {
    "country": "US",
    "name": "Valdese",
    "lat": "35.74069",
    "lng": "-81.56315"
  },
  {
    "country": "US",
    "name": "Valley Hill",
    "lat": "35.29845",
    "lng": "-82.48318"
  },
  {
    "country": "US",
    "name": "Vander",
    "lat": "35.03211",
    "lng": "-78.79474"
  },
  {
    "country": "US",
    "name": "Wadesboro",
    "lat": "34.96821",
    "lng": "-80.07673"
  },
  {
    "country": "US",
    "name": "Wake Forest",
    "lat": "35.97987",
    "lng": "-78.50972"
  },
  {
    "country": "US",
    "name": "Walkertown",
    "lat": "36.17541",
    "lng": "-80.1531"
  },
  {
    "country": "US",
    "name": "Walkertown",
    "lat": "35.28572",
    "lng": "-78.81363"
  },
  {
    "country": "US",
    "name": "Wallace",
    "lat": "34.73572",
    "lng": "-77.99526"
  },
  {
    "country": "US",
    "name": "Wallburg",
    "lat": "36.01014",
    "lng": "-80.13921"
  },
  {
    "country": "US",
    "name": "Walnut Cove",
    "lat": "36.29541",
    "lng": "-80.14171"
  },
  {
    "country": "US",
    "name": "Wanchese",
    "lat": "35.84267",
    "lng": "-75.63851"
  },
  {
    "country": "US",
    "name": "Warrenton",
    "lat": "36.39848",
    "lng": "-78.15527"
  },
  {
    "country": "US",
    "name": "Warsaw",
    "lat": "34.99933",
    "lng": "-78.0911"
  },
  {
    "country": "US",
    "name": "Washington",
    "lat": "35.54655",
    "lng": "-77.05217"
  },
  {
    "country": "US",
    "name": "Waxhaw",
    "lat": "34.92459",
    "lng": "-80.7434"
  },
  {
    "country": "US",
    "name": "Waynesville",
    "lat": "35.48871",
    "lng": "-82.98875"
  },
  {
    "country": "US",
    "name": "Weaverville",
    "lat": "35.69705",
    "lng": "-82.56069"
  },
  {
    "country": "US",
    "name": "Weddington",
    "lat": "35.02237",
    "lng": "-80.7609"
  },
  {
    "country": "US",
    "name": "Welcome",
    "lat": "35.90292",
    "lng": "-80.25699"
  },
  {
    "country": "US",
    "name": "Weldon",
    "lat": "36.4271",
    "lng": "-77.59553"
  },
  {
    "country": "US",
    "name": "Wentworth",
    "lat": "36.40014",
    "lng": "-79.77448"
  },
  {
    "country": "US",
    "name": "Wesley Chapel",
    "lat": "35.00709",
    "lng": "-80.67451"
  },
  {
    "country": "US",
    "name": "Wendell",
    "lat": "35.78099",
    "lng": "-78.36972"
  },
  {
    "country": "US",
    "name": "West Canton",
    "lat": "35.53788",
    "lng": "-82.85819"
  },
  {
    "country": "US",
    "name": "West Jefferson",
    "lat": "36.40374",
    "lng": "-81.49288"
  },
  {
    "country": "US",
    "name": "West Marion",
    "lat": "35.6579",
    "lng": "-82.02539"
  },
  {
    "country": "US",
    "name": "West Raleigh",
    "lat": "35.78682",
    "lng": "-78.66389"
  },
  {
    "country": "US",
    "name": "Westport",
    "lat": "35.50125",
    "lng": "-80.97869"
  },
  {
    "country": "US",
    "name": "Whispering Pines",
    "lat": "35.25571",
    "lng": "-79.37225"
  },
  {
    "country": "US",
    "name": "White Plains",
    "lat": "35.23402",
    "lng": "-81.39814"
  },
  {
    "country": "US",
    "name": "White Plains",
    "lat": "36.44569",
    "lng": "-80.6334"
  },
  {
    "country": "US",
    "name": "Whiteville",
    "lat": "34.33878",
    "lng": "-78.70307"
  },
  {
    "country": "US",
    "name": "Wilkesboro",
    "lat": "36.14596",
    "lng": "-81.16064"
  },
  {
    "country": "US",
    "name": "Williamston",
    "lat": "35.8546",
    "lng": "-77.05551"
  },
  {
    "country": "US",
    "name": "Wilmington",
    "lat": "34.22573",
    "lng": "-77.94471"
  },
  {
    "country": "US",
    "name": "Wilson",
    "lat": "35.72127",
    "lng": "-77.91554"
  },
  {
    "country": "US",
    "name": "Wilsons Mills",
    "lat": "35.58405",
    "lng": "-78.35583"
  },
  {
    "country": "US",
    "name": "Windsor",
    "lat": "35.99849",
    "lng": "-76.94606"
  },
  {
    "country": "US",
    "name": "Windsor",
    "lat": "35.55294",
    "lng": "-77.36108"
  },
  {
    "country": "US",
    "name": "Wingate",
    "lat": "34.98432",
    "lng": "-80.44923"
  },
  {
    "country": "US",
    "name": "Winston-Salem",
    "lat": "36.09986",
    "lng": "-80.24422"
  },
  {
    "country": "US",
    "name": "Winterville",
    "lat": "35.52905",
    "lng": "-77.40108"
  },
  {
    "country": "US",
    "name": "Winton",
    "lat": "36.39571",
    "lng": "-76.9319"
  },
  {
    "country": "US",
    "name": "Woodfin",
    "lat": "35.63344",
    "lng": "-82.58207"
  },
  {
    "country": "US",
    "name": "Wrightsboro",
    "lat": "34.2885",
    "lng": "-77.9211"
  },
  {
    "country": "US",
    "name": "Wrightsville Beach",
    "lat": "34.2085",
    "lng": "-77.79637"
  },
  {
    "country": "US",
    "name": "Yadkinville",
    "lat": "36.13458",
    "lng": "-80.65951"
  },
  {
    "country": "US",
    "name": "Yanceyville",
    "lat": "36.40403",
    "lng": "-79.33613"
  },
  {
    "country": "US",
    "name": "Youngsville",
    "lat": "36.02487",
    "lng": "-78.47444"
  },
  {
    "country": "US",
    "name": "Zebulon",
    "lat": "35.82432",
    "lng": "-78.31472"
  },
  {
    "country": "US",
    "name": "Absecon",
    "lat": "39.42845",
    "lng": "-74.49571"
  },
  {
    "country": "US",
    "name": "Alloway",
    "lat": "39.56095",
    "lng": "-75.36242"
  },
  {
    "country": "US",
    "name": "Ashland",
    "lat": "39.86317",
    "lng": "-75.006"
  },
  {
    "country": "US",
    "name": "Atco",
    "lat": "39.76984",
    "lng": "-74.88739"
  },
  {
    "country": "US",
    "name": "Atlantic City",
    "lat": "39.36428",
    "lng": "-74.42293"
  },
  {
    "country": "US",
    "name": "Audubon",
    "lat": "39.89095",
    "lng": "-75.07295"
  },
  {
    "country": "US",
    "name": "Audubon Park",
    "lat": "39.8965",
    "lng": "-75.08767"
  },
  {
    "country": "US",
    "name": "Avalon",
    "lat": "39.10122",
    "lng": "-74.71766"
  },
  {
    "country": "US",
    "name": "Barnegat",
    "lat": "39.75318",
    "lng": "-74.22292"
  },
  {
    "country": "US",
    "name": "Barrington",
    "lat": "39.86484",
    "lng": "-75.05517"
  },
  {
    "country": "US",
    "name": "Bayville",
    "lat": "39.90929",
    "lng": "-74.15486"
  },
  {
    "country": "US",
    "name": "Beach Haven",
    "lat": "39.55928",
    "lng": "-74.2432"
  },
  {
    "country": "US",
    "name": "Beach Haven West",
    "lat": "39.66984",
    "lng": "-74.23181"
  },
  {
    "country": "US",
    "name": "Beachwood",
    "lat": "39.93901",
    "lng": "-74.19292"
  },
  {
    "country": "US",
    "name": "Beckett",
    "lat": "39.754",
    "lng": "-75.35741"
  },
  {
    "country": "US",
    "name": "Bellmawr",
    "lat": "39.86761",
    "lng": "-75.09462"
  },
  {
    "country": "US",
    "name": "Berlin",
    "lat": "39.79123",
    "lng": "-74.92905"
  },
  {
    "country": "US",
    "name": "Blackwood",
    "lat": "39.80234",
    "lng": "-75.06406"
  },
  {
    "country": "US",
    "name": "Brigantine",
    "lat": "39.41012",
    "lng": "-74.36459"
  },
  {
    "country": "US",
    "name": "Bridgeton",
    "lat": "39.42734",
    "lng": "-75.23408"
  },
  {
    "country": "US",
    "name": "Brooklawn",
    "lat": "39.87817",
    "lng": "-75.12073"
  },
  {
    "country": "US",
    "name": "Browns Mills",
    "lat": "39.97261",
    "lng": "-74.58293"
  },
  {
    "country": "US",
    "name": "Buena",
    "lat": "39.51373",
    "lng": "-74.92462"
  },
  {
    "country": "US",
    "name": "Camden",
    "lat": "39.92595",
    "lng": "-75.11962"
  },
  {
    "country": "US",
    "name": "Cape May Court House",
    "lat": "39.08261",
    "lng": "-74.82378"
  },
  {
    "country": "US",
    "name": "Cape May",
    "lat": "38.93511",
    "lng": "-74.90601"
  },
  {
    "country": "US",
    "name": "Carneys Point",
    "lat": "39.71122",
    "lng": "-75.4702"
  },
  {
    "country": "US",
    "name": "Cedar Glen Lakes",
    "lat": "39.95234",
    "lng": "-74.39987"
  },
  {
    "country": "US",
    "name": "Cherry Hill",
    "lat": "39.93484",
    "lng": "-75.03073"
  },
  {
    "country": "US",
    "name": "Cherry Hill Mall",
    "lat": "39.93595",
    "lng": "-75.00906"
  },
  {
    "country": "US",
    "name": "Chesilhurst",
    "lat": "39.73234",
    "lng": "-74.881"
  },
  {
    "country": "US",
    "name": "Cinnaminson",
    "lat": "39.99678",
    "lng": "-74.99267"
  },
  {
    "country": "US",
    "name": "Clayton",
    "lat": "39.66011",
    "lng": "-75.09212"
  },
  {
    "country": "US",
    "name": "Clementon",
    "lat": "39.8115",
    "lng": "-74.98294"
  },
  {
    "country": "US",
    "name": "Collings Lakes",
    "lat": "39.59567",
    "lng": "-74.88156"
  },
  {
    "country": "US",
    "name": "Collingswood",
    "lat": "39.91817",
    "lng": "-75.07128"
  },
  {
    "country": "US",
    "name": "Country Lake Estates",
    "lat": "39.94262",
    "lng": "-74.54404"
  },
  {
    "country": "US",
    "name": "Crestwood Village",
    "lat": "39.94817",
    "lng": "-74.3607"
  },
  {
    "country": "US",
    "name": "Dover Beaches North",
    "lat": "39.99123",
    "lng": "-74.06375"
  },
  {
    "country": "US",
    "name": "Dover Beaches South",
    "lat": "39.95567",
    "lng": "-74.0743"
  },
  {
    "country": "US",
    "name": "Echelon",
    "lat": "39.84845",
    "lng": "-74.99572"
  },
  {
    "country": "US",
    "name": "Egg Harbor City",
    "lat": "39.52873",
    "lng": "-74.64794"
  },
  {
    "country": "US",
    "name": "Ellisburg",
    "lat": "39.91372",
    "lng": "-75.01045"
  },
  {
    "country": "US",
    "name": "Elmer",
    "lat": "39.59511",
    "lng": "-75.17018"
  },
  {
    "country": "US",
    "name": "Elwood",
    "lat": "39.57651",
    "lng": "-74.71683"
  },
  {
    "country": "US",
    "name": "Erma",
    "lat": "38.98776",
    "lng": "-74.9017"
  },
  {
    "country": "US",
    "name": "Estell Manor",
    "lat": "39.41206",
    "lng": "-74.74239"
  },
  {
    "country": "US",
    "name": "Fairton",
    "lat": "39.38178",
    "lng": "-75.21991"
  },
  {
    "country": "US",
    "name": "Folsom",
    "lat": "39.60206",
    "lng": "-74.84267"
  },
  {
    "country": "US",
    "name": "Forked River",
    "lat": "39.83984",
    "lng": "-74.19014"
  },
  {
    "country": "US",
    "name": "Gibbsboro",
    "lat": "39.83817",
    "lng": "-74.96489"
  },
  {
    "country": "US",
    "name": "Gibbstown",
    "lat": "39.82511",
    "lng": "-75.28352"
  },
  {
    "country": "US",
    "name": "Glassboro",
    "lat": "39.70289",
    "lng": "-75.11184"
  },
  {
    "country": "US",
    "name": "Glendora",
    "lat": "39.83956",
    "lng": "-75.07351"
  },
  {
    "country": "US",
    "name": "Gloucester City",
    "lat": "39.89178",
    "lng": "-75.11629"
  },
  {
    "country": "US",
    "name": "Golden Triangle",
    "lat": "39.92789",
    "lng": "-75.03878"
  },
  {
    "country": "US",
    "name": "Greentree",
    "lat": "39.89706",
    "lng": "-74.95572"
  },
  {
    "country": "US",
    "name": "Haddon Heights",
    "lat": "39.87734",
    "lng": "-75.06462"
  },
  {
    "country": "US",
    "name": "Haddonfield",
    "lat": "39.8915",
    "lng": "-75.03767"
  },
  {
    "country": "US",
    "name": "Hammonton",
    "lat": "39.63651",
    "lng": "-74.80239"
  },
  {
    "country": "US",
    "name": "Holiday Heights",
    "lat": "39.94595",
    "lng": "-74.25403"
  },
  {
    "country": "US",
    "name": "Island Heights",
    "lat": "39.94206",
    "lng": "-74.14986"
  },
  {
    "country": "US",
    "name": "Jackson",
    "lat": "39.7765",
    "lng": "-74.86238"
  },
  {
    "country": "US",
    "name": "Kingston Estates",
    "lat": "39.92372",
    "lng": "-74.98795"
  },
  {
    "country": "US",
    "name": "Laurel Lake",
    "lat": "39.33956",
    "lng": "-75.0299"
  },
  {
    "country": "US",
    "name": "Lavallette",
    "lat": "39.9704",
    "lng": "-74.06875"
  },
  {
    "country": "US",
    "name": "Lawnside",
    "lat": "39.8665",
    "lng": "-75.02823"
  },
  {
    "country": "US",
    "name": "Laurel Springs",
    "lat": "39.82011",
    "lng": "-75.00628"
  },
  {
    "country": "US",
    "name": "Leisuretowne",
    "lat": "39.89234",
    "lng": "-74.7021"
  },
  {
    "country": "US",
    "name": "Lindenwold",
    "lat": "39.82428",
    "lng": "-74.99767"
  },
  {
    "country": "US",
    "name": "Linwood",
    "lat": "39.33984",
    "lng": "-74.57516"
  },
  {
    "country": "US",
    "name": "Magnolia",
    "lat": "39.94984",
    "lng": "-74.66071"
  },
  {
    "country": "US",
    "name": "Magnolia",
    "lat": "39.85456",
    "lng": "-75.03906"
  },
  {
    "country": "US",
    "name": "Manahawkin",
    "lat": "39.6954",
    "lng": "-74.25875"
  },
  {
    "country": "US",
    "name": "Maple Shade",
    "lat": "39.95261",
    "lng": "-74.99239"
  },
  {
    "country": "US",
    "name": "Margate City",
    "lat": "39.32789",
    "lng": "-74.50349"
  },
  {
    "country": "US",
    "name": "Marlton",
    "lat": "39.89122",
    "lng": "-74.92183"
  },
  {
    "country": "US",
    "name": "Mays Landing",
    "lat": "39.45234",
    "lng": "-74.72766"
  },
  {
    "country": "US",
    "name": "Medford Lakes",
    "lat": "39.85845",
    "lng": "-74.80294"
  },
  {
    "country": "US",
    "name": "Millville",
    "lat": "39.40206",
    "lng": "-75.03934"
  },
  {
    "country": "US",
    "name": "Mount Ephraim",
    "lat": "39.87845",
    "lng": "-75.09267"
  },
  {
    "country": "US",
    "name": "Mount Holly",
    "lat": "39.99289",
    "lng": "-74.78766"
  },
  {
    "country": "US",
    "name": "Mount Laurel",
    "lat": "39.934",
    "lng": "-74.891"
  },
  {
    "country": "US",
    "name": "Mullica Hill",
    "lat": "39.73928",
    "lng": "-75.22407"
  },
  {
    "country": "US",
    "name": "Mystic Island",
    "lat": "39.54428",
    "lng": "-74.38237"
  },
  {
    "country": "US",
    "name": "National Park",
    "lat": "39.86595",
    "lng": "-75.17879"
  },
  {
    "country": "US",
    "name": "Newfield",
    "lat": "39.54688",
    "lng": "-75.02636"
  },
  {
    "country": "US",
    "name": "North Beach Haven",
    "lat": "39.57317",
    "lng": "-74.23153"
  },
  {
    "country": "US",
    "name": "North Cape May",
    "lat": "38.98206",
    "lng": "-74.95795"
  },
  {
    "country": "US",
    "name": "North Wildwood",
    "lat": "39.00067",
    "lng": "-74.79933"
  },
  {
    "country": "US",
    "name": "Northfield",
    "lat": "39.37039",
    "lng": "-74.55015"
  },
  {
    "country": "US",
    "name": "Oaklyn",
    "lat": "39.90095",
    "lng": "-75.08462"
  },
  {
    "country": "US",
    "name": "Ocean Acres",
    "lat": "39.74345",
    "lng": "-74.28098"
  },
  {
    "country": "US",
    "name": "Ocean City",
    "lat": "39.27762",
    "lng": "-74.5746"
  },
  {
    "country": "US",
    "name": "Ocean Gate",
    "lat": "39.92679",
    "lng": "-74.13375"
  },
  {
    "country": "US",
    "name": "Olivet",
    "lat": "39.54817",
    "lng": "-75.15463"
  },
  {
    "country": "US",
    "name": "Paulsboro",
    "lat": "39.83039",
    "lng": "-75.24046"
  },
  {
    "country": "US",
    "name": "Pemberton",
    "lat": "39.97206",
    "lng": "-74.68294"
  },
  {
    "country": "US",
    "name": "Pemberton Heights",
    "lat": "39.96261",
    "lng": "-74.67877"
  },
  {
    "country": "US",
    "name": "Penns Grove",
    "lat": "39.72956",
    "lng": "-75.46797"
  },
  {
    "country": "US",
    "name": "Pennsauken",
    "lat": "39.95622",
    "lng": "-75.05795"
  },
  {
    "country": "US",
    "name": "Pennsville",
    "lat": "39.65345",
    "lng": "-75.51659"
  },
  {
    "country": "US",
    "name": "Pine Beach",
    "lat": "39.93595",
    "lng": "-74.17097"
  },
  {
    "country": "US",
    "name": "Pine Hill",
    "lat": "39.78428",
    "lng": "-74.99211"
  },
  {
    "country": "US",
    "name": "Pine Ridge at Crestwood",
    "lat": "39.95456",
    "lng": "-74.31515"
  },
  {
    "country": "US",
    "name": "Pitman",
    "lat": "39.73289",
    "lng": "-75.13157"
  },
  {
    "country": "US",
    "name": "Pleasantville",
    "lat": "39.38984",
    "lng": "-74.52404"
  },
  {
    "country": "US",
    "name": "Pomona",
    "lat": "39.47845",
    "lng": "-74.57516"
  },
  {
    "country": "US",
    "name": "Port Norris",
    "lat": "39.24595",
    "lng": "-75.03518"
  },
  {
    "country": "US",
    "name": "Port Republic",
    "lat": "39.52067",
    "lng": "-74.48571"
  },
  {
    "country": "US",
    "name": "Presidential Lakes Estates",
    "lat": "39.91373",
    "lng": "-74.5646"
  },
  {
    "country": "US",
    "name": "Ramblewood",
    "lat": "39.92872",
    "lng": "-74.94378"
  },
  {
    "country": "US",
    "name": "Richwood",
    "lat": "39.72261",
    "lng": "-75.16546"
  },
  {
    "country": "US",
    "name": "Rio Grande",
    "lat": "39.01456",
    "lng": "-74.88156"
  },
  {
    "country": "US",
    "name": "Rosenhayn",
    "lat": "39.47817",
    "lng": "-75.13129"
  },
  {
    "country": "US",
    "name": "Salem",
    "lat": "39.57178",
    "lng": "-75.46714"
  },
  {
    "country": "US",
    "name": "Runnemede",
    "lat": "39.85234",
    "lng": "-75.06795"
  },
  {
    "country": "US",
    "name": "Sea Isle City",
    "lat": "39.15345",
    "lng": "-74.69294"
  },
  {
    "country": "US",
    "name": "Seabrook Farms",
    "lat": "39.50095",
    "lng": "-75.21796"
  },
  {
    "country": "US",
    "name": "Seaside Heights",
    "lat": "39.94429",
    "lng": "-74.07291"
  },
  {
    "country": "US",
    "name": "Seaside Park",
    "lat": "39.92679",
    "lng": "-74.07708"
  },
  {
    "country": "US",
    "name": "Ship Bottom",
    "lat": "39.6429",
    "lng": "-74.18042"
  },
  {
    "country": "US",
    "name": "Sicklerville",
    "lat": "39.71734",
    "lng": "-74.96933"
  },
  {
    "country": "US",
    "name": "Silver Ridge",
    "lat": "39.95928",
    "lng": "-74.21848"
  },
  {
    "country": "US",
    "name": "Smithville",
    "lat": "39.49401",
    "lng": "-74.45709"
  },
  {
    "country": "US",
    "name": "Somerdale",
    "lat": "39.844",
    "lng": "-75.02267"
  },
  {
    "country": "US",
    "name": "Somers Point",
    "lat": "39.31762",
    "lng": "-74.5946"
  },
  {
    "country": "US",
    "name": "South Toms River",
    "lat": "39.94206",
    "lng": "-74.20431"
  },
  {
    "country": "US",
    "name": "South Vineland",
    "lat": "39.44595",
    "lng": "-75.02879"
  },
  {
    "country": "US",
    "name": "Springdale",
    "lat": "39.90261",
    "lng": "-74.96628"
  },
  {
    "country": "US",
    "name": "Stratford",
    "lat": "39.82678",
    "lng": "-75.01545"
  },
  {
    "country": "US",
    "name": "Surf City",
    "lat": "39.66206",
    "lng": "-74.16514"
  },
  {
    "country": "US",
    "name": "Swedesboro",
    "lat": "39.74761",
    "lng": "-75.31047"
  },
  {
    "country": "US",
    "name": "Toms River",
    "lat": "39.95373",
    "lng": "-74.19792"
  },
  {
    "country": "US",
    "name": "Tuckerton",
    "lat": "39.60317",
    "lng": "-74.34015"
  },
  {
    "country": "US",
    "name": "Turnersville",
    "lat": "39.77317",
    "lng": "-75.05128"
  },
  {
    "country": "US",
    "name": "Ventnor City",
    "lat": "39.34039",
    "lng": "-74.47737"
  },
  {
    "country": "US",
    "name": "Victory Lakes",
    "lat": "39.63317",
    "lng": "-74.966"
  },
  {
    "country": "US",
    "name": "Villas",
    "lat": "39.02872",
    "lng": "-74.93851"
  },
  {
    "country": "US",
    "name": "Vincentown",
    "lat": "39.934",
    "lng": "-74.74849"
  },
  {
    "country": "US",
    "name": "Vineland",
    "lat": "39.48623",
    "lng": "-75.02573"
  },
  {
    "country": "US",
    "name": "Waretown",
    "lat": "39.79151",
    "lng": "-74.19514"
  },
  {
    "country": "US",
    "name": "Wenonah",
    "lat": "39.79456",
    "lng": "-75.14879"
  },
  {
    "country": "US",
    "name": "West Cape May",
    "lat": "38.93872",
    "lng": "-74.94184"
  },
  {
    "country": "US",
    "name": "Westville",
    "lat": "39.86789",
    "lng": "-75.13156"
  },
  {
    "country": "US",
    "name": "Whitesboro",
    "lat": "39.039",
    "lng": "-74.85684"
  },
  {
    "country": "US",
    "name": "Wildwood",
    "lat": "38.99178",
    "lng": "-74.81489"
  },
  {
    "country": "US",
    "name": "Wildwood Crest",
    "lat": "38.97484",
    "lng": "-74.8335"
  },
  {
    "country": "US",
    "name": "Williamstown",
    "lat": "39.68623",
    "lng": "-74.99517"
  },
  {
    "country": "US",
    "name": "Wood-Lynne",
    "lat": "39.91734",
    "lng": "-75.09629"
  },
  {
    "country": "US",
    "name": "Woodbine",
    "lat": "39.24178",
    "lng": "-74.81517"
  },
  {
    "country": "US",
    "name": "Woodbury",
    "lat": "39.83817",
    "lng": "-75.15268"
  },
  {
    "country": "US",
    "name": "Woodbury Heights",
    "lat": "39.81706",
    "lng": "-75.15518"
  },
  {
    "country": "US",
    "name": "Woodstown",
    "lat": "39.6515",
    "lng": "-75.32825"
  },
  {
    "country": "US",
    "name": "Aberdeen",
    "lat": "38.65563",
    "lng": "-83.76103"
  },
  {
    "country": "US",
    "name": "Amberley",
    "lat": "39.20478",
    "lng": "-84.428"
  },
  {
    "country": "US",
    "name": "Amelia",
    "lat": "39.0284",
    "lng": "-84.21771"
  },
  {
    "country": "US",
    "name": "Arcanum",
    "lat": "39.99005",
    "lng": "-84.55329"
  },
  {
    "country": "US",
    "name": "Ashville",
    "lat": "39.71562",
    "lng": "-82.95296"
  },
  {
    "country": "US",
    "name": "Athens",
    "lat": "39.32924",
    "lng": "-82.10126"
  },
  {
    "country": "US",
    "name": "Baltimore",
    "lat": "39.84534",
    "lng": "-82.60072"
  },
  {
    "country": "US",
    "name": "Barnesville",
    "lat": "39.98813",
    "lng": "-81.1765"
  },
  {
    "country": "US",
    "name": "Batavia",
    "lat": "39.07701",
    "lng": "-84.17688"
  },
  {
    "country": "US",
    "name": "Beavercreek",
    "lat": "39.70923",
    "lng": "-84.06327"
  },
  {
    "country": "US",
    "name": "Beckett Ridge",
    "lat": "39.347",
    "lng": "-84.43522"
  },
  {
    "country": "US",
    "name": "Bellbrook",
    "lat": "39.63562",
    "lng": "-84.07077"
  },
  {
    "country": "US",
    "name": "Belpre",
    "lat": "39.27396",
    "lng": "-81.5729"
  },
  {
    "country": "US",
    "name": "Bethel",
    "lat": "38.96368",
    "lng": "-84.08077"
  },
  {
    "country": "US",
    "name": "Bethel",
    "lat": "39.73034",
    "lng": "-83.39353"
  },
  {
    "country": "US",
    "name": "Beverly",
    "lat": "39.54785",
    "lng": "-81.63957"
  },
  {
    "country": "US",
    "name": "Bexley",
    "lat": "39.96895",
    "lng": "-82.93768"
  },
  {
    "country": "US",
    "name": "Blacklick Estates",
    "lat": "39.90506",
    "lng": "-82.86434"
  },
  {
    "country": "US",
    "name": "Blanchester",
    "lat": "39.29312",
    "lng": "-83.98882"
  },
  {
    "country": "US",
    "name": "Blue Ash",
    "lat": "39.232",
    "lng": "-84.37827"
  },
  {
    "country": "US",
    "name": "Bridgetown",
    "lat": "39.15311",
    "lng": "-84.63717"
  },
  {
    "country": "US",
    "name": "Brookville",
    "lat": "39.83672",
    "lng": "-84.41134"
  },
  {
    "country": "US",
    "name": "Buckeye Lake",
    "lat": "39.93368",
    "lng": "-82.47238"
  },
  {
    "country": "US",
    "name": "Burlington",
    "lat": "38.4073",
    "lng": "-82.53571"
  },
  {
    "country": "US",
    "name": "Byesville",
    "lat": "39.96979",
    "lng": "-81.53651"
  },
  {
    "country": "US",
    "name": "Caldwell",
    "lat": "39.74785",
    "lng": "-81.51651"
  },
  {
    "country": "US",
    "name": "Camden",
    "lat": "39.62894",
    "lng": "-84.64856"
  },
  {
    "country": "US",
    "name": "Canal Winchester",
    "lat": "39.84284",
    "lng": "-82.80462"
  },
  {
    "country": "US",
    "name": "Carlisle",
    "lat": "39.582",
    "lng": "-84.32022"
  },
  {
    "country": "US",
    "name": "Cedarville",
    "lat": "39.74423",
    "lng": "-83.80854"
  },
  {
    "country": "US",
    "name": "Centerville",
    "lat": "39.62839",
    "lng": "-84.15938"
  },
  {
    "country": "US",
    "name": "Chauncey",
    "lat": "39.39785",
    "lng": "-82.12931"
  },
  {
    "country": "US",
    "name": "Cherry Grove",
    "lat": "39.07256",
    "lng": "-84.32188"
  },
  {
    "country": "US",
    "name": "Cheviot",
    "lat": "39.157",
    "lng": "-84.61328"
  },
  {
    "country": "US",
    "name": "Choctaw Lake",
    "lat": "39.96006",
    "lng": "-83.48492"
  },
  {
    "country": "US",
    "name": "Cincinnati",
    "lat": "39.12711",
    "lng": "-84.51439"
  },
  {
    "country": "US",
    "name": "Circleville",
    "lat": "39.60062",
    "lng": "-82.94601"
  },
  {
    "country": "US",
    "name": "Clayton",
    "lat": "39.86311",
    "lng": "-84.3605"
  },
  {
    "country": "US",
    "name": "Cleves",
    "lat": "39.16172",
    "lng": "-84.74912"
  },
  {
    "country": "US",
    "name": "Coal Grove",
    "lat": "38.50341",
    "lng": "-82.64711"
  },
  {
    "country": "US",
    "name": "Columbus",
    "lat": "39.96118",
    "lng": "-82.99879"
  },
  {
    "country": "US",
    "name": "Commercial Point",
    "lat": "39.7684",
    "lng": "-83.05713"
  },
  {
    "country": "US",
    "name": "Covedale",
    "lat": "39.12117",
    "lng": "-84.60633"
  },
  {
    "country": "US",
    "name": "Crooksville",
    "lat": "39.76896",
    "lng": "-82.09209"
  },
  {
    "country": "US",
    "name": "Crystal Lakes",
    "lat": "39.88923",
    "lng": "-84.0266"
  },
  {
    "country": "US",
    "name": "Day Heights",
    "lat": "39.17395",
    "lng": "-84.22633"
  },
  {
    "country": "US",
    "name": "Dayton",
    "lat": "39.75895",
    "lng": "-84.19161"
  },
  {
    "country": "US",
    "name": "Deer Park",
    "lat": "39.20534",
    "lng": "-84.39466"
  },
  {
    "country": "US",
    "name": "Dent",
    "lat": "39.18589",
    "lng": "-84.65134"
  },
  {
    "country": "US",
    "name": "Devola",
    "lat": "39.47369",
    "lng": "-81.47901"
  },
  {
    "country": "US",
    "name": "Dillonvale",
    "lat": "39.21811",
    "lng": "-84.40216"
  },
  {
    "country": "US",
    "name": "Drexel",
    "lat": "39.74645",
    "lng": "-84.28661"
  },
  {
    "country": "US",
    "name": "Dry Ridge",
    "lat": "39.25922",
    "lng": "-84.61911"
  },
  {
    "country": "US",
    "name": "Dry Run",
    "lat": "39.10423",
    "lng": "-84.33049"
  },
  {
    "country": "US",
    "name": "Dunlap",
    "lat": "39.29228",
    "lng": "-84.618"
  },
  {
    "country": "US",
    "name": "Eaton",
    "lat": "39.74394",
    "lng": "-84.63662"
  },
  {
    "country": "US",
    "name": "Elmwood Place",
    "lat": "39.18728",
    "lng": "-84.488"
  },
  {
    "country": "US",
    "name": "Englewood",
    "lat": "39.87756",
    "lng": "-84.30217"
  },
  {
    "country": "US",
    "name": "Enon",
    "lat": "39.87812",
    "lng": "-83.93688"
  },
  {
    "country": "US",
    "name": "Etna",
    "lat": "39.95729",
    "lng": "-82.68183"
  },
  {
    "country": "US",
    "name": "Evendale",
    "lat": "39.25617",
    "lng": "-84.418"
  },
  {
    "country": "US",
    "name": "Fairborn",
    "lat": "39.82089",
    "lng": "-84.01938"
  },
  {
    "country": "US",
    "name": "Fairfax",
    "lat": "39.14534",
    "lng": "-84.39327"
  },
  {
    "country": "US",
    "name": "Fairfield",
    "lat": "39.34589",
    "lng": "-84.5605"
  },
  {
    "country": "US",
    "name": "Fairfield Beach",
    "lat": "39.9159",
    "lng": "-82.47516"
  },
  {
    "country": "US",
    "name": "Farmersville",
    "lat": "39.6795",
    "lng": "-84.42911"
  },
  {
    "country": "US",
    "name": "Finneytown",
    "lat": "39.20034",
    "lng": "-84.5205"
  },
  {
    "country": "US",
    "name": "Five Points",
    "lat": "39.56867",
    "lng": "-84.19299"
  },
  {
    "country": "US",
    "name": "Forest Park",
    "lat": "39.29034",
    "lng": "-84.50411"
  },
  {
    "country": "US",
    "name": "Forestville",
    "lat": "39.07506",
    "lng": "-84.34494"
  },
  {
    "country": "US",
    "name": "Fort McKinley",
    "lat": "39.79756",
    "lng": "-84.25355"
  },
  {
    "country": "US",
    "name": "Frankfort",
    "lat": "39.40145",
    "lng": "-83.18074"
  },
  {
    "country": "US",
    "name": "Franklin",
    "lat": "39.55895",
    "lng": "-84.30411"
  },
  {
    "country": "US",
    "name": "Franklin Furnace",
    "lat": "38.64508",
    "lng": "-82.84878"
  },
  {
    "country": "US",
    "name": "Fruit Hill",
    "lat": "39.07562",
    "lng": "-84.36438"
  },
  {
    "country": "US",
    "name": "Gallipolis",
    "lat": "38.8098",
    "lng": "-82.20237"
  },
  {
    "country": "US",
    "name": "Geneva",
    "lat": "39.66201",
    "lng": "-82.43349"
  },
  {
    "country": "US",
    "name": "Georgetown",
    "lat": "38.86451",
    "lng": "-83.90409"
  },
  {
    "country": "US",
    "name": "Germantown",
    "lat": "39.62617",
    "lng": "-84.36939"
  },
  {
    "country": "US",
    "name": "Glendale",
    "lat": "39.27061",
    "lng": "-84.45939"
  },
  {
    "country": "US",
    "name": "Glouster",
    "lat": "39.50313",
    "lng": "-82.08459"
  },
  {
    "country": "US",
    "name": "Golf Manor",
    "lat": "39.18728",
    "lng": "-84.44633"
  },
  {
    "country": "US",
    "name": "Goshen",
    "lat": "39.23339",
    "lng": "-84.16132"
  },
  {
    "country": "US",
    "name": "Grandview",
    "lat": "39.19422",
    "lng": "-84.72439"
  },
  {
    "country": "US",
    "name": "Grandview Heights",
    "lat": "39.97979",
    "lng": "-83.04074"
  },
  {
    "country": "US",
    "name": "Green Meadows",
    "lat": "39.86895",
    "lng": "-83.94438"
  },
  {
    "country": "US",
    "name": "Greenfield",
    "lat": "39.35201",
    "lng": "-83.38269"
  },
  {
    "country": "US",
    "name": "Greenhills",
    "lat": "39.26811",
    "lng": "-84.523"
  },
  {
    "country": "US",
    "name": "Groesbeck",
    "lat": "39.22311",
    "lng": "-84.58689"
  },
  {
    "country": "US",
    "name": "Grove City",
    "lat": "39.88145",
    "lng": "-83.09296"
  },
  {
    "country": "US",
    "name": "Groveport",
    "lat": "39.8784",
    "lng": "-82.88379"
  },
  {
    "country": "US",
    "name": "Hamilton",
    "lat": "39.3995",
    "lng": "-84.56134"
  },
  {
    "country": "US",
    "name": "Harbor Hills",
    "lat": "39.93673",
    "lng": "-82.43515"
  },
  {
    "country": "US",
    "name": "Harrison",
    "lat": "39.262",
    "lng": "-84.81995"
  },
  {
    "country": "US",
    "name": "Hebron",
    "lat": "39.96173",
    "lng": "-82.49127"
  },
  {
    "country": "US",
    "name": "Highpoint",
    "lat": "39.28839",
    "lng": "-84.35022"
  },
  {
    "country": "US",
    "name": "Hillsboro",
    "lat": "39.20229",
    "lng": "-83.61159"
  },
  {
    "country": "US",
    "name": "Holiday Valley",
    "lat": "39.85617",
    "lng": "-83.96854"
  },
  {
    "country": "US",
    "name": "Huber Heights",
    "lat": "39.84395",
    "lng": "-84.12466"
  },
  {
    "country": "US",
    "name": "Hunter",
    "lat": "39.49284",
    "lng": "-84.28966"
  },
  {
    "country": "US",
    "name": "Ironton",
    "lat": "38.53675",
    "lng": "-82.68294"
  },
  {
    "country": "US",
    "name": "Jackson",
    "lat": "39.05202",
    "lng": "-82.63655"
  },
  {
    "country": "US",
    "name": "Jamestown",
    "lat": "39.65812",
    "lng": "-83.73492"
  },
  {
    "country": "US",
    "name": "Jeffersonville",
    "lat": "39.65367",
    "lng": "-83.56381"
  },
  {
    "country": "US",
    "name": "Kenwood",
    "lat": "39.21061",
    "lng": "-84.36716"
  },
  {
    "country": "US",
    "name": "Kettering",
    "lat": "39.6895",
    "lng": "-84.16883"
  },
  {
    "country": "US",
    "name": "Kings Mills",
    "lat": "39.35561",
    "lng": "-84.24855"
  },
  {
    "country": "US",
    "name": "Kingston",
    "lat": "39.47395",
    "lng": "-82.91073"
  },
  {
    "country": "US",
    "name": "Lake Darby",
    "lat": "39.95728",
    "lng": "-83.2288"
  },
  {
    "country": "US",
    "name": "Lancaster",
    "lat": "39.71368",
    "lng": "-82.59933"
  },
  {
    "country": "US",
    "name": "Landen",
    "lat": "39.312",
    "lng": "-84.28299"
  },
  {
    "country": "US",
    "name": "Lebanon",
    "lat": "39.43534",
    "lng": "-84.20299"
  },
  {
    "country": "US",
    "name": "Leesburg",
    "lat": "39.34506",
    "lng": "-83.55297"
  },
  {
    "country": "US",
    "name": "Lewisburg",
    "lat": "39.84616",
    "lng": "-84.53967"
  },
  {
    "country": "US",
    "name": "Lincoln Heights",
    "lat": "39.23895",
    "lng": "-84.4555"
  },
  {
    "country": "US",
    "name": "Lincoln Village",
    "lat": "39.95479",
    "lng": "-83.13074"
  },
  {
    "country": "US",
    "name": "Lisbon",
    "lat": "39.86089",
    "lng": "-83.6352"
  },
  {
    "country": "US",
    "name": "Lithopolis",
    "lat": "39.80284",
    "lng": "-82.80628"
  },
  {
    "country": "US",
    "name": "Lockland",
    "lat": "39.22922",
    "lng": "-84.45772"
  },
  {
    "country": "US",
    "name": "Logan",
    "lat": "39.54007",
    "lng": "-82.4071"
  },
  {
    "country": "US",
    "name": "Logan Elm Village",
    "lat": "39.56978",
    "lng": "-82.95185"
  },
  {
    "country": "US",
    "name": "London",
    "lat": "39.88645",
    "lng": "-83.44825"
  },
  {
    "country": "US",
    "name": "Loveland",
    "lat": "39.26895",
    "lng": "-84.26383"
  },
  {
    "country": "US",
    "name": "Loveland Park",
    "lat": "39.29978",
    "lng": "-84.26327"
  },
  {
    "country": "US",
    "name": "Lucasville",
    "lat": "38.87952",
    "lng": "-82.99684"
  },
  {
    "country": "US",
    "name": "Lynchburg",
    "lat": "39.24173",
    "lng": "-83.79131"
  },
  {
    "country": "US",
    "name": "Mack",
    "lat": "39.15811",
    "lng": "-84.64967"
  },
  {
    "country": "US",
    "name": "Madeira",
    "lat": "39.19089",
    "lng": "-84.36355"
  },
  {
    "country": "US",
    "name": "Manchester",
    "lat": "38.68813",
    "lng": "-83.60936"
  },
  {
    "country": "US",
    "name": "Mariemont",
    "lat": "39.14506",
    "lng": "-84.37438"
  },
  {
    "country": "US",
    "name": "Marietta",
    "lat": "39.41535",
    "lng": "-81.45484"
  },
  {
    "country": "US",
    "name": "Mason",
    "lat": "39.36006",
    "lng": "-84.30994"
  },
  {
    "country": "US",
    "name": "Mayfield",
    "lat": "39.49478",
    "lng": "-84.37272"
  },
  {
    "country": "US",
    "name": "McArthur",
    "lat": "39.24646",
    "lng": "-82.47849"
  },
  {
    "country": "US",
    "name": "McConnelsville",
    "lat": "39.64868",
    "lng": "-81.85319"
  },
  {
    "country": "US",
    "name": "Miami Heights",
    "lat": "39.16506",
    "lng": "-84.7205"
  },
  {
    "country": "US",
    "name": "Miamisburg",
    "lat": "39.64284",
    "lng": "-84.28661"
  },
  {
    "country": "US",
    "name": "Miamitown",
    "lat": "39.21589",
    "lng": "-84.70411"
  },
  {
    "country": "US",
    "name": "Middleport",
    "lat": "39.00175",
    "lng": "-82.04875"
  },
  {
    "country": "US",
    "name": "Middletown",
    "lat": "39.51506",
    "lng": "-84.39828"
  },
  {
    "country": "US",
    "name": "Milford",
    "lat": "39.17534",
    "lng": "-84.29438"
  },
  {
    "country": "US",
    "name": "Millersport",
    "lat": "39.90006",
    "lng": "-82.53405"
  },
  {
    "country": "US",
    "name": "Monroe",
    "lat": "39.44034",
    "lng": "-84.36216"
  },
  {
    "country": "US",
    "name": "Monfort Heights",
    "lat": "39.18839",
    "lng": "-84.59522"
  },
  {
    "country": "US",
    "name": "Montgomery",
    "lat": "39.22811",
    "lng": "-84.35411"
  },
  {
    "country": "US",
    "name": "Moraine",
    "lat": "39.70617",
    "lng": "-84.21938"
  },
  {
    "country": "US",
    "name": "Morrow",
    "lat": "39.3545",
    "lng": "-84.12716"
  },
  {
    "country": "US",
    "name": "Mount Carmel",
    "lat": "39.10589",
    "lng": "-84.3041"
  },
  {
    "country": "US",
    "name": "Mount Healthy",
    "lat": "39.23367",
    "lng": "-84.54578"
  },
  {
    "country": "US",
    "name": "Mount Healthy Heights",
    "lat": "39.27033",
    "lng": "-84.568"
  },
  {
    "country": "US",
    "name": "Mount Orab",
    "lat": "39.02757",
    "lng": "-83.91965"
  },
  {
    "country": "US",
    "name": "Mount Repose",
    "lat": "39.20062",
    "lng": "-84.22438"
  },
  {
    "country": "US",
    "name": "Mount Sterling",
    "lat": "39.71951",
    "lng": "-83.26519"
  },
  {
    "country": "US",
    "name": "Mulberry",
    "lat": "39.19339",
    "lng": "-84.24216"
  },
  {
    "country": "US",
    "name": "Nelsonville",
    "lat": "39.45868",
    "lng": "-82.23182"
  },
  {
    "country": "US",
    "name": "New Boston",
    "lat": "38.7523",
    "lng": "-82.93684"
  },
  {
    "country": "US",
    "name": "New Burlington",
    "lat": "39.2595",
    "lng": "-84.55717"
  },
  {
    "country": "US",
    "name": "New Carlisle",
    "lat": "39.93617",
    "lng": "-84.02549"
  },
  {
    "country": "US",
    "name": "New Concord",
    "lat": "39.99368",
    "lng": "-81.73402"
  },
  {
    "country": "US",
    "name": "New Lebanon",
    "lat": "39.74533",
    "lng": "-84.38495"
  },
  {
    "country": "US",
    "name": "New Lexington",
    "lat": "39.71396",
    "lng": "-82.20848"
  },
  {
    "country": "US",
    "name": "New Matamoras",
    "lat": "39.52452",
    "lng": "-81.06705"
  },
  {
    "country": "US",
    "name": "New Miami",
    "lat": "39.43478",
    "lng": "-84.53689"
  },
  {
    "country": "US",
    "name": "New Paris",
    "lat": "39.85699",
    "lng": "-84.79329"
  },
  {
    "country": "US",
    "name": "New Richmond",
    "lat": "38.94868",
    "lng": "-84.27994"
  },
  {
    "country": "US",
    "name": "New Vienna",
    "lat": "39.32367",
    "lng": "-83.69103"
  },
  {
    "country": "US",
    "name": "Newport",
    "lat": "39.39091",
    "lng": "-81.22678"
  },
  {
    "country": "US",
    "name": "Newtown",
    "lat": "39.1245",
    "lng": "-84.36161"
  },
  {
    "country": "US",
    "name": "North College Hill",
    "lat": "39.21839",
    "lng": "-84.55078"
  },
  {
    "country": "US",
    "name": "North Fork Village",
    "lat": "39.3359",
    "lng": "-83.02907"
  },
  {
    "country": "US",
    "name": "North Zanesville",
    "lat": "39.97868",
    "lng": "-82.00347"
  },
  {
    "country": "US",
    "name": "Northbrook",
    "lat": "39.24645",
    "lng": "-84.58356"
  },
  {
    "country": "US",
    "name": "Northgate",
    "lat": "39.25283",
    "lng": "-84.59245"
  },
  {
    "country": "US",
    "name": "Northridge",
    "lat": "39.99173",
    "lng": "-83.77854"
  },
  {
    "country": "US",
    "name": "Northridge",
    "lat": "39.80756",
    "lng": "-84.19689"
  },
  {
    "country": "US",
    "name": "Norwood",
    "lat": "39.15561",
    "lng": "-84.45966"
  },
  {
    "country": "US",
    "name": "Oak Hill",
    "lat": "38.89396",
    "lng": "-82.57349"
  },
  {
    "country": "US",
    "name": "Oakwood",
    "lat": "39.72534",
    "lng": "-84.17411"
  },
  {
    "country": "US",
    "name": "Obetz",
    "lat": "39.87895",
    "lng": "-82.95074"
  },
  {
    "country": "US",
    "name": "Oxford",
    "lat": "39.507",
    "lng": "-84.74523"
  },
  {
    "country": "US",
    "name": "Park Layne",
    "lat": "39.88645",
    "lng": "-84.03966"
  },
  {
    "country": "US",
    "name": "Pataskala",
    "lat": "39.99562",
    "lng": "-82.67433"
  },
  {
    "country": "US",
    "name": "Peebles",
    "lat": "38.94896",
    "lng": "-83.40575"
  },
  {
    "country": "US",
    "name": "Pickerington",
    "lat": "39.88423",
    "lng": "-82.7535"
  },
  {
    "country": "US",
    "name": "Piketon",
    "lat": "39.06813",
    "lng": "-83.01434"
  },
  {
    "country": "US",
    "name": "Pleasant Grove",
    "lat": "39.95201",
    "lng": "-81.95902"
  },
  {
    "country": "US",
    "name": "Pleasant Run",
    "lat": "39.29978",
    "lng": "-84.56356"
  },
  {
    "country": "US",
    "name": "Pleasant Run Farm",
    "lat": "39.30311",
    "lng": "-84.548"
  },
  {
    "country": "US",
    "name": "Pomeroy",
    "lat": "39.02758",
    "lng": "-82.03375"
  },
  {
    "country": "US",
    "name": "Portsmouth",
    "lat": "38.73174",
    "lng": "-82.99767"
  },
  {
    "country": "US",
    "name": "Powhatan Point",
    "lat": "39.86008",
    "lng": "-80.81537"
  },
  {
    "country": "US",
    "name": "Reading",
    "lat": "39.22367",
    "lng": "-84.44216"
  },
  {
    "country": "US",
    "name": "Reno",
    "lat": "39.37285",
    "lng": "-81.39567"
  },
  {
    "country": "US",
    "name": "Reynoldsburg",
    "lat": "39.95479",
    "lng": "-82.81212"
  },
  {
    "country": "US",
    "name": "Ripley",
    "lat": "38.74563",
    "lng": "-83.84492"
  },
  {
    "country": "US",
    "name": "Riverside",
    "lat": "39.77978",
    "lng": "-84.1241"
  },
  {
    "country": "US",
    "name": "Rosemount",
    "lat": "38.78619",
    "lng": "-82.97906"
  },
  {
    "country": "US",
    "name": "Ross",
    "lat": "39.31228",
    "lng": "-84.6505"
  },
  {
    "country": "US",
    "name": "Roseville",
    "lat": "39.80729",
    "lng": "-82.07125"
  },
  {
    "country": "US",
    "name": "Rossmoyne",
    "lat": "39.21367",
    "lng": "-84.38688"
  },
  {
    "country": "US",
    "name": "Sabina",
    "lat": "39.48867",
    "lng": "-83.63687"
  },
  {
    "country": "US",
    "name": "Saint Bernard",
    "lat": "39.167",
    "lng": "-84.49855"
  },
  {
    "country": "US",
    "name": "Salem Heights",
    "lat": "39.07173",
    "lng": "-84.37827"
  },
  {
    "country": "US",
    "name": "Sciotodale",
    "lat": "38.7548",
    "lng": "-82.86878"
  },
  {
    "country": "US",
    "name": "Shadyside",
    "lat": "39.97091",
    "lng": "-80.75064"
  },
  {
    "country": "US",
    "name": "Sharonville",
    "lat": "39.26811",
    "lng": "-84.41327"
  },
  {
    "country": "US",
    "name": "Shawnee Hills",
    "lat": "39.65284",
    "lng": "-83.78687"
  },
  {
    "country": "US",
    "name": "Sherwood",
    "lat": "39.08478",
    "lng": "-84.36077"
  },
  {
    "country": "US",
    "name": "Shiloh",
    "lat": "39.81867",
    "lng": "-84.22855"
  },
  {
    "country": "US",
    "name": "Silverton",
    "lat": "39.19284",
    "lng": "-84.4005"
  },
  {
    "country": "US",
    "name": "Sixteen Mile Stand",
    "lat": "39.27284",
    "lng": "-84.32744"
  },
  {
    "country": "US",
    "name": "Skyline Acres",
    "lat": "39.22867",
    "lng": "-84.56689"
  },
  {
    "country": "US",
    "name": "Somerset",
    "lat": "39.80701",
    "lng": "-82.29709"
  },
  {
    "country": "US",
    "name": "South Bloomfield",
    "lat": "39.7184",
    "lng": "-82.98685"
  },
  {
    "country": "US",
    "name": "South Charleston",
    "lat": "39.82534",
    "lng": "-83.63437"
  },
  {
    "country": "US",
    "name": "South Lebanon",
    "lat": "39.37089",
    "lng": "-84.21327"
  },
  {
    "country": "US",
    "name": "South Point",
    "lat": "38.41786",
    "lng": "-82.58627"
  },
  {
    "country": "US",
    "name": "South Zanesville",
    "lat": "39.89923",
    "lng": "-82.00625"
  },
  {
    "country": "US",
    "name": "Springboro",
    "lat": "39.55228",
    "lng": "-84.23327"
  },
  {
    "country": "US",
    "name": "Springdale",
    "lat": "39.287",
    "lng": "-84.48522"
  },
  {
    "country": "US",
    "name": "Springfield",
    "lat": "39.92423",
    "lng": "-83.80882"
  },
  {
    "country": "US",
    "name": "Summerside",
    "lat": "39.10478",
    "lng": "-84.28827"
  },
  {
    "country": "US",
    "name": "Terrace Park",
    "lat": "39.15923",
    "lng": "-84.30716"
  },
  {
    "country": "US",
    "name": "The Plains",
    "lat": "39.36896",
    "lng": "-82.13237"
  },
  {
    "country": "US",
    "name": "The Village of Indian Hill",
    "lat": "39.17949",
    "lng": "-84.33517"
  },
  {
    "country": "US",
    "name": "Thornport",
    "lat": "39.91312",
    "lng": "-82.41099"
  },
  {
    "country": "US",
    "name": "Tipp City",
    "lat": "39.95839",
    "lng": "-84.17216"
  },
  {
    "country": "US",
    "name": "Trenton",
    "lat": "39.48089",
    "lng": "-84.45772"
  },
  {
    "country": "US",
    "name": "Trotwood",
    "lat": "39.79728",
    "lng": "-84.31133"
  },
  {
    "country": "US",
    "name": "Union",
    "lat": "39.89783",
    "lng": "-84.30633"
  },
  {
    "country": "US",
    "name": "Upper Arlington",
    "lat": "39.99451",
    "lng": "-83.06241"
  },
  {
    "country": "US",
    "name": "Urbancrest",
    "lat": "39.89756",
    "lng": "-83.08685"
  },
  {
    "country": "US",
    "name": "Vandalia",
    "lat": "39.89061",
    "lng": "-84.19883"
  },
  {
    "country": "US",
    "name": "Washington Court House",
    "lat": "39.53645",
    "lng": "-83.43908"
  },
  {
    "country": "US",
    "name": "Waverly",
    "lat": "39.12673",
    "lng": "-82.98546"
  },
  {
    "country": "US",
    "name": "Waynesville",
    "lat": "39.52978",
    "lng": "-84.0866"
  },
  {
    "country": "US",
    "name": "Wellston",
    "lat": "39.12341",
    "lng": "-82.53294"
  },
  {
    "country": "US",
    "name": "West Alexandria",
    "lat": "39.7445",
    "lng": "-84.53217"
  },
  {
    "country": "US",
    "name": "West Carrollton City",
    "lat": "39.67228",
    "lng": "-84.25216"
  },
  {
    "country": "US",
    "name": "West Jefferson",
    "lat": "39.94478",
    "lng": "-83.2688"
  },
  {
    "country": "US",
    "name": "West Milton",
    "lat": "39.96255",
    "lng": "-84.328"
  },
  {
    "country": "US",
    "name": "West Portsmouth",
    "lat": "38.75841",
    "lng": "-83.02906"
  },
  {
    "country": "US",
    "name": "West Union",
    "lat": "38.79452",
    "lng": "-83.54519"
  },
  {
    "country": "US",
    "name": "Wetherington",
    "lat": "39.36367",
    "lng": "-84.37744"
  },
  {
    "country": "US",
    "name": "Wheelersburg",
    "lat": "38.73035",
    "lng": "-82.85545"
  },
  {
    "country": "US",
    "name": "White Oak",
    "lat": "39.21311",
    "lng": "-84.59939"
  },
  {
    "country": "US",
    "name": "Whitehall",
    "lat": "39.96673",
    "lng": "-82.88546"
  },
  {
    "country": "US",
    "name": "Wilberforce",
    "lat": "39.71617",
    "lng": "-83.87771"
  },
  {
    "country": "US",
    "name": "Williamsburg",
    "lat": "39.05423",
    "lng": "-84.05299"
  },
  {
    "country": "US",
    "name": "Williamsport",
    "lat": "39.5859",
    "lng": "-83.12046"
  },
  {
    "country": "US",
    "name": "Wilmington",
    "lat": "39.44534",
    "lng": "-83.82854"
  },
  {
    "country": "US",
    "name": "Winchester",
    "lat": "38.94174",
    "lng": "-83.65075"
  },
  {
    "country": "US",
    "name": "Withamsville",
    "lat": "39.06228",
    "lng": "-84.28827"
  },
  {
    "country": "US",
    "name": "Woodlawn",
    "lat": "39.252",
    "lng": "-84.47022"
  },
  {
    "country": "US",
    "name": "Woodsfield",
    "lat": "39.76257",
    "lng": "-81.11538"
  },
  {
    "country": "US",
    "name": "Wyoming",
    "lat": "39.23117",
    "lng": "-84.46578"
  },
  {
    "country": "US",
    "name": "Xenia",
    "lat": "39.68478",
    "lng": "-83.92965"
  },
  {
    "country": "US",
    "name": "Yellow Springs",
    "lat": "39.80645",
    "lng": "-83.88687"
  },
  {
    "country": "US",
    "name": "Zanesville",
    "lat": "39.94035",
    "lng": "-82.01319"
  },
  {
    "country": "US",
    "name": "Ada",
    "lat": "34.77453",
    "lng": "-96.67834"
  },
  {
    "country": "US",
    "name": "Afton",
    "lat": "36.69369",
    "lng": "-94.96302"
  },
  {
    "country": "US",
    "name": "Altus",
    "lat": "34.63813",
    "lng": "-99.33398"
  },
  {
    "country": "US",
    "name": "Alva",
    "lat": "36.80499",
    "lng": "-98.66718"
  },
  {
    "country": "US",
    "name": "Anadarko",
    "lat": "35.07256",
    "lng": "-98.24366"
  },
  {
    "country": "US",
    "name": "Antlers",
    "lat": "34.23121",
    "lng": "-95.62025"
  },
  {
    "country": "US",
    "name": "Apache",
    "lat": "34.89368",
    "lng": "-98.36589"
  },
  {
    "country": "US",
    "name": "Arapaho",
    "lat": "35.57783",
    "lng": "-98.96453"
  },
  {
    "country": "US",
    "name": "Ardmore",
    "lat": "34.17426",
    "lng": "-97.14363"
  },
  {
    "country": "US",
    "name": "Arkoma",
    "lat": "35.35454",
    "lng": "-94.4341"
  },
  {
    "country": "US",
    "name": "Arnett",
    "lat": "36.13504",
    "lng": "-99.77484"
  },
  {
    "country": "US",
    "name": "Atoka",
    "lat": "34.38593",
    "lng": "-96.12833"
  },
  {
    "country": "US",
    "name": "Barnsdall",
    "lat": "36.56202",
    "lng": "-96.16167"
  },
  {
    "country": "US",
    "name": "Bartlesville",
    "lat": "36.74731",
    "lng": "-95.98082"
  },
  {
    "country": "US",
    "name": "Beggs",
    "lat": "35.7426",
    "lng": "-96.07027"
  },
  {
    "country": "US",
    "name": "Bethany",
    "lat": "35.51867",
    "lng": "-97.63226"
  },
  {
    "country": "US",
    "name": "Bethel Acres",
    "lat": "35.30868",
    "lng": "-97.02558"
  },
  {
    "country": "US",
    "name": "Bixby",
    "lat": "35.94204",
    "lng": "-95.88332"
  },
  {
    "country": "US",
    "name": "Blackwell",
    "lat": "36.80448",
    "lng": "-97.28282"
  },
  {
    "country": "US",
    "name": "Blanchard",
    "lat": "35.13784",
    "lng": "-97.65809"
  },
  {
    "country": "US",
    "name": "Boley",
    "lat": "35.49341",
    "lng": "-96.48362"
  },
  {
    "country": "US",
    "name": "Bray",
    "lat": "34.63786",
    "lng": "-97.81753"
  },
  {
    "country": "US",
    "name": "Bristow",
    "lat": "35.83063",
    "lng": "-96.39112"
  },
  {
    "country": "US",
    "name": "Broken Arrow",
    "lat": "36.0526",
    "lng": "-95.79082"
  },
  {
    "country": "US",
    "name": "Broken Bow",
    "lat": "34.02928",
    "lng": "-94.7391"
  },
  {
    "country": "US",
    "name": "Buffalo",
    "lat": "36.83559",
    "lng": "-99.6304"
  },
  {
    "country": "US",
    "name": "Burns Flat",
    "lat": "35.34894",
    "lng": "-99.17036"
  },
  {
    "country": "US",
    "name": "Bushyhead",
    "lat": "36.46148",
    "lng": "-95.49414"
  },
  {
    "country": "US",
    "name": "Byng",
    "lat": "34.8612",
    "lng": "-96.66557"
  },
  {
    "country": "US",
    "name": "Cache",
    "lat": "34.62952",
    "lng": "-98.62867"
  },
  {
    "country": "US",
    "name": "Caddo",
    "lat": "34.12676",
    "lng": "-96.26332"
  },
  {
    "country": "US",
    "name": "Calera",
    "lat": "33.93454",
    "lng": "-96.4286"
  },
  {
    "country": "US",
    "name": "Carnegie",
    "lat": "35.10367",
    "lng": "-98.60367"
  },
  {
    "country": "US",
    "name": "Catoosa",
    "lat": "36.18899",
    "lng": "-95.74582"
  },
  {
    "country": "US",
    "name": "Central High",
    "lat": "34.62313",
    "lng": "-98.08976"
  },
  {
    "country": "US",
    "name": "Chandler",
    "lat": "35.70173",
    "lng": "-96.88086"
  },
  {
    "country": "US",
    "name": "Checotah",
    "lat": "35.4701",
    "lng": "-95.52304"
  },
  {
    "country": "US",
    "name": "Chelsea",
    "lat": "36.53565",
    "lng": "-95.43247"
  },
  {
    "country": "US",
    "name": "Cherokee",
    "lat": "36.75447",
    "lng": "-98.35674"
  },
  {
    "country": "US",
    "name": "Cheyenne",
    "lat": "35.61394",
    "lng": "-99.67149"
  },
  {
    "country": "US",
    "name": "Chickasha",
    "lat": "35.05257",
    "lng": "-97.93643"
  },
  {
    "country": "US",
    "name": "Choctaw",
    "lat": "35.49756",
    "lng": "-97.26892"
  },
  {
    "country": "US",
    "name": "Chouteau",
    "lat": "36.18593",
    "lng": "-95.34302"
  },
  {
    "country": "US",
    "name": "Claremore",
    "lat": "36.3126",
    "lng": "-95.61609"
  },
  {
    "country": "US",
    "name": "Cleora",
    "lat": "36.57897",
    "lng": "-94.97107"
  },
  {
    "country": "US",
    "name": "Cleveland",
    "lat": "36.31032",
    "lng": "-96.46584"
  },
  {
    "country": "US",
    "name": "Clinton",
    "lat": "35.51561",
    "lng": "-98.96731"
  },
  {
    "country": "US",
    "name": "Colbert",
    "lat": "33.85316",
    "lng": "-96.50249"
  },
  {
    "country": "US",
    "name": "Collinsville",
    "lat": "36.36454",
    "lng": "-95.83888"
  },
  {
    "country": "US",
    "name": "Comanche",
    "lat": "34.36897",
    "lng": "-97.96392"
  },
  {
    "country": "US",
    "name": "Commerce",
    "lat": "36.9334",
    "lng": "-94.87301"
  },
  {
    "country": "US",
    "name": "Copeland",
    "lat": "36.65591",
    "lng": "-94.82829"
  },
  {
    "country": "US",
    "name": "Cordell",
    "lat": "35.29061",
    "lng": "-98.98841"
  },
  {
    "country": "US",
    "name": "Coweta",
    "lat": "35.95177",
    "lng": "-95.65081"
  },
  {
    "country": "US",
    "name": "Crescent",
    "lat": "35.95254",
    "lng": "-97.59477"
  },
  {
    "country": "US",
    "name": "Cushing",
    "lat": "35.98506",
    "lng": "-96.76697"
  },
  {
    "country": "US",
    "name": "Cyril",
    "lat": "34.89646",
    "lng": "-98.2006"
  },
  {
    "country": "US",
    "name": "Davis",
    "lat": "34.50453",
    "lng": "-97.11946"
  },
  {
    "country": "US",
    "name": "Del City",
    "lat": "35.44201",
    "lng": "-97.44087"
  },
  {
    "country": "US",
    "name": "Dewey",
    "lat": "36.79592",
    "lng": "-95.93554"
  },
  {
    "country": "US",
    "name": "Dickson",
    "lat": "34.18732",
    "lng": "-96.98446"
  },
  {
    "country": "US",
    "name": "Drumright",
    "lat": "35.9884",
    "lng": "-96.60113"
  },
  {
    "country": "US",
    "name": "Duncan",
    "lat": "34.5023",
    "lng": "-97.95781"
  },
  {
    "country": "US",
    "name": "Durant",
    "lat": "33.99399",
    "lng": "-96.37082"
  },
  {
    "country": "US",
    "name": "Edmond",
    "lat": "35.65283",
    "lng": "-97.4781"
  },
  {
    "country": "US",
    "name": "El Reno",
    "lat": "35.53227",
    "lng": "-97.95505"
  },
  {
    "country": "US",
    "name": "Elgin",
    "lat": "34.78035",
    "lng": "-98.29227"
  },
  {
    "country": "US",
    "name": "Elk City",
    "lat": "35.41199",
    "lng": "-99.40426"
  },
  {
    "country": "US",
    "name": "Enid",
    "lat": "36.39559",
    "lng": "-97.87839"
  },
  {
    "country": "US",
    "name": "Erick",
    "lat": "35.21533",
    "lng": "-99.86649"
  },
  {
    "country": "US",
    "name": "Eufaula",
    "lat": "35.28722",
    "lng": "-95.5825"
  },
  {
    "country": "US",
    "name": "Fairfax",
    "lat": "36.57366",
    "lng": "-96.7042"
  },
  {
    "country": "US",
    "name": "Fairland",
    "lat": "36.75118",
    "lng": "-94.84746"
  },
  {
    "country": "US",
    "name": "Fairview",
    "lat": "36.26892",
    "lng": "-98.4798"
  },
  {
    "country": "US",
    "name": "Fletcher",
    "lat": "34.82312",
    "lng": "-98.24422"
  },
  {
    "country": "US",
    "name": "Forest Park",
    "lat": "35.50423",
    "lng": "-97.44615"
  },
  {
    "country": "US",
    "name": "Fort Gibson",
    "lat": "35.7976",
    "lng": "-95.25052"
  },
  {
    "country": "US",
    "name": "Frederick",
    "lat": "34.39203",
    "lng": "-99.01841"
  },
  {
    "country": "US",
    "name": "Geary",
    "lat": "35.63116",
    "lng": "-98.31729"
  },
  {
    "country": "US",
    "name": "Geronimo",
    "lat": "34.48119",
    "lng": "-98.38311"
  },
  {
    "country": "US",
    "name": "Glenpool",
    "lat": "35.95537",
    "lng": "-96.00888"
  },
  {
    "country": "US",
    "name": "Goldsby",
    "lat": "35.14118",
    "lng": "-97.47698"
  },
  {
    "country": "US",
    "name": "Granite",
    "lat": "34.96228",
    "lng": "-99.38064"
  },
  {
    "country": "US",
    "name": "Grove",
    "lat": "36.59369",
    "lng": "-94.76912"
  },
  {
    "country": "US",
    "name": "Guthrie",
    "lat": "35.87894",
    "lng": "-97.42532"
  },
  {
    "country": "US",
    "name": "Hall Park",
    "lat": "35.23701",
    "lng": "-97.40642"
  },
  {
    "country": "US",
    "name": "Harrah",
    "lat": "35.48951",
    "lng": "-97.16364"
  },
  {
    "country": "US",
    "name": "Hartshorne",
    "lat": "34.8451",
    "lng": "-95.55748"
  },
  {
    "country": "US",
    "name": "Haskell",
    "lat": "35.82038",
    "lng": "-95.67415"
  },
  {
    "country": "US",
    "name": "Healdton",
    "lat": "34.23315",
    "lng": "-97.4878"
  },
  {
    "country": "US",
    "name": "Heavener",
    "lat": "34.88927",
    "lng": "-94.60078"
  },
  {
    "country": "US",
    "name": "Helena",
    "lat": "36.54614",
    "lng": "-98.27007"
  },
  {
    "country": "US",
    "name": "Hennessey",
    "lat": "36.1092",
    "lng": "-97.89867"
  },
  {
    "country": "US",
    "name": "Henryetta",
    "lat": "35.43983",
    "lng": "-95.98194"
  },
  {
    "country": "US",
    "name": "Hinton",
    "lat": "35.47144",
    "lng": "-98.35562"
  },
  {
    "country": "US",
    "name": "Hobart",
    "lat": "35.0295",
    "lng": "-99.09313"
  },
  {
    "country": "US",
    "name": "Holdenville",
    "lat": "35.08036",
    "lng": "-96.39918"
  },
  {
    "country": "US",
    "name": "Hollis",
    "lat": "34.68839",
    "lng": "-99.91205"
  },
  {
    "country": "US",
    "name": "Hominy",
    "lat": "36.41424",
    "lng": "-96.3953"
  },
  {
    "country": "US",
    "name": "Hugo",
    "lat": "34.01066",
    "lng": "-95.50968"
  },
  {
    "country": "US",
    "name": "Idabel",
    "lat": "33.89566",
    "lng": "-94.82633"
  },
  {
    "country": "US",
    "name": "Inola",
    "lat": "36.15121",
    "lng": "-95.50942"
  },
  {
    "country": "US",
    "name": "Jay",
    "lat": "36.42119",
    "lng": "-94.7969"
  },
  {
    "country": "US",
    "name": "Jenks",
    "lat": "36.02287",
    "lng": "-95.96833"
  },
  {
    "country": "US",
    "name": "Jones",
    "lat": "35.56589",
    "lng": "-97.28698"
  },
  {
    "country": "US",
    "name": "Justice",
    "lat": "36.29287",
    "lng": "-95.56664"
  },
  {
    "country": "US",
    "name": "Kellyville",
    "lat": "35.9437",
    "lng": "-96.21361"
  },
  {
    "country": "US",
    "name": "Kenwood",
    "lat": "36.31453",
    "lng": "-94.98579"
  },
  {
    "country": "US",
    "name": "Kiefer",
    "lat": "35.94482",
    "lng": "-96.06528"
  },
  {
    "country": "US",
    "name": "Kingfisher",
    "lat": "35.86143",
    "lng": "-97.93172"
  },
  {
    "country": "US",
    "name": "Kingston",
    "lat": "33.99871",
    "lng": "-96.71972"
  },
  {
    "country": "US",
    "name": "Konawa",
    "lat": "34.95953",
    "lng": "-96.7528"
  },
  {
    "country": "US",
    "name": "Krebs",
    "lat": "34.92787",
    "lng": "-95.71582"
  },
  {
    "country": "US",
    "name": "Langston",
    "lat": "35.94505",
    "lng": "-97.25531"
  },
  {
    "country": "US",
    "name": "Laverne",
    "lat": "36.70975",
    "lng": "-99.89346"
  },
  {
    "country": "US",
    "name": "Lawton",
    "lat": "34.60869",
    "lng": "-98.39033"
  },
  {
    "country": "US",
    "name": "Lexington",
    "lat": "35.01479",
    "lng": "-97.33558"
  },
  {
    "country": "US",
    "name": "Lindsay",
    "lat": "34.8348",
    "lng": "-97.60253"
  },
  {
    "country": "US",
    "name": "Locust Grove",
    "lat": "36.20009",
    "lng": "-95.16774"
  },
  {
    "country": "US",
    "name": "Lone Grove",
    "lat": "34.17537",
    "lng": "-97.26279"
  },
  {
    "country": "US",
    "name": "Longtown",
    "lat": "35.24538",
    "lng": "-95.51276"
  },
  {
    "country": "US",
    "name": "Luther",
    "lat": "35.66173",
    "lng": "-97.19559"
  },
  {
    "country": "US",
    "name": "Madill",
    "lat": "34.09038",
    "lng": "-96.77167"
  },
  {
    "country": "US",
    "name": "Mangum",
    "lat": "34.872",
    "lng": "-99.50426"
  },
  {
    "country": "US",
    "name": "Mannford",
    "lat": "36.13341",
    "lng": "-96.35446"
  },
  {
    "country": "US",
    "name": "Marietta",
    "lat": "33.93704",
    "lng": "-97.11668"
  },
  {
    "country": "US",
    "name": "Marlow",
    "lat": "34.64813",
    "lng": "-97.95809"
  },
  {
    "country": "US",
    "name": "Marlow",
    "lat": "34.59036",
    "lng": "-97.95587"
  },
  {
    "country": "US",
    "name": "Maud",
    "lat": "35.13036",
    "lng": "-96.77585"
  },
  {
    "country": "US",
    "name": "Maysville",
    "lat": "34.8173",
    "lng": "-97.40586"
  },
  {
    "country": "US",
    "name": "McAlester",
    "lat": "34.93343",
    "lng": "-95.76971"
  },
  {
    "country": "US",
    "name": "McCord",
    "lat": "36.67847",
    "lng": "-97.04"
  },
  {
    "country": "US",
    "name": "McLoud",
    "lat": "35.4359",
    "lng": "-97.09142"
  },
  {
    "country": "US",
    "name": "Medford",
    "lat": "36.80697",
    "lng": "-97.73366"
  },
  {
    "country": "US",
    "name": "Meeker",
    "lat": "35.5034",
    "lng": "-96.9028"
  },
  {
    "country": "US",
    "name": "Meridian",
    "lat": "34.42731",
    "lng": "-97.97809"
  },
  {
    "country": "US",
    "name": "Miami",
    "lat": "36.87451",
    "lng": "-94.87746"
  },
  {
    "country": "US",
    "name": "Midwest City",
    "lat": "35.44951",
    "lng": "-97.3967"
  },
  {
    "country": "US",
    "name": "Minco",
    "lat": "35.31284",
    "lng": "-97.94449"
  },
  {
    "country": "US",
    "name": "Moore",
    "lat": "35.33951",
    "lng": "-97.4867"
  },
  {
    "country": "US",
    "name": "Mooreland",
    "lat": "36.4392",
    "lng": "-99.20482"
  },
  {
    "country": "US",
    "name": "Morris",
    "lat": "35.6076",
    "lng": "-95.86027"
  },
  {
    "country": "US",
    "name": "Mounds",
    "lat": "35.87648",
    "lng": "-96.06111"
  },
  {
    "country": "US",
    "name": "Muldrow",
    "lat": "35.4062",
    "lng": "-94.59883"
  },
  {
    "country": "US",
    "name": "Muskogee",
    "lat": "35.74788",
    "lng": "-95.36969"
  },
  {
    "country": "US",
    "name": "Mustang",
    "lat": "35.38423",
    "lng": "-97.72449"
  },
  {
    "country": "US",
    "name": "Newcastle",
    "lat": "35.24729",
    "lng": "-97.59976"
  },
  {
    "country": "US",
    "name": "Newkirk",
    "lat": "36.88225",
    "lng": "-97.05337"
  },
  {
    "country": "US",
    "name": "Nichols Hills",
    "lat": "35.55089",
    "lng": "-97.54893"
  },
  {
    "country": "US",
    "name": "Nicoma Park",
    "lat": "35.49117",
    "lng": "-97.32309"
  },
  {
    "country": "US",
    "name": "Ninnekah",
    "lat": "34.94785",
    "lng": "-97.92393"
  },
  {
    "country": "US",
    "name": "Noble",
    "lat": "35.13924",
    "lng": "-97.39475"
  },
  {
    "country": "US",
    "name": "Norman",
    "lat": "35.22257",
    "lng": "-97.43948"
  },
  {
    "country": "US",
    "name": "Nowata",
    "lat": "36.70065",
    "lng": "-95.63803"
  },
  {
    "country": "US",
    "name": "Oakhurst",
    "lat": "36.07537",
    "lng": "-96.06444"
  },
  {
    "country": "US",
    "name": "Oakland",
    "lat": "34.1001",
    "lng": "-96.79389"
  },
  {
    "country": "US",
    "name": "Oilton",
    "lat": "36.08451",
    "lng": "-96.58363"
  },
  {
    "country": "US",
    "name": "Okarche",
    "lat": "35.72588",
    "lng": "-97.97644"
  },
  {
    "country": "US",
    "name": "Okeene",
    "lat": "36.11615",
    "lng": "-98.31702"
  },
  {
    "country": "US",
    "name": "Okemah",
    "lat": "35.43259",
    "lng": "-96.30501"
  },
  {
    "country": "US",
    "name": "Oklahoma City",
    "lat": "35.46756",
    "lng": "-97.51643"
  },
  {
    "country": "US",
    "name": "Okmulgee",
    "lat": "35.62344",
    "lng": "-95.96055"
  },
  {
    "country": "US",
    "name": "Oologah",
    "lat": "36.44704",
    "lng": "-95.70832"
  },
  {
    "country": "US",
    "name": "Owasso",
    "lat": "36.26954",
    "lng": "-95.85471"
  },
  {
    "country": "US",
    "name": "Panama",
    "lat": "35.16732",
    "lng": "-94.67245"
  },
  {
    "country": "US",
    "name": "Park Hill",
    "lat": "35.8612",
    "lng": "-94.95884"
  },
  {
    "country": "US",
    "name": "Pawhuska",
    "lat": "36.66784",
    "lng": "-96.33723"
  },
  {
    "country": "US",
    "name": "Pawnee",
    "lat": "36.33783",
    "lng": "-96.80392"
  },
  {
    "country": "US",
    "name": "Pauls Valley",
    "lat": "34.74008",
    "lng": "-97.22225"
  },
  {
    "country": "US",
    "name": "Perkins",
    "lat": "35.97394",
    "lng": "-97.03364"
  },
  {
    "country": "US",
    "name": "Perry",
    "lat": "36.28949",
    "lng": "-97.2881"
  },
  {
    "country": "US",
    "name": "Piedmont",
    "lat": "35.642",
    "lng": "-97.74643"
  },
  {
    "country": "US",
    "name": "Pink",
    "lat": "35.26063",
    "lng": "-97.11975"
  },
  {
    "country": "US",
    "name": "Pocola",
    "lat": "35.23121",
    "lng": "-94.478"
  },
  {
    "country": "US",
    "name": "Ponca City",
    "lat": "36.70698",
    "lng": "-97.08559"
  },
  {
    "country": "US",
    "name": "Poteau",
    "lat": "35.05371",
    "lng": "-94.62356"
  },
  {
    "country": "US",
    "name": "Prague",
    "lat": "35.48674",
    "lng": "-96.68502"
  },
  {
    "country": "US",
    "name": "Pryor",
    "lat": "36.30843",
    "lng": "-95.31691"
  },
  {
    "country": "US",
    "name": "Purcell",
    "lat": "35.01368",
    "lng": "-97.36114"
  },
  {
    "country": "US",
    "name": "Quinton",
    "lat": "35.12288",
    "lng": "-95.37109"
  },
  {
    "country": "US",
    "name": "Ringling",
    "lat": "34.17843",
    "lng": "-97.59253"
  },
  {
    "country": "US",
    "name": "Roland",
    "lat": "35.4212",
    "lng": "-94.51466"
  },
  {
    "country": "US",
    "name": "Rush Springs",
    "lat": "34.78257",
    "lng": "-97.95698"
  },
  {
    "country": "US",
    "name": "Salina",
    "lat": "36.29287",
    "lng": "-95.1533"
  },
  {
    "country": "US",
    "name": "Sallisaw",
    "lat": "35.46037",
    "lng": "-94.78745"
  },
  {
    "country": "US",
    "name": "Sand Springs",
    "lat": "36.13981",
    "lng": "-96.10889"
  },
  {
    "country": "US",
    "name": "Sapulpa",
    "lat": "35.9987",
    "lng": "-96.11417"
  },
  {
    "country": "US",
    "name": "Sayre",
    "lat": "35.29116",
    "lng": "-99.6401"
  },
  {
    "country": "US",
    "name": "Seminole",
    "lat": "35.22452",
    "lng": "-96.67057"
  },
  {
    "country": "US",
    "name": "Shattuck",
    "lat": "36.27614",
    "lng": "-99.88276"
  },
  {
    "country": "US",
    "name": "Shawnee",
    "lat": "35.32729",
    "lng": "-96.9253"
  },
  {
    "country": "US",
    "name": "Skiatook",
    "lat": "36.36842",
    "lng": "-96.00138"
  },
  {
    "country": "US",
    "name": "Slaughterville",
    "lat": "35.08729",
    "lng": "-97.33503"
  },
  {
    "country": "US",
    "name": "Snyder",
    "lat": "34.65896",
    "lng": "-98.95174"
  },
  {
    "country": "US",
    "name": "Spencer",
    "lat": "35.52284",
    "lng": "-97.37726"
  },
  {
    "country": "US",
    "name": "Sperry",
    "lat": "36.29731",
    "lng": "-95.99139"
  },
  {
    "country": "US",
    "name": "Spiro",
    "lat": "35.24121",
    "lng": "-94.61994"
  },
  {
    "country": "US",
    "name": "Stigler",
    "lat": "35.25371",
    "lng": "-95.12302"
  },
  {
    "country": "US",
    "name": "Stillwater",
    "lat": "36.11561",
    "lng": "-97.05837"
  },
  {
    "country": "US",
    "name": "Stilwell",
    "lat": "35.81453",
    "lng": "-94.62856"
  },
  {
    "country": "US",
    "name": "Stratford",
    "lat": "34.79675",
    "lng": "-96.95946"
  },
  {
    "country": "US",
    "name": "Stroud",
    "lat": "35.74868",
    "lng": "-96.65807"
  },
  {
    "country": "US",
    "name": "Sulphur",
    "lat": "34.50787",
    "lng": "-96.96835"
  },
  {
    "country": "US",
    "name": "Tahlequah",
    "lat": "35.91537",
    "lng": "-94.96996"
  },
  {
    "country": "US",
    "name": "Talihina",
    "lat": "34.75149",
    "lng": "-95.04802"
  },
  {
    "country": "US",
    "name": "Taloga",
    "lat": "36.03865",
    "lng": "-98.96371"
  },
  {
    "country": "US",
    "name": "Tecumseh",
    "lat": "35.25785",
    "lng": "-96.93669"
  },
  {
    "country": "US",
    "name": "Texanna",
    "lat": "35.34732",
    "lng": "-95.43692"
  },
  {
    "country": "US",
    "name": "The Village",
    "lat": "35.56089",
    "lng": "-97.55143"
  },
  {
    "country": "US",
    "name": "Thomas",
    "lat": "35.74422",
    "lng": "-98.74758"
  },
  {
    "country": "US",
    "name": "Tishomingo",
    "lat": "34.23621",
    "lng": "-96.67861"
  },
  {
    "country": "US",
    "name": "Tonkawa",
    "lat": "36.67837",
    "lng": "-97.31004"
  },
  {
    "country": "US",
    "name": "Tulsa",
    "lat": "36.15398",
    "lng": "-95.99277"
  },
  {
    "country": "US",
    "name": "Turley",
    "lat": "36.24204",
    "lng": "-95.97583"
  },
  {
    "country": "US",
    "name": "Tuttle",
    "lat": "35.29089",
    "lng": "-97.81227"
  },
  {
    "country": "US",
    "name": "Union City",
    "lat": "35.39172",
    "lng": "-97.94144"
  },
  {
    "country": "US",
    "name": "Verdigris",
    "lat": "36.23482",
    "lng": "-95.69109"
  },
  {
    "country": "US",
    "name": "Vian",
    "lat": "35.49843",
    "lng": "-94.96967"
  },
  {
    "country": "US",
    "name": "Vinita",
    "lat": "36.63869",
    "lng": "-95.15413"
  },
  {
    "country": "US",
    "name": "Wagoner",
    "lat": "35.95954",
    "lng": "-95.36941"
  },
  {
    "country": "US",
    "name": "Walters",
    "lat": "34.35981",
    "lng": "-98.30783"
  },
  {
    "country": "US",
    "name": "Warr Acres",
    "lat": "35.52256",
    "lng": "-97.61893"
  },
  {
    "country": "US",
    "name": "Warner",
    "lat": "35.49426",
    "lng": "-95.30552"
  },
  {
    "country": "US",
    "name": "Watonga",
    "lat": "35.84477",
    "lng": "-98.41313"
  },
  {
    "country": "US",
    "name": "Waukomis",
    "lat": "36.28031",
    "lng": "-97.89811"
  },
  {
    "country": "US",
    "name": "Waurika",
    "lat": "34.16704",
    "lng": "-97.99754"
  },
  {
    "country": "US",
    "name": "Weatherford",
    "lat": "35.52616",
    "lng": "-98.70757"
  },
  {
    "country": "US",
    "name": "Westville",
    "lat": "35.99258",
    "lng": "-94.568"
  },
  {
    "country": "US",
    "name": "Wetumka",
    "lat": "35.23759",
    "lng": "-96.24167"
  },
  {
    "country": "US",
    "name": "Wewoka",
    "lat": "35.15869",
    "lng": "-96.49335"
  },
  {
    "country": "US",
    "name": "Wilburton",
    "lat": "34.91871",
    "lng": "-95.30914"
  },
  {
    "country": "US",
    "name": "Wilson",
    "lat": "34.16204",
    "lng": "-97.42586"
  },
  {
    "country": "US",
    "name": "Wilson",
    "lat": "35.5076",
    "lng": "-96.03472"
  },
  {
    "country": "US",
    "name": "Wister",
    "lat": "34.96732",
    "lng": "-94.72467"
  },
  {
    "country": "US",
    "name": "Woodward",
    "lat": "36.43365",
    "lng": "-99.39039"
  },
  {
    "country": "US",
    "name": "Wynnewood",
    "lat": "34.64342",
    "lng": "-97.16447"
  },
  {
    "country": "US",
    "name": "Yale",
    "lat": "36.11423",
    "lng": "-96.69919"
  },
  {
    "country": "US",
    "name": "Yukon",
    "lat": "35.50672",
    "lng": "-97.76254"
  },
  {
    "country": "US",
    "name": "Abbottstown",
    "lat": "39.88649",
    "lng": "-76.9847"
  },
  {
    "country": "US",
    "name": "Aldan",
    "lat": "39.9215",
    "lng": "-75.28796"
  },
  {
    "country": "US",
    "name": "Atglen",
    "lat": "39.94927",
    "lng": "-75.97356"
  },
  {
    "country": "US",
    "name": "Avondale",
    "lat": "39.82344",
    "lng": "-75.78327"
  },
  {
    "country": "US",
    "name": "Berlin",
    "lat": "39.92064",
    "lng": "-78.9578"
  },
  {
    "country": "US",
    "name": "Biglerville",
    "lat": "39.93037",
    "lng": "-77.24804"
  },
  {
    "country": "US",
    "name": "Bonneauville",
    "lat": "39.81204",
    "lng": "-77.13721"
  },
  {
    "country": "US",
    "name": "Boothwyn",
    "lat": "39.83011",
    "lng": "-75.44158"
  },
  {
    "country": "US",
    "name": "Brookhaven",
    "lat": "39.86928",
    "lng": "-75.38241"
  },
  {
    "country": "US",
    "name": "Broomall",
    "lat": "39.9815",
    "lng": "-75.35658"
  },
  {
    "country": "US",
    "name": "Caln",
    "lat": "39.99094",
    "lng": "-75.78022"
  },
  {
    "country": "US",
    "name": "Carroll Valley",
    "lat": "39.74926",
    "lng": "-77.38304"
  },
  {
    "country": "US",
    "name": "Chambersburg",
    "lat": "39.93759",
    "lng": "-77.6611"
  },
  {
    "country": "US",
    "name": "Chester",
    "lat": "39.84967",
    "lng": "-75.35707"
  },
  {
    "country": "US",
    "name": "Chester Heights",
    "lat": "39.89011",
    "lng": "-75.47548"
  },
  {
    "country": "US",
    "name": "Christiana",
    "lat": "39.95483",
    "lng": "-75.99689"
  },
  {
    "country": "US",
    "name": "Clifton Heights",
    "lat": "39.92928",
    "lng": "-75.2963"
  },
  {
    "country": "US",
    "name": "Coatesville",
    "lat": "39.98316",
    "lng": "-75.82384"
  },
  {
    "country": "US",
    "name": "Collingdale",
    "lat": "39.91178",
    "lng": "-75.27713"
  },
  {
    "country": "US",
    "name": "Colwyn",
    "lat": "39.91234",
    "lng": "-75.25379"
  },
  {
    "country": "US",
    "name": "Conestoga",
    "lat": "39.94066",
    "lng": "-76.34635"
  },
  {
    "country": "US",
    "name": "Dallastown",
    "lat": "39.89954",
    "lng": "-76.64025"
  },
  {
    "country": "US",
    "name": "Darby",
    "lat": "39.91845",
    "lng": "-75.25907"
  },
  {
    "country": "US",
    "name": "Drexel Hill",
    "lat": "39.94706",
    "lng": "-75.29213"
  },
  {
    "country": "US",
    "name": "Dunbar",
    "lat": "39.97785",
    "lng": "-79.61448"
  },
  {
    "country": "US",
    "name": "East Berlin",
    "lat": "39.9376",
    "lng": "-76.97859"
  },
  {
    "country": "US",
    "name": "East Lansdowne",
    "lat": "39.94567",
    "lng": "-75.26129"
  },
  {
    "country": "US",
    "name": "East Uniontown",
    "lat": "39.8998",
    "lng": "-79.69782"
  },
  {
    "country": "US",
    "name": "East York",
    "lat": "39.97371",
    "lng": "-76.68636"
  },
  {
    "country": "US",
    "name": "Eddystone",
    "lat": "39.86011",
    "lng": "-75.34436"
  },
  {
    "country": "US",
    "name": "Fairchance",
    "lat": "39.8248",
    "lng": "-79.75449"
  },
  {
    "country": "US",
    "name": "Fairdale",
    "lat": "39.88702",
    "lng": "-79.96811"
  },
  {
    "country": "US",
    "name": "Fayetteville",
    "lat": "39.9112",
    "lng": "-77.54999"
  },
  {
    "country": "US",
    "name": "Folsom",
    "lat": "39.88983",
    "lng": "-75.32519"
  },
  {
    "country": "US",
    "name": "Folcroft",
    "lat": "39.89095",
    "lng": "-75.2838"
  },
  {
    "country": "US",
    "name": "Gap",
    "lat": "39.98732",
    "lng": "-76.02051"
  },
  {
    "country": "US",
    "name": "Georgetown",
    "lat": "39.9376",
    "lng": "-76.08329"
  },
  {
    "country": "US",
    "name": "Gettysburg",
    "lat": "39.83093",
    "lng": "-77.2311"
  },
  {
    "country": "US",
    "name": "Glen Rock",
    "lat": "39.79316",
    "lng": "-76.73025"
  },
  {
    "country": "US",
    "name": "Glenolden",
    "lat": "39.90011",
    "lng": "-75.28907"
  },
  {
    "country": "US",
    "name": "Grantley",
    "lat": "39.94038",
    "lng": "-76.72913"
  },
  {
    "country": "US",
    "name": "Greencastle",
    "lat": "39.79037",
    "lng": "-77.72777"
  },
  {
    "country": "US",
    "name": "Guilford Siding",
    "lat": "39.86537",
    "lng": "-77.61249"
  },
  {
    "country": "US",
    "name": "Hanover",
    "lat": "39.80066",
    "lng": "-76.98304"
  },
  {
    "country": "US",
    "name": "Hopwood",
    "lat": "39.87702",
    "lng": "-79.70199"
  },
  {
    "country": "US",
    "name": "Jacobus",
    "lat": "39.88316",
    "lng": "-76.71052"
  },
  {
    "country": "US",
    "name": "Kennett Square",
    "lat": "39.84678",
    "lng": "-75.7116"
  },
  {
    "country": "US",
    "name": "Lake Heritage",
    "lat": "39.80954",
    "lng": "-77.18387"
  },
  {
    "country": "US",
    "name": "Lake Meade",
    "lat": "39.9851",
    "lng": "-77.0372"
  },
  {
    "country": "US",
    "name": "Lampeter",
    "lat": "39.9901",
    "lng": "-76.23968"
  },
  {
    "country": "US",
    "name": "Lansdowne",
    "lat": "39.93817",
    "lng": "-75.27185"
  },
  {
    "country": "US",
    "name": "Lima",
    "lat": "39.91733",
    "lng": "-75.44047"
  },
  {
    "country": "US",
    "name": "Linwood",
    "lat": "39.8265",
    "lng": "-75.42547"
  },
  {
    "country": "US",
    "name": "Littlestown",
    "lat": "39.74454",
    "lng": "-77.08804"
  },
  {
    "country": "US",
    "name": "Loganville",
    "lat": "39.85566",
    "lng": "-76.70747"
  },
  {
    "country": "US",
    "name": "Luzerne",
    "lat": "39.99924",
    "lng": "-79.96283"
  },
  {
    "country": "US",
    "name": "Marcus Hook",
    "lat": "39.81928",
    "lng": "-75.41853"
  },
  {
    "country": "US",
    "name": "Masontown",
    "lat": "39.84674",
    "lng": "-79.89978"
  },
  {
    "country": "US",
    "name": "McConnellsburg",
    "lat": "39.93259",
    "lng": "-77.99889"
  },
  {
    "country": "US",
    "name": "McSherrystown",
    "lat": "39.80732",
    "lng": "-77.01137"
  },
  {
    "country": "US",
    "name": "Media",
    "lat": "39.91678",
    "lng": "-75.38769"
  },
  {
    "country": "US",
    "name": "Mercersburg",
    "lat": "39.82787",
    "lng": "-77.90333"
  },
  {
    "country": "US",
    "name": "Meyersdale",
    "lat": "39.81369",
    "lng": "-79.02475"
  },
  {
    "country": "US",
    "name": "Midway",
    "lat": "39.80843",
    "lng": "-77.00276"
  },
  {
    "country": "US",
    "name": "Milford",
    "lat": "39.95313",
    "lng": "-79.10419"
  },
  {
    "country": "US",
    "name": "Millbourne",
    "lat": "39.96345",
    "lng": "-75.25018"
  },
  {
    "country": "US",
    "name": "Millersville",
    "lat": "39.99788",
    "lng": "-76.35413"
  },
  {
    "country": "US",
    "name": "Mont Alto",
    "lat": "39.84426",
    "lng": "-77.55832"
  },
  {
    "country": "US",
    "name": "Morrisville",
    "lat": "39.8948",
    "lng": "-80.16173"
  },
  {
    "country": "US",
    "name": "Morton",
    "lat": "39.90983",
    "lng": "-75.32352"
  },
  {
    "country": "US",
    "name": "Mount Pleasant",
    "lat": "39.73371",
    "lng": "-77.07554"
  },
  {
    "country": "US",
    "name": "New Freedom",
    "lat": "39.73788",
    "lng": "-76.70136"
  },
  {
    "country": "US",
    "name": "New Oxford",
    "lat": "39.86371",
    "lng": "-77.05581"
  },
  {
    "country": "US",
    "name": "North York",
    "lat": "39.97815",
    "lng": "-76.73302"
  },
  {
    "country": "US",
    "name": "Norwood",
    "lat": "39.89178",
    "lng": "-75.29963"
  },
  {
    "country": "US",
    "name": "Oliver",
    "lat": "39.91869",
    "lng": "-79.71782"
  },
  {
    "country": "US",
    "name": "Oxford",
    "lat": "39.78539",
    "lng": "-75.97883"
  },
  {
    "country": "US",
    "name": "Parkesburg",
    "lat": "39.95872",
    "lng": "-75.91939"
  },
  {
    "country": "US",
    "name": "Parkside",
    "lat": "39.86428",
    "lng": "-75.37853"
  },
  {
    "country": "US",
    "name": "Parkville",
    "lat": "39.78121",
    "lng": "-76.96331"
  },
  {
    "country": "US",
    "name": "Penn Wynne",
    "lat": "39.98622",
    "lng": "-75.27546"
  },
  {
    "country": "US",
    "name": "Pennsport",
    "lat": "39.92761",
    "lng": "-75.15045"
  },
  {
    "country": "US",
    "name": "Pennville",
    "lat": "39.78954",
    "lng": "-76.99804"
  },
  {
    "country": "US",
    "name": "Philadelphia",
    "lat": "39.95233",
    "lng": "-75.16379"
  },
  {
    "country": "US",
    "name": "Point Marion",
    "lat": "39.73897",
    "lng": "-79.89867"
  },
  {
    "country": "US",
    "name": "Prospect Park",
    "lat": "39.88789",
    "lng": "-75.30824"
  },
  {
    "country": "US",
    "name": "Quarryville",
    "lat": "39.89705",
    "lng": "-76.16357"
  },
  {
    "country": "US",
    "name": "Red Lion",
    "lat": "39.90093",
    "lng": "-76.6058"
  },
  {
    "country": "US",
    "name": "Republic",
    "lat": "39.96258",
    "lng": "-79.87671"
  },
  {
    "country": "US",
    "name": "Ridley Park",
    "lat": "39.88122",
    "lng": "-75.3238"
  },
  {
    "country": "US",
    "name": "Scotland",
    "lat": "39.9687",
    "lng": "-77.58721"
  },
  {
    "country": "US",
    "name": "Sharon Hill",
    "lat": "39.9065",
    "lng": "-75.27157"
  },
  {
    "country": "US",
    "name": "Shiloh",
    "lat": "39.97815",
    "lng": "-76.79719"
  },
  {
    "country": "US",
    "name": "Shrewsbury",
    "lat": "39.76871",
    "lng": "-76.67969"
  },
  {
    "country": "US",
    "name": "South Connellsville",
    "lat": "39.99674",
    "lng": "-79.58587"
  },
  {
    "country": "US",
    "name": "South Coatesville",
    "lat": "39.97427",
    "lng": "-75.81995"
  },
  {
    "country": "US",
    "name": "South Uniontown",
    "lat": "39.89285",
    "lng": "-79.74699"
  },
  {
    "country": "US",
    "name": "Spring Grove",
    "lat": "39.87454",
    "lng": "-76.86581"
  },
  {
    "country": "US",
    "name": "Springfield",
    "lat": "39.93067",
    "lng": "-75.32019"
  },
  {
    "country": "US",
    "name": "Spry",
    "lat": "39.91843",
    "lng": "-76.68497"
  },
  {
    "country": "US",
    "name": "State Line",
    "lat": "39.72482",
    "lng": "-77.72444"
  },
  {
    "country": "US",
    "name": "Stewartstown",
    "lat": "39.75371",
    "lng": "-76.59136"
  },
  {
    "country": "US",
    "name": "Stonybrook",
    "lat": "39.98704",
    "lng": "-76.64413"
  },
  {
    "country": "US",
    "name": "Strasburg",
    "lat": "39.98316",
    "lng": "-76.18412"
  },
  {
    "country": "US",
    "name": "Susquehanna Trails",
    "lat": "39.75872",
    "lng": "-76.36802"
  },
  {
    "country": "US",
    "name": "Swarthmore",
    "lat": "39.90206",
    "lng": "-75.34991"
  },
  {
    "country": "US",
    "name": "Thorndale",
    "lat": "39.99288",
    "lng": "-75.74522"
  },
  {
    "country": "US",
    "name": "Toughkenamon",
    "lat": "39.8315",
    "lng": "-75.75744"
  },
  {
    "country": "US",
    "name": "Trainer",
    "lat": "39.82761",
    "lng": "-75.41436"
  },
  {
    "country": "US",
    "name": "Uniontown",
    "lat": "39.90008",
    "lng": "-79.71643"
  },
  {
    "country": "US",
    "name": "Upland",
    "lat": "39.8865",
    "lng": "-75.77439"
  },
  {
    "country": "US",
    "name": "Upland",
    "lat": "39.85261",
    "lng": "-75.38269"
  },
  {
    "country": "US",
    "name": "Valley View",
    "lat": "39.9501",
    "lng": "-76.70108"
  },
  {
    "country": "US",
    "name": "Wayne Heights",
    "lat": "39.74371",
    "lng": "-77.55388"
  },
  {
    "country": "US",
    "name": "Waynesboro",
    "lat": "39.75593",
    "lng": "-77.57777"
  },
  {
    "country": "US",
    "name": "Waynesburg",
    "lat": "39.89646",
    "lng": "-80.17923"
  },
  {
    "country": "US",
    "name": "Weigelstown",
    "lat": "39.98371",
    "lng": "-76.82247"
  },
  {
    "country": "US",
    "name": "West Chester",
    "lat": "39.96097",
    "lng": "-75.60804"
  },
  {
    "country": "US",
    "name": "West Grove",
    "lat": "39.82205",
    "lng": "-75.82744"
  },
  {
    "country": "US",
    "name": "West York",
    "lat": "39.9526",
    "lng": "-76.75136"
  },
  {
    "country": "US",
    "name": "Wharton",
    "lat": "39.92678",
    "lng": "-75.15712"
  },
  {
    "country": "US",
    "name": "Whitman",
    "lat": "39.91678",
    "lng": "-75.15546"
  },
  {
    "country": "US",
    "name": "Willow Street",
    "lat": "39.97927",
    "lng": "-76.27635"
  },
  {
    "country": "US",
    "name": "Windsor",
    "lat": "39.91621",
    "lng": "-76.58441"
  },
  {
    "country": "US",
    "name": "Woodlyn",
    "lat": "39.87233",
    "lng": "-75.33713"
  },
  {
    "country": "US",
    "name": "Yoe",
    "lat": "39.90899",
    "lng": "-76.63691"
  },
  {
    "country": "US",
    "name": "York",
    "lat": "39.9626",
    "lng": "-76.72774"
  },
  {
    "country": "US",
    "name": "Yeadon",
    "lat": "39.939",
    "lng": "-75.25546"
  },
  {
    "country": "US",
    "name": "Yorklyn",
    "lat": "39.99232",
    "lng": "-76.64635"
  },
  {
    "country": "US",
    "name": "Abbeville",
    "lat": "34.17817",
    "lng": "-82.37901"
  },
  {
    "country": "US",
    "name": "Aiken",
    "lat": "33.56042",
    "lng": "-81.71955"
  },
  {
    "country": "US",
    "name": "Allendale",
    "lat": "33.00793",
    "lng": "-81.30844"
  },
  {
    "country": "US",
    "name": "Anderson",
    "lat": "34.50344",
    "lng": "-82.65013"
  },
  {
    "country": "US",
    "name": "Andrews",
    "lat": "33.45128",
    "lng": "-79.5609"
  },
  {
    "country": "US",
    "name": "Arcadia",
    "lat": "34.95818",
    "lng": "-81.99066"
  },
  {
    "country": "US",
    "name": "Arial",
    "lat": "34.84595",
    "lng": "-82.64152"
  },
  {
    "country": "US",
    "name": "Awendaw",
    "lat": "33.03767",
    "lng": "-79.61313"
  },
  {
    "country": "US",
    "name": "Bamberg",
    "lat": "33.2971",
    "lng": "-81.03482"
  },
  {
    "country": "US",
    "name": "Barnwell",
    "lat": "33.24487",
    "lng": "-81.35872"
  },
  {
    "country": "US",
    "name": "Batesburg",
    "lat": "33.90792",
    "lng": "-81.54733"
  },
  {
    "country": "US",
    "name": "Batesburg-Leesville",
    "lat": "33.91014",
    "lng": "-81.53733"
  },
  {
    "country": "US",
    "name": "Beaufort",
    "lat": "32.43158",
    "lng": "-80.66983"
  },
  {
    "country": "US",
    "name": "Belton",
    "lat": "34.52289",
    "lng": "-82.49429"
  },
  {
    "country": "US",
    "name": "Belvedere",
    "lat": "33.53097",
    "lng": "-81.94484"
  },
  {
    "country": "US",
    "name": "Bennettsville",
    "lat": "34.61738",
    "lng": "-79.68478"
  },
  {
    "country": "US",
    "name": "Berea",
    "lat": "34.8854",
    "lng": "-82.45596"
  },
  {
    "country": "US",
    "name": "Bishopville",
    "lat": "34.21821",
    "lng": "-80.24841"
  },
  {
    "country": "US",
    "name": "Blackville",
    "lat": "33.35793",
    "lng": "-81.27066"
  },
  {
    "country": "US",
    "name": "Blacksburg",
    "lat": "35.12124",
    "lng": "-81.51592"
  },
  {
    "country": "US",
    "name": "Bluffton",
    "lat": "32.23715",
    "lng": "-80.86039"
  },
  {
    "country": "US",
    "name": "Blythewood",
    "lat": "34.21432",
    "lng": "-80.97398"
  },
  {
    "country": "US",
    "name": "Boiling Springs",
    "lat": "33.13515",
    "lng": "-81.43122"
  },
  {
    "country": "US",
    "name": "Boiling Springs",
    "lat": "35.04651",
    "lng": "-81.98177"
  },
  {
    "country": "US",
    "name": "Bonneau Beach",
    "lat": "33.31989",
    "lng": "-80.00036"
  },
  {
    "country": "US",
    "name": "Brookdale",
    "lat": "33.50682",
    "lng": "-80.82342"
  },
  {
    "country": "US",
    "name": "Buffalo",
    "lat": "34.72569",
    "lng": "-81.68343"
  },
  {
    "country": "US",
    "name": "Burnettown",
    "lat": "33.51541",
    "lng": "-81.849"
  },
  {
    "country": "US",
    "name": "Burton",
    "lat": "32.43575",
    "lng": "-80.724"
  },
  {
    "country": "US",
    "name": "Calhoun Falls",
    "lat": "34.09234",
    "lng": "-82.59569"
  },
  {
    "country": "US",
    "name": "Camden",
    "lat": "34.24654",
    "lng": "-80.60702"
  },
  {
    "country": "US",
    "name": "Cane Savannah",
    "lat": "33.90182",
    "lng": "-80.45036"
  },
  {
    "country": "US",
    "name": "Catawba",
    "lat": "34.85292",
    "lng": "-80.91119"
  },
  {
    "country": "US",
    "name": "Cayce",
    "lat": "33.96571",
    "lng": "-81.07398"
  },
  {
    "country": "US",
    "name": "Centerville",
    "lat": "34.53205",
    "lng": "-82.70402"
  },
  {
    "country": "US",
    "name": "Centerville",
    "lat": "32.99573",
    "lng": "-80.17037"
  },
  {
    "country": "US",
    "name": "Central",
    "lat": "34.72427",
    "lng": "-82.78125"
  },
  {
    "country": "US",
    "name": "Chapin",
    "lat": "34.16598",
    "lng": "-81.34982"
  },
  {
    "country": "US",
    "name": "Charleston",
    "lat": "32.77657",
    "lng": "-79.93092"
  },
  {
    "country": "US",
    "name": "Cheraw",
    "lat": "34.69766",
    "lng": "-79.8834"
  },
  {
    "country": "US",
    "name": "Cherryvale",
    "lat": "33.95571",
    "lng": "-80.45814"
  },
  {
    "country": "US",
    "name": "Chesterfield",
    "lat": "34.73599",
    "lng": "-80.08812"
  },
  {
    "country": "US",
    "name": "Chester",
    "lat": "34.70486",
    "lng": "-81.21426"
  },
  {
    "country": "US",
    "name": "City View",
    "lat": "34.86151",
    "lng": "-82.43151"
  },
  {
    "country": "US",
    "name": "Clearwater",
    "lat": "33.4968",
    "lng": "-81.89206"
  },
  {
    "country": "US",
    "name": "Clemson",
    "lat": "34.68344",
    "lng": "-82.83737"
  },
  {
    "country": "US",
    "name": "Clinton",
    "lat": "34.47263",
    "lng": "-81.88066"
  },
  {
    "country": "US",
    "name": "Clover",
    "lat": "35.11125",
    "lng": "-81.22646"
  },
  {
    "country": "US",
    "name": "Columbia",
    "lat": "34.00071",
    "lng": "-81.03481"
  },
  {
    "country": "US",
    "name": "Conway",
    "lat": "33.836",
    "lng": "-79.04781"
  },
  {
    "country": "US",
    "name": "Cowpens",
    "lat": "35.01679",
    "lng": "-81.80399"
  },
  {
    "country": "US",
    "name": "Dalzell",
    "lat": "34.01682",
    "lng": "-80.43008"
  },
  {
    "country": "US",
    "name": "Darlington",
    "lat": "34.29988",
    "lng": "-79.87617"
  },
  {
    "country": "US",
    "name": "Denmark",
    "lat": "33.32265",
    "lng": "-81.14232"
  },
  {
    "country": "US",
    "name": "Dentsville",
    "lat": "34.06404",
    "lng": "-80.95815"
  },
  {
    "country": "US",
    "name": "Dillon",
    "lat": "34.41655",
    "lng": "-79.37116"
  },
  {
    "country": "US",
    "name": "Due West",
    "lat": "34.33345",
    "lng": "-82.3879"
  },
  {
    "country": "US",
    "name": "Duncan",
    "lat": "34.9379",
    "lng": "-82.14511"
  },
  {
    "country": "US",
    "name": "Dunean",
    "lat": "34.82484",
    "lng": "-82.41929"
  },
  {
    "country": "US",
    "name": "Easley",
    "lat": "34.82984",
    "lng": "-82.60152"
  },
  {
    "country": "US",
    "name": "East Gaffney",
    "lat": "35.08013",
    "lng": "-81.63287"
  },
  {
    "country": "US",
    "name": "East Sumter",
    "lat": "33.92544",
    "lng": "-80.29619"
  },
  {
    "country": "US",
    "name": "Edgefield",
    "lat": "33.78958",
    "lng": "-81.92956"
  },
  {
    "country": "US",
    "name": "Edisto",
    "lat": "33.47654",
    "lng": "-80.8987"
  },
  {
    "country": "US",
    "name": "Elgin",
    "lat": "34.17098",
    "lng": "-80.79425"
  },
  {
    "country": "US",
    "name": "Elgin",
    "lat": "34.67293",
    "lng": "-80.71896"
  },
  {
    "country": "US",
    "name": "Estill",
    "lat": "32.75489",
    "lng": "-81.24205"
  },
  {
    "country": "US",
    "name": "Eureka Mill",
    "lat": "34.71764",
    "lng": "-81.1937"
  },
  {
    "country": "US",
    "name": "Fairfax",
    "lat": "32.95905",
    "lng": "-81.2365"
  },
  {
    "country": "US",
    "name": "Fairforest",
    "lat": "34.95651",
    "lng": "-82.01011"
  },
  {
    "country": "US",
    "name": "Five Forks",
    "lat": "34.80484",
    "lng": "-82.22956"
  },
  {
    "country": "US",
    "name": "Florence",
    "lat": "34.19543",
    "lng": "-79.76256"
  },
  {
    "country": "US",
    "name": "Folly Beach",
    "lat": "32.65518",
    "lng": "-79.94037"
  },
  {
    "country": "US",
    "name": "Forest Acres",
    "lat": "34.01932",
    "lng": "-80.98981"
  },
  {
    "country": "US",
    "name": "Forestbrook",
    "lat": "33.72239",
    "lng": "-78.95809"
  },
  {
    "country": "US",
    "name": "Fort Mill",
    "lat": "35.00737",
    "lng": "-80.94508"
  },
  {
    "country": "US",
    "name": "Fountain Inn",
    "lat": "34.68901",
    "lng": "-82.19567"
  },
  {
    "country": "US",
    "name": "Gadsden",
    "lat": "33.84571",
    "lng": "-80.76592"
  },
  {
    "country": "US",
    "name": "Gaffney",
    "lat": "35.07179",
    "lng": "-81.64982"
  },
  {
    "country": "US",
    "name": "Gantt",
    "lat": "34.80012",
    "lng": "-82.42429"
  },
  {
    "country": "US",
    "name": "Garden City",
    "lat": "33.59295",
    "lng": "-79.00865"
  },
  {
    "country": "US",
    "name": "Gaston",
    "lat": "33.8171",
    "lng": "-81.10093"
  },
  {
    "country": "US",
    "name": "Georgetown",
    "lat": "33.37683",
    "lng": "-79.2945"
  },
  {
    "country": "US",
    "name": "Gloverville",
    "lat": "33.52597",
    "lng": "-81.83011"
  },
  {
    "country": "US",
    "name": "Golden Grove",
    "lat": "34.73401",
    "lng": "-82.44374"
  },
  {
    "country": "US",
    "name": "Goose Creek",
    "lat": "32.98101",
    "lng": "-80.03259"
  },
  {
    "country": "US",
    "name": "Graniteville",
    "lat": "33.56375",
    "lng": "-81.80789"
  },
  {
    "country": "US",
    "name": "Great Falls",
    "lat": "34.57514",
    "lng": "-80.90202"
  },
  {
    "country": "US",
    "name": "Greenville",
    "lat": "34.85262",
    "lng": "-82.39401"
  },
  {
    "country": "US",
    "name": "Greenwood",
    "lat": "34.1954",
    "lng": "-82.16179"
  },
  {
    "country": "US",
    "name": "Greer",
    "lat": "34.93873",
    "lng": "-82.22706"
  },
  {
    "country": "US",
    "name": "Hampton",
    "lat": "32.87794",
    "lng": "-81.12761"
  },
  {
    "country": "US",
    "name": "Hanahan",
    "lat": "32.91851",
    "lng": "-80.02203"
  },
  {
    "country": "US",
    "name": "Hardeeville",
    "lat": "32.28714",
    "lng": "-81.08067"
  },
  {
    "country": "US",
    "name": "Hartsville",
    "lat": "34.37404",
    "lng": "-80.0734"
  },
  {
    "country": "US",
    "name": "Hilton Head Island",
    "lat": "32.19382",
    "lng": "-80.73816"
  },
  {
    "country": "US",
    "name": "Hilton Head",
    "lat": "32.21632",
    "lng": "-80.75261"
  },
  {
    "country": "US",
    "name": "Holly Hill",
    "lat": "33.32266",
    "lng": "-80.4137"
  },
  {
    "country": "US",
    "name": "Hollywood",
    "lat": "32.73434",
    "lng": "-80.24177"
  },
  {
    "country": "US",
    "name": "Honea Path",
    "lat": "34.4465",
    "lng": "-82.39151"
  },
  {
    "country": "US",
    "name": "Homeland Park",
    "lat": "34.47066",
    "lng": "-82.67069"
  },
  {
    "country": "US",
    "name": "Hopkins",
    "lat": "33.90432",
    "lng": "-80.87703"
  },
  {
    "country": "US",
    "name": "India Hook",
    "lat": "35.00737",
    "lng": "-81.02174"
  },
  {
    "country": "US",
    "name": "Inman",
    "lat": "35.04706",
    "lng": "-82.09011"
  },
  {
    "country": "US",
    "name": "Inman Mills",
    "lat": "35.04151",
    "lng": "-82.10428"
  },
  {
    "country": "US",
    "name": "Irmo",
    "lat": "34.08598",
    "lng": "-81.18315"
  },
  {
    "country": "US",
    "name": "Irwin",
    "lat": "34.69376",
    "lng": "-80.82229"
  },
  {
    "country": "US",
    "name": "Isle of Palms",
    "lat": "32.78684",
    "lng": "-79.7948"
  },
  {
    "country": "US",
    "name": "Iva",
    "lat": "34.3065",
    "lng": "-82.66374"
  },
  {
    "country": "US",
    "name": "Jackson",
    "lat": "33.32542",
    "lng": "-81.78789"
  },
  {
    "country": "US",
    "name": "Joanna",
    "lat": "34.41491",
    "lng": "-81.8124"
  },
  {
    "country": "US",
    "name": "Johnsonville",
    "lat": "33.81794",
    "lng": "-79.44922"
  },
  {
    "country": "US",
    "name": "Johnston",
    "lat": "33.83208",
    "lng": "-81.80094"
  },
  {
    "country": "US",
    "name": "Judson",
    "lat": "34.83317",
    "lng": "-82.42762"
  },
  {
    "country": "US",
    "name": "Kershaw",
    "lat": "34.55182",
    "lng": "-80.58368"
  },
  {
    "country": "US",
    "name": "Kiawah Island",
    "lat": "32.60824",
    "lng": "-80.08482"
  },
  {
    "country": "US",
    "name": "Kingstree",
    "lat": "33.66766",
    "lng": "-79.83063"
  },
  {
    "country": "US",
    "name": "Ladson",
    "lat": "32.98573",
    "lng": "-80.10981"
  },
  {
    "country": "US",
    "name": "Lake City",
    "lat": "33.871",
    "lng": "-79.75535"
  },
  {
    "country": "US",
    "name": "Lake Secession",
    "lat": "34.28455",
    "lng": "-82.59457"
  },
  {
    "country": "US",
    "name": "Lake Wylie",
    "lat": "35.10848",
    "lng": "-81.04285"
  },
  {
    "country": "US",
    "name": "Lakewood",
    "lat": "33.84683",
    "lng": "-80.35008"
  },
  {
    "country": "US",
    "name": "Lancaster",
    "lat": "34.72043",
    "lng": "-80.7709"
  },
  {
    "country": "US",
    "name": "Lancaster Mill",
    "lat": "34.70931",
    "lng": "-80.79479"
  },
  {
    "country": "US",
    "name": "Landrum",
    "lat": "35.17511",
    "lng": "-82.18928"
  },
  {
    "country": "US",
    "name": "Langley",
    "lat": "33.51791",
    "lng": "-81.844"
  },
  {
    "country": "US",
    "name": "Latta",
    "lat": "34.3371",
    "lng": "-79.43116"
  },
  {
    "country": "US",
    "name": "Laurel Bay",
    "lat": "32.45019",
    "lng": "-80.78483"
  },
  {
    "country": "US",
    "name": "Laurens",
    "lat": "34.49901",
    "lng": "-82.01426"
  },
  {
    "country": "US",
    "name": "Leesville",
    "lat": "33.91653",
    "lng": "-81.51344"
  },
  {
    "country": "US",
    "name": "Lesslie",
    "lat": "34.8907",
    "lng": "-80.95647"
  },
  {
    "country": "US",
    "name": "Lexington",
    "lat": "33.98154",
    "lng": "-81.23621"
  },
  {
    "country": "US",
    "name": "Liberty",
    "lat": "34.78789",
    "lng": "-82.69236"
  },
  {
    "country": "US",
    "name": "Lincolnville",
    "lat": "33.00684",
    "lng": "-80.15537"
  },
  {
    "country": "US",
    "name": "Little River",
    "lat": "33.87323",
    "lng": "-78.61418"
  },
  {
    "country": "US",
    "name": "Loris",
    "lat": "34.05628",
    "lng": "-78.8903"
  },
  {
    "country": "US",
    "name": "Lyman",
    "lat": "34.94817",
    "lng": "-82.12733"
  },
  {
    "country": "US",
    "name": "Manning",
    "lat": "33.69516",
    "lng": "-80.21091"
  },
  {
    "country": "US",
    "name": "Marion",
    "lat": "34.17822",
    "lng": "-79.40061"
  },
  {
    "country": "US",
    "name": "Mauldin",
    "lat": "34.77873",
    "lng": "-82.31012"
  },
  {
    "country": "US",
    "name": "Mayo",
    "lat": "35.08401",
    "lng": "-81.85983"
  },
  {
    "country": "US",
    "name": "McColl",
    "lat": "34.66877",
    "lng": "-79.54533"
  },
  {
    "country": "US",
    "name": "McCormick",
    "lat": "33.91346",
    "lng": "-82.29346"
  },
  {
    "country": "US",
    "name": "Meggett",
    "lat": "32.71796",
    "lng": "-80.23899"
  },
  {
    "country": "US",
    "name": "Moncks Corner",
    "lat": "33.19632",
    "lng": "-80.01429"
  },
  {
    "country": "US",
    "name": "Mount Pleasant",
    "lat": "32.79407",
    "lng": "-79.86259"
  },
  {
    "country": "US",
    "name": "Mullins",
    "lat": "34.20572",
    "lng": "-79.25449"
  },
  {
    "country": "US",
    "name": "Murphys Estates",
    "lat": "33.60125",
    "lng": "-81.94428"
  },
  {
    "country": "US",
    "name": "Murrells Inlet",
    "lat": "33.551",
    "lng": "-79.04143"
  },
  {
    "country": "US",
    "name": "Myrtle Beach",
    "lat": "33.68906",
    "lng": "-78.88669"
  },
  {
    "country": "US",
    "name": "New Ellenton",
    "lat": "33.42153",
    "lng": "-81.68567"
  },
  {
    "country": "US",
    "name": "Newberry",
    "lat": "34.27458",
    "lng": "-81.61872"
  },
  {
    "country": "US",
    "name": "Newport",
    "lat": "34.98986",
    "lng": "-81.10091"
  },
  {
    "country": "US",
    "name": "Ninety Six",
    "lat": "34.17513",
    "lng": "-82.02401"
  },
  {
    "country": "US",
    "name": "North Augusta",
    "lat": "33.5018",
    "lng": "-81.96512"
  },
  {
    "country": "US",
    "name": "North Charleston",
    "lat": "32.85462",
    "lng": "-79.97481"
  },
  {
    "country": "US",
    "name": "North Hartsville",
    "lat": "34.39377",
    "lng": "-80.06951"
  },
  {
    "country": "US",
    "name": "North Myrtle Beach",
    "lat": "33.81601",
    "lng": "-78.68002"
  },
  {
    "country": "US",
    "name": "Northlake",
    "lat": "34.56622",
    "lng": "-82.68402"
  },
  {
    "country": "US",
    "name": "Oak Grove",
    "lat": "33.77821",
    "lng": "-80.96676"
  },
  {
    "country": "US",
    "name": "Oakland",
    "lat": "33.98293",
    "lng": "-80.48842"
  },
  {
    "country": "US",
    "name": "Orangeburg",
    "lat": "33.49182",
    "lng": "-80.85565"
  },
  {
    "country": "US",
    "name": "Pacolet",
    "lat": "34.89902",
    "lng": "-81.76177"
  },
  {
    "country": "US",
    "name": "Pageland",
    "lat": "34.77321",
    "lng": "-80.39173"
  },
  {
    "country": "US",
    "name": "Pamplico",
    "lat": "33.996",
    "lng": "-79.57006"
  },
  {
    "country": "US",
    "name": "Parker",
    "lat": "34.85067",
    "lng": "-82.45346"
  },
  {
    "country": "US",
    "name": "Pendleton",
    "lat": "34.65177",
    "lng": "-82.78375"
  },
  {
    "country": "US",
    "name": "Pickens",
    "lat": "34.88345",
    "lng": "-82.70736"
  },
  {
    "country": "US",
    "name": "Piedmont",
    "lat": "34.70234",
    "lng": "-82.46457"
  },
  {
    "country": "US",
    "name": "Pineridge",
    "lat": "33.91043",
    "lng": "-81.10454"
  },
  {
    "country": "US",
    "name": "Port Royal",
    "lat": "32.37908",
    "lng": "-80.69261"
  },
  {
    "country": "US",
    "name": "Powdersville",
    "lat": "34.79178",
    "lng": "-82.49291"
  },
  {
    "country": "US",
    "name": "Privateer",
    "lat": "33.83321",
    "lng": "-80.41425"
  },
  {
    "country": "US",
    "name": "Prosperity",
    "lat": "34.20931",
    "lng": "-81.53316"
  },
  {
    "country": "US",
    "name": "Ravenel",
    "lat": "32.76323",
    "lng": "-80.2501"
  },
  {
    "country": "US",
    "name": "Red Bank",
    "lat": "33.93209",
    "lng": "-81.23843"
  },
  {
    "country": "US",
    "name": "Red Hill",
    "lat": "33.99961",
    "lng": "-79.2581"
  },
  {
    "country": "US",
    "name": "Red Hill",
    "lat": "33.82073",
    "lng": "-79.01892"
  },
  {
    "country": "US",
    "name": "Ridgeland",
    "lat": "32.48074",
    "lng": "-80.98039"
  },
  {
    "country": "US",
    "name": "Ridgeville",
    "lat": "33.09572",
    "lng": "-80.31537"
  },
  {
    "country": "US",
    "name": "Rock Hill",
    "lat": "34.92487",
    "lng": "-81.02508"
  },
  {
    "country": "US",
    "name": "Roebuck",
    "lat": "34.87957",
    "lng": "-81.96621"
  },
  {
    "country": "US",
    "name": "Saint Andrews",
    "lat": "34.04543",
    "lng": "-81.12926"
  },
  {
    "country": "US",
    "name": "Saint George",
    "lat": "33.186",
    "lng": "-80.57565"
  },
  {
    "country": "US",
    "name": "Saint Matthews",
    "lat": "33.66488",
    "lng": "-80.77787"
  },
  {
    "country": "US",
    "name": "Saint Stephen",
    "lat": "33.40433",
    "lng": "-79.92174"
  },
  {
    "country": "US",
    "name": "Saluda",
    "lat": "34.00152",
    "lng": "-81.77205"
  },
  {
    "country": "US",
    "name": "Sangaree",
    "lat": "33.03545",
    "lng": "-80.12787"
  },
  {
    "country": "US",
    "name": "Sans Souci",
    "lat": "34.8779",
    "lng": "-82.42401"
  },
  {
    "country": "US",
    "name": "Saxon",
    "lat": "34.96123",
    "lng": "-81.96733"
  },
  {
    "country": "US",
    "name": "Seabrook Island",
    "lat": "32.57713",
    "lng": "-80.17065"
  },
  {
    "country": "US",
    "name": "Seneca",
    "lat": "34.68566",
    "lng": "-82.9532"
  },
  {
    "country": "US",
    "name": "Seven Oaks",
    "lat": "34.04876",
    "lng": "-81.14648"
  },
  {
    "country": "US",
    "name": "Shell Point",
    "lat": "32.38353",
    "lng": "-80.73594"
  },
  {
    "country": "US",
    "name": "Shell Point",
    "lat": "32.78907",
    "lng": "-80.10676"
  },
  {
    "country": "US",
    "name": "Simpsonville",
    "lat": "34.73706",
    "lng": "-82.25428"
  },
  {
    "country": "US",
    "name": "Socastee",
    "lat": "33.6835",
    "lng": "-78.99837"
  },
  {
    "country": "US",
    "name": "South Congaree",
    "lat": "33.91099",
    "lng": "-81.13565"
  },
  {
    "country": "US",
    "name": "South Sumter",
    "lat": "33.90571",
    "lng": "-80.34619"
  },
  {
    "country": "US",
    "name": "Southern Shops",
    "lat": "34.98595",
    "lng": "-81.99455"
  },
  {
    "country": "US",
    "name": "Spartanburg",
    "lat": "34.94957",
    "lng": "-81.93205"
  },
  {
    "country": "US",
    "name": "Springdale",
    "lat": "34.68931",
    "lng": "-80.78618"
  },
  {
    "country": "US",
    "name": "Springdale",
    "lat": "33.95932",
    "lng": "-81.10898"
  },
  {
    "country": "US",
    "name": "Stateburg",
    "lat": "33.95765",
    "lng": "-80.53481"
  },
  {
    "country": "US",
    "name": "Sullivans Island",
    "lat": "32.76323",
    "lng": "-79.83675"
  },
  {
    "country": "US",
    "name": "Summerville",
    "lat": "33.0185",
    "lng": "-80.17565"
  },
  {
    "country": "US",
    "name": "Sumter",
    "lat": "33.92044",
    "lng": "-80.34147"
  },
  {
    "country": "US",
    "name": "Surfside Beach",
    "lat": "33.606",
    "lng": "-78.97309"
  },
  {
    "country": "US",
    "name": "Taylors",
    "lat": "34.92039",
    "lng": "-82.29623"
  },
  {
    "country": "US",
    "name": "Tega Cay",
    "lat": "35.02431",
    "lng": "-81.02785"
  },
  {
    "country": "US",
    "name": "Tigerville",
    "lat": "35.06845",
    "lng": "-82.36845"
  },
  {
    "country": "US",
    "name": "Timmonsville",
    "lat": "34.13488",
    "lng": "-79.93979"
  },
  {
    "country": "US",
    "name": "Travelers Rest",
    "lat": "34.96762",
    "lng": "-82.44345"
  },
  {
    "country": "US",
    "name": "Union",
    "lat": "34.71541",
    "lng": "-81.62371"
  },
  {
    "country": "US",
    "name": "Utica",
    "lat": "34.67816",
    "lng": "-82.93154"
  },
  {
    "country": "US",
    "name": "Valley Falls",
    "lat": "35.01595",
    "lng": "-81.97483"
  },
  {
    "country": "US",
    "name": "Varnville",
    "lat": "32.85044",
    "lng": "-81.07927"
  },
  {
    "country": "US",
    "name": "Wade Hampton",
    "lat": "34.90373",
    "lng": "-82.33317"
  },
  {
    "country": "US",
    "name": "Walhalla",
    "lat": "34.76482",
    "lng": "-83.06404"
  },
  {
    "country": "US",
    "name": "Walterboro",
    "lat": "32.90517",
    "lng": "-80.66677"
  },
  {
    "country": "US",
    "name": "Ware Shoals",
    "lat": "34.39845",
    "lng": "-82.24679"
  },
  {
    "country": "US",
    "name": "Warrenville",
    "lat": "33.55097",
    "lng": "-81.804"
  },
  {
    "country": "US",
    "name": "Wedgefield",
    "lat": "33.89266",
    "lng": "-80.51814"
  },
  {
    "country": "US",
    "name": "Wedgewood",
    "lat": "33.88377",
    "lng": "-80.51258"
  },
  {
    "country": "US",
    "name": "Welcome",
    "lat": "34.82651",
    "lng": "-82.43901"
  },
  {
    "country": "US",
    "name": "Wellford",
    "lat": "34.95095",
    "lng": "-82.10594"
  },
  {
    "country": "US",
    "name": "West Columbia",
    "lat": "33.99349",
    "lng": "-81.07398"
  },
  {
    "country": "US",
    "name": "Westminster",
    "lat": "34.66482",
    "lng": "-83.09654"
  },
  {
    "country": "US",
    "name": "Whitmire",
    "lat": "34.50291",
    "lng": "-81.61149"
  },
  {
    "country": "US",
    "name": "Wilkinson Heights",
    "lat": "33.5021",
    "lng": "-80.83315"
  },
  {
    "country": "US",
    "name": "Williamston",
    "lat": "34.61845",
    "lng": "-82.47791"
  },
  {
    "country": "US",
    "name": "Williston",
    "lat": "33.40265",
    "lng": "-81.42011"
  },
  {
    "country": "US",
    "name": "Winnsboro",
    "lat": "34.3807",
    "lng": "-81.08648"
  },
  {
    "country": "US",
    "name": "Winnsboro Mills",
    "lat": "34.36181",
    "lng": "-81.08537"
  },
  {
    "country": "US",
    "name": "Woodfield",
    "lat": "34.05932",
    "lng": "-80.93092"
  },
  {
    "country": "US",
    "name": "Woodruff",
    "lat": "34.73957",
    "lng": "-82.03705"
  },
  {
    "country": "US",
    "name": "York",
    "lat": "34.9943",
    "lng": "-81.24202"
  },
  {
    "country": "US",
    "name": "Adamsville",
    "lat": "35.23591",
    "lng": "-88.3906"
  },
  {
    "country": "US",
    "name": "Alamo",
    "lat": "35.78479",
    "lng": "-89.11729"
  },
  {
    "country": "US",
    "name": "Alcoa",
    "lat": "35.78953",
    "lng": "-83.97379"
  },
  {
    "country": "US",
    "name": "Algood",
    "lat": "36.19589",
    "lng": "-85.44858"
  },
  {
    "country": "US",
    "name": "Altamont",
    "lat": "35.42952",
    "lng": "-85.72303"
  },
  {
    "country": "US",
    "name": "Apison",
    "lat": "35.02396",
    "lng": "-85.02384"
  },
  {
    "country": "US",
    "name": "Ardmore",
    "lat": "34.99203",
    "lng": "-86.84667"
  },
  {
    "country": "US",
    "name": "Arlington",
    "lat": "35.2962",
    "lng": "-89.66147"
  },
  {
    "country": "US",
    "name": "Ashland City",
    "lat": "36.27422",
    "lng": "-87.06417"
  },
  {
    "country": "US",
    "name": "Athens",
    "lat": "35.44285",
    "lng": "-84.59299"
  },
  {
    "country": "US",
    "name": "Atoka",
    "lat": "35.44119",
    "lng": "-89.77814"
  },
  {
    "country": "US",
    "name": "Banner Hill",
    "lat": "36.13066",
    "lng": "-82.42458"
  },
  {
    "country": "US",
    "name": "Bartlett",
    "lat": "35.20453",
    "lng": "-89.87398"
  },
  {
    "country": "US",
    "name": "Baxter",
    "lat": "36.15367",
    "lng": "-85.64359"
  },
  {
    "country": "US",
    "name": "Bean Station",
    "lat": "36.3437",
    "lng": "-83.28406"
  },
  {
    "country": "US",
    "name": "Belle Meade",
    "lat": "36.09589",
    "lng": "-86.85694"
  },
  {
    "country": "US",
    "name": "Bells",
    "lat": "35.71118",
    "lng": "-89.08756"
  },
  {
    "country": "US",
    "name": "Benton",
    "lat": "35.17424",
    "lng": "-84.65355"
  },
  {
    "country": "US",
    "name": "Blaine",
    "lat": "36.15425",
    "lng": "-83.70407"
  },
  {
    "country": "US",
    "name": "Bloomingdale",
    "lat": "36.58455",
    "lng": "-82.48932"
  },
  {
    "country": "US",
    "name": "Blountville",
    "lat": "36.53316",
    "lng": "-82.32681"
  },
  {
    "country": "US",
    "name": "Bluff City",
    "lat": "36.47427",
    "lng": "-82.26097"
  },
  {
    "country": "US",
    "name": "Bolivar",
    "lat": "35.25619",
    "lng": "-88.98784"
  },
  {
    "country": "US",
    "name": "Bon Aqua Junction",
    "lat": "35.92784",
    "lng": "-87.31084"
  },
  {
    "country": "US",
    "name": "Bradford",
    "lat": "36.07645",
    "lng": "-88.81006"
  },
  {
    "country": "US",
    "name": "Brentwood",
    "lat": "36.03312",
    "lng": "-86.78278"
  },
  {
    "country": "US",
    "name": "Brentwood Estates",
    "lat": "36.02506",
    "lng": "-86.77917"
  },
  {
    "country": "US",
    "name": "Brighton",
    "lat": "35.08009",
    "lng": "-86.43916"
  },
  {
    "country": "US",
    "name": "Brighton",
    "lat": "35.48397",
    "lng": "-89.72508"
  },
  {
    "country": "US",
    "name": "Bristol",
    "lat": "36.59511",
    "lng": "-82.18874"
  },
  {
    "country": "US",
    "name": "Brownsville",
    "lat": "35.59397",
    "lng": "-89.26229"
  },
  {
    "country": "US",
    "name": "Bruceton",
    "lat": "36.03812",
    "lng": "-88.24449"
  },
  {
    "country": "US",
    "name": "Burns",
    "lat": "36.05339",
    "lng": "-87.31251"
  },
  {
    "country": "US",
    "name": "Byrdstown",
    "lat": "36.57451",
    "lng": "-85.12884"
  },
  {
    "country": "US",
    "name": "Camden",
    "lat": "36.05895",
    "lng": "-88.09782"
  },
  {
    "country": "US",
    "name": "Carthage",
    "lat": "36.25228",
    "lng": "-85.95165"
  },
  {
    "country": "US",
    "name": "Caryville",
    "lat": "36.29897",
    "lng": "-84.22326"
  },
  {
    "country": "US",
    "name": "Celina",
    "lat": "36.55006",
    "lng": "-85.50525"
  },
  {
    "country": "US",
    "name": "Centerville",
    "lat": "35.77896",
    "lng": "-87.46696"
  },
  {
    "country": "US",
    "name": "Central",
    "lat": "36.32622",
    "lng": "-82.28958"
  },
  {
    "country": "US",
    "name": "Central",
    "lat": "35.80369",
    "lng": "-89.5373"
  },
  {
    "country": "US",
    "name": "Chapel Hill",
    "lat": "35.62646",
    "lng": "-86.69333"
  },
  {
    "country": "US",
    "name": "Charlotte",
    "lat": "36.17728",
    "lng": "-87.33973"
  },
  {
    "country": "US",
    "name": "Chattanooga",
    "lat": "35.04563",
    "lng": "-85.30968"
  },
  {
    "country": "US",
    "name": "Christiana",
    "lat": "35.71007",
    "lng": "-86.39944"
  },
  {
    "country": "US",
    "name": "Church Hill",
    "lat": "36.52232",
    "lng": "-82.71349"
  },
  {
    "country": "US",
    "name": "Clarksville",
    "lat": "36.52977",
    "lng": "-87.35945"
  },
  {
    "country": "US",
    "name": "Cleveland",
    "lat": "35.15952",
    "lng": "-84.87661"
  },
  {
    "country": "US",
    "name": "Clifton",
    "lat": "35.38702",
    "lng": "-87.99531"
  },
  {
    "country": "US",
    "name": "Clinton",
    "lat": "36.10341",
    "lng": "-84.13186"
  },
  {
    "country": "US",
    "name": "Coalfield",
    "lat": "36.02897",
    "lng": "-84.42076"
  },
  {
    "country": "US",
    "name": "Collegedale",
    "lat": "35.05313",
    "lng": "-85.05023"
  },
  {
    "country": "US",
    "name": "Collierville",
    "lat": "35.04204",
    "lng": "-89.66453"
  },
  {
    "country": "US",
    "name": "Colonial Heights",
    "lat": "36.4851",
    "lng": "-82.5032"
  },
  {
    "country": "US",
    "name": "Columbia",
    "lat": "35.61507",
    "lng": "-87.03528"
  },
  {
    "country": "US",
    "name": "Condon",
    "lat": "36.18119",
    "lng": "-83.7938"
  },
  {
    "country": "US",
    "name": "Cookeville",
    "lat": "36.16284",
    "lng": "-85.50164"
  },
  {
    "country": "US",
    "name": "Coopertown",
    "lat": "36.43755",
    "lng": "-86.96722"
  },
  {
    "country": "US",
    "name": "Cornersville",
    "lat": "35.36146",
    "lng": "-86.83972"
  },
  {
    "country": "US",
    "name": "Covington",
    "lat": "35.56425",
    "lng": "-89.64647"
  },
  {
    "country": "US",
    "name": "Cowan",
    "lat": "35.16453",
    "lng": "-86.01054"
  },
  {
    "country": "US",
    "name": "Cross Plains",
    "lat": "36.54866",
    "lng": "-86.69611"
  },
  {
    "country": "US",
    "name": "Crossville",
    "lat": "35.94896",
    "lng": "-85.0269"
  },
  {
    "country": "US",
    "name": "Crump",
    "lat": "35.22175",
    "lng": "-88.31809"
  },
  {
    "country": "US",
    "name": "Dandridge",
    "lat": "36.01537",
    "lng": "-83.41489"
  },
  {
    "country": "US",
    "name": "Dayton",
    "lat": "35.49396",
    "lng": "-85.01245"
  },
  {
    "country": "US",
    "name": "Decatur",
    "lat": "35.51479",
    "lng": "-84.79022"
  },
  {
    "country": "US",
    "name": "Decaturville",
    "lat": "35.58424",
    "lng": "-88.11948"
  },
  {
    "country": "US",
    "name": "Decherd",
    "lat": "35.2098",
    "lng": "-86.07943"
  },
  {
    "country": "US",
    "name": "Dickson",
    "lat": "36.077",
    "lng": "-87.38779"
  },
  {
    "country": "US",
    "name": "Dodson Branch",
    "lat": "36.31256",
    "lng": "-85.5322"
  },
  {
    "country": "US",
    "name": "Dover",
    "lat": "36.48783",
    "lng": "-87.83836"
  },
  {
    "country": "US",
    "name": "Dresden",
    "lat": "36.29145",
    "lng": "-88.70811"
  },
  {
    "country": "US",
    "name": "Dunlap",
    "lat": "35.37146",
    "lng": "-85.39052"
  },
  {
    "country": "US",
    "name": "Dyer",
    "lat": "36.06673",
    "lng": "-88.99395"
  },
  {
    "country": "US",
    "name": "Dyersburg",
    "lat": "36.03452",
    "lng": "-89.38563"
  },
  {
    "country": "US",
    "name": "Eagleton Village",
    "lat": "35.79508",
    "lng": "-83.93185"
  },
  {
    "country": "US",
    "name": "East Brainerd",
    "lat": "34.99591",
    "lng": "-85.15023"
  },
  {
    "country": "US",
    "name": "East Chattanooga",
    "lat": "35.06535",
    "lng": "-85.24912"
  },
  {
    "country": "US",
    "name": "East Cleveland",
    "lat": "35.16091",
    "lng": "-84.85772"
  },
  {
    "country": "US",
    "name": "East Ridge",
    "lat": "35.01424",
    "lng": "-85.2519"
  },
  {
    "country": "US",
    "name": "Elizabethton",
    "lat": "36.34872",
    "lng": "-82.21069"
  },
  {
    "country": "US",
    "name": "Englewood",
    "lat": "35.42452",
    "lng": "-84.48743"
  },
  {
    "country": "US",
    "name": "Englewood",
    "lat": "36.36673",
    "lng": "-89.15479"
  },
  {
    "country": "US",
    "name": "Erin",
    "lat": "36.31839",
    "lng": "-87.69474"
  },
  {
    "country": "US",
    "name": "Erwin",
    "lat": "36.14511",
    "lng": "-82.41681"
  },
  {
    "country": "US",
    "name": "Estill Springs",
    "lat": "35.27064",
    "lng": "-86.12804"
  },
  {
    "country": "US",
    "name": "Etowah",
    "lat": "35.32341",
    "lng": "-84.52493"
  },
  {
    "country": "US",
    "name": "Fairfield Glade",
    "lat": "36.00035",
    "lng": "-84.88634"
  },
  {
    "country": "US",
    "name": "Fairmount",
    "lat": "35.18146",
    "lng": "-85.32357"
  },
  {
    "country": "US",
    "name": "Fairmount",
    "lat": "36.58511",
    "lng": "-82.17097"
  },
  {
    "country": "US",
    "name": "Fairview",
    "lat": "35.98201",
    "lng": "-87.1214"
  },
  {
    "country": "US",
    "name": "Fall Branch",
    "lat": "36.41816",
    "lng": "-82.62376"
  },
  {
    "country": "US",
    "name": "Falling Water",
    "lat": "35.20312",
    "lng": "-85.25357"
  },
  {
    "country": "US",
    "name": "Farragut",
    "lat": "35.88452",
    "lng": "-84.15353"
  },
  {
    "country": "US",
    "name": "Fayetteville",
    "lat": "35.15203",
    "lng": "-86.57055"
  },
  {
    "country": "US",
    "name": "Fincastle",
    "lat": "36.4098",
    "lng": "-84.0477"
  },
  {
    "country": "US",
    "name": "Forest Hills",
    "lat": "36.06839",
    "lng": "-86.84417"
  },
  {
    "country": "US",
    "name": "Franklin",
    "lat": "35.92506",
    "lng": "-86.86889"
  },
  {
    "country": "US",
    "name": "Gainesboro",
    "lat": "36.35561",
    "lng": "-85.65887"
  },
  {
    "country": "US",
    "name": "Gallatin",
    "lat": "36.38838",
    "lng": "-86.44666"
  },
  {
    "country": "US",
    "name": "Gatlinburg",
    "lat": "35.71453",
    "lng": "-83.51189"
  },
  {
    "country": "US",
    "name": "Germantown",
    "lat": "35.08676",
    "lng": "-89.81009"
  },
  {
    "country": "US",
    "name": "Gleason",
    "lat": "36.21367",
    "lng": "-88.61255"
  },
  {
    "country": "US",
    "name": "Goodlettsville",
    "lat": "36.32311",
    "lng": "-86.71333"
  },
  {
    "country": "US",
    "name": "Gordonsville",
    "lat": "36.17256",
    "lng": "-85.92971"
  },
  {
    "country": "US",
    "name": "Gray",
    "lat": "36.41983",
    "lng": "-82.47654"
  },
  {
    "country": "US",
    "name": "Graysville",
    "lat": "35.44701",
    "lng": "-85.0844"
  },
  {
    "country": "US",
    "name": "Green Hill",
    "lat": "36.22283",
    "lng": "-86.54944"
  },
  {
    "country": "US",
    "name": "Greenback",
    "lat": "35.66119",
    "lng": "-84.17214"
  },
  {
    "country": "US",
    "name": "Greenbrier",
    "lat": "36.42755",
    "lng": "-86.80472"
  },
  {
    "country": "US",
    "name": "Greeneville",
    "lat": "36.16316",
    "lng": "-82.83099"
  },
  {
    "country": "US",
    "name": "Greenfield",
    "lat": "36.1534",
    "lng": "-88.80062"
  },
  {
    "country": "US",
    "name": "Grimsley",
    "lat": "36.26701",
    "lng": "-84.9844"
  },
  {
    "country": "US",
    "name": "Gruetli-Laager",
    "lat": "35.3723",
    "lng": "-85.61803"
  },
  {
    "country": "US",
    "name": "Halls",
    "lat": "35.87563",
    "lng": "-89.39618"
  },
  {
    "country": "US",
    "name": "Harriman",
    "lat": "35.93396",
    "lng": "-84.55244"
  },
  {
    "country": "US",
    "name": "Harrison",
    "lat": "35.11368",
    "lng": "-85.13801"
  },
  {
    "country": "US",
    "name": "Harrogate",
    "lat": "36.5823",
    "lng": "-83.65686"
  },
  {
    "country": "US",
    "name": "Hartsville",
    "lat": "36.39088",
    "lng": "-86.16721"
  },
  {
    "country": "US",
    "name": "Henderson",
    "lat": "35.43924",
    "lng": "-88.64144"
  },
  {
    "country": "US",
    "name": "Hendersonville",
    "lat": "36.30477",
    "lng": "-86.62"
  },
  {
    "country": "US",
    "name": "Hickory Withe",
    "lat": "35.24398",
    "lng": "-89.58869"
  },
  {
    "country": "US",
    "name": "Hohenwald",
    "lat": "35.54785",
    "lng": "-87.55196"
  },
  {
    "country": "US",
    "name": "Hopewell",
    "lat": "35.23479",
    "lng": "-84.888"
  },
  {
    "country": "US",
    "name": "Humboldt",
    "lat": "35.81979",
    "lng": "-88.9159"
  },
  {
    "country": "US",
    "name": "Hunter",
    "lat": "36.3623",
    "lng": "-84.14048"
  },
  {
    "country": "US",
    "name": "Hunter",
    "lat": "36.37178",
    "lng": "-82.15874"
  },
  {
    "country": "US",
    "name": "Huntingdon",
    "lat": "36.00062",
    "lng": "-88.42811"
  },
  {
    "country": "US",
    "name": "Huntsville",
    "lat": "36.4098",
    "lng": "-84.49049"
  },
  {
    "country": "US",
    "name": "Jacksboro",
    "lat": "36.33008",
    "lng": "-84.18382"
  },
  {
    "country": "US",
    "name": "Jackson",
    "lat": "35.61452",
    "lng": "-88.81395"
  },
  {
    "country": "US",
    "name": "Jamestown",
    "lat": "36.42757",
    "lng": "-84.93189"
  },
  {
    "country": "US",
    "name": "Jasper",
    "lat": "35.07424",
    "lng": "-85.62608"
  },
  {
    "country": "US",
    "name": "Jefferson City",
    "lat": "36.12231",
    "lng": "-83.4924"
  },
  {
    "country": "US",
    "name": "Jellico",
    "lat": "36.58786",
    "lng": "-84.12687"
  },
  {
    "country": "US",
    "name": "Johnson City",
    "lat": "36.31344",
    "lng": "-82.35347"
  },
  {
    "country": "US",
    "name": "Johnsonville",
    "lat": "36.06006",
    "lng": "-87.95281"
  },
  {
    "country": "US",
    "name": "Jonesborough",
    "lat": "36.29427",
    "lng": "-82.47348"
  },
  {
    "country": "US",
    "name": "Kenton",
    "lat": "36.20229",
    "lng": "-89.01229"
  },
  {
    "country": "US",
    "name": "Kimball",
    "lat": "35.04786",
    "lng": "-85.67191"
  },
  {
    "country": "US",
    "name": "Kingsport",
    "lat": "36.54843",
    "lng": "-82.56182"
  },
  {
    "country": "US",
    "name": "Kingston",
    "lat": "35.88091",
    "lng": "-84.50854"
  },
  {
    "country": "US",
    "name": "Kingston Springs",
    "lat": "36.102",
    "lng": "-87.11501"
  },
  {
    "country": "US",
    "name": "Knoxville",
    "lat": "35.96064",
    "lng": "-83.92074"
  },
  {
    "country": "US",
    "name": "La Vergne",
    "lat": "36.01562",
    "lng": "-86.58194"
  },
  {
    "country": "US",
    "name": "LaFollette",
    "lat": "36.38286",
    "lng": "-84.11993"
  },
  {
    "country": "US",
    "name": "Lafayette",
    "lat": "36.52116",
    "lng": "-86.02637"
  },
  {
    "country": "US",
    "name": "Lafayette",
    "lat": "36.18589",
    "lng": "-85.71609"
  },
  {
    "country": "US",
    "name": "Rocky Top",
    "lat": "36.21786",
    "lng": "-84.15465"
  },
  {
    "country": "US",
    "name": "Lake Tansi",
    "lat": "35.87285",
    "lng": "-85.0544"
  },
  {
    "country": "US",
    "name": "Lakeland",
    "lat": "35.23064",
    "lng": "-89.74036"
  },
  {
    "country": "US",
    "name": "Lakesite",
    "lat": "35.20868",
    "lng": "-85.1269"
  },
  {
    "country": "US",
    "name": "Lakewood",
    "lat": "36.24311",
    "lng": "-86.63555"
  },
  {
    "country": "US",
    "name": "Lawrenceburg",
    "lat": "35.2423",
    "lng": "-87.33474"
  },
  {
    "country": "US",
    "name": "Lebanon",
    "lat": "36.20811",
    "lng": "-86.2911"
  },
  {
    "country": "US",
    "name": "Lenoir City",
    "lat": "35.7973",
    "lng": "-84.25603"
  },
  {
    "country": "US",
    "name": "Lewisburg",
    "lat": "35.44924",
    "lng": "-86.78889"
  },
  {
    "country": "US",
    "name": "Lexington",
    "lat": "35.6509",
    "lng": "-88.39338"
  },
  {
    "country": "US",
    "name": "Linden",
    "lat": "35.61729",
    "lng": "-87.83947"
  },
  {
    "country": "US",
    "name": "Livingston",
    "lat": "36.3834",
    "lng": "-85.32302"
  },
  {
    "country": "US",
    "name": "Lone Oak",
    "lat": "35.20063",
    "lng": "-85.36413"
  },
  {
    "country": "US",
    "name": "Lookout Mountain",
    "lat": "34.99424",
    "lng": "-85.3494"
  },
  {
    "country": "US",
    "name": "Loretto",
    "lat": "35.07786",
    "lng": "-87.43974"
  },
  {
    "country": "US",
    "name": "Loudon",
    "lat": "35.73285",
    "lng": "-84.33381"
  },
  {
    "country": "US",
    "name": "Louisville",
    "lat": "35.82175",
    "lng": "-84.04796"
  },
  {
    "country": "US",
    "name": "Luttrell",
    "lat": "36.19953",
    "lng": "-83.74185"
  },
  {
    "country": "US",
    "name": "Lynchburg",
    "lat": "35.28314",
    "lng": "-86.37416"
  },
  {
    "country": "US",
    "name": "Madisonville",
    "lat": "35.5198",
    "lng": "-84.36353"
  },
  {
    "country": "US",
    "name": "Manchester",
    "lat": "35.48174",
    "lng": "-86.0886"
  },
  {
    "country": "US",
    "name": "Martin",
    "lat": "36.3434",
    "lng": "-88.85034"
  },
  {
    "country": "US",
    "name": "Maryville",
    "lat": "35.75647",
    "lng": "-83.97046"
  },
  {
    "country": "US",
    "name": "Mascot",
    "lat": "36.0612",
    "lng": "-83.74573"
  },
  {
    "country": "US",
    "name": "Mason",
    "lat": "35.41175",
    "lng": "-89.53285"
  },
  {
    "country": "US",
    "name": "Maynardville",
    "lat": "36.25064",
    "lng": "-83.79741"
  },
  {
    "country": "US",
    "name": "McEwen",
    "lat": "36.10784",
    "lng": "-87.63307"
  },
  {
    "country": "US",
    "name": "McKenzie",
    "lat": "36.13256",
    "lng": "-88.51866"
  },
  {
    "country": "US",
    "name": "McMinnville",
    "lat": "35.6834",
    "lng": "-85.76998"
  },
  {
    "country": "US",
    "name": "Medina",
    "lat": "35.80285",
    "lng": "-88.77478"
  },
  {
    "country": "US",
    "name": "Memphis",
    "lat": "35.14953",
    "lng": "-90.04898"
  },
  {
    "country": "US",
    "name": "Middle Valley",
    "lat": "35.1959",
    "lng": "-85.18468"
  },
  {
    "country": "US",
    "name": "Midway",
    "lat": "36.30011",
    "lng": "-82.42375"
  },
  {
    "country": "US",
    "name": "Midtown",
    "lat": "35.87952",
    "lng": "-84.5641"
  },
  {
    "country": "US",
    "name": "Milan",
    "lat": "35.91979",
    "lng": "-88.75895"
  },
  {
    "country": "US",
    "name": "Millersville",
    "lat": "36.37116",
    "lng": "-86.71"
  },
  {
    "country": "US",
    "name": "Millington",
    "lat": "35.34147",
    "lng": "-89.89731"
  },
  {
    "country": "US",
    "name": "Monteagle",
    "lat": "35.24008",
    "lng": "-85.8397"
  },
  {
    "country": "US",
    "name": "Monterey",
    "lat": "36.14756",
    "lng": "-85.2683"
  },
  {
    "country": "US",
    "name": "Morristown",
    "lat": "36.21398",
    "lng": "-83.29489"
  },
  {
    "country": "US",
    "name": "Mosheim",
    "lat": "36.18954",
    "lng": "-82.95849"
  },
  {
    "country": "US",
    "name": "Mount Carmel",
    "lat": "35.49785",
    "lng": "-88.00781"
  },
  {
    "country": "US",
    "name": "Mount Carmel",
    "lat": "36.54538",
    "lng": "-82.66099"
  },
  {
    "country": "US",
    "name": "Mount Juliet",
    "lat": "36.20005",
    "lng": "-86.51861"
  },
  {
    "country": "US",
    "name": "Mount Pleasant",
    "lat": "35.53424",
    "lng": "-87.20695"
  },
  {
    "country": "US",
    "name": "Mountain City",
    "lat": "36.47456",
    "lng": "-81.80484"
  },
  {
    "country": "US",
    "name": "Munford",
    "lat": "35.44925",
    "lng": "-89.81508"
  },
  {
    "country": "US",
    "name": "Murfreesboro",
    "lat": "35.84562",
    "lng": "-86.39027"
  },
  {
    "country": "US",
    "name": "Nashville",
    "lat": "36.16589",
    "lng": "-86.78444"
  },
  {
    "country": "US",
    "name": "New Hope",
    "lat": "35.00508",
    "lng": "-85.6583"
  },
  {
    "country": "US",
    "name": "New Johnsonville",
    "lat": "36.02117",
    "lng": "-87.96698"
  },
  {
    "country": "US",
    "name": "New Market",
    "lat": "36.10398",
    "lng": "-83.55268"
  },
  {
    "country": "US",
    "name": "New South Memphis",
    "lat": "35.08676",
    "lng": "-90.05676"
  },
  {
    "country": "US",
    "name": "New Tazewell",
    "lat": "36.44258",
    "lng": "-83.59963"
  },
  {
    "country": "US",
    "name": "New Union",
    "lat": "35.53258",
    "lng": "-86.08082"
  },
  {
    "country": "US",
    "name": "Newbern",
    "lat": "36.11285",
    "lng": "-89.26174"
  },
  {
    "country": "US",
    "name": "Newport",
    "lat": "35.96704",
    "lng": "-83.18766"
  },
  {
    "country": "US",
    "name": "Nolensville",
    "lat": "35.95229",
    "lng": "-86.66944"
  },
  {
    "country": "US",
    "name": "Norris",
    "lat": "36.19563",
    "lng": "-84.06797"
  },
  {
    "country": "US",
    "name": "Oak Grove",
    "lat": "36.41177",
    "lng": "-82.42459"
  },
  {
    "country": "US",
    "name": "Oak Hill",
    "lat": "36.08784",
    "lng": "-86.78305"
  },
  {
    "country": "US",
    "name": "Oak Ridge",
    "lat": "36.01036",
    "lng": "-84.26964"
  },
  {
    "country": "US",
    "name": "Oakland",
    "lat": "35.22898",
    "lng": "-89.51508"
  },
  {
    "country": "US",
    "name": "Obion",
    "lat": "36.25896",
    "lng": "-89.19174"
  },
  {
    "country": "US",
    "name": "Olivet",
    "lat": "35.21425",
    "lng": "-88.20031"
  },
  {
    "country": "US",
    "name": "Oliver Springs",
    "lat": "36.04452",
    "lng": "-84.34437"
  },
  {
    "country": "US",
    "name": "Oneida",
    "lat": "36.49813",
    "lng": "-84.51272"
  },
  {
    "country": "US",
    "name": "Paris",
    "lat": "36.302",
    "lng": "-88.32671"
  },
  {
    "country": "US",
    "name": "Park City",
    "lat": "35.08203",
    "lng": "-86.57111"
  },
  {
    "country": "US",
    "name": "Parsons",
    "lat": "35.64979",
    "lng": "-88.1267"
  },
  {
    "country": "US",
    "name": "Pegram",
    "lat": "36.10061",
    "lng": "-87.05112"
  },
  {
    "country": "US",
    "name": "Pigeon Forge",
    "lat": "35.78842",
    "lng": "-83.55433"
  },
  {
    "country": "US",
    "name": "Pikeville",
    "lat": "35.60562",
    "lng": "-85.18885"
  },
  {
    "country": "US",
    "name": "Pine Crest",
    "lat": "36.27619",
    "lng": "-84.12881"
  },
  {
    "country": "US",
    "name": "Pine Crest",
    "lat": "36.29927",
    "lng": "-82.31792"
  },
  {
    "country": "US",
    "name": "Piperton",
    "lat": "35.04509",
    "lng": "-89.62175"
  },
  {
    "country": "US",
    "name": "Pleasant View",
    "lat": "36.39422",
    "lng": "-87.03667"
  },
  {
    "country": "US",
    "name": "Portland",
    "lat": "36.58171",
    "lng": "-86.51638"
  },
  {
    "country": "US",
    "name": "Powells Crossroads",
    "lat": "35.18952",
    "lng": "-85.4858"
  },
  {
    "country": "US",
    "name": "Pulaski",
    "lat": "35.1998",
    "lng": "-87.03084"
  },
  {
    "country": "US",
    "name": "Red Bank",
    "lat": "35.11229",
    "lng": "-85.29413"
  },
  {
    "country": "US",
    "name": "Red Boiling Springs",
    "lat": "36.53339",
    "lng": "-85.84998"
  },
  {
    "country": "US",
    "name": "Ridgely",
    "lat": "36.2634",
    "lng": "-89.48785"
  },
  {
    "country": "US",
    "name": "Ridgetop",
    "lat": "36.39505",
    "lng": "-86.77944"
  },
  {
    "country": "US",
    "name": "Ripley",
    "lat": "35.74536",
    "lng": "-89.5298"
  },
  {
    "country": "US",
    "name": "Roan Mountain",
    "lat": "36.19623",
    "lng": "-82.0704"
  },
  {
    "country": "US",
    "name": "Rockwood",
    "lat": "35.86563",
    "lng": "-84.68494"
  },
  {
    "country": "US",
    "name": "Rogersville",
    "lat": "36.40732",
    "lng": "-83.00544"
  },
  {
    "country": "US",
    "name": "Rural Hill",
    "lat": "36.11673",
    "lng": "-86.47916"
  },
  {
    "country": "US",
    "name": "Rutherford",
    "lat": "36.12757",
    "lng": "-88.9859"
  },
  {
    "country": "US",
    "name": "Rutledge",
    "lat": "36.28092",
    "lng": "-83.5149"
  },
  {
    "country": "US",
    "name": "Sale Creek",
    "lat": "35.38229",
    "lng": "-85.10884"
  },
  {
    "country": "US",
    "name": "Savannah",
    "lat": "35.2248",
    "lng": "-88.2492"
  },
  {
    "country": "US",
    "name": "Selmer",
    "lat": "35.17008",
    "lng": "-88.59227"
  },
  {
    "country": "US",
    "name": "Sevierville",
    "lat": "35.86815",
    "lng": "-83.56184"
  },
  {
    "country": "US",
    "name": "Sewanee",
    "lat": "35.20314",
    "lng": "-85.92109"
  },
  {
    "country": "US",
    "name": "Seymour",
    "lat": "35.89064",
    "lng": "-83.72462"
  },
  {
    "country": "US",
    "name": "Shackle Island",
    "lat": "36.3706",
    "lng": "-86.61666"
  },
  {
    "country": "US",
    "name": "Shelbyville",
    "lat": "35.48341",
    "lng": "-86.46027"
  },
  {
    "country": "US",
    "name": "Signal Mountain",
    "lat": "35.12257",
    "lng": "-85.34385"
  },
  {
    "country": "US",
    "name": "Smithville",
    "lat": "35.96062",
    "lng": "-85.81415"
  },
  {
    "country": "US",
    "name": "Smyrna",
    "lat": "35.98284",
    "lng": "-86.5186"
  },
  {
    "country": "US",
    "name": "Sneedville",
    "lat": "36.52981",
    "lng": "-83.2174"
  },
  {
    "country": "US",
    "name": "Soddy-Daisy",
    "lat": "35.2359",
    "lng": "-85.19079"
  },
  {
    "country": "US",
    "name": "Somerville",
    "lat": "35.2437",
    "lng": "-89.35007"
  },
  {
    "country": "US",
    "name": "South Carthage",
    "lat": "36.242",
    "lng": "-85.95193"
  },
  {
    "country": "US",
    "name": "South Cleveland",
    "lat": "35.14119",
    "lng": "-84.87217"
  },
  {
    "country": "US",
    "name": "South Fulton",
    "lat": "36.50089",
    "lng": "-88.87534"
  },
  {
    "country": "US",
    "name": "South Pittsburg",
    "lat": "35.0123",
    "lng": "-85.70441"
  },
  {
    "country": "US",
    "name": "Sparta",
    "lat": "35.9259",
    "lng": "-85.46414"
  },
  {
    "country": "US",
    "name": "Spencer",
    "lat": "35.74729",
    "lng": "-85.46664"
  },
  {
    "country": "US",
    "name": "Spring City",
    "lat": "35.69201",
    "lng": "-84.86078"
  },
  {
    "country": "US",
    "name": "Spring Hill",
    "lat": "35.75118",
    "lng": "-86.93"
  },
  {
    "country": "US",
    "name": "Springfield",
    "lat": "36.50921",
    "lng": "-86.885"
  },
  {
    "country": "US",
    "name": "Spurgeon",
    "lat": "36.43955",
    "lng": "-82.4557"
  },
  {
    "country": "US",
    "name": "Surgoinsville",
    "lat": "36.47093",
    "lng": "-82.85183"
  },
  {
    "country": "US",
    "name": "Sweetwater",
    "lat": "35.60146",
    "lng": "-84.46104"
  },
  {
    "country": "US",
    "name": "Tazewell",
    "lat": "36.45425",
    "lng": "-83.56935"
  },
  {
    "country": "US",
    "name": "Tennessee Ridge",
    "lat": "36.312",
    "lng": "-87.77336"
  },
  {
    "country": "US",
    "name": "Thompson's Station",
    "lat": "35.80201",
    "lng": "-86.91139"
  },
  {
    "country": "US",
    "name": "Three Way",
    "lat": "35.7759",
    "lng": "-88.8595"
  },
  {
    "country": "US",
    "name": "Tiptonville",
    "lat": "36.3784",
    "lng": "-89.47202"
  },
  {
    "country": "US",
    "name": "Tracy City",
    "lat": "35.26036",
    "lng": "-85.73608"
  },
  {
    "country": "US",
    "name": "Trenton",
    "lat": "35.98062",
    "lng": "-88.94145"
  },
  {
    "country": "US",
    "name": "Troy",
    "lat": "36.33868",
    "lng": "-89.16396"
  },
  {
    "country": "US",
    "name": "Tullahoma",
    "lat": "35.36202",
    "lng": "-86.20943"
  },
  {
    "country": "US",
    "name": "Tusculum",
    "lat": "36.1751",
    "lng": "-82.75876"
  },
  {
    "country": "US",
    "name": "Unicoi",
    "lat": "36.19539",
    "lng": "-82.34958"
  },
  {
    "country": "US",
    "name": "Union City",
    "lat": "36.42423",
    "lng": "-89.05701"
  },
  {
    "country": "US",
    "name": "Unionville",
    "lat": "35.62174",
    "lng": "-86.5925"
  },
  {
    "country": "US",
    "name": "Vonore",
    "lat": "35.59008",
    "lng": "-84.24186"
  },
  {
    "country": "US",
    "name": "Walden",
    "lat": "35.16479",
    "lng": "-85.30135"
  },
  {
    "country": "US",
    "name": "Walnut Hill",
    "lat": "36.56983",
    "lng": "-82.2568"
  },
  {
    "country": "US",
    "name": "Wartburg",
    "lat": "36.1048",
    "lng": "-84.59716"
  },
  {
    "country": "US",
    "name": "Watertown",
    "lat": "36.10034",
    "lng": "-86.13193"
  },
  {
    "country": "US",
    "name": "Waverly",
    "lat": "36.08395",
    "lng": "-87.79475"
  },
  {
    "country": "US",
    "name": "Waynesboro",
    "lat": "35.31952",
    "lng": "-87.76225"
  },
  {
    "country": "US",
    "name": "Westmoreland",
    "lat": "36.56199",
    "lng": "-86.24804"
  },
  {
    "country": "US",
    "name": "White Bluff",
    "lat": "36.10756",
    "lng": "-87.22084"
  },
  {
    "country": "US",
    "name": "White House",
    "lat": "36.47032",
    "lng": "-86.65138"
  },
  {
    "country": "US",
    "name": "White Pine",
    "lat": "36.10759",
    "lng": "-83.28683"
  },
  {
    "country": "US",
    "name": "Whiteville",
    "lat": "35.32647",
    "lng": "-89.14951"
  },
  {
    "country": "US",
    "name": "Whitwell",
    "lat": "35.20146",
    "lng": "-85.51913"
  },
  {
    "country": "US",
    "name": "Wildwood Lake",
    "lat": "35.09202",
    "lng": "-84.85439"
  },
  {
    "country": "US",
    "name": "Wildwood",
    "lat": "35.8037",
    "lng": "-83.87129"
  },
  {
    "country": "US",
    "name": "Winchester",
    "lat": "35.18592",
    "lng": "-86.11221"
  },
  {
    "country": "US",
    "name": "Woodbury",
    "lat": "35.82757",
    "lng": "-86.07166"
  },
  {
    "country": "US",
    "name": "Asherton",
    "lat": "28.44193",
    "lng": "-99.76033"
  },
  {
    "country": "US",
    "name": "Abilene",
    "lat": "32.44874",
    "lng": "-99.73314"
  },
  {
    "country": "US",
    "name": "Abram",
    "lat": "26.1998",
    "lng": "-98.41113"
  },
  {
    "country": "US",
    "name": "Addison",
    "lat": "32.96179",
    "lng": "-96.82917"
  },
  {
    "country": "US",
    "name": "Alamo Heights",
    "lat": "29.48495",
    "lng": "-98.46585"
  },
  {
    "country": "US",
    "name": "Alamo",
    "lat": "26.18369",
    "lng": "-98.12306"
  },
  {
    "country": "US",
    "name": "Albany",
    "lat": "32.72345",
    "lng": "-99.2973"
  },
  {
    "country": "US",
    "name": "Aldine",
    "lat": "29.93245",
    "lng": "-95.38021"
  },
  {
    "country": "US",
    "name": "Aledo",
    "lat": "32.69596",
    "lng": "-97.60225"
  },
  {
    "country": "US",
    "name": "Alice",
    "lat": "27.75225",
    "lng": "-98.06972"
  },
  {
    "country": "US",
    "name": "Alief",
    "lat": "29.71106",
    "lng": "-95.59633"
  },
  {
    "country": "US",
    "name": "Allen",
    "lat": "33.10317",
    "lng": "-96.67055"
  },
  {
    "country": "US",
    "name": "Alto",
    "lat": "31.65045",
    "lng": "-95.07272"
  },
  {
    "country": "US",
    "name": "Alton",
    "lat": "26.28729",
    "lng": "-98.31335"
  },
  {
    "country": "US",
    "name": "Alton North (historical)",
    "lat": "26.29535",
    "lng": "-98.30446"
  },
  {
    "country": "US",
    "name": "Alvarado",
    "lat": "32.40653",
    "lng": "-97.21168"
  },
  {
    "country": "US",
    "name": "Alvin",
    "lat": "29.42385",
    "lng": "-95.2441"
  },
  {
    "country": "US",
    "name": "Alvord",
    "lat": "33.35845",
    "lng": "-97.69475"
  },
  {
    "country": "US",
    "name": "Ames",
    "lat": "31.52099",
    "lng": "-97.77947"
  },
  {
    "country": "US",
    "name": "Ames",
    "lat": "30.05383",
    "lng": "-94.74353"
  },
  {
    "country": "US",
    "name": "Anahuac",
    "lat": "29.773",
    "lng": "-94.6827"
  },
  {
    "country": "US",
    "name": "Anderson",
    "lat": "30.48715",
    "lng": "-95.9869"
  },
  {
    "country": "US",
    "name": "Anderson Mill",
    "lat": "30.45492",
    "lng": "-97.80584"
  },
  {
    "country": "US",
    "name": "Angleton",
    "lat": "29.16941",
    "lng": "-95.43188"
  },
  {
    "country": "US",
    "name": "Anna",
    "lat": "33.349",
    "lng": "-96.5486"
  },
  {
    "country": "US",
    "name": "Annetta",
    "lat": "32.7093",
    "lng": "-97.67614"
  },
  {
    "country": "US",
    "name": "Anson",
    "lat": "32.7565",
    "lng": "-99.89621"
  },
  {
    "country": "US",
    "name": "Aransas Pass",
    "lat": "27.90947",
    "lng": "-97.14999"
  },
  {
    "country": "US",
    "name": "Archer City",
    "lat": "33.59566",
    "lng": "-98.62561"
  },
  {
    "country": "US",
    "name": "Arcola",
    "lat": "29.49607",
    "lng": "-95.46578"
  },
  {
    "country": "US",
    "name": "Argyle",
    "lat": "33.12123",
    "lng": "-97.18335"
  },
  {
    "country": "US",
    "name": "Arlington",
    "lat": "32.73569",
    "lng": "-97.10807"
  },
  {
    "country": "US",
    "name": "Atascocita",
    "lat": "29.99883",
    "lng": "-95.1766"
  },
  {
    "country": "US",
    "name": "Athens",
    "lat": "32.20487",
    "lng": "-95.85552"
  },
  {
    "country": "US",
    "name": "Atlanta",
    "lat": "33.11374",
    "lng": "-94.16435"
  },
  {
    "country": "US",
    "name": "Aubrey",
    "lat": "33.30428",
    "lng": "-96.98612"
  },
  {
    "country": "US",
    "name": "Aurora",
    "lat": "33.06068",
    "lng": "-97.50336"
  },
  {
    "country": "US",
    "name": "Austin",
    "lat": "30.26715",
    "lng": "-97.74306"
  },
  {
    "country": "US",
    "name": "Azle",
    "lat": "32.89513",
    "lng": "-97.54586"
  },
  {
    "country": "US",
    "name": "Bacliff",
    "lat": "29.5069",
    "lng": "-94.99243"
  },
  {
    "country": "US",
    "name": "Baird",
    "lat": "32.39402",
    "lng": "-99.39424"
  },
  {
    "country": "US",
    "name": "Balch Springs",
    "lat": "32.72874",
    "lng": "-96.62277"
  },
  {
    "country": "US",
    "name": "Balcones Heights",
    "lat": "29.48801",
    "lng": "-98.55169"
  },
  {
    "country": "US",
    "name": "Ballinger",
    "lat": "31.73821",
    "lng": "-99.94731"
  },
  {
    "country": "US",
    "name": "Bandera",
    "lat": "29.72661",
    "lng": "-99.07365"
  },
  {
    "country": "US",
    "name": "Bangs",
    "lat": "31.7171",
    "lng": "-99.13255"
  },
  {
    "country": "US",
    "name": "Barrett",
    "lat": "29.87995",
    "lng": "-95.06298"
  },
  {
    "country": "US",
    "name": "Bartlett",
    "lat": "30.79491",
    "lng": "-97.42556"
  },
  {
    "country": "US",
    "name": "Barton Creek",
    "lat": "30.28521",
    "lng": "-97.86917"
  },
  {
    "country": "US",
    "name": "Bartonville",
    "lat": "33.07318",
    "lng": "-97.13168"
  },
  {
    "country": "US",
    "name": "Bastrop",
    "lat": "30.11049",
    "lng": "-97.31527"
  },
  {
    "country": "US",
    "name": "Batesville",
    "lat": "28.95108",
    "lng": "-99.61783"
  },
  {
    "country": "US",
    "name": "Baytown",
    "lat": "29.7355",
    "lng": "-94.97743"
  },
  {
    "country": "US",
    "name": "Beach City",
    "lat": "29.66217",
    "lng": "-94.88992"
  },
  {
    "country": "US",
    "name": "Bayou Vista",
    "lat": "29.32635",
    "lng": "-94.93853"
  },
  {
    "country": "US",
    "name": "Beaumont",
    "lat": "30.08605",
    "lng": "-94.10185"
  },
  {
    "country": "US",
    "name": "Bedford",
    "lat": "32.84402",
    "lng": "-97.14307"
  },
  {
    "country": "US",
    "name": "Bee Cave",
    "lat": "30.30854",
    "lng": "-97.94501"
  },
  {
    "country": "US",
    "name": "Beeville",
    "lat": "28.40095",
    "lng": "-97.74974"
  },
  {
    "country": "US",
    "name": "Bellaire",
    "lat": "29.70579",
    "lng": "-95.45883"
  },
  {
    "country": "US",
    "name": "Bellmead",
    "lat": "31.59405",
    "lng": "-97.10889"
  },
  {
    "country": "US",
    "name": "Bells",
    "lat": "33.61038",
    "lng": "-96.41082"
  },
  {
    "country": "US",
    "name": "Bellville",
    "lat": "29.95023",
    "lng": "-96.25719"
  },
  {
    "country": "US",
    "name": "Belton",
    "lat": "31.05601",
    "lng": "-97.46445"
  },
  {
    "country": "US",
    "name": "Benavides",
    "lat": "27.59892",
    "lng": "-98.40807"
  },
  {
    "country": "US",
    "name": "Benbrook",
    "lat": "32.67319",
    "lng": "-97.46058"
  },
  {
    "country": "US",
    "name": "Benjamin",
    "lat": "33.58398",
    "lng": "-99.79231"
  },
  {
    "country": "US",
    "name": "Berryville",
    "lat": "32.08849",
    "lng": "-95.4719"
  },
  {
    "country": "US",
    "name": "Bertram",
    "lat": "30.7438",
    "lng": "-98.05558"
  },
  {
    "country": "US",
    "name": "Beverly",
    "lat": "31.52517",
    "lng": "-97.14195"
  },
  {
    "country": "US",
    "name": "Beverly Hills",
    "lat": "31.52156",
    "lng": "-97.15389"
  },
  {
    "country": "US",
    "name": "Bevil Oaks",
    "lat": "30.15021",
    "lng": "-94.26963"
  },
  {
    "country": "US",
    "name": "Big Sandy",
    "lat": "32.58375",
    "lng": "-95.10883"
  },
  {
    "country": "US",
    "name": "Bishop",
    "lat": "27.58614",
    "lng": "-97.79916"
  },
  {
    "country": "US",
    "name": "Blanco",
    "lat": "30.09799",
    "lng": "-98.42141"
  },
  {
    "country": "US",
    "name": "Bloomington",
    "lat": "28.64777",
    "lng": "-96.89249"
  },
  {
    "country": "US",
    "name": "Blossom",
    "lat": "33.6615",
    "lng": "-95.38579"
  },
  {
    "country": "US",
    "name": "Blue Mound",
    "lat": "32.85652",
    "lng": "-97.33891"
  },
  {
    "country": "US",
    "name": "Boerne",
    "lat": "29.79466",
    "lng": "-98.73197"
  },
  {
    "country": "US",
    "name": "Bogata",
    "lat": "33.47067",
    "lng": "-95.21384"
  },
  {
    "country": "US",
    "name": "Boling",
    "lat": "29.26441",
    "lng": "-95.94384"
  },
  {
    "country": "US",
    "name": "Bolivar Peninsula",
    "lat": "29.47829",
    "lng": "-94.57991"
  },
  {
    "country": "US",
    "name": "Bonham",
    "lat": "33.57733",
    "lng": "-96.17831"
  },
  {
    "country": "US",
    "name": "Bowie",
    "lat": "33.559",
    "lng": "-97.84865"
  },
  {
    "country": "US",
    "name": "Boyd",
    "lat": "33.07873",
    "lng": "-97.5653"
  },
  {
    "country": "US",
    "name": "Brady",
    "lat": "31.13517",
    "lng": "-99.33506"
  },
  {
    "country": "US",
    "name": "Brazoria",
    "lat": "29.04441",
    "lng": "-95.56911"
  },
  {
    "country": "US",
    "name": "Breckenridge",
    "lat": "32.75568",
    "lng": "-98.90229"
  },
  {
    "country": "US",
    "name": "Brenham",
    "lat": "30.16688",
    "lng": "-96.39774"
  },
  {
    "country": "US",
    "name": "Briar",
    "lat": "32.99512",
    "lng": "-97.5428"
  },
  {
    "country": "US",
    "name": "Briarcliff",
    "lat": "30.40742",
    "lng": "-98.04446"
  },
  {
    "country": "US",
    "name": "Bridge City",
    "lat": "30.02077",
    "lng": "-93.84573"
  },
  {
    "country": "US",
    "name": "Bridgeport",
    "lat": "33.21012",
    "lng": "-97.75476"
  },
  {
    "country": "US",
    "name": "Brookshire",
    "lat": "29.78606",
    "lng": "-95.95107"
  },
  {
    "country": "US",
    "name": "Brookside Village",
    "lat": "29.5869",
    "lng": "-95.32522"
  },
  {
    "country": "US",
    "name": "Brownsboro",
    "lat": "32.30237",
    "lng": "-95.61357"
  },
  {
    "country": "US",
    "name": "Brownsville",
    "lat": "25.90175",
    "lng": "-97.49748"
  },
  {
    "country": "US",
    "name": "Bruceville-Eddy",
    "lat": "31.30517",
    "lng": "-97.25167"
  },
  {
    "country": "US",
    "name": "Brownwood",
    "lat": "31.70932",
    "lng": "-98.99116"
  },
  {
    "country": "US",
    "name": "Brushy Creek",
    "lat": "30.51353",
    "lng": "-97.73973"
  },
  {
    "country": "US",
    "name": "Bryan",
    "lat": "30.67436",
    "lng": "-96.36996"
  },
  {
    "country": "US",
    "name": "Buchanan Dam",
    "lat": "30.7399",
    "lng": "-98.43114"
  },
  {
    "country": "US",
    "name": "Buffalo",
    "lat": "31.46379",
    "lng": "-96.05802"
  },
  {
    "country": "US",
    "name": "Bullard",
    "lat": "32.13988",
    "lng": "-95.32023"
  },
  {
    "country": "US",
    "name": "Bulverde",
    "lat": "29.74383",
    "lng": "-98.45307"
  },
  {
    "country": "US",
    "name": "Buna",
    "lat": "30.43298",
    "lng": "-93.9624"
  },
  {
    "country": "US",
    "name": "Bunker Hill Village",
    "lat": "29.76745",
    "lng": "-95.52994"
  },
  {
    "country": "US",
    "name": "Burkburnett",
    "lat": "34.09787",
    "lng": "-98.57061"
  },
  {
    "country": "US",
    "name": "Burleson",
    "lat": "32.54208",
    "lng": "-97.32085"
  },
  {
    "country": "US",
    "name": "Burnet",
    "lat": "30.75824",
    "lng": "-98.22836"
  },
  {
    "country": "US",
    "name": "Cactus",
    "lat": "27.90695",
    "lng": "-99.39392"
  },
  {
    "country": "US",
    "name": "Caddo Mills",
    "lat": "33.06567",
    "lng": "-96.22776"
  },
  {
    "country": "US",
    "name": "Caldwell",
    "lat": "30.53132",
    "lng": "-96.69303"
  },
  {
    "country": "US",
    "name": "Calvert",
    "lat": "30.97797",
    "lng": "-96.67386"
  },
  {
    "country": "US",
    "name": "Cameron",
    "lat": "30.85325",
    "lng": "-96.97693"
  },
  {
    "country": "US",
    "name": "Cameron Park",
    "lat": "25.96452",
    "lng": "-97.47665"
  },
  {
    "country": "US",
    "name": "Cameron Park Colonia",
    "lat": "25.97147",
    "lng": "-97.47832"
  },
  {
    "country": "US",
    "name": "Camp Swift",
    "lat": "30.19077",
    "lng": "-97.29221"
  },
  {
    "country": "US",
    "name": "Canton",
    "lat": "32.55652",
    "lng": "-95.8633"
  },
  {
    "country": "US",
    "name": "Canyon Lake",
    "lat": "29.87522",
    "lng": "-98.26251"
  },
  {
    "country": "US",
    "name": "Carrizo Springs",
    "lat": "28.52193",
    "lng": "-99.86061"
  },
  {
    "country": "US",
    "name": "Carrollton",
    "lat": "32.95373",
    "lng": "-96.89028"
  },
  {
    "country": "US",
    "name": "Carthage",
    "lat": "32.15738",
    "lng": "-94.33742"
  },
  {
    "country": "US",
    "name": "Castle Hills",
    "lat": "29.52329",
    "lng": "-98.51641"
  },
  {
    "country": "US",
    "name": "Castroville",
    "lat": "29.35579",
    "lng": "-98.87864"
  },
  {
    "country": "US",
    "name": "Cedar Hill",
    "lat": "32.58847",
    "lng": "-96.95612"
  },
  {
    "country": "US",
    "name": "Cedar Park",
    "lat": "30.5052",
    "lng": "-97.82029"
  },
  {
    "country": "US",
    "name": "Celina",
    "lat": "33.32456",
    "lng": "-96.78444"
  },
  {
    "country": "US",
    "name": "Center",
    "lat": "31.51073",
    "lng": "-96.4247"
  },
  {
    "country": "US",
    "name": "Center",
    "lat": "31.79545",
    "lng": "-94.17909"
  },
  {
    "country": "US",
    "name": "Centerville",
    "lat": "31.25796",
    "lng": "-95.97829"
  },
  {
    "country": "US",
    "name": "Central Gardens",
    "lat": "29.99549",
    "lng": "-94.01406"
  },
  {
    "country": "US",
    "name": "César Chávez",
    "lat": "26.3034",
    "lng": "-98.11529"
  },
  {
    "country": "US",
    "name": "Chandler",
    "lat": "32.30793",
    "lng": "-95.47996"
  },
  {
    "country": "US",
    "name": "Channelview",
    "lat": "29.77606",
    "lng": "-95.11465"
  },
  {
    "country": "US",
    "name": "Charlotte",
    "lat": "28.86192",
    "lng": "-98.70641"
  },
  {
    "country": "US",
    "name": "Chico",
    "lat": "33.29595",
    "lng": "-97.79892"
  },
  {
    "country": "US",
    "name": "China",
    "lat": "30.04799",
    "lng": "-94.33574"
  },
  {
    "country": "US",
    "name": "China Grove",
    "lat": "29.38885",
    "lng": "-98.3489"
  },
  {
    "country": "US",
    "name": "Cibolo",
    "lat": "29.56162",
    "lng": "-98.22696"
  },
  {
    "country": "US",
    "name": "Cinco Ranch",
    "lat": "29.73884",
    "lng": "-95.758"
  },
  {
    "country": "US",
    "name": "Cisco",
    "lat": "32.38819",
    "lng": "-98.97923"
  },
  {
    "country": "US",
    "name": "Citrus City",
    "lat": "26.32646",
    "lng": "-98.3853"
  },
  {
    "country": "US",
    "name": "Clarksville",
    "lat": "33.61066",
    "lng": "-95.05272"
  },
  {
    "country": "US",
    "name": "Clear Lake Shores",
    "lat": "29.54745",
    "lng": "-95.03215"
  },
  {
    "country": "US",
    "name": "Cleburne",
    "lat": "32.34764",
    "lng": "-97.38668"
  },
  {
    "country": "US",
    "name": "Cleveland",
    "lat": "31.67682",
    "lng": "-99.25367"
  },
  {
    "country": "US",
    "name": "Cleveland",
    "lat": "30.34132",
    "lng": "-95.08549"
  },
  {
    "country": "US",
    "name": "Clifton",
    "lat": "31.78238",
    "lng": "-97.57669"
  },
  {
    "country": "US",
    "name": "Cloverleaf",
    "lat": "29.77828",
    "lng": "-95.17188"
  },
  {
    "country": "US",
    "name": "Clute",
    "lat": "29.02469",
    "lng": "-95.39883"
  },
  {
    "country": "US",
    "name": "Clyde",
    "lat": "32.40596",
    "lng": "-99.49369"
  },
  {
    "country": "US",
    "name": "Cockrell Hill",
    "lat": "32.73624",
    "lng": "-96.88695"
  },
  {
    "country": "US",
    "name": "Coldspring",
    "lat": "30.59242",
    "lng": "-95.12938"
  },
  {
    "country": "US",
    "name": "Coleman",
    "lat": "31.82737",
    "lng": "-99.42645"
  },
  {
    "country": "US",
    "name": "College Station",
    "lat": "30.62798",
    "lng": "-96.33441"
  },
  {
    "country": "US",
    "name": "Colleyville",
    "lat": "32.88096",
    "lng": "-97.15501"
  },
  {
    "country": "US",
    "name": "Collinsville",
    "lat": "33.5615",
    "lng": "-96.91111"
  },
  {
    "country": "US",
    "name": "Columbus",
    "lat": "29.70662",
    "lng": "-96.53969"
  },
  {
    "country": "US",
    "name": "Comanche",
    "lat": "31.89737",
    "lng": "-98.60366"
  },
  {
    "country": "US",
    "name": "Combes",
    "lat": "26.24869",
    "lng": "-97.73388"
  },
  {
    "country": "US",
    "name": "Combine",
    "lat": "32.58847",
    "lng": "-96.5086"
  },
  {
    "country": "US",
    "name": "Comfort",
    "lat": "29.96771",
    "lng": "-98.90503"
  },
  {
    "country": "US",
    "name": "Commerce",
    "lat": "33.24706",
    "lng": "-95.89997"
  },
  {
    "country": "US",
    "name": "Conroe",
    "lat": "30.31188",
    "lng": "-95.45605"
  },
  {
    "country": "US",
    "name": "Converse",
    "lat": "29.51801",
    "lng": "-98.31612"
  },
  {
    "country": "US",
    "name": "Cooper",
    "lat": "33.37344",
    "lng": "-95.68829"
  },
  {
    "country": "US",
    "name": "Cooper",
    "lat": "31.24324",
    "lng": "-95.58217"
  },
  {
    "country": "US",
    "name": "Coppell",
    "lat": "32.95457",
    "lng": "-97.01501"
  },
  {
    "country": "US",
    "name": "Copper Canyon",
    "lat": "33.09595",
    "lng": "-97.09668"
  },
  {
    "country": "US",
    "name": "Copperas Cove",
    "lat": "31.12406",
    "lng": "-97.90308"
  },
  {
    "country": "US",
    "name": "Corinth",
    "lat": "33.15401",
    "lng": "-97.06473"
  },
  {
    "country": "US",
    "name": "Corpus Christi",
    "lat": "27.80058",
    "lng": "-97.39638"
  },
  {
    "country": "US",
    "name": "Corrigan",
    "lat": "30.99686",
    "lng": "-94.82715"
  },
  {
    "country": "US",
    "name": "Corsicana",
    "lat": "32.09543",
    "lng": "-96.46887"
  },
  {
    "country": "US",
    "name": "Cottonwood Shores",
    "lat": "30.55575",
    "lng": "-98.32391"
  },
  {
    "country": "US",
    "name": "Cotulla",
    "lat": "28.43693",
    "lng": "-99.23503"
  },
  {
    "country": "US",
    "name": "Crandall",
    "lat": "32.62791",
    "lng": "-96.45582"
  },
  {
    "country": "US",
    "name": "Crockett",
    "lat": "31.31824",
    "lng": "-95.45661"
  },
  {
    "country": "US",
    "name": "Crosby",
    "lat": "29.91189",
    "lng": "-95.06215"
  },
  {
    "country": "US",
    "name": "Cross Mountain",
    "lat": "29.6455",
    "lng": "-98.65947"
  },
  {
    "country": "US",
    "name": "Crowell",
    "lat": "33.98397",
    "lng": "-99.72482"
  },
  {
    "country": "US",
    "name": "Crowley",
    "lat": "32.57903",
    "lng": "-97.36252"
  },
  {
    "country": "US",
    "name": "Crystal City",
    "lat": "28.67748",
    "lng": "-99.82811"
  },
  {
    "country": "US",
    "name": "Cuero",
    "lat": "29.09387",
    "lng": "-97.28916"
  },
  {
    "country": "US",
    "name": "Cut and Shoot",
    "lat": "30.33327",
    "lng": "-95.35799"
  },
  {
    "country": "US",
    "name": "Cypress",
    "lat": "29.96911",
    "lng": "-95.69717"
  },
  {
    "country": "US",
    "name": "Daingerfield",
    "lat": "33.03179",
    "lng": "-94.72187"
  },
  {
    "country": "US",
    "name": "Dallas",
    "lat": "32.78306",
    "lng": "-96.80667"
  },
  {
    "country": "US",
    "name": "Dalworthington Gardens",
    "lat": "32.70291",
    "lng": "-97.15529"
  },
  {
    "country": "US",
    "name": "Danbury",
    "lat": "29.2283",
    "lng": "-95.34494"
  },
  {
    "country": "US",
    "name": "Dayton",
    "lat": "30.04661",
    "lng": "-94.8852"
  },
  {
    "country": "US",
    "name": "De Kalb",
    "lat": "33.50873",
    "lng": "-94.61632"
  },
  {
    "country": "US",
    "name": "De Leon",
    "lat": "32.11097",
    "lng": "-98.53588"
  },
  {
    "country": "US",
    "name": "DeCordova",
    "lat": "32.42986",
    "lng": "-97.69503"
  },
  {
    "country": "US",
    "name": "DeSoto",
    "lat": "32.58986",
    "lng": "-96.85695"
  },
  {
    "country": "US",
    "name": "Decatur",
    "lat": "33.23428",
    "lng": "-97.58614"
  },
  {
    "country": "US",
    "name": "Deer Park",
    "lat": "29.70523",
    "lng": "-95.12382"
  },
  {
    "country": "US",
    "name": "Denison",
    "lat": "33.75566",
    "lng": "-96.53666"
  },
  {
    "country": "US",
    "name": "Denton",
    "lat": "33.21484",
    "lng": "-97.13307"
  },
  {
    "country": "US",
    "name": "Deweyville",
    "lat": "30.29771",
    "lng": "-93.7435"
  },
  {
    "country": "US",
    "name": "Diboll",
    "lat": "31.18713",
    "lng": "-94.78104"
  },
  {
    "country": "US",
    "name": "Dickinson",
    "lat": "29.46079",
    "lng": "-95.05132"
  },
  {
    "country": "US",
    "name": "Doffing",
    "lat": "26.27452",
    "lng": "-98.38585"
  },
  {
    "country": "US",
    "name": "Donna",
    "lat": "26.17035",
    "lng": "-98.05195"
  },
  {
    "country": "US",
    "name": "Doolittle",
    "lat": "26.35337",
    "lng": "-98.11666"
  },
  {
    "country": "US",
    "name": "Double Oak",
    "lat": "33.06512",
    "lng": "-97.11057"
  },
  {
    "country": "US",
    "name": "Dripping Springs",
    "lat": "30.19021",
    "lng": "-98.08668"
  },
  {
    "country": "US",
    "name": "Dublin",
    "lat": "32.08514",
    "lng": "-98.34199"
  },
  {
    "country": "US",
    "name": "Duncanville",
    "lat": "32.6518",
    "lng": "-96.90834"
  },
  {
    "country": "US",
    "name": "Eagle Lake",
    "lat": "29.58968",
    "lng": "-96.33358"
  },
  {
    "country": "US",
    "name": "Eagle Mountain",
    "lat": "32.89346",
    "lng": "-97.44446"
  },
  {
    "country": "US",
    "name": "Early",
    "lat": "31.7421",
    "lng": "-98.94561"
  },
  {
    "country": "US",
    "name": "East Bernard",
    "lat": "29.53107",
    "lng": "-96.07107"
  },
  {
    "country": "US",
    "name": "Eastland",
    "lat": "32.40152",
    "lng": "-98.81756"
  },
  {
    "country": "US",
    "name": "Edcouch",
    "lat": "26.29396",
    "lng": "-97.96056"
  },
  {
    "country": "US",
    "name": "Eden",
    "lat": "31.21628",
    "lng": "-99.84563"
  },
  {
    "country": "US",
    "name": "Edgecliff Village",
    "lat": "32.65763",
    "lng": "-97.34279"
  },
  {
    "country": "US",
    "name": "Edgewood",
    "lat": "32.69818",
    "lng": "-95.88524"
  },
  {
    "country": "US",
    "name": "Edinburg",
    "lat": "26.30174",
    "lng": "-98.16334"
  },
  {
    "country": "US",
    "name": "El Campo",
    "lat": "29.19664",
    "lng": "-96.26969"
  },
  {
    "country": "US",
    "name": "El Cenizo",
    "lat": "27.35224",
    "lng": "-99.49254"
  },
  {
    "country": "US",
    "name": "El Lago",
    "lat": "29.56356",
    "lng": "-95.04521"
  },
  {
    "country": "US",
    "name": "Electra",
    "lat": "34.02926",
    "lng": "-98.91896"
  },
  {
    "country": "US",
    "name": "Elgin",
    "lat": "30.34965",
    "lng": "-97.37027"
  },
  {
    "country": "US",
    "name": "Elkhart",
    "lat": "31.62517",
    "lng": "-95.5794"
  },
  {
    "country": "US",
    "name": "Elmendorf",
    "lat": "29.25607",
    "lng": "-98.33279"
  },
  {
    "country": "US",
    "name": "Elsa",
    "lat": "26.2934",
    "lng": "-97.99306"
  },
  {
    "country": "US",
    "name": "Emory",
    "lat": "32.87457",
    "lng": "-95.76552"
  },
  {
    "country": "US",
    "name": "Encantada-Ranchito-El Calaboz",
    "lat": "26.03344",
    "lng": "-97.63307"
  },
  {
    "country": "US",
    "name": "Ennis",
    "lat": "32.32931",
    "lng": "-96.62527"
  },
  {
    "country": "US",
    "name": "Escobares",
    "lat": "26.41062",
    "lng": "-98.96253"
  },
  {
    "country": "US",
    "name": "Euless",
    "lat": "32.83707",
    "lng": "-97.08195"
  },
  {
    "country": "US",
    "name": "Evadale",
    "lat": "30.35493",
    "lng": "-94.07268"
  },
  {
    "country": "US",
    "name": "Everman",
    "lat": "32.63097",
    "lng": "-97.28918"
  },
  {
    "country": "US",
    "name": "Fair Oaks Ranch",
    "lat": "29.74578",
    "lng": "-98.64336"
  },
  {
    "country": "US",
    "name": "Fairchilds",
    "lat": "29.43135",
    "lng": "-95.78023"
  },
  {
    "country": "US",
    "name": "Fairfield",
    "lat": "31.72461",
    "lng": "-96.16525"
  },
  {
    "country": "US",
    "name": "Fairview",
    "lat": "33.1579",
    "lng": "-96.63166"
  },
  {
    "country": "US",
    "name": "Fairview",
    "lat": "33.01929",
    "lng": "-97.54586"
  },
  {
    "country": "US",
    "name": "Falcon Lake Estates",
    "lat": "26.87282",
    "lng": "-99.25531"
  },
  {
    "country": "US",
    "name": "Falfurrias",
    "lat": "27.22699",
    "lng": "-98.14417"
  },
  {
    "country": "US",
    "name": "Fannett",
    "lat": "29.92605",
    "lng": "-94.25074"
  },
  {
    "country": "US",
    "name": "Farmers Branch",
    "lat": "32.92651",
    "lng": "-96.89612"
  },
  {
    "country": "US",
    "name": "Farmersville",
    "lat": "33.16345",
    "lng": "-96.35998"
  },
  {
    "country": "US",
    "name": "Fate",
    "lat": "32.94151",
    "lng": "-96.38137"
  },
  {
    "country": "US",
    "name": "Ferris",
    "lat": "32.53403",
    "lng": "-96.66555"
  },
  {
    "country": "US",
    "name": "Fifth Street",
    "lat": "29.59829",
    "lng": "-95.55133"
  },
  {
    "country": "US",
    "name": "Flatonia",
    "lat": "29.68773",
    "lng": "-97.1086"
  },
  {
    "country": "US",
    "name": "Florence",
    "lat": "30.8413",
    "lng": "-97.79363"
  },
  {
    "country": "US",
    "name": "Floresville",
    "lat": "29.13358",
    "lng": "-98.15612"
  },
  {
    "country": "US",
    "name": "Flower Mound",
    "lat": "33.01457",
    "lng": "-97.09696"
  },
  {
    "country": "US",
    "name": "Forest Hill",
    "lat": "32.67208",
    "lng": "-97.26918"
  },
  {
    "country": "US",
    "name": "Forney",
    "lat": "32.74818",
    "lng": "-96.47193"
  },
  {
    "country": "US",
    "name": "Fort Worth",
    "lat": "32.72541",
    "lng": "-97.32085"
  },
  {
    "country": "US",
    "name": "Four Corners",
    "lat": "29.66857",
    "lng": "-95.65772"
  },
  {
    "country": "US",
    "name": "Franklin",
    "lat": "31.02602",
    "lng": "-96.48524"
  },
  {
    "country": "US",
    "name": "Frankston",
    "lat": "32.05266",
    "lng": "-95.50635"
  },
  {
    "country": "US",
    "name": "Fredericksburg",
    "lat": "30.2752",
    "lng": "-98.87198"
  },
  {
    "country": "US",
    "name": "Freeport",
    "lat": "28.95414",
    "lng": "-95.35966"
  },
  {
    "country": "US",
    "name": "Freer",
    "lat": "27.8828",
    "lng": "-98.61779"
  },
  {
    "country": "US",
    "name": "Fresno",
    "lat": "29.53885",
    "lng": "-95.44744"
  },
  {
    "country": "US",
    "name": "Friendswood",
    "lat": "29.5294",
    "lng": "-95.20104"
  },
  {
    "country": "US",
    "name": "Frisco",
    "lat": "33.15067",
    "lng": "-96.82361"
  },
  {
    "country": "US",
    "name": "Fulshear",
    "lat": "29.68996",
    "lng": "-95.89968"
  },
  {
    "country": "US",
    "name": "Fulton",
    "lat": "28.0614",
    "lng": "-97.0411"
  },
  {
    "country": "US",
    "name": "Gainesville",
    "lat": "33.62594",
    "lng": "-97.13335"
  },
  {
    "country": "US",
    "name": "Galena Park",
    "lat": "29.73356",
    "lng": "-95.23021"
  },
  {
    "country": "US",
    "name": "Galveston",
    "lat": "29.30135",
    "lng": "-94.7977"
  },
  {
    "country": "US",
    "name": "Ganado",
    "lat": "29.04054",
    "lng": "-96.51358"
  },
  {
    "country": "US",
    "name": "Garden Ridge",
    "lat": "29.63467",
    "lng": "-98.30529"
  },
  {
    "country": "US",
    "name": "Gardendale",
    "lat": "28.51693",
    "lng": "-99.21614"
  },
  {
    "country": "US",
    "name": "Garfield",
    "lat": "30.18744",
    "lng": "-97.55778"
  },
  {
    "country": "US",
    "name": "Garland",
    "lat": "32.91262",
    "lng": "-96.63888"
  },
  {
    "country": "US",
    "name": "Gatesville",
    "lat": "31.43516",
    "lng": "-97.74391"
  },
  {
    "country": "US",
    "name": "George West",
    "lat": "28.3325",
    "lng": "-98.11751"
  },
  {
    "country": "US",
    "name": "Georgetown",
    "lat": "30.63269",
    "lng": "-97.67723"
  },
  {
    "country": "US",
    "name": "Geronimo",
    "lat": "29.663",
    "lng": "-97.96695"
  },
  {
    "country": "US",
    "name": "Gholson",
    "lat": "31.701",
    "lng": "-97.2164"
  },
  {
    "country": "US",
    "name": "Giddings",
    "lat": "30.18272",
    "lng": "-96.93637"
  },
  {
    "country": "US",
    "name": "Gilmer",
    "lat": "32.72875",
    "lng": "-94.94244"
  },
  {
    "country": "US",
    "name": "Gladewater",
    "lat": "32.53653",
    "lng": "-94.94272"
  },
  {
    "country": "US",
    "name": "Glen Rose",
    "lat": "32.23459",
    "lng": "-97.75531"
  },
  {
    "country": "US",
    "name": "Glenn Heights",
    "lat": "32.54875",
    "lng": "-96.85667"
  },
  {
    "country": "US",
    "name": "Godley",
    "lat": "32.44903",
    "lng": "-97.52669"
  },
  {
    "country": "US",
    "name": "Goldthwaite",
    "lat": "31.44989",
    "lng": "-98.57088"
  },
  {
    "country": "US",
    "name": "Goliad",
    "lat": "28.66833",
    "lng": "-97.38833"
  },
  {
    "country": "US",
    "name": "Gonzales",
    "lat": "29.50163",
    "lng": "-97.45249"
  },
  {
    "country": "US",
    "name": "Gorman",
    "lat": "32.21375",
    "lng": "-98.67061"
  },
  {
    "country": "US",
    "name": "Graham",
    "lat": "33.10706",
    "lng": "-98.5895"
  },
  {
    "country": "US",
    "name": "Granbury",
    "lat": "32.44208",
    "lng": "-97.7942"
  },
  {
    "country": "US",
    "name": "Grand Prairie",
    "lat": "32.74596",
    "lng": "-96.99778"
  },
  {
    "country": "US",
    "name": "Grand Saline",
    "lat": "32.67346",
    "lng": "-95.70941"
  },
  {
    "country": "US",
    "name": "Grandview",
    "lat": "32.27042",
    "lng": "-97.17918"
  },
  {
    "country": "US",
    "name": "Granger",
    "lat": "30.71769",
    "lng": "-97.44278"
  },
  {
    "country": "US",
    "name": "Granite Shoals",
    "lat": "30.58908",
    "lng": "-98.38392"
  },
  {
    "country": "US",
    "name": "Grapeland",
    "lat": "31.49185",
    "lng": "-95.47856"
  },
  {
    "country": "US",
    "name": "Grapevine",
    "lat": "32.93429",
    "lng": "-97.07807"
  },
  {
    "country": "US",
    "name": "Greatwood",
    "lat": "29.55413",
    "lng": "-95.67578"
  },
  {
    "country": "US",
    "name": "Green Valley Farms",
    "lat": "26.12202",
    "lng": "-97.56054"
  },
  {
    "country": "US",
    "name": "Greenville",
    "lat": "33.13845",
    "lng": "-96.11081"
  },
  {
    "country": "US",
    "name": "Gregory",
    "lat": "27.92224",
    "lng": "-97.28999"
  },
  {
    "country": "US",
    "name": "Groesbeck",
    "lat": "31.52434",
    "lng": "-96.53387"
  },
  {
    "country": "US",
    "name": "Groves",
    "lat": "29.94827",
    "lng": "-93.91712"
  },
  {
    "country": "US",
    "name": "Groveton",
    "lat": "31.05491",
    "lng": "-95.12577"
  },
  {
    "country": "US",
    "name": "Gun Barrel City",
    "lat": "32.33459",
    "lng": "-96.15136"
  },
  {
    "country": "US",
    "name": "Gunter",
    "lat": "33.44789",
    "lng": "-96.74749"
  },
  {
    "country": "US",
    "name": "Gunter",
    "lat": "32.86873",
    "lng": "-95.62968"
  },
  {
    "country": "US",
    "name": "Hackberry",
    "lat": "33.15234",
    "lng": "-96.91778"
  },
  {
    "country": "US",
    "name": "Hallettsville",
    "lat": "29.44385",
    "lng": "-96.94109"
  },
  {
    "country": "US",
    "name": "Hallsville",
    "lat": "32.50432",
    "lng": "-94.57409"
  },
  {
    "country": "US",
    "name": "Haltom City",
    "lat": "32.79957",
    "lng": "-97.26918"
  },
  {
    "country": "US",
    "name": "Hamilton",
    "lat": "31.70377",
    "lng": "-98.12392"
  },
  {
    "country": "US",
    "name": "Harker Heights",
    "lat": "31.08351",
    "lng": "-97.65974"
  },
  {
    "country": "US",
    "name": "Harlingen",
    "lat": "26.19063",
    "lng": "-97.6961"
  },
  {
    "country": "US",
    "name": "Harper",
    "lat": "30.29992",
    "lng": "-99.24421"
  },
  {
    "country": "US",
    "name": "Haskell",
    "lat": "33.1576",
    "lng": "-99.7337"
  },
  {
    "country": "US",
    "name": "Haslet",
    "lat": "32.97485",
    "lng": "-97.3478"
  },
  {
    "country": "US",
    "name": "Hawkins",
    "lat": "32.58847",
    "lng": "-95.20411"
  },
  {
    "country": "US",
    "name": "Hearne",
    "lat": "30.87852",
    "lng": "-96.59303"
  },
  {
    "country": "US",
    "name": "Heath",
    "lat": "32.83651",
    "lng": "-96.47499"
  },
  {
    "country": "US",
    "name": "Hebbronville",
    "lat": "27.30688",
    "lng": "-98.68032"
  },
  {
    "country": "US",
    "name": "Hedwig Village",
    "lat": "29.77745",
    "lng": "-95.51716"
  },
  {
    "country": "US",
    "name": "Heidelberg",
    "lat": "26.19702",
    "lng": "-97.88028"
  },
  {
    "country": "US",
    "name": "Helotes",
    "lat": "29.57801",
    "lng": "-98.68975"
  },
  {
    "country": "US",
    "name": "Hemphill",
    "lat": "31.34074",
    "lng": "-93.84685"
  },
  {
    "country": "US",
    "name": "Hempstead",
    "lat": "30.09744",
    "lng": "-96.07829"
  },
  {
    "country": "US",
    "name": "Henrietta",
    "lat": "33.81732",
    "lng": "-98.19532"
  },
  {
    "country": "US",
    "name": "Hewitt",
    "lat": "31.46239",
    "lng": "-97.19584"
  },
  {
    "country": "US",
    "name": "Hickory Creek",
    "lat": "31.37879",
    "lng": "-95.32133"
  },
  {
    "country": "US",
    "name": "Hico",
    "lat": "31.98293",
    "lng": "-98.03365"
  },
  {
    "country": "US",
    "name": "Hidalgo",
    "lat": "26.10035",
    "lng": "-98.26307"
  },
  {
    "country": "US",
    "name": "Hideaway",
    "lat": "32.49042",
    "lng": "-95.45746"
  },
  {
    "country": "US",
    "name": "Highland Park",
    "lat": "32.83346",
    "lng": "-96.79195"
  },
  {
    "country": "US",
    "name": "Highland Village",
    "lat": "33.09179",
    "lng": "-97.04668"
  },
  {
    "country": "US",
    "name": "Highlands",
    "lat": "29.81884",
    "lng": "-95.05604"
  },
  {
    "country": "US",
    "name": "Hill Country Village",
    "lat": "29.58245",
    "lng": "-98.49085"
  },
  {
    "country": "US",
    "name": "Hillsboro",
    "lat": "32.01099",
    "lng": "-97.13001"
  },
  {
    "country": "US",
    "name": "Hilltop Lakes",
    "lat": "31.07935",
    "lng": "-96.20385"
  },
  {
    "country": "US",
    "name": "Hitchcock",
    "lat": "29.34829",
    "lng": "-95.01604"
  },
  {
    "country": "US",
    "name": "Holiday Lakes",
    "lat": "29.20969",
    "lng": "-95.51689"
  },
  {
    "country": "US",
    "name": "Holland",
    "lat": "30.87824",
    "lng": "-97.40167"
  },
  {
    "country": "US",
    "name": "Holliday",
    "lat": "33.81621",
    "lng": "-98.69506"
  },
  {
    "country": "US",
    "name": "Hollywood Park",
    "lat": "29.6005",
    "lng": "-98.48724"
  },
  {
    "country": "US",
    "name": "Hondo",
    "lat": "29.34746",
    "lng": "-99.14142"
  },
  {
    "country": "US",
    "name": "Honey Grove",
    "lat": "33.58344",
    "lng": "-95.90997"
  },
  {
    "country": "US",
    "name": "Hooks",
    "lat": "33.46623",
    "lng": "-94.28853"
  },
  {
    "country": "US",
    "name": "Hornsby Bend",
    "lat": "30.24743",
    "lng": "-97.58333"
  },
  {
    "country": "US",
    "name": "Horseshoe Bay",
    "lat": "30.54429",
    "lng": "-98.37394"
  },
  {
    "country": "US",
    "name": "Houston",
    "lat": "29.76328",
    "lng": "-95.36327"
  },
  {
    "country": "US",
    "name": "Howe",
    "lat": "33.50872",
    "lng": "-96.61221"
  },
  {
    "country": "US",
    "name": "Hubbard",
    "lat": "31.84849",
    "lng": "-96.79721"
  },
  {
    "country": "US",
    "name": "Hudson",
    "lat": "31.32268",
    "lng": "-94.77826"
  },
  {
    "country": "US",
    "name": "Hudson",
    "lat": "29.90245",
    "lng": "-95.50244"
  },
  {
    "country": "US",
    "name": "Hudson Bend",
    "lat": "30.41714",
    "lng": "-97.92918"
  },
  {
    "country": "US",
    "name": "Hudson Oaks",
    "lat": "32.75707",
    "lng": "-97.7067"
  },
  {
    "country": "US",
    "name": "Hughes Springs",
    "lat": "32.99846",
    "lng": "-94.63076"
  },
  {
    "country": "US",
    "name": "Humble",
    "lat": "29.99883",
    "lng": "-95.26216"
  },
  {
    "country": "US",
    "name": "Hunters Creek Village",
    "lat": "29.77051",
    "lng": "-95.4955"
  },
  {
    "country": "US",
    "name": "Huntington",
    "lat": "31.27769",
    "lng": "-94.57659"
  },
  {
    "country": "US",
    "name": "Huntsville",
    "lat": "30.72353",
    "lng": "-95.55078"
  },
  {
    "country": "US",
    "name": "Hurst",
    "lat": "32.82346",
    "lng": "-97.17057"
  },
  {
    "country": "US",
    "name": "Hutchins",
    "lat": "32.6493",
    "lng": "-96.71305"
  },
  {
    "country": "US",
    "name": "Hutto",
    "lat": "30.5427",
    "lng": "-97.54667"
  },
  {
    "country": "US",
    "name": "Indian Hills",
    "lat": "26.21285",
    "lng": "-97.91639"
  },
  {
    "country": "US",
    "name": "Inez",
    "lat": "28.90388",
    "lng": "-96.78804"
  },
  {
    "country": "US",
    "name": "Ingleside",
    "lat": "27.8778",
    "lng": "-97.21166"
  },
  {
    "country": "US",
    "name": "Ingram",
    "lat": "30.07743",
    "lng": "-99.24032"
  },
  {
    "country": "US",
    "name": "Iowa Colony",
    "lat": "29.48246",
    "lng": "-95.4155"
  },
  {
    "country": "US",
    "name": "Iowa Park",
    "lat": "33.95148",
    "lng": "-98.66867"
  },
  {
    "country": "US",
    "name": "Irving",
    "lat": "32.81402",
    "lng": "-96.94889"
  },
  {
    "country": "US",
    "name": "Italy",
    "lat": "32.18404",
    "lng": "-96.88472"
  },
  {
    "country": "US",
    "name": "Itasca",
    "lat": "32.15959",
    "lng": "-97.15001"
  },
  {
    "country": "US",
    "name": "Jacinto City",
    "lat": "29.76745",
    "lng": "-95.23382"
  },
  {
    "country": "US",
    "name": "Jacksboro",
    "lat": "33.21845",
    "lng": "-98.15866"
  },
  {
    "country": "US",
    "name": "Jacksonville",
    "lat": "31.96378",
    "lng": "-95.2705"
  },
  {
    "country": "US",
    "name": "Jamaica Beach",
    "lat": "29.18968",
    "lng": "-94.97965"
  },
  {
    "country": "US",
    "name": "Jarrell",
    "lat": "30.82491",
    "lng": "-97.60445"
  },
  {
    "country": "US",
    "name": "Jasper",
    "lat": "30.9202",
    "lng": "-93.99658"
  },
  {
    "country": "US",
    "name": "Jefferson",
    "lat": "32.75736",
    "lng": "-94.34519"
  },
  {
    "country": "US",
    "name": "Jersey Village",
    "lat": "29.88772",
    "lng": "-95.563"
  },
  {
    "country": "US",
    "name": "Jewett",
    "lat": "31.36157",
    "lng": "-96.14413"
  },
  {
    "country": "US",
    "name": "Johnson City",
    "lat": "30.27687",
    "lng": "-98.41197"
  },
  {
    "country": "US",
    "name": "Jollyville",
    "lat": "30.4427",
    "lng": "-97.77501"
  },
  {
    "country": "US",
    "name": "Jones Creek",
    "lat": "28.96858",
    "lng": "-95.45522"
  },
  {
    "country": "US",
    "name": "Jonestown",
    "lat": "30.49547",
    "lng": "-97.92335"
  },
  {
    "country": "US",
    "name": "Josephine",
    "lat": "33.06123",
    "lng": "-96.3072"
  },
  {
    "country": "US",
    "name": "Joshua",
    "lat": "32.46153",
    "lng": "-97.38807"
  },
  {
    "country": "US",
    "name": "Jourdanton",
    "lat": "28.91803",
    "lng": "-98.54641"
  },
  {
    "country": "US",
    "name": "Junction",
    "lat": "30.48936",
    "lng": "-99.77201"
  },
  {
    "country": "US",
    "name": "Justin",
    "lat": "33.08484",
    "lng": "-97.29613"
  },
  {
    "country": "US",
    "name": "Karnes City",
    "lat": "28.88498",
    "lng": "-97.90084"
  },
  {
    "country": "US",
    "name": "Kaufman",
    "lat": "32.58902",
    "lng": "-96.30887"
  },
  {
    "country": "US",
    "name": "Katy",
    "lat": "29.78579",
    "lng": "-95.8244"
  },
  {
    "country": "US",
    "name": "Keene",
    "lat": "32.39681",
    "lng": "-97.3239"
  },
  {
    "country": "US",
    "name": "Keller",
    "lat": "32.93457",
    "lng": "-97.25168"
  },
  {
    "country": "US",
    "name": "Kemah",
    "lat": "29.54273",
    "lng": "-95.02048"
  },
  {
    "country": "US",
    "name": "Kemp",
    "lat": "32.44264",
    "lng": "-96.22998"
  },
  {
    "country": "US",
    "name": "Kenedy",
    "lat": "28.81915",
    "lng": "-97.84861"
  },
  {
    "country": "US",
    "name": "Kennedale",
    "lat": "32.6468",
    "lng": "-97.22585"
  },
  {
    "country": "US",
    "name": "Kempner",
    "lat": "31.08101",
    "lng": "-98.00252"
  },
  {
    "country": "US",
    "name": "Kerens",
    "lat": "32.13321",
    "lng": "-96.22775"
  },
  {
    "country": "US",
    "name": "Kerrville",
    "lat": "30.04743",
    "lng": "-99.14032"
  },
  {
    "country": "US",
    "name": "Kilgore",
    "lat": "32.38626",
    "lng": "-94.87577"
  },
  {
    "country": "US",
    "name": "Killeen",
    "lat": "31.11712",
    "lng": "-97.7278"
  },
  {
    "country": "US",
    "name": "Kingsland",
    "lat": "30.65824",
    "lng": "-98.44058"
  },
  {
    "country": "US",
    "name": "Kingsville",
    "lat": "27.51587",
    "lng": "-97.85611"
  },
  {
    "country": "US",
    "name": "Kingwood Area",
    "lat": "30.03355",
    "lng": "-95.26104"
  },
  {
    "country": "US",
    "name": "Kirby",
    "lat": "29.46329",
    "lng": "-98.38557"
  },
  {
    "country": "US",
    "name": "Kirbyville",
    "lat": "30.66048",
    "lng": "-93.89268"
  },
  {
    "country": "US",
    "name": "Knox City",
    "lat": "33.41815",
    "lng": "-99.81898"
  },
  {
    "country": "US",
    "name": "Kountze",
    "lat": "30.3716",
    "lng": "-94.31241"
  },
  {
    "country": "US",
    "name": "Krugerville",
    "lat": "33.28151",
    "lng": "-96.99056"
  },
  {
    "country": "US",
    "name": "Krum",
    "lat": "33.26151",
    "lng": "-97.23807"
  },
  {
    "country": "US",
    "name": "Kyle",
    "lat": "29.98911",
    "lng": "-97.87723"
  },
  {
    "country": "US",
    "name": "La Blanca",
    "lat": "26.29285",
    "lng": "-98.03778"
  },
  {
    "country": "US",
    "name": "La Coste",
    "lat": "29.31079",
    "lng": "-98.81003"
  },
  {
    "country": "US",
    "name": "La Feria",
    "lat": "26.15896",
    "lng": "-97.82389"
  },
  {
    "country": "US",
    "name": "La Grange",
    "lat": "29.9055",
    "lng": "-96.87665"
  },
  {
    "country": "US",
    "name": "La Grulla",
    "lat": "26.26951",
    "lng": "-98.64725"
  },
  {
    "country": "US",
    "name": "La Homa",
    "lat": "26.25007",
    "lng": "-98.36363"
  },
  {
    "country": "US",
    "name": "La Joya",
    "lat": "26.24702",
    "lng": "-98.48141"
  },
  {
    "country": "US",
    "name": "La Marque",
    "lat": "29.36857",
    "lng": "-94.97131"
  },
  {
    "country": "US",
    "name": "La Paloma",
    "lat": "26.04591",
    "lng": "-97.66749"
  },
  {
    "country": "US",
    "name": "La Porte",
    "lat": "29.66578",
    "lng": "-95.01937"
  },
  {
    "country": "US",
    "name": "La Pryor",
    "lat": "28.94108",
    "lng": "-99.84978"
  },
  {
    "country": "US",
    "name": "La Vernia",
    "lat": "29.35635",
    "lng": "-98.11556"
  },
  {
    "country": "US",
    "name": "La Villa",
    "lat": "26.29868",
    "lng": "-97.92861"
  },
  {
    "country": "US",
    "name": "Lacy-Lakeview",
    "lat": "31.62933",
    "lng": "-97.10278"
  },
  {
    "country": "US",
    "name": "Lago Vista",
    "lat": "30.4602",
    "lng": "-97.98835"
  },
  {
    "country": "US",
    "name": "Laguna Heights",
    "lat": "26.08008",
    "lng": "-97.25386"
  },
  {
    "country": "US",
    "name": "Laguna Park",
    "lat": "31.85932",
    "lng": "-97.37974"
  },
  {
    "country": "US",
    "name": "Laguna Vista",
    "lat": "26.10091",
    "lng": "-97.29025"
  },
  {
    "country": "US",
    "name": "Lake Brownwood",
    "lat": "31.8357",
    "lng": "-99.00783"
  },
  {
    "country": "US",
    "name": "Lake Dallas",
    "lat": "33.11929",
    "lng": "-97.02556"
  },
  {
    "country": "US",
    "name": "Lake Jackson",
    "lat": "29.03386",
    "lng": "-95.43439"
  },
  {
    "country": "US",
    "name": "Lake Kiowa",
    "lat": "33.57705",
    "lng": "-97.01306"
  },
  {
    "country": "US",
    "name": "Lake Dunlap",
    "lat": "29.67578",
    "lng": "-98.07223"
  },
  {
    "country": "US",
    "name": "Lake Worth",
    "lat": "32.80485",
    "lng": "-97.44502"
  },
  {
    "country": "US",
    "name": "Lakehills",
    "lat": "29.60467",
    "lng": "-98.94309"
  },
  {
    "country": "US",
    "name": "Lakeside",
    "lat": "32.82235",
    "lng": "-97.49335"
  },
  {
    "country": "US",
    "name": "Lakeway",
    "lat": "30.36377",
    "lng": "-97.97959"
  },
  {
    "country": "US",
    "name": "Lampasas",
    "lat": "31.06378",
    "lng": "-98.1817"
  },
  {
    "country": "US",
    "name": "Lancaster",
    "lat": "32.59208",
    "lng": "-96.75611"
  },
  {
    "country": "US",
    "name": "Laredo",
    "lat": "27.50641",
    "lng": "-99.50754"
  },
  {
    "country": "US",
    "name": "Las Lomas",
    "lat": "26.36479",
    "lng": "-98.7753"
  },
  {
    "country": "US",
    "name": "Lasara",
    "lat": "26.46479",
    "lng": "-97.91111"
  },
  {
    "country": "US",
    "name": "Laureles",
    "lat": "26.10924",
    "lng": "-97.49415"
  },
  {
    "country": "US",
    "name": "Lavon",
    "lat": "33.02762",
    "lng": "-96.43415"
  },
  {
    "country": "US",
    "name": "League City",
    "lat": "29.50745",
    "lng": "-95.09493"
  },
  {
    "country": "US",
    "name": "Leakey",
    "lat": "29.72884",
    "lng": "-99.76145"
  },
  {
    "country": "US",
    "name": "Leander",
    "lat": "30.57881",
    "lng": "-97.85307"
  },
  {
    "country": "US",
    "name": "Leon Valley",
    "lat": "29.49523",
    "lng": "-98.61863"
  },
  {
    "country": "US",
    "name": "Leonard",
    "lat": "33.37955",
    "lng": "-96.24748"
  },
  {
    "country": "US",
    "name": "Lewisville",
    "lat": "33.04623",
    "lng": "-96.99417"
  },
  {
    "country": "US",
    "name": "Lexington",
    "lat": "30.4191",
    "lng": "-97.01165"
  },
  {
    "country": "US",
    "name": "Liberty",
    "lat": "30.05799",
    "lng": "-94.79548"
  },
  {
    "country": "US",
    "name": "Liberty City",
    "lat": "32.44543",
    "lng": "-94.94855"
  },
  {
    "country": "US",
    "name": "Liberty Hill",
    "lat": "30.66491",
    "lng": "-97.92252"
  },
  {
    "country": "US",
    "name": "Lindale",
    "lat": "32.5157",
    "lng": "-95.4094"
  },
  {
    "country": "US",
    "name": "Linden",
    "lat": "33.01235",
    "lng": "-94.36547"
  },
  {
    "country": "US",
    "name": "Lindsay",
    "lat": "33.63594",
    "lng": "-97.22279"
  },
  {
    "country": "US",
    "name": "Little Elm",
    "lat": "33.16262",
    "lng": "-96.93751"
  },
  {
    "country": "US",
    "name": "Little River-Academy",
    "lat": "30.98629",
    "lng": "-97.35861"
  },
  {
    "country": "US",
    "name": "Live Oak",
    "lat": "29.56523",
    "lng": "-98.3364"
  },
  {
    "country": "US",
    "name": "Livingston",
    "lat": "30.71103",
    "lng": "-94.93299"
  },
  {
    "country": "US",
    "name": "Llano",
    "lat": "30.75935",
    "lng": "-98.67504"
  },
  {
    "country": "US",
    "name": "Llano Grande",
    "lat": "26.1298",
    "lng": "-97.96806"
  },
  {
    "country": "US",
    "name": "Lockhart",
    "lat": "29.88494",
    "lng": "-97.67"
  },
  {
    "country": "US",
    "name": "Lone Star",
    "lat": "33.78566",
    "lng": "-95.38773"
  },
  {
    "country": "US",
    "name": "Lone Star",
    "lat": "32.94402",
    "lng": "-94.70715"
  },
  {
    "country": "US",
    "name": "Longview",
    "lat": "32.5007",
    "lng": "-94.74049"
  },
  {
    "country": "US",
    "name": "Lopezville",
    "lat": "26.23813",
    "lng": "-98.15973"
  },
  {
    "country": "US",
    "name": "Lorena",
    "lat": "31.38656",
    "lng": "-97.21556"
  },
  {
    "country": "US",
    "name": "Los Fresnos",
    "lat": "26.07174",
    "lng": "-97.47637"
  },
  {
    "country": "US",
    "name": "Los Indios",
    "lat": "26.04924",
    "lng": "-97.74499"
  },
  {
    "country": "US",
    "name": "Lost Creek",
    "lat": "30.29548",
    "lng": "-97.84445"
  },
  {
    "country": "US",
    "name": "Lowry Crossing",
    "lat": "33.15484",
    "lng": "-96.54721"
  },
  {
    "country": "US",
    "name": "Lucas",
    "lat": "33.08429",
    "lng": "-96.57666"
  },
  {
    "country": "US",
    "name": "Lufkin",
    "lat": "31.33824",
    "lng": "-94.7291"
  },
  {
    "country": "US",
    "name": "Luling",
    "lat": "29.68051",
    "lng": "-97.6475"
  },
  {
    "country": "US",
    "name": "Lumberton",
    "lat": "30.26577",
    "lng": "-94.19963"
  },
  {
    "country": "US",
    "name": "Lyford",
    "lat": "26.41229",
    "lng": "-97.78972"
  },
  {
    "country": "US",
    "name": "Lytle",
    "lat": "29.23329",
    "lng": "-98.79641"
  },
  {
    "country": "US",
    "name": "Mabank",
    "lat": "32.36653",
    "lng": "-96.10081"
  },
  {
    "country": "US",
    "name": "Madisonville",
    "lat": "30.94991",
    "lng": "-95.91162"
  },
  {
    "country": "US",
    "name": "Magnolia",
    "lat": "30.20938",
    "lng": "-95.75078"
  },
  {
    "country": "US",
    "name": "Malakoff",
    "lat": "32.1696",
    "lng": "-96.01247"
  },
  {
    "country": "US",
    "name": "Manchaca",
    "lat": "30.14077",
    "lng": "-97.83306"
  },
  {
    "country": "US",
    "name": "Manor",
    "lat": "30.34076",
    "lng": "-97.55695"
  },
  {
    "country": "US",
    "name": "Mansfield",
    "lat": "32.56319",
    "lng": "-97.14168"
  },
  {
    "country": "US",
    "name": "Manvel",
    "lat": "29.46274",
    "lng": "-95.35799"
  },
  {
    "country": "US",
    "name": "Marble Falls",
    "lat": "30.57841",
    "lng": "-98.27507"
  },
  {
    "country": "US",
    "name": "Marion",
    "lat": "29.57134",
    "lng": "-98.14029"
  },
  {
    "country": "US",
    "name": "Markham",
    "lat": "28.96026",
    "lng": "-96.06524"
  },
  {
    "country": "US",
    "name": "Marlin",
    "lat": "31.30629",
    "lng": "-96.89804"
  },
  {
    "country": "US",
    "name": "Marshall",
    "lat": "32.54487",
    "lng": "-94.36742"
  },
  {
    "country": "US",
    "name": "Mart",
    "lat": "31.54239",
    "lng": "-96.8336"
  },
  {
    "country": "US",
    "name": "Martindale",
    "lat": "29.8455",
    "lng": "-97.84084"
  },
  {
    "country": "US",
    "name": "Mason",
    "lat": "30.74879",
    "lng": "-99.23061"
  },
  {
    "country": "US",
    "name": "Mathis",
    "lat": "28.09446",
    "lng": "-97.82805"
  },
  {
    "country": "US",
    "name": "Maud",
    "lat": "33.3329",
    "lng": "-94.3427"
  },
  {
    "country": "US",
    "name": "Mauriceville",
    "lat": "30.20354",
    "lng": "-93.86628"
  },
  {
    "country": "US",
    "name": "McAllen",
    "lat": "26.20341",
    "lng": "-98.23001"
  },
  {
    "country": "US",
    "name": "McGregor",
    "lat": "31.44406",
    "lng": "-97.40918"
  },
  {
    "country": "US",
    "name": "McKinney",
    "lat": "33.19762",
    "lng": "-96.61527"
  },
  {
    "country": "US",
    "name": "McLendon-Chisholm",
    "lat": "32.84235",
    "lng": "-96.38054"
  },
  {
    "country": "US",
    "name": "McQueeney",
    "lat": "29.59217",
    "lng": "-98.03334"
  },
  {
    "country": "US",
    "name": "Meadowlakes",
    "lat": "30.56245",
    "lng": "-98.29867"
  },
  {
    "country": "US",
    "name": "Meadows Place",
    "lat": "29.65134",
    "lng": "-95.588"
  },
  {
    "country": "US",
    "name": "Medina",
    "lat": "29.79661",
    "lng": "-99.24643"
  },
  {
    "country": "US",
    "name": "Medina",
    "lat": "26.92115",
    "lng": "-99.25948"
  },
  {
    "country": "US",
    "name": "Melissa",
    "lat": "33.28595",
    "lng": "-96.57277"
  },
  {
    "country": "US",
    "name": "Menard",
    "lat": "30.91767",
    "lng": "-99.78646"
  },
  {
    "country": "US",
    "name": "Mercedes",
    "lat": "26.1498",
    "lng": "-97.91361"
  },
  {
    "country": "US",
    "name": "Meridian",
    "lat": "31.92321",
    "lng": "-97.65669"
  },
  {
    "country": "US",
    "name": "Mesquite",
    "lat": "32.7668",
    "lng": "-96.59916"
  },
  {
    "country": "US",
    "name": "Mexia",
    "lat": "31.67989",
    "lng": "-96.4822"
  },
  {
    "country": "US",
    "name": "Midlothian",
    "lat": "32.48236",
    "lng": "-96.99445"
  },
  {
    "country": "US",
    "name": "Midway North",
    "lat": "26.18776",
    "lng": "-98.01708"
  },
  {
    "country": "US",
    "name": "Midway South",
    "lat": "26.15694",
    "lng": "-98.02011"
  },
  {
    "country": "US",
    "name": "Mila Doce",
    "lat": "26.22618",
    "lng": "-97.95889"
  },
  {
    "country": "US",
    "name": "Milam",
    "lat": "31.4324",
    "lng": "-93.84574"
  },
  {
    "country": "US",
    "name": "Mineola",
    "lat": "32.66319",
    "lng": "-95.48829"
  },
  {
    "country": "US",
    "name": "Mineral Wells",
    "lat": "32.80846",
    "lng": "-98.11282"
  },
  {
    "country": "US",
    "name": "Mission",
    "lat": "26.21591",
    "lng": "-98.32529"
  },
  {
    "country": "US",
    "name": "Mission Bend",
    "lat": "29.69384",
    "lng": "-95.66495"
  },
  {
    "country": "US",
    "name": "Missouri City",
    "lat": "29.61857",
    "lng": "-95.53772"
  },
  {
    "country": "US",
    "name": "Mont Belvieu",
    "lat": "29.84772",
    "lng": "-94.89076"
  },
  {
    "country": "US",
    "name": "Montague",
    "lat": "33.66483",
    "lng": "-97.72059"
  },
  {
    "country": "US",
    "name": "Monte Alto",
    "lat": "26.37312",
    "lng": "-97.97167"
  },
  {
    "country": "US",
    "name": "Moody",
    "lat": "31.30823",
    "lng": "-97.3614"
  },
  {
    "country": "US",
    "name": "Morgans Point Resort",
    "lat": "31.14823",
    "lng": "-97.46334"
  },
  {
    "country": "US",
    "name": "Mount Pleasant",
    "lat": "33.15679",
    "lng": "-94.96827"
  },
  {
    "country": "US",
    "name": "Mount Vernon",
    "lat": "33.18873",
    "lng": "-95.22133"
  },
  {
    "country": "US",
    "name": "Muenster",
    "lat": "33.65177",
    "lng": "-97.37641"
  },
  {
    "country": "US",
    "name": "Munday",
    "lat": "33.44926",
    "lng": "-99.62286"
  },
  {
    "country": "US",
    "name": "Muniz",
    "lat": "26.25646",
    "lng": "-98.08945"
  },
  {
    "country": "US",
    "name": "Murillo Colonia",
    "lat": "26.25646",
    "lng": "-98.11334"
  },
  {
    "country": "US",
    "name": "Murphy",
    "lat": "33.01512",
    "lng": "-96.61305"
  },
  {
    "country": "US",
    "name": "Nacogdoches",
    "lat": "31.60351",
    "lng": "-94.65549"
  },
  {
    "country": "US",
    "name": "Naples",
    "lat": "33.20318",
    "lng": "-94.68021"
  },
  {
    "country": "US",
    "name": "Nash",
    "lat": "33.44235",
    "lng": "-94.13075"
  },
  {
    "country": "US",
    "name": "Nash",
    "lat": "32.2657",
    "lng": "-96.81277"
  },
  {
    "country": "US",
    "name": "Nassau Bay",
    "lat": "29.54468",
    "lng": "-95.09104"
  },
  {
    "country": "US",
    "name": "Navasota",
    "lat": "30.38798",
    "lng": "-96.08773"
  },
  {
    "country": "US",
    "name": "Nederland",
    "lat": "29.97438",
    "lng": "-93.9924"
  },
  {
    "country": "US",
    "name": "Needville",
    "lat": "29.39941",
    "lng": "-95.83773"
  },
  {
    "country": "US",
    "name": "Nevada",
    "lat": "33.04234",
    "lng": "-96.37387"
  },
  {
    "country": "US",
    "name": "New Boston",
    "lat": "33.45984",
    "lng": "-94.41548"
  },
  {
    "country": "US",
    "name": "New Braunfels",
    "lat": "29.703",
    "lng": "-98.12445"
  },
  {
    "country": "US",
    "name": "New Summerfield",
    "lat": "31.98072",
    "lng": "-95.09383"
  },
  {
    "country": "US",
    "name": "New Territory",
    "lat": "29.59412",
    "lng": "-95.68078"
  },
  {
    "country": "US",
    "name": "New Waverly",
    "lat": "30.5377",
    "lng": "-95.48328"
  },
  {
    "country": "US",
    "name": "Newark",
    "lat": "33.00124",
    "lng": "-97.48447"
  },
  {
    "country": "US",
    "name": "Newton",
    "lat": "30.84853",
    "lng": "-93.7574"
  },
  {
    "country": "US",
    "name": "Nixon",
    "lat": "29.26746",
    "lng": "-97.76444"
  },
  {
    "country": "US",
    "name": "Nocona",
    "lat": "33.78677",
    "lng": "-97.72586"
  },
  {
    "country": "US",
    "name": "Nolanville",
    "lat": "31.07879",
    "lng": "-97.60557"
  },
  {
    "country": "US",
    "name": "North Alamo",
    "lat": "26.2173",
    "lng": "-98.1289"
  },
  {
    "country": "US",
    "name": "North Richland Hills",
    "lat": "32.8343",
    "lng": "-97.2289"
  },
  {
    "country": "US",
    "name": "Northcliff",
    "lat": "29.62106",
    "lng": "-98.22473"
  },
  {
    "country": "US",
    "name": "Northcrest",
    "lat": "31.63655",
    "lng": "-97.09972"
  },
  {
    "country": "US",
    "name": "Northlake",
    "lat": "33.12734",
    "lng": "-97.26557"
  },
  {
    "country": "US",
    "name": "Nurillo",
    "lat": "26.26702",
    "lng": "-98.1214"
  },
  {
    "country": "US",
    "name": "Oak Leaf",
    "lat": "32.52042",
    "lng": "-96.85472"
  },
  {
    "country": "US",
    "name": "Oak Point",
    "lat": "33.19012",
    "lng": "-96.99167"
  },
  {
    "country": "US",
    "name": "Oak Ridge North",
    "lat": "30.16022",
    "lng": "-95.44438"
  },
  {
    "country": "US",
    "name": "Oak Trail Shores",
    "lat": "32.48875",
    "lng": "-97.8342"
  },
  {
    "country": "US",
    "name": "Odem",
    "lat": "27.95057",
    "lng": "-97.58222"
  },
  {
    "country": "US",
    "name": "Old River-Winfree",
    "lat": "29.86828",
    "lng": "-94.8327"
  },
  {
    "country": "US",
    "name": "Olivarez",
    "lat": "26.22841",
    "lng": "-97.99223"
  },
  {
    "country": "US",
    "name": "Olmito",
    "lat": "26.02174",
    "lng": "-97.53415"
  },
  {
    "country": "US",
    "name": "Olmos Park",
    "lat": "29.47884",
    "lng": "-98.48752"
  },
  {
    "country": "US",
    "name": "Olney",
    "lat": "33.37066",
    "lng": "-98.75284"
  },
  {
    "country": "US",
    "name": "Onalaska",
    "lat": "30.80575",
    "lng": "-95.11633"
  },
  {
    "country": "US",
    "name": "Onion Creek",
    "lat": "30.1366",
    "lng": "-97.78417"
  },
  {
    "country": "US",
    "name": "Orange",
    "lat": "30.09299",
    "lng": "-93.73655"
  },
  {
    "country": "US",
    "name": "Orange Grove",
    "lat": "27.95668",
    "lng": "-97.93694"
  },
  {
    "country": "US",
    "name": "Ore City",
    "lat": "32.80014",
    "lng": "-94.72076"
  },
  {
    "country": "US",
    "name": "Overton",
    "lat": "32.2746",
    "lng": "-94.97855"
  },
  {
    "country": "US",
    "name": "Ovilla",
    "lat": "32.52653",
    "lng": "-96.88639"
  },
  {
    "country": "US",
    "name": "Oyster Creek",
    "lat": "29.00302",
    "lng": "-95.33188"
  },
  {
    "country": "US",
    "name": "Paint Rock",
    "lat": "31.50849",
    "lng": "-99.92008"
  },
  {
    "country": "US",
    "name": "Palacios",
    "lat": "28.70805",
    "lng": "-96.21747"
  },
  {
    "country": "US",
    "name": "Palestine",
    "lat": "31.76212",
    "lng": "-95.63079"
  },
  {
    "country": "US",
    "name": "Palm Valley",
    "lat": "26.20174",
    "lng": "-97.75416"
  },
  {
    "country": "US",
    "name": "Palmer",
    "lat": "32.43125",
    "lng": "-96.66777"
  },
  {
    "country": "US",
    "name": "Palmhurst",
    "lat": "26.25841",
    "lng": "-98.31807"
  },
  {
    "country": "US",
    "name": "Palmview",
    "lat": "26.23341",
    "lng": "-98.37085"
  },
  {
    "country": "US",
    "name": "Palmview South",
    "lat": "26.21563",
    "lng": "-98.37863"
  },
  {
    "country": "US",
    "name": "Palo Pinto",
    "lat": "32.76735",
    "lng": "-98.29866"
  },
  {
    "country": "US",
    "name": "Panorama Village",
    "lat": "30.38104",
    "lng": "-95.49355"
  },
  {
    "country": "US",
    "name": "Pantego",
    "lat": "32.7143",
    "lng": "-97.1564"
  },
  {
    "country": "US",
    "name": "Paris",
    "lat": "33.66094",
    "lng": "-95.55551"
  },
  {
    "country": "US",
    "name": "Parker",
    "lat": "33.0554",
    "lng": "-96.62194"
  },
  {
    "country": "US",
    "name": "Pasadena",
    "lat": "29.69106",
    "lng": "-95.2091"
  },
  {
    "country": "US",
    "name": "Patton Village",
    "lat": "30.19299",
    "lng": "-95.16882"
  },
  {
    "country": "US",
    "name": "Pearland",
    "lat": "29.56357",
    "lng": "-95.28605"
  },
  {
    "country": "US",
    "name": "Pearsall",
    "lat": "28.89219",
    "lng": "-99.09503"
  },
  {
    "country": "US",
    "name": "Pecan Acres",
    "lat": "32.97013",
    "lng": "-97.47474"
  },
  {
    "country": "US",
    "name": "Pecan Grove",
    "lat": "29.62607",
    "lng": "-95.73162"
  },
  {
    "country": "US",
    "name": "Pecan Plantation",
    "lat": "32.36042",
    "lng": "-97.67558"
  },
  {
    "country": "US",
    "name": "Pelican Bay",
    "lat": "32.92096",
    "lng": "-97.51836"
  },
  {
    "country": "US",
    "name": "Penitas",
    "lat": "26.23063",
    "lng": "-98.44474"
  },
  {
    "country": "US",
    "name": "Perezville",
    "lat": "26.22452",
    "lng": "-98.40057"
  },
  {
    "country": "US",
    "name": "Pflugerville",
    "lat": "30.43937",
    "lng": "-97.62"
  },
  {
    "country": "US",
    "name": "Pharr",
    "lat": "26.1948",
    "lng": "-98.18362"
  },
  {
    "country": "US",
    "name": "Pilot Point",
    "lat": "33.3965",
    "lng": "-96.96056"
  },
  {
    "country": "US",
    "name": "Pine Island",
    "lat": "30.058",
    "lng": "-96.03746"
  },
  {
    "country": "US",
    "name": "Pinehurst",
    "lat": "30.17105",
    "lng": "-95.68245"
  },
  {
    "country": "US",
    "name": "Pinehurst",
    "lat": "30.10715",
    "lng": "-93.77461"
  },
  {
    "country": "US",
    "name": "Pinewood Estates",
    "lat": "30.16438",
    "lng": "-94.32158"
  },
  {
    "country": "US",
    "name": "Piney Point Village",
    "lat": "29.75995",
    "lng": "-95.51716"
  },
  {
    "country": "US",
    "name": "Pittsburg",
    "lat": "32.9954",
    "lng": "-94.96577"
  },
  {
    "country": "US",
    "name": "Plano",
    "lat": "33.01984",
    "lng": "-96.69889"
  },
  {
    "country": "US",
    "name": "Pleak",
    "lat": "29.48913",
    "lng": "-95.80773"
  },
  {
    "country": "US",
    "name": "Pleasanton",
    "lat": "28.96719",
    "lng": "-98.47863"
  },
  {
    "country": "US",
    "name": "Plum Grove",
    "lat": "32.1957",
    "lng": "-96.98945"
  },
  {
    "country": "US",
    "name": "Ponder",
    "lat": "33.1829",
    "lng": "-97.28724"
  },
  {
    "country": "US",
    "name": "Port Aransas",
    "lat": "27.83392",
    "lng": "-97.0611"
  },
  {
    "country": "US",
    "name": "Port Arthur",
    "lat": "29.88519",
    "lng": "-93.94233"
  },
  {
    "country": "US",
    "name": "Port Isabel",
    "lat": "26.07341",
    "lng": "-97.20858"
  },
  {
    "country": "US",
    "name": "Port Lavaca",
    "lat": "28.615",
    "lng": "-96.62609"
  },
  {
    "country": "US",
    "name": "Port Neches",
    "lat": "29.99132",
    "lng": "-93.95851"
  },
  {
    "country": "US",
    "name": "Port O'Connor",
    "lat": "28.44834",
    "lng": "-96.40581"
  },
  {
    "country": "US",
    "name": "Porter Heights",
    "lat": "30.15188",
    "lng": "-95.32188"
  },
  {
    "country": "US",
    "name": "Portland",
    "lat": "27.87725",
    "lng": "-97.32388"
  },
  {
    "country": "US",
    "name": "Poteet",
    "lat": "29.04052",
    "lng": "-98.56807"
  },
  {
    "country": "US",
    "name": "Poth",
    "lat": "29.06969",
    "lng": "-98.08195"
  },
  {
    "country": "US",
    "name": "Potosi",
    "lat": "32.3293",
    "lng": "-99.65647"
  },
  {
    "country": "US",
    "name": "Pottsboro",
    "lat": "33.75927",
    "lng": "-96.66944"
  },
  {
    "country": "US",
    "name": "Powderly",
    "lat": "33.81122",
    "lng": "-95.5244"
  },
  {
    "country": "US",
    "name": "Prairie View",
    "lat": "30.09327",
    "lng": "-95.98773"
  },
  {
    "country": "US",
    "name": "Premont",
    "lat": "27.36059",
    "lng": "-98.12362"
  },
  {
    "country": "US",
    "name": "Preston",
    "lat": "33.88232",
    "lng": "-96.63305"
  },
  {
    "country": "US",
    "name": "Primera",
    "lat": "26.22591",
    "lng": "-97.75805"
  },
  {
    "country": "US",
    "name": "Princeton",
    "lat": "33.18012",
    "lng": "-96.49804"
  },
  {
    "country": "US",
    "name": "Progreso",
    "lat": "26.0923",
    "lng": "-97.95722"
  },
  {
    "country": "US",
    "name": "Prosper",
    "lat": "33.23623",
    "lng": "-96.80111"
  },
  {
    "country": "US",
    "name": "Quanah",
    "lat": "34.29785",
    "lng": "-99.74037"
  },
  {
    "country": "US",
    "name": "Queen City",
    "lat": "33.14874",
    "lng": "-94.15019"
  },
  {
    "country": "US",
    "name": "Quinlan",
    "lat": "32.9104",
    "lng": "-96.13553"
  },
  {
    "country": "US",
    "name": "Quitman",
    "lat": "32.79596",
    "lng": "-95.45106"
  },
  {
    "country": "US",
    "name": "Rancho Alegre",
    "lat": "27.74169",
    "lng": "-98.09473"
  },
  {
    "country": "US",
    "name": "Rancho Viejo",
    "lat": "26.03952",
    "lng": "-97.55638"
  },
  {
    "country": "US",
    "name": "Ranger",
    "lat": "32.46985",
    "lng": "-98.67895"
  },
  {
    "country": "US",
    "name": "Raymondville",
    "lat": "26.48146",
    "lng": "-97.78305"
  },
  {
    "country": "US",
    "name": "Red Lick",
    "lat": "33.46485",
    "lng": "-94.17103"
  },
  {
    "country": "US",
    "name": "Red Oak",
    "lat": "32.51764",
    "lng": "-96.80444"
  },
  {
    "country": "US",
    "name": "Redland",
    "lat": "31.40435",
    "lng": "-94.72132"
  },
  {
    "country": "US",
    "name": "Redwater",
    "lat": "33.35818",
    "lng": "-94.25436"
  },
  {
    "country": "US",
    "name": "Redwood",
    "lat": "29.81022",
    "lng": "-97.91139"
  },
  {
    "country": "US",
    "name": "Refugio",
    "lat": "28.30528",
    "lng": "-97.27527"
  },
  {
    "country": "US",
    "name": "Rendon",
    "lat": "32.57625",
    "lng": "-97.2414"
  },
  {
    "country": "US",
    "name": "Reno",
    "lat": "33.66316",
    "lng": "-95.46245"
  },
  {
    "country": "US",
    "name": "Reno",
    "lat": "32.94429",
    "lng": "-97.57725"
  },
  {
    "country": "US",
    "name": "Rhome",
    "lat": "33.05346",
    "lng": "-97.47197"
  },
  {
    "country": "US",
    "name": "Ricardo",
    "lat": "27.42143",
    "lng": "-97.85111"
  },
  {
    "country": "US",
    "name": "Richardson",
    "lat": "32.94818",
    "lng": "-96.72972"
  },
  {
    "country": "US",
    "name": "Richland Hills",
    "lat": "32.81596",
    "lng": "-97.22807"
  },
  {
    "country": "US",
    "name": "Richmond",
    "lat": "29.58218",
    "lng": "-95.76078"
  },
  {
    "country": "US",
    "name": "Richwood",
    "lat": "29.05608",
    "lng": "-95.40994"
  },
  {
    "country": "US",
    "name": "Riesel",
    "lat": "31.47489",
    "lng": "-96.92333"
  },
  {
    "country": "US",
    "name": "Rio Bravo",
    "lat": "27.36419",
    "lng": "-99.48004"
  },
  {
    "country": "US",
    "name": "Rio Grande City",
    "lat": "26.37979",
    "lng": "-98.8203"
  },
  {
    "country": "US",
    "name": "Rio Hondo",
    "lat": "26.23535",
    "lng": "-97.58193"
  },
  {
    "country": "US",
    "name": "River Oaks",
    "lat": "32.77707",
    "lng": "-97.39446"
  },
  {
    "country": "US",
    "name": "Roanoke",
    "lat": "33.00401",
    "lng": "-97.22585"
  },
  {
    "country": "US",
    "name": "Robinson",
    "lat": "31.46767",
    "lng": "-97.11472"
  },
  {
    "country": "US",
    "name": "Robstown",
    "lat": "27.7903",
    "lng": "-97.66888"
  },
  {
    "country": "US",
    "name": "Rockdale",
    "lat": "30.65548",
    "lng": "-97.00137"
  },
  {
    "country": "US",
    "name": "Rockwall",
    "lat": "32.93123",
    "lng": "-96.45971"
  },
  {
    "country": "US",
    "name": "Rockport",
    "lat": "28.02077",
    "lng": "-97.05601"
  },
  {
    "country": "US",
    "name": "Rogers",
    "lat": "30.93157",
    "lng": "-97.22666"
  },
  {
    "country": "US",
    "name": "Rollingwood",
    "lat": "30.27687",
    "lng": "-97.79112"
  },
  {
    "country": "US",
    "name": "Roman Forest",
    "lat": "30.1791",
    "lng": "-95.16243"
  },
  {
    "country": "US",
    "name": "Roma-Los Saenz",
    "lat": "26.40506",
    "lng": "-99.01586"
  },
  {
    "country": "US",
    "name": "Rosebud",
    "lat": "31.07296",
    "lng": "-96.9786"
  },
  {
    "country": "US",
    "name": "Rosenberg",
    "lat": "29.55718",
    "lng": "-95.80856"
  },
  {
    "country": "US",
    "name": "Rosharon",
    "lat": "29.35218",
    "lng": "-95.46022"
  },
  {
    "country": "US",
    "name": "Round Rock",
    "lat": "30.50826",
    "lng": "-97.6789"
  },
  {
    "country": "US",
    "name": "Rowlett",
    "lat": "32.9029",
    "lng": "-96.56388"
  },
  {
    "country": "US",
    "name": "Royse City",
    "lat": "32.97512",
    "lng": "-96.33248"
  },
  {
    "country": "US",
    "name": "Runaway Bay",
    "lat": "33.16789",
    "lng": "-97.87837"
  },
  {
    "country": "US",
    "name": "Runge",
    "lat": "28.88331",
    "lng": "-97.71305"
  },
  {
    "country": "US",
    "name": "Rusk",
    "lat": "31.79601",
    "lng": "-95.15022"
  },
  {
    "country": "US",
    "name": "Sabinal",
    "lat": "29.31746",
    "lng": "-99.46644"
  },
  {
    "country": "US",
    "name": "Sachse",
    "lat": "32.97623",
    "lng": "-96.59527"
  },
  {
    "country": "US",
    "name": "Saginaw",
    "lat": "32.86013",
    "lng": "-97.36391"
  },
  {
    "country": "US",
    "name": "Saint Hedwig",
    "lat": "29.4144",
    "lng": "-98.20001"
  },
  {
    "country": "US",
    "name": "Saint Jo",
    "lat": "33.69483",
    "lng": "-97.52252"
  },
  {
    "country": "US",
    "name": "Saint Paul",
    "lat": "33.04123",
    "lng": "-96.55027"
  },
  {
    "country": "US",
    "name": "Salado",
    "lat": "30.94713",
    "lng": "-97.53862"
  },
  {
    "country": "US",
    "name": "Sam Rayburn",
    "lat": "31.06408",
    "lng": "-94.03575"
  },
  {
    "country": "US",
    "name": "San Antonio",
    "lat": "29.42412",
    "lng": "-98.49363"
  },
  {
    "country": "US",
    "name": "San Augustine",
    "lat": "31.5299",
    "lng": "-94.10603"
  },
  {
    "country": "US",
    "name": "San Benito",
    "lat": "26.13258",
    "lng": "-97.6311"
  },
  {
    "country": "US",
    "name": "San Carlos",
    "lat": "26.29563",
    "lng": "-98.07195"
  },
  {
    "country": "US",
    "name": "San Diego",
    "lat": "27.76391",
    "lng": "-98.2389"
  },
  {
    "country": "US",
    "name": "San Juan",
    "lat": "26.18924",
    "lng": "-98.15529"
  },
  {
    "country": "US",
    "name": "San Leon",
    "lat": "29.48329",
    "lng": "-94.92215"
  },
  {
    "country": "US",
    "name": "San Marcos",
    "lat": "29.88327",
    "lng": "-97.94139"
  },
  {
    "country": "US",
    "name": "San Saba",
    "lat": "31.19572",
    "lng": "-98.7181"
  },
  {
    "country": "US",
    "name": "Sanger",
    "lat": "33.36317",
    "lng": "-97.1739"
  },
  {
    "country": "US",
    "name": "Sansom Park",
    "lat": "32.80596",
    "lng": "-97.40307"
  },
  {
    "country": "US",
    "name": "Santa Anna",
    "lat": "31.74209",
    "lng": "-99.32173"
  },
  {
    "country": "US",
    "name": "Santa Fe",
    "lat": "29.37801",
    "lng": "-95.10576"
  },
  {
    "country": "US",
    "name": "Santa Rosa",
    "lat": "26.25674",
    "lng": "-97.825"
  },
  {
    "country": "US",
    "name": "Sarita",
    "lat": "27.22171",
    "lng": "-97.78916"
  },
  {
    "country": "US",
    "name": "Scenic Oaks",
    "lat": "29.71078",
    "lng": "-98.67586"
  },
  {
    "country": "US",
    "name": "Schertz",
    "lat": "29.55217",
    "lng": "-98.26973"
  },
  {
    "country": "US",
    "name": "Schulenburg",
    "lat": "29.6819",
    "lng": "-96.90304"
  },
  {
    "country": "US",
    "name": "Scissors",
    "lat": "26.1398",
    "lng": "-98.05389"
  },
  {
    "country": "US",
    "name": "Seabrook",
    "lat": "29.56412",
    "lng": "-95.02548"
  },
  {
    "country": "US",
    "name": "Seadrift",
    "lat": "28.41528",
    "lng": "-96.71359"
  },
  {
    "country": "US",
    "name": "Seagoville",
    "lat": "32.63958",
    "lng": "-96.53832"
  },
  {
    "country": "US",
    "name": "Sealy",
    "lat": "29.78079",
    "lng": "-96.15718"
  },
  {
    "country": "US",
    "name": "Sebastian",
    "lat": "26.34285",
    "lng": "-97.79027"
  },
  {
    "country": "US",
    "name": "Seguin",
    "lat": "29.56884",
    "lng": "-97.96473"
  },
  {
    "country": "US",
    "name": "Selma",
    "lat": "29.58439",
    "lng": "-98.30585"
  },
  {
    "country": "US",
    "name": "Serenada",
    "lat": "30.69936",
    "lng": "-97.69195"
  },
  {
    "country": "US",
    "name": "Seven Points",
    "lat": "32.32042",
    "lng": "-96.21303"
  },
  {
    "country": "US",
    "name": "Seymour",
    "lat": "33.59426",
    "lng": "-99.26035"
  },
  {
    "country": "US",
    "name": "Shady Hollow",
    "lat": "30.16493",
    "lng": "-97.86223"
  },
  {
    "country": "US",
    "name": "Shady Shores",
    "lat": "33.16512",
    "lng": "-97.02945"
  },
  {
    "country": "US",
    "name": "Shamrock",
    "lat": "32.5993",
    "lng": "-96.8875"
  },
  {
    "country": "US",
    "name": "Shavano Park",
    "lat": "29.58495",
    "lng": "-98.55252"
  },
  {
    "country": "US",
    "name": "Sheldon",
    "lat": "29.868",
    "lng": "-95.12826"
  },
  {
    "country": "US",
    "name": "Shenandoah",
    "lat": "30.18022",
    "lng": "-95.45577"
  },
  {
    "country": "US",
    "name": "Shepherd",
    "lat": "30.49798",
    "lng": "-94.9966"
  },
  {
    "country": "US",
    "name": "Sherman",
    "lat": "33.63566",
    "lng": "-96.60888"
  },
  {
    "country": "US",
    "name": "Sherwood Shores",
    "lat": "33.85232",
    "lng": "-96.81778"
  },
  {
    "country": "US",
    "name": "Shiner",
    "lat": "29.42913",
    "lng": "-97.17054"
  },
  {
    "country": "US",
    "name": "Shoreacres",
    "lat": "29.62023",
    "lng": "-95.00993"
  },
  {
    "country": "US",
    "name": "Sienna Plantation",
    "lat": "29.48607",
    "lng": "-95.508"
  },
  {
    "country": "US",
    "name": "Siesta Shores",
    "lat": "26.8581",
    "lng": "-99.25365"
  },
  {
    "country": "US",
    "name": "Silsbee",
    "lat": "30.3491",
    "lng": "-94.17796"
  },
  {
    "country": "US",
    "name": "Sinton",
    "lat": "28.03668",
    "lng": "-97.50916"
  },
  {
    "country": "US",
    "name": "Smithville",
    "lat": "30.00855",
    "lng": "-97.15943"
  },
  {
    "country": "US",
    "name": "Somerset",
    "lat": "29.22635",
    "lng": "-98.6578"
  },
  {
    "country": "US",
    "name": "Somerville",
    "lat": "30.34604",
    "lng": "-96.5283"
  },
  {
    "country": "US",
    "name": "Sour Lake",
    "lat": "30.14021",
    "lng": "-94.41102"
  },
  {
    "country": "US",
    "name": "South Alamo",
    "lat": "26.15702",
    "lng": "-98.10862"
  },
  {
    "country": "US",
    "name": "South Houston",
    "lat": "29.66301",
    "lng": "-95.23549"
  },
  {
    "country": "US",
    "name": "South Padre Island",
    "lat": "26.10369",
    "lng": "-97.16469"
  },
  {
    "country": "US",
    "name": "South Point",
    "lat": "25.86869",
    "lng": "-97.38359"
  },
  {
    "country": "US",
    "name": "Southlake",
    "lat": "32.94124",
    "lng": "-97.13418"
  },
  {
    "country": "US",
    "name": "Southmayd",
    "lat": "33.63038",
    "lng": "-96.76916"
  },
  {
    "country": "US",
    "name": "Southside Place",
    "lat": "29.70606",
    "lng": "-95.43688"
  },
  {
    "country": "US",
    "name": "Sparks",
    "lat": "30.92852",
    "lng": "-97.35972"
  },
  {
    "country": "US",
    "name": "Splendora",
    "lat": "30.23299",
    "lng": "-95.16104"
  },
  {
    "country": "US",
    "name": "Spring",
    "lat": "30.07994",
    "lng": "-95.41716"
  },
  {
    "country": "US",
    "name": "Spring Valley",
    "lat": "29.78967",
    "lng": "-95.50355"
  },
  {
    "country": "US",
    "name": "Springtown",
    "lat": "32.96596",
    "lng": "-97.68364"
  },
  {
    "country": "US",
    "name": "Stafford",
    "lat": "29.61607",
    "lng": "-95.55772"
  },
  {
    "country": "US",
    "name": "Stamford",
    "lat": "32.94539",
    "lng": "-99.80287"
  },
  {
    "country": "US",
    "name": "Stephenville",
    "lat": "32.2207",
    "lng": "-98.20226"
  },
  {
    "country": "US",
    "name": "Stockdale",
    "lat": "29.23691",
    "lng": "-97.96"
  },
  {
    "country": "US",
    "name": "Stowell",
    "lat": "29.78994",
    "lng": "-94.38324"
  },
  {
    "country": "US",
    "name": "Sugar Land",
    "lat": "29.61968",
    "lng": "-95.63495"
  },
  {
    "country": "US",
    "name": "Sullivan City",
    "lat": "26.27757",
    "lng": "-98.56363"
  },
  {
    "country": "US",
    "name": "Sulphur Springs",
    "lat": "33.13845",
    "lng": "-95.60107"
  },
  {
    "country": "US",
    "name": "Sunnyvale",
    "lat": "32.79652",
    "lng": "-96.56082"
  },
  {
    "country": "US",
    "name": "Sweeny",
    "lat": "29.03886",
    "lng": "-95.69856"
  },
  {
    "country": "US",
    "name": "Taft",
    "lat": "27.97891",
    "lng": "-97.3986"
  },
  {
    "country": "US",
    "name": "Taft Southwest (historical)",
    "lat": "27.97391",
    "lng": "-97.40305"
  },
  {
    "country": "US",
    "name": "Talty",
    "lat": "32.68319",
    "lng": "-96.38554"
  },
  {
    "country": "US",
    "name": "Tatum",
    "lat": "32.31599",
    "lng": "-94.51659"
  },
  {
    "country": "US",
    "name": "Taylor",
    "lat": "30.57076",
    "lng": "-97.40944"
  },
  {
    "country": "US",
    "name": "Taylor Lake Village",
    "lat": "29.57523",
    "lng": "-95.05021"
  },
  {
    "country": "US",
    "name": "Teague",
    "lat": "31.62711",
    "lng": "-96.28386"
  },
  {
    "country": "US",
    "name": "Tenaha",
    "lat": "31.94378",
    "lng": "-94.24409"
  },
  {
    "country": "US",
    "name": "Temple",
    "lat": "31.09823",
    "lng": "-97.34278"
  },
  {
    "country": "US",
    "name": "Terrell",
    "lat": "32.73596",
    "lng": "-96.27526"
  },
  {
    "country": "US",
    "name": "Terrell Hills",
    "lat": "29.47495",
    "lng": "-98.45085"
  },
  {
    "country": "US",
    "name": "Texarkana",
    "lat": "33.42513",
    "lng": "-94.04769"
  },
  {
    "country": "US",
    "name": "Texas City",
    "lat": "29.38385",
    "lng": "-94.9027"
  },
  {
    "country": "US",
    "name": "The Colony",
    "lat": "33.08901",
    "lng": "-96.88639"
  },
  {
    "country": "US",
    "name": "The Hills",
    "lat": "30.34798",
    "lng": "-97.98501"
  },
  {
    "country": "US",
    "name": "The Woodlands",
    "lat": "30.15799",
    "lng": "-95.48938"
  },
  {
    "country": "US",
    "name": "Thorndale",
    "lat": "30.61381",
    "lng": "-97.20555"
  },
  {
    "country": "US",
    "name": "Three Rivers",
    "lat": "28.46027",
    "lng": "-98.18251"
  },
  {
    "country": "US",
    "name": "Throckmorton",
    "lat": "33.17872",
    "lng": "-99.17758"
  },
  {
    "country": "US",
    "name": "Tilden",
    "lat": "28.46194",
    "lng": "-98.54918"
  },
  {
    "country": "US",
    "name": "Timberwood Park",
    "lat": "29.70578",
    "lng": "-98.47835"
  },
  {
    "country": "US",
    "name": "Timpson",
    "lat": "31.90378",
    "lng": "-94.3952"
  },
  {
    "country": "US",
    "name": "Tom Bean",
    "lat": "33.52011",
    "lng": "-96.48387"
  },
  {
    "country": "US",
    "name": "Tomball",
    "lat": "30.09716",
    "lng": "-95.61605"
  },
  {
    "country": "US",
    "name": "Tool",
    "lat": "32.26792",
    "lng": "-96.17025"
  },
  {
    "country": "US",
    "name": "Trinity",
    "lat": "30.94519",
    "lng": "-95.3755"
  },
  {
    "country": "US",
    "name": "Trophy Club",
    "lat": "32.9979",
    "lng": "-97.18362"
  },
  {
    "country": "US",
    "name": "Troup",
    "lat": "32.1446",
    "lng": "-95.1205"
  },
  {
    "country": "US",
    "name": "Troy",
    "lat": "31.20684",
    "lng": "-97.30278"
  },
  {
    "country": "US",
    "name": "Tye",
    "lat": "32.45762",
    "lng": "-99.87148"
  },
  {
    "country": "US",
    "name": "Tyler",
    "lat": "32.35126",
    "lng": "-95.30106"
  },
  {
    "country": "US",
    "name": "Uhland",
    "lat": "29.95772",
    "lng": "-97.78611"
  },
  {
    "country": "US",
    "name": "Universal City",
    "lat": "29.54801",
    "lng": "-98.29112"
  },
  {
    "country": "US",
    "name": "University Park",
    "lat": "32.85013",
    "lng": "-96.80028"
  },
  {
    "country": "US",
    "name": "Uvalde",
    "lat": "29.20968",
    "lng": "-99.78617"
  },
  {
    "country": "US",
    "name": "Uvalde Estates",
    "lat": "29.16524",
    "lng": "-99.83228"
  },
  {
    "country": "US",
    "name": "Valley Mills",
    "lat": "31.65933",
    "lng": "-97.47224"
  },
  {
    "country": "US",
    "name": "Van",
    "lat": "32.52486",
    "lng": "-95.63718"
  },
  {
    "country": "US",
    "name": "Van Alstyne",
    "lat": "33.4215",
    "lng": "-96.57721"
  },
  {
    "country": "US",
    "name": "Van Vleck",
    "lat": "29.01775",
    "lng": "-95.8894"
  },
  {
    "country": "US",
    "name": "Venus",
    "lat": "32.43347",
    "lng": "-97.10251"
  },
  {
    "country": "US",
    "name": "Vernon",
    "lat": "34.15536",
    "lng": "-99.26628"
  },
  {
    "country": "US",
    "name": "Victoria",
    "lat": "28.80527",
    "lng": "-97.0036"
  },
  {
    "country": "US",
    "name": "Vidor",
    "lat": "30.1316",
    "lng": "-94.01545"
  },
  {
    "country": "US",
    "name": "Von Ormy",
    "lat": "29.28913",
    "lng": "-98.64446"
  },
  {
    "country": "US",
    "name": "Waco",
    "lat": "31.54933",
    "lng": "-97.14667"
  },
  {
    "country": "US",
    "name": "Wake Village",
    "lat": "33.42679",
    "lng": "-94.1063"
  },
  {
    "country": "US",
    "name": "Waller",
    "lat": "30.05661",
    "lng": "-95.9269"
  },
  {
    "country": "US",
    "name": "Waskom",
    "lat": "32.47876",
    "lng": "-94.05963"
  },
  {
    "country": "US",
    "name": "Watauga",
    "lat": "32.85791",
    "lng": "-97.25474"
  },
  {
    "country": "US",
    "name": "Waxahachie",
    "lat": "32.38653",
    "lng": "-96.84833"
  },
  {
    "country": "US",
    "name": "Weatherford",
    "lat": "32.7593",
    "lng": "-97.79725"
  },
  {
    "country": "US",
    "name": "Webster",
    "lat": "29.53773",
    "lng": "-95.11826"
  },
  {
    "country": "US",
    "name": "Weimar",
    "lat": "29.70301",
    "lng": "-96.78053"
  },
  {
    "country": "US",
    "name": "Wells Branch",
    "lat": "30.44604",
    "lng": "-97.67945"
  },
  {
    "country": "US",
    "name": "Weslaco",
    "lat": "26.15952",
    "lng": "-97.99084"
  },
  {
    "country": "US",
    "name": "West",
    "lat": "31.80238",
    "lng": "-97.09167"
  },
  {
    "country": "US",
    "name": "West Columbia",
    "lat": "29.14386",
    "lng": "-95.64522"
  },
  {
    "country": "US",
    "name": "West Lake Hills",
    "lat": "30.29798",
    "lng": "-97.80195"
  },
  {
    "country": "US",
    "name": "West Livingston",
    "lat": "30.69825",
    "lng": "-95.00188"
  },
  {
    "country": "US",
    "name": "West Orange",
    "lat": "30.08215",
    "lng": "-93.75822"
  },
  {
    "country": "US",
    "name": "West Sharyland",
    "lat": "26.27257",
    "lng": "-98.32863"
  },
  {
    "country": "US",
    "name": "West Tawakoni",
    "lat": "32.89373",
    "lng": "-96.02941"
  },
  {
    "country": "US",
    "name": "West University Place",
    "lat": "29.71801",
    "lng": "-95.43383"
  },
  {
    "country": "US",
    "name": "Westlake",
    "lat": "32.99124",
    "lng": "-97.19501"
  },
  {
    "country": "US",
    "name": "Westworth",
    "lat": "32.75735",
    "lng": "-97.41085"
  },
  {
    "country": "US",
    "name": "Wharton",
    "lat": "29.31164",
    "lng": "-96.10274"
  },
  {
    "country": "US",
    "name": "White Oak",
    "lat": "32.52792",
    "lng": "-94.86133"
  },
  {
    "country": "US",
    "name": "White Settlement",
    "lat": "32.75957",
    "lng": "-97.45835"
  },
  {
    "country": "US",
    "name": "Whitehouse",
    "lat": "32.22682",
    "lng": "-95.2255"
  },
  {
    "country": "US",
    "name": "Whitesboro",
    "lat": "33.65622",
    "lng": "-96.90695"
  },
  {
    "country": "US",
    "name": "Whitewright",
    "lat": "33.51289",
    "lng": "-96.39248"
  },
  {
    "country": "US",
    "name": "Whitney",
    "lat": "31.95182",
    "lng": "-97.3214"
  },
  {
    "country": "US",
    "name": "Wichita Falls",
    "lat": "33.91371",
    "lng": "-98.49339"
  },
  {
    "country": "US",
    "name": "Wild Peach Village",
    "lat": "29.08358",
    "lng": "-95.63384"
  },
  {
    "country": "US",
    "name": "Wildwood",
    "lat": "30.52409",
    "lng": "-94.44158"
  },
  {
    "country": "US",
    "name": "Willis",
    "lat": "30.42493",
    "lng": "-95.47994"
  },
  {
    "country": "US",
    "name": "Willow Park",
    "lat": "32.76263",
    "lng": "-97.65058"
  },
  {
    "country": "US",
    "name": "Wills Point",
    "lat": "32.7093",
    "lng": "-96.0083"
  },
  {
    "country": "US",
    "name": "Wilmer",
    "lat": "32.58902",
    "lng": "-96.68527"
  },
  {
    "country": "US",
    "name": "Wimberley",
    "lat": "29.99744",
    "lng": "-98.09862"
  },
  {
    "country": "US",
    "name": "Windemere",
    "lat": "30.45909",
    "lng": "-97.64917"
  },
  {
    "country": "US",
    "name": "Windcrest",
    "lat": "29.51551",
    "lng": "-98.38029"
  },
  {
    "country": "US",
    "name": "Winnie",
    "lat": "29.82022",
    "lng": "-94.38408"
  },
  {
    "country": "US",
    "name": "Winnsboro",
    "lat": "32.95734",
    "lng": "-95.29022"
  },
  {
    "country": "US",
    "name": "Winters",
    "lat": "31.95653",
    "lng": "-99.96231"
  },
  {
    "country": "US",
    "name": "Wolfe City",
    "lat": "33.37067",
    "lng": "-96.06886"
  },
  {
    "country": "US",
    "name": "Woodbranch",
    "lat": "30.18105",
    "lng": "-95.18882"
  },
  {
    "country": "US",
    "name": "Woodcreek",
    "lat": "30.02827",
    "lng": "-98.11112"
  },
  {
    "country": "US",
    "name": "Woodsboro",
    "lat": "28.23834",
    "lng": "-97.31999"
  },
  {
    "country": "US",
    "name": "Woodville",
    "lat": "30.7752",
    "lng": "-94.41548"
  },
  {
    "country": "US",
    "name": "Woodway",
    "lat": "31.506",
    "lng": "-97.20501"
  },
  {
    "country": "US",
    "name": "Wortham",
    "lat": "31.78794",
    "lng": "-96.46248"
  },
  {
    "country": "US",
    "name": "Wyldwood",
    "lat": "30.12938",
    "lng": "-97.47277"
  },
  {
    "country": "US",
    "name": "Wylie",
    "lat": "33.01512",
    "lng": "-96.53888"
  },
  {
    "country": "US",
    "name": "Yoakum",
    "lat": "29.28775",
    "lng": "-97.15193"
  },
  {
    "country": "US",
    "name": "Yorktown",
    "lat": "28.98109",
    "lng": "-97.50277"
  },
  {
    "country": "US",
    "name": "Zapata",
    "lat": "26.90726",
    "lng": "-99.27143"
  },
  {
    "country": "US",
    "name": "Abingdon",
    "lat": "36.70983",
    "lng": "-81.97735"
  },
  {
    "country": "US",
    "name": "Accomac",
    "lat": "37.71957",
    "lng": "-75.66548"
  },
  {
    "country": "US",
    "name": "Adwolf",
    "lat": "36.78928",
    "lng": "-81.58206"
  },
  {
    "country": "US",
    "name": "Alexandria",
    "lat": "38.80484",
    "lng": "-77.04692"
  },
  {
    "country": "US",
    "name": "Altavista",
    "lat": "37.11181",
    "lng": "-79.28558"
  },
  {
    "country": "US",
    "name": "Amelia Court House",
    "lat": "37.34293",
    "lng": "-77.98056"
  },
  {
    "country": "US",
    "name": "Amherst",
    "lat": "37.58514",
    "lng": "-79.05141"
  },
  {
    "country": "US",
    "name": "Annandale",
    "lat": "38.83039",
    "lng": "-77.19637"
  },
  {
    "country": "US",
    "name": "Appalachia",
    "lat": "36.90676",
    "lng": "-82.78183"
  },
  {
    "country": "US",
    "name": "Apple Mountain Lake",
    "lat": "38.92428",
    "lng": "-78.10139"
  },
  {
    "country": "US",
    "name": "Appomattox",
    "lat": "37.35709",
    "lng": "-78.82529"
  },
  {
    "country": "US",
    "name": "Aquia Harbour",
    "lat": "38.46262",
    "lng": "-77.38887"
  },
  {
    "country": "US",
    "name": "Arlington",
    "lat": "38.88101",
    "lng": "-77.10428"
  },
  {
    "country": "US",
    "name": "Ashburn",
    "lat": "39.04372",
    "lng": "-77.48749"
  },
  {
    "country": "US",
    "name": "Ashland",
    "lat": "37.75903",
    "lng": "-77.47998"
  },
  {
    "country": "US",
    "name": "Atkins",
    "lat": "36.86734",
    "lng": "-81.42344"
  },
  {
    "country": "US",
    "name": "Baileys Crossroads",
    "lat": "38.85039",
    "lng": "-77.1297"
  },
  {
    "country": "US",
    "name": "Bassett",
    "lat": "36.7593",
    "lng": "-79.99032"
  },
  {
    "country": "US",
    "name": "Basye",
    "lat": "38.80706",
    "lng": "-78.79224"
  },
  {
    "country": "US",
    "name": "Bealeton",
    "lat": "38.57179",
    "lng": "-77.76388"
  },
  {
    "country": "US",
    "name": "Bedford",
    "lat": "37.33431",
    "lng": "-79.52309"
  },
  {
    "country": "US",
    "name": "Belle Haven",
    "lat": "38.78539",
    "lng": "-77.06303"
  },
  {
    "country": "US",
    "name": "Bellwood",
    "lat": "37.42181",
    "lng": "-77.43748"
  },
  {
    "country": "US",
    "name": "Belmont",
    "lat": "39.06483",
    "lng": "-77.50999"
  },
  {
    "country": "US",
    "name": "Bensley",
    "lat": "37.44681",
    "lng": "-77.44332"
  },
  {
    "country": "US",
    "name": "Berryville",
    "lat": "39.15177",
    "lng": "-77.98222"
  },
  {
    "country": "US",
    "name": "Big Stone Gap",
    "lat": "36.88176",
    "lng": "-82.7471"
  },
  {
    "country": "US",
    "name": "Blackstone",
    "lat": "37.08043",
    "lng": "-77.99723"
  },
  {
    "country": "US",
    "name": "Blacksburg",
    "lat": "37.22957",
    "lng": "-80.41394"
  },
  {
    "country": "US",
    "name": "Bland",
    "lat": "37.10206",
    "lng": "-81.1162"
  },
  {
    "country": "US",
    "name": "Blue Ridge",
    "lat": "37.37847",
    "lng": "-79.80698"
  },
  {
    "country": "US",
    "name": "Bluefield",
    "lat": "37.25262",
    "lng": "-81.27121"
  },
  {
    "country": "US",
    "name": "Bon Air",
    "lat": "37.52487",
    "lng": "-77.55777"
  },
  {
    "country": "US",
    "name": "Bowling Green",
    "lat": "38.04958",
    "lng": "-77.34665"
  },
  {
    "country": "US",
    "name": "Boydton",
    "lat": "36.66764",
    "lng": "-78.3875"
  },
  {
    "country": "US",
    "name": "Bracey",
    "lat": "36.59959",
    "lng": "-78.14305"
  },
  {
    "country": "US",
    "name": "Brambleton",
    "lat": "38.98205",
    "lng": "-77.5386"
  },
  {
    "country": "US",
    "name": "Brandermill",
    "lat": "37.43209",
    "lng": "-77.64971"
  },
  {
    "country": "US",
    "name": "Bridgewater",
    "lat": "38.38207",
    "lng": "-78.9767"
  },
  {
    "country": "US",
    "name": "Brightwood",
    "lat": "38.42152",
    "lng": "-78.19361"
  },
  {
    "country": "US",
    "name": "Bristol",
    "lat": "36.59649",
    "lng": "-82.18847"
  },
  {
    "country": "US",
    "name": "Broadlands",
    "lat": "39.01816",
    "lng": "-77.52027"
  },
  {
    "country": "US",
    "name": "Broadway",
    "lat": "38.61317",
    "lng": "-78.79891"
  },
  {
    "country": "US",
    "name": "Brookneal",
    "lat": "37.05014",
    "lng": "-78.94418"
  },
  {
    "country": "US",
    "name": "Buchanan",
    "lat": "37.52736",
    "lng": "-79.67976"
  },
  {
    "country": "US",
    "name": "Buckhall",
    "lat": "38.73178",
    "lng": "-77.4311"
  },
  {
    "country": "US",
    "name": "Buckingham",
    "lat": "37.55015",
    "lng": "-78.55556"
  },
  {
    "country": "US",
    "name": "Buena Vista",
    "lat": "37.7343",
    "lng": "-79.35392"
  },
  {
    "country": "US",
    "name": "Bull Run",
    "lat": "38.78373",
    "lng": "-77.52055"
  },
  {
    "country": "US",
    "name": "Bull Run Mountain Estates",
    "lat": "38.90372",
    "lng": "-77.66166"
  },
  {
    "country": "US",
    "name": "Burke",
    "lat": "38.79345",
    "lng": "-77.27165"
  },
  {
    "country": "US",
    "name": "Cana",
    "lat": "36.58958",
    "lng": "-80.67173"
  },
  {
    "country": "US",
    "name": "Cape Charles",
    "lat": "37.26792",
    "lng": "-76.01743"
  },
  {
    "country": "US",
    "name": "Carrollton",
    "lat": "36.94682",
    "lng": "-76.56051"
  },
  {
    "country": "US",
    "name": "Castlewood",
    "lat": "36.8901",
    "lng": "-82.27959"
  },
  {
    "country": "US",
    "name": "Cave Spring",
    "lat": "37.22764",
    "lng": "-80.01282"
  },
  {
    "country": "US",
    "name": "Cedar Bluff",
    "lat": "37.26403",
    "lng": "-79.93532"
  },
  {
    "country": "US",
    "name": "Cedar Bluff",
    "lat": "37.08761",
    "lng": "-81.759"
  },
  {
    "country": "US",
    "name": "Central Garage",
    "lat": "37.74403",
    "lng": "-77.13164"
  },
  {
    "country": "US",
    "name": "Centreville",
    "lat": "38.84039",
    "lng": "-77.42888"
  },
  {
    "country": "US",
    "name": "Chamberlayne",
    "lat": "37.62653",
    "lng": "-77.42859"
  },
  {
    "country": "US",
    "name": "Chantilly",
    "lat": "38.89428",
    "lng": "-77.4311"
  },
  {
    "country": "US",
    "name": "Charles City",
    "lat": "37.34348",
    "lng": "-77.07303"
  },
  {
    "country": "US",
    "name": "Charlotte Court House",
    "lat": "37.05654",
    "lng": "-78.63833"
  },
  {
    "country": "US",
    "name": "Charlottesville",
    "lat": "38.02931",
    "lng": "-78.47668"
  },
  {
    "country": "US",
    "name": "Chase City",
    "lat": "36.79931",
    "lng": "-78.45833"
  },
  {
    "country": "US",
    "name": "Chatham",
    "lat": "36.82569",
    "lng": "-79.39808"
  },
  {
    "country": "US",
    "name": "Chatmoss",
    "lat": "36.6568",
    "lng": "-79.81226"
  },
  {
    "country": "US",
    "name": "Cherry Hill",
    "lat": "38.56984",
    "lng": "-77.26693"
  },
  {
    "country": "US",
    "name": "Chesapeake",
    "lat": "36.81904",
    "lng": "-76.27494"
  },
  {
    "country": "US",
    "name": "Chester",
    "lat": "37.35682",
    "lng": "-77.44165"
  },
  {
    "country": "US",
    "name": "Chesterfield",
    "lat": "37.37709",
    "lng": "-77.50582"
  },
  {
    "country": "US",
    "name": "Chesterfield Court House",
    "lat": "37.37709",
    "lng": "-77.50499"
  },
  {
    "country": "US",
    "name": "Chilhowie",
    "lat": "36.79845",
    "lng": "-81.68234"
  },
  {
    "country": "US",
    "name": "Chincoteague",
    "lat": "37.93318",
    "lng": "-75.37881"
  },
  {
    "country": "US",
    "name": "Christiansburg",
    "lat": "37.12985",
    "lng": "-80.40894"
  },
  {
    "country": "US",
    "name": "Clarksville",
    "lat": "36.62403",
    "lng": "-78.55694"
  },
  {
    "country": "US",
    "name": "Claypool Hill",
    "lat": "37.06261",
    "lng": "-81.75178"
  },
  {
    "country": "US",
    "name": "Clifton Forge",
    "lat": "37.81624",
    "lng": "-79.82449"
  },
  {
    "country": "US",
    "name": "Clintwood",
    "lat": "37.15011",
    "lng": "-82.45598"
  },
  {
    "country": "US",
    "name": "Cloverdale",
    "lat": "37.36514",
    "lng": "-79.9056"
  },
  {
    "country": "US",
    "name": "Coeburn",
    "lat": "36.94399",
    "lng": "-82.46404"
  },
  {
    "country": "US",
    "name": "Collinsville",
    "lat": "36.71514",
    "lng": "-79.91532"
  },
  {
    "country": "US",
    "name": "Colonial Beach",
    "lat": "38.25457",
    "lng": "-76.96358"
  },
  {
    "country": "US",
    "name": "Colonial Heights",
    "lat": "37.26804",
    "lng": "-77.40726"
  },
  {
    "country": "US",
    "name": "Concord",
    "lat": "37.34264",
    "lng": "-78.97502"
  },
  {
    "country": "US",
    "name": "Countryside",
    "lat": "39.04094",
    "lng": "-77.4136"
  },
  {
    "country": "US",
    "name": "Courtland",
    "lat": "36.71626",
    "lng": "-77.06802"
  },
  {
    "country": "US",
    "name": "Covington",
    "lat": "37.79346",
    "lng": "-79.99395"
  },
  {
    "country": "US",
    "name": "Crewe",
    "lat": "37.17321",
    "lng": "-78.12333"
  },
  {
    "country": "US",
    "name": "Crimora",
    "lat": "38.15402",
    "lng": "-78.8503"
  },
  {
    "country": "US",
    "name": "Crozet",
    "lat": "38.06958",
    "lng": "-78.70058"
  },
  {
    "country": "US",
    "name": "Culpeper",
    "lat": "38.47318",
    "lng": "-77.99666"
  },
  {
    "country": "US",
    "name": "Cumberland",
    "lat": "37.49598",
    "lng": "-78.24527"
  },
  {
    "country": "US",
    "name": "Dahlgren",
    "lat": "38.33124",
    "lng": "-77.05109"
  },
  {
    "country": "US",
    "name": "Dale City",
    "lat": "38.63706",
    "lng": "-77.31109"
  },
  {
    "country": "US",
    "name": "Daleville",
    "lat": "37.40986",
    "lng": "-79.91254"
  },
  {
    "country": "US",
    "name": "Danville",
    "lat": "36.58597",
    "lng": "-79.39502"
  },
  {
    "country": "US",
    "name": "Dayton",
    "lat": "38.41485",
    "lng": "-78.93864"
  },
  {
    "country": "US",
    "name": "Deltaville",
    "lat": "37.55486",
    "lng": "-76.33689"
  },
  {
    "country": "US",
    "name": "Dinwiddie",
    "lat": "37.07793",
    "lng": "-77.58665"
  },
  {
    "country": "US",
    "name": "Dooms",
    "lat": "38.10902",
    "lng": "-78.85752"
  },
  {
    "country": "US",
    "name": "Dranesville",
    "lat": "39.00067",
    "lng": "-77.34582"
  },
  {
    "country": "US",
    "name": "Dryden",
    "lat": "36.77759",
    "lng": "-82.94155"
  },
  {
    "country": "US",
    "name": "Dublin",
    "lat": "37.10568",
    "lng": "-80.68534"
  },
  {
    "country": "US",
    "name": "Dulles Town Center",
    "lat": "39.03761",
    "lng": "-77.41582"
  },
  {
    "country": "US",
    "name": "Dumfries",
    "lat": "38.56762",
    "lng": "-77.32804"
  },
  {
    "country": "US",
    "name": "Dumbarton",
    "lat": "37.60376",
    "lng": "-77.49137"
  },
  {
    "country": "US",
    "name": "Dunn Loring",
    "lat": "38.89344",
    "lng": "-77.22165"
  },
  {
    "country": "US",
    "name": "East Hampton",
    "lat": "37.03737",
    "lng": "-76.33161"
  },
  {
    "country": "US",
    "name": "East Lexington",
    "lat": "37.79291",
    "lng": "-79.42532"
  },
  {
    "country": "US",
    "name": "East Highland Park",
    "lat": "37.58098",
    "lng": "-77.40693"
  },
  {
    "country": "US",
    "name": "Eastville",
    "lat": "37.35264",
    "lng": "-75.94576"
  },
  {
    "country": "US",
    "name": "Edinburg",
    "lat": "38.82095",
    "lng": "-78.56585"
  },
  {
    "country": "US",
    "name": "Elkton",
    "lat": "38.4079",
    "lng": "-78.62363"
  },
  {
    "country": "US",
    "name": "Emory",
    "lat": "36.77289",
    "lng": "-81.83623"
  },
  {
    "country": "US",
    "name": "Emporia",
    "lat": "36.68598",
    "lng": "-77.54248"
  },
  {
    "country": "US",
    "name": "Enon",
    "lat": "37.3307",
    "lng": "-77.32276"
  },
  {
    "country": "US",
    "name": "Ettrick",
    "lat": "37.24015",
    "lng": "-77.42998"
  },
  {
    "country": "US",
    "name": "Exmore",
    "lat": "37.5318",
    "lng": "-75.82299"
  },
  {
    "country": "US",
    "name": "Fairfax",
    "lat": "38.84622",
    "lng": "-77.30637"
  },
  {
    "country": "US",
    "name": "Fairfax Station",
    "lat": "38.80095",
    "lng": "-77.32554"
  },
  {
    "country": "US",
    "name": "Fairlawn",
    "lat": "37.77624",
    "lng": "-79.982"
  },
  {
    "country": "US",
    "name": "Fairlawn",
    "lat": "37.14846",
    "lng": "-80.57839"
  },
  {
    "country": "US",
    "name": "Falls Church",
    "lat": "38.88233",
    "lng": "-77.17109"
  },
  {
    "country": "US",
    "name": "Falmouth",
    "lat": "38.32402",
    "lng": "-77.46832"
  },
  {
    "country": "US",
    "name": "Farmville",
    "lat": "37.3021",
    "lng": "-78.39194"
  },
  {
    "country": "US",
    "name": "Ferrum",
    "lat": "36.92292",
    "lng": "-80.01337"
  },
  {
    "country": "US",
    "name": "Fincastle",
    "lat": "37.4993",
    "lng": "-79.87726"
  },
  {
    "country": "US",
    "name": "Fishersville",
    "lat": "38.09902",
    "lng": "-78.96919"
  },
  {
    "country": "US",
    "name": "Floris",
    "lat": "38.93706",
    "lng": "-77.41277"
  },
  {
    "country": "US",
    "name": "Floyd",
    "lat": "36.91124",
    "lng": "-80.32005"
  },
  {
    "country": "US",
    "name": "Forest",
    "lat": "37.36375",
    "lng": "-79.28975"
  },
  {
    "country": "US",
    "name": "Fort Lee",
    "lat": "37.4957",
    "lng": "-77.33526"
  },
  {
    "country": "US",
    "name": "Franconia",
    "lat": "38.78206",
    "lng": "-77.14637"
  },
  {
    "country": "US",
    "name": "Franklin",
    "lat": "36.67765",
    "lng": "-76.92246"
  },
  {
    "country": "US",
    "name": "Fredericksburg",
    "lat": "38.30318",
    "lng": "-77.46054"
  },
  {
    "country": "US",
    "name": "Front Royal",
    "lat": "38.91817",
    "lng": "-78.19444"
  },
  {
    "country": "US",
    "name": "Gainesville",
    "lat": "38.79567",
    "lng": "-77.61388"
  },
  {
    "country": "US",
    "name": "Galax",
    "lat": "36.66124",
    "lng": "-80.92397"
  },
  {
    "country": "US",
    "name": "Gate City",
    "lat": "36.63788",
    "lng": "-82.58099"
  },
  {
    "country": "US",
    "name": "Glade Spring",
    "lat": "36.79122",
    "lng": "-81.77123"
  },
  {
    "country": "US",
    "name": "Glasgow",
    "lat": "37.63402",
    "lng": "-79.45031"
  },
  {
    "country": "US",
    "name": "Glen Allen",
    "lat": "37.66598",
    "lng": "-77.50637"
  },
  {
    "country": "US",
    "name": "Gloucester Courthouse",
    "lat": "37.40986",
    "lng": "-76.52662"
  },
  {
    "country": "US",
    "name": "Gloucester Point",
    "lat": "37.25403",
    "lng": "-76.49689"
  },
  {
    "country": "US",
    "name": "Goochland",
    "lat": "37.68431",
    "lng": "-77.88527"
  },
  {
    "country": "US",
    "name": "Gordonsville",
    "lat": "38.13736",
    "lng": "-78.18778"
  },
  {
    "country": "US",
    "name": "Great Falls",
    "lat": "38.99817",
    "lng": "-77.28832"
  },
  {
    "country": "US",
    "name": "Greenbriar",
    "lat": "38.87345",
    "lng": "-77.40082"
  },
  {
    "country": "US",
    "name": "Gretna",
    "lat": "36.95375",
    "lng": "-79.35891"
  },
  {
    "country": "US",
    "name": "Grottoes",
    "lat": "38.26735",
    "lng": "-78.82586"
  },
  {
    "country": "US",
    "name": "Groveton",
    "lat": "38.76734",
    "lng": "-77.0847"
  },
  {
    "country": "US",
    "name": "Grundy",
    "lat": "37.27789",
    "lng": "-82.09902"
  },
  {
    "country": "US",
    "name": "Halifax",
    "lat": "36.76597",
    "lng": "-78.92834"
  },
  {
    "country": "US",
    "name": "Hampden Sydney",
    "lat": "37.24237",
    "lng": "-78.45972"
  },
  {
    "country": "US",
    "name": "Hampton",
    "lat": "37.02987",
    "lng": "-76.34522"
  },
  {
    "country": "US",
    "name": "Hanover",
    "lat": "37.76653",
    "lng": "-77.37026"
  },
  {
    "country": "US",
    "name": "Harrisonburg",
    "lat": "38.44957",
    "lng": "-78.86892"
  },
  {
    "country": "US",
    "name": "Hayfield",
    "lat": "38.75178",
    "lng": "-77.13581"
  },
  {
    "country": "US",
    "name": "Haymarket",
    "lat": "38.81206",
    "lng": "-77.63638"
  },
  {
    "country": "US",
    "name": "Heathsville",
    "lat": "37.91763",
    "lng": "-76.47217"
  },
  {
    "country": "US",
    "name": "Henry Fork",
    "lat": "36.96625",
    "lng": "-79.87031"
  },
  {
    "country": "US",
    "name": "Herndon",
    "lat": "38.96955",
    "lng": "-77.3861"
  },
  {
    "country": "US",
    "name": "Highland Springs",
    "lat": "37.54598",
    "lng": "-77.32776"
  },
  {
    "country": "US",
    "name": "Hillsville",
    "lat": "36.76263",
    "lng": "-80.73479"
  },
  {
    "country": "US",
    "name": "Hollins",
    "lat": "37.34125",
    "lng": "-79.9431"
  },
  {
    "country": "US",
    "name": "Hollymead",
    "lat": "38.11708",
    "lng": "-78.44168"
  },
  {
    "country": "US",
    "name": "Honaker",
    "lat": "37.01622",
    "lng": "-81.97429"
  },
  {
    "country": "US",
    "name": "Hopewell",
    "lat": "37.30432",
    "lng": "-77.2872"
  },
  {
    "country": "US",
    "name": "Horse Pasture",
    "lat": "36.62847",
    "lng": "-79.95087"
  },
  {
    "country": "US",
    "name": "Huntington",
    "lat": "38.79234",
    "lng": "-77.07081"
  },
  {
    "country": "US",
    "name": "Hurt",
    "lat": "37.09264",
    "lng": "-79.29641"
  },
  {
    "country": "US",
    "name": "Hybla Valley",
    "lat": "38.74761",
    "lng": "-77.08303"
  },
  {
    "country": "US",
    "name": "Idylwood",
    "lat": "38.89511",
    "lng": "-77.21165"
  },
  {
    "country": "US",
    "name": "Independent Hill",
    "lat": "38.63595",
    "lng": "-77.43776"
  },
  {
    "country": "US",
    "name": "Isle of Wight",
    "lat": "36.90765",
    "lng": "-76.70773"
  },
  {
    "country": "US",
    "name": "Jefferson",
    "lat": "38.86456",
    "lng": "-77.18776"
  },
  {
    "country": "US",
    "name": "Jolivue",
    "lat": "38.10985",
    "lng": "-79.07308"
  },
  {
    "country": "US",
    "name": "Jonesville",
    "lat": "36.68898",
    "lng": "-83.111"
  },
  {
    "country": "US",
    "name": "Kenbridge",
    "lat": "36.96209",
    "lng": "-78.125"
  },
  {
    "country": "US",
    "name": "Kilmarnock",
    "lat": "37.71041",
    "lng": "-76.37967"
  },
  {
    "country": "US",
    "name": "King George",
    "lat": "38.26818",
    "lng": "-77.18442"
  },
  {
    "country": "US",
    "name": "King William",
    "lat": "37.68736",
    "lng": "-77.01358"
  },
  {
    "country": "US",
    "name": "King and Queen Court House",
    "lat": "37.66986",
    "lng": "-76.87746"
  },
  {
    "country": "US",
    "name": "Kings Park",
    "lat": "38.80622",
    "lng": "-77.24332"
  },
  {
    "country": "US",
    "name": "Lake Barcroft",
    "lat": "38.84789",
    "lng": "-77.15581"
  },
  {
    "country": "US",
    "name": "Lake Monticello",
    "lat": "37.9232",
    "lng": "-78.33473"
  },
  {
    "country": "US",
    "name": "Lake Ridge",
    "lat": "38.68789",
    "lng": "-77.29776"
  },
  {
    "country": "US",
    "name": "Lakeside",
    "lat": "37.60765",
    "lng": "-77.47693"
  },
  {
    "country": "US",
    "name": "Lancaster",
    "lat": "37.76986",
    "lng": "-76.46634"
  },
  {
    "country": "US",
    "name": "Laurel",
    "lat": "37.64292",
    "lng": "-77.50887"
  },
  {
    "country": "US",
    "name": "Lawrenceville",
    "lat": "36.75765",
    "lng": "-77.84694"
  },
  {
    "country": "US",
    "name": "Laymantown",
    "lat": "37.36569",
    "lng": "-79.85754"
  },
  {
    "country": "US",
    "name": "Lebanon",
    "lat": "36.90094",
    "lng": "-82.08013"
  },
  {
    "country": "US",
    "name": "Leesburg",
    "lat": "39.11566",
    "lng": "-77.5636"
  },
  {
    "country": "US",
    "name": "Lexington",
    "lat": "37.78402",
    "lng": "-79.44282"
  },
  {
    "country": "US",
    "name": "Lincolnia",
    "lat": "38.81845",
    "lng": "-77.14331"
  },
  {
    "country": "US",
    "name": "Linton Hall",
    "lat": "38.75984",
    "lng": "-77.57499"
  },
  {
    "country": "US",
    "name": "Loch Lomond",
    "lat": "38.78623",
    "lng": "-77.47804"
  },
  {
    "country": "US",
    "name": "Lorton",
    "lat": "38.70428",
    "lng": "-77.22776"
  },
  {
    "country": "US",
    "name": "Louisa",
    "lat": "38.02514",
    "lng": "-78.00416"
  },
  {
    "country": "US",
    "name": "Lovettsville",
    "lat": "39.2726",
    "lng": "-77.63666"
  },
  {
    "country": "US",
    "name": "Lovingston",
    "lat": "37.75986",
    "lng": "-78.87086"
  },
  {
    "country": "US",
    "name": "Lowes Island",
    "lat": "39.05983",
    "lng": "-77.35221"
  },
  {
    "country": "US",
    "name": "Lunenburg",
    "lat": "36.96098",
    "lng": "-78.26555"
  },
  {
    "country": "US",
    "name": "Luray",
    "lat": "38.6654",
    "lng": "-78.45945"
  },
  {
    "country": "US",
    "name": "Lynchburg",
    "lat": "37.41375",
    "lng": "-79.14225"
  },
  {
    "country": "US",
    "name": "Lyndhurst",
    "lat": "38.0293",
    "lng": "-78.94502"
  },
  {
    "country": "US",
    "name": "Madison",
    "lat": "38.38041",
    "lng": "-78.2575"
  },
  {
    "country": "US",
    "name": "Madison Heights",
    "lat": "37.43098",
    "lng": "-79.12308"
  },
  {
    "country": "US",
    "name": "Manassas",
    "lat": "38.75095",
    "lng": "-77.47527"
  },
  {
    "country": "US",
    "name": "Manassas Park",
    "lat": "38.784",
    "lng": "-77.46971"
  },
  {
    "country": "US",
    "name": "Mantua",
    "lat": "38.85372",
    "lng": "-77.25943"
  },
  {
    "country": "US",
    "name": "Marion",
    "lat": "36.83484",
    "lng": "-81.51484"
  },
  {
    "country": "US",
    "name": "Marshall",
    "lat": "38.86484",
    "lng": "-77.85777"
  },
  {
    "country": "US",
    "name": "Martinsville",
    "lat": "36.69153",
    "lng": "-79.87254"
  },
  {
    "country": "US",
    "name": "Massanetta Springs",
    "lat": "38.4004",
    "lng": "-78.83419"
  },
  {
    "country": "US",
    "name": "Massanutten",
    "lat": "38.40957",
    "lng": "-78.7378"
  },
  {
    "country": "US",
    "name": "Mathews",
    "lat": "37.43708",
    "lng": "-76.31994"
  },
  {
    "country": "US",
    "name": "Matoaca",
    "lat": "37.23043",
    "lng": "-77.47749"
  },
  {
    "country": "US",
    "name": "McLean",
    "lat": "38.93428",
    "lng": "-77.17748"
  },
  {
    "country": "US",
    "name": "Mechanicsville",
    "lat": "37.60876",
    "lng": "-77.37331"
  },
  {
    "country": "US",
    "name": "Merrifield",
    "lat": "38.87428",
    "lng": "-77.22693"
  },
  {
    "country": "US",
    "name": "Merrimac",
    "lat": "38.45263",
    "lng": "-78.07861"
  },
  {
    "country": "US",
    "name": "Merrimac",
    "lat": "37.18957",
    "lng": "-80.42561"
  },
  {
    "country": "US",
    "name": "Middletown",
    "lat": "39.02761",
    "lng": "-78.28056"
  },
  {
    "country": "US",
    "name": "Montclair",
    "lat": "38.61095",
    "lng": "-77.33971"
  },
  {
    "country": "US",
    "name": "Monterey",
    "lat": "38.41234",
    "lng": "-79.5806"
  },
  {
    "country": "US",
    "name": "Montrose",
    "lat": "37.5207",
    "lng": "-77.37831"
  },
  {
    "country": "US",
    "name": "Montross",
    "lat": "38.09513",
    "lng": "-76.82746"
  },
  {
    "country": "US",
    "name": "Motley",
    "lat": "37.06959",
    "lng": "-79.34114"
  },
  {
    "country": "US",
    "name": "Mount Hermon",
    "lat": "36.67847",
    "lng": "-79.42225"
  },
  {
    "country": "US",
    "name": "Mount Jackson",
    "lat": "38.74595",
    "lng": "-78.64224"
  },
  {
    "country": "US",
    "name": "Mountain Road",
    "lat": "36.75958",
    "lng": "-78.98696"
  },
  {
    "country": "US",
    "name": "Narrows",
    "lat": "37.33151",
    "lng": "-80.81119"
  },
  {
    "country": "US",
    "name": "Narrows",
    "lat": "37.20542",
    "lng": "-79.95893"
  },
  {
    "country": "US",
    "name": "Nellysford",
    "lat": "37.89042",
    "lng": "-78.87224"
  },
  {
    "country": "US",
    "name": "New Baltimore",
    "lat": "38.76734",
    "lng": "-77.72833"
  },
  {
    "country": "US",
    "name": "New Castle",
    "lat": "37.50013",
    "lng": "-80.11088"
  },
  {
    "country": "US",
    "name": "New Market",
    "lat": "38.6479",
    "lng": "-78.67141"
  },
  {
    "country": "US",
    "name": "Newington",
    "lat": "38.73845",
    "lng": "-77.18498"
  },
  {
    "country": "US",
    "name": "Newport News",
    "lat": "37.08339",
    "lng": "-76.46965"
  },
  {
    "country": "US",
    "name": "Nokesville",
    "lat": "38.69873",
    "lng": "-77.57971"
  },
  {
    "country": "US",
    "name": "Norfolk",
    "lat": "36.84681",
    "lng": "-76.28522"
  },
  {
    "country": "US",
    "name": "North Shore",
    "lat": "37.08209",
    "lng": "-79.65836"
  },
  {
    "country": "US",
    "name": "North Springfield",
    "lat": "38.80428",
    "lng": "-77.2047"
  },
  {
    "country": "US",
    "name": "Norton",
    "lat": "36.93343",
    "lng": "-82.62905"
  },
  {
    "country": "US",
    "name": "Oak Grove",
    "lat": "38.984",
    "lng": "-77.40388"
  },
  {
    "country": "US",
    "name": "Oakton",
    "lat": "38.88095",
    "lng": "-77.30082"
  },
  {
    "country": "US",
    "name": "Occoquan",
    "lat": "38.68373",
    "lng": "-77.26026"
  },
  {
    "country": "US",
    "name": "Onancock",
    "lat": "37.7118",
    "lng": "-75.7491"
  },
  {
    "country": "US",
    "name": "Orange",
    "lat": "38.24541",
    "lng": "-78.11083"
  },
  {
    "country": "US",
    "name": "Palmyra",
    "lat": "37.86097",
    "lng": "-78.26334"
  },
  {
    "country": "US",
    "name": "Pannill Fork",
    "lat": "36.70903",
    "lng": "-80.0131"
  },
  {
    "country": "US",
    "name": "Passapatanzy",
    "lat": "38.29735",
    "lng": "-77.31415"
  },
  {
    "country": "US",
    "name": "Patrick Springs",
    "lat": "36.6418",
    "lng": "-80.19505"
  },
  {
    "country": "US",
    "name": "Pearisburg",
    "lat": "37.32673",
    "lng": "-80.73702"
  },
  {
    "country": "US",
    "name": "Pembroke",
    "lat": "37.31957",
    "lng": "-80.63895"
  },
  {
    "country": "US",
    "name": "Pennington Gap",
    "lat": "36.75842",
    "lng": "-83.02711"
  },
  {
    "country": "US",
    "name": "Petersburg",
    "lat": "37.22793",
    "lng": "-77.40193"
  },
  {
    "country": "US",
    "name": "Pimmit Hills",
    "lat": "38.91289",
    "lng": "-77.20081"
  },
  {
    "country": "US",
    "name": "Poquoson",
    "lat": "37.12237",
    "lng": "-76.34578"
  },
  {
    "country": "US",
    "name": "Portsmouth",
    "lat": "36.83543",
    "lng": "-76.29827"
  },
  {
    "country": "US",
    "name": "Portsmouth Heights",
    "lat": "36.82098",
    "lng": "-76.36883"
  },
  {
    "country": "US",
    "name": "Potomac Mills",
    "lat": "38.64595",
    "lng": "-77.29415"
  },
  {
    "country": "US",
    "name": "Powhatan",
    "lat": "37.54209",
    "lng": "-77.91889"
  },
  {
    "country": "US",
    "name": "Prices Fork",
    "lat": "37.20985",
    "lng": "-80.49005"
  },
  {
    "country": "US",
    "name": "Prince George",
    "lat": "37.22043",
    "lng": "-77.28803"
  },
  {
    "country": "US",
    "name": "Pulaski",
    "lat": "37.0479",
    "lng": "-80.77979"
  },
  {
    "country": "US",
    "name": "Purcellville",
    "lat": "39.13677",
    "lng": "-77.71472"
  },
  {
    "country": "US",
    "name": "Radford",
    "lat": "37.13179",
    "lng": "-80.57645"
  },
  {
    "country": "US",
    "name": "Raven",
    "lat": "37.08706",
    "lng": "-81.85512"
  },
  {
    "country": "US",
    "name": "Ravensworth",
    "lat": "38.804",
    "lng": "-77.22054"
  },
  {
    "country": "US",
    "name": "Reston",
    "lat": "38.96872",
    "lng": "-77.3411"
  },
  {
    "country": "US",
    "name": "Richmond",
    "lat": "37.55376",
    "lng": "-77.46026"
  },
  {
    "country": "US",
    "name": "Richlands",
    "lat": "37.09317",
    "lng": "-81.79373"
  },
  {
    "country": "US",
    "name": "Roanoke",
    "lat": "37.27097",
    "lng": "-79.94143"
  },
  {
    "country": "US",
    "name": "Rocky Mount",
    "lat": "36.99764",
    "lng": "-79.89198"
  },
  {
    "country": "US",
    "name": "Rose Hill",
    "lat": "38.78872",
    "lng": "-77.11276"
  },
  {
    "country": "US",
    "name": "Ruckersville",
    "lat": "38.23319",
    "lng": "-78.36917"
  },
  {
    "country": "US",
    "name": "Rural Retreat",
    "lat": "36.89373",
    "lng": "-81.27593"
  },
  {
    "country": "US",
    "name": "Rushmere",
    "lat": "37.06681",
    "lng": "-76.67635"
  },
  {
    "country": "US",
    "name": "Rustburg",
    "lat": "37.27681",
    "lng": "-79.10085"
  },
  {
    "country": "US",
    "name": "Salem",
    "lat": "37.29347",
    "lng": "-80.05476"
  },
  {
    "country": "US",
    "name": "Saluda",
    "lat": "37.60597",
    "lng": "-76.59495"
  },
  {
    "country": "US",
    "name": "Saltville",
    "lat": "36.8815",
    "lng": "-81.76206"
  },
  {
    "country": "US",
    "name": "Sandston",
    "lat": "37.52348",
    "lng": "-77.31581"
  },
  {
    "country": "US",
    "name": "Seven Corners",
    "lat": "38.87206",
    "lng": "-77.15526"
  },
  {
    "country": "US",
    "name": "Shawnee Land",
    "lat": "39.19149",
    "lng": "-78.34556"
  },
  {
    "country": "US",
    "name": "Shawsville",
    "lat": "37.16847",
    "lng": "-80.25532"
  },
  {
    "country": "US",
    "name": "Shenandoah",
    "lat": "38.48512",
    "lng": "-78.62502"
  },
  {
    "country": "US",
    "name": "Shenandoah Farms",
    "lat": "38.98178",
    "lng": "-78.07555"
  },
  {
    "country": "US",
    "name": "Short Pump",
    "lat": "37.65042",
    "lng": "-77.61249"
  },
  {
    "country": "US",
    "name": "Smithfield",
    "lat": "36.98237",
    "lng": "-76.63107"
  },
  {
    "country": "US",
    "name": "South Boston",
    "lat": "36.69875",
    "lng": "-78.9014"
  },
  {
    "country": "US",
    "name": "South Hill",
    "lat": "36.72653",
    "lng": "-78.12889"
  },
  {
    "country": "US",
    "name": "South Riding",
    "lat": "38.92094",
    "lng": "-77.50388"
  },
  {
    "country": "US",
    "name": "South Suffolk",
    "lat": "36.71709",
    "lng": "-76.59023"
  },
  {
    "country": "US",
    "name": "Spotsylvania",
    "lat": "38.20096",
    "lng": "-77.58915"
  },
  {
    "country": "US",
    "name": "Spotsylvania Courthouse",
    "lat": "38.19791",
    "lng": "-77.58777"
  },
  {
    "country": "US",
    "name": "Springfield",
    "lat": "38.78928",
    "lng": "-77.1872"
  },
  {
    "country": "US",
    "name": "Springville",
    "lat": "37.19651",
    "lng": "-81.40288"
  },
  {
    "country": "US",
    "name": "Stafford",
    "lat": "38.42207",
    "lng": "-77.40832"
  },
  {
    "country": "US",
    "name": "Stanardsville",
    "lat": "38.29735",
    "lng": "-78.44001"
  },
  {
    "country": "US",
    "name": "Stanley",
    "lat": "38.5754",
    "lng": "-78.50251"
  },
  {
    "country": "US",
    "name": "Stanleytown",
    "lat": "36.7443",
    "lng": "-79.96282"
  },
  {
    "country": "US",
    "name": "Staunton",
    "lat": "38.14991",
    "lng": "-79.0732"
  },
  {
    "country": "US",
    "name": "Stephens City",
    "lat": "39.08344",
    "lng": "-78.21806"
  },
  {
    "country": "US",
    "name": "Sterling",
    "lat": "39.00622",
    "lng": "-77.4286"
  },
  {
    "country": "US",
    "name": "Strasburg",
    "lat": "38.98872",
    "lng": "-78.35862"
  },
  {
    "country": "US",
    "name": "Stuart",
    "lat": "36.64097",
    "lng": "-80.26561"
  },
  {
    "country": "US",
    "name": "Stuarts Draft",
    "lat": "38.03014",
    "lng": "-79.03364"
  },
  {
    "country": "US",
    "name": "Sudley",
    "lat": "38.79289",
    "lng": "-77.49749"
  },
  {
    "country": "US",
    "name": "Suffolk",
    "lat": "36.72836",
    "lng": "-76.58496"
  },
  {
    "country": "US",
    "name": "Sugarland Run",
    "lat": "39.03761",
    "lng": "-77.37526"
  },
  {
    "country": "US",
    "name": "Surry",
    "lat": "37.13793",
    "lng": "-76.83524"
  },
  {
    "country": "US",
    "name": "Sussex",
    "lat": "36.91515",
    "lng": "-77.27914"
  },
  {
    "country": "US",
    "name": "Tappahannock",
    "lat": "37.92541",
    "lng": "-76.85913"
  },
  {
    "country": "US",
    "name": "Tazewell",
    "lat": "37.11484",
    "lng": "-81.51955"
  },
  {
    "country": "US",
    "name": "Timberlake",
    "lat": "37.3207",
    "lng": "-79.25753"
  },
  {
    "country": "US",
    "name": "Timberville",
    "lat": "38.63901",
    "lng": "-78.77391"
  },
  {
    "country": "US",
    "name": "Triangle",
    "lat": "38.54679",
    "lng": "-77.33665"
  },
  {
    "country": "US",
    "name": "Tuckahoe",
    "lat": "37.59015",
    "lng": "-77.55638"
  },
  {
    "country": "US",
    "name": "Tysons Corner",
    "lat": "38.91872",
    "lng": "-77.23109"
  },
  {
    "country": "US",
    "name": "Union Hall",
    "lat": "37.01875",
    "lng": "-79.68642"
  },
  {
    "country": "US",
    "name": "University Center",
    "lat": "39.05705",
    "lng": "-77.44415"
  },
  {
    "country": "US",
    "name": "Verona",
    "lat": "38.20208",
    "lng": "-79.00836"
  },
  {
    "country": "US",
    "name": "Victoria",
    "lat": "36.99487",
    "lng": "-78.22722"
  },
  {
    "country": "US",
    "name": "Vienna",
    "lat": "38.90122",
    "lng": "-77.26526"
  },
  {
    "country": "US",
    "name": "Vinton",
    "lat": "37.28097",
    "lng": "-79.89698"
  },
  {
    "country": "US",
    "name": "Virginia Beach",
    "lat": "36.85293",
    "lng": "-75.97799"
  },
  {
    "country": "US",
    "name": "Warm Springs",
    "lat": "38.04624",
    "lng": "-79.79061"
  },
  {
    "country": "US",
    "name": "Warrenton",
    "lat": "38.71345",
    "lng": "-77.79527"
  },
  {
    "country": "US",
    "name": "Warsaw",
    "lat": "37.95874",
    "lng": "-76.75801"
  },
  {
    "country": "US",
    "name": "Washington",
    "lat": "38.71345",
    "lng": "-78.15944"
  },
  {
    "country": "US",
    "name": "Wattsville",
    "lat": "37.93401",
    "lng": "-75.49965"
  },
  {
    "country": "US",
    "name": "Waverly",
    "lat": "37.03598",
    "lng": "-77.09524"
  },
  {
    "country": "US",
    "name": "Waynesboro",
    "lat": "38.06847",
    "lng": "-78.88947"
  },
  {
    "country": "US",
    "name": "Weber City",
    "lat": "37.75514",
    "lng": "-78.28389"
  },
  {
    "country": "US",
    "name": "Weber City",
    "lat": "36.62288",
    "lng": "-82.5621"
  },
  {
    "country": "US",
    "name": "West Falls Church",
    "lat": "38.89094",
    "lng": "-77.18443"
  },
  {
    "country": "US",
    "name": "West Gate",
    "lat": "38.78289",
    "lng": "-77.49749"
  },
  {
    "country": "US",
    "name": "West Lynchburg",
    "lat": "37.4032",
    "lng": "-79.17808"
  },
  {
    "country": "US",
    "name": "West Point",
    "lat": "37.53153",
    "lng": "-76.79635"
  },
  {
    "country": "US",
    "name": "West Springfield",
    "lat": "38.77261",
    "lng": "-77.22109"
  },
  {
    "country": "US",
    "name": "Weyers Cave",
    "lat": "38.28846",
    "lng": "-78.91308"
  },
  {
    "country": "US",
    "name": "Williamsburg",
    "lat": "37.2707",
    "lng": "-76.70746"
  },
  {
    "country": "US",
    "name": "Winchester",
    "lat": "39.18566",
    "lng": "-78.16333"
  },
  {
    "country": "US",
    "name": "Windsor",
    "lat": "36.80848",
    "lng": "-76.74412"
  },
  {
    "country": "US",
    "name": "Wolf Trap",
    "lat": "38.93983",
    "lng": "-77.28609"
  },
  {
    "country": "US",
    "name": "Woodbridge",
    "lat": "38.65817",
    "lng": "-77.2497"
  },
  {
    "country": "US",
    "name": "Woodlawn",
    "lat": "36.72235",
    "lng": "-80.82285"
  },
  {
    "country": "US",
    "name": "Woodlawn",
    "lat": "38.71678",
    "lng": "-77.13276"
  },
  {
    "country": "US",
    "name": "Woodstock",
    "lat": "38.88178",
    "lng": "-78.50584"
  },
  {
    "country": "US",
    "name": "Wyndham",
    "lat": "37.69848",
    "lng": "-77.61249"
  },
  {
    "country": "US",
    "name": "Wytheville",
    "lat": "36.94845",
    "lng": "-81.08481"
  },
  {
    "country": "US",
    "name": "Yorkshire",
    "lat": "38.79317",
    "lng": "-77.44777"
  },
  {
    "country": "US",
    "name": "Alderson",
    "lat": "37.72595",
    "lng": "-80.64202"
  },
  {
    "country": "US",
    "name": "Alum Creek",
    "lat": "38.28676",
    "lng": "-81.80513"
  },
  {
    "country": "US",
    "name": "Ansted",
    "lat": "38.13622",
    "lng": "-81.09955"
  },
  {
    "country": "US",
    "name": "Barboursville",
    "lat": "38.40953",
    "lng": "-82.29459"
  },
  {
    "country": "US",
    "name": "Barrackville",
    "lat": "39.5037",
    "lng": "-80.16675"
  },
  {
    "country": "US",
    "name": "Beaver",
    "lat": "37.74781",
    "lng": "-81.14352"
  },
  {
    "country": "US",
    "name": "Beckley",
    "lat": "37.77817",
    "lng": "-81.18816"
  },
  {
    "country": "US",
    "name": "Belington",
    "lat": "39.0251",
    "lng": "-79.93563"
  },
  {
    "country": "US",
    "name": "Belle",
    "lat": "38.23205",
    "lng": "-81.53762"
  },
  {
    "country": "US",
    "name": "Berkeley Springs",
    "lat": "39.6248",
    "lng": "-78.22472"
  },
  {
    "country": "US",
    "name": "Bethlehem",
    "lat": "39.39203",
    "lng": "-80.28064"
  },
  {
    "country": "US",
    "name": "Blennerhassett",
    "lat": "39.26369",
    "lng": "-81.62929"
  },
  {
    "country": "US",
    "name": "Bluefield",
    "lat": "37.26984",
    "lng": "-81.22232"
  },
  {
    "country": "US",
    "name": "Bluewell",
    "lat": "37.31262",
    "lng": "-81.25982"
  },
  {
    "country": "US",
    "name": "Boaz",
    "lat": "39.36146",
    "lng": "-81.50207"
  },
  {
    "country": "US",
    "name": "Bolivar",
    "lat": "39.32343",
    "lng": "-77.75277"
  },
  {
    "country": "US",
    "name": "Bradley",
    "lat": "37.86539",
    "lng": "-81.19399"
  },
  {
    "country": "US",
    "name": "Bridgeport",
    "lat": "39.28648",
    "lng": "-80.2562"
  },
  {
    "country": "US",
    "name": "Brookhaven",
    "lat": "39.61175",
    "lng": "-79.90451"
  },
  {
    "country": "US",
    "name": "Brush Fork",
    "lat": "37.28095",
    "lng": "-81.25593"
  },
  {
    "country": "US",
    "name": "Buckhannon",
    "lat": "38.99399",
    "lng": "-80.23203"
  },
  {
    "country": "US",
    "name": "Buffalo",
    "lat": "38.61759",
    "lng": "-81.9818"
  },
  {
    "country": "US",
    "name": "Ceredo",
    "lat": "38.39647",
    "lng": "-82.55877"
  },
  {
    "country": "US",
    "name": "Chapmanville",
    "lat": "37.97371",
    "lng": "-82.01735"
  },
  {
    "country": "US",
    "name": "Charles Town",
    "lat": "39.28899",
    "lng": "-77.85972"
  },
  {
    "country": "US",
    "name": "Charleston",
    "lat": "38.34982",
    "lng": "-81.63262"
  },
  {
    "country": "US",
    "name": "Cheat Lake",
    "lat": "39.67202",
    "lng": "-79.85339"
  },
  {
    "country": "US",
    "name": "Chesapeake",
    "lat": "38.22344",
    "lng": "-81.53623"
  },
  {
    "country": "US",
    "name": "Clarksburg",
    "lat": "39.28065",
    "lng": "-80.34453"
  },
  {
    "country": "US",
    "name": "Clay",
    "lat": "38.46038",
    "lng": "-81.08511"
  },
  {
    "country": "US",
    "name": "Clendenin",
    "lat": "38.48871",
    "lng": "-81.34817"
  },
  {
    "country": "US",
    "name": "Coal City",
    "lat": "37.679",
    "lng": "-81.21038"
  },
  {
    "country": "US",
    "name": "Coal Fork",
    "lat": "38.3176",
    "lng": "-81.52095"
  },
  {
    "country": "US",
    "name": "Crab Orchard",
    "lat": "37.74067",
    "lng": "-81.23066"
  },
  {
    "country": "US",
    "name": "Craigsville",
    "lat": "38.33067",
    "lng": "-80.65315"
  },
  {
    "country": "US",
    "name": "Cross Lanes",
    "lat": "38.42037",
    "lng": "-81.79068"
  },
  {
    "country": "US",
    "name": "Culloden",
    "lat": "38.42009",
    "lng": "-82.05542"
  },
  {
    "country": "US",
    "name": "Daniels",
    "lat": "37.74327",
    "lng": "-81.12408"
  },
  {
    "country": "US",
    "name": "Despard",
    "lat": "39.2887",
    "lng": "-80.30592"
  },
  {
    "country": "US",
    "name": "Dunbar",
    "lat": "38.36065",
    "lng": "-81.73735"
  },
  {
    "country": "US",
    "name": "Eleanor",
    "lat": "38.53759",
    "lng": "-81.93236"
  },
  {
    "country": "US",
    "name": "Elizabeth",
    "lat": "39.06341",
    "lng": "-81.39512"
  },
  {
    "country": "US",
    "name": "Elkins",
    "lat": "38.92594",
    "lng": "-79.84673"
  },
  {
    "country": "US",
    "name": "Elkview",
    "lat": "38.44288",
    "lng": "-81.4804"
  },
  {
    "country": "US",
    "name": "Fairlea",
    "lat": "37.78068",
    "lng": "-80.45702"
  },
  {
    "country": "US",
    "name": "Fairmont",
    "lat": "39.48508",
    "lng": "-80.14258"
  },
  {
    "country": "US",
    "name": "Fayetteville",
    "lat": "38.05289",
    "lng": "-81.10399"
  },
  {
    "country": "US",
    "name": "Fort Ashby",
    "lat": "39.50315",
    "lng": "-78.76863"
  },
  {
    "country": "US",
    "name": "Franklin",
    "lat": "38.64289",
    "lng": "-79.33115"
  },
  {
    "country": "US",
    "name": "Gilbert Creek",
    "lat": "37.57594",
    "lng": "-81.89484"
  },
  {
    "country": "US",
    "name": "Glenville",
    "lat": "38.93426",
    "lng": "-80.8376"
  },
  {
    "country": "US",
    "name": "Glendale",
    "lat": "39.94924",
    "lng": "-80.75425"
  },
  {
    "country": "US",
    "name": "Grafton",
    "lat": "39.34092",
    "lng": "-80.01897"
  },
  {
    "country": "US",
    "name": "Granville",
    "lat": "39.64591",
    "lng": "-79.98729"
  },
  {
    "country": "US",
    "name": "Grantsville",
    "lat": "38.92342",
    "lng": "-81.09595"
  },
  {
    "country": "US",
    "name": "Hamlin",
    "lat": "38.2787",
    "lng": "-82.10292"
  },
  {
    "country": "US",
    "name": "Harrisville",
    "lat": "39.20952",
    "lng": "-81.05178"
  },
  {
    "country": "US",
    "name": "Hinton",
    "lat": "37.67401",
    "lng": "-80.88925"
  },
  {
    "country": "US",
    "name": "Huntington",
    "lat": "38.41925",
    "lng": "-82.44515"
  },
  {
    "country": "US",
    "name": "Hurricane",
    "lat": "38.43259",
    "lng": "-82.02014"
  },
  {
    "country": "US",
    "name": "Inwood",
    "lat": "39.35788",
    "lng": "-78.04"
  },
  {
    "country": "US",
    "name": "Kenova",
    "lat": "38.39897",
    "lng": "-82.57821"
  },
  {
    "country": "US",
    "name": "Keyser",
    "lat": "39.44093",
    "lng": "-78.97392"
  },
  {
    "country": "US",
    "name": "Kingwood",
    "lat": "39.47176",
    "lng": "-79.68339"
  },
  {
    "country": "US",
    "name": "Lavalette",
    "lat": "38.32286",
    "lng": "-82.44682"
  },
  {
    "country": "US",
    "name": "Lesage",
    "lat": "38.50647",
    "lng": "-82.29848"
  },
  {
    "country": "US",
    "name": "Lewisburg",
    "lat": "37.80179",
    "lng": "-80.44563"
  },
  {
    "country": "US",
    "name": "Logan",
    "lat": "37.84871",
    "lng": "-81.99346"
  },
  {
    "country": "US",
    "name": "Lubeck",
    "lat": "39.23535",
    "lng": "-81.63124"
  },
  {
    "country": "US",
    "name": "Mabscott",
    "lat": "37.77095",
    "lng": "-81.20843"
  },
  {
    "country": "US",
    "name": "MacArthur",
    "lat": "37.75845",
    "lng": "-81.2126"
  },
  {
    "country": "US",
    "name": "Madison",
    "lat": "38.06705",
    "lng": "-81.81929"
  },
  {
    "country": "US",
    "name": "Mallory",
    "lat": "37.73066",
    "lng": "-81.8379"
  },
  {
    "country": "US",
    "name": "Mannington",
    "lat": "39.53092",
    "lng": "-80.34342"
  },
  {
    "country": "US",
    "name": "Marlinton",
    "lat": "38.22345",
    "lng": "-80.09451"
  },
  {
    "country": "US",
    "name": "Marmet",
    "lat": "38.24538",
    "lng": "-81.56706"
  },
  {
    "country": "US",
    "name": "Martinsburg",
    "lat": "39.45621",
    "lng": "-77.96389"
  },
  {
    "country": "US",
    "name": "McMechen",
    "lat": "39.98813",
    "lng": "-80.73147"
  },
  {
    "country": "US",
    "name": "Middlebourne",
    "lat": "39.4923",
    "lng": "-80.90372"
  },
  {
    "country": "US",
    "name": "Milton",
    "lat": "38.43453",
    "lng": "-82.13236"
  },
  {
    "country": "US",
    "name": "Mineral Wells",
    "lat": "39.19035",
    "lng": "-81.53207"
  },
  {
    "country": "US",
    "name": "Monongah",
    "lat": "39.46258",
    "lng": "-80.21814"
  },
  {
    "country": "US",
    "name": "Montgomery",
    "lat": "38.18038",
    "lng": "-81.32845"
  },
  {
    "country": "US",
    "name": "Moorefield",
    "lat": "39.06233",
    "lng": "-78.96947"
  },
  {
    "country": "US",
    "name": "Morgantown",
    "lat": "39.62953",
    "lng": "-79.9559"
  },
  {
    "country": "US",
    "name": "Moundsville",
    "lat": "39.92035",
    "lng": "-80.74314"
  },
  {
    "country": "US",
    "name": "Mount Hope",
    "lat": "37.89539",
    "lng": "-81.16427"
  },
  {
    "country": "US",
    "name": "Mullens",
    "lat": "37.58317",
    "lng": "-81.38038"
  },
  {
    "country": "US",
    "name": "New Martinsville",
    "lat": "39.64452",
    "lng": "-80.8576"
  },
  {
    "country": "US",
    "name": "New Haven",
    "lat": "38.98647",
    "lng": "-81.97347"
  },
  {
    "country": "US",
    "name": "Nitro",
    "lat": "38.41481",
    "lng": "-81.84402"
  },
  {
    "country": "US",
    "name": "Nutter Fort",
    "lat": "39.26342",
    "lng": "-80.31981"
  },
  {
    "country": "US",
    "name": "Oak Hill",
    "lat": "37.97233",
    "lng": "-81.14871"
  },
  {
    "country": "US",
    "name": "Oceana",
    "lat": "37.69206",
    "lng": "-81.624"
  },
  {
    "country": "US",
    "name": "Paden City",
    "lat": "39.60285",
    "lng": "-80.93677"
  },
  {
    "country": "US",
    "name": "Parkersburg",
    "lat": "39.26674",
    "lng": "-81.56151"
  },
  {
    "country": "US",
    "name": "Parsons",
    "lat": "39.09649",
    "lng": "-79.6809"
  },
  {
    "country": "US",
    "name": "Pea Ridge",
    "lat": "38.41397",
    "lng": "-82.31987"
  },
  {
    "country": "US",
    "name": "Pennsboro",
    "lat": "39.28508",
    "lng": "-80.96844"
  },
  {
    "country": "US",
    "name": "Petersburg",
    "lat": "38.99261",
    "lng": "-79.12392"
  },
  {
    "country": "US",
    "name": "Philippi",
    "lat": "39.15232",
    "lng": "-80.04036"
  },
  {
    "country": "US",
    "name": "Pinch",
    "lat": "38.40871",
    "lng": "-81.48179"
  },
  {
    "country": "US",
    "name": "Pineville",
    "lat": "37.58317",
    "lng": "-81.53705"
  },
  {
    "country": "US",
    "name": "Pleasant Valley",
    "lat": "39.45536",
    "lng": "-80.14175"
  },
  {
    "country": "US",
    "name": "Point Pleasant",
    "lat": "38.84453",
    "lng": "-82.13709"
  },
  {
    "country": "US",
    "name": "Princeton",
    "lat": "37.36623",
    "lng": "-81.10259"
  },
  {
    "country": "US",
    "name": "Prosperity",
    "lat": "37.8365",
    "lng": "-81.20177"
  },
  {
    "country": "US",
    "name": "Rainelle",
    "lat": "37.96873",
    "lng": "-80.76703"
  },
  {
    "country": "US",
    "name": "Rand",
    "lat": "38.2826",
    "lng": "-81.56234"
  },
  {
    "country": "US",
    "name": "Ranson",
    "lat": "39.2951",
    "lng": "-77.86055"
  },
  {
    "country": "US",
    "name": "Ravenswood",
    "lat": "38.94814",
    "lng": "-81.76096"
  },
  {
    "country": "US",
    "name": "Richwood",
    "lat": "38.22484",
    "lng": "-80.53314"
  },
  {
    "country": "US",
    "name": "Ripley",
    "lat": "38.8187",
    "lng": "-81.71069"
  },
  {
    "country": "US",
    "name": "Romney",
    "lat": "39.34204",
    "lng": "-78.75668"
  },
  {
    "country": "US",
    "name": "Ronceverte",
    "lat": "37.74984",
    "lng": "-80.46285"
  },
  {
    "country": "US",
    "name": "Saint Albans",
    "lat": "38.38565",
    "lng": "-81.83624"
  },
  {
    "country": "US",
    "name": "Saint Marys",
    "lat": "39.39174",
    "lng": "-81.20511"
  },
  {
    "country": "US",
    "name": "Salem",
    "lat": "39.28287",
    "lng": "-80.55899"
  },
  {
    "country": "US",
    "name": "Shady Spring",
    "lat": "37.70567",
    "lng": "-81.09843"
  },
  {
    "country": "US",
    "name": "Shannondale",
    "lat": "39.21705",
    "lng": "-77.80749"
  },
  {
    "country": "US",
    "name": "Shepherdstown",
    "lat": "39.4301",
    "lng": "-77.80416"
  },
  {
    "country": "US",
    "name": "Shinnston",
    "lat": "39.39564",
    "lng": "-80.30009"
  },
  {
    "country": "US",
    "name": "Sissonville",
    "lat": "38.52815",
    "lng": "-81.63096"
  },
  {
    "country": "US",
    "name": "Sistersville",
    "lat": "39.56424",
    "lng": "-80.99594"
  },
  {
    "country": "US",
    "name": "Sophia",
    "lat": "37.70761",
    "lng": "-81.25066"
  },
  {
    "country": "US",
    "name": "South Charleston",
    "lat": "38.36843",
    "lng": "-81.69957"
  },
  {
    "country": "US",
    "name": "Spencer",
    "lat": "38.80203",
    "lng": "-81.35095"
  },
  {
    "country": "US",
    "name": "Stanaford",
    "lat": "37.81595",
    "lng": "-81.15232"
  },
  {
    "country": "US",
    "name": "Star City",
    "lat": "39.65841",
    "lng": "-79.98645"
  },
  {
    "country": "US",
    "name": "Stonewood",
    "lat": "39.25092",
    "lng": "-80.31231"
  },
  {
    "country": "US",
    "name": "Summersville",
    "lat": "38.28122",
    "lng": "-80.8526"
  },
  {
    "country": "US",
    "name": "Sutton",
    "lat": "38.66454",
    "lng": "-80.70982"
  },
  {
    "country": "US",
    "name": "Teays Valley",
    "lat": "38.45009",
    "lng": "-81.9293"
  },
  {
    "country": "US",
    "name": "Terra Alta",
    "lat": "39.44565",
    "lng": "-79.54644"
  },
  {
    "country": "US",
    "name": "Union",
    "lat": "37.59151",
    "lng": "-80.54368"
  },
  {
    "country": "US",
    "name": "Tornado",
    "lat": "38.34287",
    "lng": "-81.8443"
  },
  {
    "country": "US",
    "name": "Vienna",
    "lat": "39.32702",
    "lng": "-81.54846"
  },
  {
    "country": "US",
    "name": "Washington",
    "lat": "39.26119",
    "lng": "-81.6718"
  },
  {
    "country": "US",
    "name": "Wayne",
    "lat": "38.22147",
    "lng": "-82.44237"
  },
  {
    "country": "US",
    "name": "Webster Springs",
    "lat": "38.47927",
    "lng": "-80.41342"
  },
  {
    "country": "US",
    "name": "Welch",
    "lat": "37.43289",
    "lng": "-81.58455"
  },
  {
    "country": "US",
    "name": "West Union",
    "lat": "39.29647",
    "lng": "-80.77705"
  },
  {
    "country": "US",
    "name": "Weston",
    "lat": "39.03843",
    "lng": "-80.46731"
  },
  {
    "country": "US",
    "name": "Westover",
    "lat": "39.63453",
    "lng": "-79.96979"
  },
  {
    "country": "US",
    "name": "White Sulphur Springs",
    "lat": "37.79651",
    "lng": "-80.29757"
  },
  {
    "country": "US",
    "name": "Wiley Ford",
    "lat": "39.61453",
    "lng": "-78.77502"
  },
  {
    "country": "US",
    "name": "Williamson",
    "lat": "37.67427",
    "lng": "-82.27736"
  },
  {
    "country": "US",
    "name": "Williamstown",
    "lat": "39.40063",
    "lng": "-81.44818"
  },
  {
    "country": "US",
    "name": "Winfield",
    "lat": "38.53314",
    "lng": "-81.89347"
  },
  {
    "country": "US",
    "name": "Elba",
    "lat": "31.41461",
    "lng": "-86.06772"
  },
  {
    "country": "US",
    "name": "Elmore",
    "lat": "32.53874",
    "lng": "-86.31497"
  },
  {
    "country": "US",
    "name": "Sherwood",
    "lat": "34.81509",
    "lng": "-92.22432"
  },
  {
    "country": "US",
    "name": "Franklin",
    "lat": "39.48061",
    "lng": "-86.05499"
  },
  {
    "country": "US",
    "name": "Newton",
    "lat": "38.99088",
    "lng": "-88.16254"
  },
  {
    "country": "US",
    "name": "Linn",
    "lat": "38.48587",
    "lng": "-91.85045"
  },
  {
    "country": "US",
    "name": "Villa Ridge",
    "lat": "38.47255",
    "lng": "-90.8868"
  },
  {
    "country": "US",
    "name": "Rosedale",
    "lat": "33.85344",
    "lng": "-91.02789"
  },
  {
    "country": "US",
    "name": "Shaw",
    "lat": "33.60211",
    "lng": "-90.77458"
  },
  {
    "country": "US",
    "name": "Merchantville",
    "lat": "39.94734",
    "lng": "-75.06656"
  },
  {
    "country": "US",
    "name": "Florence",
    "lat": "39.73428",
    "lng": "-74.91822"
  },
  {
    "country": "US",
    "name": "Oak Valley",
    "lat": "39.80122",
    "lng": "-75.1624"
  },
  {
    "country": "US",
    "name": "Bremen",
    "lat": "39.70173",
    "lng": "-82.42682"
  },
  {
    "country": "US",
    "name": "Chillicothe",
    "lat": "39.33312",
    "lng": "-82.9824"
  },
  {
    "country": "US",
    "name": "Coalgate",
    "lat": "34.53815",
    "lng": "-96.21861"
  },
  {
    "country": "US",
    "name": "Dilley",
    "lat": "28.66748",
    "lng": "-99.17059"
  },
  {
    "country": "US",
    "name": "Devine",
    "lat": "29.13996",
    "lng": "-98.90531"
  },
  {
    "country": "US",
    "name": "Hickory Creek",
    "lat": "33.12234",
    "lng": "-97.04306"
  },
  {
    "country": "US",
    "name": "Wallis",
    "lat": "29.63135",
    "lng": "-96.06524"
  },
  {
    "country": "US",
    "name": "New Kent",
    "lat": "37.51765",
    "lng": "-76.97886"
  },
  {
    "country": "US",
    "name": "Independence",
    "lat": "36.62245",
    "lng": "-81.15309"
  },
  {
    "country": "US",
    "name": "Bay City",
    "lat": "28.98276",
    "lng": "-95.9694"
  },
  {
    "country": "US",
    "name": "Wise",
    "lat": "36.97593",
    "lng": "-82.57571"
  },
  {
    "country": "US",
    "name": "Abbeville",
    "lat": "31.57184",
    "lng": "-85.25049"
  },
  {
    "country": "US",
    "name": "Adamsville",
    "lat": "33.60094",
    "lng": "-86.95611"
  },
  {
    "country": "US",
    "name": "Alabaster",
    "lat": "33.24428",
    "lng": "-86.81638"
  },
  {
    "country": "US",
    "name": "Albertville",
    "lat": "34.26783",
    "lng": "-86.20878"
  },
  {
    "country": "US",
    "name": "Alexander City",
    "lat": "32.94401",
    "lng": "-85.95385"
  },
  {
    "country": "US",
    "name": "Alexandria",
    "lat": "33.77399",
    "lng": "-85.88552"
  },
  {
    "country": "US",
    "name": "Aliceville",
    "lat": "33.12957",
    "lng": "-88.15142"
  },
  {
    "country": "US",
    "name": "Andalusia",
    "lat": "31.30808",
    "lng": "-86.48243"
  },
  {
    "country": "US",
    "name": "Anniston",
    "lat": "33.65983",
    "lng": "-85.83163"
  },
  {
    "country": "US",
    "name": "Arab",
    "lat": "34.31815",
    "lng": "-86.49582"
  },
  {
    "country": "US",
    "name": "Argo",
    "lat": "33.68778",
    "lng": "-86.50051"
  },
  {
    "country": "US",
    "name": "Athens",
    "lat": "34.80243",
    "lng": "-86.97219"
  },
  {
    "country": "US",
    "name": "Ashford",
    "lat": "31.18296",
    "lng": "-85.23632"
  },
  {
    "country": "US",
    "name": "Ashland",
    "lat": "33.27373",
    "lng": "-85.83607"
  },
  {
    "country": "US",
    "name": "Ashville",
    "lat": "33.83704",
    "lng": "-86.25442"
  },
  {
    "country": "US",
    "name": "Atmore",
    "lat": "31.02379",
    "lng": "-87.49387"
  },
  {
    "country": "US",
    "name": "Attalla",
    "lat": "34.02176",
    "lng": "-86.08859"
  },
  {
    "country": "US",
    "name": "Auburn",
    "lat": "32.60986",
    "lng": "-85.48078"
  },
  {
    "country": "US",
    "name": "Ballplay",
    "lat": "34.05871",
    "lng": "-85.80802"
  },
  {
    "country": "US",
    "name": "South Coventry",
    "lat": "41.7701",
    "lng": "-72.30508"
  },
  {
    "country": "US",
    "name": "Tariffville",
    "lat": "41.90871",
    "lng": "-72.7601"
  },
  {
    "country": "US",
    "name": "Cos Cob",
    "lat": "41.03343",
    "lng": "-73.59957"
  },
  {
    "country": "US",
    "name": "Canton",
    "lat": "40.55809",
    "lng": "-90.03512"
  },
  {
    "country": "US",
    "name": "Deer Park",
    "lat": "41.29503",
    "lng": "-89.03619"
  },
  {
    "country": "US",
    "name": "Coventry Lake",
    "lat": "41.77232",
    "lng": "-72.33258"
  },
  {
    "country": "US",
    "name": "Glendale Heights",
    "lat": "41.9146",
    "lng": "-88.06486"
  },
  {
    "country": "US",
    "name": "Lena",
    "lat": "42.37946",
    "lng": "-89.82234"
  },
  {
    "country": "US",
    "name": "Cromwell",
    "lat": "41.5951",
    "lng": "-72.64537"
  },
  {
    "country": "US",
    "name": "East Falmouth",
    "lat": "41.57844",
    "lng": "-70.55864"
  },
  {
    "country": "US",
    "name": "Crystal Lake",
    "lat": "41.93176",
    "lng": "-72.37842"
  },
  {
    "country": "US",
    "name": "North Andover",
    "lat": "42.6987",
    "lng": "-71.13506"
  },
  {
    "country": "US",
    "name": "Revere",
    "lat": "42.40843",
    "lng": "-71.01199"
  },
  {
    "country": "US",
    "name": "West Barnstable",
    "lat": "41.70566",
    "lng": "-70.37447"
  },
  {
    "country": "US",
    "name": "Alfred",
    "lat": "43.47647",
    "lng": "-70.71839"
  },
  {
    "country": "US",
    "name": "Danbury",
    "lat": "41.39482",
    "lng": "-73.45401"
  },
  {
    "country": "US",
    "name": "Berwick",
    "lat": "43.26592",
    "lng": "-70.8645"
  },
  {
    "country": "US",
    "name": "Hope",
    "lat": "44.26508",
    "lng": "-69.15893"
  },
  {
    "country": "US",
    "name": "Danielson",
    "lat": "41.8026",
    "lng": "-71.88591"
  },
  {
    "country": "US",
    "name": "Darien",
    "lat": "41.07871",
    "lng": "-73.46929"
  },
  {
    "country": "US",
    "name": "Rockland",
    "lat": "44.10369",
    "lng": "-69.10893"
  },
  {
    "country": "US",
    "name": "Union",
    "lat": "44.21147",
    "lng": "-69.27421"
  },
  {
    "country": "US",
    "name": "Inkster",
    "lat": "42.2942",
    "lng": "-83.30993"
  },
  {
    "country": "US",
    "name": "Edina",
    "lat": "40.16754",
    "lng": "-92.17268"
  },
  {
    "country": "US",
    "name": "Derby",
    "lat": "41.32065",
    "lng": "-73.089"
  },
  {
    "country": "US",
    "name": "Yardville",
    "lat": "40.18122",
    "lng": "-74.66432"
  },
  {
    "country": "US",
    "name": "Camillus",
    "lat": "43.03923",
    "lng": "-76.3041"
  },
  {
    "country": "US",
    "name": "Clyde",
    "lat": "43.08423",
    "lng": "-76.8694"
  },
  {
    "country": "US",
    "name": "Durham",
    "lat": "41.48176",
    "lng": "-72.68121"
  },
  {
    "country": "US",
    "name": "Wayland",
    "lat": "42.56784",
    "lng": "-77.58971"
  },
  {
    "country": "US",
    "name": "Watervliet",
    "lat": "42.73008",
    "lng": "-73.70123"
  },
  {
    "country": "US",
    "name": "East Brooklyn",
    "lat": "41.79677",
    "lng": "-71.89729"
  },
  {
    "country": "US",
    "name": "Camden",
    "lat": "41.23783",
    "lng": "-82.30572"
  },
  {
    "country": "US",
    "name": "Cleveland Heights",
    "lat": "41.52005",
    "lng": "-81.55624"
  },
  {
    "country": "US",
    "name": "Genoa",
    "lat": "41.51811",
    "lng": "-83.35909"
  },
  {
    "country": "US",
    "name": "East Haddam",
    "lat": "41.45315",
    "lng": "-72.4612"
  },
  {
    "country": "US",
    "name": "East Hampton",
    "lat": "41.57593",
    "lng": "-72.50259"
  },
  {
    "country": "US",
    "name": "East Hartford",
    "lat": "41.78232",
    "lng": "-72.61203"
  },
  {
    "country": "US",
    "name": "East Haven",
    "lat": "41.27621",
    "lng": "-72.86843"
  },
  {
    "country": "US",
    "name": "Carnegie",
    "lat": "40.40868",
    "lng": "-80.08339"
  },
  {
    "country": "US",
    "name": "East Norwalk",
    "lat": "41.10565",
    "lng": "-73.39845"
  },
  {
    "country": "US",
    "name": "Easton",
    "lat": "41.25287",
    "lng": "-73.29734"
  },
  {
    "country": "US",
    "name": "Hayti",
    "lat": "44.65719",
    "lng": "-97.20507"
  },
  {
    "country": "US",
    "name": "Brussels",
    "lat": "44.73611",
    "lng": "-87.62093"
  },
  {
    "country": "US",
    "name": "Ellington",
    "lat": "41.90399",
    "lng": "-72.46981"
  },
  {
    "country": "US",
    "name": "Enfield",
    "lat": "41.97621",
    "lng": "-72.59176"
  },
  {
    "country": "US",
    "name": "Fairfield",
    "lat": "41.14121",
    "lng": "-73.26373"
  },
  {
    "country": "US",
    "name": "Farmington",
    "lat": "41.71982",
    "lng": "-72.83204"
  },
  {
    "country": "US",
    "name": "Gales Ferry",
    "lat": "41.42982",
    "lng": "-72.08202"
  },
  {
    "country": "US",
    "name": "Georgetown",
    "lat": "41.25565",
    "lng": "-73.43484"
  },
  {
    "country": "US",
    "name": "Glastonbury",
    "lat": "41.71232",
    "lng": "-72.60815"
  },
  {
    "country": "US",
    "name": "Glastonbury Center",
    "lat": "41.70093",
    "lng": "-72.59953"
  },
  {
    "country": "US",
    "name": "Glenville",
    "lat": "41.03538",
    "lng": "-73.65985"
  },
  {
    "country": "US",
    "name": "Greenwich",
    "lat": "41.02649",
    "lng": "-73.62846"
  },
  {
    "country": "US",
    "name": "Groton",
    "lat": "41.3501",
    "lng": "-72.07841"
  },
  {
    "country": "US",
    "name": "Guilford",
    "lat": "41.28899",
    "lng": "-72.68176"
  },
  {
    "country": "US",
    "name": "Hamden",
    "lat": "41.39593",
    "lng": "-72.89677"
  },
  {
    "country": "US",
    "name": "Hartford",
    "lat": "41.76371",
    "lng": "-72.68509"
  },
  {
    "country": "US",
    "name": "Hazardville",
    "lat": "41.98732",
    "lng": "-72.54481"
  },
  {
    "country": "US",
    "name": "Hebron",
    "lat": "41.65788",
    "lng": "-72.36592"
  },
  {
    "country": "US",
    "name": "Heritage Village",
    "lat": "41.48565",
    "lng": "-73.23789"
  },
  {
    "country": "US",
    "name": "Higganum",
    "lat": "41.49704",
    "lng": "-72.55703"
  },
  {
    "country": "US",
    "name": "Jewett City",
    "lat": "41.60677",
    "lng": "-71.98091"
  },
  {
    "country": "US",
    "name": "Kensington",
    "lat": "41.63538",
    "lng": "-72.76871"
  },
  {
    "country": "US",
    "name": "Kent",
    "lat": "41.72482",
    "lng": "-73.47707"
  },
  {
    "country": "US",
    "name": "Killingly Center",
    "lat": "41.83871",
    "lng": "-71.86924"
  },
  {
    "country": "US",
    "name": "Lake Pocotopaug",
    "lat": "41.59843",
    "lng": "-72.51037"
  },
  {
    "country": "US",
    "name": "Ledyard",
    "lat": "41.43982",
    "lng": "-72.01424"
  },
  {
    "country": "US",
    "name": "Lisbon",
    "lat": "41.60399",
    "lng": "-72.01174"
  },
  {
    "country": "US",
    "name": "Litchfield",
    "lat": "41.74732",
    "lng": "-73.18872"
  },
  {
    "country": "US",
    "name": "Long Hill",
    "lat": "41.35399",
    "lng": "-72.0523"
  },
  {
    "country": "US",
    "name": "Madison",
    "lat": "41.27954",
    "lng": "-72.59843"
  },
  {
    "country": "US",
    "name": "Manchester",
    "lat": "41.77593",
    "lng": "-72.52148"
  },
  {
    "country": "US",
    "name": "Mansfield City",
    "lat": "41.76593",
    "lng": "-72.23369"
  },
  {
    "country": "US",
    "name": "Meriden",
    "lat": "41.53815",
    "lng": "-72.80704"
  },
  {
    "country": "US",
    "name": "Middlebury",
    "lat": "41.52787",
    "lng": "-73.12761"
  },
  {
    "country": "US",
    "name": "Middletown",
    "lat": "41.56232",
    "lng": "-72.65065"
  },
  {
    "country": "US",
    "name": "Milford",
    "lat": "41.22232",
    "lng": "-73.0565"
  },
  {
    "country": "US",
    "name": "Montville Center",
    "lat": "41.47899",
    "lng": "-72.15119"
  },
  {
    "country": "US",
    "name": "Moodus",
    "lat": "41.50288",
    "lng": "-72.45009"
  },
  {
    "country": "US",
    "name": "Moosup",
    "lat": "41.71288",
    "lng": "-71.88091"
  },
  {
    "country": "US",
    "name": "Mystic",
    "lat": "41.35427",
    "lng": "-71.96646"
  },
  {
    "country": "US",
    "name": "Naugatuck",
    "lat": "41.48593",
    "lng": "-73.05066"
  },
  {
    "country": "US",
    "name": "New Britain",
    "lat": "41.66121",
    "lng": "-72.77954"
  },
  {
    "country": "US",
    "name": "New Canaan",
    "lat": "41.14676",
    "lng": "-73.49484"
  },
  {
    "country": "US",
    "name": "New Fairfield",
    "lat": "41.46648",
    "lng": "-73.48568"
  },
  {
    "country": "US",
    "name": "New Haven",
    "lat": "41.30815",
    "lng": "-72.92816"
  },
  {
    "country": "US",
    "name": "New London",
    "lat": "41.35565",
    "lng": "-72.09952"
  },
  {
    "country": "US",
    "name": "New Milford",
    "lat": "41.57704",
    "lng": "-73.40845"
  },
  {
    "country": "US",
    "name": "New Preston",
    "lat": "41.6751",
    "lng": "-73.35179"
  },
  {
    "country": "US",
    "name": "Newington",
    "lat": "41.69788",
    "lng": "-72.72371"
  },
  {
    "country": "US",
    "name": "Niantic",
    "lat": "41.32538",
    "lng": "-72.19313"
  },
  {
    "country": "US",
    "name": "Noank",
    "lat": "41.32788",
    "lng": "-71.99063"
  },
  {
    "country": "US",
    "name": "North Branford",
    "lat": "41.3276",
    "lng": "-72.76732"
  },
  {
    "country": "US",
    "name": "North Granby",
    "lat": "41.99593",
    "lng": "-72.82954"
  },
  {
    "country": "US",
    "name": "North Grosvenor Dale",
    "lat": "41.98565",
    "lng": "-71.89868"
  },
  {
    "country": "US",
    "name": "North Haven",
    "lat": "41.39093",
    "lng": "-72.85954"
  },
  {
    "country": "US",
    "name": "North Stamford",
    "lat": "41.13815",
    "lng": "-73.54346"
  },
  {
    "country": "US",
    "name": "Norwalk",
    "lat": "41.1176",
    "lng": "-73.4079"
  },
  {
    "country": "US",
    "name": "Norwich",
    "lat": "41.52426",
    "lng": "-72.07591"
  },
  {
    "country": "US",
    "name": "Oakville",
    "lat": "41.59343",
    "lng": "-73.08539"
  },
  {
    "country": "US",
    "name": "Old Greenwich",
    "lat": "41.02287",
    "lng": "-73.56485"
  },
  {
    "country": "US",
    "name": "Old Mystic",
    "lat": "41.39149",
    "lng": "-71.96174"
  },
  {
    "country": "US",
    "name": "Old Saybrook",
    "lat": "41.29177",
    "lng": "-72.3762"
  },
  {
    "country": "US",
    "name": "Orange",
    "lat": "41.27843",
    "lng": "-73.02566"
  },
  {
    "country": "US",
    "name": "Oxford",
    "lat": "41.43399",
    "lng": "-73.11678"
  },
  {
    "country": "US",
    "name": "Pawcatuck",
    "lat": "41.37732",
    "lng": "-71.83368"
  },
  {
    "country": "US",
    "name": "Pemberwick",
    "lat": "41.02565",
    "lng": "-73.66068"
  },
  {
    "country": "US",
    "name": "Plainfield",
    "lat": "41.67649",
    "lng": "-71.91507"
  },
  {
    "country": "US",
    "name": "Plainville",
    "lat": "41.67454",
    "lng": "-72.85816"
  },
  {
    "country": "US",
    "name": "Plymouth",
    "lat": "41.67204",
    "lng": "-73.05289"
  },
  {
    "country": "US",
    "name": "Poquonock Bridge",
    "lat": "41.3451",
    "lng": "-72.0248"
  },
  {
    "country": "US",
    "name": "Portland",
    "lat": "41.57288",
    "lng": "-72.64065"
  },
  {
    "country": "US",
    "name": "Prospect",
    "lat": "41.50232",
    "lng": "-72.97872"
  },
  {
    "country": "US",
    "name": "Preston City",
    "lat": "41.52899",
    "lng": "-71.97396"
  },
  {
    "country": "US",
    "name": "Putnam",
    "lat": "41.9151",
    "lng": "-71.90896"
  },
  {
    "country": "US",
    "name": "Quinebaug",
    "lat": "42.02371",
    "lng": "-71.9498"
  },
  {
    "country": "US",
    "name": "Ridgefield",
    "lat": "41.28148",
    "lng": "-73.49818"
  },
  {
    "country": "US",
    "name": "Riverside",
    "lat": "41.03371",
    "lng": "-73.57818"
  },
  {
    "country": "US",
    "name": "Rockville",
    "lat": "41.86676",
    "lng": "-72.44953"
  },
  {
    "country": "US",
    "name": "Salem",
    "lat": "41.49038",
    "lng": "-72.27536"
  },
  {
    "country": "US",
    "name": "Salmon Brook",
    "lat": "41.95649",
    "lng": "-72.79537"
  },
  {
    "country": "US",
    "name": "Saybrook Manor",
    "lat": "41.28538",
    "lng": "-72.39897"
  },
  {
    "country": "US",
    "name": "Seymour",
    "lat": "41.39676",
    "lng": "-73.07594"
  },
  {
    "country": "US",
    "name": "Shelton",
    "lat": "41.31649",
    "lng": "-73.09316"
  },
  {
    "country": "US",
    "name": "Sherman",
    "lat": "41.57926",
    "lng": "-73.49568"
  },
  {
    "country": "US",
    "name": "Sherwood Manor",
    "lat": "42.01343",
    "lng": "-72.56425"
  },
  {
    "country": "US",
    "name": "Somers",
    "lat": "41.98537",
    "lng": "-72.4462"
  },
  {
    "country": "US",
    "name": "South Windham",
    "lat": "41.67954",
    "lng": "-72.17036"
  },
  {
    "country": "US",
    "name": "South Windsor",
    "lat": "41.82371",
    "lng": "-72.6212"
  },
  {
    "country": "US",
    "name": "South Woodstock",
    "lat": "41.93899",
    "lng": "-71.95952"
  },
  {
    "country": "US",
    "name": "Southbury",
    "lat": "41.48148",
    "lng": "-73.21317"
  },
  {
    "country": "US",
    "name": "Southport",
    "lat": "41.13649",
    "lng": "-73.28345"
  },
  {
    "country": "US",
    "name": "Southwood Acres",
    "lat": "41.9626",
    "lng": "-72.57148"
  },
  {
    "country": "US",
    "name": "Stafford",
    "lat": "41.98482",
    "lng": "-72.28897"
  },
  {
    "country": "US",
    "name": "Stafford Springs",
    "lat": "41.95426",
    "lng": "-72.3023"
  },
  {
    "country": "US",
    "name": "Stamford",
    "lat": "41.05343",
    "lng": "-73.53873"
  },
  {
    "country": "US",
    "name": "Storrs",
    "lat": "41.80843",
    "lng": "-72.24952"
  },
  {
    "country": "US",
    "name": "Stratford",
    "lat": "41.18454",
    "lng": "-73.13317"
  },
  {
    "country": "US",
    "name": "Suffield Depot",
    "lat": "41.98121",
    "lng": "-72.64981"
  },
  {
    "country": "US",
    "name": "Terramuggus",
    "lat": "41.6351",
    "lng": "-72.47036"
  },
  {
    "country": "US",
    "name": "Terryville",
    "lat": "41.67815",
    "lng": "-73.01094"
  },
  {
    "country": "US",
    "name": "Thomaston",
    "lat": "41.67399",
    "lng": "-73.07316"
  },
  {
    "country": "US",
    "name": "Thompson",
    "lat": "41.95871",
    "lng": "-71.86257"
  },
  {
    "country": "US",
    "name": "Thompsonville",
    "lat": "41.99704",
    "lng": "-72.59898"
  },
  {
    "country": "US",
    "name": "Tolland",
    "lat": "41.87149",
    "lng": "-72.36869"
  },
  {
    "country": "US",
    "name": "Torrington",
    "lat": "41.80065",
    "lng": "-73.12122"
  },
  {
    "country": "US",
    "name": "Trumbull",
    "lat": "41.24287",
    "lng": "-73.20067"
  },
  {
    "country": "US",
    "name": "Uncasville",
    "lat": "41.43454",
    "lng": "-72.1098"
  },
  {
    "country": "US",
    "name": "Wallingford",
    "lat": "41.45704",
    "lng": "-72.82316"
  },
  {
    "country": "US",
    "name": "Washington",
    "lat": "41.63148",
    "lng": "-73.31067"
  },
  {
    "country": "US",
    "name": "Waterbury",
    "lat": "41.55815",
    "lng": "-73.0515"
  },
  {
    "country": "US",
    "name": "Watertown",
    "lat": "41.60621",
    "lng": "-73.11817"
  },
  {
    "country": "US",
    "name": "Wauregan",
    "lat": "41.74427",
    "lng": "-71.90924"
  },
  {
    "country": "US",
    "name": "Weatogue",
    "lat": "41.84371",
    "lng": "-72.82843"
  },
  {
    "country": "US",
    "name": "West Hartford",
    "lat": "41.76204",
    "lng": "-72.74204"
  },
  {
    "country": "US",
    "name": "West Haven",
    "lat": "41.27065",
    "lng": "-72.94705"
  },
  {
    "country": "US",
    "name": "West Simsbury",
    "lat": "41.87315",
    "lng": "-72.85815"
  },
  {
    "country": "US",
    "name": "West Torrington",
    "lat": "41.81843",
    "lng": "-73.14372"
  },
  {
    "country": "US",
    "name": "Westport",
    "lat": "41.14149",
    "lng": "-73.3579"
  },
  {
    "country": "US",
    "name": "Wethersfield",
    "lat": "41.71427",
    "lng": "-72.65259"
  },
  {
    "country": "US",
    "name": "Willimantic",
    "lat": "41.71065",
    "lng": "-72.20813"
  },
  {
    "country": "US",
    "name": "Wilton",
    "lat": "41.19537",
    "lng": "-73.4379"
  },
  {
    "country": "US",
    "name": "Winchester Center",
    "lat": "41.9001",
    "lng": "-73.13483"
  },
  {
    "country": "US",
    "name": "Windham",
    "lat": "41.69982",
    "lng": "-72.15702"
  },
  {
    "country": "US",
    "name": "Windsor",
    "lat": "41.8526",
    "lng": "-72.6437"
  },
  {
    "country": "US",
    "name": "Windsor Locks",
    "lat": "41.92926",
    "lng": "-72.62731"
  },
  {
    "country": "US",
    "name": "Winsted",
    "lat": "41.92121",
    "lng": "-73.06011"
  },
  {
    "country": "US",
    "name": "Wolcott",
    "lat": "41.60232",
    "lng": "-72.98677"
  },
  {
    "country": "US",
    "name": "Woodbridge",
    "lat": "41.3526",
    "lng": "-73.00844"
  },
  {
    "country": "US",
    "name": "Woodbury",
    "lat": "41.54454",
    "lng": "-73.209"
  },
  {
    "country": "US",
    "name": "Woodmont",
    "lat": "41.22815",
    "lng": "-72.99149"
  },
  {
    "country": "US",
    "name": "Ackley",
    "lat": "42.55415",
    "lng": "-93.05326"
  },
  {
    "country": "US",
    "name": "Adel",
    "lat": "41.61443",
    "lng": "-94.01745"
  },
  {
    "country": "US",
    "name": "Akron",
    "lat": "42.82888",
    "lng": "-96.55948"
  },
  {
    "country": "US",
    "name": "Albia",
    "lat": "41.02667",
    "lng": "-92.80575"
  },
  {
    "country": "US",
    "name": "Algona",
    "lat": "43.06997",
    "lng": "-94.23302"
  },
  {
    "country": "US",
    "name": "Allison",
    "lat": "42.75275",
    "lng": "-92.79519"
  },
  {
    "country": "US",
    "name": "Alta",
    "lat": "42.67359",
    "lng": "-95.29055"
  },
  {
    "country": "US",
    "name": "Alton",
    "lat": "42.98749",
    "lng": "-96.01057"
  },
  {
    "country": "US",
    "name": "Altoona",
    "lat": "41.64416",
    "lng": "-93.46466"
  },
  {
    "country": "US",
    "name": "Ames",
    "lat": "42.03471",
    "lng": "-93.61994"
  },
  {
    "country": "US",
    "name": "Anamosa",
    "lat": "42.10834",
    "lng": "-91.28516"
  },
  {
    "country": "US",
    "name": "Ankeny",
    "lat": "41.72971",
    "lng": "-93.60577"
  },
  {
    "country": "US",
    "name": "Aplington",
    "lat": "42.58415",
    "lng": "-92.88436"
  },
  {
    "country": "US",
    "name": "Arnolds Park",
    "lat": "43.37274",
    "lng": "-95.12388"
  },
  {
    "country": "US",
    "name": "Asbury",
    "lat": "42.51445",
    "lng": "-90.75152"
  },
  {
    "country": "US",
    "name": "Atkins",
    "lat": "41.99694",
    "lng": "-91.86213"
  },
  {
    "country": "US",
    "name": "Atlantic",
    "lat": "41.4036",
    "lng": "-95.01388"
  },
  {
    "country": "US",
    "name": "Audubon",
    "lat": "41.71804",
    "lng": "-94.93249"
  },
  {
    "country": "US",
    "name": "Avoca",
    "lat": "41.47666",
    "lng": "-95.33805"
  },
  {
    "country": "US",
    "name": "Baxter",
    "lat": "41.8261",
    "lng": "-93.15159"
  },
  {
    "country": "US",
    "name": "Bedford",
    "lat": "40.66693",
    "lng": "-94.72136"
  },
  {
    "country": "US",
    "name": "Belle Plaine",
    "lat": "41.89694",
    "lng": "-92.27824"
  },
  {
    "country": "US",
    "name": "Bellevue",
    "lat": "42.25863",
    "lng": "-90.42291"
  },
  {
    "country": "US",
    "name": "Belmond",
    "lat": "42.84608",
    "lng": "-93.6141"
  },
  {
    "country": "US",
    "name": "Bettendorf",
    "lat": "41.52448",
    "lng": "-90.51569"
  },
  {
    "country": "US",
    "name": "Bloomfield",
    "lat": "40.75169",
    "lng": "-92.41491"
  },
  {
    "country": "US",
    "name": "Blue Grass",
    "lat": "41.50892",
    "lng": "-90.76598"
  },
  {
    "country": "US",
    "name": "Bondurant",
    "lat": "41.70054",
    "lng": "-93.46216"
  },
  {
    "country": "US",
    "name": "Boone",
    "lat": "42.0597",
    "lng": "-93.88023"
  },
  {
    "country": "US",
    "name": "Britt",
    "lat": "43.09774",
    "lng": "-93.80189"
  },
  {
    "country": "US",
    "name": "Brooklyn",
    "lat": "41.73361",
    "lng": "-92.44546"
  },
  {
    "country": "US",
    "name": "Buffalo (historical)",
    "lat": "41.3111",
    "lng": "-94.00356"
  },
  {
    "country": "US",
    "name": "Buffalo",
    "lat": "41.45642",
    "lng": "-90.72347"
  },
  {
    "country": "US",
    "name": "Burlington",
    "lat": "40.80754",
    "lng": "-91.11292"
  },
  {
    "country": "US",
    "name": "Camanche",
    "lat": "41.78809",
    "lng": "-90.25624"
  },
  {
    "country": "US",
    "name": "Carlisle",
    "lat": "41.50082",
    "lng": "-93.49105"
  },
  {
    "country": "US",
    "name": "Carroll",
    "lat": "42.06582",
    "lng": "-94.86693"
  },
  {
    "country": "US",
    "name": "Carter Lake",
    "lat": "41.29055",
    "lng": "-95.91807"
  },
  {
    "country": "US",
    "name": "Cascade",
    "lat": "42.29862",
    "lng": "-91.01486"
  },
  {
    "country": "US",
    "name": "Cedar Falls",
    "lat": "42.52776",
    "lng": "-92.44547"
  },
  {
    "country": "US",
    "name": "Cedar Rapids",
    "lat": "42.00833",
    "lng": "-91.64407"
  },
  {
    "country": "US",
    "name": "Center Point",
    "lat": "42.19083",
    "lng": "-91.78518"
  },
  {
    "country": "US",
    "name": "Centerville",
    "lat": "40.73418",
    "lng": "-92.87409"
  },
  {
    "country": "US",
    "name": "Centerville",
    "lat": "42.09276",
    "lng": "-93.93551"
  },
  {
    "country": "US",
    "name": "Central City",
    "lat": "42.20388",
    "lng": "-91.52406"
  },
  {
    "country": "US",
    "name": "Chariton",
    "lat": "41.01389",
    "lng": "-93.3066"
  },
  {
    "country": "US",
    "name": "Charles City",
    "lat": "43.06636",
    "lng": "-92.67241"
  },
  {
    "country": "US",
    "name": "Cherokee",
    "lat": "42.74943",
    "lng": "-95.55167"
  },
  {
    "country": "US",
    "name": "Clarinda",
    "lat": "40.73981",
    "lng": "-95.038"
  },
  {
    "country": "US",
    "name": "Clarion",
    "lat": "42.73164",
    "lng": "-93.73299"
  },
  {
    "country": "US",
    "name": "Clarksville",
    "lat": "42.7847",
    "lng": "-92.66769"
  },
  {
    "country": "US",
    "name": "Clear Lake",
    "lat": "43.13802",
    "lng": "-93.37937"
  },
  {
    "country": "US",
    "name": "Clinton",
    "lat": "41.84447",
    "lng": "-90.18874"
  },
  {
    "country": "US",
    "name": "Clive",
    "lat": "41.60304",
    "lng": "-93.72411"
  },
  {
    "country": "US",
    "name": "Colfax",
    "lat": "41.67777",
    "lng": "-93.2452"
  },
  {
    "country": "US",
    "name": "Columbus Junction",
    "lat": "41.28003",
    "lng": "-91.36071"
  },
  {
    "country": "US",
    "name": "Conrad",
    "lat": "42.22471",
    "lng": "-92.87465"
  },
  {
    "country": "US",
    "name": "Coon Rapids",
    "lat": "41.87082",
    "lng": "-94.67748"
  },
  {
    "country": "US",
    "name": "Coralville",
    "lat": "41.6764",
    "lng": "-91.58045"
  },
  {
    "country": "US",
    "name": "Corning",
    "lat": "40.98999",
    "lng": "-94.74081"
  },
  {
    "country": "US",
    "name": "Corydon",
    "lat": "40.75695",
    "lng": "-93.31882"
  },
  {
    "country": "US",
    "name": "Council Bluffs",
    "lat": "41.26194",
    "lng": "-95.86083"
  },
  {
    "country": "US",
    "name": "Cresco",
    "lat": "43.38136",
    "lng": "-92.11405"
  },
  {
    "country": "US",
    "name": "Creston",
    "lat": "41.0586",
    "lng": "-94.36135"
  },
  {
    "country": "US",
    "name": "Dakota City",
    "lat": "42.72219",
    "lng": "-94.19718"
  },
  {
    "country": "US",
    "name": "Dallas Center",
    "lat": "41.68443",
    "lng": "-93.96106"
  },
  {
    "country": "US",
    "name": "Davenport",
    "lat": "41.52364",
    "lng": "-90.57764"
  },
  {
    "country": "US",
    "name": "De Soto",
    "lat": "41.53166",
    "lng": "-94.00967"
  },
  {
    "country": "US",
    "name": "De Witt",
    "lat": "41.82336",
    "lng": "-90.53819"
  },
  {
    "country": "US",
    "name": "Decorah",
    "lat": "43.30331",
    "lng": "-91.78571"
  },
  {
    "country": "US",
    "name": "Denison",
    "lat": "42.01777",
    "lng": "-95.35528"
  },
  {
    "country": "US",
    "name": "Denver",
    "lat": "42.67137",
    "lng": "-92.3374"
  },
  {
    "country": "US",
    "name": "Des Moines",
    "lat": "41.60054",
    "lng": "-93.60911"
  },
  {
    "country": "US",
    "name": "Dike",
    "lat": "42.46415",
    "lng": "-92.62825"
  },
  {
    "country": "US",
    "name": "Dubuque",
    "lat": "42.50056",
    "lng": "-90.66457"
  },
  {
    "country": "US",
    "name": "Durant",
    "lat": "41.59975",
    "lng": "-90.9107"
  },
  {
    "country": "US",
    "name": "Dyersville",
    "lat": "42.48444",
    "lng": "-91.12291"
  },
  {
    "country": "US",
    "name": "Dysart",
    "lat": "42.17166",
    "lng": "-92.3063"
  },
  {
    "country": "US",
    "name": "Eagle Grove",
    "lat": "42.66414",
    "lng": "-93.90439"
  },
  {
    "country": "US",
    "name": "Earlham",
    "lat": "41.49193",
    "lng": "-94.12412"
  },
  {
    "country": "US",
    "name": "Eddyville",
    "lat": "41.1565",
    "lng": "-92.63739"
  },
  {
    "country": "US",
    "name": "Eldora",
    "lat": "42.36082",
    "lng": "-93.09965"
  },
  {
    "country": "US",
    "name": "Eldridge",
    "lat": "41.65809",
    "lng": "-90.58458"
  },
  {
    "country": "US",
    "name": "Elk Run Heights",
    "lat": "42.46693",
    "lng": "-92.25657"
  },
  {
    "country": "US",
    "name": "Elkader",
    "lat": "42.85387",
    "lng": "-91.40542"
  },
  {
    "country": "US",
    "name": "Ely",
    "lat": "41.87362",
    "lng": "-91.58518"
  },
  {
    "country": "US",
    "name": "Emmetsburg",
    "lat": "43.11274",
    "lng": "-94.68304"
  },
  {
    "country": "US",
    "name": "Epworth",
    "lat": "42.445",
    "lng": "-90.93208"
  },
  {
    "country": "US",
    "name": "Estherville",
    "lat": "43.40163",
    "lng": "-94.83276"
  },
  {
    "country": "US",
    "name": "Evansdale",
    "lat": "42.46915",
    "lng": "-92.28102"
  },
  {
    "country": "US",
    "name": "Fairbank",
    "lat": "42.63915",
    "lng": "-92.04712"
  },
  {
    "country": "US",
    "name": "Fairfax",
    "lat": "41.91945",
    "lng": "-91.78101"
  },
  {
    "country": "US",
    "name": "Fairfield",
    "lat": "41.00863",
    "lng": "-91.96267"
  },
  {
    "country": "US",
    "name": "Farley",
    "lat": "42.44278",
    "lng": "-91.00625"
  },
  {
    "country": "US",
    "name": "Fayette",
    "lat": "42.84193",
    "lng": "-91.80211"
  },
  {
    "country": "US",
    "name": "Forest City",
    "lat": "43.26246",
    "lng": "-93.63716"
  },
  {
    "country": "US",
    "name": "Fort Dodge",
    "lat": "42.49747",
    "lng": "-94.16802"
  },
  {
    "country": "US",
    "name": "Fort Madison",
    "lat": "40.62976",
    "lng": "-91.31515"
  },
  {
    "country": "US",
    "name": "Garner",
    "lat": "43.10246",
    "lng": "-93.60188"
  },
  {
    "country": "US",
    "name": "George",
    "lat": "43.34386",
    "lng": "-96.00224"
  },
  {
    "country": "US",
    "name": "Gilbert",
    "lat": "42.10693",
    "lng": "-93.64966"
  },
  {
    "country": "US",
    "name": "Glenwood",
    "lat": "41.04694",
    "lng": "-95.74251"
  },
  {
    "country": "US",
    "name": "Glidden",
    "lat": "42.05693",
    "lng": "-94.72887"
  },
  {
    "country": "US",
    "name": "Granger",
    "lat": "41.7611",
    "lng": "-93.82439"
  },
  {
    "country": "US",
    "name": "Greene",
    "lat": "42.89581",
    "lng": "-92.80242"
  },
  {
    "country": "US",
    "name": "Greenfield",
    "lat": "41.30527",
    "lng": "-94.46135"
  },
  {
    "country": "US",
    "name": "Grimes",
    "lat": "41.68832",
    "lng": "-93.79106"
  },
  {
    "country": "US",
    "name": "Grinnell",
    "lat": "41.74305",
    "lng": "-92.72241"
  },
  {
    "country": "US",
    "name": "Grundy Center",
    "lat": "42.36165",
    "lng": "-92.76853"
  },
  {
    "country": "US",
    "name": "Guthrie Center",
    "lat": "41.67721",
    "lng": "-94.5033"
  },
  {
    "country": "US",
    "name": "Guttenberg",
    "lat": "42.78582",
    "lng": "-91.09957"
  },
  {
    "country": "US",
    "name": "Hamburg",
    "lat": "40.60445",
    "lng": "-95.65777"
  },
  {
    "country": "US",
    "name": "Hampton",
    "lat": "42.74192",
    "lng": "-93.20242"
  },
  {
    "country": "US",
    "name": "Harlan",
    "lat": "41.65304",
    "lng": "-95.32555"
  },
  {
    "country": "US",
    "name": "Hartley",
    "lat": "43.17997",
    "lng": "-95.47695"
  },
  {
    "country": "US",
    "name": "Hawarden",
    "lat": "42.99582",
    "lng": "-96.48531"
  },
  {
    "country": "US",
    "name": "Hiawatha",
    "lat": "42.03583",
    "lng": "-91.68212"
  },
  {
    "country": "US",
    "name": "Holstein",
    "lat": "42.48915",
    "lng": "-95.545"
  },
  {
    "country": "US",
    "name": "Hudson",
    "lat": "42.40665",
    "lng": "-92.45547"
  },
  {
    "country": "US",
    "name": "Hull",
    "lat": "43.18859",
    "lng": "-96.13363"
  },
  {
    "country": "US",
    "name": "Humboldt",
    "lat": "42.7208",
    "lng": "-94.21524"
  },
  {
    "country": "US",
    "name": "Huxley",
    "lat": "41.89527",
    "lng": "-93.60077"
  },
  {
    "country": "US",
    "name": "Ida Grove",
    "lat": "42.34499",
    "lng": "-95.47167"
  },
  {
    "country": "US",
    "name": "Independence",
    "lat": "42.4686",
    "lng": "-91.88934"
  },
  {
    "country": "US",
    "name": "Indianola",
    "lat": "41.35805",
    "lng": "-93.55744"
  },
  {
    "country": "US",
    "name": "Iowa City",
    "lat": "41.66113",
    "lng": "-91.53017"
  },
  {
    "country": "US",
    "name": "Iowa Falls",
    "lat": "42.52248",
    "lng": "-93.25131"
  },
  {
    "country": "US",
    "name": "Jefferson",
    "lat": "42.01526",
    "lng": "-94.37747"
  },
  {
    "country": "US",
    "name": "Jesup",
    "lat": "42.47554",
    "lng": "-92.06379"
  },
  {
    "country": "US",
    "name": "Jewell",
    "lat": "42.30693",
    "lng": "-93.64022"
  },
  {
    "country": "US",
    "name": "Johnston",
    "lat": "41.67304",
    "lng": "-93.69772"
  },
  {
    "country": "US",
    "name": "Kalona",
    "lat": "41.48307",
    "lng": "-91.706"
  },
  {
    "country": "US",
    "name": "Keokuk",
    "lat": "40.39727",
    "lng": "-91.38487"
  },
  {
    "country": "US",
    "name": "Keosauqua",
    "lat": "40.73031",
    "lng": "-91.96239"
  },
  {
    "country": "US",
    "name": "Kingsley",
    "lat": "42.58832",
    "lng": "-95.96752"
  },
  {
    "country": "US",
    "name": "Knoxville",
    "lat": "41.32083",
    "lng": "-93.10937"
  },
  {
    "country": "US",
    "name": "La Porte City",
    "lat": "42.31499",
    "lng": "-92.19213"
  },
  {
    "country": "US",
    "name": "Lake City",
    "lat": "42.26748",
    "lng": "-94.73387"
  },
  {
    "country": "US",
    "name": "Lake Mills",
    "lat": "43.4194",
    "lng": "-93.53327"
  },
  {
    "country": "US",
    "name": "Lake Park",
    "lat": "43.45552",
    "lng": "-95.32083"
  },
  {
    "country": "US",
    "name": "Lake View",
    "lat": "42.31165",
    "lng": "-95.05332"
  },
  {
    "country": "US",
    "name": "Lamoni",
    "lat": "40.62278",
    "lng": "-93.93412"
  },
  {
    "country": "US",
    "name": "Laurens",
    "lat": "42.84664",
    "lng": "-94.85193"
  },
  {
    "country": "US",
    "name": "Le Claire",
    "lat": "41.59864",
    "lng": "-90.34346"
  },
  {
    "country": "US",
    "name": "Le Mars",
    "lat": "42.79416",
    "lng": "-96.16558"
  },
  {
    "country": "US",
    "name": "Lenox",
    "lat": "40.88165",
    "lng": "-94.56191"
  },
  {
    "country": "US",
    "name": "Leon",
    "lat": "40.73972",
    "lng": "-93.74772"
  },
  {
    "country": "US",
    "name": "Lisbon",
    "lat": "41.92112",
    "lng": "-91.38545"
  },
  {
    "country": "US",
    "name": "Logan",
    "lat": "41.64305",
    "lng": "-95.7889"
  },
  {
    "country": "US",
    "name": "Lone Tree",
    "lat": "41.48808",
    "lng": "-91.42599"
  },
  {
    "country": "US",
    "name": "Madrid",
    "lat": "41.87665",
    "lng": "-93.82328"
  },
  {
    "country": "US",
    "name": "Maharishi Vedic City",
    "lat": "41.05252",
    "lng": "-91.9949"
  },
  {
    "country": "US",
    "name": "Malvern",
    "lat": "41.00278",
    "lng": "-95.58528"
  },
  {
    "country": "US",
    "name": "Manchester",
    "lat": "42.48415",
    "lng": "-91.45543"
  },
  {
    "country": "US",
    "name": "Manly",
    "lat": "43.28718",
    "lng": "-93.20215"
  },
  {
    "country": "US",
    "name": "Manning",
    "lat": "41.90915",
    "lng": "-95.06499"
  },
  {
    "country": "US",
    "name": "Manson",
    "lat": "42.52914",
    "lng": "-94.53414"
  },
  {
    "country": "US",
    "name": "Mapleton",
    "lat": "42.16582",
    "lng": "-95.79306"
  },
  {
    "country": "US",
    "name": "Maquoketa",
    "lat": "42.06891",
    "lng": "-90.66569"
  },
  {
    "country": "US",
    "name": "Marcus",
    "lat": "42.82582",
    "lng": "-95.80751"
  },
  {
    "country": "US",
    "name": "Marengo",
    "lat": "41.79806",
    "lng": "-92.07074"
  },
  {
    "country": "US",
    "name": "Marion",
    "lat": "42.03417",
    "lng": "-91.59768"
  },
  {
    "country": "US",
    "name": "Marshalltown",
    "lat": "42.04943",
    "lng": "-92.90798"
  },
  {
    "country": "US",
    "name": "Mason City",
    "lat": "43.15357",
    "lng": "-93.20104"
  },
  {
    "country": "US",
    "name": "Mechanicsville",
    "lat": "41.90446",
    "lng": "-91.25461"
  },
  {
    "country": "US",
    "name": "Mediapolis",
    "lat": "41.00809",
    "lng": "-91.16404"
  },
  {
    "country": "US",
    "name": "Melcher-Dallas",
    "lat": "41.225",
    "lng": "-93.24132"
  },
  {
    "country": "US",
    "name": "Milford",
    "lat": "43.32469",
    "lng": "-95.15"
  },
  {
    "country": "US",
    "name": "Missouri Valley",
    "lat": "41.55638",
    "lng": "-95.88779"
  },
  {
    "country": "US",
    "name": "Mitchellville",
    "lat": "41.6686",
    "lng": "-93.35771"
  },
  {
    "country": "US",
    "name": "Monona",
    "lat": "43.05165",
    "lng": "-91.3893"
  },
  {
    "country": "US",
    "name": "Monroe",
    "lat": "41.52221",
    "lng": "-93.10187"
  },
  {
    "country": "US",
    "name": "Montezuma",
    "lat": "41.58583",
    "lng": "-92.52741"
  },
  {
    "country": "US",
    "name": "Monticello",
    "lat": "42.23834",
    "lng": "-91.18709"
  },
  {
    "country": "US",
    "name": "Mount Ayr",
    "lat": "40.71471",
    "lng": "-94.23523"
  },
  {
    "country": "US",
    "name": "Mount Pleasant",
    "lat": "40.96364",
    "lng": "-91.55794"
  },
  {
    "country": "US",
    "name": "Mount Vernon",
    "lat": "41.92195",
    "lng": "-91.41684"
  },
  {
    "country": "US",
    "name": "Moville",
    "lat": "42.48888",
    "lng": "-96.07252"
  },
  {
    "country": "US",
    "name": "Muscatine",
    "lat": "41.42447",
    "lng": "-91.04321"
  },
  {
    "country": "US",
    "name": "Nashua",
    "lat": "42.95275",
    "lng": "-92.5363"
  },
  {
    "country": "US",
    "name": "Nevada",
    "lat": "42.02277",
    "lng": "-93.45243"
  },
  {
    "country": "US",
    "name": "New Hampton",
    "lat": "43.05914",
    "lng": "-92.31768"
  },
  {
    "country": "US",
    "name": "New London",
    "lat": "40.92698",
    "lng": "-91.3996"
  },
  {
    "country": "US",
    "name": "New Sharon",
    "lat": "41.47",
    "lng": "-92.6513"
  },
  {
    "country": "US",
    "name": "Newton",
    "lat": "41.69971",
    "lng": "-93.04798"
  },
  {
    "country": "US",
    "name": "Nora Springs",
    "lat": "43.14275",
    "lng": "-93.00437"
  },
  {
    "country": "US",
    "name": "North English",
    "lat": "41.5139",
    "lng": "-92.07629"
  },
  {
    "country": "US",
    "name": "North Liberty",
    "lat": "41.74918",
    "lng": "-91.59795"
  },
  {
    "country": "US",
    "name": "Northwood",
    "lat": "43.44412",
    "lng": "-93.22104"
  },
  {
    "country": "US",
    "name": "Norwalk",
    "lat": "41.47555",
    "lng": "-93.67883"
  },
  {
    "country": "US",
    "name": "Oakland",
    "lat": "42.58109",
    "lng": "-93.44326"
  },
  {
    "country": "US",
    "name": "Oakland",
    "lat": "41.30916",
    "lng": "-95.39667"
  },
  {
    "country": "US",
    "name": "Oelwein",
    "lat": "42.67332",
    "lng": "-91.9135"
  },
  {
    "country": "US",
    "name": "Ogden",
    "lat": "42.03915",
    "lng": "-94.02773"
  },
  {
    "country": "US",
    "name": "Onawa",
    "lat": "42.02665",
    "lng": "-96.09724"
  },
  {
    "country": "US",
    "name": "Orange City",
    "lat": "43.00721",
    "lng": "-96.05835"
  },
  {
    "country": "US",
    "name": "Osage",
    "lat": "43.28414",
    "lng": "-92.81103"
  },
  {
    "country": "US",
    "name": "Osceola",
    "lat": "41.03389",
    "lng": "-93.7655"
  },
  {
    "country": "US",
    "name": "Oskaloosa",
    "lat": "41.29639",
    "lng": "-92.64436"
  },
  {
    "country": "US",
    "name": "Ottumwa",
    "lat": "41.02001",
    "lng": "-92.4113"
  },
  {
    "country": "US",
    "name": "Palo",
    "lat": "42.06611",
    "lng": "-91.79546"
  },
  {
    "country": "US",
    "name": "Panora",
    "lat": "41.69165",
    "lng": "-94.36302"
  },
  {
    "country": "US",
    "name": "Park View",
    "lat": "41.6942",
    "lng": "-90.54569"
  },
  {
    "country": "US",
    "name": "Parkersburg",
    "lat": "42.57748",
    "lng": "-92.78686"
  },
  {
    "country": "US",
    "name": "Paullina",
    "lat": "42.97915",
    "lng": "-95.68807"
  },
  {
    "country": "US",
    "name": "Pella",
    "lat": "41.40805",
    "lng": "-92.91631"
  },
  {
    "country": "US",
    "name": "Peosta",
    "lat": "42.45056",
    "lng": "-90.85041"
  },
  {
    "country": "US",
    "name": "Perry",
    "lat": "41.8386",
    "lng": "-94.10718"
  },
  {
    "country": "US",
    "name": "Pleasant Hill",
    "lat": "41.58388",
    "lng": "-93.51994"
  },
  {
    "country": "US",
    "name": "Pleasantville",
    "lat": "41.38583",
    "lng": "-93.26937"
  },
  {
    "country": "US",
    "name": "Pocahontas",
    "lat": "42.73553",
    "lng": "-94.66915"
  },
  {
    "country": "US",
    "name": "Polk City",
    "lat": "41.77138",
    "lng": "-93.713"
  },
  {
    "country": "US",
    "name": "Postville",
    "lat": "43.0847",
    "lng": "-91.5682"
  },
  {
    "country": "US",
    "name": "Prairie City",
    "lat": "41.59943",
    "lng": "-93.23521"
  },
  {
    "country": "US",
    "name": "Preston",
    "lat": "42.0503",
    "lng": "-90.41402"
  },
  {
    "country": "US",
    "name": "Primghar",
    "lat": "43.08692",
    "lng": "-95.62723"
  },
  {
    "country": "US",
    "name": "Red Oak",
    "lat": "41.00972",
    "lng": "-95.22555"
  },
  {
    "country": "US",
    "name": "Reinbeck",
    "lat": "42.3236",
    "lng": "-92.59936"
  },
  {
    "country": "US",
    "name": "Remsen",
    "lat": "42.81471",
    "lng": "-95.97335"
  },
  {
    "country": "US",
    "name": "Riverside",
    "lat": "41.47974",
    "lng": "-91.58128"
  },
  {
    "country": "US",
    "name": "Robins",
    "lat": "42.07111",
    "lng": "-91.66684"
  },
  {
    "country": "US",
    "name": "Rock Rapids",
    "lat": "43.42719",
    "lng": "-96.17586"
  },
  {
    "country": "US",
    "name": "Rock Valley",
    "lat": "43.20526",
    "lng": "-96.29503"
  },
  {
    "country": "US",
    "name": "Rockwell",
    "lat": "42.98524",
    "lng": "-93.19187"
  },
  {
    "country": "US",
    "name": "Rockwell City",
    "lat": "42.39526",
    "lng": "-94.63387"
  },
  {
    "country": "US",
    "name": "Roland",
    "lat": "42.16637",
    "lng": "-93.50188"
  },
  {
    "country": "US",
    "name": "Sac City",
    "lat": "42.4222",
    "lng": "-94.98971"
  },
  {
    "country": "US",
    "name": "Saint Ansgar",
    "lat": "43.3783",
    "lng": "-92.91881"
  },
  {
    "country": "US",
    "name": "Sanborn",
    "lat": "43.18164",
    "lng": "-95.65557"
  },
  {
    "country": "US",
    "name": "Saylorville",
    "lat": "41.6786",
    "lng": "-93.62966"
  },
  {
    "country": "US",
    "name": "Sergeant Bluff",
    "lat": "42.40388",
    "lng": "-96.35864"
  },
  {
    "country": "US",
    "name": "Sheffield",
    "lat": "42.8933",
    "lng": "-93.2152"
  },
  {
    "country": "US",
    "name": "Sheldon",
    "lat": "43.18109",
    "lng": "-95.85613"
  },
  {
    "country": "US",
    "name": "Shell Rock",
    "lat": "42.71026",
    "lng": "-92.58297"
  },
  {
    "country": "US",
    "name": "Shenandoah",
    "lat": "40.76555",
    "lng": "-95.37221"
  },
  {
    "country": "US",
    "name": "Sidney",
    "lat": "40.74833",
    "lng": "-95.6475"
  },
  {
    "country": "US",
    "name": "Sibley",
    "lat": "43.39914",
    "lng": "-95.75196"
  },
  {
    "country": "US",
    "name": "Sigourney",
    "lat": "41.33334",
    "lng": "-92.20463"
  },
  {
    "country": "US",
    "name": "Sioux Center",
    "lat": "43.07971",
    "lng": "-96.17558"
  },
  {
    "country": "US",
    "name": "Sioux City",
    "lat": "42.49999",
    "lng": "-96.40031"
  },
  {
    "country": "US",
    "name": "Slater",
    "lat": "41.87776",
    "lng": "-93.67855"
  },
  {
    "country": "US",
    "name": "Solon",
    "lat": "41.80723",
    "lng": "-91.49406"
  },
  {
    "country": "US",
    "name": "Spencer",
    "lat": "43.14136",
    "lng": "-95.14444"
  },
  {
    "country": "US",
    "name": "Spirit Lake",
    "lat": "43.42218",
    "lng": "-95.10222"
  },
  {
    "country": "US",
    "name": "Springville",
    "lat": "42.05945",
    "lng": "-91.44267"
  },
  {
    "country": "US",
    "name": "State Center",
    "lat": "42.01665",
    "lng": "-93.16354"
  },
  {
    "country": "US",
    "name": "Storm Lake",
    "lat": "42.64109",
    "lng": "-95.20972"
  },
  {
    "country": "US",
    "name": "Story City",
    "lat": "42.18721",
    "lng": "-93.59577"
  },
  {
    "country": "US",
    "name": "Strawberry Point",
    "lat": "42.6836",
    "lng": "-91.53403"
  },
  {
    "country": "US",
    "name": "Stuart",
    "lat": "41.50332",
    "lng": "-94.31857"
  },
  {
    "country": "US",
    "name": "Sumner",
    "lat": "42.84748",
    "lng": "-92.09156"
  },
  {
    "country": "US",
    "name": "Tama",
    "lat": "41.96666",
    "lng": "-92.57686"
  },
  {
    "country": "US",
    "name": "Tiffin",
    "lat": "41.70585",
    "lng": "-91.66295"
  },
  {
    "country": "US",
    "name": "Tipton",
    "lat": "41.76974",
    "lng": "-91.12793"
  },
  {
    "country": "US",
    "name": "Toledo",
    "lat": "41.99555",
    "lng": "-92.57686"
  },
  {
    "country": "US",
    "name": "Traer",
    "lat": "42.1936",
    "lng": "-92.46547"
  },
  {
    "country": "US",
    "name": "Tripoli",
    "lat": "42.80804",
    "lng": "-92.25823"
  },
  {
    "country": "US",
    "name": "University Heights",
    "lat": "41.65502",
    "lng": "-91.55684"
  },
  {
    "country": "US",
    "name": "Urbana",
    "lat": "42.22416",
    "lng": "-91.87434"
  },
  {
    "country": "US",
    "name": "Urbandale",
    "lat": "41.62666",
    "lng": "-93.71217"
  },
  {
    "country": "US",
    "name": "Van Meter",
    "lat": "41.53193",
    "lng": "-93.95412"
  },
  {
    "country": "US",
    "name": "Villisca",
    "lat": "40.92971",
    "lng": "-94.97609"
  },
  {
    "country": "US",
    "name": "Vinton",
    "lat": "42.16861",
    "lng": "-92.02351"
  },
  {
    "country": "US",
    "name": "Walcott",
    "lat": "41.58475",
    "lng": "-90.77209"
  },
  {
    "country": "US",
    "name": "Walford",
    "lat": "41.87834",
    "lng": "-91.83462"
  },
  {
    "country": "US",
    "name": "Wapello",
    "lat": "41.18142",
    "lng": "-91.18543"
  },
  {
    "country": "US",
    "name": "Washington",
    "lat": "41.29918",
    "lng": "-91.69294"
  },
  {
    "country": "US",
    "name": "Waterloo",
    "lat": "42.49276",
    "lng": "-92.34296"
  },
  {
    "country": "US",
    "name": "Waukee",
    "lat": "41.61166",
    "lng": "-93.88523"
  },
  {
    "country": "US",
    "name": "Waukon",
    "lat": "43.26942",
    "lng": "-91.4757"
  },
  {
    "country": "US",
    "name": "Waverly",
    "lat": "42.72581",
    "lng": "-92.47546"
  },
  {
    "country": "US",
    "name": "Webster City",
    "lat": "42.46942",
    "lng": "-93.81605"
  },
  {
    "country": "US",
    "name": "Wellman",
    "lat": "41.46418",
    "lng": "-91.83823"
  },
  {
    "country": "US",
    "name": "West Branch",
    "lat": "41.67141",
    "lng": "-91.34655"
  },
  {
    "country": "US",
    "name": "West Burlington",
    "lat": "40.82504",
    "lng": "-91.15654"
  },
  {
    "country": "US",
    "name": "West Des Moines",
    "lat": "41.57721",
    "lng": "-93.71133"
  },
  {
    "country": "US",
    "name": "West Liberty",
    "lat": "41.57002",
    "lng": "-91.26377"
  },
  {
    "country": "US",
    "name": "West Union",
    "lat": "42.96276",
    "lng": "-91.80822"
  },
  {
    "country": "US",
    "name": "Williamsburg",
    "lat": "41.66112",
    "lng": "-92.00907"
  },
  {
    "country": "US",
    "name": "Wilton",
    "lat": "41.58892",
    "lng": "-91.01682"
  },
  {
    "country": "US",
    "name": "Windsor Heights",
    "lat": "41.59777",
    "lng": "-93.70828"
  },
  {
    "country": "US",
    "name": "Winfield",
    "lat": "41.12308",
    "lng": "-91.44127"
  },
  {
    "country": "US",
    "name": "Winterset",
    "lat": "41.33082",
    "lng": "-94.01384"
  },
  {
    "country": "US",
    "name": "Woodbine",
    "lat": "41.73832",
    "lng": "-95.70278"
  },
  {
    "country": "US",
    "name": "Woodward",
    "lat": "41.85693",
    "lng": "-93.9219"
  },
  {
    "country": "US",
    "name": "Abingdon",
    "lat": "40.80448",
    "lng": "-90.4018"
  },
  {
    "country": "US",
    "name": "Addison",
    "lat": "41.9317",
    "lng": "-87.98896"
  },
  {
    "country": "US",
    "name": "Albany Park",
    "lat": "41.96836",
    "lng": "-87.72339"
  },
  {
    "country": "US",
    "name": "Aledo",
    "lat": "41.19976",
    "lng": "-90.74931"
  },
  {
    "country": "US",
    "name": "Algonquin",
    "lat": "42.16558",
    "lng": "-88.29425"
  },
  {
    "country": "US",
    "name": "Alsip",
    "lat": "41.66892",
    "lng": "-87.73866"
  },
  {
    "country": "US",
    "name": "Amboy",
    "lat": "41.7142",
    "lng": "-89.32871"
  },
  {
    "country": "US",
    "name": "Andalusia",
    "lat": "41.4392",
    "lng": "-90.71764"
  },
  {
    "country": "US",
    "name": "Antioch",
    "lat": "42.47724",
    "lng": "-88.09564"
  },
  {
    "country": "US",
    "name": "Arlington Heights",
    "lat": "42.08836",
    "lng": "-87.98063"
  },
  {
    "country": "US",
    "name": "Ashburn",
    "lat": "41.74753",
    "lng": "-87.71116"
  },
  {
    "country": "US",
    "name": "Astoria",
    "lat": "40.22754",
    "lng": "-90.35957"
  },
  {
    "country": "US",
    "name": "Atlanta",
    "lat": "40.25948",
    "lng": "-89.23342"
  },
  {
    "country": "US",
    "name": "Aurora",
    "lat": "41.76058",
    "lng": "-88.32007"
  },
  {
    "country": "US",
    "name": "Avondale",
    "lat": "41.93892",
    "lng": "-87.71117"
  },
  {
    "country": "US",
    "name": "Bannockburn",
    "lat": "42.19336",
    "lng": "-87.86646"
  },
  {
    "country": "US",
    "name": "Barrington",
    "lat": "42.15391",
    "lng": "-88.13619"
  },
  {
    "country": "US",
    "name": "Barrington Hills",
    "lat": "42.14475",
    "lng": "-88.15563"
  },
  {
    "country": "US",
    "name": "Bartlett",
    "lat": "41.99503",
    "lng": "-88.18563"
  },
  {
    "country": "US",
    "name": "Bartonville",
    "lat": "40.65032",
    "lng": "-89.65205"
  },
  {
    "country": "US",
    "name": "Batavia",
    "lat": "41.85003",
    "lng": "-88.31257"
  },
  {
    "country": "US",
    "name": "Beach Park",
    "lat": "42.42224",
    "lng": "-87.8573"
  },
  {
    "country": "US",
    "name": "Beardstown",
    "lat": "40.01755",
    "lng": "-90.42429"
  },
  {
    "country": "US",
    "name": "Beecher",
    "lat": "41.34059",
    "lng": "-87.62143"
  },
  {
    "country": "US",
    "name": "Bellevue",
    "lat": "40.68448",
    "lng": "-89.6801"
  },
  {
    "country": "US",
    "name": "Bellwood",
    "lat": "41.88142",
    "lng": "-87.88312"
  },
  {
    "country": "US",
    "name": "Belmont Cragin",
    "lat": "41.9317",
    "lng": "-87.76867"
  },
  {
    "country": "US",
    "name": "Belvidere",
    "lat": "42.26391",
    "lng": "-88.84427"
  },
  {
    "country": "US",
    "name": "Bensenville",
    "lat": "41.95503",
    "lng": "-87.94007"
  },
  {
    "country": "US",
    "name": "Berkeley",
    "lat": "41.88892",
    "lng": "-87.9034"
  },
  {
    "country": "US",
    "name": "Berwyn",
    "lat": "41.85059",
    "lng": "-87.79367"
  },
  {
    "country": "US",
    "name": "Big Rock",
    "lat": "41.76392",
    "lng": "-88.54702"
  },
  {
    "country": "US",
    "name": "Bloomingdale",
    "lat": "41.95753",
    "lng": "-88.0809"
  },
  {
    "country": "US",
    "name": "Bloomington",
    "lat": "40.4842",
    "lng": "-88.99369"
  },
  {
    "country": "US",
    "name": "Blue Island",
    "lat": "41.65726",
    "lng": "-87.68005"
  },
  {
    "country": "US",
    "name": "Bolingbrook",
    "lat": "41.69864",
    "lng": "-88.0684"
  },
  {
    "country": "US",
    "name": "Boulder Hill",
    "lat": "41.71253",
    "lng": "-88.33618"
  },
  {
    "country": "US",
    "name": "Bourbonnais",
    "lat": "41.15376",
    "lng": "-87.88754"
  },
  {
    "country": "US",
    "name": "Bradley",
    "lat": "41.14198",
    "lng": "-87.86115"
  },
  {
    "country": "US",
    "name": "Braidwood",
    "lat": "41.26503",
    "lng": "-88.21228"
  },
  {
    "country": "US",
    "name": "Bridgeport",
    "lat": "41.83809",
    "lng": "-87.65116"
  },
  {
    "country": "US",
    "name": "Bridgeview",
    "lat": "41.75003",
    "lng": "-87.80422"
  },
  {
    "country": "US",
    "name": "Brighton Park",
    "lat": "41.81892",
    "lng": "-87.69894"
  },
  {
    "country": "US",
    "name": "Broadview",
    "lat": "41.86392",
    "lng": "-87.85339"
  },
  {
    "country": "US",
    "name": "Brookfield",
    "lat": "41.82392",
    "lng": "-87.85173"
  },
  {
    "country": "US",
    "name": "Buffalo Grove",
    "lat": "42.15141",
    "lng": "-87.95979"
  },
  {
    "country": "US",
    "name": "Bull Valley",
    "lat": "42.32058",
    "lng": "-88.35509"
  },
  {
    "country": "US",
    "name": "Burbank",
    "lat": "41.73392",
    "lng": "-87.7795"
  },
  {
    "country": "US",
    "name": "Burnham",
    "lat": "41.63892",
    "lng": "-87.55671"
  },
  {
    "country": "US",
    "name": "Burr Ridge",
    "lat": "41.74892",
    "lng": "-87.91839"
  },
  {
    "country": "US",
    "name": "Bushnell",
    "lat": "40.55282",
    "lng": "-90.50624"
  },
  {
    "country": "US",
    "name": "Byron",
    "lat": "42.12697",
    "lng": "-89.25566"
  },
  {
    "country": "US",
    "name": "Calumet City",
    "lat": "41.61559",
    "lng": "-87.52949"
  },
  {
    "country": "US",
    "name": "Calumet Park",
    "lat": "41.66281",
    "lng": "-87.6606"
  },
  {
    "country": "US",
    "name": "Cambridge",
    "lat": "41.30365",
    "lng": "-90.1929"
  },
  {
    "country": "US",
    "name": "Camp Point",
    "lat": "40.03921",
    "lng": "-91.0693"
  },
  {
    "country": "US",
    "name": "Capron",
    "lat": "42.39974",
    "lng": "-88.74038"
  },
  {
    "country": "US",
    "name": "Carbon Cliff",
    "lat": "41.49476",
    "lng": "-90.39068"
  },
  {
    "country": "US",
    "name": "Carol Stream",
    "lat": "41.91253",
    "lng": "-88.13479"
  },
  {
    "country": "US",
    "name": "Carpentersville",
    "lat": "42.12114",
    "lng": "-88.25786"
  },
  {
    "country": "US",
    "name": "Carthage",
    "lat": "40.41643",
    "lng": "-91.13625"
  },
  {
    "country": "US",
    "name": "Carthage",
    "lat": "41.91892",
    "lng": "-89.31371"
  },
  {
    "country": "US",
    "name": "Cary",
    "lat": "42.21197",
    "lng": "-88.23814"
  },
  {
    "country": "US",
    "name": "Catlin",
    "lat": "40.06504",
    "lng": "-87.70197"
  },
  {
    "country": "US",
    "name": "Central City",
    "lat": "41.23781",
    "lng": "-88.28173"
  },
  {
    "country": "US",
    "name": "Champaign",
    "lat": "40.11642",
    "lng": "-88.24338"
  },
  {
    "country": "US",
    "name": "Channahon",
    "lat": "41.42948",
    "lng": "-88.22867"
  },
  {
    "country": "US",
    "name": "Channel Lake",
    "lat": "42.47863",
    "lng": "-88.13759"
  },
  {
    "country": "US",
    "name": "Chatham",
    "lat": "41.74115",
    "lng": "-87.61255"
  },
  {
    "country": "US",
    "name": "Chatsworth",
    "lat": "40.75365",
    "lng": "-88.29199"
  },
  {
    "country": "US",
    "name": "Chebanse",
    "lat": "41.00309",
    "lng": "-87.9081"
  },
  {
    "country": "US",
    "name": "Chenoa",
    "lat": "40.7417",
    "lng": "-88.71979"
  },
  {
    "country": "US",
    "name": "Cherry Valley",
    "lat": "42.23474",
    "lng": "-88.94899"
  },
  {
    "country": "US",
    "name": "Chicago",
    "lat": "41.85003",
    "lng": "-87.65005"
  },
  {
    "country": "US",
    "name": "Chicago Heights",
    "lat": "41.50615",
    "lng": "-87.6356"
  },
  {
    "country": "US",
    "name": "Chicago Lawn",
    "lat": "41.77503",
    "lng": "-87.69644"
  },
  {
    "country": "US",
    "name": "Chicago Ridge",
    "lat": "41.70142",
    "lng": "-87.77922"
  },
  {
    "country": "US",
    "name": "Chillicothe",
    "lat": "40.92226",
    "lng": "-89.4862"
  },
  {
    "country": "US",
    "name": "Cicero",
    "lat": "41.84559",
    "lng": "-87.75394"
  },
  {
    "country": "US",
    "name": "Clarendon Hills",
    "lat": "41.79753",
    "lng": "-87.95478"
  },
  {
    "country": "US",
    "name": "Clifton",
    "lat": "40.93531",
    "lng": "-87.93449"
  },
  {
    "country": "US",
    "name": "Clinton",
    "lat": "40.15365",
    "lng": "-88.96453"
  },
  {
    "country": "US",
    "name": "Coal City",
    "lat": "41.28781",
    "lng": "-88.28562"
  },
  {
    "country": "US",
    "name": "Coal Valley",
    "lat": "41.42865",
    "lng": "-90.46096"
  },
  {
    "country": "US",
    "name": "Colchester",
    "lat": "40.42643",
    "lng": "-90.79263"
  },
  {
    "country": "US",
    "name": "Colfax",
    "lat": "40.56698",
    "lng": "-88.61645"
  },
  {
    "country": "US",
    "name": "Colona",
    "lat": "41.48392",
    "lng": "-90.35318"
  },
  {
    "country": "US",
    "name": "Cortland",
    "lat": "41.92003",
    "lng": "-88.6887"
  },
  {
    "country": "US",
    "name": "Country Club Hills",
    "lat": "41.56809",
    "lng": "-87.72033"
  },
  {
    "country": "US",
    "name": "Countryside",
    "lat": "41.78281",
    "lng": "-87.87811"
  },
  {
    "country": "US",
    "name": "Crest Hill",
    "lat": "41.55475",
    "lng": "-88.09867"
  },
  {
    "country": "US",
    "name": "Crestwood",
    "lat": "41.64463",
    "lng": "-87.74154"
  },
  {
    "country": "US",
    "name": "Crete",
    "lat": "41.44448",
    "lng": "-87.63143"
  },
  {
    "country": "US",
    "name": "Creve Coeur",
    "lat": "40.64726",
    "lng": "-89.59121"
  },
  {
    "country": "US",
    "name": "Crystal Lake",
    "lat": "42.24113",
    "lng": "-88.3162"
  },
  {
    "country": "US",
    "name": "Crystal Lawns",
    "lat": "41.57031",
    "lng": "-88.15812"
  },
  {
    "country": "US",
    "name": "Cuba",
    "lat": "40.49282",
    "lng": "-90.19068"
  },
  {
    "country": "US",
    "name": "Cuba",
    "lat": "42.18391",
    "lng": "-88.19091"
  },
  {
    "country": "US",
    "name": "Danvers",
    "lat": "40.52948",
    "lng": "-89.17731"
  },
  {
    "country": "US",
    "name": "Danville",
    "lat": "40.12448",
    "lng": "-87.63002"
  },
  {
    "country": "US",
    "name": "Darien",
    "lat": "41.75198",
    "lng": "-87.97395"
  },
  {
    "country": "US",
    "name": "Davis Junction",
    "lat": "42.10169",
    "lng": "-89.09316"
  },
  {
    "country": "US",
    "name": "DeKalb",
    "lat": "41.92947",
    "lng": "-88.75036"
  },
  {
    "country": "US",
    "name": "Deer Park",
    "lat": "42.16086",
    "lng": "-88.08147"
  },
  {
    "country": "US",
    "name": "Deerfield",
    "lat": "42.17114",
    "lng": "-87.84451"
  },
  {
    "country": "US",
    "name": "Delavan",
    "lat": "40.37254",
    "lng": "-89.54732"
  },
  {
    "country": "US",
    "name": "Depue",
    "lat": "41.3242",
    "lng": "-89.30675"
  },
  {
    "country": "US",
    "name": "Des Plaines",
    "lat": "42.03336",
    "lng": "-87.8834"
  },
  {
    "country": "US",
    "name": "Diamond",
    "lat": "41.28864",
    "lng": "-88.25173"
  },
  {
    "country": "US",
    "name": "Dixmoor",
    "lat": "41.6317",
    "lng": "-87.66088"
  },
  {
    "country": "US",
    "name": "Dixon",
    "lat": "41.83892",
    "lng": "-89.47955"
  },
  {
    "country": "US",
    "name": "Dolton",
    "lat": "41.63892",
    "lng": "-87.60727"
  },
  {
    "country": "US",
    "name": "Douglas",
    "lat": "41.83476",
    "lng": "-87.61811"
  },
  {
    "country": "US",
    "name": "Downers Grove",
    "lat": "41.80892",
    "lng": "-88.01117"
  },
  {
    "country": "US",
    "name": "Dunlap",
    "lat": "40.8617",
    "lng": "-89.67871"
  },
  {
    "country": "US",
    "name": "Durand",
    "lat": "42.4364",
    "lng": "-89.33206"
  },
  {
    "country": "US",
    "name": "Dwight",
    "lat": "41.09448",
    "lng": "-88.42506"
  },
  {
    "country": "US",
    "name": "Earlville",
    "lat": "41.58948",
    "lng": "-88.92203"
  },
  {
    "country": "US",
    "name": "East Dundee",
    "lat": "42.09891",
    "lng": "-88.27147"
  },
  {
    "country": "US",
    "name": "East Dubuque",
    "lat": "42.49223",
    "lng": "-90.64291"
  },
  {
    "country": "US",
    "name": "East Garfield Park",
    "lat": "41.88087",
    "lng": "-87.70283"
  },
  {
    "country": "US",
    "name": "East Hazel Crest",
    "lat": "41.57365",
    "lng": "-87.64643"
  },
  {
    "country": "US",
    "name": "East Moline",
    "lat": "41.50087",
    "lng": "-90.4443"
  },
  {
    "country": "US",
    "name": "East Peoria",
    "lat": "40.66615",
    "lng": "-89.5801"
  },
  {
    "country": "US",
    "name": "Edgewater",
    "lat": "41.98337",
    "lng": "-87.66395"
  },
  {
    "country": "US",
    "name": "El Paso",
    "lat": "40.7392",
    "lng": "-89.01646"
  },
  {
    "country": "US",
    "name": "Elburn",
    "lat": "41.89225",
    "lng": "-88.4723"
  },
  {
    "country": "US",
    "name": "Elgin",
    "lat": "42.03725",
    "lng": "-88.28119"
  },
  {
    "country": "US",
    "name": "Elk Grove Village",
    "lat": "42.00392",
    "lng": "-87.97035"
  },
  {
    "country": "US",
    "name": "Elmhurst",
    "lat": "41.89947",
    "lng": "-87.94034"
  },
  {
    "country": "US",
    "name": "Elmwood",
    "lat": "40.77782",
    "lng": "-89.9665"
  },
  {
    "country": "US",
    "name": "Elmwood Park",
    "lat": "41.92114",
    "lng": "-87.80923"
  },
  {
    "country": "US",
    "name": "Elwood",
    "lat": "41.40392",
    "lng": "-88.11172"
  },
  {
    "country": "US",
    "name": "Englewood",
    "lat": "41.77976",
    "lng": "-87.64588"
  },
  {
    "country": "US",
    "name": "Erie",
    "lat": "41.65642",
    "lng": "-90.07929"
  },
  {
    "country": "US",
    "name": "Eureka",
    "lat": "40.72143",
    "lng": "-89.27286"
  },
  {
    "country": "US",
    "name": "Evanston",
    "lat": "42.04114",
    "lng": "-87.69006"
  },
  {
    "country": "US",
    "name": "Evergreen Park",
    "lat": "41.72059",
    "lng": "-87.70172"
  },
  {
    "country": "US",
    "name": "Fairbury",
    "lat": "40.74726",
    "lng": "-88.51478"
  },
  {
    "country": "US",
    "name": "Fairfield",
    "lat": "42.21919",
    "lng": "-88.06147"
  },
  {
    "country": "US",
    "name": "Fairmont",
    "lat": "41.55614",
    "lng": "-88.05923"
  },
  {
    "country": "US",
    "name": "Farmer City",
    "lat": "40.24337",
    "lng": "-88.64257"
  },
  {
    "country": "US",
    "name": "Farmington",
    "lat": "40.69809",
    "lng": "-90.00595"
  },
  {
    "country": "US",
    "name": "Farmington",
    "lat": "41.94475",
    "lng": "-88.31591"
  },
  {
    "country": "US",
    "name": "Fisher",
    "lat": "40.31476",
    "lng": "-88.35005"
  },
  {
    "country": "US",
    "name": "Flanagan",
    "lat": "40.87809",
    "lng": "-88.86118"
  },
  {
    "country": "US",
    "name": "Flossmoor",
    "lat": "41.54281",
    "lng": "-87.68477"
  },
  {
    "country": "US",
    "name": "Ford Heights",
    "lat": "41.50642",
    "lng": "-87.59171"
  },
  {
    "country": "US",
    "name": "Forest Lake",
    "lat": "42.20752",
    "lng": "-88.05563"
  },
  {
    "country": "US",
    "name": "Forest Park",
    "lat": "41.87948",
    "lng": "-87.81367"
  },
  {
    "country": "US",
    "name": "Forrest",
    "lat": "40.75198",
    "lng": "-88.41116"
  },
  {
    "country": "US",
    "name": "Forreston",
    "lat": "42.12614",
    "lng": "-89.57928"
  },
  {
    "country": "US",
    "name": "Fox Lake",
    "lat": "42.39669",
    "lng": "-88.1837"
  },
  {
    "country": "US",
    "name": "Fox Lake Hills",
    "lat": "42.40808",
    "lng": "-88.13175"
  },
  {
    "country": "US",
    "name": "Fox River Grove",
    "lat": "42.20086",
    "lng": "-88.21453"
  },
  {
    "country": "US",
    "name": "Frankfort",
    "lat": "41.49587",
    "lng": "-87.84866"
  },
  {
    "country": "US",
    "name": "Frankfort Square",
    "lat": "41.51892",
    "lng": "-87.8031"
  },
  {
    "country": "US",
    "name": "Franklin Park",
    "lat": "41.93531",
    "lng": "-87.86562"
  },
  {
    "country": "US",
    "name": "Freeport",
    "lat": "42.29669",
    "lng": "-89.62123"
  },
  {
    "country": "US",
    "name": "Fulton",
    "lat": "41.86725",
    "lng": "-90.15957"
  },
  {
    "country": "US",
    "name": "Gage Park",
    "lat": "41.79503",
    "lng": "-87.69616"
  },
  {
    "country": "US",
    "name": "Gages Lake",
    "lat": "42.35169",
    "lng": "-87.98258"
  },
  {
    "country": "US",
    "name": "Galena",
    "lat": "42.41667",
    "lng": "-90.42902"
  },
  {
    "country": "US",
    "name": "Galesburg",
    "lat": "40.94782",
    "lng": "-90.37124"
  },
  {
    "country": "US",
    "name": "Galva",
    "lat": "41.16754",
    "lng": "-90.04261"
  },
  {
    "country": "US",
    "name": "Gardner",
    "lat": "41.18559",
    "lng": "-88.30978"
  },
  {
    "country": "US",
    "name": "Geneseo",
    "lat": "41.44809",
    "lng": "-90.15428"
  },
  {
    "country": "US",
    "name": "Geneva",
    "lat": "41.88753",
    "lng": "-88.30535"
  },
  {
    "country": "US",
    "name": "Genoa",
    "lat": "42.09725",
    "lng": "-88.69287"
  },
  {
    "country": "US",
    "name": "Georgetown",
    "lat": "42.13975",
    "lng": "-89.82873"
  },
  {
    "country": "US",
    "name": "Germantown Hills",
    "lat": "40.76643",
    "lng": "-89.46787"
  },
  {
    "country": "US",
    "name": "Gibson City",
    "lat": "40.45843",
    "lng": "-88.3846"
  },
  {
    "country": "US",
    "name": "Gifford",
    "lat": "40.30587",
    "lng": "-88.02115"
  },
  {
    "country": "US",
    "name": "Gilberts",
    "lat": "42.10336",
    "lng": "-88.37286"
  },
  {
    "country": "US",
    "name": "Gilman",
    "lat": "40.7667",
    "lng": "-87.99226"
  },
  {
    "country": "US",
    "name": "Glasford",
    "lat": "40.57254",
    "lng": "-89.81344"
  },
  {
    "country": "US",
    "name": "Glen Ellyn",
    "lat": "41.87753",
    "lng": "-88.06701"
  },
  {
    "country": "US",
    "name": "Glenview",
    "lat": "42.06975",
    "lng": "-87.78784"
  },
  {
    "country": "US",
    "name": "Glenwood",
    "lat": "41.54253",
    "lng": "-87.60227"
  },
  {
    "country": "US",
    "name": "Goodings Grove",
    "lat": "41.6292",
    "lng": "-87.93089"
  },
  {
    "country": "US",
    "name": "Glencoe",
    "lat": "42.13503",
    "lng": "-87.75812"
  },
  {
    "country": "US",
    "name": "Grand Boulevard",
    "lat": "41.81392",
    "lng": "-87.61727"
  },
  {
    "country": "US",
    "name": "Grandwood Park",
    "lat": "42.39308",
    "lng": "-87.98674"
  },
  {
    "country": "US",
    "name": "Grant Park",
    "lat": "41.24114",
    "lng": "-87.64615"
  },
  {
    "country": "US",
    "name": "Granville",
    "lat": "41.26115",
    "lng": "-89.22759"
  },
  {
    "country": "US",
    "name": "Grayslake",
    "lat": "42.34447",
    "lng": "-88.04175"
  },
  {
    "country": "US",
    "name": "Green Oaks",
    "lat": "42.29002",
    "lng": "-87.90341"
  },
  {
    "country": "US",
    "name": "Green Rock",
    "lat": "41.47309",
    "lng": "-90.35763"
  },
  {
    "country": "US",
    "name": "Gridley",
    "lat": "40.74337",
    "lng": "-88.88146"
  },
  {
    "country": "US",
    "name": "Gurnee",
    "lat": "42.3703",
    "lng": "-87.90202"
  },
  {
    "country": "US",
    "name": "Hainesville",
    "lat": "42.34502",
    "lng": "-88.06786"
  },
  {
    "country": "US",
    "name": "Hamilton",
    "lat": "40.39643",
    "lng": "-91.33904"
  },
  {
    "country": "US",
    "name": "Hampshire",
    "lat": "42.0978",
    "lng": "-88.53036"
  },
  {
    "country": "US",
    "name": "Hampton",
    "lat": "41.55587",
    "lng": "-90.4093"
  },
  {
    "country": "US",
    "name": "Hanna City",
    "lat": "40.6917",
    "lng": "-89.79511"
  },
  {
    "country": "US",
    "name": "Hanover Park",
    "lat": "41.99947",
    "lng": "-88.14507"
  },
  {
    "country": "US",
    "name": "Harvard",
    "lat": "42.42224",
    "lng": "-88.61371"
  },
  {
    "country": "US",
    "name": "Harvey",
    "lat": "41.61003",
    "lng": "-87.64671"
  },
  {
    "country": "US",
    "name": "Harwood Heights",
    "lat": "41.96725",
    "lng": "-87.80756"
  },
  {
    "country": "US",
    "name": "Havana",
    "lat": "40.30004",
    "lng": "-90.06095"
  },
  {
    "country": "US",
    "name": "Hawthorn Woods",
    "lat": "42.21697",
    "lng": "-88.04952"
  },
  {
    "country": "US",
    "name": "Hazel Crest",
    "lat": "41.5717",
    "lng": "-87.69449"
  },
  {
    "country": "US",
    "name": "Hebron",
    "lat": "42.47169",
    "lng": "-88.43232"
  },
  {
    "country": "US",
    "name": "Hennepin",
    "lat": "41.2542",
    "lng": "-89.34231"
  },
  {
    "country": "US",
    "name": "Henry",
    "lat": "41.11142",
    "lng": "-89.35648"
  },
  {
    "country": "US",
    "name": "Herscher",
    "lat": "41.0492",
    "lng": "-88.09783"
  },
  {
    "country": "US",
    "name": "Heyworth",
    "lat": "40.31337",
    "lng": "-88.97369"
  },
  {
    "country": "US",
    "name": "Hickory Hills",
    "lat": "41.72559",
    "lng": "-87.82506"
  },
  {
    "country": "US",
    "name": "Highland Park",
    "lat": "42.18169",
    "lng": "-87.80034"
  },
  {
    "country": "US",
    "name": "Highwood",
    "lat": "42.19975",
    "lng": "-87.80923"
  },
  {
    "country": "US",
    "name": "Hillcrest",
    "lat": "41.95114",
    "lng": "-89.06454"
  },
  {
    "country": "US",
    "name": "Hillside",
    "lat": "41.87781",
    "lng": "-87.90284"
  },
  {
    "country": "US",
    "name": "Hinckley",
    "lat": "41.76892",
    "lng": "-88.64091"
  },
  {
    "country": "US",
    "name": "Hinsdale",
    "lat": "41.80086",
    "lng": "-87.93701"
  },
  {
    "country": "US",
    "name": "Hodgkins",
    "lat": "41.76892",
    "lng": "-87.85783"
  },
  {
    "country": "US",
    "name": "Hoffman Estates",
    "lat": "42.04281",
    "lng": "-88.0798"
  },
  {
    "country": "US",
    "name": "Homer",
    "lat": "40.03476",
    "lng": "-87.95809"
  },
  {
    "country": "US",
    "name": "Homer Glen",
    "lat": "41.60003",
    "lng": "-87.93811"
  },
  {
    "country": "US",
    "name": "Hometown",
    "lat": "41.73448",
    "lng": "-87.73144"
  },
  {
    "country": "US",
    "name": "Homewood",
    "lat": "41.55726",
    "lng": "-87.6656"
  },
  {
    "country": "US",
    "name": "Hoopeston",
    "lat": "40.46726",
    "lng": "-87.66836"
  },
  {
    "country": "US",
    "name": "Hudson",
    "lat": "40.60587",
    "lng": "-88.9873"
  },
  {
    "country": "US",
    "name": "Huntley",
    "lat": "42.16808",
    "lng": "-88.42814"
  },
  {
    "country": "US",
    "name": "Hyde Park",
    "lat": "41.7942",
    "lng": "-87.59394"
  },
  {
    "country": "US",
    "name": "Indian Head Park",
    "lat": "41.77031",
    "lng": "-87.90228"
  },
  {
    "country": "US",
    "name": "Ingalls Park",
    "lat": "41.52253",
    "lng": "-88.04283"
  },
  {
    "country": "US",
    "name": "Inverness",
    "lat": "42.11808",
    "lng": "-88.09619"
  },
  {
    "country": "US",
    "name": "Irving Park",
    "lat": "41.95336",
    "lng": "-87.73645"
  },
  {
    "country": "US",
    "name": "Island Lake",
    "lat": "42.27613",
    "lng": "-88.19203"
  },
  {
    "country": "US",
    "name": "Itasca",
    "lat": "41.97503",
    "lng": "-88.00729"
  },
  {
    "country": "US",
    "name": "Johnsburg",
    "lat": "42.38002",
    "lng": "-88.24203"
  },
  {
    "country": "US",
    "name": "Joliet",
    "lat": "41.52519",
    "lng": "-88.0834"
  },
  {
    "country": "US",
    "name": "Justice",
    "lat": "41.74448",
    "lng": "-87.83783"
  },
  {
    "country": "US",
    "name": "Kankakee",
    "lat": "41.12003",
    "lng": "-87.86115"
  },
  {
    "country": "US",
    "name": "Kenilworth",
    "lat": "42.08586",
    "lng": "-87.71756"
  },
  {
    "country": "US",
    "name": "Kenwood",
    "lat": "41.8092",
    "lng": "-87.59755"
  },
  {
    "country": "US",
    "name": "Kewanee",
    "lat": "41.24559",
    "lng": "-89.92483"
  },
  {
    "country": "US",
    "name": "Kildeer",
    "lat": "42.17058",
    "lng": "-88.04785"
  },
  {
    "country": "US",
    "name": "Kingston",
    "lat": "42.09975",
    "lng": "-88.75898"
  },
  {
    "country": "US",
    "name": "Kirkland",
    "lat": "42.09253",
    "lng": "-88.85121"
  },
  {
    "country": "US",
    "name": "Knollwood",
    "lat": "42.28613",
    "lng": "-87.88563"
  },
  {
    "country": "US",
    "name": "Knoxville",
    "lat": "40.90837",
    "lng": "-90.28485"
  },
  {
    "country": "US",
    "name": "La Grange",
    "lat": "41.80503",
    "lng": "-87.86923"
  },
  {
    "country": "US",
    "name": "La Grange Park",
    "lat": "41.83475",
    "lng": "-87.86173"
  },
  {
    "country": "US",
    "name": "La Harpe",
    "lat": "40.58337",
    "lng": "-90.96931"
  },
  {
    "country": "US",
    "name": "La Salle",
    "lat": "41.33337",
    "lng": "-89.09175"
  },
  {
    "country": "US",
    "name": "Lacon",
    "lat": "41.02476",
    "lng": "-89.4112"
  },
  {
    "country": "US",
    "name": "Ladd",
    "lat": "41.38253",
    "lng": "-89.21897"
  },
  {
    "country": "US",
    "name": "Lake Barrington",
    "lat": "42.21252",
    "lng": "-88.15258"
  },
  {
    "country": "US",
    "name": "Lake Bluff",
    "lat": "42.27891",
    "lng": "-87.83424"
  },
  {
    "country": "US",
    "name": "Lake Catherine",
    "lat": "42.47919",
    "lng": "-88.13342"
  },
  {
    "country": "US",
    "name": "Lake Forest",
    "lat": "42.25863",
    "lng": "-87.84063"
  },
  {
    "country": "US",
    "name": "Lake Summerset",
    "lat": "42.45446",
    "lng": "-89.38956"
  },
  {
    "country": "US",
    "name": "Lake Villa",
    "lat": "42.41697",
    "lng": "-88.07397"
  },
  {
    "country": "US",
    "name": "Lake Zurich",
    "lat": "42.19697",
    "lng": "-88.09341"
  },
  {
    "country": "US",
    "name": "Lake in the Hills",
    "lat": "42.18169",
    "lng": "-88.33036"
  },
  {
    "country": "US",
    "name": "Lake of the Woods",
    "lat": "40.20642",
    "lng": "-88.36867"
  },
  {
    "country": "US",
    "name": "Lakemoor",
    "lat": "42.32863",
    "lng": "-88.19897"
  },
  {
    "country": "US",
    "name": "Lakewood",
    "lat": "42.22919",
    "lng": "-88.35509"
  },
  {
    "country": "US",
    "name": "Lakewood Shores",
    "lat": "41.2817",
    "lng": "-88.14478"
  },
  {
    "country": "US",
    "name": "Lanark",
    "lat": "42.10225",
    "lng": "-89.83345"
  },
  {
    "country": "US",
    "name": "Lansing",
    "lat": "41.56476",
    "lng": "-87.53893"
  },
  {
    "country": "US",
    "name": "Le Roy",
    "lat": "40.35198",
    "lng": "-88.76424"
  },
  {
    "country": "US",
    "name": "Lemont",
    "lat": "41.67364",
    "lng": "-88.00173"
  },
  {
    "country": "US",
    "name": "Lewistown",
    "lat": "40.3931",
    "lng": "-90.15484"
  },
  {
    "country": "US",
    "name": "Lexington",
    "lat": "40.64142",
    "lng": "-88.7834"
  },
  {
    "country": "US",
    "name": "Libertyville",
    "lat": "42.28308",
    "lng": "-87.95313"
  },
  {
    "country": "US",
    "name": "Lily Lake",
    "lat": "41.94892",
    "lng": "-88.47786"
  },
  {
    "country": "US",
    "name": "Lincoln",
    "lat": "40.14838",
    "lng": "-89.36482"
  },
  {
    "country": "US",
    "name": "Lincoln Park",
    "lat": "41.9217",
    "lng": "-87.64783"
  },
  {
    "country": "US",
    "name": "Lincoln Square",
    "lat": "41.97587",
    "lng": "-87.68922"
  },
  {
    "country": "US",
    "name": "Lincolnshire",
    "lat": "42.19002",
    "lng": "-87.9084"
  },
  {
    "country": "US",
    "name": "Lincolnwood",
    "lat": "42.00448",
    "lng": "-87.73006"
  },
  {
    "country": "US",
    "name": "Lindenhurst",
    "lat": "42.41058",
    "lng": "-88.02619"
  },
  {
    "country": "US",
    "name": "Lisle",
    "lat": "41.80114",
    "lng": "-88.07479"
  },
  {
    "country": "US",
    "name": "Lockport",
    "lat": "41.58948",
    "lng": "-88.05784"
  },
  {
    "country": "US",
    "name": "Logan Square",
    "lat": "41.92337",
    "lng": "-87.69922"
  },
  {
    "country": "US",
    "name": "Lombard",
    "lat": "41.88003",
    "lng": "-88.00784"
  },
  {
    "country": "US",
    "name": "Long Grove",
    "lat": "42.17836",
    "lng": "-87.99785"
  },
  {
    "country": "US",
    "name": "Long Lake",
    "lat": "42.37085",
    "lng": "-88.12758"
  },
  {
    "country": "US",
    "name": "Loves Park",
    "lat": "42.32002",
    "lng": "-89.05816"
  },
  {
    "country": "US",
    "name": "Lower West Side",
    "lat": "41.8542",
    "lng": "-87.66561"
  },
  {
    "country": "US",
    "name": "Lynwood",
    "lat": "41.52642",
    "lng": "-87.53865"
  },
  {
    "country": "US",
    "name": "Lynwood",
    "lat": "41.68364",
    "lng": "-88.39368"
  },
  {
    "country": "US",
    "name": "Lyons",
    "lat": "41.81337",
    "lng": "-87.81811"
  },
  {
    "country": "US",
    "name": "Machesney Park",
    "lat": "42.34724",
    "lng": "-89.039"
  },
  {
    "country": "US",
    "name": "Mackinaw",
    "lat": "40.53698",
    "lng": "-89.35759"
  },
  {
    "country": "US",
    "name": "Macomb",
    "lat": "40.45921",
    "lng": "-90.6718"
  },
  {
    "country": "US",
    "name": "Mahomet",
    "lat": "40.19531",
    "lng": "-88.40422"
  },
  {
    "country": "US",
    "name": "Malta",
    "lat": "41.92975",
    "lng": "-88.86092"
  },
  {
    "country": "US",
    "name": "Manhattan",
    "lat": "41.42253",
    "lng": "-87.98589"
  },
  {
    "country": "US",
    "name": "Manito",
    "lat": "40.42587",
    "lng": "-89.77928"
  },
  {
    "country": "US",
    "name": "Manteno",
    "lat": "41.25059",
    "lng": "-87.83143"
  },
  {
    "country": "US",
    "name": "Maple Park",
    "lat": "41.90753",
    "lng": "-88.59925"
  },
  {
    "country": "US",
    "name": "Marengo",
    "lat": "42.24863",
    "lng": "-88.60843"
  },
  {
    "country": "US",
    "name": "Markham",
    "lat": "41.59365",
    "lng": "-87.69477"
  },
  {
    "country": "US",
    "name": "Maroa",
    "lat": "40.03643",
    "lng": "-88.95703"
  },
  {
    "country": "US",
    "name": "Marquette Heights",
    "lat": "40.61754",
    "lng": "-89.60038"
  },
  {
    "country": "US",
    "name": "Marseilles",
    "lat": "41.33087",
    "lng": "-88.70813"
  },
  {
    "country": "US",
    "name": "Mason City",
    "lat": "40.20227",
    "lng": "-89.69816"
  },
  {
    "country": "US",
    "name": "Matteson",
    "lat": "41.50392",
    "lng": "-87.7131"
  },
  {
    "country": "US",
    "name": "Maywood",
    "lat": "41.8792",
    "lng": "-87.84312"
  },
  {
    "country": "US",
    "name": "McCullom Lake",
    "lat": "42.36835",
    "lng": "-88.29259"
  },
  {
    "country": "US",
    "name": "McHenry",
    "lat": "42.33335",
    "lng": "-88.26675"
  },
  {
    "country": "US",
    "name": "McKinley Park",
    "lat": "41.8317",
    "lng": "-87.67366"
  },
  {
    "country": "US",
    "name": "Melrose Park",
    "lat": "41.90059",
    "lng": "-87.85673"
  },
  {
    "country": "US",
    "name": "Mendota",
    "lat": "41.54725",
    "lng": "-89.11759"
  },
  {
    "country": "US",
    "name": "Merrionette Park",
    "lat": "41.6842",
    "lng": "-87.70033"
  },
  {
    "country": "US",
    "name": "Metamora",
    "lat": "40.79059",
    "lng": "-89.36064"
  },
  {
    "country": "US",
    "name": "Midlothian",
    "lat": "41.62531",
    "lng": "-87.71755"
  },
  {
    "country": "US",
    "name": "Milan",
    "lat": "41.45309",
    "lng": "-90.57208"
  },
  {
    "country": "US",
    "name": "Milford",
    "lat": "40.62837",
    "lng": "-87.69614"
  },
  {
    "country": "US",
    "name": "Minier",
    "lat": "40.43365",
    "lng": "-89.31315"
  },
  {
    "country": "US",
    "name": "Minonk",
    "lat": "40.90448",
    "lng": "-89.03452"
  },
  {
    "country": "US",
    "name": "Minooka",
    "lat": "41.45531",
    "lng": "-88.26173"
  },
  {
    "country": "US",
    "name": "Mokena",
    "lat": "41.52614",
    "lng": "-87.88922"
  },
  {
    "country": "US",
    "name": "Moline",
    "lat": "41.5067",
    "lng": "-90.51513"
  },
  {
    "country": "US",
    "name": "Momence",
    "lat": "41.1667",
    "lng": "-87.66281"
  },
  {
    "country": "US",
    "name": "Monee",
    "lat": "41.42003",
    "lng": "-87.74171"
  },
  {
    "country": "US",
    "name": "Monmouth",
    "lat": "40.91143",
    "lng": "-90.64736"
  },
  {
    "country": "US",
    "name": "Montgomery",
    "lat": "41.73058",
    "lng": "-88.3459"
  },
  {
    "country": "US",
    "name": "Monticello",
    "lat": "40.02781",
    "lng": "-88.5734"
  },
  {
    "country": "US",
    "name": "Morgan Park",
    "lat": "41.69031",
    "lng": "-87.66672"
  },
  {
    "country": "US",
    "name": "Morris",
    "lat": "41.35725",
    "lng": "-88.42118"
  },
  {
    "country": "US",
    "name": "Morrison",
    "lat": "41.80975",
    "lng": "-89.96512"
  },
  {
    "country": "US",
    "name": "Morton",
    "lat": "40.61282",
    "lng": "-89.45926"
  },
  {
    "country": "US",
    "name": "Morton Grove",
    "lat": "42.04059",
    "lng": "-87.78256"
  },
  {
    "country": "US",
    "name": "Mount Carroll",
    "lat": "42.09502",
    "lng": "-89.97818"
  },
  {
    "country": "US",
    "name": "Mount Greenwood",
    "lat": "41.69809",
    "lng": "-87.70866"
  },
  {
    "country": "US",
    "name": "Mount Morris",
    "lat": "42.05031",
    "lng": "-89.43122"
  },
  {
    "country": "US",
    "name": "Mount Prospect",
    "lat": "42.06642",
    "lng": "-87.93729"
  },
  {
    "country": "US",
    "name": "Mount Pulaski",
    "lat": "40.01088",
    "lng": "-89.28231"
  },
  {
    "country": "US",
    "name": "Mundelein",
    "lat": "42.26308",
    "lng": "-88.00397"
  },
  {
    "country": "US",
    "name": "Naperville",
    "lat": "41.78586",
    "lng": "-88.14729"
  },
  {
    "country": "US",
    "name": "Nauvoo",
    "lat": "40.55004",
    "lng": "-91.38487"
  },
  {
    "country": "US",
    "name": "Near North Side",
    "lat": "41.90003",
    "lng": "-87.6345"
  },
  {
    "country": "US",
    "name": "Near South Side",
    "lat": "41.8567",
    "lng": "-87.62477"
  },
  {
    "country": "US",
    "name": "New City",
    "lat": "41.80753",
    "lng": "-87.65644"
  },
  {
    "country": "US",
    "name": "New Lenox",
    "lat": "41.51198",
    "lng": "-87.96561"
  },
  {
    "country": "US",
    "name": "Newark",
    "lat": "41.53697",
    "lng": "-88.58341"
  },
  {
    "country": "US",
    "name": "Niles",
    "lat": "42.01892",
    "lng": "-87.80284"
  },
  {
    "country": "US",
    "name": "Normal",
    "lat": "40.5142",
    "lng": "-88.99063"
  },
  {
    "country": "US",
    "name": "Norridge",
    "lat": "41.96336",
    "lng": "-87.82728"
  },
  {
    "country": "US",
    "name": "North Aurora",
    "lat": "41.80614",
    "lng": "-88.3273"
  },
  {
    "country": "US",
    "name": "North Barrington",
    "lat": "42.2078",
    "lng": "-88.14063"
  },
  {
    "country": "US",
    "name": "North Center",
    "lat": "41.95392",
    "lng": "-87.67895"
  },
  {
    "country": "US",
    "name": "North Chicago",
    "lat": "42.32558",
    "lng": "-87.84118"
  },
  {
    "country": "US",
    "name": "North Lawndale",
    "lat": "41.86003",
    "lng": "-87.71839"
  },
  {
    "country": "US",
    "name": "North Pekin",
    "lat": "40.61504",
    "lng": "-89.62232"
  },
  {
    "country": "US",
    "name": "North Peoria",
    "lat": "40.71754",
    "lng": "-89.58426"
  },
  {
    "country": "US",
    "name": "North Riverside",
    "lat": "41.84281",
    "lng": "-87.82311"
  },
  {
    "country": "US",
    "name": "Northbrook",
    "lat": "42.12753",
    "lng": "-87.82895"
  },
  {
    "country": "US",
    "name": "Northfield",
    "lat": "42.09975",
    "lng": "-87.7809"
  },
  {
    "country": "US",
    "name": "Northlake",
    "lat": "41.91725",
    "lng": "-87.89562"
  },
  {
    "country": "US",
    "name": "Oak Brook",
    "lat": "41.83281",
    "lng": "-87.92895"
  },
  {
    "country": "US",
    "name": "Oak Forest",
    "lat": "41.60281",
    "lng": "-87.74394"
  },
  {
    "country": "US",
    "name": "Oak Lawn",
    "lat": "41.71087",
    "lng": "-87.75811"
  },
  {
    "country": "US",
    "name": "Oak Park",
    "lat": "41.88503",
    "lng": "-87.7845"
  },
  {
    "country": "US",
    "name": "Oakbrook Terrace",
    "lat": "41.85003",
    "lng": "-87.96451"
  },
  {
    "country": "US",
    "name": "Oakwood",
    "lat": "40.11615",
    "lng": "-87.77836"
  },
  {
    "country": "US",
    "name": "Oakwood Hills",
    "lat": "42.24641",
    "lng": "-88.24286"
  },
  {
    "country": "US",
    "name": "Oglesby",
    "lat": "41.29531",
    "lng": "-89.05953"
  },
  {
    "country": "US",
    "name": "Olympia Fields",
    "lat": "41.51337",
    "lng": "-87.67421"
  },
  {
    "country": "US",
    "name": "Onarga",
    "lat": "40.71504",
    "lng": "-88.00615"
  },
  {
    "country": "US",
    "name": "Oquawka",
    "lat": "40.93198",
    "lng": "-90.94709"
  },
  {
    "country": "US",
    "name": "Oregon",
    "lat": "42.01475",
    "lng": "-89.33233"
  },
  {
    "country": "US",
    "name": "Orion",
    "lat": "41.35476",
    "lng": "-90.38152"
  },
  {
    "country": "US",
    "name": "Orland Hills",
    "lat": "41.58531",
    "lng": "-87.84311"
  },
  {
    "country": "US",
    "name": "Orland Park",
    "lat": "41.63031",
    "lng": "-87.85394"
  },
  {
    "country": "US",
    "name": "Oswego",
    "lat": "41.68281",
    "lng": "-88.35146"
  },
  {
    "country": "US",
    "name": "Ottawa",
    "lat": "41.34559",
    "lng": "-88.84258"
  },
  {
    "country": "US",
    "name": "Palatine",
    "lat": "42.1103",
    "lng": "-88.03424"
  },
  {
    "country": "US",
    "name": "Palos Heights",
    "lat": "41.66809",
    "lng": "-87.79644"
  },
  {
    "country": "US",
    "name": "Palos Hills",
    "lat": "41.6967",
    "lng": "-87.817"
  },
  {
    "country": "US",
    "name": "Palos Park",
    "lat": "41.66725",
    "lng": "-87.83033"
  },
  {
    "country": "US",
    "name": "Park City",
    "lat": "42.34836",
    "lng": "-87.88424"
  },
  {
    "country": "US",
    "name": "Park Forest",
    "lat": "41.49142",
    "lng": "-87.67449"
  },
  {
    "country": "US",
    "name": "Park Ridge",
    "lat": "42.01114",
    "lng": "-87.84062"
  },
  {
    "country": "US",
    "name": "Paxton",
    "lat": "40.46031",
    "lng": "-88.09532"
  },
  {
    "country": "US",
    "name": "Pecatonica",
    "lat": "42.31391",
    "lng": "-89.35928"
  },
  {
    "country": "US",
    "name": "Pekin",
    "lat": "40.56754",
    "lng": "-89.64066"
  },
  {
    "country": "US",
    "name": "Peoria",
    "lat": "40.69365",
    "lng": "-89.58899"
  },
  {
    "country": "US",
    "name": "Peoria Heights",
    "lat": "40.74726",
    "lng": "-89.57398"
  },
  {
    "country": "US",
    "name": "Peotone",
    "lat": "41.33226",
    "lng": "-87.78532"
  },
  {
    "country": "US",
    "name": "Peru",
    "lat": "41.32753",
    "lng": "-89.12897"
  },
  {
    "country": "US",
    "name": "Petersburg",
    "lat": "40.01172",
    "lng": "-89.84817"
  },
  {
    "country": "US",
    "name": "Philo",
    "lat": "40.00698",
    "lng": "-88.1581"
  },
  {
    "country": "US",
    "name": "Phoenix",
    "lat": "41.61115",
    "lng": "-87.63477"
  },
  {
    "country": "US",
    "name": "Pingree Grove",
    "lat": "42.06864",
    "lng": "-88.41342"
  },
  {
    "country": "US",
    "name": "Pistakee Highlands",
    "lat": "42.40863",
    "lng": "-88.20648"
  },
  {
    "country": "US",
    "name": "Plainfield",
    "lat": "41.62697",
    "lng": "-88.20395"
  },
  {
    "country": "US",
    "name": "Plano",
    "lat": "41.66281",
    "lng": "-88.53702"
  },
  {
    "country": "US",
    "name": "Polo",
    "lat": "41.98614",
    "lng": "-89.57928"
  },
  {
    "country": "US",
    "name": "Pontiac",
    "lat": "40.88087",
    "lng": "-88.62978"
  },
  {
    "country": "US",
    "name": "Poplar Grove",
    "lat": "42.36835",
    "lng": "-88.82205"
  },
  {
    "country": "US",
    "name": "Port Barrington",
    "lat": "42.24252",
    "lng": "-88.20203"
  },
  {
    "country": "US",
    "name": "Port Byron",
    "lat": "41.60642",
    "lng": "-90.33541"
  },
  {
    "country": "US",
    "name": "Portage Park",
    "lat": "41.95781",
    "lng": "-87.76506"
  },
  {
    "country": "US",
    "name": "Posen",
    "lat": "41.6317",
    "lng": "-87.68144"
  },
  {
    "country": "US",
    "name": "Prairie Grove",
    "lat": "42.27863",
    "lng": "-88.26092"
  },
  {
    "country": "US",
    "name": "Preston Heights",
    "lat": "41.4917",
    "lng": "-88.08172"
  },
  {
    "country": "US",
    "name": "Princeton",
    "lat": "41.36809",
    "lng": "-89.46481"
  },
  {
    "country": "US",
    "name": "Princeville",
    "lat": "40.92976",
    "lng": "-89.7576"
  },
  {
    "country": "US",
    "name": "Prophetstown",
    "lat": "41.67142",
    "lng": "-89.93622"
  },
  {
    "country": "US",
    "name": "Prospect Heights",
    "lat": "42.0953",
    "lng": "-87.93757"
  },
  {
    "country": "US",
    "name": "Rantoul",
    "lat": "40.30837",
    "lng": "-88.15588"
  },
  {
    "country": "US",
    "name": "Richmond",
    "lat": "42.47585",
    "lng": "-88.30593"
  },
  {
    "country": "US",
    "name": "Richmond",
    "lat": "40.36087",
    "lng": "-89.36898"
  },
  {
    "country": "US",
    "name": "Richton Park",
    "lat": "41.48448",
    "lng": "-87.70338"
  },
  {
    "country": "US",
    "name": "River Forest",
    "lat": "41.89781",
    "lng": "-87.81395"
  },
  {
    "country": "US",
    "name": "River Grove",
    "lat": "41.92586",
    "lng": "-87.83589"
  },
  {
    "country": "US",
    "name": "Riverdale",
    "lat": "41.63337",
    "lng": "-87.6331"
  },
  {
    "country": "US",
    "name": "Riverside",
    "lat": "41.83503",
    "lng": "-87.82284"
  },
  {
    "country": "US",
    "name": "Riverwoods",
    "lat": "42.16753",
    "lng": "-87.89701"
  },
  {
    "country": "US",
    "name": "Roanoke",
    "lat": "40.79615",
    "lng": "-89.1973"
  },
  {
    "country": "US",
    "name": "Robbins",
    "lat": "41.64392",
    "lng": "-87.70366"
  },
  {
    "country": "US",
    "name": "Rochelle",
    "lat": "41.92392",
    "lng": "-89.06871"
  },
  {
    "country": "US",
    "name": "Rock Falls",
    "lat": "41.77975",
    "lng": "-89.689"
  },
  {
    "country": "US",
    "name": "Rock Island",
    "lat": "41.50948",
    "lng": "-90.57875"
  },
  {
    "country": "US",
    "name": "Rockdale",
    "lat": "41.50614",
    "lng": "-88.1145"
  },
  {
    "country": "US",
    "name": "Rockford",
    "lat": "42.27113",
    "lng": "-89.094"
  },
  {
    "country": "US",
    "name": "Rockton",
    "lat": "42.45252",
    "lng": "-89.07233"
  },
  {
    "country": "US",
    "name": "Rogers Park",
    "lat": "42.00864",
    "lng": "-87.66672"
  },
  {
    "country": "US",
    "name": "Rolling Meadows",
    "lat": "42.08419",
    "lng": "-88.01313"
  },
  {
    "country": "US",
    "name": "Rome",
    "lat": "40.88309",
    "lng": "-89.50259"
  },
  {
    "country": "US",
    "name": "Romeoville",
    "lat": "41.64753",
    "lng": "-88.08951"
  },
  {
    "country": "US",
    "name": "Roscoe",
    "lat": "42.41335",
    "lng": "-89.00927"
  },
  {
    "country": "US",
    "name": "Roselle",
    "lat": "41.98475",
    "lng": "-88.07979"
  },
  {
    "country": "US",
    "name": "Rosemont",
    "lat": "41.99531",
    "lng": "-87.88451"
  },
  {
    "country": "US",
    "name": "Rossville",
    "lat": "40.3792",
    "lng": "-87.66863"
  },
  {
    "country": "US",
    "name": "Round Lake",
    "lat": "42.35336",
    "lng": "-88.09341"
  },
  {
    "country": "US",
    "name": "Round Lake Beach",
    "lat": "42.37169",
    "lng": "-88.09008"
  },
  {
    "country": "US",
    "name": "Round Lake Heights",
    "lat": "42.38002",
    "lng": "-88.10425"
  },
  {
    "country": "US",
    "name": "Round Lake Park",
    "lat": "42.35697",
    "lng": "-88.07675"
  },
  {
    "country": "US",
    "name": "Rushville",
    "lat": "40.12116",
    "lng": "-90.56318"
  },
  {
    "country": "US",
    "name": "Saint Anne",
    "lat": "41.02503",
    "lng": "-87.71392"
  },
  {
    "country": "US",
    "name": "Saint Charles",
    "lat": "41.91419",
    "lng": "-88.30869"
  },
  {
    "country": "US",
    "name": "Saint Joseph",
    "lat": "40.1117",
    "lng": "-88.0417"
  },
  {
    "country": "US",
    "name": "Sandwich",
    "lat": "41.64586",
    "lng": "-88.62174"
  },
  {
    "country": "US",
    "name": "Sauk Village",
    "lat": "41.48837",
    "lng": "-87.56754"
  },
  {
    "country": "US",
    "name": "Savanna",
    "lat": "42.09447",
    "lng": "-90.15679"
  },
  {
    "country": "US",
    "name": "Savoy",
    "lat": "40.05475",
    "lng": "-88.25172"
  },
  {
    "country": "US",
    "name": "Schaumburg",
    "lat": "42.03336",
    "lng": "-88.08341"
  },
  {
    "country": "US",
    "name": "Schiller Park",
    "lat": "41.95586",
    "lng": "-87.8709"
  },
  {
    "country": "US",
    "name": "Seneca",
    "lat": "41.31114",
    "lng": "-88.60979"
  },
  {
    "country": "US",
    "name": "Sheldon",
    "lat": "40.7692",
    "lng": "-87.56392"
  },
  {
    "country": "US",
    "name": "Sheridan",
    "lat": "41.53003",
    "lng": "-88.6798"
  },
  {
    "country": "US",
    "name": "Shorewood",
    "lat": "41.52003",
    "lng": "-88.20173"
  },
  {
    "country": "US",
    "name": "Sidney",
    "lat": "40.02503",
    "lng": "-88.07337"
  },
  {
    "country": "US",
    "name": "Silvis",
    "lat": "41.51226",
    "lng": "-90.41513"
  },
  {
    "country": "US",
    "name": "Skokie",
    "lat": "42.03336",
    "lng": "-87.73339"
  },
  {
    "country": "US",
    "name": "Sleepy Hollow",
    "lat": "42.09419",
    "lng": "-88.30258"
  },
  {
    "country": "US",
    "name": "Somonauk",
    "lat": "41.63364",
    "lng": "-88.68119"
  },
  {
    "country": "US",
    "name": "South Barrington",
    "lat": "42.09142",
    "lng": "-88.12174"
  },
  {
    "country": "US",
    "name": "South Beloit",
    "lat": "42.49307",
    "lng": "-89.03678"
  },
  {
    "country": "US",
    "name": "South Chicago",
    "lat": "41.73977",
    "lng": "-87.55425"
  },
  {
    "country": "US",
    "name": "South Chicago Heights",
    "lat": "41.48087",
    "lng": "-87.63782"
  },
  {
    "country": "US",
    "name": "South Elgin",
    "lat": "41.99419",
    "lng": "-88.2923"
  },
  {
    "country": "US",
    "name": "South Holland",
    "lat": "41.60087",
    "lng": "-87.60699"
  },
  {
    "country": "US",
    "name": "South Lawndale",
    "lat": "41.84364",
    "lng": "-87.71255"
  },
  {
    "country": "US",
    "name": "South Pekin",
    "lat": "40.49448",
    "lng": "-89.65177"
  },
  {
    "country": "US",
    "name": "South Shore",
    "lat": "41.76198",
    "lng": "-87.57783"
  },
  {
    "country": "US",
    "name": "Spring Grove",
    "lat": "42.44363",
    "lng": "-88.23648"
  },
  {
    "country": "US",
    "name": "Spring Valley",
    "lat": "41.32754",
    "lng": "-89.19981"
  },
  {
    "country": "US",
    "name": "Steger",
    "lat": "41.47003",
    "lng": "-87.63643"
  },
  {
    "country": "US",
    "name": "Sterling",
    "lat": "41.78864",
    "lng": "-89.69622"
  },
  {
    "country": "US",
    "name": "Stickney",
    "lat": "41.82142",
    "lng": "-87.78283"
  },
  {
    "country": "US",
    "name": "Stillman Valley",
    "lat": "42.10725",
    "lng": "-89.17927"
  },
  {
    "country": "US",
    "name": "Stockton",
    "lat": "42.34974",
    "lng": "-90.00679"
  },
  {
    "country": "US",
    "name": "Stone Park",
    "lat": "41.90559",
    "lng": "-87.88367"
  },
  {
    "country": "US",
    "name": "Streamwood",
    "lat": "42.02558",
    "lng": "-88.17841"
  },
  {
    "country": "US",
    "name": "Streator",
    "lat": "41.12087",
    "lng": "-88.83535"
  },
  {
    "country": "US",
    "name": "Sugar Grove",
    "lat": "41.76142",
    "lng": "-88.44369"
  },
  {
    "country": "US",
    "name": "Summit",
    "lat": "41.78809",
    "lng": "-87.81033"
  },
  {
    "country": "US",
    "name": "Sycamore",
    "lat": "41.98892",
    "lng": "-88.68675"
  },
  {
    "country": "US",
    "name": "Third Lake",
    "lat": "42.37391",
    "lng": "-88.01091"
  },
  {
    "country": "US",
    "name": "Thomasboro",
    "lat": "40.2417",
    "lng": "-88.18421"
  },
  {
    "country": "US",
    "name": "Thornton",
    "lat": "41.56809",
    "lng": "-87.6081"
  },
  {
    "country": "US",
    "name": "Tilton",
    "lat": "40.09531",
    "lng": "-87.64752"
  },
  {
    "country": "US",
    "name": "Tinley Park",
    "lat": "41.57337",
    "lng": "-87.78449"
  },
  {
    "country": "US",
    "name": "Toluca",
    "lat": "41.00226",
    "lng": "-89.13342"
  },
  {
    "country": "US",
    "name": "Toulon",
    "lat": "41.09365",
    "lng": "-89.86483"
  },
  {
    "country": "US",
    "name": "Tower Lake",
    "lat": "42.23197",
    "lng": "-88.15202"
  },
  {
    "country": "US",
    "name": "Tremont",
    "lat": "40.52754",
    "lng": "-89.4926"
  },
  {
    "country": "US",
    "name": "Twin Grove",
    "lat": "40.49337",
    "lng": "-89.0798"
  },
  {
    "country": "US",
    "name": "Uptown",
    "lat": "41.9659",
    "lng": "-87.65262"
  },
  {
    "country": "US",
    "name": "Urbana",
    "lat": "40.11059",
    "lng": "-88.20727"
  },
  {
    "country": "US",
    "name": "Venetian Village",
    "lat": "42.39863",
    "lng": "-88.05258"
  },
  {
    "country": "US",
    "name": "Vernon Hills",
    "lat": "42.21947",
    "lng": "-87.97952"
  },
  {
    "country": "US",
    "name": "Villa Park",
    "lat": "41.88975",
    "lng": "-87.98895"
  },
  {
    "country": "US",
    "name": "Volo",
    "lat": "42.32613",
    "lng": "-88.16786"
  },
  {
    "country": "US",
    "name": "Wadsworth",
    "lat": "42.42863",
    "lng": "-87.92397"
  },
  {
    "country": "US",
    "name": "Walnut",
    "lat": "41.5567",
    "lng": "-89.59343"
  },
  {
    "country": "US",
    "name": "Warren",
    "lat": "42.4964",
    "lng": "-89.98957"
  },
  {
    "country": "US",
    "name": "Warrenville",
    "lat": "41.81781",
    "lng": "-88.1734"
  },
  {
    "country": "US",
    "name": "Warsaw",
    "lat": "40.35921",
    "lng": "-91.4346"
  },
  {
    "country": "US",
    "name": "Wasco",
    "lat": "41.93808",
    "lng": "-88.40452"
  },
  {
    "country": "US",
    "name": "Washburn",
    "lat": "40.9192",
    "lng": "-89.2912"
  },
  {
    "country": "US",
    "name": "Washington",
    "lat": "40.70365",
    "lng": "-89.40731"
  },
  {
    "country": "US",
    "name": "Waterman",
    "lat": "41.7717",
    "lng": "-88.77369"
  },
  {
    "country": "US",
    "name": "Watseka",
    "lat": "40.77615",
    "lng": "-87.73642"
  },
  {
    "country": "US",
    "name": "Wauconda",
    "lat": "42.25891",
    "lng": "-88.13925"
  },
  {
    "country": "US",
    "name": "Waukegan",
    "lat": "42.36363",
    "lng": "-87.84479"
  },
  {
    "country": "US",
    "name": "Wayne",
    "lat": "41.95086",
    "lng": "-88.2423"
  },
  {
    "country": "US",
    "name": "West Chicago",
    "lat": "41.88475",
    "lng": "-88.20396"
  },
  {
    "country": "US",
    "name": "West Dundee",
    "lat": "42.09808",
    "lng": "-88.28286"
  },
  {
    "country": "US",
    "name": "West Elsdon",
    "lat": "41.79392",
    "lng": "-87.7245"
  },
  {
    "country": "US",
    "name": "West Englewood",
    "lat": "41.77809",
    "lng": "-87.66672"
  },
  {
    "country": "US",
    "name": "West Garfield Park",
    "lat": "41.88059",
    "lng": "-87.72922"
  },
  {
    "country": "US",
    "name": "West Lawn",
    "lat": "41.77281",
    "lng": "-87.72227"
  },
  {
    "country": "US",
    "name": "West Peoria",
    "lat": "40.69254",
    "lng": "-89.62788"
  },
  {
    "country": "US",
    "name": "West Ridge",
    "lat": "41.99975",
    "lng": "-87.69284"
  },
  {
    "country": "US",
    "name": "West Town",
    "lat": "41.89381",
    "lng": "-87.67493"
  },
  {
    "country": "US",
    "name": "Westchester",
    "lat": "41.85059",
    "lng": "-87.882"
  },
  {
    "country": "US",
    "name": "Western Springs",
    "lat": "41.80975",
    "lng": "-87.90062"
  },
  {
    "country": "US",
    "name": "Westmont",
    "lat": "41.79586",
    "lng": "-87.97562"
  },
  {
    "country": "US",
    "name": "Westville",
    "lat": "40.04226",
    "lng": "-87.63863"
  },
  {
    "country": "US",
    "name": "Wheaton",
    "lat": "41.86614",
    "lng": "-88.10701"
  },
  {
    "country": "US",
    "name": "Wheeling",
    "lat": "42.13919",
    "lng": "-87.92896"
  },
  {
    "country": "US",
    "name": "Willow Springs",
    "lat": "41.74087",
    "lng": "-87.86033"
  },
  {
    "country": "US",
    "name": "Willowbrook",
    "lat": "41.76975",
    "lng": "-87.93589"
  },
  {
    "country": "US",
    "name": "Willowbrook",
    "lat": "41.45781",
    "lng": "-87.53643"
  },
  {
    "country": "US",
    "name": "Wilmette",
    "lat": "42.07225",
    "lng": "-87.72284"
  },
  {
    "country": "US",
    "name": "Wilmington",
    "lat": "41.30781",
    "lng": "-88.14672"
  },
  {
    "country": "US",
    "name": "Winfield",
    "lat": "41.8617",
    "lng": "-88.1609"
  },
  {
    "country": "US",
    "name": "Winnebago",
    "lat": "42.26613",
    "lng": "-89.24122"
  },
  {
    "country": "US",
    "name": "Winnetka",
    "lat": "42.10808",
    "lng": "-87.7359"
  },
  {
    "country": "US",
    "name": "Winthrop Harbor",
    "lat": "42.47891",
    "lng": "-87.82368"
  },
  {
    "country": "US",
    "name": "Wonder Lake",
    "lat": "42.3853",
    "lng": "-88.34731"
  },
  {
    "country": "US",
    "name": "Wood Dale",
    "lat": "41.96336",
    "lng": "-87.97896"
  },
  {
    "country": "US",
    "name": "Woodlawn",
    "lat": "41.77948",
    "lng": "-87.59949"
  },
  {
    "country": "US",
    "name": "Woodridge",
    "lat": "41.74697",
    "lng": "-88.05034"
  },
  {
    "country": "US",
    "name": "Woodstock",
    "lat": "42.31474",
    "lng": "-88.4487"
  },
  {
    "country": "US",
    "name": "Worth",
    "lat": "41.68975",
    "lng": "-87.79728"
  },
  {
    "country": "US",
    "name": "Wyoming",
    "lat": "41.0617",
    "lng": "-89.77316"
  },
  {
    "country": "US",
    "name": "Yorkville",
    "lat": "41.64114",
    "lng": "-88.44729"
  },
  {
    "country": "US",
    "name": "Zion",
    "lat": "42.44613",
    "lng": "-87.83285"
  },
  {
    "country": "US",
    "name": "Aberdeen",
    "lat": "41.43893",
    "lng": "-87.11142"
  },
  {
    "country": "US",
    "name": "Akron",
    "lat": "41.03838",
    "lng": "-86.02805"
  },
  {
    "country": "US",
    "name": "Albany",
    "lat": "40.30088",
    "lng": "-85.24191"
  },
  {
    "country": "US",
    "name": "Albion",
    "lat": "41.3956",
    "lng": "-85.42442"
  },
  {
    "country": "US",
    "name": "Alexandria",
    "lat": "40.26282",
    "lng": "-85.67581"
  },
  {
    "country": "US",
    "name": "Anderson",
    "lat": "40.10532",
    "lng": "-85.68025"
  },
  {
    "country": "US",
    "name": "Andrews",
    "lat": "40.86254",
    "lng": "-85.60165"
  },
  {
    "country": "US",
    "name": "Angola",
    "lat": "41.63477",
    "lng": "-84.99941"
  },
  {
    "country": "US",
    "name": "Arcadia",
    "lat": "40.17587",
    "lng": "-86.02165"
  },
  {
    "country": "US",
    "name": "Argos",
    "lat": "41.2378",
    "lng": "-86.21465"
  },
  {
    "country": "US",
    "name": "Attica",
    "lat": "40.2942",
    "lng": "-87.2489"
  },
  {
    "country": "US",
    "name": "Auburn",
    "lat": "41.36699",
    "lng": "-85.05886"
  },
  {
    "country": "US",
    "name": "Avilla",
    "lat": "41.36588",
    "lng": "-85.23886"
  },
  {
    "country": "US",
    "name": "Bass Lake",
    "lat": "41.20726",
    "lng": "-86.60196"
  },
  {
    "country": "US",
    "name": "Battle Ground",
    "lat": "40.50837",
    "lng": "-86.84168"
  },
  {
    "country": "US",
    "name": "Berne",
    "lat": "40.65782",
    "lng": "-84.95191"
  },
  {
    "country": "US",
    "name": "Bluffton",
    "lat": "40.73866",
    "lng": "-85.17164"
  },
  {
    "country": "US",
    "name": "Bourbon",
    "lat": "41.2956",
    "lng": "-86.11639"
  },
  {
    "country": "US",
    "name": "Bremen",
    "lat": "41.44644",
    "lng": "-86.14806"
  },
  {
    "country": "US",
    "name": "Bristol",
    "lat": "41.72144",
    "lng": "-85.81749"
  },
  {
    "country": "US",
    "name": "Brookston",
    "lat": "40.60281",
    "lng": "-86.86723"
  },
  {
    "country": "US",
    "name": "Burns Harbor",
    "lat": "41.62587",
    "lng": "-87.13337"
  },
  {
    "country": "US",
    "name": "Butler",
    "lat": "41.42977",
    "lng": "-84.87135"
  },
  {
    "country": "US",
    "name": "Cedar Lake",
    "lat": "41.36476",
    "lng": "-87.44115"
  },
  {
    "country": "US",
    "name": "Chesterfield",
    "lat": "40.11254",
    "lng": "-85.59692"
  },
  {
    "country": "US",
    "name": "Chesterton",
    "lat": "41.61059",
    "lng": "-87.0642"
  },
  {
    "country": "US",
    "name": "Churubusco",
    "lat": "41.2306",
    "lng": "-85.31942"
  },
  {
    "country": "US",
    "name": "Cicero",
    "lat": "40.12393",
    "lng": "-86.01332"
  },
  {
    "country": "US",
    "name": "Columbia City",
    "lat": "41.15727",
    "lng": "-85.48831"
  },
  {
    "country": "US",
    "name": "Converse",
    "lat": "40.57754",
    "lng": "-85.87332"
  },
  {
    "country": "US",
    "name": "Covington",
    "lat": "40.1417",
    "lng": "-87.39474"
  },
  {
    "country": "US",
    "name": "Crawfordsville",
    "lat": "40.04115",
    "lng": "-86.87445"
  },
  {
    "country": "US",
    "name": "Crown Point",
    "lat": "41.41698",
    "lng": "-87.36531"
  },
  {
    "country": "US",
    "name": "Culver",
    "lat": "41.21893",
    "lng": "-86.42306"
  },
  {
    "country": "US",
    "name": "Dale",
    "lat": "40.01671",
    "lng": "-86.4"
  },
  {
    "country": "US",
    "name": "Daleville",
    "lat": "40.12115",
    "lng": "-85.55803"
  },
  {
    "country": "US",
    "name": "Dayton",
    "lat": "40.3742",
    "lng": "-86.7689"
  },
  {
    "country": "US",
    "name": "DeMotte",
    "lat": "41.19504",
    "lng": "-87.19864"
  },
  {
    "country": "US",
    "name": "Decatur",
    "lat": "40.8306",
    "lng": "-84.92913"
  },
  {
    "country": "US",
    "name": "Delphi",
    "lat": "40.58754",
    "lng": "-86.67501"
  },
  {
    "country": "US",
    "name": "Dunkirk",
    "lat": "40.75643",
    "lng": "-86.39361"
  },
  {
    "country": "US",
    "name": "Dunkirk",
    "lat": "40.37532",
    "lng": "-85.20941"
  },
  {
    "country": "US",
    "name": "Dyer",
    "lat": "41.4942",
    "lng": "-87.52171"
  },
  {
    "country": "US",
    "name": "Dunlap",
    "lat": "41.63783",
    "lng": "-85.92166"
  },
  {
    "country": "US",
    "name": "East Chicago",
    "lat": "41.6392",
    "lng": "-87.45476"
  },
  {
    "country": "US",
    "name": "Eaton",
    "lat": "40.34032",
    "lng": "-85.3508"
  },
  {
    "country": "US",
    "name": "Edgewood",
    "lat": "40.10337",
    "lng": "-85.73414"
  },
  {
    "country": "US",
    "name": "Elkhart",
    "lat": "41.68199",
    "lng": "-85.97667"
  },
  {
    "country": "US",
    "name": "Elwood",
    "lat": "40.27698",
    "lng": "-85.84192"
  },
  {
    "country": "US",
    "name": "Fairmount",
    "lat": "40.41532",
    "lng": "-85.65053"
  },
  {
    "country": "US",
    "name": "Farmland",
    "lat": "40.18782",
    "lng": "-85.12747"
  },
  {
    "country": "US",
    "name": "Fish Lake",
    "lat": "41.56671",
    "lng": "-86.55196"
  },
  {
    "country": "US",
    "name": "Flora",
    "lat": "40.54726",
    "lng": "-86.52444"
  },
  {
    "country": "US",
    "name": "Fort Wayne",
    "lat": "41.1306",
    "lng": "-85.12886"
  },
  {
    "country": "US",
    "name": "Fowler",
    "lat": "40.6167",
    "lng": "-87.32085"
  },
  {
    "country": "US",
    "name": "Frankfort",
    "lat": "40.27948",
    "lng": "-86.51084"
  },
  {
    "country": "US",
    "name": "Fremont",
    "lat": "41.73088",
    "lng": "-84.93274"
  },
  {
    "country": "US",
    "name": "Frankton",
    "lat": "40.22282",
    "lng": "-85.77887"
  },
  {
    "country": "US",
    "name": "Galveston",
    "lat": "40.57893",
    "lng": "-86.19027"
  },
  {
    "country": "US",
    "name": "Garrett",
    "lat": "41.34949",
    "lng": "-85.13553"
  },
  {
    "country": "US",
    "name": "Gary",
    "lat": "41.59337",
    "lng": "-87.34643"
  },
  {
    "country": "US",
    "name": "Gas City",
    "lat": "40.48726",
    "lng": "-85.61303"
  },
  {
    "country": "US",
    "name": "Geneva",
    "lat": "40.59199",
    "lng": "-84.95719"
  },
  {
    "country": "US",
    "name": "Georgetown",
    "lat": "40.7406",
    "lng": "-86.50473"
  },
  {
    "country": "US",
    "name": "Georgetown",
    "lat": "41.72949",
    "lng": "-86.22834"
  },
  {
    "country": "US",
    "name": "Goodland",
    "lat": "40.76337",
    "lng": "-87.29363"
  },
  {
    "country": "US",
    "name": "Goshen",
    "lat": "41.58227",
    "lng": "-85.83444"
  },
  {
    "country": "US",
    "name": "Grabill",
    "lat": "41.21088",
    "lng": "-84.96691"
  },
  {
    "country": "US",
    "name": "Granger",
    "lat": "41.75338",
    "lng": "-86.11084"
  },
  {
    "country": "US",
    "name": "Greentown",
    "lat": "40.47809",
    "lng": "-85.96665"
  },
  {
    "country": "US",
    "name": "Griffith",
    "lat": "41.52837",
    "lng": "-87.42365"
  },
  {
    "country": "US",
    "name": "Gulivoire Park",
    "lat": "41.61338",
    "lng": "-86.24528"
  },
  {
    "country": "US",
    "name": "Hamilton",
    "lat": "41.53366",
    "lng": "-84.91274"
  },
  {
    "country": "US",
    "name": "Hammond",
    "lat": "41.58337",
    "lng": "-87.50004"
  },
  {
    "country": "US",
    "name": "Harlan",
    "lat": "41.19616",
    "lng": "-84.91969"
  },
  {
    "country": "US",
    "name": "Hartford City",
    "lat": "40.45115",
    "lng": "-85.36997"
  },
  {
    "country": "US",
    "name": "Hebron",
    "lat": "41.31865",
    "lng": "-87.20031"
  },
  {
    "country": "US",
    "name": "Highland",
    "lat": "41.55365",
    "lng": "-87.45198"
  },
  {
    "country": "US",
    "name": "Hobart",
    "lat": "41.53226",
    "lng": "-87.25504"
  },
  {
    "country": "US",
    "name": "Hudson Lake",
    "lat": "41.71032",
    "lng": "-86.53419"
  },
  {
    "country": "US",
    "name": "Huntertown",
    "lat": "41.22838",
    "lng": "-85.17247"
  },
  {
    "country": "US",
    "name": "Huntington",
    "lat": "40.8831",
    "lng": "-85.49748"
  },
  {
    "country": "US",
    "name": "Indian Heights",
    "lat": "40.42726",
    "lng": "-86.12555"
  },
  {
    "country": "US",
    "name": "Jonesboro",
    "lat": "40.47976",
    "lng": "-85.62775"
  },
  {
    "country": "US",
    "name": "Kendallville",
    "lat": "41.44144",
    "lng": "-85.26498"
  },
  {
    "country": "US",
    "name": "Kentland",
    "lat": "40.77032",
    "lng": "-87.4453"
  },
  {
    "country": "US",
    "name": "Kingsford Heights",
    "lat": "41.4806",
    "lng": "-86.69169"
  },
  {
    "country": "US",
    "name": "Kokomo",
    "lat": "40.48643",
    "lng": "-86.1336"
  },
  {
    "country": "US",
    "name": "Koontz Lake",
    "lat": "41.4181",
    "lng": "-86.48585"
  },
  {
    "country": "US",
    "name": "Kouts",
    "lat": "41.31671",
    "lng": "-87.02586"
  },
  {
    "country": "US",
    "name": "Knox",
    "lat": "41.29588",
    "lng": "-86.62501"
  },
  {
    "country": "US",
    "name": "LaPorte",
    "lat": "41.6106",
    "lng": "-86.72252"
  },
  {
    "country": "US",
    "name": "Lafayette",
    "lat": "40.4167",
    "lng": "-86.87529"
  },
  {
    "country": "US",
    "name": "Lagrange",
    "lat": "41.64172",
    "lng": "-85.41665"
  },
  {
    "country": "US",
    "name": "Lake Dalecarlia",
    "lat": "41.33087",
    "lng": "-87.39476"
  },
  {
    "country": "US",
    "name": "Lake Station",
    "lat": "41.57504",
    "lng": "-87.23892"
  },
  {
    "country": "US",
    "name": "Lakes of the Four Seasons",
    "lat": "41.41032",
    "lng": "-87.21309"
  },
  {
    "country": "US",
    "name": "Lapel",
    "lat": "40.06837",
    "lng": "-85.84831"
  },
  {
    "country": "US",
    "name": "Lebanon",
    "lat": "40.04837",
    "lng": "-86.46917"
  },
  {
    "country": "US",
    "name": "Leo-Cedarville",
    "lat": "41.21255",
    "lng": "-85.01664"
  },
  {
    "country": "US",
    "name": "Ligonier",
    "lat": "41.46588",
    "lng": "-85.58748"
  },
  {
    "country": "US",
    "name": "Logansport",
    "lat": "40.75448",
    "lng": "-86.35667"
  },
  {
    "country": "US",
    "name": "Long Beach",
    "lat": "41.73893",
    "lng": "-86.85697"
  },
  {
    "country": "US",
    "name": "Lowell",
    "lat": "41.29142",
    "lng": "-87.42059"
  },
  {
    "country": "US",
    "name": "Lynn",
    "lat": "40.04977",
    "lng": "-84.93969"
  },
  {
    "country": "US",
    "name": "Marion",
    "lat": "40.55837",
    "lng": "-85.65914"
  },
  {
    "country": "US",
    "name": "Markle",
    "lat": "40.82462",
    "lng": "-85.33884"
  },
  {
    "country": "US",
    "name": "Merrillville",
    "lat": "41.48281",
    "lng": "-87.33281"
  },
  {
    "country": "US",
    "name": "Michigan City",
    "lat": "41.70754",
    "lng": "-86.89503"
  },
  {
    "country": "US",
    "name": "Middlebury",
    "lat": "41.67533",
    "lng": "-85.7061"
  },
  {
    "country": "US",
    "name": "Middletown",
    "lat": "40.05727",
    "lng": "-85.5372"
  },
  {
    "country": "US",
    "name": "Milford",
    "lat": "41.40977",
    "lng": "-85.84555"
  },
  {
    "country": "US",
    "name": "Mishawaka",
    "lat": "41.66199",
    "lng": "-86.15862"
  },
  {
    "country": "US",
    "name": "Monon",
    "lat": "40.86782",
    "lng": "-86.8789"
  },
  {
    "country": "US",
    "name": "Monroeville",
    "lat": "40.97477",
    "lng": "-84.8683"
  },
  {
    "country": "US",
    "name": "Monticello",
    "lat": "40.74532",
    "lng": "-86.76473"
  },
  {
    "country": "US",
    "name": "Montpelier",
    "lat": "40.55393",
    "lng": "-85.27747"
  },
  {
    "country": "US",
    "name": "Morocco",
    "lat": "40.94615",
    "lng": "-87.45336"
  },
  {
    "country": "US",
    "name": "Mount Vernon",
    "lat": "40.66949",
    "lng": "-85.82415"
  },
  {
    "country": "US",
    "name": "Mulberry",
    "lat": "40.34448",
    "lng": "-86.66528"
  },
  {
    "country": "US",
    "name": "Muncie",
    "lat": "40.19338",
    "lng": "-85.38636"
  },
  {
    "country": "US",
    "name": "Munster",
    "lat": "41.56448",
    "lng": "-87.51254"
  },
  {
    "country": "US",
    "name": "Nappanee",
    "lat": "41.44283",
    "lng": "-86.00139"
  },
  {
    "country": "US",
    "name": "New Carlisle",
    "lat": "41.70032",
    "lng": "-86.50946"
  },
  {
    "country": "US",
    "name": "New Chicago",
    "lat": "41.55837",
    "lng": "-87.27448"
  },
  {
    "country": "US",
    "name": "New Haven",
    "lat": "41.0706",
    "lng": "-85.01441"
  },
  {
    "country": "US",
    "name": "New Paris",
    "lat": "41.50033",
    "lng": "-85.82805"
  },
  {
    "country": "US",
    "name": "Noblesville",
    "lat": "40.04559",
    "lng": "-86.0086"
  },
  {
    "country": "US",
    "name": "North Judson",
    "lat": "41.21504",
    "lng": "-86.77585"
  },
  {
    "country": "US",
    "name": "North Liberty",
    "lat": "41.53421",
    "lng": "-86.42723"
  },
  {
    "country": "US",
    "name": "North Manchester",
    "lat": "41.0006",
    "lng": "-85.7686"
  },
  {
    "country": "US",
    "name": "North Webster",
    "lat": "41.3256",
    "lng": "-85.69776"
  },
  {
    "country": "US",
    "name": "Ogden Dunes",
    "lat": "41.62281",
    "lng": "-87.1917"
  },
  {
    "country": "US",
    "name": "Osceola",
    "lat": "41.66505",
    "lng": "-86.07584"
  },
  {
    "country": "US",
    "name": "Ossian",
    "lat": "40.8806",
    "lng": "-85.16636"
  },
  {
    "country": "US",
    "name": "Otterbein",
    "lat": "40.49059",
    "lng": "-87.0964"
  },
  {
    "country": "US",
    "name": "Oxford",
    "lat": "40.51976",
    "lng": "-87.24779"
  },
  {
    "country": "US",
    "name": "Parker City",
    "lat": "40.18893",
    "lng": "-85.20413"
  },
  {
    "country": "US",
    "name": "Peru",
    "lat": "40.75365",
    "lng": "-86.06888"
  },
  {
    "country": "US",
    "name": "Pierceton",
    "lat": "41.20032",
    "lng": "-85.70554"
  },
  {
    "country": "US",
    "name": "Plymouth",
    "lat": "41.34366",
    "lng": "-86.30973"
  },
  {
    "country": "US",
    "name": "Portage",
    "lat": "41.57587",
    "lng": "-87.17615"
  },
  {
    "country": "US",
    "name": "Porter",
    "lat": "41.61559",
    "lng": "-87.0742"
  },
  {
    "country": "US",
    "name": "Portland",
    "lat": "40.43449",
    "lng": "-84.97775"
  },
  {
    "country": "US",
    "name": "Redkey",
    "lat": "40.34893",
    "lng": "-85.14997"
  },
  {
    "country": "US",
    "name": "Remington",
    "lat": "40.76087",
    "lng": "-87.15085"
  },
  {
    "country": "US",
    "name": "Rensselaer",
    "lat": "40.9367",
    "lng": "-87.15086"
  },
  {
    "country": "US",
    "name": "Roanoke",
    "lat": "40.96255",
    "lng": "-85.37331"
  },
  {
    "country": "US",
    "name": "Rochester",
    "lat": "41.06476",
    "lng": "-86.21583"
  },
  {
    "country": "US",
    "name": "Rome City",
    "lat": "41.49616",
    "lng": "-85.37665"
  },
  {
    "country": "US",
    "name": "Roselawn",
    "lat": "41.1417",
    "lng": "-87.31475"
  },
  {
    "country": "US",
    "name": "Rossville",
    "lat": "40.41698",
    "lng": "-86.59472"
  },
  {
    "country": "US",
    "name": "Russiaville",
    "lat": "40.41754",
    "lng": "-86.27138"
  },
  {
    "country": "US",
    "name": "Saint John",
    "lat": "41.45004",
    "lng": "-87.47004"
  },
  {
    "country": "US",
    "name": "Schererville",
    "lat": "41.47892",
    "lng": "-87.45476"
  },
  {
    "country": "US",
    "name": "Shadeland",
    "lat": "40.37365",
    "lng": "-86.9489"
  },
  {
    "country": "US",
    "name": "Sheridan",
    "lat": "40.13504",
    "lng": "-86.22055"
  },
  {
    "country": "US",
    "name": "Simonton Lake",
    "lat": "41.75422",
    "lng": "-85.975"
  },
  {
    "country": "US",
    "name": "South Bend",
    "lat": "41.68338",
    "lng": "-86.25001"
  },
  {
    "country": "US",
    "name": "South Haven",
    "lat": "41.54198",
    "lng": "-87.13726"
  },
  {
    "country": "US",
    "name": "South Whitley",
    "lat": "41.08477",
    "lng": "-85.62804"
  },
  {
    "country": "US",
    "name": "Sweetser",
    "lat": "40.57198",
    "lng": "-85.76915"
  },
  {
    "country": "US",
    "name": "Syracuse",
    "lat": "41.42783",
    "lng": "-85.75249"
  },
  {
    "country": "US",
    "name": "Thorntown",
    "lat": "40.12948",
    "lng": "-86.60667"
  },
  {
    "country": "US",
    "name": "Tipton",
    "lat": "40.28226",
    "lng": "-86.0411"
  },
  {
    "country": "US",
    "name": "Topeka",
    "lat": "41.53922",
    "lng": "-85.53971"
  },
  {
    "country": "US",
    "name": "Trail Creek",
    "lat": "41.69837",
    "lng": "-86.8592"
  },
  {
    "country": "US",
    "name": "Tri-Lakes",
    "lat": "41.24588",
    "lng": "-85.44192"
  },
  {
    "country": "US",
    "name": "Union City",
    "lat": "40.20199",
    "lng": "-84.80913"
  },
  {
    "country": "US",
    "name": "Upland",
    "lat": "40.4756",
    "lng": "-85.49442"
  },
  {
    "country": "US",
    "name": "Valparaiso",
    "lat": "41.47309",
    "lng": "-87.06114"
  },
  {
    "country": "US",
    "name": "Veedersburg",
    "lat": "40.11309",
    "lng": "-87.26251"
  },
  {
    "country": "US",
    "name": "Wabash",
    "lat": "40.79782",
    "lng": "-85.82054"
  },
  {
    "country": "US",
    "name": "Wakarusa",
    "lat": "41.53616",
    "lng": "-86.02083"
  },
  {
    "country": "US",
    "name": "Walkerton",
    "lat": "41.46671",
    "lng": "-86.48307"
  },
  {
    "country": "US",
    "name": "Walton",
    "lat": "40.66087",
    "lng": "-86.24194"
  },
  {
    "country": "US",
    "name": "Wanatah",
    "lat": "41.4306",
    "lng": "-86.89836"
  },
  {
    "country": "US",
    "name": "Warren",
    "lat": "40.68282",
    "lng": "-85.4272"
  },
  {
    "country": "US",
    "name": "Warsaw",
    "lat": "41.2381",
    "lng": "-85.85305"
  },
  {
    "country": "US",
    "name": "Waterloo",
    "lat": "41.43199",
    "lng": "-85.01997"
  },
  {
    "country": "US",
    "name": "West Lafayette",
    "lat": "40.42587",
    "lng": "-86.90807"
  },
  {
    "country": "US",
    "name": "Westfield",
    "lat": "40.04282",
    "lng": "-86.12749"
  },
  {
    "country": "US",
    "name": "Westville",
    "lat": "41.54143",
    "lng": "-86.90058"
  },
  {
    "country": "US",
    "name": "Whiting",
    "lat": "41.67976",
    "lng": "-87.49449"
  },
  {
    "country": "US",
    "name": "Williamsport",
    "lat": "40.28837",
    "lng": "-87.2939"
  },
  {
    "country": "US",
    "name": "Winamac",
    "lat": "41.05143",
    "lng": "-86.60306"
  },
  {
    "country": "US",
    "name": "Winchester",
    "lat": "40.17199",
    "lng": "-84.98135"
  },
  {
    "country": "US",
    "name": "Winona Lake",
    "lat": "41.22727",
    "lng": "-85.82193"
  },
  {
    "country": "US",
    "name": "Winfield",
    "lat": "41.40531",
    "lng": "-87.27531"
  },
  {
    "country": "US",
    "name": "Wolcottville",
    "lat": "41.52588",
    "lng": "-85.36665"
  },
  {
    "country": "US",
    "name": "Woodburn",
    "lat": "41.12533",
    "lng": "-84.8533"
  },
  {
    "country": "US",
    "name": "Yorktown",
    "lat": "40.17365",
    "lng": "-85.49414"
  },
  {
    "country": "US",
    "name": "Abington",
    "lat": "42.10482",
    "lng": "-70.94532"
  },
  {
    "country": "US",
    "name": "Acton",
    "lat": "42.48509",
    "lng": "-71.43284"
  },
  {
    "country": "US",
    "name": "Acushnet",
    "lat": "41.68066",
    "lng": "-70.90782"
  },
  {
    "country": "US",
    "name": "Adams",
    "lat": "42.62425",
    "lng": "-73.1176"
  },
  {
    "country": "US",
    "name": "Agawam",
    "lat": "42.06954",
    "lng": "-72.61481"
  },
  {
    "country": "US",
    "name": "Amesbury",
    "lat": "42.85842",
    "lng": "-70.93005"
  },
  {
    "country": "US",
    "name": "Amherst",
    "lat": "42.36723",
    "lng": "-72.51852"
  },
  {
    "country": "US",
    "name": "Amherst Center",
    "lat": "42.37537",
    "lng": "-72.51925"
  },
  {
    "country": "US",
    "name": "Andover",
    "lat": "42.65843",
    "lng": "-71.137"
  },
  {
    "country": "US",
    "name": "Arlington",
    "lat": "42.41537",
    "lng": "-71.15644"
  },
  {
    "country": "US",
    "name": "Ashburnham",
    "lat": "42.6362",
    "lng": "-71.90785"
  },
  {
    "country": "US",
    "name": "Ashby",
    "lat": "42.67787",
    "lng": "-71.82035"
  },
  {
    "country": "US",
    "name": "Ashfield",
    "lat": "42.52647",
    "lng": "-72.78843"
  },
  {
    "country": "US",
    "name": "Ashland",
    "lat": "42.26121",
    "lng": "-71.4634"
  },
  {
    "country": "US",
    "name": "Assonet",
    "lat": "41.79594",
    "lng": "-71.06782"
  },
  {
    "country": "US",
    "name": "Athol",
    "lat": "42.59592",
    "lng": "-72.22675"
  },
  {
    "country": "US",
    "name": "Attleboro",
    "lat": "41.94454",
    "lng": "-71.28561"
  },
  {
    "country": "US",
    "name": "Auburn",
    "lat": "42.19454",
    "lng": "-71.83563"
  },
  {
    "country": "US",
    "name": "Avon",
    "lat": "42.13066",
    "lng": "-71.04116"
  },
  {
    "country": "US",
    "name": "Ayer",
    "lat": "42.5612",
    "lng": "-71.58979"
  },
  {
    "country": "US",
    "name": "Baldwinville",
    "lat": "42.60842",
    "lng": "-72.07591"
  },
  {
    "country": "US",
    "name": "Barnstable",
    "lat": "41.70011",
    "lng": "-70.29947"
  },
  {
    "country": "US",
    "name": "Barre",
    "lat": "42.42287",
    "lng": "-72.10508"
  },
  {
    "country": "US",
    "name": "Becket",
    "lat": "42.33203",
    "lng": "-73.08288"
  },
  {
    "country": "US",
    "name": "Bedford",
    "lat": "42.49065",
    "lng": "-71.27617"
  },
  {
    "country": "US",
    "name": "Belchertown",
    "lat": "42.27704",
    "lng": "-72.40092"
  },
  {
    "country": "US",
    "name": "Bellingham",
    "lat": "42.08676",
    "lng": "-71.47451"
  },
  {
    "country": "US",
    "name": "Belmont",
    "lat": "42.39593",
    "lng": "-71.17867"
  },
  {
    "country": "US",
    "name": "Berkley",
    "lat": "41.84593",
    "lng": "-71.08282"
  },
  {
    "country": "US",
    "name": "Berlin",
    "lat": "42.3812",
    "lng": "-71.63701"
  },
  {
    "country": "US",
    "name": "Bernardston",
    "lat": "42.67092",
    "lng": "-72.54953"
  },
  {
    "country": "US",
    "name": "Beverly",
    "lat": "42.55843",
    "lng": "-70.88005"
  },
  {
    "country": "US",
    "name": "Beverly Cove",
    "lat": "42.55343",
    "lng": "-70.85366"
  },
  {
    "country": "US",
    "name": "Billerica",
    "lat": "42.55843",
    "lng": "-71.26895"
  },
  {
    "country": "US",
    "name": "Blackstone",
    "lat": "42.01788",
    "lng": "-71.54117"
  },
  {
    "country": "US",
    "name": "Bliss Corner",
    "lat": "41.61177",
    "lng": "-70.93837"
  },
  {
    "country": "US",
    "name": "Bolton",
    "lat": "42.43343",
    "lng": "-71.60784"
  },
  {
    "country": "US",
    "name": "Bondsville",
    "lat": "42.21259",
    "lng": "-72.34536"
  },
  {
    "country": "US",
    "name": "Boston",
    "lat": "42.35843",
    "lng": "-71.05977"
  },
  {
    "country": "US",
    "name": "Bourne",
    "lat": "41.74122",
    "lng": "-70.59892"
  },
  {
    "country": "US",
    "name": "Boxborough",
    "lat": "42.49084",
    "lng": "-71.52851"
  },
  {
    "country": "US",
    "name": "Boxford",
    "lat": "42.6612",
    "lng": "-70.99672"
  },
  {
    "country": "US",
    "name": "Boylston",
    "lat": "42.39176",
    "lng": "-71.70368"
  },
  {
    "country": "US",
    "name": "Braintree",
    "lat": "42.22232",
    "lng": "-70.99949"
  },
  {
    "country": "US",
    "name": "Brewster",
    "lat": "41.76011",
    "lng": "-70.0828"
  },
  {
    "country": "US",
    "name": "Bridgewater",
    "lat": "41.99038",
    "lng": "-70.97504"
  },
  {
    "country": "US",
    "name": "Brimfield",
    "lat": "42.12287",
    "lng": "-72.20091"
  },
  {
    "country": "US",
    "name": "Brockton",
    "lat": "42.08343",
    "lng": "-71.01838"
  },
  {
    "country": "US",
    "name": "Brookline",
    "lat": "42.33176",
    "lng": "-71.12116"
  },
  {
    "country": "US",
    "name": "Buckland",
    "lat": "42.59231",
    "lng": "-72.79176"
  },
  {
    "country": "US",
    "name": "Burlington",
    "lat": "42.50482",
    "lng": "-71.19561"
  },
  {
    "country": "US",
    "name": "Buzzards Bay",
    "lat": "41.74538",
    "lng": "-70.61809"
  },
  {
    "country": "US",
    "name": "Cambridge",
    "lat": "42.3751",
    "lng": "-71.10561"
  },
  {
    "country": "US",
    "name": "Canton",
    "lat": "42.15843",
    "lng": "-71.14477"
  },
  {
    "country": "US",
    "name": "Carlisle",
    "lat": "42.52926",
    "lng": "-71.3495"
  },
  {
    "country": "US",
    "name": "Carver",
    "lat": "41.88344",
    "lng": "-70.76254"
  },
  {
    "country": "US",
    "name": "Centerville",
    "lat": "41.64872",
    "lng": "-70.34808"
  },
  {
    "country": "US",
    "name": "Charlemont",
    "lat": "42.62786",
    "lng": "-72.86982"
  },
  {
    "country": "US",
    "name": "Charlton",
    "lat": "42.13565",
    "lng": "-71.97007"
  },
  {
    "country": "US",
    "name": "Chatham",
    "lat": "41.68206",
    "lng": "-69.95974"
  },
  {
    "country": "US",
    "name": "Chelmsford",
    "lat": "42.59981",
    "lng": "-71.36728"
  },
  {
    "country": "US",
    "name": "Chelsea",
    "lat": "42.39176",
    "lng": "-71.03283"
  },
  {
    "country": "US",
    "name": "Chesterfield",
    "lat": "42.39175",
    "lng": "-72.83982"
  },
  {
    "country": "US",
    "name": "Chicopee",
    "lat": "42.1487",
    "lng": "-72.60787"
  },
  {
    "country": "US",
    "name": "Clinton",
    "lat": "42.41676",
    "lng": "-71.68285"
  },
  {
    "country": "US",
    "name": "Cochituate",
    "lat": "42.32093",
    "lng": "-71.36423"
  },
  {
    "country": "US",
    "name": "Cohasset",
    "lat": "42.24177",
    "lng": "-70.80365"
  },
  {
    "country": "US",
    "name": "Colrain",
    "lat": "42.67314",
    "lng": "-72.69676"
  },
  {
    "country": "US",
    "name": "Concord",
    "lat": "42.46037",
    "lng": "-71.34895"
  },
  {
    "country": "US",
    "name": "Conway",
    "lat": "42.50981",
    "lng": "-72.69953"
  },
  {
    "country": "US",
    "name": "Cordaville",
    "lat": "42.26898",
    "lng": "-71.52395"
  },
  {
    "country": "US",
    "name": "Cotuit",
    "lat": "41.61678",
    "lng": "-70.43697"
  },
  {
    "country": "US",
    "name": "Dalton",
    "lat": "42.4737",
    "lng": "-73.16621"
  },
  {
    "country": "US",
    "name": "Danvers",
    "lat": "42.57509",
    "lng": "-70.93005"
  },
  {
    "country": "US",
    "name": "Dedham",
    "lat": "42.24177",
    "lng": "-71.16616"
  },
  {
    "country": "US",
    "name": "Dennis",
    "lat": "41.73539",
    "lng": "-70.19391"
  },
  {
    "country": "US",
    "name": "Dennis Port",
    "lat": "41.65845",
    "lng": "-70.12863"
  },
  {
    "country": "US",
    "name": "Dighton",
    "lat": "41.81399",
    "lng": "-71.12032"
  },
  {
    "country": "US",
    "name": "Douglas",
    "lat": "42.05426",
    "lng": "-71.73951"
  },
  {
    "country": "US",
    "name": "Dover",
    "lat": "42.24593",
    "lng": "-71.28283"
  },
  {
    "country": "US",
    "name": "Dracut",
    "lat": "42.67037",
    "lng": "-71.30201"
  },
  {
    "country": "US",
    "name": "Dudley",
    "lat": "42.0451",
    "lng": "-71.93007"
  },
  {
    "country": "US",
    "name": "Dunstable",
    "lat": "42.67509",
    "lng": "-71.48284"
  },
  {
    "country": "US",
    "name": "Duxbury",
    "lat": "42.04177",
    "lng": "-70.67226"
  },
  {
    "country": "US",
    "name": "East Bridgewater",
    "lat": "42.03343",
    "lng": "-70.95921"
  },
  {
    "country": "US",
    "name": "East Brookfield",
    "lat": "42.22787",
    "lng": "-72.04674"
  },
  {
    "country": "US",
    "name": "East Dennis",
    "lat": "41.74261",
    "lng": "-70.16196"
  },
  {
    "country": "US",
    "name": "East Douglas",
    "lat": "42.07232",
    "lng": "-71.7134"
  },
  {
    "country": "US",
    "name": "East Harwich",
    "lat": "41.70011",
    "lng": "-70.02724"
  },
  {
    "country": "US",
    "name": "East Longmeadow",
    "lat": "42.06454",
    "lng": "-72.51259"
  },
  {
    "country": "US",
    "name": "East Pepperell",
    "lat": "42.66537",
    "lng": "-71.57312"
  },
  {
    "country": "US",
    "name": "East Sandwich",
    "lat": "41.74177",
    "lng": "-70.45169"
  },
  {
    "country": "US",
    "name": "Eastham",
    "lat": "41.83011",
    "lng": "-69.97391"
  },
  {
    "country": "US",
    "name": "Easthampton",
    "lat": "42.26676",
    "lng": "-72.66898"
  },
  {
    "country": "US",
    "name": "Easton",
    "lat": "42.02454",
    "lng": "-71.12866"
  },
  {
    "country": "US",
    "name": "Edgartown",
    "lat": "41.38901",
    "lng": "-70.51336"
  },
  {
    "country": "US",
    "name": "Erving",
    "lat": "42.60009",
    "lng": "-72.39814"
  },
  {
    "country": "US",
    "name": "Essex",
    "lat": "42.63204",
    "lng": "-70.78283"
  },
  {
    "country": "US",
    "name": "Everett",
    "lat": "42.40843",
    "lng": "-71.05366"
  },
  {
    "country": "US",
    "name": "Fairhaven",
    "lat": "41.6376",
    "lng": "-70.90365"
  },
  {
    "country": "US",
    "name": "Fall River",
    "lat": "41.70149",
    "lng": "-71.15505"
  },
  {
    "country": "US",
    "name": "Falmouth",
    "lat": "41.5515",
    "lng": "-70.61475"
  },
  {
    "country": "US",
    "name": "Fiskdale",
    "lat": "42.11621",
    "lng": "-72.11341"
  },
  {
    "country": "US",
    "name": "Fitchburg",
    "lat": "42.58342",
    "lng": "-71.8023"
  },
  {
    "country": "US",
    "name": "Forestdale",
    "lat": "41.69177",
    "lng": "-70.49947"
  },
  {
    "country": "US",
    "name": "Foxborough",
    "lat": "42.06538",
    "lng": "-71.24783"
  },
  {
    "country": "US",
    "name": "Framingham",
    "lat": "42.27926",
    "lng": "-71.41617"
  },
  {
    "country": "US",
    "name": "Framingham Center",
    "lat": "42.29732",
    "lng": "-71.43701"
  },
  {
    "country": "US",
    "name": "Franklin",
    "lat": "42.08343",
    "lng": "-71.39673"
  },
  {
    "country": "US",
    "name": "Freetown",
    "lat": "41.76677",
    "lng": "-71.03282"
  },
  {
    "country": "US",
    "name": "Gardner",
    "lat": "42.57509",
    "lng": "-71.99813"
  },
  {
    "country": "US",
    "name": "Gill",
    "lat": "42.64036",
    "lng": "-72.49953"
  },
  {
    "country": "US",
    "name": "Gloucester",
    "lat": "42.61593",
    "lng": "-70.66199"
  },
  {
    "country": "US",
    "name": "Grafton",
    "lat": "42.20704",
    "lng": "-71.68562"
  },
  {
    "country": "US",
    "name": "Granby",
    "lat": "42.25648",
    "lng": "-72.5162"
  },
  {
    "country": "US",
    "name": "Granville",
    "lat": "42.06676",
    "lng": "-72.86149"
  },
  {
    "country": "US",
    "name": "Great Barrington",
    "lat": "42.19592",
    "lng": "-73.36206"
  },
  {
    "country": "US",
    "name": "Greenfield",
    "lat": "42.58759",
    "lng": "-72.59953"
  },
  {
    "country": "US",
    "name": "Groveland",
    "lat": "42.76037",
    "lng": "-71.03145"
  },
  {
    "country": "US",
    "name": "Hadley",
    "lat": "42.34176",
    "lng": "-72.58842"
  },
  {
    "country": "US",
    "name": "Halifax",
    "lat": "41.99121",
    "lng": "-70.86199"
  },
  {
    "country": "US",
    "name": "Hamilton",
    "lat": "42.2562",
    "lng": "-71.76757"
  },
  {
    "country": "US",
    "name": "Hampden",
    "lat": "42.06398",
    "lng": "-72.41342"
  },
  {
    "country": "US",
    "name": "Hanson",
    "lat": "42.0751",
    "lng": "-70.88004"
  },
  {
    "country": "US",
    "name": "Hanover",
    "lat": "42.11316",
    "lng": "-70.81199"
  },
  {
    "country": "US",
    "name": "Hardwick",
    "lat": "42.35009",
    "lng": "-72.19952"
  },
  {
    "country": "US",
    "name": "Harvard",
    "lat": "42.50009",
    "lng": "-71.58284"
  },
  {
    "country": "US",
    "name": "Harwich",
    "lat": "41.68622",
    "lng": "-70.07585"
  },
  {
    "country": "US",
    "name": "Harwich Port",
    "lat": "41.66678",
    "lng": "-70.07863"
  },
  {
    "country": "US",
    "name": "Hatfield",
    "lat": "42.37092",
    "lng": "-72.59814"
  },
  {
    "country": "US",
    "name": "Haverhill",
    "lat": "42.7762",
    "lng": "-71.07728"
  },
  {
    "country": "US",
    "name": "Head of Westport",
    "lat": "41.62094",
    "lng": "-71.06199"
  },
  {
    "country": "US",
    "name": "Hingham",
    "lat": "42.24177",
    "lng": "-70.88977"
  },
  {
    "country": "US",
    "name": "Hinsdale",
    "lat": "42.4387",
    "lng": "-73.12538"
  },
  {
    "country": "US",
    "name": "Holbrook",
    "lat": "42.1551",
    "lng": "-71.00866"
  },
  {
    "country": "US",
    "name": "Holden",
    "lat": "42.35176",
    "lng": "-71.86341"
  },
  {
    "country": "US",
    "name": "Holland",
    "lat": "42.06398",
    "lng": "-72.1573"
  },
  {
    "country": "US",
    "name": "Holliston",
    "lat": "42.2001",
    "lng": "-71.4245"
  },
  {
    "country": "US",
    "name": "Holyoke",
    "lat": "42.20426",
    "lng": "-72.6162"
  },
  {
    "country": "US",
    "name": "Hopedale",
    "lat": "42.13065",
    "lng": "-71.54117"
  },
  {
    "country": "US",
    "name": "Hopkinton",
    "lat": "42.22871",
    "lng": "-71.52256"
  },
  {
    "country": "US",
    "name": "Housatonic",
    "lat": "42.25425",
    "lng": "-73.36622"
  },
  {
    "country": "US",
    "name": "Hubbardston",
    "lat": "42.4737",
    "lng": "-72.00619"
  },
  {
    "country": "US",
    "name": "Hudson",
    "lat": "42.39176",
    "lng": "-71.56618"
  },
  {
    "country": "US",
    "name": "Hull",
    "lat": "42.30204",
    "lng": "-70.90782"
  },
  {
    "country": "US",
    "name": "Hyannis",
    "lat": "41.65289",
    "lng": "-70.2828"
  },
  {
    "country": "US",
    "name": "Ipswich",
    "lat": "42.67926",
    "lng": "-70.84116"
  },
  {
    "country": "US",
    "name": "Jamaica Plain",
    "lat": "42.30982",
    "lng": "-71.12033"
  },
  {
    "country": "US",
    "name": "Kingston",
    "lat": "41.99455",
    "lng": "-70.72448"
  },
  {
    "country": "US",
    "name": "Lancaster",
    "lat": "42.45565",
    "lng": "-71.67312"
  },
  {
    "country": "US",
    "name": "Lanesborough",
    "lat": "42.51731",
    "lng": "-73.22816"
  },
  {
    "country": "US",
    "name": "Lawrence",
    "lat": "42.70704",
    "lng": "-71.16311"
  },
  {
    "country": "US",
    "name": "Lee",
    "lat": "42.30425",
    "lng": "-73.24816"
  },
  {
    "country": "US",
    "name": "Leicester",
    "lat": "42.24593",
    "lng": "-71.90868"
  },
  {
    "country": "US",
    "name": "Lenox",
    "lat": "42.35648",
    "lng": "-73.28483"
  },
  {
    "country": "US",
    "name": "Leominster",
    "lat": "42.52509",
    "lng": "-71.75979"
  },
  {
    "country": "US",
    "name": "Leverett",
    "lat": "42.45203",
    "lng": "-72.50148"
  },
  {
    "country": "US",
    "name": "Lexington",
    "lat": "42.44732",
    "lng": "-71.2245"
  },
  {
    "country": "US",
    "name": "Lincoln",
    "lat": "42.42593",
    "lng": "-71.30395"
  },
  {
    "country": "US",
    "name": "Littleton Common",
    "lat": "42.54593",
    "lng": "-71.47451"
  },
  {
    "country": "US",
    "name": "Longmeadow",
    "lat": "42.0501",
    "lng": "-72.58287"
  },
  {
    "country": "US",
    "name": "Lowell",
    "lat": "42.63342",
    "lng": "-71.31617"
  },
  {
    "country": "US",
    "name": "Ludlow",
    "lat": "42.16009",
    "lng": "-72.47592"
  },
  {
    "country": "US",
    "name": "Lunenburg",
    "lat": "42.59453",
    "lng": "-71.72452"
  },
  {
    "country": "US",
    "name": "Lynn",
    "lat": "42.46676",
    "lng": "-70.94949"
  },
  {
    "country": "US",
    "name": "Lynnfield",
    "lat": "42.53898",
    "lng": "-71.04811"
  },
  {
    "country": "US",
    "name": "Malden",
    "lat": "42.4251",
    "lng": "-71.06616"
  },
  {
    "country": "US",
    "name": "Manchester-by-the-Sea",
    "lat": "42.57787",
    "lng": "-70.76894"
  },
  {
    "country": "US",
    "name": "Mansfield",
    "lat": "42.03343",
    "lng": "-71.21894"
  },
  {
    "country": "US",
    "name": "Marblehead",
    "lat": "42.5001",
    "lng": "-70.85783"
  },
  {
    "country": "US",
    "name": "Marion",
    "lat": "41.7001",
    "lng": "-70.76281"
  },
  {
    "country": "US",
    "name": "Marlborough",
    "lat": "42.34593",
    "lng": "-71.55229"
  },
  {
    "country": "US",
    "name": "Marshfield",
    "lat": "42.09177",
    "lng": "-70.70559"
  },
  {
    "country": "US",
    "name": "Marshfield Hills",
    "lat": "42.14594",
    "lng": "-70.73976"
  },
  {
    "country": "US",
    "name": "Marstons Mills",
    "lat": "41.65622",
    "lng": "-70.41614"
  },
  {
    "country": "US",
    "name": "Mashpee",
    "lat": "41.64844",
    "lng": "-70.48114"
  },
  {
    "country": "US",
    "name": "Mattapoisett",
    "lat": "41.65844",
    "lng": "-70.81615"
  },
  {
    "country": "US",
    "name": "Maynard",
    "lat": "42.43343",
    "lng": "-71.44951"
  },
  {
    "country": "US",
    "name": "Medfield",
    "lat": "42.1876",
    "lng": "-71.30645"
  },
  {
    "country": "US",
    "name": "Medford",
    "lat": "42.41843",
    "lng": "-71.10616"
  },
  {
    "country": "US",
    "name": "Medway",
    "lat": "42.14176",
    "lng": "-71.39673"
  },
  {
    "country": "US",
    "name": "Melrose",
    "lat": "42.45843",
    "lng": "-71.06616"
  },
  {
    "country": "US",
    "name": "Mendon",
    "lat": "42.10565",
    "lng": "-71.55229"
  },
  {
    "country": "US",
    "name": "Merrimac",
    "lat": "42.83065",
    "lng": "-71.00228"
  },
  {
    "country": "US",
    "name": "Methuen",
    "lat": "42.7262",
    "lng": "-71.19089"
  },
  {
    "country": "US",
    "name": "Middleborough",
    "lat": "41.89316",
    "lng": "-70.91115"
  },
  {
    "country": "US",
    "name": "Middleton",
    "lat": "42.59509",
    "lng": "-71.01616"
  },
  {
    "country": "US",
    "name": "Milford",
    "lat": "42.13982",
    "lng": "-71.51617"
  },
  {
    "country": "US",
    "name": "Millbury",
    "lat": "42.19398",
    "lng": "-71.76007"
  },
  {
    "country": "US",
    "name": "Millers Falls",
    "lat": "42.58203",
    "lng": "-72.49259"
  },
  {
    "country": "US",
    "name": "Millis",
    "lat": "42.1676",
    "lng": "-71.35784"
  },
  {
    "country": "US",
    "name": "Millville",
    "lat": "42.02788",
    "lng": "-71.5809"
  },
  {
    "country": "US",
    "name": "Milton",
    "lat": "42.24954",
    "lng": "-71.06616"
  },
  {
    "country": "US",
    "name": "Monson",
    "lat": "42.10426",
    "lng": "-72.31897"
  },
  {
    "country": "US",
    "name": "Monument Beach",
    "lat": "41.71955",
    "lng": "-70.61198"
  },
  {
    "country": "US",
    "name": "Montague",
    "lat": "42.53564",
    "lng": "-72.53509"
  },
  {
    "country": "US",
    "name": "Nahant",
    "lat": "42.42649",
    "lng": "-70.91894"
  },
  {
    "country": "US",
    "name": "Nantucket",
    "lat": "41.28346",
    "lng": "-70.09946"
  },
  {
    "country": "US",
    "name": "Natick",
    "lat": "42.28343",
    "lng": "-71.3495"
  },
  {
    "country": "US",
    "name": "Needham",
    "lat": "42.28343",
    "lng": "-71.23283"
  },
  {
    "country": "US",
    "name": "New Bedford",
    "lat": "41.63622",
    "lng": "-70.93421"
  },
  {
    "country": "US",
    "name": "New Marlborough",
    "lat": "42.12287",
    "lng": "-73.22872"
  },
  {
    "country": "US",
    "name": "Newburyport",
    "lat": "42.81259",
    "lng": "-70.87728"
  },
  {
    "country": "US",
    "name": "Newton",
    "lat": "42.33704",
    "lng": "-71.20922"
  },
  {
    "country": "US",
    "name": "Norfolk",
    "lat": "42.11954",
    "lng": "-71.32506"
  },
  {
    "country": "US",
    "name": "North Adams",
    "lat": "42.70092",
    "lng": "-73.10871"
  },
  {
    "country": "US",
    "name": "North Amherst",
    "lat": "42.41037",
    "lng": "-72.53092"
  },
  {
    "country": "US",
    "name": "North Brookfield",
    "lat": "42.26676",
    "lng": "-72.08285"
  },
  {
    "country": "US",
    "name": "North Chicopee",
    "lat": "42.18343",
    "lng": "-72.59953"
  },
  {
    "country": "US",
    "name": "North Eastham",
    "lat": "41.86511",
    "lng": "-69.99113"
  },
  {
    "country": "US",
    "name": "North Falmouth",
    "lat": "41.64594",
    "lng": "-70.61836"
  },
  {
    "country": "US",
    "name": "North Lakeville",
    "lat": "41.8576",
    "lng": "-70.94226"
  },
  {
    "country": "US",
    "name": "North Pembroke",
    "lat": "42.09316",
    "lng": "-70.79254"
  },
  {
    "country": "US",
    "name": "North Plymouth",
    "lat": "41.97094",
    "lng": "-70.68281"
  },
  {
    "country": "US",
    "name": "North Reading",
    "lat": "42.57509",
    "lng": "-71.07867"
  },
  {
    "country": "US",
    "name": "North Scituate",
    "lat": "42.21899",
    "lng": "-70.7856"
  },
  {
    "country": "US",
    "name": "North Seekonk",
    "lat": "41.88927",
    "lng": "-71.33005"
  },
  {
    "country": "US",
    "name": "North Westport",
    "lat": "41.66038",
    "lng": "-71.08838"
  },
  {
    "country": "US",
    "name": "Northampton",
    "lat": "42.32509",
    "lng": "-72.6412"
  },
  {
    "country": "US",
    "name": "Northborough",
    "lat": "42.31954",
    "lng": "-71.64118"
  },
  {
    "country": "US",
    "name": "Northbridge",
    "lat": "42.15148",
    "lng": "-71.64951"
  },
  {
    "country": "US",
    "name": "Northfield",
    "lat": "42.69592",
    "lng": "-72.45287"
  },
  {
    "country": "US",
    "name": "Norton",
    "lat": "41.96677",
    "lng": "-71.18699"
  },
  {
    "country": "US",
    "name": "Norwell",
    "lat": "42.16177",
    "lng": "-70.79393"
  },
  {
    "country": "US",
    "name": "Norwood",
    "lat": "42.19454",
    "lng": "-71.1995"
  },
  {
    "country": "US",
    "name": "Oak Bluffs",
    "lat": "41.45428",
    "lng": "-70.56197"
  },
  {
    "country": "US",
    "name": "Oakham",
    "lat": "42.35287",
    "lng": "-72.04535"
  },
  {
    "country": "US",
    "name": "Ocean Grove",
    "lat": "41.72927",
    "lng": "-71.20921"
  },
  {
    "country": "US",
    "name": "Onset",
    "lat": "41.74177",
    "lng": "-70.65781"
  },
  {
    "country": "US",
    "name": "Orange",
    "lat": "42.59036",
    "lng": "-72.30981"
  },
  {
    "country": "US",
    "name": "Orleans",
    "lat": "41.78983",
    "lng": "-69.98974"
  },
  {
    "country": "US",
    "name": "Osterville",
    "lat": "41.62844",
    "lng": "-70.38697"
  },
  {
    "country": "US",
    "name": "Otis",
    "lat": "42.19315",
    "lng": "-73.09177"
  },
  {
    "country": "US",
    "name": "Oxford",
    "lat": "42.11676",
    "lng": "-71.86479"
  },
  {
    "country": "US",
    "name": "Palmer",
    "lat": "42.15843",
    "lng": "-72.32869"
  },
  {
    "country": "US",
    "name": "Paxton",
    "lat": "42.3112",
    "lng": "-71.92813"
  },
  {
    "country": "US",
    "name": "Peabody",
    "lat": "42.52787",
    "lng": "-70.92866"
  },
  {
    "country": "US",
    "name": "Pelham",
    "lat": "42.39315",
    "lng": "-72.4037"
  },
  {
    "country": "US",
    "name": "Pepperell",
    "lat": "42.66592",
    "lng": "-71.5884"
  },
  {
    "country": "US",
    "name": "Phillipston",
    "lat": "42.5487",
    "lng": "-72.13286"
  },
  {
    "country": "US",
    "name": "Pinehurst",
    "lat": "42.52926",
    "lng": "-71.22811"
  },
  {
    "country": "US",
    "name": "Pittsfield",
    "lat": "42.45008",
    "lng": "-73.24538"
  },
  {
    "country": "US",
    "name": "Plainville",
    "lat": "42.00427",
    "lng": "-71.33283"
  },
  {
    "country": "US",
    "name": "Plymouth",
    "lat": "41.95844",
    "lng": "-70.66726"
  },
  {
    "country": "US",
    "name": "Plympton",
    "lat": "41.95288",
    "lng": "-70.81448"
  },
  {
    "country": "US",
    "name": "Pocasset",
    "lat": "41.68622",
    "lng": "-70.61614"
  },
  {
    "country": "US",
    "name": "Princeton",
    "lat": "42.4487",
    "lng": "-71.8773"
  },
  {
    "country": "US",
    "name": "Provincetown",
    "lat": "42.05295",
    "lng": "-70.1864"
  },
  {
    "country": "US",
    "name": "Quincy",
    "lat": "42.25288",
    "lng": "-71.00227"
  },
  {
    "country": "US",
    "name": "Randolph",
    "lat": "42.1626",
    "lng": "-71.04116"
  },
  {
    "country": "US",
    "name": "Raynham",
    "lat": "41.94871",
    "lng": "-71.0731"
  },
  {
    "country": "US",
    "name": "Raynham Center",
    "lat": "41.92371",
    "lng": "-71.05227"
  },
  {
    "country": "US",
    "name": "Reading",
    "lat": "42.52565",
    "lng": "-71.09533"
  },
  {
    "country": "US",
    "name": "Rehoboth",
    "lat": "41.84038",
    "lng": "-71.24949"
  },
  {
    "country": "US",
    "name": "Richmond",
    "lat": "42.37314",
    "lng": "-73.36761"
  },
  {
    "country": "US",
    "name": "Rochester",
    "lat": "41.73177",
    "lng": "-70.82004"
  },
  {
    "country": "US",
    "name": "Rockland",
    "lat": "42.13066",
    "lng": "-70.91616"
  },
  {
    "country": "US",
    "name": "Rockport",
    "lat": "42.65565",
    "lng": "-70.62032"
  },
  {
    "country": "US",
    "name": "Rowley",
    "lat": "42.71676",
    "lng": "-70.87866"
  },
  {
    "country": "US",
    "name": "Royalston",
    "lat": "42.67759",
    "lng": "-72.18786"
  },
  {
    "country": "US",
    "name": "Rutland",
    "lat": "42.36954",
    "lng": "-71.94813"
  },
  {
    "country": "US",
    "name": "Sagamore",
    "lat": "41.77011",
    "lng": "-70.52836"
  },
  {
    "country": "US",
    "name": "Salem",
    "lat": "42.51954",
    "lng": "-70.89672"
  },
  {
    "country": "US",
    "name": "Salisbury",
    "lat": "42.84176",
    "lng": "-70.86061"
  },
  {
    "country": "US",
    "name": "Sandwich",
    "lat": "41.759",
    "lng": "-70.49392"
  },
  {
    "country": "US",
    "name": "Saugus",
    "lat": "42.46482",
    "lng": "-71.01005"
  },
  {
    "country": "US",
    "name": "Scituate",
    "lat": "42.19593",
    "lng": "-70.72587"
  },
  {
    "country": "US",
    "name": "Seekonk",
    "lat": "41.80843",
    "lng": "-71.337"
  },
  {
    "country": "US",
    "name": "Sharon",
    "lat": "42.12371",
    "lng": "-71.17866"
  },
  {
    "country": "US",
    "name": "Shelburne",
    "lat": "42.58981",
    "lng": "-72.68842"
  },
  {
    "country": "US",
    "name": "Shelburne Falls",
    "lat": "42.60425",
    "lng": "-72.73926"
  },
  {
    "country": "US",
    "name": "Sherborn",
    "lat": "42.23899",
    "lng": "-71.36978"
  },
  {
    "country": "US",
    "name": "Shirley",
    "lat": "42.5437",
    "lng": "-71.64951"
  },
  {
    "country": "US",
    "name": "Shrewsbury",
    "lat": "42.29593",
    "lng": "-71.71285"
  },
  {
    "country": "US",
    "name": "Shutesbury",
    "lat": "42.45648",
    "lng": "-72.40981"
  },
  {
    "country": "US",
    "name": "Smith Mills",
    "lat": "41.63899",
    "lng": "-70.99115"
  },
  {
    "country": "US",
    "name": "Somerset",
    "lat": "41.76955",
    "lng": "-71.12866"
  },
  {
    "country": "US",
    "name": "Somerville",
    "lat": "42.3876",
    "lng": "-71.0995"
  },
  {
    "country": "US",
    "name": "South Amherst",
    "lat": "42.34037",
    "lng": "-72.50509"
  },
  {
    "country": "US",
    "name": "South Ashburnham",
    "lat": "42.61037",
    "lng": "-71.93897"
  },
  {
    "country": "US",
    "name": "South Boston",
    "lat": "42.33343",
    "lng": "-71.04949"
  },
  {
    "country": "US",
    "name": "South Deerfield",
    "lat": "42.47731",
    "lng": "-72.60787"
  },
  {
    "country": "US",
    "name": "South Dennis",
    "lat": "41.68956",
    "lng": "-70.15641"
  },
  {
    "country": "US",
    "name": "South Hadley",
    "lat": "42.25842",
    "lng": "-72.57453"
  },
  {
    "country": "US",
    "name": "South Lancaster",
    "lat": "42.44454",
    "lng": "-71.68701"
  },
  {
    "country": "US",
    "name": "South Peabody",
    "lat": "42.50982",
    "lng": "-70.94949"
  },
  {
    "country": "US",
    "name": "South Yarmouth",
    "lat": "41.66678",
    "lng": "-70.18474"
  },
  {
    "country": "US",
    "name": "Southampton",
    "lat": "42.22926",
    "lng": "-72.73009"
  },
  {
    "country": "US",
    "name": "Southborough",
    "lat": "42.30565",
    "lng": "-71.52451"
  },
  {
    "country": "US",
    "name": "Southbridge",
    "lat": "42.0751",
    "lng": "-72.03341"
  },
  {
    "country": "US",
    "name": "Southwick",
    "lat": "42.05482",
    "lng": "-72.77037"
  },
  {
    "country": "US",
    "name": "Spencer",
    "lat": "42.24398",
    "lng": "-71.9923"
  },
  {
    "country": "US",
    "name": "Springfield",
    "lat": "42.10148",
    "lng": "-72.58981"
  },
  {
    "country": "US",
    "name": "Sterling",
    "lat": "42.43759",
    "lng": "-71.76063"
  },
  {
    "country": "US",
    "name": "Stockbridge",
    "lat": "42.28759",
    "lng": "-73.32039"
  },
  {
    "country": "US",
    "name": "Stoneham",
    "lat": "42.4801",
    "lng": "-71.0995"
  },
  {
    "country": "US",
    "name": "Stoughton",
    "lat": "42.1251",
    "lng": "-71.10227"
  },
  {
    "country": "US",
    "name": "Stow",
    "lat": "42.43704",
    "lng": "-71.50562"
  },
  {
    "country": "US",
    "name": "Sturbridge",
    "lat": "42.10843",
    "lng": "-72.07869"
  },
  {
    "country": "US",
    "name": "Sudbury",
    "lat": "42.38343",
    "lng": "-71.41617"
  },
  {
    "country": "US",
    "name": "Sunderland",
    "lat": "42.24454",
    "lng": "-71.77174"
  },
  {
    "country": "US",
    "name": "Sutton",
    "lat": "42.1501",
    "lng": "-71.76285"
  },
  {
    "country": "US",
    "name": "Swampscott",
    "lat": "42.47093",
    "lng": "-70.91755"
  },
  {
    "country": "US",
    "name": "Swansea",
    "lat": "41.74816",
    "lng": "-71.18977"
  },
  {
    "country": "US",
    "name": "Taunton",
    "lat": "41.9001",
    "lng": "-71.08977"
  },
  {
    "country": "US",
    "name": "Teaticket",
    "lat": "41.56455",
    "lng": "-70.59586"
  },
  {
    "country": "US",
    "name": "Templeton",
    "lat": "42.55564",
    "lng": "-72.06758"
  },
  {
    "country": "US",
    "name": "Tewksbury",
    "lat": "42.61065",
    "lng": "-71.23422"
  },
  {
    "country": "US",
    "name": "Topsfield",
    "lat": "42.63759",
    "lng": "-70.9495"
  },
  {
    "country": "US",
    "name": "Townsend",
    "lat": "42.66676",
    "lng": "-71.70507"
  },
  {
    "country": "US",
    "name": "Truro",
    "lat": "41.99344",
    "lng": "-70.04975"
  },
  {
    "country": "US",
    "name": "Turners Falls",
    "lat": "42.60425",
    "lng": "-72.55648"
  },
  {
    "country": "US",
    "name": "Tyngsboro",
    "lat": "42.67676",
    "lng": "-71.42451"
  },
  {
    "country": "US",
    "name": "Upton",
    "lat": "42.17454",
    "lng": "-71.60229"
  },
  {
    "country": "US",
    "name": "Uxbridge",
    "lat": "42.07732",
    "lng": "-71.62951"
  },
  {
    "country": "US",
    "name": "Vineyard Haven",
    "lat": "41.45428",
    "lng": "-70.60364"
  },
  {
    "country": "US",
    "name": "Wakefield",
    "lat": "42.50648",
    "lng": "-71.07283"
  },
  {
    "country": "US",
    "name": "Wales",
    "lat": "42.06954",
    "lng": "-72.2223"
  },
  {
    "country": "US",
    "name": "Walpole",
    "lat": "42.14177",
    "lng": "-71.2495"
  },
  {
    "country": "US",
    "name": "Waltham",
    "lat": "42.37649",
    "lng": "-71.23561"
  },
  {
    "country": "US",
    "name": "Ware",
    "lat": "42.25981",
    "lng": "-72.2398"
  },
  {
    "country": "US",
    "name": "Wareham Center",
    "lat": "41.76677",
    "lng": "-70.72615"
  },
  {
    "country": "US",
    "name": "Warren",
    "lat": "42.21259",
    "lng": "-72.19119"
  },
  {
    "country": "US",
    "name": "Watertown",
    "lat": "42.37093",
    "lng": "-71.18283"
  },
  {
    "country": "US",
    "name": "Wayland",
    "lat": "42.3626",
    "lng": "-71.36145"
  },
  {
    "country": "US",
    "name": "Webster",
    "lat": "42.0501",
    "lng": "-71.88007"
  },
  {
    "country": "US",
    "name": "Wellesley",
    "lat": "42.29649",
    "lng": "-71.29256"
  },
  {
    "country": "US",
    "name": "Wellfleet",
    "lat": "41.93761",
    "lng": "-70.0328"
  },
  {
    "country": "US",
    "name": "Wendell",
    "lat": "42.54814",
    "lng": "-72.39675"
  },
  {
    "country": "US",
    "name": "Wenham",
    "lat": "42.60426",
    "lng": "-70.89116"
  },
  {
    "country": "US",
    "name": "West Boylston",
    "lat": "42.36676",
    "lng": "-71.78563"
  },
  {
    "country": "US",
    "name": "West Bridgewater",
    "lat": "42.01899",
    "lng": "-71.00782"
  },
  {
    "country": "US",
    "name": "West Chatham",
    "lat": "41.68122",
    "lng": "-69.99113"
  },
  {
    "country": "US",
    "name": "West Concord",
    "lat": "42.45843",
    "lng": "-71.39534"
  },
  {
    "country": "US",
    "name": "West Brookfield",
    "lat": "42.23537",
    "lng": "-72.14119"
  },
  {
    "country": "US",
    "name": "West Dennis",
    "lat": "41.66456",
    "lng": "-70.1728"
  },
  {
    "country": "US",
    "name": "West Falmouth",
    "lat": "41.60427",
    "lng": "-70.63447"
  },
  {
    "country": "US",
    "name": "West Newbury",
    "lat": "42.80148",
    "lng": "-70.98978"
  },
  {
    "country": "US",
    "name": "West Springfield",
    "lat": "42.10704",
    "lng": "-72.62037"
  },
  {
    "country": "US",
    "name": "West Stockbridge",
    "lat": "42.34592",
    "lng": "-73.36622"
  },
  {
    "country": "US",
    "name": "West Tisbury",
    "lat": "41.38122",
    "lng": "-70.67447"
  },
  {
    "country": "US",
    "name": "West Wareham",
    "lat": "41.78983",
    "lng": "-70.76031"
  },
  {
    "country": "US",
    "name": "West Yarmouth",
    "lat": "41.65011",
    "lng": "-70.24113"
  },
  {
    "country": "US",
    "name": "Westborough",
    "lat": "42.26954",
    "lng": "-71.61618"
  },
  {
    "country": "US",
    "name": "Westfield",
    "lat": "42.12509",
    "lng": "-72.74954"
  },
  {
    "country": "US",
    "name": "Westford",
    "lat": "42.57926",
    "lng": "-71.43784"
  },
  {
    "country": "US",
    "name": "Westhampton",
    "lat": "42.30287",
    "lng": "-72.77454"
  },
  {
    "country": "US",
    "name": "Westminster",
    "lat": "42.54592",
    "lng": "-71.91063"
  },
  {
    "country": "US",
    "name": "Weston",
    "lat": "42.36676",
    "lng": "-71.30311"
  },
  {
    "country": "US",
    "name": "Westwood",
    "lat": "42.21399",
    "lng": "-71.2245"
  },
  {
    "country": "US",
    "name": "Weweantic",
    "lat": "41.73538",
    "lng": "-70.73198"
  },
  {
    "country": "US",
    "name": "Weymouth",
    "lat": "42.22093",
    "lng": "-70.93977"
  },
  {
    "country": "US",
    "name": "Whately",
    "lat": "42.43981",
    "lng": "-72.63481"
  },
  {
    "country": "US",
    "name": "White Island Shores",
    "lat": "41.8001",
    "lng": "-70.63475"
  },
  {
    "country": "US",
    "name": "Whitinsville",
    "lat": "42.11121",
    "lng": "-71.66618"
  },
  {
    "country": "US",
    "name": "Whitman",
    "lat": "42.08066",
    "lng": "-70.9356"
  },
  {
    "country": "US",
    "name": "Wilbraham",
    "lat": "42.12371",
    "lng": "-72.43147"
  },
  {
    "country": "US",
    "name": "Williamsburg",
    "lat": "42.39314",
    "lng": "-72.73009"
  },
  {
    "country": "US",
    "name": "Williamstown",
    "lat": "42.71202",
    "lng": "-73.20372"
  },
  {
    "country": "US",
    "name": "Wilmington",
    "lat": "42.54648",
    "lng": "-71.17367"
  },
  {
    "country": "US",
    "name": "Winchendon",
    "lat": "42.6862",
    "lng": "-72.04397"
  },
  {
    "country": "US",
    "name": "Winchester",
    "lat": "42.45232",
    "lng": "-71.137"
  },
  {
    "country": "US",
    "name": "Winthrop",
    "lat": "42.3751",
    "lng": "-70.98283"
  },
  {
    "country": "US",
    "name": "Woburn",
    "lat": "42.47926",
    "lng": "-71.15228"
  },
  {
    "country": "US",
    "name": "Worcester",
    "lat": "42.26259",
    "lng": "-71.80229"
  },
  {
    "country": "US",
    "name": "Wrentham",
    "lat": "42.06677",
    "lng": "-71.32811"
  },
  {
    "country": "US",
    "name": "Yarmouth",
    "lat": "41.70567",
    "lng": "-70.22863"
  },
  {
    "country": "US",
    "name": "Yarmouth Port",
    "lat": "41.70205",
    "lng": "-70.24947"
  },
  {
    "country": "US",
    "name": "Acton",
    "lat": "43.53425",
    "lng": "-70.90978"
  },
  {
    "country": "US",
    "name": "Addison",
    "lat": "44.61841",
    "lng": "-67.74416"
  },
  {
    "country": "US",
    "name": "Albion",
    "lat": "44.53229",
    "lng": "-69.44254"
  },
  {
    "country": "US",
    "name": "Appleton",
    "lat": "44.28924",
    "lng": "-69.25088"
  },
  {
    "country": "US",
    "name": "Arundel",
    "lat": "43.38259",
    "lng": "-70.47783"
  },
  {
    "country": "US",
    "name": "Auburn",
    "lat": "44.09785",
    "lng": "-70.23117"
  },
  {
    "country": "US",
    "name": "Augusta",
    "lat": "44.31062",
    "lng": "-69.77949"
  },
  {
    "country": "US",
    "name": "Bangor",
    "lat": "44.80118",
    "lng": "-68.77781"
  },
  {
    "country": "US",
    "name": "Bar Harbor",
    "lat": "44.38758",
    "lng": "-68.2039"
  },
  {
    "country": "US",
    "name": "Bath",
    "lat": "43.91064",
    "lng": "-69.8206"
  },
  {
    "country": "US",
    "name": "Belfast",
    "lat": "44.42591",
    "lng": "-69.00642"
  },
  {
    "country": "US",
    "name": "Belgrade",
    "lat": "44.44729",
    "lng": "-69.83255"
  },
  {
    "country": "US",
    "name": "Benton",
    "lat": "44.58618",
    "lng": "-69.55088"
  },
  {
    "country": "US",
    "name": "Bethel",
    "lat": "44.40423",
    "lng": "-70.79062"
  },
  {
    "country": "US",
    "name": "Biddeford",
    "lat": "43.49258",
    "lng": "-70.45338"
  },
  {
    "country": "US",
    "name": "Boothbay",
    "lat": "43.87647",
    "lng": "-69.63366"
  },
  {
    "country": "US",
    "name": "Boothbay Harbor",
    "lat": "43.8523",
    "lng": "-69.6281"
  },
  {
    "country": "US",
    "name": "Bradford",
    "lat": "45.06673",
    "lng": "-68.93781"
  },
  {
    "country": "US",
    "name": "Bradley",
    "lat": "44.9209",
    "lng": "-68.62809"
  },
  {
    "country": "US",
    "name": "Brewer",
    "lat": "44.79674",
    "lng": "-68.76142"
  },
  {
    "country": "US",
    "name": "Bridgton",
    "lat": "44.05479",
    "lng": "-70.71284"
  },
  {
    "country": "US",
    "name": "Bristol",
    "lat": "43.95758",
    "lng": "-69.50921"
  },
  {
    "country": "US",
    "name": "Brooks",
    "lat": "44.55035",
    "lng": "-69.12087"
  },
  {
    "country": "US",
    "name": "Brownfield",
    "lat": "43.93813",
    "lng": "-70.90868"
  },
  {
    "country": "US",
    "name": "Brownville",
    "lat": "45.307",
    "lng": "-69.03337"
  },
  {
    "country": "US",
    "name": "Brunswick",
    "lat": "43.91452",
    "lng": "-69.96533"
  },
  {
    "country": "US",
    "name": "Buckfield",
    "lat": "44.28951",
    "lng": "-70.36534"
  },
  {
    "country": "US",
    "name": "Bucksport",
    "lat": "44.57369",
    "lng": "-68.79559"
  },
  {
    "country": "US",
    "name": "Burnham",
    "lat": "44.69284",
    "lng": "-69.42755"
  },
  {
    "country": "US",
    "name": "Buxton",
    "lat": "43.63786",
    "lng": "-70.51894"
  },
  {
    "country": "US",
    "name": "Calais",
    "lat": "45.18896",
    "lng": "-67.2786"
  },
  {
    "country": "US",
    "name": "Camden",
    "lat": "44.2098",
    "lng": "-69.06476"
  },
  {
    "country": "US",
    "name": "Canaan",
    "lat": "44.76173",
    "lng": "-69.56144"
  },
  {
    "country": "US",
    "name": "Canton",
    "lat": "44.4408",
    "lng": "-70.31649"
  },
  {
    "country": "US",
    "name": "Cape Neddick",
    "lat": "43.1937",
    "lng": "-70.62089"
  },
  {
    "country": "US",
    "name": "Caribou",
    "lat": "46.8606",
    "lng": "-68.01197"
  },
  {
    "country": "US",
    "name": "Castine",
    "lat": "44.38785",
    "lng": "-68.79975"
  },
  {
    "country": "US",
    "name": "Charleston",
    "lat": "45.08506",
    "lng": "-69.04059"
  },
  {
    "country": "US",
    "name": "Chelsea",
    "lat": "44.25035",
    "lng": "-69.71727"
  },
  {
    "country": "US",
    "name": "Cherryfield",
    "lat": "44.6073",
    "lng": "-67.92584"
  },
  {
    "country": "US",
    "name": "Chesterville",
    "lat": "44.55117",
    "lng": "-70.08617"
  },
  {
    "country": "US",
    "name": "China",
    "lat": "44.47868",
    "lng": "-69.51726"
  },
  {
    "country": "US",
    "name": "Chisholm",
    "lat": "44.48145",
    "lng": "-70.1995"
  },
  {
    "country": "US",
    "name": "Clinton",
    "lat": "44.63784",
    "lng": "-69.5031"
  },
  {
    "country": "US",
    "name": "Corinna",
    "lat": "44.92117",
    "lng": "-69.26171"
  },
  {
    "country": "US",
    "name": "Cornish",
    "lat": "43.8048",
    "lng": "-70.80117"
  },
  {
    "country": "US",
    "name": "Cornville",
    "lat": "44.83673",
    "lng": "-69.67311"
  },
  {
    "country": "US",
    "name": "Cumberland Center",
    "lat": "43.79647",
    "lng": "-70.25894"
  },
  {
    "country": "US",
    "name": "Cushing",
    "lat": "44.01925",
    "lng": "-69.23977"
  },
  {
    "country": "US",
    "name": "Damariscotta",
    "lat": "44.03286",
    "lng": "-69.51866"
  },
  {
    "country": "US",
    "name": "Dedham",
    "lat": "44.69174",
    "lng": "-68.66198"
  },
  {
    "country": "US",
    "name": "Deer Isle",
    "lat": "44.22397",
    "lng": "-68.67753"
  },
  {
    "country": "US",
    "name": "Denmark",
    "lat": "43.97035",
    "lng": "-70.8034"
  },
  {
    "country": "US",
    "name": "Dexter",
    "lat": "45.02395",
    "lng": "-69.28977"
  },
  {
    "country": "US",
    "name": "Dixfield",
    "lat": "44.53395",
    "lng": "-70.4559"
  },
  {
    "country": "US",
    "name": "Dixmont",
    "lat": "44.68035",
    "lng": "-69.16282"
  },
  {
    "country": "US",
    "name": "Dover-Foxcroft",
    "lat": "45.18339",
    "lng": "-69.22699"
  },
  {
    "country": "US",
    "name": "East Machias",
    "lat": "44.73924",
    "lng": "-67.38999"
  },
  {
    "country": "US",
    "name": "East Millinocket",
    "lat": "45.62755",
    "lng": "-68.57448"
  },
  {
    "country": "US",
    "name": "Easton",
    "lat": "46.64115",
    "lng": "-67.90947"
  },
  {
    "country": "US",
    "name": "Eastport",
    "lat": "44.90619",
    "lng": "-66.98998"
  },
  {
    "country": "US",
    "name": "Eddington",
    "lat": "44.82618",
    "lng": "-68.69337"
  },
  {
    "country": "US",
    "name": "Edgecomb",
    "lat": "43.95841",
    "lng": "-69.6306"
  },
  {
    "country": "US",
    "name": "Eliot",
    "lat": "43.15314",
    "lng": "-70.80006"
  },
  {
    "country": "US",
    "name": "Ellsworth",
    "lat": "44.54341",
    "lng": "-68.41946"
  },
  {
    "country": "US",
    "name": "Enfield",
    "lat": "45.24894",
    "lng": "-68.56836"
  },
  {
    "country": "US",
    "name": "Etna",
    "lat": "44.8209",
    "lng": "-69.11115"
  },
  {
    "country": "US",
    "name": "Fairfield",
    "lat": "44.5884",
    "lng": "-69.59866"
  },
  {
    "country": "US",
    "name": "Falmouth",
    "lat": "43.72953",
    "lng": "-70.24199"
  },
  {
    "country": "US",
    "name": "Falmouth Foreside",
    "lat": "43.7348",
    "lng": "-70.20783"
  },
  {
    "country": "US",
    "name": "Farmingdale",
    "lat": "44.24451",
    "lng": "-69.77143"
  },
  {
    "country": "US",
    "name": "Farmington",
    "lat": "44.67062",
    "lng": "-70.15117"
  },
  {
    "country": "US",
    "name": "Fayette",
    "lat": "44.40896",
    "lng": "-70.03367"
  },
  {
    "country": "US",
    "name": "Fort Fairfield",
    "lat": "46.77227",
    "lng": "-67.83391"
  },
  {
    "country": "US",
    "name": "Fort Kent",
    "lat": "47.25865",
    "lng": "-68.58949"
  },
  {
    "country": "US",
    "name": "Frankfort",
    "lat": "44.6098",
    "lng": "-68.8767"
  },
  {
    "country": "US",
    "name": "Franklin",
    "lat": "44.58702",
    "lng": "-68.23224"
  },
  {
    "country": "US",
    "name": "Freeport",
    "lat": "43.85702",
    "lng": "-70.10311"
  },
  {
    "country": "US",
    "name": "Frenchville",
    "lat": "47.28087",
    "lng": "-68.37976"
  },
  {
    "country": "US",
    "name": "Friendship",
    "lat": "43.98369",
    "lng": "-69.33394"
  },
  {
    "country": "US",
    "name": "Fryeburg",
    "lat": "44.01646",
    "lng": "-70.98062"
  },
  {
    "country": "US",
    "name": "Gardiner",
    "lat": "44.23007",
    "lng": "-69.77532"
  },
  {
    "country": "US",
    "name": "Garland",
    "lat": "45.0384",
    "lng": "-69.16032"
  },
  {
    "country": "US",
    "name": "Gorham",
    "lat": "43.67952",
    "lng": "-70.44422"
  },
  {
    "country": "US",
    "name": "Gouldsboro",
    "lat": "44.47841",
    "lng": "-68.03834"
  },
  {
    "country": "US",
    "name": "Greenbush",
    "lat": "45.08034",
    "lng": "-68.65086"
  },
  {
    "country": "US",
    "name": "Greene",
    "lat": "44.18979",
    "lng": "-70.14033"
  },
  {
    "country": "US",
    "name": "Greenville",
    "lat": "45.45949",
    "lng": "-69.59061"
  },
  {
    "country": "US",
    "name": "Hallowell",
    "lat": "44.2859",
    "lng": "-69.79088"
  },
  {
    "country": "US",
    "name": "Hampden",
    "lat": "44.74452",
    "lng": "-68.83698"
  },
  {
    "country": "US",
    "name": "Hancock",
    "lat": "44.52924",
    "lng": "-68.25363"
  },
  {
    "country": "US",
    "name": "Harpswell Center",
    "lat": "43.80175",
    "lng": "-69.98421"
  },
  {
    "country": "US",
    "name": "Harrison",
    "lat": "44.11035",
    "lng": "-70.67923"
  },
  {
    "country": "US",
    "name": "Hartford",
    "lat": "44.37284",
    "lng": "-70.34673"
  },
  {
    "country": "US",
    "name": "Hebron",
    "lat": "44.19813",
    "lng": "-70.40645"
  },
  {
    "country": "US",
    "name": "Hermon",
    "lat": "44.81007",
    "lng": "-68.91337"
  },
  {
    "country": "US",
    "name": "Hiram",
    "lat": "43.87868",
    "lng": "-70.8034"
  },
  {
    "country": "US",
    "name": "Hodgdon",
    "lat": "46.05394",
    "lng": "-67.86668"
  },
  {
    "country": "US",
    "name": "Holden",
    "lat": "44.75285",
    "lng": "-68.67892"
  },
  {
    "country": "US",
    "name": "Hollis Center",
    "lat": "43.60508",
    "lng": "-70.59311"
  },
  {
    "country": "US",
    "name": "Houlton",
    "lat": "46.12616",
    "lng": "-67.8403"
  },
  {
    "country": "US",
    "name": "Howland",
    "lat": "45.23867",
    "lng": "-68.66364"
  },
  {
    "country": "US",
    "name": "Hudson",
    "lat": "45.00118",
    "lng": "-68.88059"
  },
  {
    "country": "US",
    "name": "Jay",
    "lat": "44.50395",
    "lng": "-70.21617"
  },
  {
    "country": "US",
    "name": "Jefferson",
    "lat": "44.20674",
    "lng": "-69.45254"
  },
  {
    "country": "US",
    "name": "Jonesport",
    "lat": "44.53286",
    "lng": "-67.59833"
  },
  {
    "country": "US",
    "name": "Kenduskeag",
    "lat": "44.91951",
    "lng": "-68.9317"
  },
  {
    "country": "US",
    "name": "Kennebunk",
    "lat": "43.38397",
    "lng": "-70.54478"
  },
  {
    "country": "US",
    "name": "Kennebunkport",
    "lat": "43.36175",
    "lng": "-70.47672"
  },
  {
    "country": "US",
    "name": "Kingfield",
    "lat": "44.95922",
    "lng": "-70.15395"
  },
  {
    "country": "US",
    "name": "Kittery Point",
    "lat": "43.08342",
    "lng": "-70.70783"
  },
  {
    "country": "US",
    "name": "Kittery",
    "lat": "43.08814",
    "lng": "-70.73616"
  },
  {
    "country": "US",
    "name": "Lake Arrowhead",
    "lat": "43.66369",
    "lng": "-70.73478"
  },
  {
    "country": "US",
    "name": "Lebanon",
    "lat": "43.39453",
    "lng": "-70.85089"
  },
  {
    "country": "US",
    "name": "Leeds",
    "lat": "44.3034",
    "lng": "-70.1195"
  },
  {
    "country": "US",
    "name": "Levant",
    "lat": "44.86924",
    "lng": "-68.93476"
  },
  {
    "country": "US",
    "name": "Lewiston",
    "lat": "44.10035",
    "lng": "-70.21478"
  },
  {
    "country": "US",
    "name": "Limerick",
    "lat": "43.68841",
    "lng": "-70.79367"
  },
  {
    "country": "US",
    "name": "Limestone",
    "lat": "46.90866",
    "lng": "-67.82585"
  },
  {
    "country": "US",
    "name": "Limington",
    "lat": "43.73174",
    "lng": "-70.71089"
  },
  {
    "country": "US",
    "name": "Lincoln",
    "lat": "45.36228",
    "lng": "-68.50502"
  },
  {
    "country": "US",
    "name": "Lincolnville",
    "lat": "44.28119",
    "lng": "-69.00865"
  },
  {
    "country": "US",
    "name": "Lisbon",
    "lat": "44.03146",
    "lng": "-70.1045"
  },
  {
    "country": "US",
    "name": "Lisbon Falls",
    "lat": "43.99619",
    "lng": "-70.06061"
  },
  {
    "country": "US",
    "name": "Livermore",
    "lat": "44.38396",
    "lng": "-70.24922"
  },
  {
    "country": "US",
    "name": "Livermore Falls",
    "lat": "44.47534",
    "lng": "-70.18811"
  },
  {
    "country": "US",
    "name": "Lovell",
    "lat": "44.12674",
    "lng": "-70.89173"
  },
  {
    "country": "US",
    "name": "Machias",
    "lat": "44.71508",
    "lng": "-67.46138"
  },
  {
    "country": "US",
    "name": "Machiasport",
    "lat": "44.69869",
    "lng": "-67.39471"
  },
  {
    "country": "US",
    "name": "Madawaska",
    "lat": "47.35532",
    "lng": "-68.32171"
  },
  {
    "country": "US",
    "name": "Madawaska",
    "lat": "46.88421",
    "lng": "-67.94725"
  },
  {
    "country": "US",
    "name": "Madison",
    "lat": "44.79756",
    "lng": "-69.87978"
  },
  {
    "country": "US",
    "name": "Manchester",
    "lat": "44.32451",
    "lng": "-69.86033"
  },
  {
    "country": "US",
    "name": "Mechanic Falls",
    "lat": "44.11174",
    "lng": "-70.39172"
  },
  {
    "country": "US",
    "name": "Medway",
    "lat": "45.60894",
    "lng": "-68.53086"
  },
  {
    "country": "US",
    "name": "Mexico",
    "lat": "44.5609",
    "lng": "-70.54534"
  },
  {
    "country": "US",
    "name": "Milbridge",
    "lat": "44.53536",
    "lng": "-67.88083"
  },
  {
    "country": "US",
    "name": "Milford",
    "lat": "44.94618",
    "lng": "-68.64392"
  },
  {
    "country": "US",
    "name": "Millinocket",
    "lat": "45.65727",
    "lng": "-68.70976"
  },
  {
    "country": "US",
    "name": "Milo",
    "lat": "45.25366",
    "lng": "-68.98587"
  },
  {
    "country": "US",
    "name": "Minot",
    "lat": "44.08563",
    "lng": "-70.32006"
  },
  {
    "country": "US",
    "name": "Monmouth",
    "lat": "44.23868",
    "lng": "-70.03561"
  },
  {
    "country": "US",
    "name": "Mount Vernon",
    "lat": "44.50118",
    "lng": "-69.98756"
  },
  {
    "country": "US",
    "name": "New Gloucester",
    "lat": "43.96285",
    "lng": "-70.28255"
  },
  {
    "country": "US",
    "name": "New Sharon",
    "lat": "44.63895",
    "lng": "-70.01561"
  },
  {
    "country": "US",
    "name": "Newport",
    "lat": "44.83534",
    "lng": "-69.27394"
  },
  {
    "country": "US",
    "name": "Newfield",
    "lat": "43.64813",
    "lng": "-70.84701"
  },
  {
    "country": "US",
    "name": "Nobleboro",
    "lat": "44.07952",
    "lng": "-69.48505"
  },
  {
    "country": "US",
    "name": "Norridgewock",
    "lat": "44.71312",
    "lng": "-69.79061"
  },
  {
    "country": "US",
    "name": "North Bath",
    "lat": "43.9348",
    "lng": "-69.81588"
  },
  {
    "country": "US",
    "name": "North Berwick",
    "lat": "43.3037",
    "lng": "-70.73339"
  },
  {
    "country": "US",
    "name": "North Windham",
    "lat": "43.83424",
    "lng": "-70.43839"
  },
  {
    "country": "US",
    "name": "Northport",
    "lat": "44.33786",
    "lng": "-68.96142"
  },
  {
    "country": "US",
    "name": "Norway",
    "lat": "44.21396",
    "lng": "-70.54478"
  },
  {
    "country": "US",
    "name": "Oakland",
    "lat": "44.54034",
    "lng": "-69.72199"
  },
  {
    "country": "US",
    "name": "Ogunquit",
    "lat": "43.24898",
    "lng": "-70.59922"
  },
  {
    "country": "US",
    "name": "Old Orchard Beach",
    "lat": "43.51731",
    "lng": "-70.37755"
  },
  {
    "country": "US",
    "name": "Old Town",
    "lat": "44.93423",
    "lng": "-68.64531"
  },
  {
    "country": "US",
    "name": "Orland",
    "lat": "44.57035",
    "lng": "-68.73586"
  },
  {
    "country": "US",
    "name": "Orono",
    "lat": "44.88312",
    "lng": "-68.67198"
  },
  {
    "country": "US",
    "name": "Orrington",
    "lat": "44.73118",
    "lng": "-68.82643"
  },
  {
    "country": "US",
    "name": "Owls Head",
    "lat": "44.0823",
    "lng": "-69.05726"
  },
  {
    "country": "US",
    "name": "Oxford",
    "lat": "44.13174",
    "lng": "-70.49311"
  },
  {
    "country": "US",
    "name": "Palermo",
    "lat": "44.40785",
    "lng": "-69.47393"
  },
  {
    "country": "US",
    "name": "Palmyra",
    "lat": "44.84645",
    "lng": "-69.35866"
  },
  {
    "country": "US",
    "name": "Paris",
    "lat": "44.25979",
    "lng": "-70.50062"
  },
  {
    "country": "US",
    "name": "Parsonsfield",
    "lat": "43.72702",
    "lng": "-70.92868"
  },
  {
    "country": "US",
    "name": "Patten",
    "lat": "45.99644",
    "lng": "-68.44614"
  },
  {
    "country": "US",
    "name": "Penobscot",
    "lat": "44.46452",
    "lng": "-68.71114"
  },
  {
    "country": "US",
    "name": "Peru",
    "lat": "44.50673",
    "lng": "-70.40534"
  },
  {
    "country": "US",
    "name": "Phippsburg",
    "lat": "43.82064",
    "lng": "-69.81477"
  },
  {
    "country": "US",
    "name": "Pittsfield",
    "lat": "44.78256",
    "lng": "-69.38338"
  },
  {
    "country": "US",
    "name": "Pittston",
    "lat": "44.22174",
    "lng": "-69.7556"
  },
  {
    "country": "US",
    "name": "Plymouth",
    "lat": "44.76729",
    "lng": "-69.21033"
  },
  {
    "country": "US",
    "name": "Poland",
    "lat": "44.06063",
    "lng": "-70.39367"
  },
  {
    "country": "US",
    "name": "Porter",
    "lat": "43.79591",
    "lng": "-70.93256"
  },
  {
    "country": "US",
    "name": "Portland",
    "lat": "43.66147",
    "lng": "-70.25533"
  },
  {
    "country": "US",
    "name": "Presque Isle",
    "lat": "46.68115",
    "lng": "-68.01586"
  },
  {
    "country": "US",
    "name": "Randolph",
    "lat": "44.23035",
    "lng": "-69.76671"
  },
  {
    "country": "US",
    "name": "Raymond",
    "lat": "43.90146",
    "lng": "-70.47033"
  },
  {
    "country": "US",
    "name": "Readfield",
    "lat": "44.38785",
    "lng": "-69.96672"
  },
  {
    "country": "US",
    "name": "Richmond",
    "lat": "44.0873",
    "lng": "-69.79893"
  },
  {
    "country": "US",
    "name": "Rockport",
    "lat": "44.18452",
    "lng": "-69.07615"
  },
  {
    "country": "US",
    "name": "Rome",
    "lat": "44.58506",
    "lng": "-69.86922"
  },
  {
    "country": "US",
    "name": "Rumford",
    "lat": "44.55367",
    "lng": "-70.5509"
  },
  {
    "country": "US",
    "name": "Sabattus",
    "lat": "44.1198",
    "lng": "-70.10755"
  },
  {
    "country": "US",
    "name": "Saco",
    "lat": "43.50092",
    "lng": "-70.44283"
  },
  {
    "country": "US",
    "name": "Saint Albans",
    "lat": "44.91006",
    "lng": "-69.41005"
  },
  {
    "country": "US",
    "name": "Saint George",
    "lat": "44.01647",
    "lng": "-69.19893"
  },
  {
    "country": "US",
    "name": "Sanford",
    "lat": "43.43925",
    "lng": "-70.77422"
  },
  {
    "country": "US",
    "name": "Sangerville",
    "lat": "45.16478",
    "lng": "-69.35644"
  },
  {
    "country": "US",
    "name": "Scarborough",
    "lat": "43.57814",
    "lng": "-70.32172"
  },
  {
    "country": "US",
    "name": "Searsmont",
    "lat": "44.36174",
    "lng": "-69.19504"
  },
  {
    "country": "US",
    "name": "Sedgwick",
    "lat": "44.30369",
    "lng": "-68.61614"
  },
  {
    "country": "US",
    "name": "Shapleigh",
    "lat": "43.54064",
    "lng": "-70.84812"
  },
  {
    "country": "US",
    "name": "Sidney",
    "lat": "44.41312",
    "lng": "-69.72893"
  },
  {
    "country": "US",
    "name": "Skowhegan",
    "lat": "44.76506",
    "lng": "-69.71922"
  },
  {
    "country": "US",
    "name": "South Berwick",
    "lat": "43.23453",
    "lng": "-70.8095"
  },
  {
    "country": "US",
    "name": "South Eliot",
    "lat": "43.10814",
    "lng": "-70.77755"
  },
  {
    "country": "US",
    "name": "South Paris",
    "lat": "44.22368",
    "lng": "-70.51339"
  },
  {
    "country": "US",
    "name": "South Portland",
    "lat": "43.64147",
    "lng": "-70.24088"
  },
  {
    "country": "US",
    "name": "South Portland Gardens",
    "lat": "43.63897",
    "lng": "-70.31533"
  },
  {
    "country": "US",
    "name": "South Sanford",
    "lat": "43.41119",
    "lng": "-70.74256"
  },
  {
    "country": "US",
    "name": "South Thomaston",
    "lat": "44.05147",
    "lng": "-69.12782"
  },
  {
    "country": "US",
    "name": "South Windham",
    "lat": "43.73619",
    "lng": "-70.42366"
  },
  {
    "country": "US",
    "name": "Springvale",
    "lat": "43.46675",
    "lng": "-70.79367"
  },
  {
    "country": "US",
    "name": "Steep Falls",
    "lat": "43.79397",
    "lng": "-70.65256"
  },
  {
    "country": "US",
    "name": "Stetson",
    "lat": "44.89173",
    "lng": "-69.14282"
  },
  {
    "country": "US",
    "name": "Steuben",
    "lat": "44.51098",
    "lng": "-67.96662"
  },
  {
    "country": "US",
    "name": "Stockton Springs",
    "lat": "44.48952",
    "lng": "-68.85698"
  },
  {
    "country": "US",
    "name": "Stonington",
    "lat": "44.15619",
    "lng": "-68.66669"
  },
  {
    "country": "US",
    "name": "Strong",
    "lat": "44.80756",
    "lng": "-70.2209"
  },
  {
    "country": "US",
    "name": "Sullivan",
    "lat": "44.52036",
    "lng": "-68.19668"
  },
  {
    "country": "US",
    "name": "Surry",
    "lat": "44.49591",
    "lng": "-68.50169"
  },
  {
    "country": "US",
    "name": "Swanville",
    "lat": "44.52119",
    "lng": "-68.99781"
  },
  {
    "country": "US",
    "name": "Thomaston",
    "lat": "44.07897",
    "lng": "-69.18171"
  },
  {
    "country": "US",
    "name": "Topsham",
    "lat": "43.92758",
    "lng": "-69.97588"
  },
  {
    "country": "US",
    "name": "Tremont",
    "lat": "44.25369",
    "lng": "-68.35141"
  },
  {
    "country": "US",
    "name": "Trenton",
    "lat": "44.43897",
    "lng": "-68.37002"
  },
  {
    "country": "US",
    "name": "Troy",
    "lat": "44.66479",
    "lng": "-69.24088"
  },
  {
    "country": "US",
    "name": "Turner",
    "lat": "44.25646",
    "lng": "-70.25617"
  },
  {
    "country": "US",
    "name": "Van Buren",
    "lat": "47.15727",
    "lng": "-67.9353"
  },
  {
    "country": "US",
    "name": "Vassalboro",
    "lat": "44.45923",
    "lng": "-69.67755"
  },
  {
    "country": "US",
    "name": "Veazie",
    "lat": "44.83868",
    "lng": "-68.70531"
  },
  {
    "country": "US",
    "name": "Vinalhaven",
    "lat": "44.04814",
    "lng": "-68.8317"
  },
  {
    "country": "US",
    "name": "Waldoboro",
    "lat": "44.09536",
    "lng": "-69.3756"
  },
  {
    "country": "US",
    "name": "Warren",
    "lat": "44.12036",
    "lng": "-69.24005"
  },
  {
    "country": "US",
    "name": "Washington",
    "lat": "44.27369",
    "lng": "-69.36727"
  },
  {
    "country": "US",
    "name": "Waterboro",
    "lat": "43.53564",
    "lng": "-70.71506"
  },
  {
    "country": "US",
    "name": "Waterville",
    "lat": "44.55201",
    "lng": "-69.63171"
  },
  {
    "country": "US",
    "name": "Wayne",
    "lat": "44.34868",
    "lng": "-70.06616"
  },
  {
    "country": "US",
    "name": "Wells Beach Station",
    "lat": "43.32397",
    "lng": "-70.59144"
  },
  {
    "country": "US",
    "name": "West Paris",
    "lat": "44.32423",
    "lng": "-70.57395"
  },
  {
    "country": "US",
    "name": "West Scarborough",
    "lat": "43.57036",
    "lng": "-70.38783"
  },
  {
    "country": "US",
    "name": "Westbrook",
    "lat": "43.67703",
    "lng": "-70.37116"
  },
  {
    "country": "US",
    "name": "Whitefield",
    "lat": "44.17007",
    "lng": "-69.62532"
  },
  {
    "country": "US",
    "name": "Wilton",
    "lat": "44.59284",
    "lng": "-70.22812"
  },
  {
    "country": "US",
    "name": "Windsor",
    "lat": "44.31063",
    "lng": "-69.5806"
  },
  {
    "country": "US",
    "name": "Winslow",
    "lat": "44.54701",
    "lng": "-69.62116"
  },
  {
    "country": "US",
    "name": "Winterport",
    "lat": "44.63785",
    "lng": "-68.84504"
  },
  {
    "country": "US",
    "name": "Winthrop",
    "lat": "44.30507",
    "lng": "-69.977"
  },
  {
    "country": "US",
    "name": "Wiscasset",
    "lat": "44.00286",
    "lng": "-69.6656"
  },
  {
    "country": "US",
    "name": "Woolwich",
    "lat": "43.91869",
    "lng": "-69.80116"
  },
  {
    "country": "US",
    "name": "Yarmouth",
    "lat": "43.80064",
    "lng": "-70.18672"
  },
  {
    "country": "US",
    "name": "York Beach",
    "lat": "43.17148",
    "lng": "-70.60894"
  },
  {
    "country": "US",
    "name": "York Harbor",
    "lat": "43.13676",
    "lng": "-70.64561"
  },
  {
    "country": "US",
    "name": "Adrian",
    "lat": "41.89755",
    "lng": "-84.03717"
  },
  {
    "country": "US",
    "name": "Albion",
    "lat": "42.2431",
    "lng": "-84.75303"
  },
  {
    "country": "US",
    "name": "Algonac",
    "lat": "42.61858",
    "lng": "-82.5323"
  },
  {
    "country": "US",
    "name": "Allegan",
    "lat": "42.5292",
    "lng": "-85.8553"
  },
  {
    "country": "US",
    "name": "Allen Park",
    "lat": "42.25754",
    "lng": "-83.21104"
  },
  {
    "country": "US",
    "name": "Allendale",
    "lat": "42.97225",
    "lng": "-85.95365"
  },
  {
    "country": "US",
    "name": "Alma",
    "lat": "43.37892",
    "lng": "-84.65973"
  },
  {
    "country": "US",
    "name": "Almont",
    "lat": "42.92058",
    "lng": "-83.04493"
  },
  {
    "country": "US",
    "name": "Alpena",
    "lat": "45.06168",
    "lng": "-83.43275"
  },
  {
    "country": "US",
    "name": "Ann Arbor",
    "lat": "42.27756",
    "lng": "-83.74088"
  },
  {
    "country": "US",
    "name": "Argentine",
    "lat": "42.79142",
    "lng": "-83.84634"
  },
  {
    "country": "US",
    "name": "Armada",
    "lat": "42.8442",
    "lng": "-82.88437"
  },
  {
    "country": "US",
    "name": "Athens",
    "lat": "42.08866",
    "lng": "-85.23471"
  },
  {
    "country": "US",
    "name": "Atlanta",
    "lat": "45.00473",
    "lng": "-84.14389"
  },
  {
    "country": "US",
    "name": "Au Sable",
    "lat": "44.41085",
    "lng": "-83.33219"
  },
  {
    "country": "US",
    "name": "Auburn",
    "lat": "43.60336",
    "lng": "-84.0697"
  },
  {
    "country": "US",
    "name": "Auburn Hills",
    "lat": "42.68753",
    "lng": "-83.2341"
  },
  {
    "country": "US",
    "name": "Bad Axe",
    "lat": "43.80196",
    "lng": "-83.00078"
  },
  {
    "country": "US",
    "name": "Baldwin",
    "lat": "43.90112",
    "lng": "-85.85173"
  },
  {
    "country": "US",
    "name": "Bangor",
    "lat": "42.31254",
    "lng": "-86.11308"
  },
  {
    "country": "US",
    "name": "Baraga",
    "lat": "46.77854",
    "lng": "-88.48902"
  },
  {
    "country": "US",
    "name": "Bath",
    "lat": "42.81864",
    "lng": "-84.44859"
  },
  {
    "country": "US",
    "name": "Battle Creek",
    "lat": "42.3173",
    "lng": "-85.17816"
  },
  {
    "country": "US",
    "name": "Bay City",
    "lat": "43.59447",
    "lng": "-83.88886"
  },
  {
    "country": "US",
    "name": "Beaverton",
    "lat": "43.88225",
    "lng": "-84.48473"
  },
  {
    "country": "US",
    "name": "Beecher",
    "lat": "43.09003",
    "lng": "-83.6944"
  },
  {
    "country": "US",
    "name": "Beechwood",
    "lat": "42.79697",
    "lng": "-86.12588"
  },
  {
    "country": "US",
    "name": "Belding",
    "lat": "43.09781",
    "lng": "-85.22891"
  },
  {
    "country": "US",
    "name": "Bellaire",
    "lat": "44.98028",
    "lng": "-85.21117"
  },
  {
    "country": "US",
    "name": "Belleville",
    "lat": "42.20476",
    "lng": "-83.48521"
  },
  {
    "country": "US",
    "name": "Bellevue",
    "lat": "42.44337",
    "lng": "-85.01805"
  },
  {
    "country": "US",
    "name": "Benton Harbor",
    "lat": "42.11671",
    "lng": "-86.45419"
  },
  {
    "country": "US",
    "name": "Benton Heights",
    "lat": "42.13115",
    "lng": "-86.40724"
  },
  {
    "country": "US",
    "name": "Berkley",
    "lat": "42.50309",
    "lng": "-83.18354"
  },
  {
    "country": "US",
    "name": "Berrien Springs",
    "lat": "41.94643",
    "lng": "-86.3389"
  },
  {
    "country": "US",
    "name": "Bessemer",
    "lat": "46.48134",
    "lng": "-90.05295"
  },
  {
    "country": "US",
    "name": "Beulah",
    "lat": "44.63194",
    "lng": "-86.09092"
  },
  {
    "country": "US",
    "name": "Beverly Hills",
    "lat": "42.52392",
    "lng": "-83.22326"
  },
  {
    "country": "US",
    "name": "Big Rapids",
    "lat": "43.69808",
    "lng": "-85.48366"
  },
  {
    "country": "US",
    "name": "Bingham Farms",
    "lat": "42.51587",
    "lng": "-83.27326"
  },
  {
    "country": "US",
    "name": "Birch Run",
    "lat": "43.25086",
    "lng": "-83.79413"
  },
  {
    "country": "US",
    "name": "Birmingham",
    "lat": "42.5467",
    "lng": "-83.21132"
  },
  {
    "country": "US",
    "name": "Blissfield",
    "lat": "41.83255",
    "lng": "-83.86244"
  },
  {
    "country": "US",
    "name": "Bloomfield Hills",
    "lat": "42.58364",
    "lng": "-83.24549"
  },
  {
    "country": "US",
    "name": "Boyne City",
    "lat": "45.21668",
    "lng": "-85.01394"
  },
  {
    "country": "US",
    "name": "Breckenridge",
    "lat": "43.40808",
    "lng": "-84.475"
  },
  {
    "country": "US",
    "name": "Bridgeport",
    "lat": "43.35947",
    "lng": "-83.88164"
  },
  {
    "country": "US",
    "name": "Bridgman",
    "lat": "41.9431",
    "lng": "-86.55697"
  },
  {
    "country": "US",
    "name": "Brighton",
    "lat": "42.52948",
    "lng": "-83.78022"
  },
  {
    "country": "US",
    "name": "Bronson",
    "lat": "41.87227",
    "lng": "-85.1947"
  },
  {
    "country": "US",
    "name": "Brooklyn",
    "lat": "42.10587",
    "lng": "-84.24828"
  },
  {
    "country": "US",
    "name": "Brown City",
    "lat": "43.21225",
    "lng": "-82.98966"
  },
  {
    "country": "US",
    "name": "Brownlee Park",
    "lat": "42.31893",
    "lng": "-85.14249"
  },
  {
    "country": "US",
    "name": "Buchanan",
    "lat": "41.82727",
    "lng": "-86.36112"
  },
  {
    "country": "US",
    "name": "Buena Vista",
    "lat": "43.4203",
    "lng": "-83.89858"
  },
  {
    "country": "US",
    "name": "Burt",
    "lat": "43.23669",
    "lng": "-83.90636"
  },
  {
    "country": "US",
    "name": "Burton",
    "lat": "42.99947",
    "lng": "-83.61634"
  },
  {
    "country": "US",
    "name": "Byron Center",
    "lat": "42.81225",
    "lng": "-85.72281"
  },
  {
    "country": "US",
    "name": "Cadillac",
    "lat": "44.25195",
    "lng": "-85.40116"
  },
  {
    "country": "US",
    "name": "Caledonia",
    "lat": "42.7892",
    "lng": "-85.51669"
  },
  {
    "country": "US",
    "name": "Canadian Lakes",
    "lat": "43.57919",
    "lng": "-85.3017"
  },
  {
    "country": "US",
    "name": "Canton",
    "lat": "42.30865",
    "lng": "-83.48216"
  },
  {
    "country": "US",
    "name": "Capac",
    "lat": "43.01253",
    "lng": "-82.92799"
  },
  {
    "country": "US",
    "name": "Carleton",
    "lat": "42.05921",
    "lng": "-83.39077"
  },
  {
    "country": "US",
    "name": "Caro",
    "lat": "43.49073",
    "lng": "-83.39885"
  },
  {
    "country": "US",
    "name": "Carrollton",
    "lat": "43.45864",
    "lng": "-83.93025"
  },
  {
    "country": "US",
    "name": "Carson City",
    "lat": "43.17698",
    "lng": "-84.84639"
  },
  {
    "country": "US",
    "name": "Cass City",
    "lat": "43.60085",
    "lng": "-83.17467"
  },
  {
    "country": "US",
    "name": "Cassopolis",
    "lat": "41.91171",
    "lng": "-86.01001"
  },
  {
    "country": "US",
    "name": "Cedar Springs",
    "lat": "43.22336",
    "lng": "-85.55142"
  },
  {
    "country": "US",
    "name": "Center Line",
    "lat": "42.48504",
    "lng": "-83.0277"
  },
  {
    "country": "US",
    "name": "Centreville",
    "lat": "41.92338",
    "lng": "-85.52832"
  },
  {
    "country": "US",
    "name": "Charlevoix",
    "lat": "45.31806",
    "lng": "-85.2584"
  },
  {
    "country": "US",
    "name": "Charlotte",
    "lat": "42.56365",
    "lng": "-84.83582"
  },
  {
    "country": "US",
    "name": "Cheboygan",
    "lat": "45.64696",
    "lng": "-84.47448"
  },
  {
    "country": "US",
    "name": "Chelsea",
    "lat": "42.31807",
    "lng": "-84.02181"
  },
  {
    "country": "US",
    "name": "Chesaning",
    "lat": "43.18475",
    "lng": "-84.11497"
  },
  {
    "country": "US",
    "name": "Clare",
    "lat": "43.81947",
    "lng": "-84.76863"
  },
  {
    "country": "US",
    "name": "Clarkston",
    "lat": "42.73586",
    "lng": "-83.41883"
  },
  {
    "country": "US",
    "name": "Clawson",
    "lat": "42.53337",
    "lng": "-83.14632"
  },
  {
    "country": "US",
    "name": "Clinton",
    "lat": "42.07199",
    "lng": "-83.97161"
  },
  {
    "country": "US",
    "name": "Clinton Township",
    "lat": "42.58698",
    "lng": "-82.91992"
  },
  {
    "country": "US",
    "name": "Clio",
    "lat": "43.17753",
    "lng": "-83.73413"
  },
  {
    "country": "US",
    "name": "Coldwater",
    "lat": "41.94033",
    "lng": "-85.00052"
  },
  {
    "country": "US",
    "name": "Coleman",
    "lat": "43.75669",
    "lng": "-84.58584"
  },
  {
    "country": "US",
    "name": "Coloma",
    "lat": "42.18615",
    "lng": "-86.30836"
  },
  {
    "country": "US",
    "name": "Colon",
    "lat": "41.95838",
    "lng": "-85.32498"
  },
  {
    "country": "US",
    "name": "Comstock Park",
    "lat": "43.03864",
    "lng": "-85.67003"
  },
  {
    "country": "US",
    "name": "Concord",
    "lat": "42.17782",
    "lng": "-84.64302"
  },
  {
    "country": "US",
    "name": "Constantine",
    "lat": "41.84116",
    "lng": "-85.6686"
  },
  {
    "country": "US",
    "name": "Coopersville",
    "lat": "43.06391",
    "lng": "-85.93477"
  },
  {
    "country": "US",
    "name": "Corunna",
    "lat": "42.98197",
    "lng": "-84.11775"
  },
  {
    "country": "US",
    "name": "Croswell",
    "lat": "43.27558",
    "lng": "-82.62104"
  },
  {
    "country": "US",
    "name": "Crystal Falls",
    "lat": "46.09801",
    "lng": "-88.33402"
  },
  {
    "country": "US",
    "name": "Cutlerville",
    "lat": "42.84086",
    "lng": "-85.66364"
  },
  {
    "country": "US",
    "name": "Davison",
    "lat": "43.03475",
    "lng": "-83.51801"
  },
  {
    "country": "US",
    "name": "DeWitt",
    "lat": "42.84226",
    "lng": "-84.56915"
  },
  {
    "country": "US",
    "name": "Dearborn",
    "lat": "42.32226",
    "lng": "-83.17631"
  },
  {
    "country": "US",
    "name": "Dearborn Heights",
    "lat": "42.33698",
    "lng": "-83.27326"
  },
  {
    "country": "US",
    "name": "Decatur",
    "lat": "42.1081",
    "lng": "-85.97446"
  },
  {
    "country": "US",
    "name": "Detroit",
    "lat": "42.33143",
    "lng": "-83.04575"
  },
  {
    "country": "US",
    "name": "Detroit Beach",
    "lat": "41.93116",
    "lng": "-83.32688"
  },
  {
    "country": "US",
    "name": "Dexter",
    "lat": "42.33834",
    "lng": "-83.88954"
  },
  {
    "country": "US",
    "name": "Dimondale",
    "lat": "42.64559",
    "lng": "-84.64887"
  },
  {
    "country": "US",
    "name": "Dollar Bay",
    "lat": "47.11965",
    "lng": "-88.51151"
  },
  {
    "country": "US",
    "name": "Douglas",
    "lat": "42.64336",
    "lng": "-86.20059"
  },
  {
    "country": "US",
    "name": "Dowagiac",
    "lat": "41.98421",
    "lng": "-86.10862"
  },
  {
    "country": "US",
    "name": "Dundee",
    "lat": "41.95727",
    "lng": "-83.65966"
  },
  {
    "country": "US",
    "name": "Durand",
    "lat": "42.91198",
    "lng": "-83.98468"
  },
  {
    "country": "US",
    "name": "Eagle River",
    "lat": "47.41381",
    "lng": "-88.29566"
  },
  {
    "country": "US",
    "name": "East Grand Rapids",
    "lat": "42.94114",
    "lng": "-85.61003"
  },
  {
    "country": "US",
    "name": "East Jordan",
    "lat": "45.15806",
    "lng": "-85.12423"
  },
  {
    "country": "US",
    "name": "East Lansing",
    "lat": "42.73698",
    "lng": "-84.48387"
  },
  {
    "country": "US",
    "name": "East Tawas",
    "lat": "44.27946",
    "lng": "-83.49025"
  },
  {
    "country": "US",
    "name": "Eastpointe",
    "lat": "42.46837",
    "lng": "-82.95547"
  },
  {
    "country": "US",
    "name": "Eastwood",
    "lat": "42.3031",
    "lng": "-85.55028"
  },
  {
    "country": "US",
    "name": "Eaton Rapids",
    "lat": "42.5092",
    "lng": "-84.65581"
  },
  {
    "country": "US",
    "name": "Ecorse",
    "lat": "42.24448",
    "lng": "-83.14576"
  },
  {
    "country": "US",
    "name": "Edgemont Park",
    "lat": "42.7467",
    "lng": "-84.59359"
  },
  {
    "country": "US",
    "name": "Edmore",
    "lat": "43.40809",
    "lng": "-85.03863"
  },
  {
    "country": "US",
    "name": "Edwardsburg",
    "lat": "41.7956",
    "lng": "-86.08084"
  },
  {
    "country": "US",
    "name": "Elk Rapids",
    "lat": "44.89556",
    "lng": "-85.41646"
  },
  {
    "country": "US",
    "name": "Escanaba",
    "lat": "45.74525",
    "lng": "-87.06458"
  },
  {
    "country": "US",
    "name": "Essexville",
    "lat": "43.6153",
    "lng": "-83.84192"
  },
  {
    "country": "US",
    "name": "Evart",
    "lat": "43.90058",
    "lng": "-85.2581"
  },
  {
    "country": "US",
    "name": "Fair Plain",
    "lat": "42.08699",
    "lng": "-86.45586"
  },
  {
    "country": "US",
    "name": "Farmington",
    "lat": "42.46448",
    "lng": "-83.37632"
  },
  {
    "country": "US",
    "name": "Farmington Hills",
    "lat": "42.48531",
    "lng": "-83.37716"
  },
  {
    "country": "US",
    "name": "Fennville",
    "lat": "42.59392",
    "lng": "-86.1017"
  },
  {
    "country": "US",
    "name": "Fenton",
    "lat": "42.79781",
    "lng": "-83.70495"
  },
  {
    "country": "US",
    "name": "Ferndale",
    "lat": "42.46059",
    "lng": "-83.13465"
  },
  {
    "country": "US",
    "name": "Ferrysburg",
    "lat": "43.08446",
    "lng": "-86.22033"
  },
  {
    "country": "US",
    "name": "Flat Rock",
    "lat": "42.09643",
    "lng": "-83.29187"
  },
  {
    "country": "US",
    "name": "Flint",
    "lat": "43.01253",
    "lng": "-83.68746"
  },
  {
    "country": "US",
    "name": "Flushing",
    "lat": "43.06308",
    "lng": "-83.85107"
  },
  {
    "country": "US",
    "name": "Forest Hills",
    "lat": "42.95947",
    "lng": "-85.48975"
  },
  {
    "country": "US",
    "name": "Fowler",
    "lat": "43.0017",
    "lng": "-84.73972"
  },
  {
    "country": "US",
    "name": "Fowlerville",
    "lat": "42.66059",
    "lng": "-84.07301"
  },
  {
    "country": "US",
    "name": "Frankenmuth",
    "lat": "43.33169",
    "lng": "-83.73802"
  },
  {
    "country": "US",
    "name": "Frankfort",
    "lat": "44.63361",
    "lng": "-86.23454"
  },
  {
    "country": "US",
    "name": "Franklin",
    "lat": "42.52226",
    "lng": "-83.30604"
  },
  {
    "country": "US",
    "name": "Fraser",
    "lat": "42.5392",
    "lng": "-82.94937"
  },
  {
    "country": "US",
    "name": "Freeland",
    "lat": "43.52503",
    "lng": "-84.12276"
  },
  {
    "country": "US",
    "name": "Fremont",
    "lat": "43.46752",
    "lng": "-85.942"
  },
  {
    "country": "US",
    "name": "Fruitport",
    "lat": "43.13196",
    "lng": "-86.15478"
  },
  {
    "country": "US",
    "name": "Galesburg",
    "lat": "42.28865",
    "lng": "-85.41806"
  },
  {
    "country": "US",
    "name": "Garden City",
    "lat": "42.32559",
    "lng": "-83.33104"
  },
  {
    "country": "US",
    "name": "Gaylord",
    "lat": "45.02751",
    "lng": "-84.67475"
  },
  {
    "country": "US",
    "name": "Gibraltar",
    "lat": "42.09504",
    "lng": "-83.18965"
  },
  {
    "country": "US",
    "name": "Gladstone",
    "lat": "45.85274",
    "lng": "-87.0218"
  },
  {
    "country": "US",
    "name": "Gladwin",
    "lat": "43.98085",
    "lng": "-84.4864"
  },
  {
    "country": "US",
    "name": "Goodrich",
    "lat": "42.91697",
    "lng": "-83.50634"
  },
  {
    "country": "US",
    "name": "Grand Blanc",
    "lat": "42.92753",
    "lng": "-83.62995"
  },
  {
    "country": "US",
    "name": "Grand Haven",
    "lat": "43.06307",
    "lng": "-86.22839"
  },
  {
    "country": "US",
    "name": "Grand Ledge",
    "lat": "42.75337",
    "lng": "-84.74638"
  },
  {
    "country": "US",
    "name": "Grand Rapids",
    "lat": "42.96336",
    "lng": "-85.66809"
  },
  {
    "country": "US",
    "name": "Grandville",
    "lat": "42.90975",
    "lng": "-85.76309"
  },
  {
    "country": "US",
    "name": "Grass Lake",
    "lat": "42.25087",
    "lng": "-84.21301"
  },
  {
    "country": "US",
    "name": "Grayling",
    "lat": "44.6614",
    "lng": "-84.71475"
  },
  {
    "country": "US",
    "name": "Greenville",
    "lat": "43.17753",
    "lng": "-85.2528"
  },
  {
    "country": "US",
    "name": "Greilickville",
    "lat": "44.78306",
    "lng": "-85.63869"
  },
  {
    "country": "US",
    "name": "Grosse Ile",
    "lat": "42.12921",
    "lng": "-83.14437"
  },
  {
    "country": "US",
    "name": "Grosse Pointe",
    "lat": "42.38615",
    "lng": "-82.91186"
  },
  {
    "country": "US",
    "name": "Grosse Pointe Farms",
    "lat": "42.4092",
    "lng": "-82.89186"
  },
  {
    "country": "US",
    "name": "Grosse Pointe Park",
    "lat": "42.37587",
    "lng": "-82.93742"
  },
  {
    "country": "US",
    "name": "Grosse Pointe Shores",
    "lat": "42.4367",
    "lng": "-82.87686"
  },
  {
    "country": "US",
    "name": "Grosse Pointe Woods",
    "lat": "42.44365",
    "lng": "-82.90686"
  },
  {
    "country": "US",
    "name": "Gwinn",
    "lat": "46.28106",
    "lng": "-87.44097"
  },
  {
    "country": "US",
    "name": "Hamtramck",
    "lat": "42.39282",
    "lng": "-83.04964"
  },
  {
    "country": "US",
    "name": "Hancock",
    "lat": "47.12687",
    "lng": "-88.58096"
  },
  {
    "country": "US",
    "name": "Harbor Beach",
    "lat": "43.84474",
    "lng": "-82.65132"
  },
  {
    "country": "US",
    "name": "Harbor Springs",
    "lat": "45.43168",
    "lng": "-84.992"
  },
  {
    "country": "US",
    "name": "Harper Woods",
    "lat": "42.43309",
    "lng": "-82.92408"
  },
  {
    "country": "US",
    "name": "Harrison",
    "lat": "44.01919",
    "lng": "-84.79947"
  },
  {
    "country": "US",
    "name": "Harrisville",
    "lat": "44.6564",
    "lng": "-83.29469"
  },
  {
    "country": "US",
    "name": "Hart",
    "lat": "43.69834",
    "lng": "-86.36397"
  },
  {
    "country": "US",
    "name": "Hartford",
    "lat": "42.20671",
    "lng": "-86.16669"
  },
  {
    "country": "US",
    "name": "Harvey",
    "lat": "46.49466",
    "lng": "-87.35431"
  },
  {
    "country": "US",
    "name": "Haslett",
    "lat": "42.74698",
    "lng": "-84.40108"
  },
  {
    "country": "US",
    "name": "Hastings",
    "lat": "42.64587",
    "lng": "-85.29084"
  },
  {
    "country": "US",
    "name": "Hazel Park",
    "lat": "42.46254",
    "lng": "-83.10409"
  },
  {
    "country": "US",
    "name": "Hemlock",
    "lat": "43.41475",
    "lng": "-84.23054"
  },
  {
    "country": "US",
    "name": "Highland Park",
    "lat": "42.40559",
    "lng": "-83.09687"
  },
  {
    "country": "US",
    "name": "Hillsdale",
    "lat": "41.92005",
    "lng": "-84.63051"
  },
  {
    "country": "US",
    "name": "Holland",
    "lat": "42.78752",
    "lng": "-86.10893"
  },
  {
    "country": "US",
    "name": "Holly",
    "lat": "42.79197",
    "lng": "-83.62773"
  },
  {
    "country": "US",
    "name": "Holt",
    "lat": "42.64059",
    "lng": "-84.51525"
  },
  {
    "country": "US",
    "name": "Homer",
    "lat": "42.14588",
    "lng": "-84.80886"
  },
  {
    "country": "US",
    "name": "Houghton",
    "lat": "47.12187",
    "lng": "-88.56901"
  },
  {
    "country": "US",
    "name": "Houghton Lake",
    "lat": "44.31474",
    "lng": "-84.76475"
  },
  {
    "country": "US",
    "name": "Howard City",
    "lat": "43.39558",
    "lng": "-85.46782"
  },
  {
    "country": "US",
    "name": "Howell",
    "lat": "42.60726",
    "lng": "-83.9294"
  },
  {
    "country": "US",
    "name": "Hubbard Lake",
    "lat": "44.75973",
    "lng": "-83.54442"
  },
  {
    "country": "US",
    "name": "Hudson",
    "lat": "41.85505",
    "lng": "-84.35384"
  },
  {
    "country": "US",
    "name": "Hudsonville",
    "lat": "42.87086",
    "lng": "-85.86504"
  },
  {
    "country": "US",
    "name": "Huntington Woods",
    "lat": "42.48059",
    "lng": "-83.16687"
  },
  {
    "country": "US",
    "name": "Imlay City",
    "lat": "43.02475",
    "lng": "-83.07772"
  },
  {
    "country": "US",
    "name": "Indian River",
    "lat": "45.41251",
    "lng": "-84.61254"
  },
  {
    "country": "US",
    "name": "Ionia",
    "lat": "42.98725",
    "lng": "-85.07112"
  },
  {
    "country": "US",
    "name": "Iron Mountain",
    "lat": "45.82023",
    "lng": "-88.06596"
  },
  {
    "country": "US",
    "name": "Iron River",
    "lat": "46.09273",
    "lng": "-88.64235"
  },
  {
    "country": "US",
    "name": "Ironwood",
    "lat": "46.45467",
    "lng": "-90.17101"
  },
  {
    "country": "US",
    "name": "Ishpeming",
    "lat": "46.48855",
    "lng": "-87.66764"
  },
  {
    "country": "US",
    "name": "Ithaca",
    "lat": "43.2917",
    "lng": "-84.6075"
  },
  {
    "country": "US",
    "name": "Jackson",
    "lat": "42.24587",
    "lng": "-84.40135"
  },
  {
    "country": "US",
    "name": "Jenison",
    "lat": "42.90725",
    "lng": "-85.79198"
  },
  {
    "country": "US",
    "name": "Jonesville",
    "lat": "41.98421",
    "lng": "-84.6619"
  },
  {
    "country": "US",
    "name": "Kalamazoo",
    "lat": "42.29171",
    "lng": "-85.58723"
  },
  {
    "country": "US",
    "name": "Kalkaska",
    "lat": "44.73417",
    "lng": "-85.17589"
  },
  {
    "country": "US",
    "name": "Keego Harbor",
    "lat": "42.60809",
    "lng": "-83.34382"
  },
  {
    "country": "US",
    "name": "Kent City",
    "lat": "43.22002",
    "lng": "-85.75115"
  },
  {
    "country": "US",
    "name": "Kentwood",
    "lat": "42.86947",
    "lng": "-85.64475"
  },
  {
    "country": "US",
    "name": "Kilmanagh",
    "lat": "43.75613",
    "lng": "-83.3569"
  },
  {
    "country": "US",
    "name": "Kingsford",
    "lat": "45.79496",
    "lng": "-88.07207"
  },
  {
    "country": "US",
    "name": "Kingsley",
    "lat": "44.58473",
    "lng": "-85.5359"
  },
  {
    "country": "US",
    "name": "L'Anse",
    "lat": "46.7566",
    "lng": "-88.45291"
  },
  {
    "country": "US",
    "name": "Laingsburg",
    "lat": "42.89031",
    "lng": "-84.35136"
  },
  {
    "country": "US",
    "name": "Lake City",
    "lat": "44.33529",
    "lng": "-85.21505"
  },
  {
    "country": "US",
    "name": "Lake Fenton",
    "lat": "42.84614",
    "lng": "-83.70773"
  },
  {
    "country": "US",
    "name": "Lake Michigan Beach",
    "lat": "42.22087",
    "lng": "-86.36947"
  },
  {
    "country": "US",
    "name": "Lake Odessa",
    "lat": "42.78476",
    "lng": "-85.13834"
  },
  {
    "country": "US",
    "name": "Lake Orion",
    "lat": "42.78448",
    "lng": "-83.23966"
  },
  {
    "country": "US",
    "name": "Lakeview",
    "lat": "42.29838",
    "lng": "-85.2111"
  },
  {
    "country": "US",
    "name": "Lakeview",
    "lat": "43.44642",
    "lng": "-85.2742"
  },
  {
    "country": "US",
    "name": "Lakewood Club",
    "lat": "43.37112",
    "lng": "-86.26034"
  },
  {
    "country": "US",
    "name": "Lambertville",
    "lat": "41.76588",
    "lng": "-83.62799"
  },
  {
    "country": "US",
    "name": "Lansing",
    "lat": "42.73253",
    "lng": "-84.55553"
  },
  {
    "country": "US",
    "name": "Lapeer",
    "lat": "43.05142",
    "lng": "-83.31883"
  },
  {
    "country": "US",
    "name": "Lathrup Village",
    "lat": "42.49642",
    "lng": "-83.22271"
  },
  {
    "country": "US",
    "name": "Laurium",
    "lat": "47.23743",
    "lng": "-88.44317"
  },
  {
    "country": "US",
    "name": "Lawton",
    "lat": "42.16726",
    "lng": "-85.84695"
  },
  {
    "country": "US",
    "name": "Leland",
    "lat": "45.02305",
    "lng": "-85.75981"
  },
  {
    "country": "US",
    "name": "Leslie",
    "lat": "42.45143",
    "lng": "-84.43247"
  },
  {
    "country": "US",
    "name": "Lewiston",
    "lat": "44.8839",
    "lng": "-84.30557"
  },
  {
    "country": "US",
    "name": "Lexington",
    "lat": "43.26808",
    "lng": "-82.53076"
  },
  {
    "country": "US",
    "name": "Lincoln Park",
    "lat": "42.25059",
    "lng": "-83.17854"
  },
  {
    "country": "US",
    "name": "Linden",
    "lat": "42.81447",
    "lng": "-83.78245"
  },
  {
    "country": "US",
    "name": "Litchfield",
    "lat": "42.04393",
    "lng": "-84.75746"
  },
  {
    "country": "US",
    "name": "Livonia",
    "lat": "42.36837",
    "lng": "-83.35271"
  },
  {
    "country": "US",
    "name": "Lowell",
    "lat": "42.93364",
    "lng": "-85.34196"
  },
  {
    "country": "US",
    "name": "Ludington",
    "lat": "43.95528",
    "lng": "-86.45258"
  },
  {
    "country": "US",
    "name": "Luna Pier",
    "lat": "41.80699",
    "lng": "-83.44243"
  },
  {
    "country": "US",
    "name": "Madison Heights",
    "lat": "42.48587",
    "lng": "-83.1052"
  },
  {
    "country": "US",
    "name": "Manchester",
    "lat": "42.15032",
    "lng": "-84.03772"
  },
  {
    "country": "US",
    "name": "Manistee",
    "lat": "44.24445",
    "lng": "-86.32425"
  },
  {
    "country": "US",
    "name": "Mancelona",
    "lat": "44.90223",
    "lng": "-85.06088"
  },
  {
    "country": "US",
    "name": "Manistique",
    "lat": "45.95775",
    "lng": "-86.24625"
  },
  {
    "country": "US",
    "name": "Manton",
    "lat": "44.41084",
    "lng": "-85.39894"
  },
  {
    "country": "US",
    "name": "Marcellus",
    "lat": "42.02588",
    "lng": "-85.81556"
  },
  {
    "country": "US",
    "name": "Marine City",
    "lat": "42.71948",
    "lng": "-82.49213"
  },
  {
    "country": "US",
    "name": "Marlette",
    "lat": "43.32697",
    "lng": "-83.08022"
  },
  {
    "country": "US",
    "name": "Marquette",
    "lat": "46.54354",
    "lng": "-87.39542"
  },
  {
    "country": "US",
    "name": "Marshall",
    "lat": "42.27226",
    "lng": "-84.96331"
  },
  {
    "country": "US",
    "name": "Marysville",
    "lat": "42.91253",
    "lng": "-82.48686"
  },
  {
    "country": "US",
    "name": "Mason",
    "lat": "42.5792",
    "lng": "-84.44358"
  },
  {
    "country": "US",
    "name": "Mattawan",
    "lat": "42.20948",
    "lng": "-85.78445"
  },
  {
    "country": "US",
    "name": "Melvindale",
    "lat": "42.28254",
    "lng": "-83.1752"
  },
  {
    "country": "US",
    "name": "Memphis",
    "lat": "42.89642",
    "lng": "-82.76881"
  },
  {
    "country": "US",
    "name": "Menominee",
    "lat": "45.10776",
    "lng": "-87.61427"
  },
  {
    "country": "US",
    "name": "Michigan Center",
    "lat": "42.23309",
    "lng": "-84.32718"
  },
  {
    "country": "US",
    "name": "Middleville",
    "lat": "42.71309",
    "lng": "-85.46196"
  },
  {
    "country": "US",
    "name": "Midland",
    "lat": "43.61558",
    "lng": "-84.24721"
  },
  {
    "country": "US",
    "name": "Milan",
    "lat": "42.08532",
    "lng": "-83.68244"
  },
  {
    "country": "US",
    "name": "Milford",
    "lat": "42.59364",
    "lng": "-83.59939"
  },
  {
    "country": "US",
    "name": "Millington",
    "lat": "43.28141",
    "lng": "-83.52968"
  },
  {
    "country": "US",
    "name": "Mio",
    "lat": "44.65224",
    "lng": "-84.12973"
  },
  {
    "country": "US",
    "name": "Monroe",
    "lat": "41.91643",
    "lng": "-83.39771"
  },
  {
    "country": "US",
    "name": "Montague",
    "lat": "43.41668",
    "lng": "-86.35701"
  },
  {
    "country": "US",
    "name": "Montrose",
    "lat": "43.17669",
    "lng": "-83.89274"
  },
  {
    "country": "US",
    "name": "Morenci",
    "lat": "41.71949",
    "lng": "-84.218"
  },
  {
    "country": "US",
    "name": "Mount Clemens",
    "lat": "42.59726",
    "lng": "-82.87798"
  },
  {
    "country": "US",
    "name": "Mount Morris",
    "lat": "43.11864",
    "lng": "-83.69496"
  },
  {
    "country": "US",
    "name": "Mount Pleasant",
    "lat": "43.59781",
    "lng": "-84.76751"
  },
  {
    "country": "US",
    "name": "Munising",
    "lat": "46.4112",
    "lng": "-86.64926"
  },
  {
    "country": "US",
    "name": "Muskegon",
    "lat": "43.23418",
    "lng": "-86.24839"
  },
  {
    "country": "US",
    "name": "Muskegon Heights",
    "lat": "43.20113",
    "lng": "-86.23895"
  },
  {
    "country": "US",
    "name": "Napoleon",
    "lat": "42.16059",
    "lng": "-84.24606"
  },
  {
    "country": "US",
    "name": "Nashville",
    "lat": "42.60281",
    "lng": "-85.09305"
  },
  {
    "country": "US",
    "name": "Negaunee",
    "lat": "46.4991",
    "lng": "-87.6118"
  },
  {
    "country": "US",
    "name": "New Baltimore",
    "lat": "42.68114",
    "lng": "-82.73686"
  },
  {
    "country": "US",
    "name": "New Buffalo",
    "lat": "41.79393",
    "lng": "-86.74392"
  },
  {
    "country": "US",
    "name": "New Haven",
    "lat": "42.72948",
    "lng": "-82.80131"
  },
  {
    "country": "US",
    "name": "New Haven",
    "lat": "43.09364",
    "lng": "-84.15331"
  },
  {
    "country": "US",
    "name": "Newaygo",
    "lat": "43.41974",
    "lng": "-85.80005"
  },
  {
    "country": "US",
    "name": "Newberry",
    "lat": "46.355",
    "lng": "-85.50956"
  },
  {
    "country": "US",
    "name": "Niles",
    "lat": "41.82977",
    "lng": "-86.25418"
  },
  {
    "country": "US",
    "name": "North Branch",
    "lat": "43.22947",
    "lng": "-83.19661"
  },
  {
    "country": "US",
    "name": "North Muskegon",
    "lat": "43.25613",
    "lng": "-86.26756"
  },
  {
    "country": "US",
    "name": "Northview",
    "lat": "43.04558",
    "lng": "-85.60059"
  },
  {
    "country": "US",
    "name": "Northville",
    "lat": "42.43115",
    "lng": "-83.48327"
  },
  {
    "country": "US",
    "name": "Norton Shores",
    "lat": "43.1689",
    "lng": "-86.26395"
  },
  {
    "country": "US",
    "name": "Norway",
    "lat": "45.7869",
    "lng": "-87.90374"
  },
  {
    "country": "US",
    "name": "Novi",
    "lat": "42.48059",
    "lng": "-83.47549"
  },
  {
    "country": "US",
    "name": "Oak Park",
    "lat": "42.45948",
    "lng": "-83.18271"
  },
  {
    "country": "US",
    "name": "Okemos",
    "lat": "42.72226",
    "lng": "-84.42747"
  },
  {
    "country": "US",
    "name": "Olivet",
    "lat": "42.44143",
    "lng": "-84.92415"
  },
  {
    "country": "US",
    "name": "Ontonagon",
    "lat": "46.87105",
    "lng": "-89.31403"
  },
  {
    "country": "US",
    "name": "Orchard Lake",
    "lat": "42.58309",
    "lng": "-83.35938"
  },
  {
    "country": "US",
    "name": "Ortonville",
    "lat": "42.85225",
    "lng": "-83.443"
  },
  {
    "country": "US",
    "name": "Otsego",
    "lat": "42.46059",
    "lng": "-85.69641"
  },
  {
    "country": "US",
    "name": "Ovid",
    "lat": "43.00586",
    "lng": "-84.37164"
  },
  {
    "country": "US",
    "name": "Owosso",
    "lat": "42.9978",
    "lng": "-84.17664"
  },
  {
    "country": "US",
    "name": "Oxford",
    "lat": "42.82475",
    "lng": "-83.26466"
  },
  {
    "country": "US",
    "name": "Parchment",
    "lat": "42.3281",
    "lng": "-85.56973"
  },
  {
    "country": "US",
    "name": "Paw Paw",
    "lat": "42.21782",
    "lng": "-85.89112"
  },
  {
    "country": "US",
    "name": "Paw Paw Lake",
    "lat": "42.21226",
    "lng": "-86.27197"
  },
  {
    "country": "US",
    "name": "Pearl Beach",
    "lat": "42.6267",
    "lng": "-82.59769"
  },
  {
    "country": "US",
    "name": "Perry",
    "lat": "42.82642",
    "lng": "-84.21941"
  },
  {
    "country": "US",
    "name": "Petersburg",
    "lat": "41.90116",
    "lng": "-83.71494"
  },
  {
    "country": "US",
    "name": "Petoskey",
    "lat": "45.37334",
    "lng": "-84.95533"
  },
  {
    "country": "US",
    "name": "Pigeon",
    "lat": "43.83002",
    "lng": "-83.26996"
  },
  {
    "country": "US",
    "name": "Pinckney",
    "lat": "42.457",
    "lng": "-83.94791"
  },
  {
    "country": "US",
    "name": "Pinconning",
    "lat": "43.85363",
    "lng": "-83.96499"
  },
  {
    "country": "US",
    "name": "Plainwell",
    "lat": "42.44004",
    "lng": "-85.6489"
  },
  {
    "country": "US",
    "name": "Pleasant Ridge",
    "lat": "42.47115",
    "lng": "-83.14215"
  },
  {
    "country": "US",
    "name": "Plymouth",
    "lat": "42.37143",
    "lng": "-83.47021"
  },
  {
    "country": "US",
    "name": "Pontiac",
    "lat": "42.63892",
    "lng": "-83.29105"
  },
  {
    "country": "US",
    "name": "Port Huron",
    "lat": "42.97086",
    "lng": "-82.42491"
  },
  {
    "country": "US",
    "name": "Portage",
    "lat": "42.20115",
    "lng": "-85.58"
  },
  {
    "country": "US",
    "name": "Portland",
    "lat": "42.8692",
    "lng": "-84.90305"
  },
  {
    "country": "US",
    "name": "Potterville",
    "lat": "42.6292",
    "lng": "-84.73887"
  },
  {
    "country": "US",
    "name": "Prudenville",
    "lat": "44.29835",
    "lng": "-84.65197"
  },
  {
    "country": "US",
    "name": "Quincy",
    "lat": "41.94421",
    "lng": "-84.88385"
  },
  {
    "country": "US",
    "name": "Quinnesec",
    "lat": "45.80635",
    "lng": "-87.98846"
  },
  {
    "country": "US",
    "name": "Rapid City",
    "lat": "44.83445",
    "lng": "-85.28256"
  },
  {
    "country": "US",
    "name": "Ravenna",
    "lat": "43.18947",
    "lng": "-85.93699"
  },
  {
    "country": "US",
    "name": "Reading",
    "lat": "41.83949",
    "lng": "-84.74801"
  },
  {
    "country": "US",
    "name": "Redford",
    "lat": "42.38337",
    "lng": "-83.2966"
  },
  {
    "country": "US",
    "name": "Reed City",
    "lat": "43.87502",
    "lng": "-85.51005"
  },
  {
    "country": "US",
    "name": "Reese",
    "lat": "43.45058",
    "lng": "-83.69635"
  },
  {
    "country": "US",
    "name": "Richmond",
    "lat": "42.8092",
    "lng": "-82.75576"
  },
  {
    "country": "US",
    "name": "River Rouge",
    "lat": "42.27337",
    "lng": "-83.13437"
  },
  {
    "country": "US",
    "name": "Riverview",
    "lat": "42.17421",
    "lng": "-83.17937"
  },
  {
    "country": "US",
    "name": "Rochester",
    "lat": "42.68059",
    "lng": "-83.13382"
  },
  {
    "country": "US",
    "name": "Rochester Hills",
    "lat": "42.65837",
    "lng": "-83.14993"
  },
  {
    "country": "US",
    "name": "Rockford",
    "lat": "43.12003",
    "lng": "-85.56003"
  },
  {
    "country": "US",
    "name": "Rockwood",
    "lat": "42.07088",
    "lng": "-83.2466"
  },
  {
    "country": "US",
    "name": "Rogers City",
    "lat": "45.4214",
    "lng": "-83.81833"
  },
  {
    "country": "US",
    "name": "Romeo",
    "lat": "42.80281",
    "lng": "-83.01299"
  },
  {
    "country": "US",
    "name": "Romulus",
    "lat": "42.22226",
    "lng": "-83.3966"
  },
  {
    "country": "US",
    "name": "Roosevelt Park",
    "lat": "43.1964",
    "lng": "-86.27228"
  },
  {
    "country": "US",
    "name": "Roscommon",
    "lat": "44.49835",
    "lng": "-84.59197"
  },
  {
    "country": "US",
    "name": "Roseville",
    "lat": "42.49726",
    "lng": "-82.93714"
  },
  {
    "country": "US",
    "name": "Royal Oak",
    "lat": "42.48948",
    "lng": "-83.14465"
  },
  {
    "country": "US",
    "name": "Saginaw",
    "lat": "43.41947",
    "lng": "-83.95081"
  },
  {
    "country": "US",
    "name": "Saint Charles",
    "lat": "43.29697",
    "lng": "-84.14053"
  },
  {
    "country": "US",
    "name": "Saint Helen",
    "lat": "44.36363",
    "lng": "-84.41029"
  },
  {
    "country": "US",
    "name": "Saint Ignace",
    "lat": "45.86614",
    "lng": "-84.72751"
  },
  {
    "country": "US",
    "name": "Saint Johns",
    "lat": "43.00114",
    "lng": "-84.55915"
  },
  {
    "country": "US",
    "name": "Saint Joseph",
    "lat": "42.10976",
    "lng": "-86.48002"
  },
  {
    "country": "US",
    "name": "Saint Louis",
    "lat": "43.40836",
    "lng": "-84.60667"
  },
  {
    "country": "US",
    "name": "Saline",
    "lat": "42.16671",
    "lng": "-83.78161"
  },
  {
    "country": "US",
    "name": "Sand Lake",
    "lat": "44.31918",
    "lng": "-83.6847"
  },
  {
    "country": "US",
    "name": "Sandusky",
    "lat": "43.4203",
    "lng": "-82.82966"
  },
  {
    "country": "US",
    "name": "Saranac",
    "lat": "42.92948",
    "lng": "-85.21307"
  },
  {
    "country": "US",
    "name": "Sault Ste. Marie",
    "lat": "46.4953",
    "lng": "-84.34532"
  },
  {
    "country": "US",
    "name": "Schoolcraft",
    "lat": "42.11421",
    "lng": "-85.63778"
  },
  {
    "country": "US",
    "name": "Scottville",
    "lat": "43.95473",
    "lng": "-86.28008"
  },
  {
    "country": "US",
    "name": "Sebewaing",
    "lat": "43.73224",
    "lng": "-83.45107"
  },
  {
    "country": "US",
    "name": "Shelby",
    "lat": "42.67087",
    "lng": "-83.03298"
  },
  {
    "country": "US",
    "name": "Shelby",
    "lat": "43.60862",
    "lng": "-86.36396"
  },
  {
    "country": "US",
    "name": "Shepherd",
    "lat": "43.52447",
    "lng": "-84.69473"
  },
  {
    "country": "US",
    "name": "Shields",
    "lat": "43.4153",
    "lng": "-84.05637"
  },
  {
    "country": "US",
    "name": "Skidway Lake",
    "lat": "44.18335",
    "lng": "-84.03527"
  },
  {
    "country": "US",
    "name": "South Gull Lake",
    "lat": "42.38754",
    "lng": "-85.39667"
  },
  {
    "country": "US",
    "name": "South Haven",
    "lat": "42.40309",
    "lng": "-86.27364"
  },
  {
    "country": "US",
    "name": "South Lyon",
    "lat": "42.46059",
    "lng": "-83.65161"
  },
  {
    "country": "US",
    "name": "South Monroe",
    "lat": "41.89588",
    "lng": "-83.41771"
  },
  {
    "country": "US",
    "name": "South Rockwood",
    "lat": "42.06393",
    "lng": "-83.26104"
  },
  {
    "country": "US",
    "name": "Southfield",
    "lat": "42.47337",
    "lng": "-83.22187"
  },
  {
    "country": "US",
    "name": "Southgate",
    "lat": "42.21393",
    "lng": "-83.19381"
  },
  {
    "country": "US",
    "name": "Sparta",
    "lat": "43.16086",
    "lng": "-85.71004"
  },
  {
    "country": "US",
    "name": "Spring Arbor",
    "lat": "42.20504",
    "lng": "-84.55274"
  },
  {
    "country": "US",
    "name": "Spring Lake",
    "lat": "43.07696",
    "lng": "-86.197"
  },
  {
    "country": "US",
    "name": "Springfield",
    "lat": "42.32643",
    "lng": "-85.23916"
  },
  {
    "country": "US",
    "name": "Saint Clair",
    "lat": "42.82087",
    "lng": "-82.48602"
  },
  {
    "country": "US",
    "name": "Saint Clair Shores",
    "lat": "42.49698",
    "lng": "-82.88881"
  },
  {
    "country": "US",
    "name": "Stambaugh, Iron River",
    "lat": "46.08107",
    "lng": "-88.62708"
  },
  {
    "country": "US",
    "name": "Standish",
    "lat": "43.98308",
    "lng": "-83.95888"
  },
  {
    "country": "US",
    "name": "Stanton",
    "lat": "43.29253",
    "lng": "-85.08141"
  },
  {
    "country": "US",
    "name": "Sterling Heights",
    "lat": "42.58031",
    "lng": "-83.0302"
  },
  {
    "country": "US",
    "name": "Stevensville",
    "lat": "42.01449",
    "lng": "-86.51947"
  },
  {
    "country": "US",
    "name": "Stockbridge",
    "lat": "42.45115",
    "lng": "-84.18051"
  },
  {
    "country": "US",
    "name": "Stony Point",
    "lat": "42.49698",
    "lng": "-85.42668"
  },
  {
    "country": "US",
    "name": "Stony Point",
    "lat": "41.94143",
    "lng": "-83.26493"
  },
  {
    "country": "US",
    "name": "Sturgis",
    "lat": "41.79922",
    "lng": "-85.41915"
  },
  {
    "country": "US",
    "name": "Swartz Creek",
    "lat": "42.95725",
    "lng": "-83.83051"
  },
  {
    "country": "US",
    "name": "Sylvan Lake",
    "lat": "42.61142",
    "lng": "-83.32855"
  },
  {
    "country": "US",
    "name": "Tawas City",
    "lat": "44.26946",
    "lng": "-83.5147"
  },
  {
    "country": "US",
    "name": "Taylor",
    "lat": "42.24087",
    "lng": "-83.26965"
  },
  {
    "country": "US",
    "name": "Tecumseh",
    "lat": "42.00393",
    "lng": "-83.94494"
  },
  {
    "country": "US",
    "name": "Temperance",
    "lat": "41.77921",
    "lng": "-83.56882"
  },
  {
    "country": "US",
    "name": "Three Rivers",
    "lat": "41.94394",
    "lng": "-85.63249"
  },
  {
    "country": "US",
    "name": "Three Oaks",
    "lat": "41.79865",
    "lng": "-86.61058"
  },
  {
    "country": "US",
    "name": "Traverse City",
    "lat": "44.76306",
    "lng": "-85.62063"
  },
  {
    "country": "US",
    "name": "Trenton",
    "lat": "42.13949",
    "lng": "-83.17826"
  },
  {
    "country": "US",
    "name": "Trowbridge Park",
    "lat": "46.5566",
    "lng": "-87.43736"
  },
  {
    "country": "US",
    "name": "Troy",
    "lat": "42.60559",
    "lng": "-83.14993"
  },
  {
    "country": "US",
    "name": "Twin Lake",
    "lat": "43.36279",
    "lng": "-86.16478"
  },
  {
    "country": "US",
    "name": "Union City",
    "lat": "42.06671",
    "lng": "-85.13609"
  },
  {
    "country": "US",
    "name": "Utica",
    "lat": "42.62614",
    "lng": "-83.03354"
  },
  {
    "country": "US",
    "name": "Vandercook Lake",
    "lat": "42.19337",
    "lng": "-84.39107"
  },
  {
    "country": "US",
    "name": "Vassar",
    "lat": "43.37197",
    "lng": "-83.58329"
  },
  {
    "country": "US",
    "name": "Vicksburg",
    "lat": "42.12005",
    "lng": "-85.53278"
  },
  {
    "country": "US",
    "name": "Lake Isabella",
    "lat": "43.64364",
    "lng": "-84.99725"
  },
  {
    "country": "US",
    "name": "Wacousta",
    "lat": "42.82781",
    "lng": "-84.70082"
  },
  {
    "country": "US",
    "name": "Wakefield",
    "lat": "46.47523",
    "lng": "-89.93989"
  },
  {
    "country": "US",
    "name": "Walker",
    "lat": "43.00141",
    "lng": "-85.76809"
  },
  {
    "country": "US",
    "name": "Walled Lake",
    "lat": "42.53781",
    "lng": "-83.48105"
  },
  {
    "country": "US",
    "name": "Warren",
    "lat": "42.49044",
    "lng": "-83.01304"
  },
  {
    "country": "US",
    "name": "Waterford",
    "lat": "42.69303",
    "lng": "-83.41181"
  },
  {
    "country": "US",
    "name": "Watervliet",
    "lat": "42.18671",
    "lng": "-86.26058"
  },
  {
    "country": "US",
    "name": "Waverly",
    "lat": "42.7392",
    "lng": "-84.62081"
  },
  {
    "country": "US",
    "name": "Wayland",
    "lat": "42.67392",
    "lng": "-85.64474"
  },
  {
    "country": "US",
    "name": "Wayne",
    "lat": "42.28143",
    "lng": "-83.38632"
  },
  {
    "country": "US",
    "name": "Webberville",
    "lat": "42.66698",
    "lng": "-84.17413"
  },
  {
    "country": "US",
    "name": "West Branch",
    "lat": "44.27641",
    "lng": "-84.23861"
  },
  {
    "country": "US",
    "name": "West Ishpeming",
    "lat": "46.48355",
    "lng": "-87.70097"
  },
  {
    "country": "US",
    "name": "West Monroe",
    "lat": "41.91393",
    "lng": "-83.4316"
  },
  {
    "country": "US",
    "name": "Westland",
    "lat": "42.3242",
    "lng": "-83.40021"
  },
  {
    "country": "US",
    "name": "Westwood",
    "lat": "42.30282",
    "lng": "-85.63362"
  },
  {
    "country": "US",
    "name": "White Cloud",
    "lat": "43.5503",
    "lng": "-85.772"
  },
  {
    "country": "US",
    "name": "White Pigeon",
    "lat": "41.79811",
    "lng": "-85.64332"
  },
  {
    "country": "US",
    "name": "Whitehall",
    "lat": "43.41001",
    "lng": "-86.34868"
  },
  {
    "country": "US",
    "name": "Whitmore Lake",
    "lat": "42.4397",
    "lng": "-83.7453"
  },
  {
    "country": "US",
    "name": "Williamston",
    "lat": "42.68892",
    "lng": "-84.28302"
  },
  {
    "country": "US",
    "name": "Wixom",
    "lat": "42.52476",
    "lng": "-83.53633"
  },
  {
    "country": "US",
    "name": "Wolf Lake",
    "lat": "43.25474",
    "lng": "-86.10978"
  },
  {
    "country": "US",
    "name": "Wolverine Lake",
    "lat": "42.5567",
    "lng": "-83.47383"
  },
  {
    "country": "US",
    "name": "Woodhaven",
    "lat": "42.13893",
    "lng": "-83.2416"
  },
  {
    "country": "US",
    "name": "Woodland Beach",
    "lat": "41.94005",
    "lng": "-83.31326"
  },
  {
    "country": "US",
    "name": "Wyandotte",
    "lat": "42.21421",
    "lng": "-83.14992"
  },
  {
    "country": "US",
    "name": "Wyoming",
    "lat": "42.91336",
    "lng": "-85.70531"
  },
  {
    "country": "US",
    "name": "Yale",
    "lat": "43.13003",
    "lng": "-82.79826"
  },
  {
    "country": "US",
    "name": "Ypsilanti",
    "lat": "42.24115",
    "lng": "-83.61299"
  },
  {
    "country": "US",
    "name": "Zeeland",
    "lat": "42.81252",
    "lng": "-86.01865"
  },
  {
    "country": "US",
    "name": "Zilwaukee",
    "lat": "43.47641",
    "lng": "-83.92053"
  },
  {
    "country": "US",
    "name": "Ada",
    "lat": "47.29969",
    "lng": "-96.51535"
  },
  {
    "country": "US",
    "name": "Adrian",
    "lat": "43.63497",
    "lng": "-95.9328"
  },
  {
    "country": "US",
    "name": "Afton",
    "lat": "44.90275",
    "lng": "-92.78354"
  },
  {
    "country": "US",
    "name": "Aitkin",
    "lat": "46.53301",
    "lng": "-93.71025"
  },
  {
    "country": "US",
    "name": "Albany",
    "lat": "45.62996",
    "lng": "-94.57"
  },
  {
    "country": "US",
    "name": "Albert Lea",
    "lat": "43.64801",
    "lng": "-93.36827"
  },
  {
    "country": "US",
    "name": "Albertville",
    "lat": "45.23774",
    "lng": "-93.65441"
  },
  {
    "country": "US",
    "name": "Alexandria",
    "lat": "45.88524",
    "lng": "-95.37754"
  },
  {
    "country": "US",
    "name": "Andover",
    "lat": "45.2333",
    "lng": "-93.29134"
  },
  {
    "country": "US",
    "name": "Anoka",
    "lat": "45.19774",
    "lng": "-93.38718"
  },
  {
    "country": "US",
    "name": "Annandale",
    "lat": "45.26274",
    "lng": "-94.12443"
  },
  {
    "country": "US",
    "name": "Apple Valley",
    "lat": "44.73191",
    "lng": "-93.21772"
  },
  {
    "country": "US",
    "name": "Appleton",
    "lat": "45.19691",
    "lng": "-96.01977"
  },
  {
    "country": "US",
    "name": "Arden Hills",
    "lat": "45.05024",
    "lng": "-93.15661"
  },
  {
    "country": "US",
    "name": "Arlington",
    "lat": "44.6083",
    "lng": "-94.08053"
  },
  {
    "country": "US",
    "name": "Arnold",
    "lat": "46.88022",
    "lng": "-92.09047"
  },
  {
    "country": "US",
    "name": "Atwater",
    "lat": "45.13885",
    "lng": "-94.77806"
  },
  {
    "country": "US",
    "name": "Aurora",
    "lat": "47.52993",
    "lng": "-92.23712"
  },
  {
    "country": "US",
    "name": "Austin",
    "lat": "43.66663",
    "lng": "-92.97464"
  },
  {
    "country": "US",
    "name": "Avon",
    "lat": "45.60913",
    "lng": "-94.45167"
  },
  {
    "country": "US",
    "name": "Babbitt",
    "lat": "47.70853",
    "lng": "-91.9446"
  },
  {
    "country": "US",
    "name": "Bagley",
    "lat": "47.52162",
    "lng": "-95.39835"
  },
  {
    "country": "US",
    "name": "Barnesville",
    "lat": "46.65218",
    "lng": "-96.41979"
  },
  {
    "country": "US",
    "name": "Baudette",
    "lat": "48.71247",
    "lng": "-94.59993"
  },
  {
    "country": "US",
    "name": "Baxter",
    "lat": "46.3433",
    "lng": "-94.28667"
  },
  {
    "country": "US",
    "name": "Bayport",
    "lat": "45.02136",
    "lng": "-92.78104"
  },
  {
    "country": "US",
    "name": "Becker",
    "lat": "45.3933",
    "lng": "-93.87692"
  },
  {
    "country": "US",
    "name": "Belle Plaine",
    "lat": "44.62274",
    "lng": "-93.76857"
  },
  {
    "country": "US",
    "name": "Bemidji",
    "lat": "47.47356",
    "lng": "-94.88028"
  },
  {
    "country": "US",
    "name": "Benson",
    "lat": "45.31496",
    "lng": "-95.60003"
  },
  {
    "country": "US",
    "name": "Big Lake",
    "lat": "45.33246",
    "lng": "-93.74608"
  },
  {
    "country": "US",
    "name": "Birchwood",
    "lat": "45.06108",
    "lng": "-92.97605"
  },
  {
    "country": "US",
    "name": "Blaine",
    "lat": "45.1608",
    "lng": "-93.23495"
  },
  {
    "country": "US",
    "name": "Blooming Prairie",
    "lat": "43.86663",
    "lng": "-93.05103"
  },
  {
    "country": "US",
    "name": "Bloomington",
    "lat": "44.8408",
    "lng": "-93.29828"
  },
  {
    "country": "US",
    "name": "Blue Earth",
    "lat": "43.63746",
    "lng": "-94.10218"
  },
  {
    "country": "US",
    "name": "Braham",
    "lat": "45.72274",
    "lng": "-93.17078"
  },
  {
    "country": "US",
    "name": "Brainerd",
    "lat": "46.35802",
    "lng": "-94.20083"
  },
  {
    "country": "US",
    "name": "Branch",
    "lat": "45.48524",
    "lng": "-92.96188"
  },
  {
    "country": "US",
    "name": "Breckenridge",
    "lat": "46.26357",
    "lng": "-96.58813"
  },
  {
    "country": "US",
    "name": "Breezy Point",
    "lat": "46.59001",
    "lng": "-94.21982"
  },
  {
    "country": "US",
    "name": "Brooklyn Center",
    "lat": "45.07608",
    "lng": "-93.33273"
  },
  {
    "country": "US",
    "name": "Brooklyn Park",
    "lat": "45.09413",
    "lng": "-93.35634"
  },
  {
    "country": "US",
    "name": "Buffalo",
    "lat": "45.17191",
    "lng": "-93.87469"
  },
  {
    "country": "US",
    "name": "Burnsville",
    "lat": "44.76774",
    "lng": "-93.27772"
  },
  {
    "country": "US",
    "name": "Byron",
    "lat": "44.03274",
    "lng": "-92.64546"
  },
  {
    "country": "US",
    "name": "Caledonia",
    "lat": "43.63469",
    "lng": "-91.49681"
  },
  {
    "country": "US",
    "name": "Cambridge",
    "lat": "45.57274",
    "lng": "-93.22439"
  },
  {
    "country": "US",
    "name": "Canby",
    "lat": "44.70885",
    "lng": "-96.27643"
  },
  {
    "country": "US",
    "name": "Cannon Falls",
    "lat": "44.50691",
    "lng": "-92.90548"
  },
  {
    "country": "US",
    "name": "Carlton",
    "lat": "46.66383",
    "lng": "-92.42491"
  },
  {
    "country": "US",
    "name": "Carver",
    "lat": "44.76357",
    "lng": "-93.62579"
  },
  {
    "country": "US",
    "name": "Center City",
    "lat": "45.39385",
    "lng": "-92.8166"
  },
  {
    "country": "US",
    "name": "Centerville",
    "lat": "45.16302",
    "lng": "-93.05578"
  },
  {
    "country": "US",
    "name": "Champlin",
    "lat": "45.18885",
    "lng": "-93.39745"
  },
  {
    "country": "US",
    "name": "Chanhassen",
    "lat": "44.86219",
    "lng": "-93.53079"
  },
  {
    "country": "US",
    "name": "Chaska",
    "lat": "44.78941",
    "lng": "-93.60218"
  },
  {
    "country": "US",
    "name": "Chatfield",
    "lat": "43.84552",
    "lng": "-92.18905"
  },
  {
    "country": "US",
    "name": "Chisago City",
    "lat": "45.37358",
    "lng": "-92.88994"
  },
  {
    "country": "US",
    "name": "Chisholm",
    "lat": "47.4891",
    "lng": "-92.8838"
  },
  {
    "country": "US",
    "name": "Circle Pines",
    "lat": "45.14858",
    "lng": "-93.15161"
  },
  {
    "country": "US",
    "name": "Clara City",
    "lat": "44.95496",
    "lng": "-95.3664"
  },
  {
    "country": "US",
    "name": "Clearwater",
    "lat": "45.41941",
    "lng": "-94.04887"
  },
  {
    "country": "US",
    "name": "Cloquet",
    "lat": "46.72161",
    "lng": "-92.45936"
  },
  {
    "country": "US",
    "name": "Cohasset",
    "lat": "47.26356",
    "lng": "-93.62022"
  },
  {
    "country": "US",
    "name": "Cokato",
    "lat": "45.0758",
    "lng": "-94.18998"
  },
  {
    "country": "US",
    "name": "Coleraine",
    "lat": "47.28883",
    "lng": "-93.42771"
  },
  {
    "country": "US",
    "name": "Collegeville",
    "lat": "45.59441",
    "lng": "-94.36305"
  },
  {
    "country": "US",
    "name": "Cold Spring",
    "lat": "45.4558",
    "lng": "-94.42888"
  },
  {
    "country": "US",
    "name": "Cologne",
    "lat": "44.77163",
    "lng": "-93.78135"
  },
  {
    "country": "US",
    "name": "Columbia Heights",
    "lat": "45.0408",
    "lng": "-93.263"
  },
  {
    "country": "US",
    "name": "Coon Rapids",
    "lat": "45.11997",
    "lng": "-93.28773"
  },
  {
    "country": "US",
    "name": "Corcoran",
    "lat": "45.09524",
    "lng": "-93.54746"
  },
  {
    "country": "US",
    "name": "Cottage Grove",
    "lat": "44.82774",
    "lng": "-92.94382"
  },
  {
    "country": "US",
    "name": "Cottonwood",
    "lat": "44.60885",
    "lng": "-95.67419"
  },
  {
    "country": "US",
    "name": "Crookston",
    "lat": "47.77414",
    "lng": "-96.60812"
  },
  {
    "country": "US",
    "name": "Crosby",
    "lat": "46.48218",
    "lng": "-93.95776"
  },
  {
    "country": "US",
    "name": "Cross Lake",
    "lat": "46.65941",
    "lng": "-94.11387"
  },
  {
    "country": "US",
    "name": "Crystal",
    "lat": "45.03274",
    "lng": "-93.36023"
  },
  {
    "country": "US",
    "name": "Dassel",
    "lat": "45.08163",
    "lng": "-94.30693"
  },
  {
    "country": "US",
    "name": "Dawson",
    "lat": "44.93274",
    "lng": "-96.05448"
  },
  {
    "country": "US",
    "name": "Dayton",
    "lat": "45.24385",
    "lng": "-93.51496"
  },
  {
    "country": "US",
    "name": "Deephaven",
    "lat": "44.92969",
    "lng": "-93.52246"
  },
  {
    "country": "US",
    "name": "Delano",
    "lat": "45.04191",
    "lng": "-93.78913"
  },
  {
    "country": "US",
    "name": "Dellwood",
    "lat": "45.08997",
    "lng": "-92.97244"
  },
  {
    "country": "US",
    "name": "Detroit Lakes",
    "lat": "46.81718",
    "lng": "-95.84533"
  },
  {
    "country": "US",
    "name": "Dilworth",
    "lat": "46.87663",
    "lng": "-96.70341"
  },
  {
    "country": "US",
    "name": "Dodge Center",
    "lat": "44.02802",
    "lng": "-92.85464"
  },
  {
    "country": "US",
    "name": "Duluth",
    "lat": "46.78327",
    "lng": "-92.10658"
  },
  {
    "country": "US",
    "name": "Dundas",
    "lat": "44.42941",
    "lng": "-93.20188"
  },
  {
    "country": "US",
    "name": "Eagan",
    "lat": "44.80413",
    "lng": "-93.16689"
  },
  {
    "country": "US",
    "name": "Eagle Lake",
    "lat": "44.16497",
    "lng": "-93.88134"
  },
  {
    "country": "US",
    "name": "East Bethel",
    "lat": "45.31941",
    "lng": "-93.20245"
  },
  {
    "country": "US",
    "name": "East Grand Forks",
    "lat": "47.92998",
    "lng": "-97.02452"
  },
  {
    "country": "US",
    "name": "East Gull Lake",
    "lat": "46.40802",
    "lng": "-94.35584"
  },
  {
    "country": "US",
    "name": "Eden Prairie",
    "lat": "44.85469",
    "lng": "-93.47079"
  },
  {
    "country": "US",
    "name": "Eden Valley",
    "lat": "45.32607",
    "lng": "-94.54611"
  },
  {
    "country": "US",
    "name": "Edgerton",
    "lat": "43.87247",
    "lng": "-96.12864"
  },
  {
    "country": "US",
    "name": "Edina",
    "lat": "44.88969",
    "lng": "-93.34995"
  },
  {
    "country": "US",
    "name": "Elbow Lake",
    "lat": "45.99413",
    "lng": "-95.97672"
  },
  {
    "country": "US",
    "name": "Elgin",
    "lat": "44.13024",
    "lng": "-92.25156"
  },
  {
    "country": "US",
    "name": "Elk River",
    "lat": "45.30385",
    "lng": "-93.56718"
  },
  {
    "country": "US",
    "name": "Ely",
    "lat": "47.90324",
    "lng": "-91.86709"
  },
  {
    "country": "US",
    "name": "Esko",
    "lat": "46.70578",
    "lng": "-92.36325"
  },
  {
    "country": "US",
    "name": "Eveleth",
    "lat": "47.46243",
    "lng": "-92.53991"
  },
  {
    "country": "US",
    "name": "Excelsior",
    "lat": "44.9033",
    "lng": "-93.56635"
  },
  {
    "country": "US",
    "name": "Eyota",
    "lat": "43.9883",
    "lng": "-92.2285"
  },
  {
    "country": "US",
    "name": "Fairfax",
    "lat": "44.52913",
    "lng": "-94.72082"
  },
  {
    "country": "US",
    "name": "Fairmont",
    "lat": "43.65218",
    "lng": "-94.46108"
  },
  {
    "country": "US",
    "name": "Falcon Heights",
    "lat": "44.99163",
    "lng": "-93.16633"
  },
  {
    "country": "US",
    "name": "Faribault",
    "lat": "44.29496",
    "lng": "-93.26883"
  },
  {
    "country": "US",
    "name": "Farmington",
    "lat": "44.64024",
    "lng": "-93.14355"
  },
  {
    "country": "US",
    "name": "Fergus Falls",
    "lat": "46.28302",
    "lng": "-96.07756"
  },
  {
    "country": "US",
    "name": "Foley",
    "lat": "45.66469",
    "lng": "-93.9097"
  },
  {
    "country": "US",
    "name": "Forest Lake",
    "lat": "45.27886",
    "lng": "-92.98522"
  },
  {
    "country": "US",
    "name": "Fosston",
    "lat": "47.57635",
    "lng": "-95.75141"
  },
  {
    "country": "US",
    "name": "Frazee",
    "lat": "46.72801",
    "lng": "-95.70088"
  },
  {
    "country": "US",
    "name": "Fridley",
    "lat": "45.08608",
    "lng": "-93.26328"
  },
  {
    "country": "US",
    "name": "Fulda",
    "lat": "43.87052",
    "lng": "-95.60029"
  },
  {
    "country": "US",
    "name": "Gaylord",
    "lat": "44.55302",
    "lng": "-94.22053"
  },
  {
    "country": "US",
    "name": "Gilbert",
    "lat": "47.48882",
    "lng": "-92.46491"
  },
  {
    "country": "US",
    "name": "Glencoe",
    "lat": "44.76913",
    "lng": "-94.15164"
  },
  {
    "country": "US",
    "name": "Glenwood",
    "lat": "45.65024",
    "lng": "-95.38976"
  },
  {
    "country": "US",
    "name": "Glyndon",
    "lat": "46.87524",
    "lng": "-96.57896"
  },
  {
    "country": "US",
    "name": "Golden Valley",
    "lat": "45.00969",
    "lng": "-93.34912"
  },
  {
    "country": "US",
    "name": "Goodhue",
    "lat": "44.40052",
    "lng": "-92.6238"
  },
  {
    "country": "US",
    "name": "Goodview",
    "lat": "44.06246",
    "lng": "-91.69571"
  },
  {
    "country": "US",
    "name": "Grand Marais",
    "lat": "47.75045",
    "lng": "-90.33427"
  },
  {
    "country": "US",
    "name": "Grand Meadow",
    "lat": "43.7058",
    "lng": "-92.57212"
  },
  {
    "country": "US",
    "name": "Grand Rapids",
    "lat": "47.23717",
    "lng": "-93.53021"
  },
  {
    "country": "US",
    "name": "Granite Falls",
    "lat": "44.80996",
    "lng": "-95.54558"
  },
  {
    "country": "US",
    "name": "Grant",
    "lat": "45.08441",
    "lng": "-92.91049"
  },
  {
    "country": "US",
    "name": "Greenfield",
    "lat": "45.1033",
    "lng": "-93.69135"
  },
  {
    "country": "US",
    "name": "Hallock",
    "lat": "48.77443",
    "lng": "-96.94645"
  },
  {
    "country": "US",
    "name": "Ham Lake",
    "lat": "45.25024",
    "lng": "-93.24995"
  },
  {
    "country": "US",
    "name": "Hanover",
    "lat": "45.1558",
    "lng": "-93.66635"
  },
  {
    "country": "US",
    "name": "Harris",
    "lat": "45.58635",
    "lng": "-92.97466"
  },
  {
    "country": "US",
    "name": "Hastings",
    "lat": "44.7433",
    "lng": "-92.85243"
  },
  {
    "country": "US",
    "name": "Hawley",
    "lat": "46.88079",
    "lng": "-96.31673"
  },
  {
    "country": "US",
    "name": "Hayfield",
    "lat": "43.89052",
    "lng": "-92.84769"
  },
  {
    "country": "US",
    "name": "Hector",
    "lat": "44.74385",
    "lng": "-94.71555"
  },
  {
    "country": "US",
    "name": "Hermantown",
    "lat": "46.80689",
    "lng": "-92.23825"
  },
  {
    "country": "US",
    "name": "Hibbing",
    "lat": "47.42715",
    "lng": "-92.93769"
  },
  {
    "country": "US",
    "name": "Hinckley",
    "lat": "46.01134",
    "lng": "-92.94437"
  },
  {
    "country": "US",
    "name": "Hopkins",
    "lat": "44.92496",
    "lng": "-93.46273"
  },
  {
    "country": "US",
    "name": "Howard Lake",
    "lat": "45.0608",
    "lng": "-94.07331"
  },
  {
    "country": "US",
    "name": "Hoyt Lakes",
    "lat": "47.51965",
    "lng": "-92.13851"
  },
  {
    "country": "US",
    "name": "Hugo",
    "lat": "45.15997",
    "lng": "-92.99327"
  },
  {
    "country": "US",
    "name": "Hutchinson",
    "lat": "44.88774",
    "lng": "-94.36971"
  },
  {
    "country": "US",
    "name": "Independence",
    "lat": "45.02524",
    "lng": "-93.70746"
  },
  {
    "country": "US",
    "name": "International Falls",
    "lat": "48.60105",
    "lng": "-93.41098"
  },
  {
    "country": "US",
    "name": "Inver Grove Heights",
    "lat": "44.84802",
    "lng": "-93.04272"
  },
  {
    "country": "US",
    "name": "Isanti",
    "lat": "45.49024",
    "lng": "-93.24773"
  },
  {
    "country": "US",
    "name": "Ivanhoe",
    "lat": "44.4633",
    "lng": "-96.24726"
  },
  {
    "country": "US",
    "name": "Jackson",
    "lat": "43.62079",
    "lng": "-94.9886"
  },
  {
    "country": "US",
    "name": "Janesville",
    "lat": "44.11608",
    "lng": "-93.708"
  },
  {
    "country": "US",
    "name": "Jordan",
    "lat": "44.66691",
    "lng": "-93.6269"
  },
  {
    "country": "US",
    "name": "Kasson",
    "lat": "44.02996",
    "lng": "-92.75074"
  },
  {
    "country": "US",
    "name": "Keewatin",
    "lat": "47.39966",
    "lng": "-93.07242"
  },
  {
    "country": "US",
    "name": "Kenyon",
    "lat": "44.27219",
    "lng": "-92.98548"
  },
  {
    "country": "US",
    "name": "La Crescent",
    "lat": "43.82802",
    "lng": "-91.30403"
  },
  {
    "country": "US",
    "name": "Lake City",
    "lat": "44.44968",
    "lng": "-92.2682"
  },
  {
    "country": "US",
    "name": "Lake Crystal",
    "lat": "44.1058",
    "lng": "-94.21885"
  },
  {
    "country": "US",
    "name": "Lake Elmo",
    "lat": "44.9958",
    "lng": "-92.87938"
  },
  {
    "country": "US",
    "name": "Zimmerman",
    "lat": "45.4433",
    "lng": "-93.58996"
  },
  {
    "country": "US",
    "name": "Lake Saint Croix Beach",
    "lat": "44.9208",
    "lng": "-92.76687"
  },
  {
    "country": "US",
    "name": "Lake Shore",
    "lat": "46.48552",
    "lng": "-94.36056"
  },
  {
    "country": "US",
    "name": "Lakefield",
    "lat": "43.67746",
    "lng": "-95.17166"
  },
  {
    "country": "US",
    "name": "Lakeland",
    "lat": "44.95636",
    "lng": "-92.76576"
  },
  {
    "country": "US",
    "name": "Lakeville",
    "lat": "44.64969",
    "lng": "-93.24272"
  },
  {
    "country": "US",
    "name": "Lauderdale",
    "lat": "44.99858",
    "lng": "-93.20578"
  },
  {
    "country": "US",
    "name": "Le Center",
    "lat": "44.38941",
    "lng": "-93.73023"
  },
  {
    "country": "US",
    "name": "Le Sueur",
    "lat": "44.46135",
    "lng": "-93.91524"
  },
  {
    "country": "US",
    "name": "Lester Prairie",
    "lat": "44.88385",
    "lng": "-94.04164"
  },
  {
    "country": "US",
    "name": "Lewiston",
    "lat": "43.98441",
    "lng": "-91.86932"
  },
  {
    "country": "US",
    "name": "Lexington",
    "lat": "45.14247",
    "lng": "-93.16328"
  },
  {
    "country": "US",
    "name": "Lindstrom",
    "lat": "45.38941",
    "lng": "-92.84799"
  },
  {
    "country": "US",
    "name": "Lino Lakes",
    "lat": "45.16024",
    "lng": "-93.08883"
  },
  {
    "country": "US",
    "name": "Litchfield",
    "lat": "45.12718",
    "lng": "-94.52805"
  },
  {
    "country": "US",
    "name": "Little Canada",
    "lat": "45.02691",
    "lng": "-93.08772"
  },
  {
    "country": "US",
    "name": "Little Falls",
    "lat": "45.97635",
    "lng": "-94.3625"
  },
  {
    "country": "US",
    "name": "Little Rock",
    "lat": "47.86801",
    "lng": "-95.11055"
  },
  {
    "country": "US",
    "name": "Long Lake",
    "lat": "44.98663",
    "lng": "-93.57162"
  },
  {
    "country": "US",
    "name": "Long Prairie",
    "lat": "45.97469",
    "lng": "-94.86558"
  },
  {
    "country": "US",
    "name": "Lonsdale",
    "lat": "44.48024",
    "lng": "-93.42856"
  },
  {
    "country": "US",
    "name": "Luverne",
    "lat": "43.65414",
    "lng": "-96.21281"
  },
  {
    "country": "US",
    "name": "Madelia",
    "lat": "44.05079",
    "lng": "-94.4183"
  },
  {
    "country": "US",
    "name": "Madison",
    "lat": "45.00968",
    "lng": "-96.19588"
  },
  {
    "country": "US",
    "name": "Madison Lake",
    "lat": "44.20441",
    "lng": "-93.81551"
  },
  {
    "country": "US",
    "name": "Mahnomen",
    "lat": "47.31524",
    "lng": "-95.96865"
  },
  {
    "country": "US",
    "name": "Mahtomedi",
    "lat": "45.06969",
    "lng": "-92.9516"
  },
  {
    "country": "US",
    "name": "Mankato",
    "lat": "44.15906",
    "lng": "-94.00915"
  },
  {
    "country": "US",
    "name": "Mantorville",
    "lat": "44.06913",
    "lng": "-92.75575"
  },
  {
    "country": "US",
    "name": "Maple Grove",
    "lat": "45.07246",
    "lng": "-93.45579"
  },
  {
    "country": "US",
    "name": "Maple Lake",
    "lat": "45.22913",
    "lng": "-94.00192"
  },
  {
    "country": "US",
    "name": "Maple Plain",
    "lat": "45.00719",
    "lng": "-93.65579"
  },
  {
    "country": "US",
    "name": "Mapleton",
    "lat": "43.92885",
    "lng": "-93.95606"
  },
  {
    "country": "US",
    "name": "Maplewood",
    "lat": "44.95302",
    "lng": "-92.99522"
  },
  {
    "country": "US",
    "name": "Marshall",
    "lat": "44.4469",
    "lng": "-95.78835"
  },
  {
    "country": "US",
    "name": "Mayer",
    "lat": "44.88496",
    "lng": "-93.88775"
  },
  {
    "country": "US",
    "name": "Medford",
    "lat": "44.17413",
    "lng": "-93.24632"
  },
  {
    "country": "US",
    "name": "Medina",
    "lat": "45.03524",
    "lng": "-93.58246"
  },
  {
    "country": "US",
    "name": "Melrose",
    "lat": "45.67469",
    "lng": "-94.80752"
  },
  {
    "country": "US",
    "name": "Menahga",
    "lat": "46.75385",
    "lng": "-95.09808"
  },
  {
    "country": "US",
    "name": "Mendota Heights",
    "lat": "44.88358",
    "lng": "-93.13827"
  },
  {
    "country": "US",
    "name": "Milaca",
    "lat": "45.7558",
    "lng": "-93.65441"
  },
  {
    "country": "US",
    "name": "Minneapolis",
    "lat": "44.97997",
    "lng": "-93.26384"
  },
  {
    "country": "US",
    "name": "Minneota",
    "lat": "44.55885",
    "lng": "-95.98559"
  },
  {
    "country": "US",
    "name": "Minnetonka",
    "lat": "44.9133",
    "lng": "-93.50329"
  },
  {
    "country": "US",
    "name": "Minnetonka Mills",
    "lat": "44.94107",
    "lng": "-93.4419"
  },
  {
    "country": "US",
    "name": "Minnetrista",
    "lat": "44.9383",
    "lng": "-93.71774"
  },
  {
    "country": "US",
    "name": "Montevideo",
    "lat": "44.94803",
    "lng": "-95.71701"
  },
  {
    "country": "US",
    "name": "Montgomery",
    "lat": "44.43885",
    "lng": "-93.58134"
  },
  {
    "country": "US",
    "name": "Monticello",
    "lat": "45.30552",
    "lng": "-93.79414"
  },
  {
    "country": "US",
    "name": "Montrose",
    "lat": "45.06496",
    "lng": "-93.91108"
  },
  {
    "country": "US",
    "name": "Moorhead",
    "lat": "46.87386",
    "lng": "-96.76951"
  },
  {
    "country": "US",
    "name": "Moose Lake",
    "lat": "46.45411",
    "lng": "-92.76187"
  },
  {
    "country": "US",
    "name": "Mora",
    "lat": "45.8769",
    "lng": "-93.29384"
  },
  {
    "country": "US",
    "name": "Morris",
    "lat": "45.58607",
    "lng": "-95.91394"
  },
  {
    "country": "US",
    "name": "Mound",
    "lat": "44.93663",
    "lng": "-93.66607"
  },
  {
    "country": "US",
    "name": "Mounds View",
    "lat": "45.10497",
    "lng": "-93.20856"
  },
  {
    "country": "US",
    "name": "Mountain Iron",
    "lat": "47.53243",
    "lng": "-92.62351"
  },
  {
    "country": "US",
    "name": "Mountain Lake",
    "lat": "43.93885",
    "lng": "-94.92971"
  },
  {
    "country": "US",
    "name": "New Brighton",
    "lat": "45.06552",
    "lng": "-93.20189"
  },
  {
    "country": "US",
    "name": "New Hope",
    "lat": "45.03802",
    "lng": "-93.38662"
  },
  {
    "country": "US",
    "name": "New London",
    "lat": "45.30108",
    "lng": "-94.94418"
  },
  {
    "country": "US",
    "name": "New Prague",
    "lat": "44.5433",
    "lng": "-93.57607"
  },
  {
    "country": "US",
    "name": "New Richland",
    "lat": "43.89385",
    "lng": "-93.49383"
  },
  {
    "country": "US",
    "name": "New Ulm",
    "lat": "44.31246",
    "lng": "-94.46053"
  },
  {
    "country": "US",
    "name": "New York Mills",
    "lat": "46.51802",
    "lng": "-95.37615"
  },
  {
    "country": "US",
    "name": "Newport",
    "lat": "44.86636",
    "lng": "-93.00049"
  },
  {
    "country": "US",
    "name": "Nicollet",
    "lat": "44.27608",
    "lng": "-94.18746"
  },
  {
    "country": "US",
    "name": "Nisswa",
    "lat": "46.52052",
    "lng": "-94.28861"
  },
  {
    "country": "US",
    "name": "North Branch",
    "lat": "45.51135",
    "lng": "-92.98022"
  },
  {
    "country": "US",
    "name": "North Mankato",
    "lat": "44.1733",
    "lng": "-94.03385"
  },
  {
    "country": "US",
    "name": "North Oaks",
    "lat": "45.10274",
    "lng": "-93.07911"
  },
  {
    "country": "US",
    "name": "North Saint Paul",
    "lat": "45.01247",
    "lng": "-92.99188"
  },
  {
    "country": "US",
    "name": "Northfield",
    "lat": "44.4583",
    "lng": "-93.1616"
  },
  {
    "country": "US",
    "name": "Norwood (historical)",
    "lat": "44.76802",
    "lng": "-93.92747"
  },
  {
    "country": "US",
    "name": "Norwood Young America",
    "lat": "44.77357",
    "lng": "-93.92163"
  },
  {
    "country": "US",
    "name": "Oak Grove",
    "lat": "45.3408",
    "lng": "-93.3269"
  },
  {
    "country": "US",
    "name": "Oak Park Heights",
    "lat": "45.03136",
    "lng": "-92.79298"
  },
  {
    "country": "US",
    "name": "Oakdale",
    "lat": "44.96302",
    "lng": "-92.96494"
  },
  {
    "country": "US",
    "name": "Oakport",
    "lat": "46.93191",
    "lng": "-96.77897"
  },
  {
    "country": "US",
    "name": "Olivia",
    "lat": "44.77635",
    "lng": "-94.98972"
  },
  {
    "country": "US",
    "name": "Orono",
    "lat": "44.97135",
    "lng": "-93.6044"
  },
  {
    "country": "US",
    "name": "Oronoco",
    "lat": "44.16608",
    "lng": "-92.53491"
  },
  {
    "country": "US",
    "name": "Ortonville",
    "lat": "45.30469",
    "lng": "-96.44478"
  },
  {
    "country": "US",
    "name": "Osakis",
    "lat": "45.86691",
    "lng": "-95.15225"
  },
  {
    "country": "US",
    "name": "Osseo",
    "lat": "45.11941",
    "lng": "-93.40245"
  },
  {
    "country": "US",
    "name": "Otsego",
    "lat": "45.27413",
    "lng": "-93.59135"
  },
  {
    "country": "US",
    "name": "Owatonna",
    "lat": "44.08385",
    "lng": "-93.22604"
  },
  {
    "country": "US",
    "name": "Park Rapids",
    "lat": "46.92218",
    "lng": "-95.05863"
  },
  {
    "country": "US",
    "name": "Parkers Prairie",
    "lat": "46.15302",
    "lng": "-95.32892"
  },
  {
    "country": "US",
    "name": "Parkville",
    "lat": "47.53104",
    "lng": "-92.57907"
  },
  {
    "country": "US",
    "name": "Paynesville",
    "lat": "45.38052",
    "lng": "-94.71195"
  },
  {
    "country": "US",
    "name": "Pelican Rapids",
    "lat": "46.57079",
    "lng": "-96.08311"
  },
  {
    "country": "US",
    "name": "Pequot Lakes",
    "lat": "46.60302",
    "lng": "-94.30944"
  },
  {
    "country": "US",
    "name": "Perham",
    "lat": "46.5944",
    "lng": "-95.57254"
  },
  {
    "country": "US",
    "name": "Pierz",
    "lat": "45.98163",
    "lng": "-94.10471"
  },
  {
    "country": "US",
    "name": "Pine City",
    "lat": "45.82607",
    "lng": "-92.96854"
  },
  {
    "country": "US",
    "name": "Pine Island",
    "lat": "44.20135",
    "lng": "-92.6463"
  },
  {
    "country": "US",
    "name": "Pipestone",
    "lat": "44.00053",
    "lng": "-96.31753"
  },
  {
    "country": "US",
    "name": "Plainview",
    "lat": "44.16497",
    "lng": "-92.17156"
  },
  {
    "country": "US",
    "name": "Plymouth",
    "lat": "45.01052",
    "lng": "-93.45551"
  },
  {
    "country": "US",
    "name": "Preston",
    "lat": "43.67024",
    "lng": "-92.08322"
  },
  {
    "country": "US",
    "name": "Princeton",
    "lat": "45.56997",
    "lng": "-93.58163"
  },
  {
    "country": "US",
    "name": "Prior Lake",
    "lat": "44.7133",
    "lng": "-93.42273"
  },
  {
    "country": "US",
    "name": "Proctor",
    "lat": "46.74716",
    "lng": "-92.22547"
  },
  {
    "country": "US",
    "name": "Ramsey",
    "lat": "45.2611",
    "lng": "-93.45"
  },
  {
    "country": "US",
    "name": "Red Lake",
    "lat": "47.87635",
    "lng": "-95.01694"
  },
  {
    "country": "US",
    "name": "Red Lake Falls",
    "lat": "47.88219",
    "lng": "-96.27421"
  },
  {
    "country": "US",
    "name": "Red Wing",
    "lat": "44.56247",
    "lng": "-92.5338"
  },
  {
    "country": "US",
    "name": "Redby",
    "lat": "47.87857",
    "lng": "-94.91305"
  },
  {
    "country": "US",
    "name": "Redwood Falls",
    "lat": "44.5394",
    "lng": "-95.11694"
  },
  {
    "country": "US",
    "name": "Renville",
    "lat": "44.78913",
    "lng": "-95.21167"
  },
  {
    "country": "US",
    "name": "Rice",
    "lat": "45.75191",
    "lng": "-94.22027"
  },
  {
    "country": "US",
    "name": "Richfield",
    "lat": "44.8833",
    "lng": "-93.283"
  },
  {
    "country": "US",
    "name": "Richmond",
    "lat": "45.45413",
    "lng": "-94.51833"
  },
  {
    "country": "US",
    "name": "Robbinsdale",
    "lat": "45.03219",
    "lng": "-93.33856"
  },
  {
    "country": "US",
    "name": "Rochester",
    "lat": "44.02163",
    "lng": "-92.4699"
  },
  {
    "country": "US",
    "name": "Rock Creek",
    "lat": "45.75746",
    "lng": "-92.96243"
  },
  {
    "country": "US",
    "name": "Rockford",
    "lat": "45.0883",
    "lng": "-93.73441"
  },
  {
    "country": "US",
    "name": "Rockville",
    "lat": "45.47191",
    "lng": "-94.34083"
  },
  {
    "country": "US",
    "name": "Rogers",
    "lat": "45.18885",
    "lng": "-93.55301"
  },
  {
    "country": "US",
    "name": "Roseau",
    "lat": "48.84609",
    "lng": "-95.76277"
  },
  {
    "country": "US",
    "name": "Rosemount",
    "lat": "44.73941",
    "lng": "-93.12577"
  },
  {
    "country": "US",
    "name": "Roseville",
    "lat": "45.00608",
    "lng": "-93.15661"
  },
  {
    "country": "US",
    "name": "Royalton",
    "lat": "45.82997",
    "lng": "-94.29361"
  },
  {
    "country": "US",
    "name": "Rush City",
    "lat": "45.68551",
    "lng": "-92.96549"
  },
  {
    "country": "US",
    "name": "Rushford",
    "lat": "43.8083",
    "lng": "-91.75293"
  },
  {
    "country": "US",
    "name": "Saint Anthony",
    "lat": "45.02052",
    "lng": "-93.218"
  },
  {
    "country": "US",
    "name": "Saint Augusta",
    "lat": "45.47858",
    "lng": "-94.15415"
  },
  {
    "country": "US",
    "name": "Saint Bonifacius",
    "lat": "44.90552",
    "lng": "-93.74746"
  },
  {
    "country": "US",
    "name": "Saint Charles",
    "lat": "43.96941",
    "lng": "-92.06433"
  },
  {
    "country": "US",
    "name": "Saint Cloud",
    "lat": "45.5608",
    "lng": "-94.16249"
  },
  {
    "country": "US",
    "name": "Saint Francis",
    "lat": "45.38691",
    "lng": "-93.3594"
  },
  {
    "country": "US",
    "name": "Saint James",
    "lat": "43.98246",
    "lng": "-94.62692"
  },
  {
    "country": "US",
    "name": "Saint Joseph",
    "lat": "45.56496",
    "lng": "-94.31833"
  },
  {
    "country": "US",
    "name": "Saint Louis Park",
    "lat": "44.9483",
    "lng": "-93.34801"
  },
  {
    "country": "US",
    "name": "Saint Michael",
    "lat": "45.20996",
    "lng": "-93.66496"
  },
  {
    "country": "US",
    "name": "Saint Paul",
    "lat": "44.94441",
    "lng": "-93.09327"
  },
  {
    "country": "US",
    "name": "Saint Paul Park",
    "lat": "44.84219",
    "lng": "-92.99132"
  },
  {
    "country": "US",
    "name": "Saint Peter",
    "lat": "44.32358",
    "lng": "-93.95801"
  },
  {
    "country": "US",
    "name": "Sandstone",
    "lat": "46.13106",
    "lng": "-92.86742"
  },
  {
    "country": "US",
    "name": "Sartell",
    "lat": "45.62163",
    "lng": "-94.20694"
  },
  {
    "country": "US",
    "name": "Sauk Centre",
    "lat": "45.73747",
    "lng": "-94.95252"
  },
  {
    "country": "US",
    "name": "Sauk Rapids",
    "lat": "45.59191",
    "lng": "-94.1661"
  },
  {
    "country": "US",
    "name": "Savage",
    "lat": "44.77913",
    "lng": "-93.33634"
  },
  {
    "country": "US",
    "name": "Scandia",
    "lat": "45.25358",
    "lng": "-92.80577"
  },
  {
    "country": "US",
    "name": "Shafer",
    "lat": "45.38691",
    "lng": "-92.74771"
  },
  {
    "country": "US",
    "name": "Shakopee",
    "lat": "44.79802",
    "lng": "-93.5269"
  },
  {
    "country": "US",
    "name": "Sherburn",
    "lat": "43.65218",
    "lng": "-94.72692"
  },
  {
    "country": "US",
    "name": "Shoreview",
    "lat": "45.07913",
    "lng": "-93.14717"
  },
  {
    "country": "US",
    "name": "Shorewood",
    "lat": "44.9008",
    "lng": "-93.58912"
  },
  {
    "country": "US",
    "name": "Silver Bay",
    "lat": "47.29436",
    "lng": "-91.25739"
  },
  {
    "country": "US",
    "name": "Slayton",
    "lat": "43.98774",
    "lng": "-95.75585"
  },
  {
    "country": "US",
    "name": "Sleepy Eye",
    "lat": "44.29718",
    "lng": "-94.72415"
  },
  {
    "country": "US",
    "name": "South Saint Paul",
    "lat": "44.89274",
    "lng": "-93.03494"
  },
  {
    "country": "US",
    "name": "Spicer",
    "lat": "45.23302",
    "lng": "-94.94001"
  },
  {
    "country": "US",
    "name": "Spring Grove",
    "lat": "43.56108",
    "lng": "-91.63598"
  },
  {
    "country": "US",
    "name": "Spring Lake Park",
    "lat": "45.10774",
    "lng": "-93.238"
  },
  {
    "country": "US",
    "name": "Spring Park",
    "lat": "44.93524",
    "lng": "-93.63218"
  },
  {
    "country": "US",
    "name": "Spring Valley",
    "lat": "43.68691",
    "lng": "-92.38906"
  },
  {
    "country": "US",
    "name": "Springfield",
    "lat": "44.23885",
    "lng": "-94.97582"
  },
  {
    "country": "US",
    "name": "Saint Augusta",
    "lat": "45.4583",
    "lng": "-94.19804"
  },
  {
    "country": "US",
    "name": "Stacy",
    "lat": "45.39802",
    "lng": "-92.98744"
  },
  {
    "country": "US",
    "name": "Staples",
    "lat": "46.35552",
    "lng": "-94.79224"
  },
  {
    "country": "US",
    "name": "Starbuck",
    "lat": "45.6144",
    "lng": "-95.53115"
  },
  {
    "country": "US",
    "name": "Stewartville",
    "lat": "43.85552",
    "lng": "-92.48851"
  },
  {
    "country": "US",
    "name": "Stillwater",
    "lat": "45.05636",
    "lng": "-92.80604"
  },
  {
    "country": "US",
    "name": "Taylors Falls",
    "lat": "45.40191",
    "lng": "-92.65243"
  },
  {
    "country": "US",
    "name": "Thief River Falls",
    "lat": "48.11914",
    "lng": "-96.18115"
  },
  {
    "country": "US",
    "name": "Tonka Bay",
    "lat": "44.90857",
    "lng": "-93.59301"
  },
  {
    "country": "US",
    "name": "Tracy",
    "lat": "44.23329",
    "lng": "-95.61918"
  },
  {
    "country": "US",
    "name": "Truman",
    "lat": "43.82773",
    "lng": "-94.43719"
  },
  {
    "country": "US",
    "name": "Two Harbors",
    "lat": "47.02271",
    "lng": "-91.67073"
  },
  {
    "country": "US",
    "name": "Tyler",
    "lat": "44.2783",
    "lng": "-96.13475"
  },
  {
    "country": "US",
    "name": "Vadnais Heights",
    "lat": "45.05747",
    "lng": "-93.07383"
  },
  {
    "country": "US",
    "name": "Victoria",
    "lat": "44.85857",
    "lng": "-93.66163"
  },
  {
    "country": "US",
    "name": "Vineland",
    "lat": "46.16357",
    "lng": "-93.75747"
  },
  {
    "country": "US",
    "name": "Virginia",
    "lat": "47.52326",
    "lng": "-92.53657"
  },
  {
    "country": "US",
    "name": "Wabasha",
    "lat": "44.38386",
    "lng": "-92.03294"
  },
  {
    "country": "US",
    "name": "Waconia",
    "lat": "44.8508",
    "lng": "-93.78691"
  },
  {
    "country": "US",
    "name": "Wadena",
    "lat": "46.44246",
    "lng": "-95.13614"
  },
  {
    "country": "US",
    "name": "Waite Park",
    "lat": "45.55719",
    "lng": "-94.22416"
  },
  {
    "country": "US",
    "name": "Walker",
    "lat": "47.10135",
    "lng": "-94.58722"
  },
  {
    "country": "US",
    "name": "Wanamingo",
    "lat": "44.30441",
    "lng": "-92.79047"
  },
  {
    "country": "US",
    "name": "Warren",
    "lat": "48.19664",
    "lng": "-96.77284"
  },
  {
    "country": "US",
    "name": "Warroad",
    "lat": "48.90527",
    "lng": "-95.3144"
  },
  {
    "country": "US",
    "name": "Waseca",
    "lat": "44.07774",
    "lng": "-93.50744"
  },
  {
    "country": "US",
    "name": "Watertown",
    "lat": "44.96357",
    "lng": "-93.84719"
  },
  {
    "country": "US",
    "name": "Waterville",
    "lat": "44.21885",
    "lng": "-93.568"
  },
  {
    "country": "US",
    "name": "Waverly",
    "lat": "45.06663",
    "lng": "-93.96636"
  },
  {
    "country": "US",
    "name": "Wayzata",
    "lat": "44.97413",
    "lng": "-93.50662"
  },
  {
    "country": "US",
    "name": "Wells",
    "lat": "43.74607",
    "lng": "-93.72884"
  },
  {
    "country": "US",
    "name": "West Coon Rapids",
    "lat": "45.15969",
    "lng": "-93.34967"
  },
  {
    "country": "US",
    "name": "West Saint Paul",
    "lat": "44.91608",
    "lng": "-93.10161"
  },
  {
    "country": "US",
    "name": "Wheaton",
    "lat": "45.80441",
    "lng": "-96.49923"
  },
  {
    "country": "US",
    "name": "White Bear Lake",
    "lat": "45.08469",
    "lng": "-93.00994"
  },
  {
    "country": "US",
    "name": "Willmar",
    "lat": "45.12191",
    "lng": "-95.04334"
  },
  {
    "country": "US",
    "name": "Windom",
    "lat": "43.86635",
    "lng": "-95.11694"
  },
  {
    "country": "US",
    "name": "Winnebago",
    "lat": "43.76773",
    "lng": "-94.16579"
  },
  {
    "country": "US",
    "name": "Winona",
    "lat": "44.04996",
    "lng": "-91.63932"
  },
  {
    "country": "US",
    "name": "Winsted",
    "lat": "44.96385",
    "lng": "-94.04747"
  },
  {
    "country": "US",
    "name": "Winthrop",
    "lat": "44.54302",
    "lng": "-94.36637"
  },
  {
    "country": "US",
    "name": "Woodbury",
    "lat": "44.92386",
    "lng": "-92.95938"
  },
  {
    "country": "US",
    "name": "Worthington",
    "lat": "43.61996",
    "lng": "-95.5964"
  },
  {
    "country": "US",
    "name": "Wyoming",
    "lat": "45.33636",
    "lng": "-92.99716"
  },
  {
    "country": "US",
    "name": "Young America (historical)",
    "lat": "44.78274",
    "lng": "-93.91358"
  },
  {
    "country": "US",
    "name": "Zumbrota",
    "lat": "44.29413",
    "lng": "-92.66908"
  },
  {
    "country": "US",
    "name": "Albany",
    "lat": "40.24861",
    "lng": "-94.33107"
  },
  {
    "country": "US",
    "name": "Bethany",
    "lat": "40.26833",
    "lng": "-94.02829"
  },
  {
    "country": "US",
    "name": "Canton",
    "lat": "40.12504",
    "lng": "-91.62516"
  },
  {
    "country": "US",
    "name": "Grant City",
    "lat": "40.48749",
    "lng": "-94.41107"
  },
  {
    "country": "US",
    "name": "Kahoka",
    "lat": "40.42032",
    "lng": "-91.71961"
  },
  {
    "country": "US",
    "name": "King City",
    "lat": "40.05138",
    "lng": "-94.52412"
  },
  {
    "country": "US",
    "name": "Kirksville",
    "lat": "40.19475",
    "lng": "-92.58325"
  },
  {
    "country": "US",
    "name": "La Plata",
    "lat": "40.02337",
    "lng": "-92.49158"
  },
  {
    "country": "US",
    "name": "Lancaster",
    "lat": "40.52086",
    "lng": "-92.52797"
  },
  {
    "country": "US",
    "name": "Maryville",
    "lat": "40.3461",
    "lng": "-94.87247"
  },
  {
    "country": "US",
    "name": "Memphis",
    "lat": "40.45781",
    "lng": "-92.17129"
  },
  {
    "country": "US",
    "name": "Milan",
    "lat": "40.20224",
    "lng": "-93.12521"
  },
  {
    "country": "US",
    "name": "Monticello",
    "lat": "40.11838",
    "lng": "-91.71211"
  },
  {
    "country": "US",
    "name": "Mound City",
    "lat": "40.13111",
    "lng": "-95.23164"
  },
  {
    "country": "US",
    "name": "Princeton",
    "lat": "40.40084",
    "lng": "-93.5805"
  },
  {
    "country": "US",
    "name": "Rock Port",
    "lat": "40.41111",
    "lng": "-95.51693"
  },
  {
    "country": "US",
    "name": "Stanberry",
    "lat": "40.21777",
    "lng": "-94.53829"
  },
  {
    "country": "US",
    "name": "Tarkio",
    "lat": "40.44028",
    "lng": "-95.37776"
  },
  {
    "country": "US",
    "name": "Terre Haute",
    "lat": "40.43946",
    "lng": "-93.2341"
  },
  {
    "country": "US",
    "name": "Trenton",
    "lat": "40.0789",
    "lng": "-93.61661"
  },
  {
    "country": "US",
    "name": "Unionville",
    "lat": "40.47696",
    "lng": "-93.00326"
  },
  {
    "country": "US",
    "name": "Ashley",
    "lat": "46.03414",
    "lng": "-99.3715"
  },
  {
    "country": "US",
    "name": "Belcourt",
    "lat": "48.83917",
    "lng": "-99.74487"
  },
  {
    "country": "US",
    "name": "Cando",
    "lat": "48.48667",
    "lng": "-99.20986"
  },
  {
    "country": "US",
    "name": "Carrington",
    "lat": "47.44972",
    "lng": "-99.12622"
  },
  {
    "country": "US",
    "name": "Casselton",
    "lat": "46.90053",
    "lng": "-97.2112"
  },
  {
    "country": "US",
    "name": "Cavalier",
    "lat": "48.79388",
    "lng": "-97.62231"
  },
  {
    "country": "US",
    "name": "Cooperstown",
    "lat": "47.44444",
    "lng": "-98.12398"
  },
  {
    "country": "US",
    "name": "Devils Lake",
    "lat": "48.11278",
    "lng": "-98.86512"
  },
  {
    "country": "US",
    "name": "Ellendale",
    "lat": "46.00275",
    "lng": "-98.52705"
  },
  {
    "country": "US",
    "name": "Fargo",
    "lat": "46.87719",
    "lng": "-96.7898"
  },
  {
    "country": "US",
    "name": "Fessenden",
    "lat": "47.64917",
    "lng": "-99.62929"
  },
  {
    "country": "US",
    "name": "Finley",
    "lat": "47.51416",
    "lng": "-97.83593"
  },
  {
    "country": "US",
    "name": "Forman",
    "lat": "46.10774",
    "lng": "-97.63649"
  },
  {
    "country": "US",
    "name": "Fort Totten",
    "lat": "47.98",
    "lng": "-98.9929"
  },
  {
    "country": "US",
    "name": "Grafton",
    "lat": "48.41221",
    "lng": "-97.41063"
  },
  {
    "country": "US",
    "name": "Grand Forks",
    "lat": "47.92526",
    "lng": "-97.03285"
  },
  {
    "country": "US",
    "name": "Harvey",
    "lat": "47.76972",
    "lng": "-99.9354"
  },
  {
    "country": "US",
    "name": "Hillsboro",
    "lat": "47.40387",
    "lng": "-97.06203"
  },
  {
    "country": "US",
    "name": "Horace",
    "lat": "46.75886",
    "lng": "-96.9037"
  },
  {
    "country": "US",
    "name": "Jamestown",
    "lat": "46.91054",
    "lng": "-98.70844"
  },
  {
    "country": "US",
    "name": "Lakota",
    "lat": "48.04278",
    "lng": "-98.33621"
  },
  {
    "country": "US",
    "name": "Langdon",
    "lat": "48.76",
    "lng": "-98.36817"
  },
  {
    "country": "US",
    "name": "Larimore",
    "lat": "47.90666",
    "lng": "-97.62675"
  },
  {
    "country": "US",
    "name": "Lisbon",
    "lat": "46.44163",
    "lng": "-97.68121"
  },
  {
    "country": "US",
    "name": "Mayville",
    "lat": "47.49804",
    "lng": "-97.32454"
  },
  {
    "country": "US",
    "name": "Napoleon",
    "lat": "46.50831",
    "lng": "-99.77122"
  },
  {
    "country": "US",
    "name": "Minnewaukan",
    "lat": "48.07139",
    "lng": "-99.25236"
  },
  {
    "country": "US",
    "name": "New Rockford",
    "lat": "47.68",
    "lng": "-99.1379"
  },
  {
    "country": "US",
    "name": "Oakes",
    "lat": "46.13858",
    "lng": "-98.09038"
  },
  {
    "country": "US",
    "name": "Park River",
    "lat": "48.3986",
    "lng": "-97.7412"
  },
  {
    "country": "US",
    "name": "Rolla",
    "lat": "48.85778",
    "lng": "-99.61792"
  },
  {
    "country": "US",
    "name": "Rugby",
    "lat": "48.36889",
    "lng": "-99.99625"
  },
  {
    "country": "US",
    "name": "Sheldon",
    "lat": "46.5858",
    "lng": "-97.4912"
  },
  {
    "country": "US",
    "name": "Shell Valley",
    "lat": "48.79806",
    "lng": "-99.86486"
  },
  {
    "country": "US",
    "name": "Steele",
    "lat": "46.85471",
    "lng": "-99.91594"
  },
  {
    "country": "US",
    "name": "Thompson",
    "lat": "47.77359",
    "lng": "-97.1098"
  },
  {
    "country": "US",
    "name": "Valley City",
    "lat": "46.92331",
    "lng": "-98.00315"
  },
  {
    "country": "US",
    "name": "Wahpeton",
    "lat": "46.26524",
    "lng": "-96.60591"
  },
  {
    "country": "US",
    "name": "West Fargo",
    "lat": "46.87497",
    "lng": "-96.90036"
  },
  {
    "country": "US",
    "name": "Ainsworth",
    "lat": "42.55",
    "lng": "-99.86262"
  },
  {
    "country": "US",
    "name": "Albion",
    "lat": "41.69084",
    "lng": "-98.00367"
  },
  {
    "country": "US",
    "name": "Alma",
    "lat": "40.09751",
    "lng": "-99.36204"
  },
  {
    "country": "US",
    "name": "Arapahoe",
    "lat": "40.30417",
    "lng": "-99.9004"
  },
  {
    "country": "US",
    "name": "Arlington",
    "lat": "41.4525",
    "lng": "-96.35113"
  },
  {
    "country": "US",
    "name": "Ashland",
    "lat": "41.03916",
    "lng": "-96.36835"
  },
  {
    "country": "US",
    "name": "Atkinson",
    "lat": "42.53139",
    "lng": "-98.97815"
  },
  {
    "country": "US",
    "name": "Auburn",
    "lat": "40.39278",
    "lng": "-95.83889"
  },
  {
    "country": "US",
    "name": "Aurora",
    "lat": "40.86723",
    "lng": "-98.00422"
  },
  {
    "country": "US",
    "name": "Bartlett",
    "lat": "41.88529",
    "lng": "-98.5523"
  },
  {
    "country": "US",
    "name": "Bassett",
    "lat": "42.58583",
    "lng": "-99.53789"
  },
  {
    "country": "US",
    "name": "Battle Creek",
    "lat": "41.99945",
    "lng": "-97.59839"
  },
  {
    "country": "US",
    "name": "Beatrice",
    "lat": "40.26806",
    "lng": "-96.74697"
  },
  {
    "country": "US",
    "name": "Beaver City",
    "lat": "40.13751",
    "lng": "-99.82956"
  },
  {
    "country": "US",
    "name": "Bellevue",
    "lat": "41.13667",
    "lng": "-95.89084"
  },
  {
    "country": "US",
    "name": "Bennington",
    "lat": "41.36472",
    "lng": "-96.1578"
  },
  {
    "country": "US",
    "name": "Blair",
    "lat": "41.54444",
    "lng": "-96.12502"
  },
  {
    "country": "US",
    "name": "Brewster",
    "lat": "41.93889",
    "lng": "-99.86485"
  },
  {
    "country": "US",
    "name": "Broken Bow",
    "lat": "41.40195",
    "lng": "-99.63928"
  },
  {
    "country": "US",
    "name": "Burwell",
    "lat": "41.78167",
    "lng": "-99.13315"
  },
  {
    "country": "US",
    "name": "Butte",
    "lat": "42.91139",
    "lng": "-98.84926"
  },
  {
    "country": "US",
    "name": "Center",
    "lat": "42.60945",
    "lng": "-97.87673"
  },
  {
    "country": "US",
    "name": "Central City",
    "lat": "41.11585",
    "lng": "-98.00172"
  },
  {
    "country": "US",
    "name": "Chalco",
    "lat": "41.18389",
    "lng": "-96.1503"
  },
  {
    "country": "US",
    "name": "Clay Center",
    "lat": "40.52168",
    "lng": "-98.05533"
  },
  {
    "country": "US",
    "name": "Columbus",
    "lat": "41.42973",
    "lng": "-97.36838"
  },
  {
    "country": "US",
    "name": "Cozad",
    "lat": "40.85973",
    "lng": "-99.98734"
  },
  {
    "country": "US",
    "name": "Creighton",
    "lat": "42.46667",
    "lng": "-97.90618"
  },
  {
    "country": "US",
    "name": "Crete",
    "lat": "40.62778",
    "lng": "-96.96142"
  },
  {
    "country": "US",
    "name": "Dakota City",
    "lat": "42.41555",
    "lng": "-96.41836"
  },
  {
    "country": "US",
    "name": "David City",
    "lat": "41.25279",
    "lng": "-97.13004"
  },
  {
    "country": "US",
    "name": "Eagle",
    "lat": "40.81667",
    "lng": "-96.43029"
  },
  {
    "country": "US",
    "name": "Elkhorn",
    "lat": "41.28639",
    "lng": "-96.23447"
  },
  {
    "country": "US",
    "name": "Elwood",
    "lat": "40.59028",
    "lng": "-99.86095"
  },
  {
    "country": "US",
    "name": "Fairbury",
    "lat": "40.13722",
    "lng": "-97.18059"
  },
  {
    "country": "US",
    "name": "Falls City",
    "lat": "40.06084",
    "lng": "-95.60193"
  },
  {
    "country": "US",
    "name": "Franklin",
    "lat": "40.09612",
    "lng": "-98.95258"
  },
  {
    "country": "US",
    "name": "Fremont",
    "lat": "41.43333",
    "lng": "-96.49808"
  },
  {
    "country": "US",
    "name": "Friend",
    "lat": "40.65362",
    "lng": "-97.28616"
  },
  {
    "country": "US",
    "name": "Fullerton",
    "lat": "41.36335",
    "lng": "-97.96923"
  },
  {
    "country": "US",
    "name": "Geneva",
    "lat": "40.52695",
    "lng": "-97.59588"
  },
  {
    "country": "US",
    "name": "Gibbon",
    "lat": "40.74835",
    "lng": "-98.8448"
  },
  {
    "country": "US",
    "name": "Grand Island",
    "lat": "40.92501",
    "lng": "-98.34201"
  },
  {
    "country": "US",
    "name": "Greeley",
    "lat": "41.54862",
    "lng": "-98.53118"
  },
  {
    "country": "US",
    "name": "Gretna",
    "lat": "41.14083",
    "lng": "-96.23974"
  },
  {
    "country": "US",
    "name": "Hartington",
    "lat": "42.6225",
    "lng": "-97.2645"
  },
  {
    "country": "US",
    "name": "Hastings",
    "lat": "40.58612",
    "lng": "-98.38839"
  },
  {
    "country": "US",
    "name": "Hebron",
    "lat": "40.16639",
    "lng": "-97.58588"
  },
  {
    "country": "US",
    "name": "Hickman",
    "lat": "40.62",
    "lng": "-96.62918"
  },
  {
    "country": "US",
    "name": "Holdrege",
    "lat": "40.44029",
    "lng": "-99.36982"
  },
  {
    "country": "US",
    "name": "Kearney",
    "lat": "40.69946",
    "lng": "-99.08148"
  },
  {
    "country": "US",
    "name": "La Vista",
    "lat": "41.18389",
    "lng": "-96.03113"
  },
  {
    "country": "US",
    "name": "Lexington",
    "lat": "40.78084",
    "lng": "-99.7415"
  },
  {
    "country": "US",
    "name": "Lincoln",
    "lat": "40.8",
    "lng": "-96.66696"
  },
  {
    "country": "US",
    "name": "Louisville",
    "lat": "40.99778",
    "lng": "-96.16224"
  },
  {
    "country": "US",
    "name": "Loup City",
    "lat": "41.27557",
    "lng": "-98.96675"
  },
  {
    "country": "US",
    "name": "Macy",
    "lat": "42.11305",
    "lng": "-96.35642"
  },
  {
    "country": "US",
    "name": "Madison",
    "lat": "41.82834",
    "lng": "-97.45505"
  },
  {
    "country": "US",
    "name": "Milford",
    "lat": "40.77445",
    "lng": "-97.05059"
  },
  {
    "country": "US",
    "name": "Minden",
    "lat": "40.49863",
    "lng": "-98.94786"
  },
  {
    "country": "US",
    "name": "Nebraska City",
    "lat": "40.67667",
    "lng": "-95.85917"
  },
  {
    "country": "US",
    "name": "Neligh",
    "lat": "42.12862",
    "lng": "-98.02979"
  },
  {
    "country": "US",
    "name": "Nelson",
    "lat": "40.20168",
    "lng": "-98.06782"
  },
  {
    "country": "US",
    "name": "Norfolk",
    "lat": "42.02834",
    "lng": "-97.417"
  },
  {
    "country": "US",
    "name": "North Bend",
    "lat": "41.46195",
    "lng": "-96.77975"
  },
  {
    "country": "US",
    "name": "O'Neill",
    "lat": "42.45778",
    "lng": "-98.64759"
  },
  {
    "country": "US",
    "name": "Oakland",
    "lat": "41.83583",
    "lng": "-96.46697"
  },
  {
    "country": "US",
    "name": "Omaha",
    "lat": "41.25626",
    "lng": "-95.94043"
  },
  {
    "country": "US",
    "name": "Ord",
    "lat": "41.60334",
    "lng": "-98.9262"
  },
  {
    "country": "US",
    "name": "Osceola",
    "lat": "41.17974",
    "lng": "-97.54755"
  },
  {
    "country": "US",
    "name": "Papillion",
    "lat": "41.15444",
    "lng": "-96.04224"
  },
  {
    "country": "US",
    "name": "Pawnee City",
    "lat": "40.10833",
    "lng": "-96.15445"
  },
  {
    "country": "US",
    "name": "Pender",
    "lat": "42.11416",
    "lng": "-96.70726"
  },
  {
    "country": "US",
    "name": "Pierce",
    "lat": "42.19917",
    "lng": "-97.52672"
  },
  {
    "country": "US",
    "name": "Plainview",
    "lat": "42.34973",
    "lng": "-97.79201"
  },
  {
    "country": "US",
    "name": "Plattsmouth",
    "lat": "41.01139",
    "lng": "-95.88223"
  },
  {
    "country": "US",
    "name": "Ponca",
    "lat": "42.5625",
    "lng": "-96.70559"
  },
  {
    "country": "US",
    "name": "Ralston",
    "lat": "41.20528",
    "lng": "-96.04252"
  },
  {
    "country": "US",
    "name": "Ravenna",
    "lat": "41.02612",
    "lng": "-98.91258"
  },
  {
    "country": "US",
    "name": "Red Cloud",
    "lat": "40.0889",
    "lng": "-98.5195"
  },
  {
    "country": "US",
    "name": "Saint Paul",
    "lat": "41.21473",
    "lng": "-98.45812"
  },
  {
    "country": "US",
    "name": "Schuyler",
    "lat": "41.44723",
    "lng": "-97.05948"
  },
  {
    "country": "US",
    "name": "Seward",
    "lat": "40.90695",
    "lng": "-97.09892"
  },
  {
    "country": "US",
    "name": "Shelton",
    "lat": "40.77918",
    "lng": "-98.73091"
  },
  {
    "country": "US",
    "name": "South Sioux City",
    "lat": "42.47388",
    "lng": "-96.41364"
  },
  {
    "country": "US",
    "name": "Springfield",
    "lat": "41.08194",
    "lng": "-96.13446"
  },
  {
    "country": "US",
    "name": "Stanton",
    "lat": "41.95028",
    "lng": "-97.22393"
  },
  {
    "country": "US",
    "name": "Springview",
    "lat": "42.82444",
    "lng": "-99.74901"
  },
  {
    "country": "US",
    "name": "Stromsburg",
    "lat": "41.11418",
    "lng": "-97.59894"
  },
  {
    "country": "US",
    "name": "Superior",
    "lat": "40.02085",
    "lng": "-98.07004"
  },
  {
    "country": "US",
    "name": "Sutton",
    "lat": "40.60557",
    "lng": "-97.85921"
  },
  {
    "country": "US",
    "name": "Syracuse",
    "lat": "40.65722",
    "lng": "-96.1864"
  },
  {
    "country": "US",
    "name": "Taylor",
    "lat": "41.77028",
    "lng": "-99.37872"
  },
  {
    "country": "US",
    "name": "Tecumseh",
    "lat": "40.36667",
    "lng": "-96.19612"
  },
  {
    "country": "US",
    "name": "Tekamah",
    "lat": "41.77832",
    "lng": "-96.22113"
  },
  {
    "country": "US",
    "name": "Valley",
    "lat": "41.31278",
    "lng": "-96.34614"
  },
  {
    "country": "US",
    "name": "Wahoo",
    "lat": "41.21139",
    "lng": "-96.6203"
  },
  {
    "country": "US",
    "name": "Wakefield",
    "lat": "42.26917",
    "lng": "-96.86504"
  },
  {
    "country": "US",
    "name": "Waterloo",
    "lat": "41.28694",
    "lng": "-96.28558"
  },
  {
    "country": "US",
    "name": "Waverly",
    "lat": "40.9175",
    "lng": "-96.52834"
  },
  {
    "country": "US",
    "name": "Wayne",
    "lat": "42.23056",
    "lng": "-97.01782"
  },
  {
    "country": "US",
    "name": "Weeping Water",
    "lat": "40.87",
    "lng": "-96.14057"
  },
  {
    "country": "US",
    "name": "West Point",
    "lat": "41.84167",
    "lng": "-96.70864"
  },
  {
    "country": "US",
    "name": "Wilber",
    "lat": "40.48139",
    "lng": "-96.96058"
  },
  {
    "country": "US",
    "name": "Wisner",
    "lat": "41.98722",
    "lng": "-96.91421"
  },
  {
    "country": "US",
    "name": "Wood River",
    "lat": "40.82057",
    "lng": "-98.60007"
  },
  {
    "country": "US",
    "name": "Wymore",
    "lat": "40.12222",
    "lng": "-96.66252"
  },
  {
    "country": "US",
    "name": "York",
    "lat": "40.86807",
    "lng": "-97.592"
  },
  {
    "country": "US",
    "name": "Yutan",
    "lat": "41.245",
    "lng": "-96.39725"
  },
  {
    "country": "US",
    "name": "Alexandria",
    "lat": "43.61146",
    "lng": "-71.79286"
  },
  {
    "country": "US",
    "name": "Alstead",
    "lat": "43.14897",
    "lng": "-72.36064"
  },
  {
    "country": "US",
    "name": "Andover",
    "lat": "43.43702",
    "lng": "-71.82341"
  },
  {
    "country": "US",
    "name": "Antrim",
    "lat": "43.03091",
    "lng": "-71.93897"
  },
  {
    "country": "US",
    "name": "Ashland",
    "lat": "43.69535",
    "lng": "-71.63063"
  },
  {
    "country": "US",
    "name": "Atkinson",
    "lat": "42.83842",
    "lng": "-71.147"
  },
  {
    "country": "US",
    "name": "Auburn",
    "lat": "43.00453",
    "lng": "-71.3484"
  },
  {
    "country": "US",
    "name": "Barnstead",
    "lat": "43.33397",
    "lng": "-71.29284"
  },
  {
    "country": "US",
    "name": "Barrington",
    "lat": "43.22286",
    "lng": "-71.04701"
  },
  {
    "country": "US",
    "name": "Bedford",
    "lat": "42.94647",
    "lng": "-71.5159"
  },
  {
    "country": "US",
    "name": "Belmont",
    "lat": "43.44536",
    "lng": "-71.47785"
  },
  {
    "country": "US",
    "name": "Berlin",
    "lat": "44.46867",
    "lng": "-71.18508"
  },
  {
    "country": "US",
    "name": "Boscawen",
    "lat": "43.31508",
    "lng": "-71.62091"
  },
  {
    "country": "US",
    "name": "Bow Bog",
    "lat": "43.12064",
    "lng": "-71.51146"
  },
  {
    "country": "US",
    "name": "Brentwood",
    "lat": "42.9787",
    "lng": "-71.07284"
  },
  {
    "country": "US",
    "name": "Bridgewater",
    "lat": "43.63841",
    "lng": "-71.73647"
  },
  {
    "country": "US",
    "name": "Bristol",
    "lat": "43.59119",
    "lng": "-71.73675"
  },
  {
    "country": "US",
    "name": "Brookline",
    "lat": "42.73481",
    "lng": "-71.65813"
  },
  {
    "country": "US",
    "name": "Candia",
    "lat": "43.07786",
    "lng": "-71.27673"
  },
  {
    "country": "US",
    "name": "Canterbury",
    "lat": "43.33702",
    "lng": "-71.56535"
  },
  {
    "country": "US",
    "name": "Center Harbor",
    "lat": "43.7098",
    "lng": "-71.46035"
  },
  {
    "country": "US",
    "name": "Charlestown",
    "lat": "43.23869",
    "lng": "-72.42453"
  },
  {
    "country": "US",
    "name": "Chester",
    "lat": "42.95675",
    "lng": "-71.25728"
  },
  {
    "country": "US",
    "name": "Chesterfield",
    "lat": "42.8873",
    "lng": "-72.47037"
  },
  {
    "country": "US",
    "name": "Chichester",
    "lat": "43.24925",
    "lng": "-71.39979"
  },
  {
    "country": "US",
    "name": "Claremont",
    "lat": "43.37674",
    "lng": "-72.34676"
  },
  {
    "country": "US",
    "name": "Colebrook",
    "lat": "44.89449",
    "lng": "-71.49592"
  },
  {
    "country": "US",
    "name": "Concord",
    "lat": "43.20814",
    "lng": "-71.53757"
  },
  {
    "country": "US",
    "name": "Contoocook",
    "lat": "43.22202",
    "lng": "-71.71397"
  },
  {
    "country": "US",
    "name": "Conway",
    "lat": "43.97924",
    "lng": "-71.12035"
  },
  {
    "country": "US",
    "name": "Danbury",
    "lat": "43.52563",
    "lng": "-71.86175"
  },
  {
    "country": "US",
    "name": "Danville",
    "lat": "42.91259",
    "lng": "-71.1245"
  },
  {
    "country": "US",
    "name": "Deering",
    "lat": "43.07314",
    "lng": "-71.84452"
  },
  {
    "country": "US",
    "name": "Deerfield",
    "lat": "44.23062",
    "lng": "-71.61703"
  },
  {
    "country": "US",
    "name": "Derry",
    "lat": "42.88064",
    "lng": "-71.32729"
  },
  {
    "country": "US",
    "name": "Derry Village",
    "lat": "42.89175",
    "lng": "-71.31201"
  },
  {
    "country": "US",
    "name": "Dover",
    "lat": "43.19786",
    "lng": "-70.87367"
  },
  {
    "country": "US",
    "name": "Dublin",
    "lat": "42.90758",
    "lng": "-72.06258"
  },
  {
    "country": "US",
    "name": "Durham",
    "lat": "43.13397",
    "lng": "-70.92645"
  },
  {
    "country": "US",
    "name": "East Concord",
    "lat": "43.24202",
    "lng": "-71.53813"
  },
  {
    "country": "US",
    "name": "East Kingston",
    "lat": "42.92564",
    "lng": "-71.01672"
  },
  {
    "country": "US",
    "name": "East Merrimack",
    "lat": "42.86814",
    "lng": "-71.4834"
  },
  {
    "country": "US",
    "name": "Effingham",
    "lat": "43.76119",
    "lng": "-70.99645"
  },
  {
    "country": "US",
    "name": "Enfield",
    "lat": "43.64063",
    "lng": "-72.14398"
  },
  {
    "country": "US",
    "name": "Epping",
    "lat": "43.03342",
    "lng": "-71.07423"
  },
  {
    "country": "US",
    "name": "Epsom",
    "lat": "43.22286",
    "lng": "-71.33201"
  },
  {
    "country": "US",
    "name": "Exeter",
    "lat": "42.98148",
    "lng": "-70.94783"
  },
  {
    "country": "US",
    "name": "Farmington",
    "lat": "43.3898",
    "lng": "-71.06506"
  },
  {
    "country": "US",
    "name": "Fitzwilliam",
    "lat": "42.78064",
    "lng": "-72.14175"
  },
  {
    "country": "US",
    "name": "Francestown",
    "lat": "42.98758",
    "lng": "-71.81258"
  },
  {
    "country": "US",
    "name": "Franklin",
    "lat": "43.44424",
    "lng": "-71.6473"
  },
  {
    "country": "US",
    "name": "Freedom",
    "lat": "43.8123",
    "lng": "-71.03562"
  },
  {
    "country": "US",
    "name": "Fremont",
    "lat": "42.99092",
    "lng": "-71.14256"
  },
  {
    "country": "US",
    "name": "Gilford",
    "lat": "43.54758",
    "lng": "-71.40674"
  },
  {
    "country": "US",
    "name": "Gilmanton",
    "lat": "43.42425",
    "lng": "-71.41452"
  },
  {
    "country": "US",
    "name": "Goffstown",
    "lat": "43.02036",
    "lng": "-71.60035"
  },
  {
    "country": "US",
    "name": "Gorham",
    "lat": "44.38784",
    "lng": "-71.17313"
  },
  {
    "country": "US",
    "name": "Grafton",
    "lat": "43.55868",
    "lng": "-71.94397"
  },
  {
    "country": "US",
    "name": "Grantham",
    "lat": "43.48952",
    "lng": "-72.13759"
  },
  {
    "country": "US",
    "name": "Greenfield",
    "lat": "42.95064",
    "lng": "-71.8723"
  },
  {
    "country": "US",
    "name": "Greenland",
    "lat": "43.0362",
    "lng": "-70.83283"
  },
  {
    "country": "US",
    "name": "Greenville",
    "lat": "42.76731",
    "lng": "-71.8123"
  },
  {
    "country": "US",
    "name": "Groveton",
    "lat": "44.59867",
    "lng": "-71.5112"
  },
  {
    "country": "US",
    "name": "Hampstead",
    "lat": "42.87453",
    "lng": "-71.18117"
  },
  {
    "country": "US",
    "name": "Hampton",
    "lat": "42.93759",
    "lng": "-70.83894"
  },
  {
    "country": "US",
    "name": "Hampton Beach",
    "lat": "42.90731",
    "lng": "-70.812"
  },
  {
    "country": "US",
    "name": "Hampton Falls",
    "lat": "42.9162",
    "lng": "-70.86366"
  },
  {
    "country": "US",
    "name": "Hanover",
    "lat": "43.70229",
    "lng": "-72.28954"
  },
  {
    "country": "US",
    "name": "Harrisville",
    "lat": "42.94508",
    "lng": "-72.09647"
  },
  {
    "country": "US",
    "name": "Haverhill",
    "lat": "44.03451",
    "lng": "-72.06398"
  },
  {
    "country": "US",
    "name": "Henniker",
    "lat": "43.1798",
    "lng": "-71.8223"
  },
  {
    "country": "US",
    "name": "Hill",
    "lat": "43.52424",
    "lng": "-71.70091"
  },
  {
    "country": "US",
    "name": "Hinsdale",
    "lat": "42.78619",
    "lng": "-72.48648"
  },
  {
    "country": "US",
    "name": "Holderness",
    "lat": "43.73202",
    "lng": "-71.58841"
  },
  {
    "country": "US",
    "name": "Hollis",
    "lat": "42.74314",
    "lng": "-71.59174"
  },
  {
    "country": "US",
    "name": "Hooksett",
    "lat": "43.09675",
    "lng": "-71.46507"
  },
  {
    "country": "US",
    "name": "Hopkinton",
    "lat": "43.19147",
    "lng": "-71.67535"
  },
  {
    "country": "US",
    "name": "Hudson",
    "lat": "42.76481",
    "lng": "-71.43979"
  },
  {
    "country": "US",
    "name": "Jaffrey",
    "lat": "42.81397",
    "lng": "-72.02314"
  },
  {
    "country": "US",
    "name": "Jefferson",
    "lat": "44.41895",
    "lng": "-71.47453"
  },
  {
    "country": "US",
    "name": "Keene",
    "lat": "42.93369",
    "lng": "-72.27814"
  },
  {
    "country": "US",
    "name": "Kensington",
    "lat": "42.92703",
    "lng": "-70.94394"
  },
  {
    "country": "US",
    "name": "Kingston",
    "lat": "42.93648",
    "lng": "-71.05339"
  },
  {
    "country": "US",
    "name": "Laconia",
    "lat": "43.52785",
    "lng": "-71.47035"
  },
  {
    "country": "US",
    "name": "Lancaster",
    "lat": "44.48895",
    "lng": "-71.56925"
  },
  {
    "country": "US",
    "name": "Lebanon",
    "lat": "43.64229",
    "lng": "-72.25176"
  },
  {
    "country": "US",
    "name": "Lee",
    "lat": "43.12314",
    "lng": "-71.01145"
  },
  {
    "country": "US",
    "name": "Lempster",
    "lat": "43.23841",
    "lng": "-72.21064"
  },
  {
    "country": "US",
    "name": "Litchfield",
    "lat": "42.84425",
    "lng": "-71.47979"
  },
  {
    "country": "US",
    "name": "Littleton",
    "lat": "44.30617",
    "lng": "-71.77009"
  },
  {
    "country": "US",
    "name": "Londonderry",
    "lat": "42.86509",
    "lng": "-71.37395"
  },
  {
    "country": "US",
    "name": "Lyme",
    "lat": "43.80951",
    "lng": "-72.15592"
  },
  {
    "country": "US",
    "name": "Lyndeborough",
    "lat": "42.90758",
    "lng": "-71.76646"
  },
  {
    "country": "US",
    "name": "Madbury",
    "lat": "43.16925",
    "lng": "-70.92395"
  },
  {
    "country": "US",
    "name": "Madison",
    "lat": "43.89924",
    "lng": "-71.1484"
  },
  {
    "country": "US",
    "name": "Manchester",
    "lat": "42.99564",
    "lng": "-71.45479"
  },
  {
    "country": "US",
    "name": "Marlborough",
    "lat": "42.90425",
    "lng": "-72.20786"
  },
  {
    "country": "US",
    "name": "Mason",
    "lat": "42.7437",
    "lng": "-71.76896"
  },
  {
    "country": "US",
    "name": "Meredith",
    "lat": "43.65757",
    "lng": "-71.50035"
  },
  {
    "country": "US",
    "name": "Merrimack",
    "lat": "42.86509",
    "lng": "-71.4934"
  },
  {
    "country": "US",
    "name": "Milan",
    "lat": "44.57339",
    "lng": "-71.18508"
  },
  {
    "country": "US",
    "name": "Milford",
    "lat": "42.83536",
    "lng": "-71.64896"
  },
  {
    "country": "US",
    "name": "Mont Vernon",
    "lat": "42.89453",
    "lng": "-71.67424"
  },
  {
    "country": "US",
    "name": "Moultonborough",
    "lat": "43.7548",
    "lng": "-71.39674"
  },
  {
    "country": "US",
    "name": "Nashua",
    "lat": "42.76537",
    "lng": "-71.46757"
  },
  {
    "country": "US",
    "name": "New Boston",
    "lat": "42.97619",
    "lng": "-71.69396"
  },
  {
    "country": "US",
    "name": "New Castle",
    "lat": "43.07231",
    "lng": "-70.71616"
  },
  {
    "country": "US",
    "name": "New Durham",
    "lat": "43.43675",
    "lng": "-71.17229"
  },
  {
    "country": "US",
    "name": "New Ipswich",
    "lat": "42.74814",
    "lng": "-71.85424"
  },
  {
    "country": "US",
    "name": "New London",
    "lat": "43.41396",
    "lng": "-71.98508"
  },
  {
    "country": "US",
    "name": "Newbury",
    "lat": "43.32146",
    "lng": "-72.03592"
  },
  {
    "country": "US",
    "name": "Newmarket",
    "lat": "43.08286",
    "lng": "-70.93506"
  },
  {
    "country": "US",
    "name": "Newport",
    "lat": "43.36535",
    "lng": "-72.17342"
  },
  {
    "country": "US",
    "name": "Newton",
    "lat": "42.86953",
    "lng": "-71.0345"
  },
  {
    "country": "US",
    "name": "North Conway",
    "lat": "44.05368",
    "lng": "-71.1284"
  },
  {
    "country": "US",
    "name": "North Haverhill",
    "lat": "44.09034",
    "lng": "-72.02648"
  },
  {
    "country": "US",
    "name": "North Hampton",
    "lat": "42.97259",
    "lng": "-70.82978"
  },
  {
    "country": "US",
    "name": "Northfield",
    "lat": "43.43313",
    "lng": "-71.5923"
  },
  {
    "country": "US",
    "name": "Northumberland",
    "lat": "44.56339",
    "lng": "-71.5587"
  },
  {
    "country": "US",
    "name": "Northwood",
    "lat": "43.19425",
    "lng": "-71.1509"
  },
  {
    "country": "US",
    "name": "Nottingham",
    "lat": "43.11453",
    "lng": "-71.09978"
  },
  {
    "country": "US",
    "name": "Orford",
    "lat": "43.90535",
    "lng": "-72.14009"
  },
  {
    "country": "US",
    "name": "Ossipee",
    "lat": "43.68536",
    "lng": "-71.11673"
  },
  {
    "country": "US",
    "name": "Pelham",
    "lat": "42.73453",
    "lng": "-71.32451"
  },
  {
    "country": "US",
    "name": "Pembroke",
    "lat": "43.14675",
    "lng": "-71.45757"
  },
  {
    "country": "US",
    "name": "Peterborough",
    "lat": "42.87064",
    "lng": "-71.95175"
  },
  {
    "country": "US",
    "name": "Pinardville",
    "lat": "42.99425",
    "lng": "-71.50729"
  },
  {
    "country": "US",
    "name": "Pittsfield",
    "lat": "43.30591",
    "lng": "-71.32423"
  },
  {
    "country": "US",
    "name": "Plaistow",
    "lat": "42.83648",
    "lng": "-71.09478"
  },
  {
    "country": "US",
    "name": "Plymouth",
    "lat": "43.75702",
    "lng": "-71.68813"
  },
  {
    "country": "US",
    "name": "Portsmouth",
    "lat": "43.07704",
    "lng": "-70.75766"
  },
  {
    "country": "US",
    "name": "Raymond",
    "lat": "43.0362",
    "lng": "-71.1834"
  },
  {
    "country": "US",
    "name": "Richmond",
    "lat": "42.75481",
    "lng": "-72.27175"
  },
  {
    "country": "US",
    "name": "Rindge",
    "lat": "42.7512",
    "lng": "-72.0098"
  },
  {
    "country": "US",
    "name": "Rochester",
    "lat": "43.30453",
    "lng": "-70.97562"
  },
  {
    "country": "US",
    "name": "Rollinsford",
    "lat": "43.2362",
    "lng": "-70.82034"
  },
  {
    "country": "US",
    "name": "Rumney",
    "lat": "43.80535",
    "lng": "-71.81258"
  },
  {
    "country": "US",
    "name": "Rye",
    "lat": "43.01342",
    "lng": "-70.77089"
  },
  {
    "country": "US",
    "name": "Salem",
    "lat": "42.78842",
    "lng": "-71.20089"
  },
  {
    "country": "US",
    "name": "Salisbury",
    "lat": "43.38008",
    "lng": "-71.71702"
  },
  {
    "country": "US",
    "name": "Sanbornton",
    "lat": "43.48924",
    "lng": "-71.5823"
  },
  {
    "country": "US",
    "name": "Sanbornville",
    "lat": "43.55425",
    "lng": "-71.0309"
  },
  {
    "country": "US",
    "name": "Sandown",
    "lat": "42.9287",
    "lng": "-71.18701"
  },
  {
    "country": "US",
    "name": "Sandwich",
    "lat": "43.79035",
    "lng": "-71.41118"
  },
  {
    "country": "US",
    "name": "Seabrook",
    "lat": "42.89481",
    "lng": "-70.87116"
  },
  {
    "country": "US",
    "name": "Somersworth",
    "lat": "43.26175",
    "lng": "-70.86534"
  },
  {
    "country": "US",
    "name": "South Hooksett",
    "lat": "43.02647",
    "lng": "-71.43534"
  },
  {
    "country": "US",
    "name": "Springfield",
    "lat": "43.49507",
    "lng": "-72.03342"
  },
  {
    "country": "US",
    "name": "Strafford",
    "lat": "43.32703",
    "lng": "-71.18423"
  },
  {
    "country": "US",
    "name": "Stratford",
    "lat": "44.65505",
    "lng": "-71.55564"
  },
  {
    "country": "US",
    "name": "Stratham Station",
    "lat": "43.05287",
    "lng": "-70.89533"
  },
  {
    "country": "US",
    "name": "Sunapee",
    "lat": "43.38757",
    "lng": "-72.08786"
  },
  {
    "country": "US",
    "name": "Suncook",
    "lat": "43.13064",
    "lng": "-71.45312"
  },
  {
    "country": "US",
    "name": "Sutton",
    "lat": "43.33424",
    "lng": "-71.95147"
  },
  {
    "country": "US",
    "name": "Swanzey",
    "lat": "42.8698",
    "lng": "-72.28175"
  },
  {
    "country": "US",
    "name": "Tamworth",
    "lat": "43.8598",
    "lng": "-71.26313"
  },
  {
    "country": "US",
    "name": "Temple",
    "lat": "42.81814",
    "lng": "-71.85147"
  },
  {
    "country": "US",
    "name": "Thornton",
    "lat": "43.89285",
    "lng": "-71.67591"
  },
  {
    "country": "US",
    "name": "Tilton",
    "lat": "43.4423",
    "lng": "-71.58896"
  },
  {
    "country": "US",
    "name": "Troy",
    "lat": "42.82397",
    "lng": "-72.18119"
  },
  {
    "country": "US",
    "name": "Tuftonboro",
    "lat": "43.69647",
    "lng": "-71.22201"
  },
  {
    "country": "US",
    "name": "Unity",
    "lat": "43.29396",
    "lng": "-72.26037"
  },
  {
    "country": "US",
    "name": "Wakefield",
    "lat": "43.56813",
    "lng": "-71.03007"
  },
  {
    "country": "US",
    "name": "Weare",
    "lat": "43.0948",
    "lng": "-71.73063"
  },
  {
    "country": "US",
    "name": "Webster",
    "lat": "43.32897",
    "lng": "-71.71786"
  },
  {
    "country": "US",
    "name": "West Swanzey",
    "lat": "42.87008",
    "lng": "-72.32175"
  },
  {
    "country": "US",
    "name": "Westmoreland",
    "lat": "42.96203",
    "lng": "-72.44231"
  },
  {
    "country": "US",
    "name": "Whitefield",
    "lat": "44.37312",
    "lng": "-71.61008"
  },
  {
    "country": "US",
    "name": "Wilmot",
    "lat": "43.45174",
    "lng": "-71.91369"
  },
  {
    "country": "US",
    "name": "Wilton",
    "lat": "42.84342",
    "lng": "-71.73507"
  },
  {
    "country": "US",
    "name": "Winchester",
    "lat": "42.77342",
    "lng": "-72.38314"
  },
  {
    "country": "US",
    "name": "Windham",
    "lat": "42.80064",
    "lng": "-71.30423"
  },
  {
    "country": "US",
    "name": "Wolfeboro",
    "lat": "43.58397",
    "lng": "-71.20729"
  },
  {
    "country": "US",
    "name": "Woodstock",
    "lat": "43.97757",
    "lng": "-71.68508"
  },
  {
    "country": "US",
    "name": "Woodsville",
    "lat": "44.15229",
    "lng": "-72.03731"
  },
  {
    "country": "US",
    "name": "Allendale",
    "lat": "41.04149",
    "lng": "-74.12903"
  },
  {
    "country": "US",
    "name": "Allentown",
    "lat": "40.17789",
    "lng": "-74.58349"
  },
  {
    "country": "US",
    "name": "Alpine",
    "lat": "40.95593",
    "lng": "-73.93125"
  },
  {
    "country": "US",
    "name": "Alpha",
    "lat": "40.66704",
    "lng": "-75.1574"
  },
  {
    "country": "US",
    "name": "Annandale",
    "lat": "40.64093",
    "lng": "-74.88128"
  },
  {
    "country": "US",
    "name": "Asbury Park",
    "lat": "40.22039",
    "lng": "-74.01208"
  },
  {
    "country": "US",
    "name": "Atlantic Highlands",
    "lat": "40.40789",
    "lng": "-74.03431"
  },
  {
    "country": "US",
    "name": "Avenel",
    "lat": "40.58038",
    "lng": "-74.28515"
  },
  {
    "country": "US",
    "name": "Avon-by-the-Sea",
    "lat": "40.19234",
    "lng": "-74.01597"
  },
  {
    "country": "US",
    "name": "Bayonne",
    "lat": "40.66871",
    "lng": "-74.11431"
  },
  {
    "country": "US",
    "name": "Beattystown",
    "lat": "40.81315",
    "lng": "-74.84294"
  },
  {
    "country": "US",
    "name": "Bedminster",
    "lat": "40.68066",
    "lng": "-74.64544"
  },
  {
    "country": "US",
    "name": "Belleville",
    "lat": "40.79371",
    "lng": "-74.15014"
  },
  {
    "country": "US",
    "name": "Belford",
    "lat": "40.42594",
    "lng": "-74.08681"
  },
  {
    "country": "US",
    "name": "Belmar",
    "lat": "40.17845",
    "lng": "-74.0218"
  },
  {
    "country": "US",
    "name": "Belvidere",
    "lat": "40.82982",
    "lng": "-75.07767"
  },
  {
    "country": "US",
    "name": "Bergenfield",
    "lat": "40.9276",
    "lng": "-73.99736"
  },
  {
    "country": "US",
    "name": "Berkeley Heights",
    "lat": "40.68343",
    "lng": "-74.44265"
  },
  {
    "country": "US",
    "name": "Bernardsville",
    "lat": "40.71871",
    "lng": "-74.56932"
  },
  {
    "country": "US",
    "name": "Beverly",
    "lat": "40.06539",
    "lng": "-74.91906"
  },
  {
    "country": "US",
    "name": "Bloomfield",
    "lat": "40.80677",
    "lng": "-74.18542"
  },
  {
    "country": "US",
    "name": "Bloomingdale",
    "lat": "41.00204",
    "lng": "-74.32654"
  },
  {
    "country": "US",
    "name": "Bloomingdale",
    "lat": "40.4976",
    "lng": "-74.64738"
  },
  {
    "country": "US",
    "name": "Bogota",
    "lat": "40.87621",
    "lng": "-74.02986"
  },
  {
    "country": "US",
    "name": "Boonton",
    "lat": "40.9026",
    "lng": "-74.4071"
  },
  {
    "country": "US",
    "name": "Bordentown",
    "lat": "40.14622",
    "lng": "-74.71183"
  },
  {
    "country": "US",
    "name": "Bound Brook",
    "lat": "40.56844",
    "lng": "-74.53849"
  },
  {
    "country": "US",
    "name": "Bradley Beach",
    "lat": "40.20234",
    "lng": "-74.01208"
  },
  {
    "country": "US",
    "name": "Bradley Gardens",
    "lat": "40.56288",
    "lng": "-74.6546"
  },
  {
    "country": "US",
    "name": "Brass Castle",
    "lat": "40.76482",
    "lng": "-75.01101"
  },
  {
    "country": "US",
    "name": "Brielle",
    "lat": "40.10789",
    "lng": "-74.05653"
  },
  {
    "country": "US",
    "name": "Brownville",
    "lat": "40.40066",
    "lng": "-74.29515"
  },
  {
    "country": "US",
    "name": "Brookdale",
    "lat": "40.83371",
    "lng": "-74.18292"
  },
  {
    "country": "US",
    "name": "Budd Lake",
    "lat": "40.87121",
    "lng": "-74.73405"
  },
  {
    "country": "US",
    "name": "Burlington",
    "lat": "40.07122",
    "lng": "-74.86489"
  },
  {
    "country": "US",
    "name": "Butler",
    "lat": "41.00371",
    "lng": "-74.34154"
  },
  {
    "country": "US",
    "name": "Caldwell",
    "lat": "40.83982",
    "lng": "-74.27654"
  },
  {
    "country": "US",
    "name": "Califon",
    "lat": "40.71954",
    "lng": "-74.83572"
  },
  {
    "country": "US",
    "name": "Carlstadt",
    "lat": "40.84038",
    "lng": "-74.0907"
  },
  {
    "country": "US",
    "name": "Carteret",
    "lat": "40.57733",
    "lng": "-74.2282"
  },
  {
    "country": "US",
    "name": "Cedar Glen West",
    "lat": "40.04206",
    "lng": "-74.29265"
  },
  {
    "country": "US",
    "name": "Cedar Grove",
    "lat": "40.85177",
    "lng": "-74.22903"
  },
  {
    "country": "US",
    "name": "Chatham",
    "lat": "40.74093",
    "lng": "-74.38376"
  },
  {
    "country": "US",
    "name": "Chester",
    "lat": "40.78427",
    "lng": "-74.69683"
  },
  {
    "country": "US",
    "name": "Clark",
    "lat": "40.64094",
    "lng": "-74.3107"
  },
  {
    "country": "US",
    "name": "Clearbrook Park",
    "lat": "40.30983",
    "lng": "-74.4646"
  },
  {
    "country": "US",
    "name": "Cliffside Park",
    "lat": "40.82149",
    "lng": "-73.98764"
  },
  {
    "country": "US",
    "name": "Cliffwood Beach",
    "lat": "40.44205",
    "lng": "-74.21681"
  },
  {
    "country": "US",
    "name": "Clifton",
    "lat": "40.85843",
    "lng": "-74.16376"
  },
  {
    "country": "US",
    "name": "Clinton",
    "lat": "40.63677",
    "lng": "-74.90989"
  },
  {
    "country": "US",
    "name": "Closter",
    "lat": "40.97315",
    "lng": "-73.96153"
  },
  {
    "country": "US",
    "name": "Colonia",
    "lat": "40.57455",
    "lng": "-74.30209"
  },
  {
    "country": "US",
    "name": "Concordia",
    "lat": "40.31094",
    "lng": "-74.44821"
  },
  {
    "country": "US",
    "name": "Cranbury",
    "lat": "40.31622",
    "lng": "-74.51376"
  },
  {
    "country": "US",
    "name": "Crandon Lakes",
    "lat": "41.12426",
    "lng": "-74.83989"
  },
  {
    "country": "US",
    "name": "Cranford",
    "lat": "40.65844",
    "lng": "-74.29959"
  },
  {
    "country": "US",
    "name": "Cresskill",
    "lat": "40.94149",
    "lng": "-73.9593"
  },
  {
    "country": "US",
    "name": "Dayton",
    "lat": "40.37261",
    "lng": "-74.51015"
  },
  {
    "country": "US",
    "name": "Delanco",
    "lat": "40.05067",
    "lng": "-74.9535"
  },
  {
    "country": "US",
    "name": "Demarest",
    "lat": "40.95732",
    "lng": "-73.96347"
  },
  {
    "country": "US",
    "name": "Dover",
    "lat": "40.88399",
    "lng": "-74.5621"
  },
  {
    "country": "US",
    "name": "Dunellen",
    "lat": "40.58927",
    "lng": "-74.47182"
  },
  {
    "country": "US",
    "name": "Dumont",
    "lat": "40.94065",
    "lng": "-73.99681"
  },
  {
    "country": "US",
    "name": "East Brunswick",
    "lat": "40.42788",
    "lng": "-74.41598"
  },
  {
    "country": "US",
    "name": "East Freehold",
    "lat": "40.28094",
    "lng": "-74.25126"
  },
  {
    "country": "US",
    "name": "East Hanover",
    "lat": "40.8201",
    "lng": "-74.36487"
  },
  {
    "country": "US",
    "name": "East Newark",
    "lat": "40.74843",
    "lng": "-74.16181"
  },
  {
    "country": "US",
    "name": "East Orange",
    "lat": "40.76732",
    "lng": "-74.20487"
  },
  {
    "country": "US",
    "name": "East Rutherford",
    "lat": "40.83399",
    "lng": "-74.09709"
  },
  {
    "country": "US",
    "name": "Eatontown",
    "lat": "40.29622",
    "lng": "-74.05097"
  },
  {
    "country": "US",
    "name": "Edgewater Park",
    "lat": "40.06817",
    "lng": "-74.90072"
  },
  {
    "country": "US",
    "name": "Edison",
    "lat": "40.51872",
    "lng": "-74.4121"
  },
  {
    "country": "US",
    "name": "Edgewater",
    "lat": "40.82704",
    "lng": "-73.97569"
  },
  {
    "country": "US",
    "name": "Elizabeth",
    "lat": "40.66399",
    "lng": "-74.2107"
  },
  {
    "country": "US",
    "name": "Elmwood Park",
    "lat": "40.90399",
    "lng": "-74.11848"
  },
  {
    "country": "US",
    "name": "Emerson",
    "lat": "40.97621",
    "lng": "-74.02625"
  },
  {
    "country": "US",
    "name": "Englewood",
    "lat": "40.89288",
    "lng": "-73.97264"
  },
  {
    "country": "US",
    "name": "Englewood Cliffs",
    "lat": "40.88538",
    "lng": "-73.95236"
  },
  {
    "country": "US",
    "name": "Englishtown",
    "lat": "40.29733",
    "lng": "-74.3582"
  },
  {
    "country": "US",
    "name": "Essex Fells",
    "lat": "40.82454",
    "lng": "-74.28459"
  },
  {
    "country": "US",
    "name": "Ewing",
    "lat": "40.26983",
    "lng": "-74.79988"
  },
  {
    "country": "US",
    "name": "Fair Haven",
    "lat": "40.36067",
    "lng": "-74.03819"
  },
  {
    "country": "US",
    "name": "Fair Lawn",
    "lat": "40.94038",
    "lng": "-74.13181"
  },
  {
    "country": "US",
    "name": "Fairfield",
    "lat": "40.88371",
    "lng": "-74.30598"
  },
  {
    "country": "US",
    "name": "Fairview",
    "lat": "40.8126",
    "lng": "-73.99903"
  },
  {
    "country": "US",
    "name": "Fairview",
    "lat": "40.37316",
    "lng": "-74.08681"
  },
  {
    "country": "US",
    "name": "Fanwood",
    "lat": "40.64094",
    "lng": "-74.38348"
  },
  {
    "country": "US",
    "name": "Farmingdale",
    "lat": "40.1965",
    "lng": "-74.16848"
  },
  {
    "country": "US",
    "name": "Finderne",
    "lat": "40.56316",
    "lng": "-74.57766"
  },
  {
    "country": "US",
    "name": "Florence",
    "lat": "40.11955",
    "lng": "-74.80544"
  },
  {
    "country": "US",
    "name": "Florham Park",
    "lat": "40.78788",
    "lng": "-74.38821"
  },
  {
    "country": "US",
    "name": "Fords",
    "lat": "40.52927",
    "lng": "-74.31598"
  },
  {
    "country": "US",
    "name": "Flemington",
    "lat": "40.51233",
    "lng": "-74.85933"
  },
  {
    "country": "US",
    "name": "Fort Dix",
    "lat": "40.02984",
    "lng": "-74.61849"
  },
  {
    "country": "US",
    "name": "Fort Lee",
    "lat": "40.85093",
    "lng": "-73.97014"
  },
  {
    "country": "US",
    "name": "Franklin",
    "lat": "41.12204",
    "lng": "-74.58044"
  },
  {
    "country": "US",
    "name": "Franklin Lakes",
    "lat": "41.01676",
    "lng": "-74.2057"
  },
  {
    "country": "US",
    "name": "Franklin Park",
    "lat": "40.43899",
    "lng": "-74.53515"
  },
  {
    "country": "US",
    "name": "Freehold",
    "lat": "40.26011",
    "lng": "-74.27376"
  },
  {
    "country": "US",
    "name": "Frenchtown",
    "lat": "40.52621",
    "lng": "-75.06156"
  },
  {
    "country": "US",
    "name": "Garfield",
    "lat": "40.88149",
    "lng": "-74.1132"
  },
  {
    "country": "US",
    "name": "Garwood",
    "lat": "40.65177",
    "lng": "-74.32293"
  },
  {
    "country": "US",
    "name": "Gladstone",
    "lat": "40.7226",
    "lng": "-74.66544"
  },
  {
    "country": "US",
    "name": "Glen Gardner",
    "lat": "40.69677",
    "lng": "-74.94072"
  },
  {
    "country": "US",
    "name": "Glen Ridge",
    "lat": "40.80538",
    "lng": "-74.20376"
  },
  {
    "country": "US",
    "name": "Glen Rock",
    "lat": "40.96288",
    "lng": "-74.13292"
  },
  {
    "country": "US",
    "name": "Green Knoll",
    "lat": "40.6001",
    "lng": "-74.6121"
  },
  {
    "country": "US",
    "name": "Groveville",
    "lat": "40.16983",
    "lng": "-74.67155"
  },
  {
    "country": "US",
    "name": "Guttenberg",
    "lat": "40.79205",
    "lng": "-74.00375"
  },
  {
    "country": "US",
    "name": "Hackensack",
    "lat": "40.88593",
    "lng": "-74.04347"
  },
  {
    "country": "US",
    "name": "Hackettstown",
    "lat": "40.85399",
    "lng": "-74.82906"
  },
  {
    "country": "US",
    "name": "Hamburg",
    "lat": "41.15343",
    "lng": "-74.57627"
  },
  {
    "country": "US",
    "name": "Hamilton Square",
    "lat": "40.22733",
    "lng": "-74.65321"
  },
  {
    "country": "US",
    "name": "Hampton",
    "lat": "40.70704",
    "lng": "-74.956"
  },
  {
    "country": "US",
    "name": "Haledon",
    "lat": "40.93565",
    "lng": "-74.18626"
  },
  {
    "country": "US",
    "name": "Hanover",
    "lat": "40.80454",
    "lng": "-74.36682"
  },
  {
    "country": "US",
    "name": "Hardwick",
    "lat": "41.05454",
    "lng": "-74.93212"
  },
  {
    "country": "US",
    "name": "Harrington Park",
    "lat": "40.98371",
    "lng": "-73.97986"
  },
  {
    "country": "US",
    "name": "Harrison",
    "lat": "40.74649",
    "lng": "-74.15626"
  },
  {
    "country": "US",
    "name": "Hasbrouck Heights",
    "lat": "40.85816",
    "lng": "-74.0807"
  },
  {
    "country": "US",
    "name": "Haworth",
    "lat": "40.96093",
    "lng": "-73.99014"
  },
  {
    "country": "US",
    "name": "Hawthorne",
    "lat": "40.94926",
    "lng": "-74.15375"
  },
  {
    "country": "US",
    "name": "Heathcote",
    "lat": "40.38872",
    "lng": "-74.57571"
  },
  {
    "country": "US",
    "name": "Helmetta",
    "lat": "40.37677",
    "lng": "-74.4246"
  },
  {
    "country": "US",
    "name": "High Bridge",
    "lat": "40.66705",
    "lng": "-74.89572"
  },
  {
    "country": "US",
    "name": "Highland Lake",
    "lat": "41.17676",
    "lng": "-74.45655"
  },
  {
    "country": "US",
    "name": "Highland Park",
    "lat": "40.49594",
    "lng": "-74.42432"
  },
  {
    "country": "US",
    "name": "Highlands",
    "lat": "40.40372",
    "lng": "-73.99153"
  },
  {
    "country": "US",
    "name": "Hightstown",
    "lat": "40.26955",
    "lng": "-74.52321"
  },
  {
    "country": "US",
    "name": "Hillsdale",
    "lat": "41.0026",
    "lng": "-74.04042"
  },
  {
    "country": "US",
    "name": "Hillside",
    "lat": "40.70121",
    "lng": "-74.23015"
  },
  {
    "country": "US",
    "name": "Ho-Ho-Kus",
    "lat": "40.99649",
    "lng": "-74.10125"
  },
  {
    "country": "US",
    "name": "Hoboken",
    "lat": "40.74399",
    "lng": "-74.03236"
  },
  {
    "country": "US",
    "name": "Hopatcong",
    "lat": "40.93288",
    "lng": "-74.65933"
  },
  {
    "country": "US",
    "name": "Hopatcong Hills",
    "lat": "40.94399",
    "lng": "-74.67072"
  },
  {
    "country": "US",
    "name": "Hopewell",
    "lat": "40.38927",
    "lng": "-74.76183"
  },
  {
    "country": "US",
    "name": "Irvington",
    "lat": "40.73232",
    "lng": "-74.23487"
  },
  {
    "country": "US",
    "name": "Iselin",
    "lat": "40.57538",
    "lng": "-74.32237"
  },
  {
    "country": "US",
    "name": "Jamesburg",
    "lat": "40.35261",
    "lng": "-74.44015"
  },
  {
    "country": "US",
    "name": "Jersey City",
    "lat": "40.72816",
    "lng": "-74.07764"
  },
  {
    "country": "US",
    "name": "Keansburg",
    "lat": "40.44177",
    "lng": "-74.12986"
  },
  {
    "country": "US",
    "name": "Kearny",
    "lat": "40.76843",
    "lng": "-74.14542"
  },
  {
    "country": "US",
    "name": "Kendall Park",
    "lat": "40.42094",
    "lng": "-74.56071"
  },
  {
    "country": "US",
    "name": "Kenvil",
    "lat": "40.87982",
    "lng": "-74.61849"
  },
  {
    "country": "US",
    "name": "Kenilworth",
    "lat": "40.67649",
    "lng": "-74.2907"
  },
  {
    "country": "US",
    "name": "Keyport",
    "lat": "40.43316",
    "lng": "-74.19959"
  },
  {
    "country": "US",
    "name": "Kingston",
    "lat": "40.37538",
    "lng": "-74.61349"
  },
  {
    "country": "US",
    "name": "Kinnelon",
    "lat": "41.00176",
    "lng": "-74.3671"
  },
  {
    "country": "US",
    "name": "Lake Como",
    "lat": "40.15984",
    "lng": "-74.02819"
  },
  {
    "country": "US",
    "name": "Lake Mohawk",
    "lat": "41.01843",
    "lng": "-74.66016"
  },
  {
    "country": "US",
    "name": "Lake Telemark",
    "lat": "40.95677",
    "lng": "-74.49793"
  },
  {
    "country": "US",
    "name": "Lakehurst",
    "lat": "40.01456",
    "lng": "-74.31126"
  },
  {
    "country": "US",
    "name": "Lakewood",
    "lat": "40.09789",
    "lng": "-74.21764"
  },
  {
    "country": "US",
    "name": "Lambertville",
    "lat": "40.36594",
    "lng": "-74.94294"
  },
  {
    "country": "US",
    "name": "Laurence Harbor",
    "lat": "40.45677",
    "lng": "-74.24653"
  },
  {
    "country": "US",
    "name": "Lawrenceville",
    "lat": "40.29733",
    "lng": "-74.7296"
  },
  {
    "country": "US",
    "name": "Lebanon",
    "lat": "40.64177",
    "lng": "-74.836"
  },
  {
    "country": "US",
    "name": "Leisure Knoll",
    "lat": "40.01901",
    "lng": "-74.29209"
  },
  {
    "country": "US",
    "name": "Leisure Village",
    "lat": "40.04262",
    "lng": "-74.18486"
  },
  {
    "country": "US",
    "name": "Leisure Village East",
    "lat": "40.03012",
    "lng": "-74.16431"
  },
  {
    "country": "US",
    "name": "Leonardo",
    "lat": "40.41733",
    "lng": "-74.06208"
  },
  {
    "country": "US",
    "name": "Leonia",
    "lat": "40.86149",
    "lng": "-73.98819"
  },
  {
    "country": "US",
    "name": "Lincoln Park",
    "lat": "40.92427",
    "lng": "-74.30209"
  },
  {
    "country": "US",
    "name": "Lincroft",
    "lat": "40.33067",
    "lng": "-74.12097"
  },
  {
    "country": "US",
    "name": "Linden",
    "lat": "40.62205",
    "lng": "-74.24459"
  },
  {
    "country": "US",
    "name": "Little Falls",
    "lat": "40.86899",
    "lng": "-74.2082"
  },
  {
    "country": "US",
    "name": "Little Ferry",
    "lat": "40.85288",
    "lng": "-74.04208"
  },
  {
    "country": "US",
    "name": "Little Silver",
    "lat": "40.33678",
    "lng": "-74.04708"
  },
  {
    "country": "US",
    "name": "Livingston",
    "lat": "40.79593",
    "lng": "-74.31487"
  },
  {
    "country": "US",
    "name": "Lodi",
    "lat": "40.88232",
    "lng": "-74.0832"
  },
  {
    "country": "US",
    "name": "Long Branch",
    "lat": "40.30428",
    "lng": "-73.99236"
  },
  {
    "country": "US",
    "name": "Long Valley",
    "lat": "40.78593",
    "lng": "-74.78016"
  },
  {
    "country": "US",
    "name": "Lyndhurst",
    "lat": "40.81204",
    "lng": "-74.12431"
  },
  {
    "country": "US",
    "name": "Madison",
    "lat": "40.75982",
    "lng": "-74.4171"
  },
  {
    "country": "US",
    "name": "Madison Park",
    "lat": "40.4515",
    "lng": "-74.30792"
  },
  {
    "country": "US",
    "name": "Mahwah",
    "lat": "41.08871",
    "lng": "-74.14376"
  },
  {
    "country": "US",
    "name": "Manasquan",
    "lat": "40.12623",
    "lng": "-74.0493"
  },
  {
    "country": "US",
    "name": "Manville",
    "lat": "40.54094",
    "lng": "-74.58766"
  },
  {
    "country": "US",
    "name": "Maplewood",
    "lat": "40.73121",
    "lng": "-74.27348"
  },
  {
    "country": "US",
    "name": "Marlboro",
    "lat": "40.31539",
    "lng": "-74.24626"
  },
  {
    "country": "US",
    "name": "Martinsville",
    "lat": "40.60121",
    "lng": "-74.55905"
  },
  {
    "country": "US",
    "name": "Matawan",
    "lat": "40.41483",
    "lng": "-74.22959"
  },
  {
    "country": "US",
    "name": "Maywood",
    "lat": "40.9026",
    "lng": "-74.06181"
  },
  {
    "country": "US",
    "name": "Mendham",
    "lat": "40.77593",
    "lng": "-74.60071"
  },
  {
    "country": "US",
    "name": "Mercerville",
    "lat": "40.23705",
    "lng": "-74.68655"
  },
  {
    "country": "US",
    "name": "Metuchen",
    "lat": "40.54316",
    "lng": "-74.3632"
  },
  {
    "country": "US",
    "name": "Middlebush",
    "lat": "40.4976",
    "lng": "-74.52932"
  },
  {
    "country": "US",
    "name": "Middlesex",
    "lat": "40.5726",
    "lng": "-74.49265"
  },
  {
    "country": "US",
    "name": "Midland Park",
    "lat": "40.98926",
    "lng": "-74.1407"
  },
  {
    "country": "US",
    "name": "Milford",
    "lat": "40.56871",
    "lng": "-75.09462"
  },
  {
    "country": "US",
    "name": "Milltown",
    "lat": "40.45622",
    "lng": "-74.44321"
  },
  {
    "country": "US",
    "name": "Monmouth Beach",
    "lat": "40.33039",
    "lng": "-73.98153"
  },
  {
    "country": "US",
    "name": "Monmouth Junction",
    "lat": "40.379",
    "lng": "-74.54654"
  },
  {
    "country": "US",
    "name": "Montclair",
    "lat": "40.82593",
    "lng": "-74.20903"
  },
  {
    "country": "US",
    "name": "Montvale",
    "lat": "41.04676",
    "lng": "-74.02292"
  },
  {
    "country": "US",
    "name": "Moonachie",
    "lat": "40.84121",
    "lng": "-74.04514"
  },
  {
    "country": "US",
    "name": "Morganville",
    "lat": "40.3765",
    "lng": "-74.24431"
  },
  {
    "country": "US",
    "name": "Morris Plains",
    "lat": "40.82177",
    "lng": "-74.48099"
  },
  {
    "country": "US",
    "name": "Morristown",
    "lat": "40.79677",
    "lng": "-74.48154"
  },
  {
    "country": "US",
    "name": "Mount Arlington",
    "lat": "40.92593",
    "lng": "-74.63488"
  },
  {
    "country": "US",
    "name": "Mountain Lakes",
    "lat": "40.89482",
    "lng": "-74.43293"
  },
  {
    "country": "US",
    "name": "Mountainside",
    "lat": "40.67232",
    "lng": "-74.35737"
  },
  {
    "country": "US",
    "name": "Navesink",
    "lat": "40.39955",
    "lng": "-74.03542"
  },
  {
    "country": "US",
    "name": "Neptune City",
    "lat": "40.20011",
    "lng": "-74.02792"
  },
  {
    "country": "US",
    "name": "Netcong",
    "lat": "40.89899",
    "lng": "-74.70655"
  },
  {
    "country": "US",
    "name": "New Brunswick",
    "lat": "40.48622",
    "lng": "-74.45182"
  },
  {
    "country": "US",
    "name": "New Egypt",
    "lat": "40.06761",
    "lng": "-74.53071"
  },
  {
    "country": "US",
    "name": "New Milford",
    "lat": "40.9351",
    "lng": "-74.01903"
  },
  {
    "country": "US",
    "name": "New Providence",
    "lat": "40.69843",
    "lng": "-74.40154"
  },
  {
    "country": "US",
    "name": "Newark",
    "lat": "40.73566",
    "lng": "-74.17237"
  },
  {
    "country": "US",
    "name": "Newton",
    "lat": "41.05815",
    "lng": "-74.75267"
  },
  {
    "country": "US",
    "name": "North Arlington",
    "lat": "40.78843",
    "lng": "-74.1332"
  },
  {
    "country": "US",
    "name": "North Bergen",
    "lat": "40.80427",
    "lng": "-74.01208"
  },
  {
    "country": "US",
    "name": "North Caldwell",
    "lat": "40.86482",
    "lng": "-74.2582"
  },
  {
    "country": "US",
    "name": "North Haledon",
    "lat": "40.9551",
    "lng": "-74.18598"
  },
  {
    "country": "US",
    "name": "North Middletown",
    "lat": "40.43955",
    "lng": "-74.11903"
  },
  {
    "country": "US",
    "name": "North Plainfield",
    "lat": "40.6301",
    "lng": "-74.42737"
  },
  {
    "country": "US",
    "name": "Northfield",
    "lat": "40.77427",
    "lng": "-74.32459"
  },
  {
    "country": "US",
    "name": "Northvale",
    "lat": "41.00649",
    "lng": "-73.94903"
  },
  {
    "country": "US",
    "name": "Norwood",
    "lat": "40.99815",
    "lng": "-73.9618"
  },
  {
    "country": "US",
    "name": "Nutley",
    "lat": "40.82232",
    "lng": "-74.15987"
  },
  {
    "country": "US",
    "name": "Oakhurst",
    "lat": "40.27094",
    "lng": "-74.01625"
  },
  {
    "country": "US",
    "name": "Oakland",
    "lat": "41.01315",
    "lng": "-74.26431"
  },
  {
    "country": "US",
    "name": "Ocean Grove",
    "lat": "40.21206",
    "lng": "-74.00653"
  },
  {
    "country": "US",
    "name": "Oceanport",
    "lat": "40.31817",
    "lng": "-74.01514"
  },
  {
    "country": "US",
    "name": "Ogdensburg",
    "lat": "41.08176",
    "lng": "-74.59238"
  },
  {
    "country": "US",
    "name": "Old Bridge",
    "lat": "40.41483",
    "lng": "-74.36543"
  },
  {
    "country": "US",
    "name": "Old Tappan",
    "lat": "41.01065",
    "lng": "-73.99125"
  },
  {
    "country": "US",
    "name": "Oradell",
    "lat": "40.95871",
    "lng": "-74.03681"
  },
  {
    "country": "US",
    "name": "Orange",
    "lat": "40.77066",
    "lng": "-74.23265"
  },
  {
    "country": "US",
    "name": "Oxford",
    "lat": "40.80315",
    "lng": "-74.98962"
  },
  {
    "country": "US",
    "name": "Palisades Park",
    "lat": "40.84816",
    "lng": "-73.99764"
  },
  {
    "country": "US",
    "name": "Palmyra",
    "lat": "40.00706",
    "lng": "-75.02823"
  },
  {
    "country": "US",
    "name": "Paramus",
    "lat": "40.94454",
    "lng": "-74.07542"
  },
  {
    "country": "US",
    "name": "Park Ridge",
    "lat": "41.0376",
    "lng": "-74.0407"
  },
  {
    "country": "US",
    "name": "Parsippany",
    "lat": "40.85788",
    "lng": "-74.42599"
  },
  {
    "country": "US",
    "name": "Passaic",
    "lat": "40.85677",
    "lng": "-74.12848"
  },
  {
    "country": "US",
    "name": "Paterson",
    "lat": "40.91677",
    "lng": "-74.17181"
  },
  {
    "country": "US",
    "name": "Peapack",
    "lat": "40.71677",
    "lng": "-74.65655"
  },
  {
    "country": "US",
    "name": "Pennington",
    "lat": "40.32844",
    "lng": "-74.79072"
  },
  {
    "country": "US",
    "name": "Perth Amboy",
    "lat": "40.50677",
    "lng": "-74.26542"
  },
  {
    "country": "US",
    "name": "Phillipsburg",
    "lat": "40.69371",
    "lng": "-75.19018"
  },
  {
    "country": "US",
    "name": "Pine Lake Park",
    "lat": "40.00317",
    "lng": "-74.25653"
  },
  {
    "country": "US",
    "name": "Piscataway",
    "lat": "40.49927",
    "lng": "-74.39904"
  },
  {
    "country": "US",
    "name": "Plainfield",
    "lat": "40.63371",
    "lng": "-74.40737"
  },
  {
    "country": "US",
    "name": "Plainsboro Center",
    "lat": "40.33177",
    "lng": "-74.5946"
  },
  {
    "country": "US",
    "name": "Point Pleasant",
    "lat": "40.08317",
    "lng": "-74.06819"
  },
  {
    "country": "US",
    "name": "Point Pleasant Beach",
    "lat": "40.09123",
    "lng": "-74.04791"
  },
  {
    "country": "US",
    "name": "Pompton Lakes",
    "lat": "41.00538",
    "lng": "-74.2907"
  },
  {
    "country": "US",
    "name": "Port Monmouth",
    "lat": "40.43011",
    "lng": "-74.09847"
  },
  {
    "country": "US",
    "name": "Port Reading",
    "lat": "40.56538",
    "lng": "-74.26042"
  },
  {
    "country": "US",
    "name": "Princeton",
    "lat": "40.34872",
    "lng": "-74.65905"
  },
  {
    "country": "US",
    "name": "Princeton Junction",
    "lat": "40.31733",
    "lng": "-74.61988"
  },
  {
    "country": "US",
    "name": "Princeton Meadows",
    "lat": "40.33177",
    "lng": "-74.56377"
  },
  {
    "country": "US",
    "name": "Prospect Park",
    "lat": "40.24039",
    "lng": "-74.76627"
  },
  {
    "country": "US",
    "name": "Prospect Park",
    "lat": "40.93704",
    "lng": "-74.17431"
  },
  {
    "country": "US",
    "name": "Rahway",
    "lat": "40.60816",
    "lng": "-74.27765"
  },
  {
    "country": "US",
    "name": "Ramsey",
    "lat": "41.05732",
    "lng": "-74.14098"
  },
  {
    "country": "US",
    "name": "Ramtown",
    "lat": "40.12095",
    "lng": "-74.14375"
  },
  {
    "country": "US",
    "name": "Raritan",
    "lat": "40.56955",
    "lng": "-74.63294"
  },
  {
    "country": "US",
    "name": "Red Bank",
    "lat": "40.34705",
    "lng": "-74.06431"
  },
  {
    "country": "US",
    "name": "Ridgefield",
    "lat": "40.83427",
    "lng": "-74.00875"
  },
  {
    "country": "US",
    "name": "Ridgefield Park",
    "lat": "40.85704",
    "lng": "-74.02153"
  },
  {
    "country": "US",
    "name": "Ridgewood",
    "lat": "40.97926",
    "lng": "-74.11653"
  },
  {
    "country": "US",
    "name": "Ringwood",
    "lat": "41.11343",
    "lng": "-74.24543"
  },
  {
    "country": "US",
    "name": "River Edge",
    "lat": "40.92871",
    "lng": "-74.03986"
  },
  {
    "country": "US",
    "name": "River Vale",
    "lat": "40.99538",
    "lng": "-74.01208"
  },
  {
    "country": "US",
    "name": "Riverdale",
    "lat": "40.99399",
    "lng": "-74.30348"
  },
  {
    "country": "US",
    "name": "Riverton",
    "lat": "40.00845",
    "lng": "-74.99684"
  },
  {
    "country": "US",
    "name": "Riverton",
    "lat": "40.0115",
    "lng": "-75.01489"
  },
  {
    "country": "US",
    "name": "Robbinsville",
    "lat": "40.21455",
    "lng": "-74.61932"
  },
  {
    "country": "US",
    "name": "Robertsville",
    "lat": "40.34622",
    "lng": "-74.28792"
  },
  {
    "country": "US",
    "name": "Rochelle Park",
    "lat": "40.90732",
    "lng": "-74.07514"
  },
  {
    "country": "US",
    "name": "Rockaway",
    "lat": "40.90121",
    "lng": "-74.51432"
  },
  {
    "country": "US",
    "name": "Roebling",
    "lat": "40.11594",
    "lng": "-74.78627"
  },
  {
    "country": "US",
    "name": "Roseland",
    "lat": "40.82066",
    "lng": "-74.29376"
  },
  {
    "country": "US",
    "name": "Roselle",
    "lat": "40.65223",
    "lng": "-74.25882"
  },
  {
    "country": "US",
    "name": "Roselle Park",
    "lat": "40.66455",
    "lng": "-74.26431"
  },
  {
    "country": "US",
    "name": "Rossmoor",
    "lat": "40.3365",
    "lng": "-74.47349"
  },
  {
    "country": "US",
    "name": "Rumson",
    "lat": "40.37205",
    "lng": "-73.99903"
  },
  {
    "country": "US",
    "name": "Rutherford",
    "lat": "40.82649",
    "lng": "-74.10681"
  },
  {
    "country": "US",
    "name": "Saddle River",
    "lat": "41.03176",
    "lng": "-74.10209"
  },
  {
    "country": "US",
    "name": "Saddle Brook",
    "lat": "40.89899",
    "lng": "-74.09264"
  },
  {
    "country": "US",
    "name": "Sayreville",
    "lat": "40.45927",
    "lng": "-74.36098"
  },
  {
    "country": "US",
    "name": "Sayreville Junction",
    "lat": "40.46538",
    "lng": "-74.33043"
  },
  {
    "country": "US",
    "name": "Scotch Plains",
    "lat": "40.65538",
    "lng": "-74.38987"
  },
  {
    "country": "US",
    "name": "Sea Bright",
    "lat": "40.3615",
    "lng": "-73.97403"
  },
  {
    "country": "US",
    "name": "Sea Girt",
    "lat": "40.13206",
    "lng": "-74.03458"
  },
  {
    "country": "US",
    "name": "Secaucus",
    "lat": "40.78955",
    "lng": "-74.05653"
  },
  {
    "country": "US",
    "name": "Sewaren",
    "lat": "40.55205",
    "lng": "-74.25876"
  },
  {
    "country": "US",
    "name": "Shark River Hills",
    "lat": "40.194",
    "lng": "-74.04875"
  },
  {
    "country": "US",
    "name": "Short Hills",
    "lat": "40.74788",
    "lng": "-74.32543"
  },
  {
    "country": "US",
    "name": "Shrewsbury",
    "lat": "40.18261",
    "lng": "-74.52932"
  },
  {
    "country": "US",
    "name": "Shrewsbury",
    "lat": "40.32955",
    "lng": "-74.06153"
  },
  {
    "country": "US",
    "name": "Singac",
    "lat": "40.88677",
    "lng": "-74.24098"
  },
  {
    "country": "US",
    "name": "Sixmile Run",
    "lat": "40.45761",
    "lng": "-74.51154"
  },
  {
    "country": "US",
    "name": "Society Hill",
    "lat": "40.53399",
    "lng": "-74.45793"
  },
  {
    "country": "US",
    "name": "Somerset",
    "lat": "40.4976",
    "lng": "-74.48849"
  },
  {
    "country": "US",
    "name": "Somerville",
    "lat": "40.57427",
    "lng": "-74.60988"
  },
  {
    "country": "US",
    "name": "South Amboy",
    "lat": "40.47788",
    "lng": "-74.2907"
  },
  {
    "country": "US",
    "name": "South Belmar",
    "lat": "40.17095",
    "lng": "-74.02736"
  },
  {
    "country": "US",
    "name": "South Bound Brook",
    "lat": "40.55344",
    "lng": "-74.53154"
  },
  {
    "country": "US",
    "name": "South Old Bridge",
    "lat": "40.40816",
    "lng": "-74.35432"
  },
  {
    "country": "US",
    "name": "South Orange",
    "lat": "40.74899",
    "lng": "-74.26126"
  },
  {
    "country": "US",
    "name": "South Plainfield",
    "lat": "40.57927",
    "lng": "-74.41154"
  },
  {
    "country": "US",
    "name": "South River",
    "lat": "40.44649",
    "lng": "-74.38598"
  },
  {
    "country": "US",
    "name": "Spotswood",
    "lat": "40.39177",
    "lng": "-74.39848"
  },
  {
    "country": "US",
    "name": "Spring Lake",
    "lat": "40.15345",
    "lng": "-74.02819"
  },
  {
    "country": "US",
    "name": "Spring Lake Heights",
    "lat": "40.15039",
    "lng": "-74.03097"
  },
  {
    "country": "US",
    "name": "Springfield",
    "lat": "40.70491",
    "lng": "-74.31723"
  },
  {
    "country": "US",
    "name": "Stanhope",
    "lat": "40.90288",
    "lng": "-74.70905"
  },
  {
    "country": "US",
    "name": "Strathmore",
    "lat": "40.39594",
    "lng": "-74.21348"
  },
  {
    "country": "US",
    "name": "Succasunna",
    "lat": "40.86843",
    "lng": "-74.64044"
  },
  {
    "country": "US",
    "name": "Summit",
    "lat": "40.71562",
    "lng": "-74.36468"
  },
  {
    "country": "US",
    "name": "Sussex",
    "lat": "41.20982",
    "lng": "-74.60766"
  },
  {
    "country": "US",
    "name": "Teaneck",
    "lat": "40.8976",
    "lng": "-74.01597"
  },
  {
    "country": "US",
    "name": "Ten Mile Run",
    "lat": "40.41301",
    "lng": "-74.60223"
  },
  {
    "country": "US",
    "name": "Tenafly",
    "lat": "40.92538",
    "lng": "-73.96292"
  },
  {
    "country": "US",
    "name": "Tinton Falls",
    "lat": "40.30428",
    "lng": "-74.10042"
  },
  {
    "country": "US",
    "name": "Totowa",
    "lat": "40.9051",
    "lng": "-74.20987"
  },
  {
    "country": "US",
    "name": "Trenton",
    "lat": "40.21705",
    "lng": "-74.74294"
  },
  {
    "country": "US",
    "name": "Twin Rivers",
    "lat": "40.264",
    "lng": "-74.49126"
  },
  {
    "country": "US",
    "name": "Union",
    "lat": "40.6976",
    "lng": "-74.2632"
  },
  {
    "country": "US",
    "name": "Union Beach",
    "lat": "40.4465",
    "lng": "-74.1782"
  },
  {
    "country": "US",
    "name": "Union City",
    "lat": "40.77955",
    "lng": "-74.02375"
  },
  {
    "country": "US",
    "name": "Upper Montclair",
    "lat": "40.84621",
    "lng": "-74.20126"
  },
  {
    "country": "US",
    "name": "Upper Saddle River",
    "lat": "41.05843",
    "lng": "-74.09848"
  },
  {
    "country": "US",
    "name": "Verona",
    "lat": "40.82982",
    "lng": "-74.24015"
  },
  {
    "country": "US",
    "name": "Victory Gardens",
    "lat": "40.87593",
    "lng": "-74.54238"
  },
  {
    "country": "US",
    "name": "Vista Center",
    "lat": "40.15928",
    "lng": "-74.31792"
  },
  {
    "country": "US",
    "name": "Voorhees",
    "lat": "40.48122",
    "lng": "-74.48321"
  },
  {
    "country": "US",
    "name": "Vernon Valley",
    "lat": "41.23676",
    "lng": "-74.4871"
  },
  {
    "country": "US",
    "name": "Waldwick",
    "lat": "41.01065",
    "lng": "-74.11792"
  },
  {
    "country": "US",
    "name": "Wallington",
    "lat": "40.85316",
    "lng": "-74.11375"
  },
  {
    "country": "US",
    "name": "Wanaque",
    "lat": "41.03815",
    "lng": "-74.29404"
  },
  {
    "country": "US",
    "name": "Wanamassa",
    "lat": "40.23178",
    "lng": "-74.02542"
  },
  {
    "country": "US",
    "name": "Washington",
    "lat": "40.75843",
    "lng": "-74.97934"
  },
  {
    "country": "US",
    "name": "Watchung",
    "lat": "40.63788",
    "lng": "-74.45099"
  },
  {
    "country": "US",
    "name": "Wayne",
    "lat": "40.92538",
    "lng": "-74.27654"
  },
  {
    "country": "US",
    "name": "Weehawken",
    "lat": "40.76955",
    "lng": "-74.02042"
  },
  {
    "country": "US",
    "name": "West Belmar",
    "lat": "40.16928",
    "lng": "-74.03542"
  },
  {
    "country": "US",
    "name": "West Caldwell",
    "lat": "40.84093",
    "lng": "-74.30182"
  },
  {
    "country": "US",
    "name": "West Freehold",
    "lat": "40.24206",
    "lng": "-74.30126"
  },
  {
    "country": "US",
    "name": "West Long Branch",
    "lat": "40.29039",
    "lng": "-74.01764"
  },
  {
    "country": "US",
    "name": "West Milford",
    "lat": "41.13121",
    "lng": "-74.36737"
  },
  {
    "country": "US",
    "name": "West New York",
    "lat": "40.78788",
    "lng": "-74.01431"
  },
  {
    "country": "US",
    "name": "West Orange",
    "lat": "40.79871",
    "lng": "-74.23904"
  },
  {
    "country": "US",
    "name": "Woodland Park",
    "lat": "40.88982",
    "lng": "-74.19487"
  },
  {
    "country": "US",
    "name": "Westfield",
    "lat": "40.65899",
    "lng": "-74.34737"
  },
  {
    "country": "US",
    "name": "Weston",
    "lat": "40.5351",
    "lng": "-74.59071"
  },
  {
    "country": "US",
    "name": "Westville",
    "lat": "40.84454",
    "lng": "-74.29959"
  },
  {
    "country": "US",
    "name": "Westwood",
    "lat": "40.99121",
    "lng": "-74.03264"
  },
  {
    "country": "US",
    "name": "Wharton",
    "lat": "40.89315",
    "lng": "-74.58183"
  },
  {
    "country": "US",
    "name": "White Horse",
    "lat": "40.19067",
    "lng": "-74.70238"
  },
  {
    "country": "US",
    "name": "White Meadow Lake",
    "lat": "40.92371",
    "lng": "-74.51071"
  },
  {
    "country": "US",
    "name": "Whitehouse Station",
    "lat": "40.61538",
    "lng": "-74.77044"
  },
  {
    "country": "US",
    "name": "Willingboro",
    "lat": "40.02789",
    "lng": "-74.86905"
  },
  {
    "country": "US",
    "name": "Winfield",
    "lat": "40.6426",
    "lng": "-74.28543"
  },
  {
    "country": "US",
    "name": "Wood-Ridge",
    "lat": "40.84566",
    "lng": "-74.08792"
  },
  {
    "country": "US",
    "name": "Woodbridge",
    "lat": "40.5576",
    "lng": "-74.28459"
  },
  {
    "country": "US",
    "name": "Woodcliff Lake",
    "lat": "41.02343",
    "lng": "-74.06653"
  },
  {
    "country": "US",
    "name": "Wyckoff",
    "lat": "41.00954",
    "lng": "-74.17292"
  },
  {
    "country": "US",
    "name": "Yorketown",
    "lat": "40.30789",
    "lng": "-74.33765"
  },
  {
    "country": "US",
    "name": "Adams",
    "lat": "43.80923",
    "lng": "-76.02409"
  },
  {
    "country": "US",
    "name": "Adams Center",
    "lat": "43.86006",
    "lng": "-76.00548"
  },
  {
    "country": "US",
    "name": "Addison",
    "lat": "42.10285",
    "lng": "-77.23359"
  },
  {
    "country": "US",
    "name": "Airmont",
    "lat": "41.10093",
    "lng": "-74.11625"
  },
  {
    "country": "US",
    "name": "Akron",
    "lat": "43.02089",
    "lng": "-78.4953"
  },
  {
    "country": "US",
    "name": "Albany",
    "lat": "42.65258",
    "lng": "-73.75623"
  },
  {
    "country": "US",
    "name": "Albertson",
    "lat": "40.77343",
    "lng": "-73.64318"
  },
  {
    "country": "US",
    "name": "Albion",
    "lat": "43.24645",
    "lng": "-78.19363"
  },
  {
    "country": "US",
    "name": "Alabama",
    "lat": "43.09645",
    "lng": "-78.39086"
  },
  {
    "country": "US",
    "name": "Alden",
    "lat": "42.90006",
    "lng": "-78.49197"
  },
  {
    "country": "US",
    "name": "Alexandria Bay",
    "lat": "44.33588",
    "lng": "-75.91773"
  },
  {
    "country": "US",
    "name": "Alfred",
    "lat": "42.25424",
    "lng": "-77.79055"
  },
  {
    "country": "US",
    "name": "Allegany",
    "lat": "42.09006",
    "lng": "-78.49419"
  },
  {
    "country": "US",
    "name": "Altamont",
    "lat": "42.70063",
    "lng": "-74.03374"
  },
  {
    "country": "US",
    "name": "Amagansett",
    "lat": "40.97371",
    "lng": "-72.14369"
  },
  {
    "country": "US",
    "name": "Amherst",
    "lat": "42.97839",
    "lng": "-78.79976"
  },
  {
    "country": "US",
    "name": "Amityville",
    "lat": "40.67899",
    "lng": "-73.41707"
  },
  {
    "country": "US",
    "name": "Amsterdam",
    "lat": "42.93869",
    "lng": "-74.18819"
  },
  {
    "country": "US",
    "name": "Andover",
    "lat": "42.15646",
    "lng": "-77.79555"
  },
  {
    "country": "US",
    "name": "Angola on the Lake",
    "lat": "42.65478",
    "lng": "-79.04893"
  },
  {
    "country": "US",
    "name": "Angola",
    "lat": "42.63839",
    "lng": "-79.02782"
  },
  {
    "country": "US",
    "name": "Apalachin",
    "lat": "42.06952",
    "lng": "-76.15465"
  },
  {
    "country": "US",
    "name": "Aquebogue",
    "lat": "40.94454",
    "lng": "-72.62704"
  },
  {
    "country": "US",
    "name": "Arcade",
    "lat": "42.53395",
    "lng": "-78.42307"
  },
  {
    "country": "US",
    "name": "Ardsley",
    "lat": "41.01065",
    "lng": "-73.84375"
  },
  {
    "country": "US",
    "name": "Arlington",
    "lat": "41.69593",
    "lng": "-73.8968"
  },
  {
    "country": "US",
    "name": "Armonk",
    "lat": "41.12648",
    "lng": "-73.71402"
  },
  {
    "country": "US",
    "name": "Arrochar",
    "lat": "40.59844",
    "lng": "-74.07264"
  },
  {
    "country": "US",
    "name": "Arverne",
    "lat": "40.59122",
    "lng": "-73.79597"
  },
  {
    "country": "US",
    "name": "Astoria",
    "lat": "40.77205",
    "lng": "-73.93014"
  },
  {
    "country": "US",
    "name": "Athens",
    "lat": "42.26036",
    "lng": "-73.80957"
  },
  {
    "country": "US",
    "name": "Atlantic Beach",
    "lat": "40.58899",
    "lng": "-73.72902"
  },
  {
    "country": "US",
    "name": "Attica",
    "lat": "42.86423",
    "lng": "-78.28029"
  },
  {
    "country": "US",
    "name": "Auburn",
    "lat": "42.93173",
    "lng": "-76.56605"
  },
  {
    "country": "US",
    "name": "Augusta",
    "lat": "42.97479",
    "lng": "-75.50129"
  },
  {
    "country": "US",
    "name": "Averill Park",
    "lat": "42.63397",
    "lng": "-73.55373"
  },
  {
    "country": "US",
    "name": "Avon",
    "lat": "42.91201",
    "lng": "-77.74556"
  },
  {
    "country": "US",
    "name": "Babylon",
    "lat": "40.69566",
    "lng": "-73.32568"
  },
  {
    "country": "US",
    "name": "Bainbridge",
    "lat": "42.29341",
    "lng": "-75.47935"
  },
  {
    "country": "US",
    "name": "Baiting Hollow",
    "lat": "40.95621",
    "lng": "-72.74427"
  },
  {
    "country": "US",
    "name": "Baldwin",
    "lat": "40.65649",
    "lng": "-73.6093"
  },
  {
    "country": "US",
    "name": "Baldwin Harbor",
    "lat": "40.63955",
    "lng": "-73.60846"
  },
  {
    "country": "US",
    "name": "Baldwinsville",
    "lat": "43.15868",
    "lng": "-76.33271"
  },
  {
    "country": "US",
    "name": "Ballston Spa",
    "lat": "43.00091",
    "lng": "-73.84901"
  },
  {
    "country": "US",
    "name": "Balmville",
    "lat": "41.53482",
    "lng": "-74.01486"
  },
  {
    "country": "US",
    "name": "Bardonia",
    "lat": "41.10954",
    "lng": "-73.99625"
  },
  {
    "country": "US",
    "name": "Barnum Island",
    "lat": "40.60455",
    "lng": "-73.64402"
  },
  {
    "country": "US",
    "name": "Batavia",
    "lat": "42.99812",
    "lng": "-78.18752"
  },
  {
    "country": "US",
    "name": "Bath",
    "lat": "42.33702",
    "lng": "-77.31776"
  },
  {
    "country": "US",
    "name": "Bath Beach",
    "lat": "40.60455",
    "lng": "-74.00431"
  },
  {
    "country": "US",
    "name": "Bay Park",
    "lat": "40.63316",
    "lng": "-73.67041"
  },
  {
    "country": "US",
    "name": "Bay Shore",
    "lat": "40.7251",
    "lng": "-73.24539"
  },
  {
    "country": "US",
    "name": "Baxter Estates",
    "lat": "40.83482",
    "lng": "-73.69541"
  },
  {
    "country": "US",
    "name": "Bay Wood",
    "lat": "40.7501",
    "lng": "-73.29123"
  },
  {
    "country": "US",
    "name": "Baychester",
    "lat": "40.86928",
    "lng": "-73.83645"
  },
  {
    "country": "US",
    "name": "Bayport",
    "lat": "40.73843",
    "lng": "-73.05067"
  },
  {
    "country": "US",
    "name": "Bayside",
    "lat": "40.76844",
    "lng": "-73.77708"
  },
  {
    "country": "US",
    "name": "Bayville",
    "lat": "40.91065",
    "lng": "-73.56207"
  },
  {
    "country": "US",
    "name": "Beacon",
    "lat": "41.50482",
    "lng": "-73.96958"
  },
  {
    "country": "US",
    "name": "Bedford",
    "lat": "41.20426",
    "lng": "-73.64374"
  },
  {
    "country": "US",
    "name": "Bedford Hills",
    "lat": "41.23676",
    "lng": "-73.69458"
  },
  {
    "country": "US",
    "name": "Bellaire",
    "lat": "40.71399",
    "lng": "-73.75402"
  },
  {
    "country": "US",
    "name": "Belle Harbor",
    "lat": "40.57594",
    "lng": "-73.84819"
  },
  {
    "country": "US",
    "name": "Bellerose",
    "lat": "40.72427",
    "lng": "-73.71513"
  },
  {
    "country": "US",
    "name": "Bellerose Terrace",
    "lat": "40.72066",
    "lng": "-73.72596"
  },
  {
    "country": "US",
    "name": "Bellmore",
    "lat": "40.66871",
    "lng": "-73.52707"
  },
  {
    "country": "US",
    "name": "Bellport",
    "lat": "40.75704",
    "lng": "-72.93927"
  },
  {
    "country": "US",
    "name": "Belmont",
    "lat": "42.22312",
    "lng": "-78.03445"
  },
  {
    "country": "US",
    "name": "Bensonhurst",
    "lat": "40.60177",
    "lng": "-73.99403"
  },
  {
    "country": "US",
    "name": "Bergen",
    "lat": "43.08534",
    "lng": "-77.94223"
  },
  {
    "country": "US",
    "name": "Bergen Beach",
    "lat": "40.62038",
    "lng": "-73.9068"
  },
  {
    "country": "US",
    "name": "Bethpage",
    "lat": "40.74427",
    "lng": "-73.48207"
  },
  {
    "country": "US",
    "name": "Big Flats",
    "lat": "42.1373",
    "lng": "-76.93691"
  },
  {
    "country": "US",
    "name": "Billington Heights",
    "lat": "42.78423",
    "lng": "-78.62642"
  },
  {
    "country": "US",
    "name": "Binghamton",
    "lat": "42.09869",
    "lng": "-75.91797"
  },
  {
    "country": "US",
    "name": "Black River",
    "lat": "44.01256",
    "lng": "-75.79437"
  },
  {
    "country": "US",
    "name": "Blasdell",
    "lat": "42.79728",
    "lng": "-78.82337"
  },
  {
    "country": "US",
    "name": "Blauvelt",
    "lat": "41.06343",
    "lng": "-73.95764"
  },
  {
    "country": "US",
    "name": "Bloomfield",
    "lat": "40.6126",
    "lng": "-74.1782"
  },
  {
    "country": "US",
    "name": "Blue Point",
    "lat": "40.74399",
    "lng": "-73.03455"
  },
  {
    "country": "US",
    "name": "Bohemia",
    "lat": "40.76926",
    "lng": "-73.11511"
  },
  {
    "country": "US",
    "name": "Bolivar",
    "lat": "42.06673",
    "lng": "-78.16779"
  },
  {
    "country": "US",
    "name": "Bolivar",
    "lat": "43.07118",
    "lng": "-75.8888"
  },
  {
    "country": "US",
    "name": "Boonville",
    "lat": "43.48368",
    "lng": "-75.33656"
  },
  {
    "country": "US",
    "name": "Borough Park",
    "lat": "40.63399",
    "lng": "-73.99681"
  },
  {
    "country": "US",
    "name": "Boston",
    "lat": "42.62895",
    "lng": "-78.73753"
  },
  {
    "country": "US",
    "name": "Brentwood",
    "lat": "40.78121",
    "lng": "-73.24623"
  },
  {
    "country": "US",
    "name": "Brewerton",
    "lat": "43.23812",
    "lng": "-76.14076"
  },
  {
    "country": "US",
    "name": "Brewster",
    "lat": "41.39732",
    "lng": "-73.61707"
  },
  {
    "country": "US",
    "name": "Brewster Hill",
    "lat": "41.42398",
    "lng": "-73.60429"
  },
  {
    "country": "US",
    "name": "Briarcliff Manor",
    "lat": "41.14565",
    "lng": "-73.82375"
  },
  {
    "country": "US",
    "name": "Bridgehampton",
    "lat": "40.93788",
    "lng": "-72.30092"
  },
  {
    "country": "US",
    "name": "Bridgeport",
    "lat": "43.15535",
    "lng": "-75.96936"
  },
  {
    "country": "US",
    "name": "Bridgeport",
    "lat": "42.9159",
    "lng": "-76.75245"
  },
  {
    "country": "US",
    "name": "Brighton",
    "lat": "43.14756",
    "lng": "-77.55055"
  },
  {
    "country": "US",
    "name": "Brighton Beach",
    "lat": "40.57788",
    "lng": "-73.95958"
  },
  {
    "country": "US",
    "name": "Brightwaters",
    "lat": "40.72093",
    "lng": "-73.26734"
  },
  {
    "country": "US",
    "name": "Brinckerhoff",
    "lat": "41.54398",
    "lng": "-73.86819"
  },
  {
    "country": "US",
    "name": "Broad Channel",
    "lat": "40.60316",
    "lng": "-73.82041"
  },
  {
    "country": "US",
    "name": "Broadalbin",
    "lat": "43.05868",
    "lng": "-74.19652"
  },
  {
    "country": "US",
    "name": "Brockport",
    "lat": "43.21367",
    "lng": "-77.93918"
  },
  {
    "country": "US",
    "name": "Brocton",
    "lat": "42.38867",
    "lng": "-79.44116"
  },
  {
    "country": "US",
    "name": "The Bronx",
    "lat": "40.84985",
    "lng": "-73.86641"
  },
  {
    "country": "US",
    "name": "Bronxville",
    "lat": "40.93815",
    "lng": "-73.83208"
  },
  {
    "country": "US",
    "name": "Brookhaven",
    "lat": "40.77927",
    "lng": "-72.91538"
  },
  {
    "country": "US",
    "name": "Brooklyn",
    "lat": "40.6501",
    "lng": "-73.94958"
  },
  {
    "country": "US",
    "name": "Brooklyn Heights",
    "lat": "40.69538",
    "lng": "-73.99375"
  },
  {
    "country": "US",
    "name": "Brookville",
    "lat": "40.81316",
    "lng": "-73.56735"
  },
  {
    "country": "US",
    "name": "Brownsville",
    "lat": "40.66094",
    "lng": "-73.92014"
  },
  {
    "country": "US",
    "name": "Brownville",
    "lat": "44.007",
    "lng": "-75.98409"
  },
  {
    "country": "US",
    "name": "Brownville",
    "lat": "41.79982",
    "lng": "-74.38071"
  },
  {
    "country": "US",
    "name": "Buchanan",
    "lat": "41.26204",
    "lng": "-73.93819"
  },
  {
    "country": "US",
    "name": "Buffalo",
    "lat": "42.88645",
    "lng": "-78.87837"
  },
  {
    "country": "US",
    "name": "Bushwick",
    "lat": "40.69427",
    "lng": "-73.91875"
  },
  {
    "country": "US",
    "name": "Cairo",
    "lat": "42.29897",
    "lng": "-73.99847"
  },
  {
    "country": "US",
    "name": "Calcium",
    "lat": "44.02173",
    "lng": "-75.84604"
  },
  {
    "country": "US",
    "name": "Caledonia",
    "lat": "42.97312",
    "lng": "-77.85278"
  },
  {
    "country": "US",
    "name": "Calverton",
    "lat": "40.90649",
    "lng": "-72.74343"
  },
  {
    "country": "US",
    "name": "Cambria Heights",
    "lat": "40.69455",
    "lng": "-73.73847"
  },
  {
    "country": "US",
    "name": "Cambridge",
    "lat": "43.02813",
    "lng": "-73.38122"
  },
  {
    "country": "US",
    "name": "Camden",
    "lat": "43.33451",
    "lng": "-75.74796"
  },
  {
    "country": "US",
    "name": "Canajoharie",
    "lat": "42.90563",
    "lng": "-74.57181"
  },
  {
    "country": "US",
    "name": "Canandaigua",
    "lat": "42.87423",
    "lng": "-77.28804"
  },
  {
    "country": "US",
    "name": "Canarsie",
    "lat": "40.64372",
    "lng": "-73.90069"
  },
  {
    "country": "US",
    "name": "Canastota",
    "lat": "43.07951",
    "lng": "-75.75074"
  },
  {
    "country": "US",
    "name": "Canisteo",
    "lat": "42.27035",
    "lng": "-77.60582"
  },
  {
    "country": "US",
    "name": "Canton",
    "lat": "44.59562",
    "lng": "-75.16909"
  },
  {
    "country": "US",
    "name": "Carle Place",
    "lat": "40.7526",
    "lng": "-73.61041"
  },
  {
    "country": "US",
    "name": "Carmel",
    "lat": "41.43009",
    "lng": "-73.68013"
  },
  {
    "country": "US",
    "name": "Carthage",
    "lat": "43.97812",
    "lng": "-75.60936"
  },
  {
    "country": "US",
    "name": "Castleton-on-Hudson",
    "lat": "42.51841",
    "lng": "-73.75123"
  },
  {
    "country": "US",
    "name": "Catskill",
    "lat": "42.21731",
    "lng": "-73.86457"
  },
  {
    "country": "US",
    "name": "Cayuga Heights",
    "lat": "42.4601",
    "lng": "-76.48776"
  },
  {
    "country": "US",
    "name": "Cazenovia",
    "lat": "42.93007",
    "lng": "-75.85269"
  },
  {
    "country": "US",
    "name": "Cedarhurst",
    "lat": "40.62288",
    "lng": "-73.7243"
  },
  {
    "country": "US",
    "name": "Celoron",
    "lat": "42.1095",
    "lng": "-79.2831"
  },
  {
    "country": "US",
    "name": "Center Moriches",
    "lat": "40.80038",
    "lng": "-72.78982"
  },
  {
    "country": "US",
    "name": "Centereach",
    "lat": "40.85843",
    "lng": "-73.09955"
  },
  {
    "country": "US",
    "name": "Centerport",
    "lat": "43.0409",
    "lng": "-76.59272"
  },
  {
    "country": "US",
    "name": "Centerport",
    "lat": "40.88538",
    "lng": "-73.37623"
  },
  {
    "country": "US",
    "name": "Central Islip",
    "lat": "40.79065",
    "lng": "-73.20178"
  },
  {
    "country": "US",
    "name": "Central Square",
    "lat": "43.28674",
    "lng": "-76.14604"
  },
  {
    "country": "US",
    "name": "Central Valley",
    "lat": "41.33176",
    "lng": "-74.12098"
  },
  {
    "country": "US",
    "name": "Chadwicks",
    "lat": "43.02785",
    "lng": "-75.27155"
  },
  {
    "country": "US",
    "name": "Champlain",
    "lat": "44.98643",
    "lng": "-73.44653"
  },
  {
    "country": "US",
    "name": "Chappaqua",
    "lat": "41.15954",
    "lng": "-73.76485"
  },
  {
    "country": "US",
    "name": "Charleston",
    "lat": "40.53677",
    "lng": "-74.23737"
  },
  {
    "country": "US",
    "name": "Chatham",
    "lat": "42.36425",
    "lng": "-73.59484"
  },
  {
    "country": "US",
    "name": "Cheektowaga",
    "lat": "42.90339",
    "lng": "-78.75475"
  },
  {
    "country": "US",
    "name": "Chelsea",
    "lat": "40.60066",
    "lng": "-74.19487"
  },
  {
    "country": "US",
    "name": "Chenango Bridge",
    "lat": "42.16674",
    "lng": "-75.86242"
  },
  {
    "country": "US",
    "name": "Chester",
    "lat": "41.36259",
    "lng": "-74.27126"
  },
  {
    "country": "US",
    "name": "Chestnut Ridge",
    "lat": "41.08426",
    "lng": "-74.0557"
  },
  {
    "country": "US",
    "name": "Chittenango",
    "lat": "43.04507",
    "lng": "-75.86658"
  },
  {
    "country": "US",
    "name": "Churchville",
    "lat": "43.10423",
    "lng": "-77.88445"
  },
  {
    "country": "US",
    "name": "City Island",
    "lat": "40.84732",
    "lng": "-73.78652"
  },
  {
    "country": "US",
    "name": "Clarence",
    "lat": "42.97673",
    "lng": "-78.59197"
  },
  {
    "country": "US",
    "name": "Clarence Center",
    "lat": "43.01061",
    "lng": "-78.63753"
  },
  {
    "country": "US",
    "name": "Clark Mills",
    "lat": "43.09229",
    "lng": "-75.37962"
  },
  {
    "country": "US",
    "name": "Clarkson",
    "lat": "43.23312",
    "lng": "-77.92751"
  },
  {
    "country": "US",
    "name": "Clayton",
    "lat": "44.23949",
    "lng": "-76.08578"
  },
  {
    "country": "US",
    "name": "Clifton",
    "lat": "40.6201",
    "lng": "-74.07709"
  },
  {
    "country": "US",
    "name": "Clifton Springs",
    "lat": "42.96173",
    "lng": "-77.13998"
  },
  {
    "country": "US",
    "name": "Clinton",
    "lat": "43.0484",
    "lng": "-75.3785"
  },
  {
    "country": "US",
    "name": "Clintondale",
    "lat": "41.69482",
    "lng": "-74.05125"
  },
  {
    "country": "US",
    "name": "Clymer",
    "lat": "42.02089",
    "lng": "-79.63005"
  },
  {
    "country": "US",
    "name": "Cobleskill",
    "lat": "42.67785",
    "lng": "-74.48542"
  },
  {
    "country": "US",
    "name": "Cohoes",
    "lat": "42.77424",
    "lng": "-73.70012"
  },
  {
    "country": "US",
    "name": "Cold Spring",
    "lat": "41.42009",
    "lng": "-73.95458"
  },
  {
    "country": "US",
    "name": "Cold Spring Harbor",
    "lat": "40.87149",
    "lng": "-73.45679"
  },
  {
    "country": "US",
    "name": "College Point",
    "lat": "40.7876",
    "lng": "-73.84597"
  },
  {
    "country": "US",
    "name": "Colonie",
    "lat": "42.71786",
    "lng": "-73.83346"
  },
  {
    "country": "US",
    "name": "Commack",
    "lat": "40.84288",
    "lng": "-73.29289"
  },
  {
    "country": "US",
    "name": "Concord",
    "lat": "40.60816",
    "lng": "-74.08431"
  },
  {
    "country": "US",
    "name": "Coney Island",
    "lat": "40.57788",
    "lng": "-73.99403"
  },
  {
    "country": "US",
    "name": "Congers",
    "lat": "41.15065",
    "lng": "-73.94542"
  },
  {
    "country": "US",
    "name": "Constantia",
    "lat": "43.24785",
    "lng": "-76.0002"
  },
  {
    "country": "US",
    "name": "Cooperstown",
    "lat": "42.70048",
    "lng": "-74.92426"
  },
  {
    "country": "US",
    "name": "Copiague",
    "lat": "40.68149",
    "lng": "-73.39984"
  },
  {
    "country": "US",
    "name": "Coram",
    "lat": "40.86871",
    "lng": "-73.00149"
  },
  {
    "country": "US",
    "name": "Corinth",
    "lat": "43.24452",
    "lng": "-73.83234"
  },
  {
    "country": "US",
    "name": "Corning",
    "lat": "42.14285",
    "lng": "-77.05469"
  },
  {
    "country": "US",
    "name": "Cornwall",
    "lat": "41.44482",
    "lng": "-74.0157"
  },
  {
    "country": "US",
    "name": "Corona",
    "lat": "40.74705",
    "lng": "-73.86014"
  },
  {
    "country": "US",
    "name": "Cortland",
    "lat": "42.60118",
    "lng": "-76.18048"
  },
  {
    "country": "US",
    "name": "Country Knolls",
    "lat": "42.91508",
    "lng": "-73.80512"
  },
  {
    "country": "US",
    "name": "Coxsackie",
    "lat": "42.35092",
    "lng": "-73.8029"
  },
  {
    "country": "US",
    "name": "Crompond",
    "lat": "41.29509",
    "lng": "-73.86541"
  },
  {
    "country": "US",
    "name": "Croton-on-Hudson",
    "lat": "41.20843",
    "lng": "-73.89125"
  },
  {
    "country": "US",
    "name": "Crown Heights",
    "lat": "41.63732",
    "lng": "-73.93792"
  },
  {
    "country": "US",
    "name": "Crugers",
    "lat": "41.23343",
    "lng": "-73.92264"
  },
  {
    "country": "US",
    "name": "Cuba",
    "lat": "42.21757",
    "lng": "-78.27529"
  },
  {
    "country": "US",
    "name": "Cumberland Head",
    "lat": "44.71643",
    "lng": "-73.40263"
  },
  {
    "country": "US",
    "name": "Cutchogue",
    "lat": "41.01066",
    "lng": "-72.48509"
  },
  {
    "country": "US",
    "name": "Cypress Hills",
    "lat": "40.67705",
    "lng": "-73.89125"
  },
  {
    "country": "US",
    "name": "Dannemora",
    "lat": "44.72143",
    "lng": "-73.72375"
  },
  {
    "country": "US",
    "name": "Dansville",
    "lat": "42.5609",
    "lng": "-77.69611"
  },
  {
    "country": "US",
    "name": "Deer Park",
    "lat": "40.76177",
    "lng": "-73.32929"
  },
  {
    "country": "US",
    "name": "Delevan",
    "lat": "42.48923",
    "lng": "-78.48085"
  },
  {
    "country": "US",
    "name": "Delhi",
    "lat": "42.27814",
    "lng": "-74.91599"
  },
  {
    "country": "US",
    "name": "Delmar",
    "lat": "42.62202",
    "lng": "-73.83262"
  },
  {
    "country": "US",
    "name": "Depew",
    "lat": "42.90395",
    "lng": "-78.69225"
  },
  {
    "country": "US",
    "name": "Deposit",
    "lat": "42.06008",
    "lng": "-75.42768"
  },
  {
    "country": "US",
    "name": "Dexter",
    "lat": "44.00784",
    "lng": "-76.04437"
  },
  {
    "country": "US",
    "name": "Dix Hills",
    "lat": "40.80482",
    "lng": "-73.33623"
  },
  {
    "country": "US",
    "name": "Dobbs Ferry",
    "lat": "41.01454",
    "lng": "-73.87264"
  },
  {
    "country": "US",
    "name": "Dolgeville",
    "lat": "43.1009",
    "lng": "-74.77293"
  },
  {
    "country": "US",
    "name": "Dongan Hills",
    "lat": "40.58844",
    "lng": "-74.09625"
  },
  {
    "country": "US",
    "name": "Douglaston",
    "lat": "40.76871",
    "lng": "-73.74708"
  },
  {
    "country": "US",
    "name": "Dover Plains",
    "lat": "41.74121",
    "lng": "-73.57652"
  },
  {
    "country": "US",
    "name": "Dryden",
    "lat": "42.49091",
    "lng": "-76.29716"
  },
  {
    "country": "US",
    "name": "Dundee",
    "lat": "42.5234",
    "lng": "-76.97663"
  },
  {
    "country": "US",
    "name": "Dunkirk",
    "lat": "42.4795",
    "lng": "-79.33393"
  },
  {
    "country": "US",
    "name": "Durham",
    "lat": "42.39953",
    "lng": "-74.17236"
  },
  {
    "country": "US",
    "name": "Dyker Heights",
    "lat": "40.62149",
    "lng": "-74.00958"
  },
  {
    "country": "US",
    "name": "East Atlantic Beach",
    "lat": "40.78982",
    "lng": "-73.74708"
  },
  {
    "country": "US",
    "name": "East Aurora",
    "lat": "42.76784",
    "lng": "-78.61336"
  },
  {
    "country": "US",
    "name": "East Farmingdale",
    "lat": "40.72927",
    "lng": "-73.41679"
  },
  {
    "country": "US",
    "name": "East Flatbush",
    "lat": "40.65371",
    "lng": "-73.93042"
  },
  {
    "country": "US",
    "name": "East Garden City",
    "lat": "40.73083",
    "lng": "-73.59806"
  },
  {
    "country": "US",
    "name": "East Glenville",
    "lat": "42.89452",
    "lng": "-73.9279"
  },
  {
    "country": "US",
    "name": "East Greenbush",
    "lat": "42.59091",
    "lng": "-73.70179"
  },
  {
    "country": "US",
    "name": "East Hampton",
    "lat": "40.96343",
    "lng": "-72.1848"
  },
  {
    "country": "US",
    "name": "East Hills",
    "lat": "40.79371",
    "lng": "-73.62707"
  },
  {
    "country": "US",
    "name": "East Islip",
    "lat": "40.73204",
    "lng": "-73.18567"
  },
  {
    "country": "US",
    "name": "East Ithaca",
    "lat": "42.43952",
    "lng": "-76.47855"
  },
  {
    "country": "US",
    "name": "East Meadow",
    "lat": "40.71399",
    "lng": "-73.55902"
  },
  {
    "country": "US",
    "name": "East Massapequa",
    "lat": "40.67343",
    "lng": "-73.43651"
  },
  {
    "country": "US",
    "name": "East Moriches",
    "lat": "40.8051",
    "lng": "-72.76093"
  },
  {
    "country": "US",
    "name": "East New York",
    "lat": "40.66677",
    "lng": "-73.88236"
  },
  {
    "country": "US",
    "name": "East Northport",
    "lat": "40.87676",
    "lng": "-73.32456"
  },
  {
    "country": "US",
    "name": "East Norwich",
    "lat": "40.84677",
    "lng": "-73.53512"
  },
  {
    "country": "US",
    "name": "East Patchogue",
    "lat": "40.76704",
    "lng": "-72.99622"
  },
  {
    "country": "US",
    "name": "East Quogue",
    "lat": "40.84066",
    "lng": "-72.58148"
  },
  {
    "country": "US",
    "name": "East Rochester",
    "lat": "43.10867",
    "lng": "-77.4875"
  },
  {
    "country": "US",
    "name": "East Rockaway",
    "lat": "40.64205",
    "lng": "-73.66957"
  },
  {
    "country": "US",
    "name": "East Setauket",
    "lat": "40.94149",
    "lng": "-73.10594"
  },
  {
    "country": "US",
    "name": "East Shoreham",
    "lat": "40.94482",
    "lng": "-72.87955"
  },
  {
    "country": "US",
    "name": "East Syracuse",
    "lat": "43.06534",
    "lng": "-76.07853"
  },
  {
    "country": "US",
    "name": "East Tremont",
    "lat": "40.84538",
    "lng": "-73.89097"
  },
  {
    "country": "US",
    "name": "East Village",
    "lat": "40.72927",
    "lng": "-73.98736"
  },
  {
    "country": "US",
    "name": "East Williston",
    "lat": "40.75843",
    "lng": "-73.63485"
  },
  {
    "country": "US",
    "name": "Eastchester",
    "lat": "40.95833",
    "lng": "-73.80861"
  },
  {
    "country": "US",
    "name": "Eastchester",
    "lat": "40.88601",
    "lng": "-73.82804"
  },
  {
    "country": "US",
    "name": "Eastport",
    "lat": "40.82593",
    "lng": "-72.73177"
  },
  {
    "country": "US",
    "name": "Eatons Neck",
    "lat": "40.93065",
    "lng": "-73.40151"
  },
  {
    "country": "US",
    "name": "Eden",
    "lat": "42.65228",
    "lng": "-78.89698"
  },
  {
    "country": "US",
    "name": "Eden",
    "lat": "41.28871",
    "lng": "-74.49433"
  },
  {
    "country": "US",
    "name": "Edgemere",
    "lat": "40.59622",
    "lng": "-73.76763"
  },
  {
    "country": "US",
    "name": "Edinburg",
    "lat": "43.22174",
    "lng": "-74.10402"
  },
  {
    "country": "US",
    "name": "Eggertsville",
    "lat": "42.96339",
    "lng": "-78.80392"
  },
  {
    "country": "US",
    "name": "Elbridge",
    "lat": "43.03451",
    "lng": "-76.44799"
  },
  {
    "country": "US",
    "name": "Elizabethtown",
    "lat": "44.21616",
    "lng": "-73.59097"
  },
  {
    "country": "US",
    "name": "Ellenville",
    "lat": "41.71704",
    "lng": "-74.39571"
  },
  {
    "country": "US",
    "name": "Elma Center",
    "lat": "42.82978",
    "lng": "-78.63614"
  },
  {
    "country": "US",
    "name": "Elmhurst",
    "lat": "40.73649",
    "lng": "-73.87791"
  },
  {
    "country": "US",
    "name": "Elmira",
    "lat": "42.0898",
    "lng": "-76.80773"
  },
  {
    "country": "US",
    "name": "Elmira Heights",
    "lat": "42.1298",
    "lng": "-76.82079"
  },
  {
    "country": "US",
    "name": "Elmont",
    "lat": "40.70094",
    "lng": "-73.71291"
  },
  {
    "country": "US",
    "name": "Elmsford",
    "lat": "41.0551",
    "lng": "-73.82013"
  },
  {
    "country": "US",
    "name": "Eltingville",
    "lat": "40.54538",
    "lng": "-74.1657"
  },
  {
    "country": "US",
    "name": "Elwood",
    "lat": "40.84538",
    "lng": "-73.33512"
  },
  {
    "country": "US",
    "name": "Emerson Hill",
    "lat": "40.60872",
    "lng": "-74.09598"
  },
  {
    "country": "US",
    "name": "Endicott",
    "lat": "42.09841",
    "lng": "-76.04937"
  },
  {
    "country": "US",
    "name": "Endwell",
    "lat": "42.11285",
    "lng": "-76.02103"
  },
  {
    "country": "US",
    "name": "Fairmount",
    "lat": "43.04729",
    "lng": "-76.23854"
  },
  {
    "country": "US",
    "name": "Fairport",
    "lat": "43.09867",
    "lng": "-77.44194"
  },
  {
    "country": "US",
    "name": "Fairview",
    "lat": "41.7237",
    "lng": "-73.91986"
  },
  {
    "country": "US",
    "name": "Fairview",
    "lat": "41.04343",
    "lng": "-73.79736"
  },
  {
    "country": "US",
    "name": "Falconer",
    "lat": "42.11867",
    "lng": "-79.19838"
  },
  {
    "country": "US",
    "name": "Fallsburg",
    "lat": "41.73204",
    "lng": "-74.60127"
  },
  {
    "country": "US",
    "name": "Far Rockaway",
    "lat": "40.60538",
    "lng": "-73.75513"
  },
  {
    "country": "US",
    "name": "Farmingdale",
    "lat": "40.7326",
    "lng": "-73.4454"
  },
  {
    "country": "US",
    "name": "Farmingville",
    "lat": "40.83121",
    "lng": "-73.02955"
  },
  {
    "country": "US",
    "name": "Fayetteville",
    "lat": "43.02979",
    "lng": "-76.00436"
  },
  {
    "country": "US",
    "name": "Firthcliffe",
    "lat": "41.43926",
    "lng": "-74.04514"
  },
  {
    "country": "US",
    "name": "Fishkill",
    "lat": "41.53565",
    "lng": "-73.89903"
  },
  {
    "country": "US",
    "name": "Flanders",
    "lat": "40.90343",
    "lng": "-72.61759"
  },
  {
    "country": "US",
    "name": "Flatbush",
    "lat": "40.65205",
    "lng": "-73.95903"
  },
  {
    "country": "US",
    "name": "Flatlands",
    "lat": "40.62122",
    "lng": "-73.93486"
  },
  {
    "country": "US",
    "name": "Floral Park",
    "lat": "40.72371",
    "lng": "-73.70485"
  },
  {
    "country": "US",
    "name": "Florida",
    "lat": "41.33176",
    "lng": "-74.35682"
  },
  {
    "country": "US",
    "name": "Flower Hill",
    "lat": "40.80732",
    "lng": "-73.68124"
  },
  {
    "country": "US",
    "name": "Fonda",
    "lat": "42.95452",
    "lng": "-74.37652"
  },
  {
    "country": "US",
    "name": "Fordham",
    "lat": "40.85927",
    "lng": "-73.89847"
  },
  {
    "country": "US",
    "name": "Forest Hills",
    "lat": "40.71621",
    "lng": "-73.85014"
  },
  {
    "country": "US",
    "name": "Fort Edward",
    "lat": "43.26702",
    "lng": "-73.58456"
  },
  {
    "country": "US",
    "name": "Fort Hamilton",
    "lat": "40.61872",
    "lng": "-74.0332"
  },
  {
    "country": "US",
    "name": "Fort Montgomery",
    "lat": "41.33148",
    "lng": "-73.98681"
  },
  {
    "country": "US",
    "name": "Fort Plain",
    "lat": "42.93146",
    "lng": "-74.62264"
  },
  {
    "country": "US",
    "name": "Fort Salonga",
    "lat": "40.9126",
    "lng": "-73.30095"
  },
  {
    "country": "US",
    "name": "Fort Wadsworth",
    "lat": "40.60113",
    "lng": "-74.05738"
  },
  {
    "country": "US",
    "name": "Frankfort",
    "lat": "43.03896",
    "lng": "-75.07044"
  },
  {
    "country": "US",
    "name": "Franklin Square",
    "lat": "40.70732",
    "lng": "-73.67596"
  },
  {
    "country": "US",
    "name": "Franklinville",
    "lat": "42.33701",
    "lng": "-78.45808"
  },
  {
    "country": "US",
    "name": "Fredonia",
    "lat": "42.44006",
    "lng": "-79.33171"
  },
  {
    "country": "US",
    "name": "Freeport",
    "lat": "40.6576",
    "lng": "-73.58318"
  },
  {
    "country": "US",
    "name": "Fresh Meadows",
    "lat": "40.73482",
    "lng": "-73.79347"
  },
  {
    "country": "US",
    "name": "Frewsburg",
    "lat": "42.0545",
    "lng": "-79.1581"
  },
  {
    "country": "US",
    "name": "Friendship",
    "lat": "42.20646",
    "lng": "-78.13751"
  },
  {
    "country": "US",
    "name": "Fulton",
    "lat": "43.32285",
    "lng": "-76.41716"
  },
  {
    "country": "US",
    "name": "Galeville",
    "lat": "43.09007",
    "lng": "-76.17298"
  },
  {
    "country": "US",
    "name": "Garden City",
    "lat": "40.72677",
    "lng": "-73.6343"
  },
  {
    "country": "US",
    "name": "Garden City Park",
    "lat": "40.74093",
    "lng": "-73.66263"
  },
  {
    "country": "US",
    "name": "Garden City South",
    "lat": "40.71232",
    "lng": "-73.66096"
  },
  {
    "country": "US",
    "name": "Gang Mills",
    "lat": "42.14619",
    "lng": "-77.11164"
  },
  {
    "country": "US",
    "name": "Gardnertown",
    "lat": "41.53509",
    "lng": "-74.07014"
  },
  {
    "country": "US",
    "name": "Gasport",
    "lat": "43.19922",
    "lng": "-78.57614"
  },
  {
    "country": "US",
    "name": "Geneseo",
    "lat": "42.7959",
    "lng": "-77.81695"
  },
  {
    "country": "US",
    "name": "Geneva",
    "lat": "42.86896",
    "lng": "-76.97774"
  },
  {
    "country": "US",
    "name": "Glasco",
    "lat": "42.0437",
    "lng": "-73.94736"
  },
  {
    "country": "US",
    "name": "Glen Cove",
    "lat": "40.86232",
    "lng": "-73.63374"
  },
  {
    "country": "US",
    "name": "Glen Head",
    "lat": "40.83538",
    "lng": "-73.62374"
  },
  {
    "country": "US",
    "name": "Glen Oaks",
    "lat": "40.74705",
    "lng": "-73.71152"
  },
  {
    "country": "US",
    "name": "Glendale",
    "lat": "40.70149",
    "lng": "-73.8868"
  },
  {
    "country": "US",
    "name": "Glens Falls",
    "lat": "43.30952",
    "lng": "-73.64401"
  },
  {
    "country": "US",
    "name": "Glenwood Landing",
    "lat": "40.83066",
    "lng": "-73.63874"
  },
  {
    "country": "US",
    "name": "Gloversville",
    "lat": "43.05285",
    "lng": "-74.34375"
  },
  {
    "country": "US",
    "name": "Goldens Bridge",
    "lat": "41.29343",
    "lng": "-73.6768"
  },
  {
    "country": "US",
    "name": "Gordon Heights",
    "lat": "40.85871",
    "lng": "-72.97066"
  },
  {
    "country": "US",
    "name": "Goshen",
    "lat": "41.40204",
    "lng": "-74.32432"
  },
  {
    "country": "US",
    "name": "Gouverneur",
    "lat": "44.33673",
    "lng": "-75.46299"
  },
  {
    "country": "US",
    "name": "Gowanda",
    "lat": "42.46312",
    "lng": "-78.93587"
  },
  {
    "country": "US",
    "name": "Grand Island",
    "lat": "43.03311",
    "lng": "-78.96254"
  },
  {
    "country": "US",
    "name": "Grandyle Village",
    "lat": "42.99645",
    "lng": "-78.95504"
  },
  {
    "country": "US",
    "name": "Graniteville",
    "lat": "40.62483",
    "lng": "-74.14848"
  },
  {
    "country": "US",
    "name": "Grant City",
    "lat": "40.58205",
    "lng": "-74.10486"
  },
  {
    "country": "US",
    "name": "Granville",
    "lat": "43.40785",
    "lng": "-73.25955"
  },
  {
    "country": "US",
    "name": "Gravesend",
    "lat": "40.5976",
    "lng": "-73.96514"
  },
  {
    "country": "US",
    "name": "Great Kills",
    "lat": "40.55427",
    "lng": "-74.15153"
  },
  {
    "country": "US",
    "name": "Great Neck",
    "lat": "40.80066",
    "lng": "-73.72846"
  },
  {
    "country": "US",
    "name": "Great Neck Gardens",
    "lat": "40.79722",
    "lng": "-73.72389"
  },
  {
    "country": "US",
    "name": "Great Neck Plaza",
    "lat": "40.78677",
    "lng": "-73.72652"
  },
  {
    "country": "US",
    "name": "Great River",
    "lat": "40.72121",
    "lng": "-73.15761"
  },
  {
    "country": "US",
    "name": "Great Neck Estates",
    "lat": "40.78705",
    "lng": "-73.7368"
  },
  {
    "country": "US",
    "name": "Greece",
    "lat": "43.20978",
    "lng": "-77.69306"
  },
  {
    "country": "US",
    "name": "Green Island",
    "lat": "42.74424",
    "lng": "-73.69151"
  },
  {
    "country": "US",
    "name": "Greenburgh",
    "lat": "41.03287",
    "lng": "-73.84291"
  },
  {
    "country": "US",
    "name": "Greene",
    "lat": "42.32924",
    "lng": "-75.76991"
  },
  {
    "country": "US",
    "name": "Greenlawn",
    "lat": "40.86899",
    "lng": "-73.36512"
  },
  {
    "country": "US",
    "name": "Greenpoint",
    "lat": "40.72371",
    "lng": "-73.95097"
  },
  {
    "country": "US",
    "name": "Greenport",
    "lat": "41.10343",
    "lng": "-72.35925"
  },
  {
    "country": "US",
    "name": "Greenvale",
    "lat": "40.81066",
    "lng": "-73.62846"
  },
  {
    "country": "US",
    "name": "Greenville",
    "lat": "40.99315",
    "lng": "-73.81986"
  },
  {
    "country": "US",
    "name": "Greenwich",
    "lat": "43.09063",
    "lng": "-73.49873"
  },
  {
    "country": "US",
    "name": "Greenwood Lake",
    "lat": "41.22259",
    "lng": "-74.29432"
  },
  {
    "country": "US",
    "name": "Groton",
    "lat": "42.58785",
    "lng": "-76.36688"
  },
  {
    "country": "US",
    "name": "Grymes Hill",
    "lat": "40.61872",
    "lng": "-74.09348"
  },
  {
    "country": "US",
    "name": "Hadley",
    "lat": "43.31729",
    "lng": "-73.84818"
  },
  {
    "country": "US",
    "name": "Hagaman",
    "lat": "42.97452",
    "lng": "-74.15096"
  },
  {
    "country": "US",
    "name": "Halesite",
    "lat": "40.88843",
    "lng": "-73.4154"
  },
  {
    "country": "US",
    "name": "Hamburg",
    "lat": "42.71589",
    "lng": "-78.82948"
  },
  {
    "country": "US",
    "name": "Hamilton",
    "lat": "42.82701",
    "lng": "-75.54462"
  },
  {
    "country": "US",
    "name": "Hamlin",
    "lat": "43.30312",
    "lng": "-77.92112"
  },
  {
    "country": "US",
    "name": "Hampton Bays",
    "lat": "40.86899",
    "lng": "-72.51759"
  },
  {
    "country": "US",
    "name": "Hampton Manor",
    "lat": "42.62091",
    "lng": "-73.72845"
  },
  {
    "country": "US",
    "name": "Hannawa Falls",
    "lat": "44.61228",
    "lng": "-74.97103"
  },
  {
    "country": "US",
    "name": "Harbor Isle",
    "lat": "40.60344",
    "lng": "-73.66457"
  },
  {
    "country": "US",
    "name": "Harlem",
    "lat": "40.80788",
    "lng": "-73.94542"
  },
  {
    "country": "US",
    "name": "Harriman",
    "lat": "41.30843",
    "lng": "-74.14459"
  },
  {
    "country": "US",
    "name": "Harris Hill",
    "lat": "42.96478",
    "lng": "-78.67753"
  },
  {
    "country": "US",
    "name": "Harrison",
    "lat": "40.96899",
    "lng": "-73.71263"
  },
  {
    "country": "US",
    "name": "Hartford",
    "lat": "43.36368",
    "lng": "-73.39372"
  },
  {
    "country": "US",
    "name": "Hartsdale",
    "lat": "41.01899",
    "lng": "-73.79819"
  },
  {
    "country": "US",
    "name": "Hastings-on-Hudson",
    "lat": "40.99454",
    "lng": "-73.87875"
  },
  {
    "country": "US",
    "name": "Hauppauge",
    "lat": "40.82565",
    "lng": "-73.20261"
  },
  {
    "country": "US",
    "name": "Haverstraw",
    "lat": "41.19759",
    "lng": "-73.96458"
  },
  {
    "country": "US",
    "name": "Haviland",
    "lat": "41.76676",
    "lng": "-73.90152"
  },
  {
    "country": "US",
    "name": "Hawthorne",
    "lat": "41.10732",
    "lng": "-73.79597"
  },
  {
    "country": "US",
    "name": "Head of the Harbor",
    "lat": "40.90343",
    "lng": "-73.15789"
  },
  {
    "country": "US",
    "name": "Hell's Kitchen",
    "lat": "40.76496",
    "lng": "-73.9909"
  },
  {
    "country": "US",
    "name": "Hempstead",
    "lat": "40.70621",
    "lng": "-73.61874"
  },
  {
    "country": "US",
    "name": "New Hempstead",
    "lat": "41.14982",
    "lng": "-74.03375"
  },
  {
    "country": "US",
    "name": "Herkimer",
    "lat": "43.02563",
    "lng": "-74.98599"
  },
  {
    "country": "US",
    "name": "Heritage Hills",
    "lat": "41.33954",
    "lng": "-73.69735"
  },
  {
    "country": "US",
    "name": "Herricks",
    "lat": "40.75538",
    "lng": "-73.6668"
  },
  {
    "country": "US",
    "name": "Hewlett",
    "lat": "40.64316",
    "lng": "-73.69569"
  },
  {
    "country": "US",
    "name": "Hewlett Harbor",
    "lat": "40.63621",
    "lng": "-73.68152"
  },
  {
    "country": "US",
    "name": "Hicksville",
    "lat": "40.76843",
    "lng": "-73.52513"
  },
  {
    "country": "US",
    "name": "Highland",
    "lat": "41.72093",
    "lng": "-73.96014"
  },
  {
    "country": "US",
    "name": "Highland Falls",
    "lat": "41.36926",
    "lng": "-73.96625"
  },
  {
    "country": "US",
    "name": "Highland Mills",
    "lat": "41.34704",
    "lng": "-74.12626"
  },
  {
    "country": "US",
    "name": "Hillcrest",
    "lat": "41.12787",
    "lng": "-74.04097"
  },
  {
    "country": "US",
    "name": "Hillside",
    "lat": "40.70788",
    "lng": "-73.7868"
  },
  {
    "country": "US",
    "name": "Hillside Lake",
    "lat": "41.61482",
    "lng": "-73.79819"
  },
  {
    "country": "US",
    "name": "Hilton",
    "lat": "43.28812",
    "lng": "-77.79334"
  },
  {
    "country": "US",
    "name": "Holbrook",
    "lat": "40.81232",
    "lng": "-73.07844"
  },
  {
    "country": "US",
    "name": "Holcomb",
    "lat": "42.90229",
    "lng": "-77.41971"
  },
  {
    "country": "US",
    "name": "Holland",
    "lat": "42.64117",
    "lng": "-78.54169"
  },
  {
    "country": "US",
    "name": "Holley",
    "lat": "43.22645",
    "lng": "-78.02668"
  },
  {
    "country": "US",
    "name": "Holtsville",
    "lat": "40.81538",
    "lng": "-73.04511"
  },
  {
    "country": "US",
    "name": "Homer",
    "lat": "42.63701",
    "lng": "-76.17882"
  },
  {
    "country": "US",
    "name": "Honeoye Falls",
    "lat": "42.95229",
    "lng": "-77.59028"
  },
  {
    "country": "US",
    "name": "Hoosick Falls",
    "lat": "42.90119",
    "lng": "-73.3515"
  },
  {
    "country": "US",
    "name": "Hornell",
    "lat": "42.32785",
    "lng": "-77.6611"
  },
  {
    "country": "US",
    "name": "Horseheads",
    "lat": "42.16702",
    "lng": "-76.82051"
  },
  {
    "country": "US",
    "name": "Houghton",
    "lat": "42.4234",
    "lng": "-78.15723"
  },
  {
    "country": "US",
    "name": "Howard Beach",
    "lat": "40.65788",
    "lng": "-73.83625"
  },
  {
    "country": "US",
    "name": "Hudson",
    "lat": "42.25286",
    "lng": "-73.79096"
  },
  {
    "country": "US",
    "name": "Hudson Falls",
    "lat": "43.30063",
    "lng": "-73.58595"
  },
  {
    "country": "US",
    "name": "Huguenot",
    "lat": "40.53733",
    "lng": "-74.19459"
  },
  {
    "country": "US",
    "name": "Huntington",
    "lat": "40.86815",
    "lng": "-73.42568"
  },
  {
    "country": "US",
    "name": "Huntington Bay",
    "lat": "40.89982",
    "lng": "-73.41484"
  },
  {
    "country": "US",
    "name": "Huntington Station",
    "lat": "40.85343",
    "lng": "-73.41151"
  },
  {
    "country": "US",
    "name": "Hurley",
    "lat": "41.92454",
    "lng": "-74.06125"
  },
  {
    "country": "US",
    "name": "Hyde Park",
    "lat": "41.78482",
    "lng": "-73.93319"
  },
  {
    "country": "US",
    "name": "Ilion",
    "lat": "43.01507",
    "lng": "-75.03543"
  },
  {
    "country": "US",
    "name": "Inwood",
    "lat": "40.62205",
    "lng": "-73.7468"
  },
  {
    "country": "US",
    "name": "Inwood",
    "lat": "40.86566",
    "lng": "-73.9268"
  },
  {
    "country": "US",
    "name": "Irondequoit",
    "lat": "43.2134",
    "lng": "-77.57972"
  },
  {
    "country": "US",
    "name": "Irvington",
    "lat": "41.03922",
    "lng": "-73.86823"
  },
  {
    "country": "US",
    "name": "Island Park",
    "lat": "40.60427",
    "lng": "-73.65541"
  },
  {
    "country": "US",
    "name": "Islandia",
    "lat": "40.80426",
    "lng": "-73.169"
  },
  {
    "country": "US",
    "name": "Islip",
    "lat": "40.72982",
    "lng": "-73.21039"
  },
  {
    "country": "US",
    "name": "Islip Terrace",
    "lat": "40.74315",
    "lng": "-73.19262"
  },
  {
    "country": "US",
    "name": "Ithaca",
    "lat": "42.44063",
    "lng": "-76.49661"
  },
  {
    "country": "US",
    "name": "Jackson Heights",
    "lat": "40.75566",
    "lng": "-73.88541"
  },
  {
    "country": "US",
    "name": "Jamaica",
    "lat": "40.69149",
    "lng": "-73.80569"
  },
  {
    "country": "US",
    "name": "Jamesport",
    "lat": "40.94954",
    "lng": "-72.58148"
  },
  {
    "country": "US",
    "name": "Jamestown",
    "lat": "42.097",
    "lng": "-79.23533"
  },
  {
    "country": "US",
    "name": "Jefferson Heights",
    "lat": "42.23398",
    "lng": "-73.88235"
  },
  {
    "country": "US",
    "name": "Jericho",
    "lat": "40.79204",
    "lng": "-73.53985"
  },
  {
    "country": "US",
    "name": "Johnson City",
    "lat": "42.11563",
    "lng": "-75.95881"
  },
  {
    "country": "US",
    "name": "Johnstown",
    "lat": "43.00674",
    "lng": "-74.36764"
  },
  {
    "country": "US",
    "name": "Jordan",
    "lat": "43.06534",
    "lng": "-76.47299"
  },
  {
    "country": "US",
    "name": "Kaser",
    "lat": "41.12121",
    "lng": "-74.06709"
  },
  {
    "country": "US",
    "name": "Katonah",
    "lat": "41.25898",
    "lng": "-73.68541"
  },
  {
    "country": "US",
    "name": "Keeseville",
    "lat": "44.50505",
    "lng": "-73.48013"
  },
  {
    "country": "US",
    "name": "Kenmore",
    "lat": "42.96589",
    "lng": "-78.87004"
  },
  {
    "country": "US",
    "name": "Kensington",
    "lat": "40.64621",
    "lng": "-73.97069"
  },
  {
    "country": "US",
    "name": "Kensington",
    "lat": "40.79343",
    "lng": "-73.72208"
  },
  {
    "country": "US",
    "name": "Kerhonkson",
    "lat": "41.77482",
    "lng": "-74.29821"
  },
  {
    "country": "US",
    "name": "Kew Gardens",
    "lat": "40.71427",
    "lng": "-73.83097"
  },
  {
    "country": "US",
    "name": "Keuka Park",
    "lat": "42.61535",
    "lng": "-77.09219"
  },
  {
    "country": "US",
    "name": "Kiantone",
    "lat": "42.022",
    "lng": "-79.1981"
  },
  {
    "country": "US",
    "name": "Kinderhook",
    "lat": "42.39536",
    "lng": "-73.6979"
  },
  {
    "country": "US",
    "name": "Kings Bridge",
    "lat": "40.87871",
    "lng": "-73.90514"
  },
  {
    "country": "US",
    "name": "Kings Park",
    "lat": "40.88621",
    "lng": "-73.25734"
  },
  {
    "country": "US",
    "name": "Kings Point",
    "lat": "40.81982",
    "lng": "-73.73513"
  },
  {
    "country": "US",
    "name": "Kingston",
    "lat": "41.92704",
    "lng": "-73.99736"
  },
  {
    "country": "US",
    "name": "Kiryas Joel",
    "lat": "41.34204",
    "lng": "-74.16792"
  },
  {
    "country": "US",
    "name": "Lackawanna",
    "lat": "42.82561",
    "lng": "-78.82337"
  },
  {
    "country": "US",
    "name": "Lake Carmel",
    "lat": "41.46148",
    "lng": "-73.67096"
  },
  {
    "country": "US",
    "name": "Lake Erie Beach",
    "lat": "42.62423",
    "lng": "-79.06698"
  },
  {
    "country": "US",
    "name": "Lake Grove",
    "lat": "40.85288",
    "lng": "-73.11511"
  },
  {
    "country": "US",
    "name": "Lake Katrine",
    "lat": "41.98565",
    "lng": "-73.98819"
  },
  {
    "country": "US",
    "name": "Lake Luzerne",
    "lat": "43.31285",
    "lng": "-73.83484"
  },
  {
    "country": "US",
    "name": "Lake Mohegan",
    "lat": "41.31787",
    "lng": "-73.84625"
  },
  {
    "country": "US",
    "name": "Lake Placid",
    "lat": "44.27962",
    "lng": "-73.98198"
  },
  {
    "country": "US",
    "name": "Lake Pleasant",
    "lat": "43.4709",
    "lng": "-74.41265"
  },
  {
    "country": "US",
    "name": "Lake Ronkonkoma",
    "lat": "40.8351",
    "lng": "-73.13122"
  },
  {
    "country": "US",
    "name": "Lake Success",
    "lat": "40.77066",
    "lng": "-73.71763"
  },
  {
    "country": "US",
    "name": "Lakeland",
    "lat": "43.09034",
    "lng": "-76.24048"
  },
  {
    "country": "US",
    "name": "Lakeview",
    "lat": "42.43202",
    "lng": "-75.86547"
  },
  {
    "country": "US",
    "name": "Lakeview",
    "lat": "40.68538",
    "lng": "-73.65263"
  },
  {
    "country": "US",
    "name": "Lakewood",
    "lat": "42.10422",
    "lng": "-79.3331"
  },
  {
    "country": "US",
    "name": "Lancaster",
    "lat": "42.90061",
    "lng": "-78.67031"
  },
  {
    "country": "US",
    "name": "Lansing",
    "lat": "42.48424",
    "lng": "-76.47994"
  },
  {
    "country": "US",
    "name": "Larchmont",
    "lat": "40.92788",
    "lng": "-73.7518"
  },
  {
    "country": "US",
    "name": "Latham",
    "lat": "42.74702",
    "lng": "-73.75901"
  },
  {
    "country": "US",
    "name": "Lattingtown",
    "lat": "40.89538",
    "lng": "-73.60096"
  },
  {
    "country": "US",
    "name": "Laurel",
    "lat": "40.96954",
    "lng": "-72.56203"
  },
  {
    "country": "US",
    "name": "Laurel Hollow",
    "lat": "40.85677",
    "lng": "-73.46957"
  },
  {
    "country": "US",
    "name": "Laurelton",
    "lat": "40.67019",
    "lng": "-73.74659"
  },
  {
    "country": "US",
    "name": "Lawrence",
    "lat": "40.61566",
    "lng": "-73.72958"
  },
  {
    "country": "US",
    "name": "Le Roy",
    "lat": "42.97839",
    "lng": "-77.98418"
  },
  {
    "country": "US",
    "name": "Levittown",
    "lat": "40.72593",
    "lng": "-73.51429"
  },
  {
    "country": "US",
    "name": "Lewiston",
    "lat": "43.17256",
    "lng": "-79.03588"
  },
  {
    "country": "US",
    "name": "Liberty",
    "lat": "41.8012",
    "lng": "-74.74655"
  },
  {
    "country": "US",
    "name": "Lido Beach",
    "lat": "40.58899",
    "lng": "-73.62541"
  },
  {
    "country": "US",
    "name": "Lima",
    "lat": "42.90479",
    "lng": "-77.61139"
  },
  {
    "country": "US",
    "name": "Lincoln Park",
    "lat": "41.95065",
    "lng": "-73.99403"
  },
  {
    "country": "US",
    "name": "Lincolndale",
    "lat": "41.32287",
    "lng": "-73.71819"
  },
  {
    "country": "US",
    "name": "Lindenhurst",
    "lat": "40.68677",
    "lng": "-73.37345"
  },
  {
    "country": "US",
    "name": "Lindley",
    "lat": "42.02841",
    "lng": "-77.13969"
  },
  {
    "country": "US",
    "name": "Little Falls",
    "lat": "43.0434",
    "lng": "-74.8596"
  },
  {
    "country": "US",
    "name": "Little Neck",
    "lat": "40.76289",
    "lng": "-73.73225"
  },
  {
    "country": "US",
    "name": "Little Valley",
    "lat": "42.25256",
    "lng": "-78.80559"
  },
  {
    "country": "US",
    "name": "Liverpool",
    "lat": "43.10646",
    "lng": "-76.2177"
  },
  {
    "country": "US",
    "name": "Livingston Manor",
    "lat": "41.90037",
    "lng": "-74.82822"
  },
  {
    "country": "US",
    "name": "Livonia",
    "lat": "42.82145",
    "lng": "-77.66861"
  },
  {
    "country": "US",
    "name": "Lloyd Harbor",
    "lat": "40.90343",
    "lng": "-73.45984"
  },
  {
    "country": "US",
    "name": "Lockport",
    "lat": "43.17061",
    "lng": "-78.69031"
  },
  {
    "country": "US",
    "name": "Locust Valley",
    "lat": "40.87593",
    "lng": "-73.59707"
  },
  {
    "country": "US",
    "name": "Long Beach",
    "lat": "40.58844",
    "lng": "-73.65791"
  },
  {
    "country": "US",
    "name": "Long Island City",
    "lat": "40.74482",
    "lng": "-73.94875"
  },
  {
    "country": "US",
    "name": "Lorenz Park",
    "lat": "42.2637",
    "lng": "-73.76846"
  },
  {
    "country": "US",
    "name": "Lowville",
    "lat": "43.78674",
    "lng": "-75.49185"
  },
  {
    "country": "US",
    "name": "Lynbrook",
    "lat": "40.65483",
    "lng": "-73.6718"
  },
  {
    "country": "US",
    "name": "Lyncourt",
    "lat": "43.08146",
    "lng": "-76.12576"
  },
  {
    "country": "US",
    "name": "Lyons",
    "lat": "43.06423",
    "lng": "-76.99025"
  },
  {
    "country": "US",
    "name": "Macedon",
    "lat": "43.06923",
    "lng": "-77.29887"
  },
  {
    "country": "US",
    "name": "Mahopac",
    "lat": "41.37232",
    "lng": "-73.73346"
  },
  {
    "country": "US",
    "name": "Malone",
    "lat": "44.84866",
    "lng": "-74.2949"
  },
  {
    "country": "US",
    "name": "Malverne",
    "lat": "40.67899",
    "lng": "-73.67402"
  },
  {
    "country": "US",
    "name": "Mamaroneck",
    "lat": "40.94871",
    "lng": "-73.73263"
  },
  {
    "country": "US",
    "name": "Manchester",
    "lat": "42.96979",
    "lng": "-77.23026"
  },
  {
    "country": "US",
    "name": "Manhasset",
    "lat": "40.79788",
    "lng": "-73.69957"
  },
  {
    "country": "US",
    "name": "Manhasset Hills",
    "lat": "40.75927",
    "lng": "-73.67985"
  },
  {
    "country": "US",
    "name": "Manhattan",
    "lat": "40.78343",
    "lng": "-73.96625"
  },
  {
    "country": "US",
    "name": "Manlius",
    "lat": "43.00201",
    "lng": "-75.97686"
  },
  {
    "country": "US",
    "name": "Manorhaven",
    "lat": "40.84316",
    "lng": "-73.71485"
  },
  {
    "country": "US",
    "name": "Manorville",
    "lat": "40.87371",
    "lng": "-72.80788"
  },
  {
    "country": "US",
    "name": "Manorville",
    "lat": "42.14231",
    "lng": "-74.03597"
  },
  {
    "country": "US",
    "name": "Marcellus",
    "lat": "42.98284",
    "lng": "-76.34049"
  },
  {
    "country": "US",
    "name": "Marbletown",
    "lat": "41.88343",
    "lng": "-74.1132"
  },
  {
    "country": "US",
    "name": "Mariners Harbor",
    "lat": "40.63677",
    "lng": "-74.15875"
  },
  {
    "country": "US",
    "name": "Marion",
    "lat": "43.1434",
    "lng": "-77.18915"
  },
  {
    "country": "US",
    "name": "Marlboro",
    "lat": "41.60565",
    "lng": "-73.97153"
  },
  {
    "country": "US",
    "name": "Maspeth",
    "lat": "40.72316",
    "lng": "-73.91264"
  },
  {
    "country": "US",
    "name": "Massapequa",
    "lat": "40.68066",
    "lng": "-73.47429"
  },
  {
    "country": "US",
    "name": "Massapequa Park",
    "lat": "40.68038",
    "lng": "-73.45512"
  },
  {
    "country": "US",
    "name": "Massena",
    "lat": "44.9281",
    "lng": "-74.89186"
  },
  {
    "country": "US",
    "name": "Mastic",
    "lat": "40.80204",
    "lng": "-72.84094"
  },
  {
    "country": "US",
    "name": "Mastic Beach",
    "lat": "40.76677",
    "lng": "-72.85205"
  },
  {
    "country": "US",
    "name": "Mattituck",
    "lat": "40.99121",
    "lng": "-72.53425"
  },
  {
    "country": "US",
    "name": "Mattydale",
    "lat": "43.09784",
    "lng": "-76.1452"
  },
  {
    "country": "US",
    "name": "Maybrook",
    "lat": "41.48398",
    "lng": "-74.21765"
  },
  {
    "country": "US",
    "name": "Mayville",
    "lat": "42.25395",
    "lng": "-79.50449"
  },
  {
    "country": "US",
    "name": "McGraw",
    "lat": "42.59618",
    "lng": "-76.09326"
  },
  {
    "country": "US",
    "name": "McKownville",
    "lat": "42.68397",
    "lng": "-73.84762"
  },
  {
    "country": "US",
    "name": "Mechanicstown",
    "lat": "41.44287",
    "lng": "-74.38849"
  },
  {
    "country": "US",
    "name": "Mechanicville",
    "lat": "42.90285",
    "lng": "-73.68734"
  },
  {
    "country": "US",
    "name": "Medford",
    "lat": "40.8176",
    "lng": "-73.00011"
  },
  {
    "country": "US",
    "name": "Medina",
    "lat": "43.22006",
    "lng": "-78.38697"
  },
  {
    "country": "US",
    "name": "Melrose",
    "lat": "40.82455",
    "lng": "-73.91041"
  },
  {
    "country": "US",
    "name": "Melrose Park",
    "lat": "42.90868",
    "lng": "-76.54022"
  },
  {
    "country": "US",
    "name": "Melville",
    "lat": "40.79343",
    "lng": "-73.41512"
  },
  {
    "country": "US",
    "name": "Menands",
    "lat": "42.69202",
    "lng": "-73.72456"
  },
  {
    "country": "US",
    "name": "Merrick",
    "lat": "40.66288",
    "lng": "-73.55152"
  },
  {
    "country": "US",
    "name": "Mexico",
    "lat": "43.45951",
    "lng": "-76.22882"
  },
  {
    "country": "US",
    "name": "Middle Island",
    "lat": "40.88427",
    "lng": "-72.93733"
  },
  {
    "country": "US",
    "name": "Middle Village",
    "lat": "40.71649",
    "lng": "-73.88125"
  },
  {
    "country": "US",
    "name": "Middleburgh",
    "lat": "42.59869",
    "lng": "-74.33292"
  },
  {
    "country": "US",
    "name": "Middleport",
    "lat": "42.79062",
    "lng": "-75.5599"
  },
  {
    "country": "US",
    "name": "Middleport",
    "lat": "43.21256",
    "lng": "-78.47641"
  },
  {
    "country": "US",
    "name": "Middletown",
    "lat": "41.44593",
    "lng": "-74.42293"
  },
  {
    "country": "US",
    "name": "Midland Beach",
    "lat": "40.57316",
    "lng": "-74.09459"
  },
  {
    "country": "US",
    "name": "Mill Neck",
    "lat": "40.88704",
    "lng": "-73.55512"
  },
  {
    "country": "US",
    "name": "Millbrook",
    "lat": "41.78509",
    "lng": "-73.69402"
  },
  {
    "country": "US",
    "name": "Miller Place",
    "lat": "40.95982",
    "lng": "-72.99621"
  },
  {
    "country": "US",
    "name": "Milton",
    "lat": "43.03369",
    "lng": "-73.85262"
  },
  {
    "country": "US",
    "name": "Milton",
    "lat": "41.65982",
    "lng": "-73.95708"
  },
  {
    "country": "US",
    "name": "Mineola",
    "lat": "40.74927",
    "lng": "-73.64068"
  },
  {
    "country": "US",
    "name": "Minetto",
    "lat": "43.39812",
    "lng": "-76.47744"
  },
  {
    "country": "US",
    "name": "Mineville",
    "lat": "44.09283",
    "lng": "-73.51818"
  },
  {
    "country": "US",
    "name": "Minoa",
    "lat": "43.07618",
    "lng": "-76.00075"
  },
  {
    "country": "US",
    "name": "Mohawk",
    "lat": "43.01146",
    "lng": "-75.00404"
  },
  {
    "country": "US",
    "name": "Monroe",
    "lat": "41.33065",
    "lng": "-74.18681"
  },
  {
    "country": "US",
    "name": "Monsey",
    "lat": "41.11121",
    "lng": "-74.06848"
  },
  {
    "country": "US",
    "name": "Montauk",
    "lat": "41.03594",
    "lng": "-71.95451"
  },
  {
    "country": "US",
    "name": "Montebello",
    "lat": "41.13593",
    "lng": "-74.11848"
  },
  {
    "country": "US",
    "name": "Montgomery",
    "lat": "41.52759",
    "lng": "-74.23682"
  },
  {
    "country": "US",
    "name": "Monticello",
    "lat": "41.65565",
    "lng": "-74.68933"
  },
  {
    "country": "US",
    "name": "Montour Falls",
    "lat": "42.3473",
    "lng": "-76.84524"
  },
  {
    "country": "US",
    "name": "Montrose",
    "lat": "41.25232",
    "lng": "-73.93153"
  },
  {
    "country": "US",
    "name": "Moravia",
    "lat": "42.71257",
    "lng": "-76.4216"
  },
  {
    "country": "US",
    "name": "Moriches",
    "lat": "40.80732",
    "lng": "-72.82121"
  },
  {
    "country": "US",
    "name": "Morris Heights",
    "lat": "40.84982",
    "lng": "-73.91986"
  },
  {
    "country": "US",
    "name": "Morrisania",
    "lat": "40.82927",
    "lng": "-73.90653"
  },
  {
    "country": "US",
    "name": "Morrisonville",
    "lat": "44.6931",
    "lng": "-73.56208"
  },
  {
    "country": "US",
    "name": "Morrisville",
    "lat": "42.89868",
    "lng": "-75.64018"
  },
  {
    "country": "US",
    "name": "Mott Haven",
    "lat": "40.80899",
    "lng": "-73.92291"
  },
  {
    "country": "US",
    "name": "Mount Ivy",
    "lat": "41.18676",
    "lng": "-74.03486"
  },
  {
    "country": "US",
    "name": "Mount Kisco",
    "lat": "41.20426",
    "lng": "-73.72708"
  },
  {
    "country": "US",
    "name": "Mount Morris",
    "lat": "42.72562",
    "lng": "-77.87417"
  },
  {
    "country": "US",
    "name": "Mount Sinai",
    "lat": "40.94704",
    "lng": "-73.02955"
  },
  {
    "country": "US",
    "name": "Mount Vernon",
    "lat": "40.9126",
    "lng": "-73.83708"
  },
  {
    "country": "US",
    "name": "Mountain Lodge Park",
    "lat": "41.38843",
    "lng": "-74.14181"
  },
  {
    "country": "US",
    "name": "Munsey Park",
    "lat": "40.79871",
    "lng": "-73.67985"
  },
  {
    "country": "US",
    "name": "Munsons Corners",
    "lat": "42.58229",
    "lng": "-76.2091"
  },
  {
    "country": "US",
    "name": "Myers Corner",
    "lat": "41.6062",
    "lng": "-73.87291"
  },
  {
    "country": "US",
    "name": "Muttontown",
    "lat": "40.82399",
    "lng": "-73.54763"
  },
  {
    "country": "US",
    "name": "Nanuet",
    "lat": "41.08871",
    "lng": "-74.01347"
  },
  {
    "country": "US",
    "name": "Napanoch",
    "lat": "41.74398",
    "lng": "-74.37154"
  },
  {
    "country": "US",
    "name": "Naples",
    "lat": "42.61535",
    "lng": "-77.40249"
  },
  {
    "country": "US",
    "name": "Nassau",
    "lat": "42.51591",
    "lng": "-73.61012"
  },
  {
    "country": "US",
    "name": "Nedrow",
    "lat": "42.97507",
    "lng": "-76.14131"
  },
  {
    "country": "US",
    "name": "Neponsit",
    "lat": "40.57177",
    "lng": "-73.86152"
  },
  {
    "country": "US",
    "name": "Nesconset",
    "lat": "40.85204",
    "lng": "-73.154"
  },
  {
    "country": "US",
    "name": "New Cassel",
    "lat": "40.75899",
    "lng": "-73.56957"
  },
  {
    "country": "US",
    "name": "New City",
    "lat": "41.1476",
    "lng": "-73.98931"
  },
  {
    "country": "US",
    "name": "New Dorp",
    "lat": "40.57399",
    "lng": "-74.11598"
  },
  {
    "country": "US",
    "name": "New Dorp Beach",
    "lat": "40.56538",
    "lng": "-74.10292"
  },
  {
    "country": "US",
    "name": "New Hartford",
    "lat": "43.0734",
    "lng": "-75.28767"
  },
  {
    "country": "US",
    "name": "New Hyde Park",
    "lat": "40.7351",
    "lng": "-73.68791"
  },
  {
    "country": "US",
    "name": "New Brighton",
    "lat": "40.64233",
    "lng": "-74.09292"
  },
  {
    "country": "US",
    "name": "New Paltz",
    "lat": "41.74759",
    "lng": "-74.08681"
  },
  {
    "country": "US",
    "name": "New Rochelle",
    "lat": "40.91149",
    "lng": "-73.78235"
  },
  {
    "country": "US",
    "name": "New Springville",
    "lat": "40.59344",
    "lng": "-74.1632"
  },
  {
    "country": "US",
    "name": "New Square",
    "lat": "41.13956",
    "lng": "-74.02942"
  },
  {
    "country": "US",
    "name": "New Windsor",
    "lat": "41.47676",
    "lng": "-74.02375"
  },
  {
    "country": "US",
    "name": "New York City",
    "lat": "40.71427",
    "lng": "-74.00597"
  },
  {
    "country": "US",
    "name": "New York Mills",
    "lat": "43.10535",
    "lng": "-75.29128"
  },
  {
    "country": "US",
    "name": "Newark",
    "lat": "43.04673",
    "lng": "-77.09525"
  },
  {
    "country": "US",
    "name": "Newburgh",
    "lat": "41.50343",
    "lng": "-74.01042"
  },
  {
    "country": "US",
    "name": "Newfane",
    "lat": "43.28672",
    "lng": "-78.71031"
  },
  {
    "country": "US",
    "name": "Niagara Falls",
    "lat": "43.0945",
    "lng": "-79.05671"
  },
  {
    "country": "US",
    "name": "Niskayuna",
    "lat": "42.7798",
    "lng": "-73.84568"
  },
  {
    "country": "US",
    "name": "Nissequogue",
    "lat": "40.90399",
    "lng": "-73.19789"
  },
  {
    "country": "US",
    "name": "Niverville",
    "lat": "42.44092",
    "lng": "-73.66095"
  },
  {
    "country": "US",
    "name": "Norfolk",
    "lat": "44.80089",
    "lng": "-74.99103"
  },
  {
    "country": "US",
    "name": "North Amityville",
    "lat": "40.6976",
    "lng": "-73.42512"
  },
  {
    "country": "US",
    "name": "North Babylon",
    "lat": "40.71649",
    "lng": "-73.32179"
  },
  {
    "country": "US",
    "name": "North Bay Shore",
    "lat": "40.73621",
    "lng": "-73.26262"
  },
  {
    "country": "US",
    "name": "North Bellmore",
    "lat": "40.69149",
    "lng": "-73.53346"
  },
  {
    "country": "US",
    "name": "North Bellport",
    "lat": "40.77427",
    "lng": "-72.94288"
  },
  {
    "country": "US",
    "name": "North Boston",
    "lat": "42.68562",
    "lng": "-78.7767"
  },
  {
    "country": "US",
    "name": "North Collins",
    "lat": "42.59534",
    "lng": "-78.94115"
  },
  {
    "country": "US",
    "name": "North Elba",
    "lat": "44.24338",
    "lng": "-73.95431"
  },
  {
    "country": "US",
    "name": "North Gates",
    "lat": "43.17645",
    "lng": "-77.70139"
  },
  {
    "country": "US",
    "name": "North Great River",
    "lat": "40.74732",
    "lng": "-73.16984"
  },
  {
    "country": "US",
    "name": "North Hills",
    "lat": "40.78093",
    "lng": "-73.67652"
  },
  {
    "country": "US",
    "name": "North Lindenhurst",
    "lat": "40.71427",
    "lng": "-73.38151"
  },
  {
    "country": "US",
    "name": "North Massapequa",
    "lat": "40.70093",
    "lng": "-73.46207"
  },
  {
    "country": "US",
    "name": "North Merrick",
    "lat": "40.69121",
    "lng": "-73.56318"
  },
  {
    "country": "US",
    "name": "North New Hyde Park",
    "lat": "40.74316",
    "lng": "-73.69319"
  },
  {
    "country": "US",
    "name": "North Patchogue",
    "lat": "40.78704",
    "lng": "-73.009"
  },
  {
    "country": "US",
    "name": "North Sea",
    "lat": "40.93288",
    "lng": "-72.41425"
  },
  {
    "country": "US",
    "name": "North Syracuse",
    "lat": "43.13479",
    "lng": "-76.12992"
  },
  {
    "country": "US",
    "name": "North Tonawanda",
    "lat": "43.03867",
    "lng": "-78.8642"
  },
  {
    "country": "US",
    "name": "North Valley Stream",
    "lat": "40.6851",
    "lng": "-73.7018"
  },
  {
    "country": "US",
    "name": "North Wantagh",
    "lat": "40.69343",
    "lng": "-73.50763"
  },
  {
    "country": "US",
    "name": "Northport",
    "lat": "40.90093",
    "lng": "-73.34317"
  },
  {
    "country": "US",
    "name": "Northumberland",
    "lat": "43.1273",
    "lng": "-73.58817"
  },
  {
    "country": "US",
    "name": "Northville",
    "lat": "43.22563",
    "lng": "-74.17208"
  },
  {
    "country": "US",
    "name": "Northville",
    "lat": "40.9701",
    "lng": "-72.61898"
  },
  {
    "country": "US",
    "name": "Northwest Harbor",
    "lat": "41.00982",
    "lng": "-72.22119"
  },
  {
    "country": "US",
    "name": "Norwich",
    "lat": "42.53118",
    "lng": "-75.52351"
  },
  {
    "country": "US",
    "name": "Norwood",
    "lat": "44.75145",
    "lng": "-74.99436"
  },
  {
    "country": "US",
    "name": "Noyack",
    "lat": "40.99566",
    "lng": "-72.34119"
  },
  {
    "country": "US",
    "name": "Nunda",
    "lat": "42.57951",
    "lng": "-77.9425"
  },
  {
    "country": "US",
    "name": "Nyack",
    "lat": "41.09065",
    "lng": "-73.91791"
  },
  {
    "country": "US",
    "name": "Oakdale",
    "lat": "42.2512",
    "lng": "-73.78013"
  },
  {
    "country": "US",
    "name": "Oakdale",
    "lat": "40.74399",
    "lng": "-73.13872"
  },
  {
    "country": "US",
    "name": "Oakfield",
    "lat": "43.06589",
    "lng": "-78.26974"
  },
  {
    "country": "US",
    "name": "Oakwood",
    "lat": "40.56399",
    "lng": "-74.11598"
  },
  {
    "country": "US",
    "name": "Oceanside",
    "lat": "40.63871",
    "lng": "-73.64013"
  },
  {
    "country": "US",
    "name": "Ogdensburg",
    "lat": "44.69423",
    "lng": "-75.48634"
  },
  {
    "country": "US",
    "name": "Olcott",
    "lat": "43.33783",
    "lng": "-78.71476"
  },
  {
    "country": "US",
    "name": "Old Bethpage",
    "lat": "40.7626",
    "lng": "-73.45318"
  },
  {
    "country": "US",
    "name": "Old Brookville",
    "lat": "40.83204",
    "lng": "-73.60485"
  },
  {
    "country": "US",
    "name": "Old Westbury",
    "lat": "40.78871",
    "lng": "-73.59957"
  },
  {
    "country": "US",
    "name": "Olean",
    "lat": "42.07756",
    "lng": "-78.42974"
  },
  {
    "country": "US",
    "name": "Oneida",
    "lat": "43.09257",
    "lng": "-75.65129"
  },
  {
    "country": "US",
    "name": "Oneonta",
    "lat": "42.45286",
    "lng": "-75.06377"
  },
  {
    "country": "US",
    "name": "Ontario",
    "lat": "43.2209",
    "lng": "-77.28304"
  },
  {
    "country": "US",
    "name": "Orange Lake",
    "lat": "41.53982",
    "lng": "-74.0982"
  },
  {
    "country": "US",
    "name": "Orangeburg",
    "lat": "41.04649",
    "lng": "-73.94958"
  },
  {
    "country": "US",
    "name": "Orchard Park",
    "lat": "42.76756",
    "lng": "-78.74392"
  },
  {
    "country": "US",
    "name": "Oriskany",
    "lat": "43.15729",
    "lng": "-75.33267"
  },
  {
    "country": "US",
    "name": "Ossining",
    "lat": "41.16287",
    "lng": "-73.86152"
  },
  {
    "country": "US",
    "name": "Oswego",
    "lat": "43.45535",
    "lng": "-76.5105"
  },
  {
    "country": "US",
    "name": "Otisville",
    "lat": "41.47343",
    "lng": "-74.53849"
  },
  {
    "country": "US",
    "name": "Owego",
    "lat": "42.10341",
    "lng": "-76.26215"
  },
  {
    "country": "US",
    "name": "Oxford",
    "lat": "42.44202",
    "lng": "-75.59769"
  },
  {
    "country": "US",
    "name": "Oyster Bay",
    "lat": "40.86565",
    "lng": "-73.53207"
  },
  {
    "country": "US",
    "name": "Oyster Bay Cove",
    "lat": "40.87093",
    "lng": "-73.51096"
  },
  {
    "country": "US",
    "name": "Ozone Park",
    "lat": "40.67677",
    "lng": "-73.84375"
  },
  {
    "country": "US",
    "name": "Painted Post",
    "lat": "42.16202",
    "lng": "-77.09414"
  },
  {
    "country": "US",
    "name": "Palenville",
    "lat": "42.17453",
    "lng": "-74.02014"
  },
  {
    "country": "US",
    "name": "Palmyra",
    "lat": "43.06395",
    "lng": "-77.23332"
  },
  {
    "country": "US",
    "name": "Park Slope",
    "lat": "40.6701",
    "lng": "-73.98597"
  },
  {
    "country": "US",
    "name": "Parkchester",
    "lat": "40.83899",
    "lng": "-73.86041"
  },
  {
    "country": "US",
    "name": "Patchogue",
    "lat": "40.76565",
    "lng": "-73.01511"
  },
  {
    "country": "US",
    "name": "Pawling",
    "lat": "41.56204",
    "lng": "-73.60263"
  },
  {
    "country": "US",
    "name": "Peach Lake",
    "lat": "41.36759",
    "lng": "-73.5779"
  },
  {
    "country": "US",
    "name": "Pearl River",
    "lat": "41.05899",
    "lng": "-74.02181"
  },
  {
    "country": "US",
    "name": "Peekskill",
    "lat": "41.29009",
    "lng": "-73.92042"
  },
  {
    "country": "US",
    "name": "Pelham",
    "lat": "40.90982",
    "lng": "-73.80791"
  },
  {
    "country": "US",
    "name": "Pelham Manor",
    "lat": "40.89538",
    "lng": "-73.80708"
  },
  {
    "country": "US",
    "name": "Penn Yan",
    "lat": "42.6609",
    "lng": "-77.05386"
  },
  {
    "country": "US",
    "name": "Perry",
    "lat": "42.71562",
    "lng": "-78.00556"
  },
  {
    "country": "US",
    "name": "Perth",
    "lat": "43.01757",
    "lng": "-74.19402"
  },
  {
    "country": "US",
    "name": "Peru",
    "lat": "44.57838",
    "lng": "-73.5268"
  },
  {
    "country": "US",
    "name": "Peru",
    "lat": "43.08229",
    "lng": "-76.40799"
  },
  {
    "country": "US",
    "name": "Phelps",
    "lat": "42.95756",
    "lng": "-77.05747"
  },
  {
    "country": "US",
    "name": "Philadelphia",
    "lat": "44.1545",
    "lng": "-75.70882"
  },
  {
    "country": "US",
    "name": "Philmont",
    "lat": "42.24842",
    "lng": "-73.65318"
  },
  {
    "country": "US",
    "name": "Phoenix",
    "lat": "43.23118",
    "lng": "-76.30076"
  },
  {
    "country": "US",
    "name": "Piermont",
    "lat": "41.04204",
    "lng": "-73.91819"
  },
  {
    "country": "US",
    "name": "Pine Bush",
    "lat": "41.60815",
    "lng": "-74.29904"
  },
  {
    "country": "US",
    "name": "Pine Plains",
    "lat": "41.97981",
    "lng": "-73.65596"
  },
  {
    "country": "US",
    "name": "Pittsford",
    "lat": "43.09062",
    "lng": "-77.515"
  },
  {
    "country": "US",
    "name": "Plainedge",
    "lat": "40.71732",
    "lng": "-73.48374"
  },
  {
    "country": "US",
    "name": "Plainview",
    "lat": "40.77649",
    "lng": "-73.46735"
  },
  {
    "country": "US",
    "name": "Plandome",
    "lat": "40.80677",
    "lng": "-73.70346"
  },
  {
    "country": "US",
    "name": "Plandome Heights",
    "lat": "40.8026",
    "lng": "-73.7043"
  },
  {
    "country": "US",
    "name": "Plattekill",
    "lat": "41.61759",
    "lng": "-74.07598"
  },
  {
    "country": "US",
    "name": "Plattsburgh",
    "lat": "44.69949",
    "lng": "-73.45291"
  },
  {
    "country": "US",
    "name": "Pleasant Valley",
    "lat": "41.74454",
    "lng": "-73.82124"
  },
  {
    "country": "US",
    "name": "Pleasantville",
    "lat": "41.13287",
    "lng": "-73.79263"
  },
  {
    "country": "US",
    "name": "Poestenkill",
    "lat": "42.69036",
    "lng": "-73.56456"
  },
  {
    "country": "US",
    "name": "Point Lookout",
    "lat": "40.59233",
    "lng": "-73.58068"
  },
  {
    "country": "US",
    "name": "Pomona",
    "lat": "41.16704",
    "lng": "-74.0432"
  },
  {
    "country": "US",
    "name": "Port Byron",
    "lat": "43.03451",
    "lng": "-76.62383"
  },
  {
    "country": "US",
    "name": "Port Chester",
    "lat": "41.00176",
    "lng": "-73.66568"
  },
  {
    "country": "US",
    "name": "Port Dickinson",
    "lat": "42.13341",
    "lng": "-75.89631"
  },
  {
    "country": "US",
    "name": "Port Ewen",
    "lat": "41.90537",
    "lng": "-73.97625"
  },
  {
    "country": "US",
    "name": "Port Henry",
    "lat": "44.04839",
    "lng": "-73.45985"
  },
  {
    "country": "US",
    "name": "Port Jefferson",
    "lat": "40.94649",
    "lng": "-73.06927"
  },
  {
    "country": "US",
    "name": "Port Jefferson Station",
    "lat": "40.92538",
    "lng": "-73.04733"
  },
  {
    "country": "US",
    "name": "Port Jervis",
    "lat": "41.37509",
    "lng": "-74.69266"
  },
  {
    "country": "US",
    "name": "Port Morris",
    "lat": "40.80149",
    "lng": "-73.90958"
  },
  {
    "country": "US",
    "name": "Port Richmond",
    "lat": "40.63316",
    "lng": "-74.13653"
  },
  {
    "country": "US",
    "name": "Port Washington",
    "lat": "40.82566",
    "lng": "-73.69819"
  },
  {
    "country": "US",
    "name": "Port Washington North",
    "lat": "40.84482",
    "lng": "-73.7018"
  },
  {
    "country": "US",
    "name": "Portland",
    "lat": "42.37978",
    "lng": "-79.46755"
  },
  {
    "country": "US",
    "name": "Potsdam",
    "lat": "44.66978",
    "lng": "-74.98131"
  },
  {
    "country": "US",
    "name": "Poughkeepsie",
    "lat": "41.70037",
    "lng": "-73.92097"
  },
  {
    "country": "US",
    "name": "Pound Ridge",
    "lat": "41.20871",
    "lng": "-73.57485"
  },
  {
    "country": "US",
    "name": "Pulaski",
    "lat": "43.56701",
    "lng": "-76.1277"
  },
  {
    "country": "US",
    "name": "Purchase",
    "lat": "41.04093",
    "lng": "-73.71457"
  },
  {
    "country": "US",
    "name": "Putnam Lake",
    "lat": "41.46204",
    "lng": "-73.54624"
  },
  {
    "country": "US",
    "name": "Queens Village",
    "lat": "40.72677",
    "lng": "-73.74152"
  },
  {
    "country": "US",
    "name": "Queens",
    "lat": "40.68149",
    "lng": "-73.83652"
  },
  {
    "country": "US",
    "name": "Queensbury",
    "lat": "43.37729",
    "lng": "-73.61317"
  },
  {
    "country": "US",
    "name": "Randolph",
    "lat": "42.16201",
    "lng": "-78.97532"
  },
  {
    "country": "US",
    "name": "Ransomville",
    "lat": "43.23867",
    "lng": "-78.90976"
  },
  {
    "country": "US",
    "name": "Rapids",
    "lat": "43.09839",
    "lng": "-78.64086"
  },
  {
    "country": "US",
    "name": "Ravena",
    "lat": "42.46841",
    "lng": "-73.81624"
  },
  {
    "country": "US",
    "name": "Red Hook",
    "lat": "41.99509",
    "lng": "-73.87541"
  },
  {
    "country": "US",
    "name": "Red Oaks Mill",
    "lat": "41.65565",
    "lng": "-73.87486"
  },
  {
    "country": "US",
    "name": "Rego Park",
    "lat": "40.72649",
    "lng": "-73.85264"
  },
  {
    "country": "US",
    "name": "Rensselaer",
    "lat": "42.64258",
    "lng": "-73.7429"
  },
  {
    "country": "US",
    "name": "Rhinebeck",
    "lat": "41.92676",
    "lng": "-73.91264"
  },
  {
    "country": "US",
    "name": "Richfield Springs",
    "lat": "42.85341",
    "lng": "-74.98543"
  },
  {
    "country": "US",
    "name": "Richland",
    "lat": "43.56951",
    "lng": "-76.0477"
  },
  {
    "country": "US",
    "name": "Richmond Hill",
    "lat": "40.69983",
    "lng": "-73.83125"
  },
  {
    "country": "US",
    "name": "Ridge",
    "lat": "40.89399",
    "lng": "-72.89594"
  },
  {
    "country": "US",
    "name": "Ridgewood",
    "lat": "40.7001",
    "lng": "-73.90569"
  },
  {
    "country": "US",
    "name": "Riverdale",
    "lat": "40.90056",
    "lng": "-73.90639"
  },
  {
    "country": "US",
    "name": "Riverhead",
    "lat": "40.91704",
    "lng": "-72.66204"
  },
  {
    "country": "US",
    "name": "Riverside",
    "lat": "40.88121",
    "lng": "-72.67787"
  },
  {
    "country": "US",
    "name": "Rochester",
    "lat": "43.15478",
    "lng": "-77.61556"
  },
  {
    "country": "US",
    "name": "Rock Hill",
    "lat": "41.62593",
    "lng": "-74.59766"
  },
  {
    "country": "US",
    "name": "Rockaway Point",
    "lat": "40.56066",
    "lng": "-73.91514"
  },
  {
    "country": "US",
    "name": "Rockville Centre",
    "lat": "40.65871",
    "lng": "-73.64124"
  },
  {
    "country": "US",
    "name": "Rocky Point",
    "lat": "40.9526",
    "lng": "-72.92538"
  },
  {
    "country": "US",
    "name": "Roessleville",
    "lat": "42.69508",
    "lng": "-73.80707"
  },
  {
    "country": "US",
    "name": "Rome",
    "lat": "43.21285",
    "lng": "-75.45573"
  },
  {
    "country": "US",
    "name": "Ronkonkoma",
    "lat": "40.81538",
    "lng": "-73.11233"
  },
  {
    "country": "US",
    "name": "Roosevelt",
    "lat": "40.67871",
    "lng": "-73.58902"
  },
  {
    "country": "US",
    "name": "Rosebank",
    "lat": "40.61399",
    "lng": "-74.06625"
  },
  {
    "country": "US",
    "name": "Rosedale",
    "lat": "40.66205",
    "lng": "-73.73541"
  },
  {
    "country": "US",
    "name": "Roslyn",
    "lat": "40.79982",
    "lng": "-73.65096"
  },
  {
    "country": "US",
    "name": "Roslyn Estates",
    "lat": "40.79427",
    "lng": "-73.66041"
  },
  {
    "country": "US",
    "name": "Roslyn Harbor",
    "lat": "40.81649",
    "lng": "-73.63707"
  },
  {
    "country": "US",
    "name": "Roslyn Heights",
    "lat": "40.78871",
    "lng": "-73.64735"
  },
  {
    "country": "US",
    "name": "Rossville",
    "lat": "40.55566",
    "lng": "-74.21348"
  },
  {
    "country": "US",
    "name": "Rotterdam",
    "lat": "42.78702",
    "lng": "-73.97096"
  },
  {
    "country": "US",
    "name": "Rouses Point",
    "lat": "44.99393",
    "lng": "-73.36486"
  },
  {
    "country": "US",
    "name": "Rye",
    "lat": "40.98065",
    "lng": "-73.68374"
  },
  {
    "country": "US",
    "name": "Rye Brook",
    "lat": "41.01926",
    "lng": "-73.68346"
  },
  {
    "country": "US",
    "name": "Sackets Harbor",
    "lat": "43.94617",
    "lng": "-76.11909"
  },
  {
    "country": "US",
    "name": "Sag Harbor",
    "lat": "40.99788",
    "lng": "-72.29258"
  },
  {
    "country": "US",
    "name": "Saint James",
    "lat": "40.87899",
    "lng": "-73.15678"
  },
  {
    "country": "US",
    "name": "Saint Johnsville",
    "lat": "42.99813",
    "lng": "-74.68292"
  },
  {
    "country": "US",
    "name": "Salamanca",
    "lat": "42.15784",
    "lng": "-78.71503"
  },
  {
    "country": "US",
    "name": "Salisbury",
    "lat": "40.74566",
    "lng": "-73.56013"
  },
  {
    "country": "US",
    "name": "Sanborn",
    "lat": "43.13672",
    "lng": "-78.88476"
  },
  {
    "country": "US",
    "name": "Sands Point",
    "lat": "40.85177",
    "lng": "-73.71874"
  },
  {
    "country": "US",
    "name": "Saranac Lake",
    "lat": "44.3295",
    "lng": "-74.13127"
  },
  {
    "country": "US",
    "name": "Saratoga Springs",
    "lat": "43.08313",
    "lng": "-73.78457"
  },
  {
    "country": "US",
    "name": "Saugerties",
    "lat": "42.07759",
    "lng": "-73.95291"
  },
  {
    "country": "US",
    "name": "Sayville",
    "lat": "40.73593",
    "lng": "-73.08206"
  },
  {
    "country": "US",
    "name": "Scarsdale",
    "lat": "41.0051",
    "lng": "-73.78458"
  },
  {
    "country": "US",
    "name": "Schenectady",
    "lat": "42.81424",
    "lng": "-73.93957"
  },
  {
    "country": "US",
    "name": "Schoharie",
    "lat": "42.66591",
    "lng": "-74.30958"
  },
  {
    "country": "US",
    "name": "Schuylerville",
    "lat": "43.10008",
    "lng": "-73.58178"
  },
  {
    "country": "US",
    "name": "Scotchtown",
    "lat": "41.48148",
    "lng": "-74.36015"
  },
  {
    "country": "US",
    "name": "Scotia",
    "lat": "42.82647",
    "lng": "-73.96429"
  },
  {
    "country": "US",
    "name": "Scottsville",
    "lat": "43.0259",
    "lng": "-77.74528"
  },
  {
    "country": "US",
    "name": "Sea Cliff",
    "lat": "40.84899",
    "lng": "-73.64485"
  },
  {
    "country": "US",
    "name": "Seaford",
    "lat": "40.66593",
    "lng": "-73.48818"
  },
  {
    "country": "US",
    "name": "Searingtown",
    "lat": "40.77482",
    "lng": "-73.65568"
  },
  {
    "country": "US",
    "name": "Seaside",
    "lat": "40.58316",
    "lng": "-73.82819"
  },
  {
    "country": "US",
    "name": "Selden",
    "lat": "40.86649",
    "lng": "-73.03566"
  },
  {
    "country": "US",
    "name": "Seneca Falls",
    "lat": "42.91062",
    "lng": "-76.79662"
  },
  {
    "country": "US",
    "name": "Seneca Knolls",
    "lat": "43.12007",
    "lng": "-76.28632"
  },
  {
    "country": "US",
    "name": "Sheepshead Bay",
    "lat": "40.59122",
    "lng": "-73.94458"
  },
  {
    "country": "US",
    "name": "Shelter Island",
    "lat": "41.06815",
    "lng": "-72.33869"
  },
  {
    "country": "US",
    "name": "Shelter Island Heights",
    "lat": "41.08399",
    "lng": "-72.35592"
  },
  {
    "country": "US",
    "name": "Shenorock",
    "lat": "41.33176",
    "lng": "-73.73819"
  },
  {
    "country": "US",
    "name": "Sherburne",
    "lat": "42.67813",
    "lng": "-75.49851"
  },
  {
    "country": "US",
    "name": "Sherrill",
    "lat": "43.07368",
    "lng": "-75.59824"
  },
  {
    "country": "US",
    "name": "Shinnecock Hills",
    "lat": "40.89093",
    "lng": "-72.4637"
  },
  {
    "country": "US",
    "name": "Shirley",
    "lat": "40.80149",
    "lng": "-72.8676"
  },
  {
    "country": "US",
    "name": "Shokan",
    "lat": "41.97343",
    "lng": "-74.21209"
  },
  {
    "country": "US",
    "name": "Shortsville",
    "lat": "42.9559",
    "lng": "-77.22081"
  },
  {
    "country": "US",
    "name": "Shrub Oak",
    "lat": "41.32759",
    "lng": "-73.81958"
  },
  {
    "country": "US",
    "name": "Sidney",
    "lat": "42.3148",
    "lng": "-75.39157"
  },
  {
    "country": "US",
    "name": "Silver Creek",
    "lat": "42.54423",
    "lng": "-79.16671"
  },
  {
    "country": "US",
    "name": "Skaneateles",
    "lat": "42.94701",
    "lng": "-76.4291"
  },
  {
    "country": "US",
    "name": "Sleepy Hollow",
    "lat": "41.08565",
    "lng": "-73.85847"
  },
  {
    "country": "US",
    "name": "Sloan",
    "lat": "42.89339",
    "lng": "-78.79392"
  },
  {
    "country": "US",
    "name": "Sloatsburg",
    "lat": "41.15454",
    "lng": "-74.19292"
  },
  {
    "country": "US",
    "name": "Smithtown",
    "lat": "40.85593",
    "lng": "-73.20067"
  },
  {
    "country": "US",
    "name": "Sodus",
    "lat": "43.23784",
    "lng": "-77.06136"
  },
  {
    "country": "US",
    "name": "Solvay",
    "lat": "43.05812",
    "lng": "-76.20743"
  },
  {
    "country": "US",
    "name": "Sound Beach",
    "lat": "40.95621",
    "lng": "-72.96788"
  },
  {
    "country": "US",
    "name": "South Beach",
    "lat": "40.58329",
    "lng": "-74.07609"
  },
  {
    "country": "US",
    "name": "South Corning",
    "lat": "42.12174",
    "lng": "-77.03719"
  },
  {
    "country": "US",
    "name": "South Fallsburg",
    "lat": "41.72065",
    "lng": "-74.63433"
  },
  {
    "country": "US",
    "name": "South Farmingdale",
    "lat": "40.72066",
    "lng": "-73.44012"
  },
  {
    "country": "US",
    "name": "South Floral Park",
    "lat": "40.71427",
    "lng": "-73.70013"
  },
  {
    "country": "US",
    "name": "South Glens Falls",
    "lat": "43.29924",
    "lng": "-73.63512"
  },
  {
    "country": "US",
    "name": "South Hempstead",
    "lat": "40.68094",
    "lng": "-73.61541"
  },
  {
    "country": "US",
    "name": "South Hill",
    "lat": "42.42924",
    "lng": "-76.49494"
  },
  {
    "country": "US",
    "name": "South Huntington",
    "lat": "40.82371",
    "lng": "-73.39873"
  },
  {
    "country": "US",
    "name": "South Lockport",
    "lat": "43.15006",
    "lng": "-78.6967"
  },
  {
    "country": "US",
    "name": "South Nyack",
    "lat": "41.08315",
    "lng": "-73.92014"
  },
  {
    "country": "US",
    "name": "South Valley Stream",
    "lat": "40.65594",
    "lng": "-73.71763"
  },
  {
    "country": "US",
    "name": "Southampton",
    "lat": "40.88427",
    "lng": "-72.38953"
  },
  {
    "country": "US",
    "name": "Southold",
    "lat": "41.06482",
    "lng": "-72.4262"
  },
  {
    "country": "US",
    "name": "Southport",
    "lat": "42.0548",
    "lng": "-76.81912"
  },
  {
    "country": "US",
    "name": "Spackenkill",
    "lat": "41.65593",
    "lng": "-73.91347"
  },
  {
    "country": "US",
    "name": "Sparkill",
    "lat": "41.03121",
    "lng": "-73.92708"
  },
  {
    "country": "US",
    "name": "Spencerport",
    "lat": "43.18645",
    "lng": "-77.8039"
  },
  {
    "country": "US",
    "name": "Springfield",
    "lat": "42.83618",
    "lng": "-74.85348"
  },
  {
    "country": "US",
    "name": "Springfield Gardens",
    "lat": "40.66312",
    "lng": "-73.76221"
  },
  {
    "country": "US",
    "name": "Springs",
    "lat": "41.01621",
    "lng": "-72.15924"
  },
  {
    "country": "US",
    "name": "Springville",
    "lat": "42.5084",
    "lng": "-78.66725"
  },
  {
    "country": "US",
    "name": "Spring Valley",
    "lat": "41.11315",
    "lng": "-74.04375"
  },
  {
    "country": "US",
    "name": "Spuyten Duyvil",
    "lat": "40.88121",
    "lng": "-73.91736"
  },
  {
    "country": "US",
    "name": "Saint Bonaventure",
    "lat": "42.08034",
    "lng": "-78.47502"
  },
  {
    "country": "US",
    "name": "Stamford",
    "lat": "42.4073",
    "lng": "-74.61432"
  },
  {
    "country": "US",
    "name": "Stapleton",
    "lat": "40.62649",
    "lng": "-74.07764"
  },
  {
    "country": "US",
    "name": "Staten Island",
    "lat": "40.56233",
    "lng": "-74.13986"
  },
  {
    "country": "US",
    "name": "Steinway",
    "lat": "40.77455",
    "lng": "-73.90375"
  },
  {
    "country": "US",
    "name": "Stewart Manor",
    "lat": "40.71927",
    "lng": "-73.68846"
  },
  {
    "country": "US",
    "name": "Stillwater",
    "lat": "42.93841",
    "lng": "-73.65317"
  },
  {
    "country": "US",
    "name": "Stone Ridge",
    "lat": "41.85315",
    "lng": "-74.13903"
  },
  {
    "country": "US",
    "name": "Stony Brook",
    "lat": "40.92565",
    "lng": "-73.14094"
  },
  {
    "country": "US",
    "name": "Stony Point",
    "lat": "41.22954",
    "lng": "-73.98708"
  },
  {
    "country": "US",
    "name": "Stottville",
    "lat": "42.2862",
    "lng": "-73.73873"
  },
  {
    "country": "US",
    "name": "Suffern",
    "lat": "41.11482",
    "lng": "-74.14959"
  },
  {
    "country": "US",
    "name": "Sunnyside",
    "lat": "40.73982",
    "lng": "-73.93542"
  },
  {
    "country": "US",
    "name": "Sylvan Beach",
    "lat": "42.46479",
    "lng": "-77.1083"
  },
  {
    "country": "US",
    "name": "Syosset",
    "lat": "40.82621",
    "lng": "-73.50207"
  },
  {
    "country": "US",
    "name": "Syracuse",
    "lat": "43.04812",
    "lng": "-76.14742"
  },
  {
    "country": "US",
    "name": "Tappan",
    "lat": "41.02204",
    "lng": "-73.94736"
  },
  {
    "country": "US",
    "name": "Tarrytown",
    "lat": "41.07621",
    "lng": "-73.85875"
  },
  {
    "country": "US",
    "name": "Terrace Heights",
    "lat": "40.72149",
    "lng": "-73.7693"
  },
  {
    "country": "US",
    "name": "Terryville",
    "lat": "40.90899",
    "lng": "-73.06511"
  },
  {
    "country": "US",
    "name": "Thiells",
    "lat": "41.21065",
    "lng": "-74.01764"
  },
  {
    "country": "US",
    "name": "Thomaston",
    "lat": "40.78621",
    "lng": "-73.71374"
  },
  {
    "country": "US",
    "name": "Thornwood",
    "lat": "41.12343",
    "lng": "-73.77902"
  },
  {
    "country": "US",
    "name": "Throgs Neck",
    "lat": "40.8226",
    "lng": "-73.81958"
  },
  {
    "country": "US",
    "name": "Ticonderoga",
    "lat": "43.84867",
    "lng": "-73.42345"
  },
  {
    "country": "US",
    "name": "Tillson",
    "lat": "41.82898",
    "lng": "-74.06848"
  },
  {
    "country": "US",
    "name": "Tivoli",
    "lat": "42.05842",
    "lng": "-73.9093"
  },
  {
    "country": "US",
    "name": "Tompkinsville",
    "lat": "40.63649",
    "lng": "-74.08542"
  },
  {
    "country": "US",
    "name": "Tonawanda",
    "lat": "43.02033",
    "lng": "-78.88031"
  },
  {
    "country": "US",
    "name": "Town Line",
    "lat": "42.89061",
    "lng": "-78.5778"
  },
  {
    "country": "US",
    "name": "Tremont",
    "lat": "40.84954",
    "lng": "-73.90569"
  },
  {
    "country": "US",
    "name": "Tribes Hill",
    "lat": "42.95535",
    "lng": "-74.28513"
  },
  {
    "country": "US",
    "name": "Troy",
    "lat": "42.72841",
    "lng": "-73.69179"
  },
  {
    "country": "US",
    "name": "Trumansburg",
    "lat": "42.54229",
    "lng": "-76.66606"
  },
  {
    "country": "US",
    "name": "Tuckahoe",
    "lat": "40.89899",
    "lng": "-72.41092"
  },
  {
    "country": "US",
    "name": "Tuckahoe",
    "lat": "40.95038",
    "lng": "-73.82736"
  },
  {
    "country": "US",
    "name": "Tupper Lake",
    "lat": "44.22395",
    "lng": "-74.46406"
  },
  {
    "country": "US",
    "name": "Unadilla",
    "lat": "42.32536",
    "lng": "-75.3124"
  },
  {
    "country": "US",
    "name": "Union Springs",
    "lat": "42.83979",
    "lng": "-76.69328"
  },
  {
    "country": "US",
    "name": "Uniondale",
    "lat": "40.70038",
    "lng": "-73.59291"
  },
  {
    "country": "US",
    "name": "Unionport",
    "lat": "40.82732",
    "lng": "-73.85013"
  },
  {
    "country": "US",
    "name": "University Gardens",
    "lat": "40.77732",
    "lng": "-73.72263"
  },
  {
    "country": "US",
    "name": "University Heights",
    "lat": "40.8601",
    "lng": "-73.9093"
  },
  {
    "country": "US",
    "name": "Upper Brookville",
    "lat": "40.83871",
    "lng": "-73.56513"
  },
  {
    "country": "US",
    "name": "Upper Nyack",
    "lat": "41.10704",
    "lng": "-73.92014"
  },
  {
    "country": "US",
    "name": "Utica",
    "lat": "43.1009",
    "lng": "-75.23266"
  },
  {
    "country": "US",
    "name": "Vails Gate",
    "lat": "41.45426",
    "lng": "-74.05764"
  },
  {
    "country": "US",
    "name": "Valatie",
    "lat": "42.41342",
    "lng": "-73.67317"
  },
  {
    "country": "US",
    "name": "Valhalla",
    "lat": "41.07482",
    "lng": "-73.77513"
  },
  {
    "country": "US",
    "name": "Valley Cottage",
    "lat": "41.11815",
    "lng": "-73.95542"
  },
  {
    "country": "US",
    "name": "Valley Stream",
    "lat": "40.66427",
    "lng": "-73.70846"
  },
  {
    "country": "US",
    "name": "Van Nest",
    "lat": "40.84843",
    "lng": "-73.86375"
  },
  {
    "country": "US",
    "name": "Vernon",
    "lat": "43.07951",
    "lng": "-75.53934"
  },
  {
    "country": "US",
    "name": "Verplanck",
    "lat": "41.25287",
    "lng": "-73.95986"
  },
  {
    "country": "US",
    "name": "Victor",
    "lat": "42.98256",
    "lng": "-77.40888"
  },
  {
    "country": "US",
    "name": "Village Green",
    "lat": "43.1334",
    "lng": "-76.31299"
  },
  {
    "country": "US",
    "name": "Village of the Branch",
    "lat": "40.85621",
    "lng": "-73.18733"
  },
  {
    "country": "US",
    "name": "Viola",
    "lat": "41.13648",
    "lng": "-74.08236"
  },
  {
    "country": "US",
    "name": "Volney",
    "lat": "43.34285",
    "lng": "-76.35771"
  },
  {
    "country": "US",
    "name": "Voorheesville",
    "lat": "42.65397",
    "lng": "-73.92874"
  },
  {
    "country": "US",
    "name": "Wading River",
    "lat": "40.95038",
    "lng": "-72.8426"
  },
  {
    "country": "US",
    "name": "Wakefield",
    "lat": "40.89788",
    "lng": "-73.85236"
  },
  {
    "country": "US",
    "name": "Walden",
    "lat": "41.5612",
    "lng": "-74.18848"
  },
  {
    "country": "US",
    "name": "Wallkill",
    "lat": "41.60565",
    "lng": "-74.18404"
  },
  {
    "country": "US",
    "name": "Walton",
    "lat": "42.16953",
    "lng": "-75.12934"
  },
  {
    "country": "US",
    "name": "Walton Park",
    "lat": "41.30982",
    "lng": "-74.22904"
  },
  {
    "country": "US",
    "name": "Wampsville",
    "lat": "43.07535",
    "lng": "-75.70685"
  },
  {
    "country": "US",
    "name": "Wantagh",
    "lat": "40.68371",
    "lng": "-73.51013"
  },
  {
    "country": "US",
    "name": "Wanakah",
    "lat": "42.74617",
    "lng": "-78.90309"
  },
  {
    "country": "US",
    "name": "Wappingers Falls",
    "lat": "41.59648",
    "lng": "-73.91097"
  },
  {
    "country": "US",
    "name": "Warrensburg",
    "lat": "43.49674",
    "lng": "-73.77623"
  },
  {
    "country": "US",
    "name": "Warsaw",
    "lat": "42.74006",
    "lng": "-78.13279"
  },
  {
    "country": "US",
    "name": "Warwick",
    "lat": "41.25648",
    "lng": "-74.35988"
  },
  {
    "country": "US",
    "name": "Washington Heights",
    "lat": "40.8501",
    "lng": "-73.93541"
  },
  {
    "country": "US",
    "name": "Washington Heights",
    "lat": "41.47009",
    "lng": "-74.41571"
  },
  {
    "country": "US",
    "name": "Washington Mills",
    "lat": "43.05007",
    "lng": "-75.27294"
  },
  {
    "country": "US",
    "name": "Washingtonville",
    "lat": "41.42787",
    "lng": "-74.16598"
  },
  {
    "country": "US",
    "name": "Water Mill",
    "lat": "40.90593",
    "lng": "-72.36203"
  },
  {
    "country": "US",
    "name": "Waterford",
    "lat": "42.79258",
    "lng": "-73.68123"
  },
  {
    "country": "US",
    "name": "Waterloo",
    "lat": "42.90479",
    "lng": "-76.86274"
  },
  {
    "country": "US",
    "name": "Water Mill",
    "lat": "40.91959",
    "lng": "-72.34274"
  },
  {
    "country": "US",
    "name": "Watertown",
    "lat": "43.97478",
    "lng": "-75.91076"
  },
  {
    "country": "US",
    "name": "Waterville",
    "lat": "42.93118",
    "lng": "-75.37989"
  },
  {
    "country": "US",
    "name": "Watkins Glen",
    "lat": "42.38063",
    "lng": "-76.87329"
  },
  {
    "country": "US",
    "name": "Waverly",
    "lat": "42.01035",
    "lng": "-76.52717"
  },
  {
    "country": "US",
    "name": "Wawarsing",
    "lat": "41.75898",
    "lng": "-74.35738"
  },
  {
    "country": "US",
    "name": "Webster",
    "lat": "43.21229",
    "lng": "-77.42999"
  },
  {
    "country": "US",
    "name": "Weedsport",
    "lat": "43.04868",
    "lng": "-76.56272"
  },
  {
    "country": "US",
    "name": "Wellsville",
    "lat": "42.12201",
    "lng": "-77.94806"
  },
  {
    "country": "US",
    "name": "Wellsville",
    "lat": "42.87591",
    "lng": "-74.27235"
  },
  {
    "country": "US",
    "name": "Wesley Hills",
    "lat": "41.15926",
    "lng": "-74.06986"
  },
  {
    "country": "US",
    "name": "West Albany",
    "lat": "42.68313",
    "lng": "-73.77845"
  },
  {
    "country": "US",
    "name": "West Babylon",
    "lat": "40.71816",
    "lng": "-73.35429"
  },
  {
    "country": "US",
    "name": "West Bay Shore",
    "lat": "40.70871",
    "lng": "-73.28123"
  },
  {
    "country": "US",
    "name": "West Carthage",
    "lat": "43.97423",
    "lng": "-75.61519"
  },
  {
    "country": "US",
    "name": "West Elmira",
    "lat": "42.07813",
    "lng": "-76.84524"
  },
  {
    "country": "US",
    "name": "West End",
    "lat": "42.46869",
    "lng": "-75.09378"
  },
  {
    "country": "US",
    "name": "West Glens Falls",
    "lat": "43.30007",
    "lng": "-73.68401"
  },
  {
    "country": "US",
    "name": "West Haverstraw",
    "lat": "41.20954",
    "lng": "-73.98542"
  },
  {
    "country": "US",
    "name": "West Hempstead",
    "lat": "40.70482",
    "lng": "-73.65013"
  },
  {
    "country": "US",
    "name": "West Hills",
    "lat": "40.81621",
    "lng": "-73.43234"
  },
  {
    "country": "US",
    "name": "West Hurley",
    "lat": "41.99731",
    "lng": "-74.10486"
  },
  {
    "country": "US",
    "name": "West Islip",
    "lat": "40.70621",
    "lng": "-73.30623"
  },
  {
    "country": "US",
    "name": "West Nyack",
    "lat": "41.09649",
    "lng": "-73.97292"
  },
  {
    "country": "US",
    "name": "West Point",
    "lat": "41.39148",
    "lng": "-73.95597"
  },
  {
    "country": "US",
    "name": "West Sand Lake",
    "lat": "42.64341",
    "lng": "-73.60873"
  },
  {
    "country": "US",
    "name": "West Sayville",
    "lat": "40.72788",
    "lng": "-73.09761"
  },
  {
    "country": "US",
    "name": "West Seneca",
    "lat": "42.85006",
    "lng": "-78.79975"
  },
  {
    "country": "US",
    "name": "Westbury",
    "lat": "40.75566",
    "lng": "-73.58763"
  },
  {
    "country": "US",
    "name": "Westerleigh",
    "lat": "40.62121",
    "lng": "-74.13181"
  },
  {
    "country": "US",
    "name": "Westfield",
    "lat": "42.32228",
    "lng": "-79.5781"
  },
  {
    "country": "US",
    "name": "Westhampton",
    "lat": "40.82454",
    "lng": "-72.66621"
  },
  {
    "country": "US",
    "name": "Westhampton Beach",
    "lat": "40.80316",
    "lng": "-72.61454"
  },
  {
    "country": "US",
    "name": "Westmere",
    "lat": "42.69119",
    "lng": "-73.86873"
  },
  {
    "country": "US",
    "name": "Weston Mills",
    "lat": "42.0759",
    "lng": "-78.37252"
  },
  {
    "country": "US",
    "name": "Westons Mills",
    "lat": "42.06229",
    "lng": "-78.37724"
  },
  {
    "country": "US",
    "name": "Westvale",
    "lat": "43.04757",
    "lng": "-76.22048"
  },
  {
    "country": "US",
    "name": "Wheatley Heights",
    "lat": "40.76371",
    "lng": "-73.36984"
  },
  {
    "country": "US",
    "name": "White Plains",
    "lat": "41.03399",
    "lng": "-73.76291"
  },
  {
    "country": "US",
    "name": "Whitehall",
    "lat": "43.55562",
    "lng": "-73.40372"
  },
  {
    "country": "US",
    "name": "Whitesboro",
    "lat": "43.12201",
    "lng": "-75.29156"
  },
  {
    "country": "US",
    "name": "Whitestone",
    "lat": "40.79455",
    "lng": "-73.81847"
  },
  {
    "country": "US",
    "name": "Williamsburg",
    "lat": "40.71427",
    "lng": "-73.95347"
  },
  {
    "country": "US",
    "name": "Williamson",
    "lat": "43.22395",
    "lng": "-77.18609"
  },
  {
    "country": "US",
    "name": "Williamsville",
    "lat": "42.96395",
    "lng": "-78.73781"
  },
  {
    "country": "US",
    "name": "Williston Park",
    "lat": "40.75649",
    "lng": "-73.64485"
  },
  {
    "country": "US",
    "name": "Willowbrook",
    "lat": "40.60316",
    "lng": "-74.13848"
  },
  {
    "country": "US",
    "name": "Wilson",
    "lat": "43.30978",
    "lng": "-78.82615"
  },
  {
    "country": "US",
    "name": "Wolcott",
    "lat": "43.22062",
    "lng": "-76.81496"
  },
  {
    "country": "US",
    "name": "Woodbury",
    "lat": "40.82565",
    "lng": "-73.46762"
  },
  {
    "country": "US",
    "name": "Woodbury",
    "lat": "41.36454",
    "lng": "-74.10598"
  },
  {
    "country": "US",
    "name": "Woodhaven",
    "lat": "40.68927",
    "lng": "-73.85791"
  },
  {
    "country": "US",
    "name": "Woodlawn",
    "lat": "40.89816",
    "lng": "-73.86736"
  },
  {
    "country": "US",
    "name": "Woodmere",
    "lat": "40.63205",
    "lng": "-73.71263"
  },
  {
    "country": "US",
    "name": "Woodrow",
    "lat": "40.54344",
    "lng": "-74.19764"
  },
  {
    "country": "US",
    "name": "Woodside",
    "lat": "40.74538",
    "lng": "-73.90541"
  },
  {
    "country": "US",
    "name": "Woodstock",
    "lat": "42.04092",
    "lng": "-74.1182"
  },
  {
    "country": "US",
    "name": "Worcester",
    "lat": "42.59146",
    "lng": "-74.75043"
  },
  {
    "country": "US",
    "name": "Wurtsboro",
    "lat": "41.57676",
    "lng": "-74.4871"
  },
  {
    "country": "US",
    "name": "Wyandanch",
    "lat": "40.75399",
    "lng": "-73.3604"
  },
  {
    "country": "US",
    "name": "Wykagyl",
    "lat": "40.94149",
    "lng": "-73.79902"
  },
  {
    "country": "US",
    "name": "Wynantskill",
    "lat": "42.69675",
    "lng": "-73.64428"
  },
  {
    "country": "US",
    "name": "Yaphank",
    "lat": "40.83677",
    "lng": "-72.91705"
  },
  {
    "country": "US",
    "name": "Yonkers",
    "lat": "40.93121",
    "lng": "-73.89875"
  },
  {
    "country": "US",
    "name": "Yorkshire",
    "lat": "42.53006",
    "lng": "-78.4728"
  },
  {
    "country": "US",
    "name": "Yorktown Heights",
    "lat": "41.27093",
    "lng": "-73.77763"
  },
  {
    "country": "US",
    "name": "Yorkville",
    "lat": "43.11285",
    "lng": "-75.271"
  },
  {
    "country": "US",
    "name": "Youngstown",
    "lat": "43.24728",
    "lng": "-79.05005"
  },
  {
    "country": "US",
    "name": "Zena",
    "lat": "42.01676",
    "lng": "-74.07625"
  },
  {
    "country": "US",
    "name": "Ada",
    "lat": "40.7695",
    "lng": "-83.82271"
  },
  {
    "country": "US",
    "name": "Akron",
    "lat": "41.08144",
    "lng": "-81.51901"
  },
  {
    "country": "US",
    "name": "Alliance",
    "lat": "40.91534",
    "lng": "-81.10593"
  },
  {
    "country": "US",
    "name": "Amherst",
    "lat": "41.39782",
    "lng": "-82.22238"
  },
  {
    "country": "US",
    "name": "Andover",
    "lat": "41.60672",
    "lng": "-80.5723"
  },
  {
    "country": "US",
    "name": "Anna",
    "lat": "40.39449",
    "lng": "-84.17272"
  },
  {
    "country": "US",
    "name": "Ansonia",
    "lat": "40.21449",
    "lng": "-84.6369"
  },
  {
    "country": "US",
    "name": "Antwerp",
    "lat": "41.18144",
    "lng": "-84.74051"
  },
  {
    "country": "US",
    "name": "Apple Creek",
    "lat": "40.75172",
    "lng": "-81.8393"
  },
  {
    "country": "US",
    "name": "Archbold",
    "lat": "41.52144",
    "lng": "-84.30717"
  },
  {
    "country": "US",
    "name": "Arlington",
    "lat": "40.89366",
    "lng": "-83.65021"
  },
  {
    "country": "US",
    "name": "Ashland",
    "lat": "40.86867",
    "lng": "-82.31822"
  },
  {
    "country": "US",
    "name": "Ashley",
    "lat": "40.40895",
    "lng": "-82.95546"
  },
  {
    "country": "US",
    "name": "Ashtabula",
    "lat": "41.86505",
    "lng": "-80.78981"
  },
  {
    "country": "US",
    "name": "Aurora",
    "lat": "41.31755",
    "lng": "-81.34539"
  },
  {
    "country": "US",
    "name": "Austintown",
    "lat": "41.10172",
    "lng": "-80.76452"
  },
  {
    "country": "US",
    "name": "Avon",
    "lat": "41.45171",
    "lng": "-82.03542"
  },
  {
    "country": "US",
    "name": "Avon Center",
    "lat": "41.45976",
    "lng": "-82.01959"
  },
  {
    "country": "US",
    "name": "Avon Lake",
    "lat": "41.50532",
    "lng": "-82.0282"
  },
  {
    "country": "US",
    "name": "Bainbridge",
    "lat": "41.38644",
    "lng": "-81.33955"
  },
  {
    "country": "US",
    "name": "Ballville",
    "lat": "41.32783",
    "lng": "-83.13214"
  },
  {
    "country": "US",
    "name": "Barberton",
    "lat": "41.01283",
    "lng": "-81.60512"
  },
  {
    "country": "US",
    "name": "Bay Village",
    "lat": "41.48477",
    "lng": "-81.92208"
  },
  {
    "country": "US",
    "name": "Beach City",
    "lat": "40.65312",
    "lng": "-81.58096"
  },
  {
    "country": "US",
    "name": "Beachwood",
    "lat": "41.4645",
    "lng": "-81.50873"
  },
  {
    "country": "US",
    "name": "Bedford",
    "lat": "41.39311",
    "lng": "-81.53651"
  },
  {
    "country": "US",
    "name": "Bedford Heights",
    "lat": "41.417",
    "lng": "-81.52734"
  },
  {
    "country": "US",
    "name": "Beechwood Trails",
    "lat": "40.02367",
    "lng": "-82.65072"
  },
  {
    "country": "US",
    "name": "Bellaire",
    "lat": "40.01618",
    "lng": "-80.74231"
  },
  {
    "country": "US",
    "name": "Bellefontaine",
    "lat": "40.36116",
    "lng": "-83.75966"
  },
  {
    "country": "US",
    "name": "Bellevue",
    "lat": "41.27366",
    "lng": "-82.84158"
  },
  {
    "country": "US",
    "name": "Bellville",
    "lat": "40.62006",
    "lng": "-82.51072"
  },
  {
    "country": "US",
    "name": "Berea",
    "lat": "41.36616",
    "lng": "-81.8543"
  },
  {
    "country": "US",
    "name": "Bethesda",
    "lat": "40.01618",
    "lng": "-81.0726"
  },
  {
    "country": "US",
    "name": "Bluffton",
    "lat": "40.89533",
    "lng": "-83.88883"
  },
  {
    "country": "US",
    "name": "Boardman",
    "lat": "41.02423",
    "lng": "-80.66285"
  },
  {
    "country": "US",
    "name": "Bolindale",
    "lat": "41.20728",
    "lng": "-80.77758"
  },
  {
    "country": "US",
    "name": "Boston Heights",
    "lat": "41.26478",
    "lng": "-81.51317"
  },
  {
    "country": "US",
    "name": "Botkins",
    "lat": "40.46783",
    "lng": "-84.1805"
  },
  {
    "country": "US",
    "name": "Bowling Green",
    "lat": "41.37477",
    "lng": "-83.65132"
  },
  {
    "country": "US",
    "name": "Bradford",
    "lat": "40.13227",
    "lng": "-84.43078"
  },
  {
    "country": "US",
    "name": "Bradner",
    "lat": "41.32422",
    "lng": "-83.43854"
  },
  {
    "country": "US",
    "name": "Bratenahl",
    "lat": "41.54255",
    "lng": "-81.62624"
  },
  {
    "country": "US",
    "name": "Brecksville",
    "lat": "41.31978",
    "lng": "-81.62679"
  },
  {
    "country": "US",
    "name": "Brewster",
    "lat": "40.707",
    "lng": "-81.59818"
  },
  {
    "country": "US",
    "name": "Bridgeport",
    "lat": "40.06979",
    "lng": "-80.74008"
  },
  {
    "country": "US",
    "name": "Brilliant",
    "lat": "40.26479",
    "lng": "-80.62619"
  },
  {
    "country": "US",
    "name": "Brimfield",
    "lat": "41.10006",
    "lng": "-81.3465"
  },
  {
    "country": "US",
    "name": "Broadview Heights",
    "lat": "41.31394",
    "lng": "-81.68513"
  },
  {
    "country": "US",
    "name": "Brook Park",
    "lat": "41.39838",
    "lng": "-81.80458"
  },
  {
    "country": "US",
    "name": "Brookfield Center",
    "lat": "41.24061",
    "lng": "-80.55785"
  },
  {
    "country": "US",
    "name": "Brooklyn",
    "lat": "41.43977",
    "lng": "-81.73541"
  },
  {
    "country": "US",
    "name": "Brooklyn Heights",
    "lat": "41.42533",
    "lng": "-81.68818"
  },
  {
    "country": "US",
    "name": "Brunswick",
    "lat": "41.23811",
    "lng": "-81.8418"
  },
  {
    "country": "US",
    "name": "Bryan",
    "lat": "41.47477",
    "lng": "-84.55245"
  },
  {
    "country": "US",
    "name": "Bucyrus",
    "lat": "40.80839",
    "lng": "-82.97546"
  },
  {
    "country": "US",
    "name": "Burlington",
    "lat": "41.57227",
    "lng": "-84.308"
  },
  {
    "country": "US",
    "name": "Burton",
    "lat": "41.47061",
    "lng": "-81.1451"
  },
  {
    "country": "US",
    "name": "Cadiz",
    "lat": "40.27285",
    "lng": "-80.99676"
  },
  {
    "country": "US",
    "name": "Calcutta",
    "lat": "40.6734",
    "lng": "-80.57646"
  },
  {
    "country": "US",
    "name": "Cambridge",
    "lat": "40.03118",
    "lng": "-81.58846"
  },
  {
    "country": "US",
    "name": "Campbell",
    "lat": "41.07839",
    "lng": "-80.59924"
  },
  {
    "country": "US",
    "name": "Canal Fulton",
    "lat": "40.88978",
    "lng": "-81.59762"
  },
  {
    "country": "US",
    "name": "Canfield",
    "lat": "41.02506",
    "lng": "-80.76091"
  },
  {
    "country": "US",
    "name": "Canton",
    "lat": "40.79895",
    "lng": "-81.37845"
  },
  {
    "country": "US",
    "name": "Cardington",
    "lat": "40.50062",
    "lng": "-82.89351"
  },
  {
    "country": "US",
    "name": "Carey",
    "lat": "40.95256",
    "lng": "-83.38242"
  },
  {
    "country": "US",
    "name": "Carrollton",
    "lat": "40.57284",
    "lng": "-81.08565"
  },
  {
    "country": "US",
    "name": "Celina",
    "lat": "40.54894",
    "lng": "-84.57023"
  },
  {
    "country": "US",
    "name": "Centerburg",
    "lat": "40.30451",
    "lng": "-82.69628"
  },
  {
    "country": "US",
    "name": "Chagrin Falls",
    "lat": "41.43616",
    "lng": "-81.3865"
  },
  {
    "country": "US",
    "name": "Chardon",
    "lat": "41.61422",
    "lng": "-81.14899"
  },
  {
    "country": "US",
    "name": "Chesterland",
    "lat": "41.52227",
    "lng": "-81.33789"
  },
  {
    "country": "US",
    "name": "Churchill",
    "lat": "41.162",
    "lng": "-80.6648"
  },
  {
    "country": "US",
    "name": "Cleveland",
    "lat": "41.4995",
    "lng": "-81.69541"
  },
  {
    "country": "US",
    "name": "Clinton",
    "lat": "40.92672",
    "lng": "-81.6304"
  },
  {
    "country": "US",
    "name": "Clyde",
    "lat": "41.30422",
    "lng": "-82.97519"
  },
  {
    "country": "US",
    "name": "Coldwater",
    "lat": "40.47977",
    "lng": "-84.62829"
  },
  {
    "country": "US",
    "name": "Collinwood",
    "lat": "41.55838",
    "lng": "-81.56929"
  },
  {
    "country": "US",
    "name": "Columbiana",
    "lat": "40.88839",
    "lng": "-80.69396"
  },
  {
    "country": "US",
    "name": "Columbus Grove",
    "lat": "40.9195",
    "lng": "-84.05689"
  },
  {
    "country": "US",
    "name": "Conneaut",
    "lat": "41.94756",
    "lng": "-80.55424"
  },
  {
    "country": "US",
    "name": "Continental",
    "lat": "41.10033",
    "lng": "-84.26634"
  },
  {
    "country": "US",
    "name": "Convoy",
    "lat": "40.91672",
    "lng": "-84.70274"
  },
  {
    "country": "US",
    "name": "Copley",
    "lat": "41.09894",
    "lng": "-81.64457"
  },
  {
    "country": "US",
    "name": "Cortland",
    "lat": "41.33033",
    "lng": "-80.72536"
  },
  {
    "country": "US",
    "name": "Coshocton",
    "lat": "40.27202",
    "lng": "-81.85958"
  },
  {
    "country": "US",
    "name": "Covington",
    "lat": "40.11727",
    "lng": "-84.35384"
  },
  {
    "country": "US",
    "name": "Craig Beach",
    "lat": "41.117",
    "lng": "-80.98342"
  },
  {
    "country": "US",
    "name": "Sheffield",
    "lat": "41.46222",
    "lng": "-82.09868"
  },
  {
    "country": "US",
    "name": "Crestline",
    "lat": "40.78756",
    "lng": "-82.73657"
  },
  {
    "country": "US",
    "name": "Creston",
    "lat": "40.987",
    "lng": "-81.89375"
  },
  {
    "country": "US",
    "name": "Cridersville",
    "lat": "40.65422",
    "lng": "-84.15078"
  },
  {
    "country": "US",
    "name": "Curtice",
    "lat": "41.61838",
    "lng": "-83.36771"
  },
  {
    "country": "US",
    "name": "Cuyahoga Falls",
    "lat": "41.13394",
    "lng": "-81.48456"
  },
  {
    "country": "US",
    "name": "Dalton",
    "lat": "40.79894",
    "lng": "-81.69541"
  },
  {
    "country": "US",
    "name": "Danville",
    "lat": "40.44756",
    "lng": "-82.26016"
  },
  {
    "country": "US",
    "name": "De Graff",
    "lat": "40.312",
    "lng": "-83.91577"
  },
  {
    "country": "US",
    "name": "Defiance",
    "lat": "41.28449",
    "lng": "-84.35578"
  },
  {
    "country": "US",
    "name": "Delaware",
    "lat": "40.29867",
    "lng": "-83.06797"
  },
  {
    "country": "US",
    "name": "Delphos",
    "lat": "40.84338",
    "lng": "-84.34162"
  },
  {
    "country": "US",
    "name": "Delta",
    "lat": "41.57366",
    "lng": "-84.00522"
  },
  {
    "country": "US",
    "name": "Dennison",
    "lat": "40.3934",
    "lng": "-81.33372"
  },
  {
    "country": "US",
    "name": "Deshler",
    "lat": "41.20755",
    "lng": "-83.89911"
  },
  {
    "country": "US",
    "name": "Dover",
    "lat": "40.52062",
    "lng": "-81.47401"
  },
  {
    "country": "US",
    "name": "Doylestown",
    "lat": "40.97005",
    "lng": "-81.69652"
  },
  {
    "country": "US",
    "name": "Dresden",
    "lat": "40.12146",
    "lng": "-82.01069"
  },
  {
    "country": "US",
    "name": "Dublin",
    "lat": "40.09923",
    "lng": "-83.11408"
  },
  {
    "country": "US",
    "name": "East Canton",
    "lat": "40.78728",
    "lng": "-81.28261"
  },
  {
    "country": "US",
    "name": "East Cleveland",
    "lat": "41.53311",
    "lng": "-81.57901"
  },
  {
    "country": "US",
    "name": "East Liverpool",
    "lat": "40.61868",
    "lng": "-80.57729"
  },
  {
    "country": "US",
    "name": "East Palestine",
    "lat": "40.83395",
    "lng": "-80.54035"
  },
  {
    "country": "US",
    "name": "Eastlake",
    "lat": "41.65394",
    "lng": "-81.45039"
  },
  {
    "country": "US",
    "name": "Eaton Estates",
    "lat": "41.30894",
    "lng": "-82.0057"
  },
  {
    "country": "US",
    "name": "Edgerton",
    "lat": "41.44866",
    "lng": "-84.74801"
  },
  {
    "country": "US",
    "name": "Edgewood",
    "lat": "41.87283",
    "lng": "-80.77286"
  },
  {
    "country": "US",
    "name": "Elida",
    "lat": "40.78866",
    "lng": "-84.20384"
  },
  {
    "country": "US",
    "name": "Elmore",
    "lat": "41.47616",
    "lng": "-83.29576"
  },
  {
    "country": "US",
    "name": "Elyria",
    "lat": "41.36838",
    "lng": "-82.10765"
  },
  {
    "country": "US",
    "name": "Euclid",
    "lat": "41.5931",
    "lng": "-81.52679"
  },
  {
    "country": "US",
    "name": "Fairlawn",
    "lat": "41.12783",
    "lng": "-81.60984"
  },
  {
    "country": "US",
    "name": "Fairport Harbor",
    "lat": "41.75004",
    "lng": "-81.27399"
  },
  {
    "country": "US",
    "name": "Fairview Park",
    "lat": "41.44144",
    "lng": "-81.8643"
  },
  {
    "country": "US",
    "name": "Fayette",
    "lat": "41.67338",
    "lng": "-84.32689"
  },
  {
    "country": "US",
    "name": "Findlay",
    "lat": "41.04422",
    "lng": "-83.64993"
  },
  {
    "country": "US",
    "name": "Forest",
    "lat": "40.80172",
    "lng": "-83.51048"
  },
  {
    "country": "US",
    "name": "Fort Loramie",
    "lat": "40.35144",
    "lng": "-84.37384"
  },
  {
    "country": "US",
    "name": "Fort Recovery",
    "lat": "40.41282",
    "lng": "-84.77635"
  },
  {
    "country": "US",
    "name": "Fort Shawnee",
    "lat": "40.68672",
    "lng": "-84.13773"
  },
  {
    "country": "US",
    "name": "Fostoria",
    "lat": "41.157",
    "lng": "-83.41687"
  },
  {
    "country": "US",
    "name": "Frazeysburg",
    "lat": "40.11729",
    "lng": "-82.11931"
  },
  {
    "country": "US",
    "name": "Fredericktown",
    "lat": "40.48117",
    "lng": "-82.54072"
  },
  {
    "country": "US",
    "name": "Fremont",
    "lat": "41.35033",
    "lng": "-83.12186"
  },
  {
    "country": "US",
    "name": "Gahanna",
    "lat": "40.01923",
    "lng": "-82.87934"
  },
  {
    "country": "US",
    "name": "Galion",
    "lat": "40.73367",
    "lng": "-82.7899"
  },
  {
    "country": "US",
    "name": "Gambier",
    "lat": "40.37562",
    "lng": "-82.3971"
  },
  {
    "country": "US",
    "name": "Garfield Heights",
    "lat": "41.417",
    "lng": "-81.60596"
  },
  {
    "country": "US",
    "name": "Garrettsville",
    "lat": "41.28422",
    "lng": "-81.09649"
  },
  {
    "country": "US",
    "name": "Gates Mills",
    "lat": "41.51755",
    "lng": "-81.40345"
  },
  {
    "country": "US",
    "name": "Geneva",
    "lat": "41.80505",
    "lng": "-80.94815"
  },
  {
    "country": "US",
    "name": "Geneva-on-the-Lake",
    "lat": "41.8595",
    "lng": "-80.95398"
  },
  {
    "country": "US",
    "name": "Genoa",
    "lat": "40.78284",
    "lng": "-81.46651"
  },
  {
    "country": "US",
    "name": "Gibsonburg",
    "lat": "41.3845",
    "lng": "-83.32048"
  },
  {
    "country": "US",
    "name": "Girard",
    "lat": "41.15395",
    "lng": "-80.70147"
  },
  {
    "country": "US",
    "name": "Glandorf",
    "lat": "41.02894",
    "lng": "-84.07911"
  },
  {
    "country": "US",
    "name": "Glendale",
    "lat": "41.397",
    "lng": "-81.54234"
  },
  {
    "country": "US",
    "name": "Glenmoor",
    "lat": "40.66617",
    "lng": "-80.62313"
  },
  {
    "country": "US",
    "name": "Glenville",
    "lat": "41.53338",
    "lng": "-81.61735"
  },
  {
    "country": "US",
    "name": "Gnadenhutten",
    "lat": "40.3584",
    "lng": "-81.43428"
  },
  {
    "country": "US",
    "name": "Grafton",
    "lat": "41.27255",
    "lng": "-82.05459"
  },
  {
    "country": "US",
    "name": "Granville",
    "lat": "40.06812",
    "lng": "-82.5196"
  },
  {
    "country": "US",
    "name": "Green",
    "lat": "40.94589",
    "lng": "-81.48317"
  },
  {
    "country": "US",
    "name": "Green Springs",
    "lat": "41.25616",
    "lng": "-83.05158"
  },
  {
    "country": "US",
    "name": "Greensburg",
    "lat": "40.93172",
    "lng": "-81.46484"
  },
  {
    "country": "US",
    "name": "Greentown",
    "lat": "40.92756",
    "lng": "-81.40261"
  },
  {
    "country": "US",
    "name": "Greenville",
    "lat": "40.10283",
    "lng": "-84.63301"
  },
  {
    "country": "US",
    "name": "Greenwich",
    "lat": "41.03005",
    "lng": "-82.51573"
  },
  {
    "country": "US",
    "name": "Hanover",
    "lat": "40.07979",
    "lng": "-82.26098"
  },
  {
    "country": "US",
    "name": "Hartville",
    "lat": "40.96367",
    "lng": "-81.33122"
  },
  {
    "country": "US",
    "name": "Haskins",
    "lat": "41.46477",
    "lng": "-83.70605"
  },
  {
    "country": "US",
    "name": "Heath",
    "lat": "40.02284",
    "lng": "-82.4446"
  },
  {
    "country": "US",
    "name": "Hicksville",
    "lat": "41.29311",
    "lng": "-84.7619"
  },
  {
    "country": "US",
    "name": "Highland Heights",
    "lat": "41.552",
    "lng": "-81.47845"
  },
  {
    "country": "US",
    "name": "Hilliard",
    "lat": "40.0334",
    "lng": "-83.15825"
  },
  {
    "country": "US",
    "name": "Hiram",
    "lat": "41.31256",
    "lng": "-81.14371"
  },
  {
    "country": "US",
    "name": "Holgate",
    "lat": "41.24894",
    "lng": "-84.133"
  },
  {
    "country": "US",
    "name": "Holland",
    "lat": "41.62172",
    "lng": "-83.7116"
  },
  {
    "country": "US",
    "name": "Hough",
    "lat": "41.512",
    "lng": "-81.63652"
  },
  {
    "country": "US",
    "name": "Howland Center",
    "lat": "41.25117",
    "lng": "-80.74536"
  },
  {
    "country": "US",
    "name": "Hubbard",
    "lat": "41.15645",
    "lng": "-80.56924"
  },
  {
    "country": "US",
    "name": "Huber Ridge",
    "lat": "40.08867",
    "lng": "-82.91657"
  },
  {
    "country": "US",
    "name": "Hudson",
    "lat": "41.24006",
    "lng": "-81.44067"
  },
  {
    "country": "US",
    "name": "Huron",
    "lat": "41.39505",
    "lng": "-82.55517"
  },
  {
    "country": "US",
    "name": "Independence",
    "lat": "41.36866",
    "lng": "-81.6379"
  },
  {
    "country": "US",
    "name": "Jackson Center",
    "lat": "40.43949",
    "lng": "-84.04022"
  },
  {
    "country": "US",
    "name": "Jefferson",
    "lat": "41.73867",
    "lng": "-80.76981"
  },
  {
    "country": "US",
    "name": "Johnstown",
    "lat": "40.15367",
    "lng": "-82.68517"
  },
  {
    "country": "US",
    "name": "Kalida",
    "lat": "40.98283",
    "lng": "-84.19939"
  },
  {
    "country": "US",
    "name": "Kent",
    "lat": "41.15367",
    "lng": "-81.35789"
  },
  {
    "country": "US",
    "name": "Kenton",
    "lat": "40.647",
    "lng": "-83.60965"
  },
  {
    "country": "US",
    "name": "Kirtland",
    "lat": "41.62894",
    "lng": "-81.3615"
  },
  {
    "country": "US",
    "name": "La Croft",
    "lat": "40.6459",
    "lng": "-80.59785"
  },
  {
    "country": "US",
    "name": "Lagrange",
    "lat": "41.23728",
    "lng": "-82.11987"
  },
  {
    "country": "US",
    "name": "Lake Mohawk",
    "lat": "40.66673",
    "lng": "-81.19927"
  },
  {
    "country": "US",
    "name": "Lakemore",
    "lat": "41.02089",
    "lng": "-81.43595"
  },
  {
    "country": "US",
    "name": "Lakeview",
    "lat": "40.48477",
    "lng": "-83.923"
  },
  {
    "country": "US",
    "name": "Lakewood",
    "lat": "41.48199",
    "lng": "-81.79819"
  },
  {
    "country": "US",
    "name": "Leavittsburg",
    "lat": "41.24783",
    "lng": "-80.87703"
  },
  {
    "country": "US",
    "name": "Leetonia",
    "lat": "40.87728",
    "lng": "-80.75536"
  },
  {
    "country": "US",
    "name": "Leipsic",
    "lat": "41.09838",
    "lng": "-83.98467"
  },
  {
    "country": "US",
    "name": "Lewis Center",
    "lat": "40.1984",
    "lng": "-83.01018"
  },
  {
    "country": "US",
    "name": "Lexington",
    "lat": "40.67867",
    "lng": "-82.58239"
  },
  {
    "country": "US",
    "name": "Liberty Center",
    "lat": "41.44338",
    "lng": "-84.00883"
  },
  {
    "country": "US",
    "name": "Lima",
    "lat": "40.74255",
    "lng": "-84.10523"
  },
  {
    "country": "US",
    "name": "Lincoln Heights",
    "lat": "40.77145",
    "lng": "-82.48433"
  },
  {
    "country": "US",
    "name": "Lisbon",
    "lat": "40.772",
    "lng": "-80.76813"
  },
  {
    "country": "US",
    "name": "Lodi",
    "lat": "41.03339",
    "lng": "-82.01209"
  },
  {
    "country": "US",
    "name": "Lorain",
    "lat": "41.45282",
    "lng": "-82.18237"
  },
  {
    "country": "US",
    "name": "Lordstown",
    "lat": "41.16561",
    "lng": "-80.85758"
  },
  {
    "country": "US",
    "name": "Loudonville",
    "lat": "40.63534",
    "lng": "-82.23321"
  },
  {
    "country": "US",
    "name": "Louisville",
    "lat": "40.83728",
    "lng": "-81.25955"
  },
  {
    "country": "US",
    "name": "Lowellville",
    "lat": "41.03534",
    "lng": "-80.53646"
  },
  {
    "country": "US",
    "name": "Luckey",
    "lat": "41.45061",
    "lng": "-83.48743"
  },
  {
    "country": "US",
    "name": "Lyndhurst",
    "lat": "41.52005",
    "lng": "-81.48873"
  },
  {
    "country": "US",
    "name": "Macedonia",
    "lat": "41.31367",
    "lng": "-81.50845"
  },
  {
    "country": "US",
    "name": "Madison",
    "lat": "41.77116",
    "lng": "-81.04982"
  },
  {
    "country": "US",
    "name": "Malvern",
    "lat": "40.69173",
    "lng": "-81.18121"
  },
  {
    "country": "US",
    "name": "Manchester",
    "lat": "40.937",
    "lng": "-81.56929"
  },
  {
    "country": "US",
    "name": "Mansfield",
    "lat": "40.75839",
    "lng": "-82.51545"
  },
  {
    "country": "US",
    "name": "Mantua",
    "lat": "40.07785",
    "lng": "-81.67901"
  },
  {
    "country": "US",
    "name": "Mantua",
    "lat": "41.28394",
    "lng": "-81.22399"
  },
  {
    "country": "US",
    "name": "Maple Heights",
    "lat": "41.41533",
    "lng": "-81.56596"
  },
  {
    "country": "US",
    "name": "Marion",
    "lat": "40.58867",
    "lng": "-83.12852"
  },
  {
    "country": "US",
    "name": "Martins Ferry",
    "lat": "40.09591",
    "lng": "-80.72453"
  },
  {
    "country": "US",
    "name": "Marysville",
    "lat": "40.23645",
    "lng": "-83.36714"
  },
  {
    "country": "US",
    "name": "Massillon",
    "lat": "40.79672",
    "lng": "-81.52151"
  },
  {
    "country": "US",
    "name": "Masury",
    "lat": "41.21117",
    "lng": "-80.53785"
  },
  {
    "country": "US",
    "name": "Maumee",
    "lat": "41.56283",
    "lng": "-83.65382"
  },
  {
    "country": "US",
    "name": "Mayfield",
    "lat": "41.552",
    "lng": "-81.43928"
  },
  {
    "country": "US",
    "name": "Mayfield Heights",
    "lat": "41.51922",
    "lng": "-81.4579"
  },
  {
    "country": "US",
    "name": "McComb",
    "lat": "41.10755",
    "lng": "-83.79271"
  },
  {
    "country": "US",
    "name": "McDonald",
    "lat": "41.16367",
    "lng": "-80.72424"
  },
  {
    "country": "US",
    "name": "McKinley Heights",
    "lat": "41.18367",
    "lng": "-80.7173"
  },
  {
    "country": "US",
    "name": "Mechanicsburg",
    "lat": "40.072",
    "lng": "-83.55631"
  },
  {
    "country": "US",
    "name": "Medina",
    "lat": "41.13839",
    "lng": "-81.86375"
  },
  {
    "country": "US",
    "name": "Mentor",
    "lat": "41.66616",
    "lng": "-81.33955"
  },
  {
    "country": "US",
    "name": "Mentor-on-the-Lake",
    "lat": "41.70504",
    "lng": "-81.36039"
  },
  {
    "country": "US",
    "name": "Middleburg Heights",
    "lat": "41.36144",
    "lng": "-81.81291"
  },
  {
    "country": "US",
    "name": "Middlefield",
    "lat": "41.462",
    "lng": "-81.07371"
  },
  {
    "country": "US",
    "name": "Milan",
    "lat": "41.29755",
    "lng": "-82.60545"
  },
  {
    "country": "US",
    "name": "Millbury",
    "lat": "41.56616",
    "lng": "-83.42465"
  },
  {
    "country": "US",
    "name": "Millersburg",
    "lat": "40.55451",
    "lng": "-81.91792"
  },
  {
    "country": "US",
    "name": "Mineral Ridge",
    "lat": "41.14006",
    "lng": "-80.76897"
  },
  {
    "country": "US",
    "name": "Minerva",
    "lat": "40.72978",
    "lng": "-81.10538"
  },
  {
    "country": "US",
    "name": "Minerva Park",
    "lat": "40.07645",
    "lng": "-82.94379"
  },
  {
    "country": "US",
    "name": "Mingo Junction",
    "lat": "40.32174",
    "lng": "-80.6098"
  },
  {
    "country": "US",
    "name": "Minster",
    "lat": "40.3931",
    "lng": "-84.37606"
  },
  {
    "country": "US",
    "name": "Mogadore",
    "lat": "41.04645",
    "lng": "-81.39789"
  },
  {
    "country": "US",
    "name": "Monroeville",
    "lat": "41.24422",
    "lng": "-82.69629"
  },
  {
    "country": "US",
    "name": "Montpelier",
    "lat": "41.5845",
    "lng": "-84.60551"
  },
  {
    "country": "US",
    "name": "Moreland Hills",
    "lat": "41.44783",
    "lng": "-81.42762"
  },
  {
    "country": "US",
    "name": "Morgandale",
    "lat": "41.26561",
    "lng": "-80.78286"
  },
  {
    "country": "US",
    "name": "Mount Carmel",
    "lat": "41.27116",
    "lng": "-82.93686"
  },
  {
    "country": "US",
    "name": "Mount Gilead",
    "lat": "40.54923",
    "lng": "-82.8274"
  },
  {
    "country": "US",
    "name": "Mount Vernon",
    "lat": "40.3934",
    "lng": "-82.48572"
  },
  {
    "country": "US",
    "name": "Munroe Falls",
    "lat": "41.1445",
    "lng": "-81.43983"
  },
  {
    "country": "US",
    "name": "Napoleon",
    "lat": "41.39227",
    "lng": "-84.12522"
  },
  {
    "country": "US",
    "name": "Navarre",
    "lat": "40.7245",
    "lng": "-81.52207"
  },
  {
    "country": "US",
    "name": "New Albany",
    "lat": "40.08117",
    "lng": "-82.80879"
  },
  {
    "country": "US",
    "name": "New Bremen",
    "lat": "40.43699",
    "lng": "-84.37967"
  },
  {
    "country": "US",
    "name": "New California",
    "lat": "40.15617",
    "lng": "-83.23658"
  },
  {
    "country": "US",
    "name": "New Franklin",
    "lat": "40.94172",
    "lng": "-81.54151"
  },
  {
    "country": "US",
    "name": "New London",
    "lat": "41.08505",
    "lng": "-82.39989"
  },
  {
    "country": "US",
    "name": "New Middletown",
    "lat": "40.96117",
    "lng": "-80.55757"
  },
  {
    "country": "US",
    "name": "New Philadelphia",
    "lat": "40.48979",
    "lng": "-81.44567"
  },
  {
    "country": "US",
    "name": "New Waterford",
    "lat": "40.84506",
    "lng": "-80.61452"
  },
  {
    "country": "US",
    "name": "Newark",
    "lat": "40.05812",
    "lng": "-82.40126"
  },
  {
    "country": "US",
    "name": "Newburgh Heights",
    "lat": "41.45005",
    "lng": "-81.66346"
  },
  {
    "country": "US",
    "name": "Newcomerstown",
    "lat": "40.27229",
    "lng": "-81.60595"
  },
  {
    "country": "US",
    "name": "Newton Falls",
    "lat": "41.18839",
    "lng": "-80.97815"
  },
  {
    "country": "US",
    "name": "Niles",
    "lat": "41.18284",
    "lng": "-80.76536"
  },
  {
    "country": "US",
    "name": "North Baltimore",
    "lat": "41.18283",
    "lng": "-83.67827"
  },
  {
    "country": "US",
    "name": "North Canton",
    "lat": "40.87589",
    "lng": "-81.40234"
  },
  {
    "country": "US",
    "name": "North Kingsville",
    "lat": "41.90589",
    "lng": "-80.69036"
  },
  {
    "country": "US",
    "name": "North Lewisburg",
    "lat": "40.22311",
    "lng": "-83.55743"
  },
  {
    "country": "US",
    "name": "North Madison",
    "lat": "41.802",
    "lng": "-81.04899"
  },
  {
    "country": "US",
    "name": "North Olmsted",
    "lat": "41.4156",
    "lng": "-81.92347"
  },
  {
    "country": "US",
    "name": "North Randall",
    "lat": "41.43478",
    "lng": "-81.52568"
  },
  {
    "country": "US",
    "name": "North Ridgeville",
    "lat": "41.38949",
    "lng": "-82.01903"
  },
  {
    "country": "US",
    "name": "North Royalton",
    "lat": "41.31366",
    "lng": "-81.72457"
  },
  {
    "country": "US",
    "name": "Northfield",
    "lat": "41.34505",
    "lng": "-81.52845"
  },
  {
    "country": "US",
    "name": "Northwood",
    "lat": "40.47283",
    "lng": "-83.73243"
  },
  {
    "country": "US",
    "name": "Northwood",
    "lat": "41.60727",
    "lng": "-83.46882"
  },
  {
    "country": "US",
    "name": "Norton",
    "lat": "41.02922",
    "lng": "-81.63818"
  },
  {
    "country": "US",
    "name": "Norwalk",
    "lat": "41.24255",
    "lng": "-82.61573"
  },
  {
    "country": "US",
    "name": "Oak Harbor",
    "lat": "41.50672",
    "lng": "-83.14659"
  },
  {
    "country": "US",
    "name": "Oak Hill",
    "lat": "40.41423",
    "lng": "-82.24099"
  },
  {
    "country": "US",
    "name": "Oakwood",
    "lat": "41.36533",
    "lng": "-81.5079"
  },
  {
    "country": "US",
    "name": "Oberlin",
    "lat": "41.29394",
    "lng": "-82.21738"
  },
  {
    "country": "US",
    "name": "Olmsted Falls",
    "lat": "41.37505",
    "lng": "-81.90819"
  },
  {
    "country": "US",
    "name": "Ontario",
    "lat": "40.7595",
    "lng": "-82.59017"
  },
  {
    "country": "US",
    "name": "Orange",
    "lat": "41.44978",
    "lng": "-81.48067"
  },
  {
    "country": "US",
    "name": "Oregon",
    "lat": "41.64366",
    "lng": "-83.48688"
  },
  {
    "country": "US",
    "name": "Orrville",
    "lat": "40.84367",
    "lng": "-81.76402"
  },
  {
    "country": "US",
    "name": "Orwell",
    "lat": "41.53506",
    "lng": "-80.86814"
  },
  {
    "country": "US",
    "name": "Ottawa",
    "lat": "41.01922",
    "lng": "-84.04717"
  },
  {
    "country": "US",
    "name": "Ottawa Hills",
    "lat": "41.66422",
    "lng": "-83.64327"
  },
  {
    "country": "US",
    "name": "Painesville",
    "lat": "41.72449",
    "lng": "-81.24566"
  },
  {
    "country": "US",
    "name": "Pandora",
    "lat": "40.94811",
    "lng": "-83.96105"
  },
  {
    "country": "US",
    "name": "Parma",
    "lat": "41.40477",
    "lng": "-81.72291"
  },
  {
    "country": "US",
    "name": "Parma Heights",
    "lat": "41.39005",
    "lng": "-81.75958"
  },
  {
    "country": "US",
    "name": "Paulding",
    "lat": "41.13811",
    "lng": "-84.58051"
  },
  {
    "country": "US",
    "name": "Payne",
    "lat": "41.07755",
    "lng": "-84.72718"
  },
  {
    "country": "US",
    "name": "Pemberville",
    "lat": "41.41089",
    "lng": "-83.46104"
  },
  {
    "country": "US",
    "name": "Pepper Pike",
    "lat": "41.47839",
    "lng": "-81.46373"
  },
  {
    "country": "US",
    "name": "Perry",
    "lat": "41.76033",
    "lng": "-81.14093"
  },
  {
    "country": "US",
    "name": "Perry Heights",
    "lat": "40.79534",
    "lng": "-81.47345"
  },
  {
    "country": "US",
    "name": "Perrysburg",
    "lat": "41.557",
    "lng": "-83.62716"
  },
  {
    "country": "US",
    "name": "Pioneer",
    "lat": "41.68005",
    "lng": "-84.55301"
  },
  {
    "country": "US",
    "name": "Piqua",
    "lat": "40.14477",
    "lng": "-84.24244"
  },
  {
    "country": "US",
    "name": "Plain City",
    "lat": "40.10756",
    "lng": "-83.26742"
  },
  {
    "country": "US",
    "name": "Pleasant Hill",
    "lat": "40.05172",
    "lng": "-84.34439"
  },
  {
    "country": "US",
    "name": "Plymouth",
    "lat": "40.99561",
    "lng": "-82.66712"
  },
  {
    "country": "US",
    "name": "Poland",
    "lat": "41.02423",
    "lng": "-80.6148"
  },
  {
    "country": "US",
    "name": "Port Clinton",
    "lat": "41.512",
    "lng": "-82.93769"
  },
  {
    "country": "US",
    "name": "Portage Lakes",
    "lat": "41.00728",
    "lng": "-81.52706"
  },
  {
    "country": "US",
    "name": "Powell",
    "lat": "40.15784",
    "lng": "-83.07519"
  },
  {
    "country": "US",
    "name": "Prospect",
    "lat": "40.45034",
    "lng": "-83.18853"
  },
  {
    "country": "US",
    "name": "Ravenna",
    "lat": "41.15756",
    "lng": "-81.24205"
  },
  {
    "country": "US",
    "name": "Reminderville",
    "lat": "41.34589",
    "lng": "-81.39511"
  },
  {
    "country": "US",
    "name": "Richfield",
    "lat": "41.23978",
    "lng": "-81.63818"
  },
  {
    "country": "US",
    "name": "Richmond Heights",
    "lat": "41.55283",
    "lng": "-81.51012"
  },
  {
    "country": "US",
    "name": "Richville",
    "lat": "40.75117",
    "lng": "-81.4779"
  },
  {
    "country": "US",
    "name": "Richwood",
    "lat": "40.42645",
    "lng": "-83.29686"
  },
  {
    "country": "US",
    "name": "Rittman",
    "lat": "40.97811",
    "lng": "-81.78208"
  },
  {
    "country": "US",
    "name": "Roaming Shores",
    "lat": "41.64311",
    "lng": "-80.82342"
  },
  {
    "country": "US",
    "name": "Rockford",
    "lat": "40.68783",
    "lng": "-84.64663"
  },
  {
    "country": "US",
    "name": "Rockford",
    "lat": "40.47701",
    "lng": "-81.30844"
  },
  {
    "country": "US",
    "name": "Rocky River",
    "lat": "41.4756",
    "lng": "-81.8393"
  },
  {
    "country": "US",
    "name": "Rossford",
    "lat": "41.60977",
    "lng": "-83.56438"
  },
  {
    "country": "US",
    "name": "Russells Point",
    "lat": "40.47116",
    "lng": "-83.89272"
  },
  {
    "country": "US",
    "name": "Saint Clairsville",
    "lat": "40.08063",
    "lng": "-80.90009"
  },
  {
    "country": "US",
    "name": "Saint Henry",
    "lat": "40.41755",
    "lng": "-84.63968"
  },
  {
    "country": "US",
    "name": "Saint Marys",
    "lat": "40.54227",
    "lng": "-84.3894"
  },
  {
    "country": "US",
    "name": "Saint Paris",
    "lat": "40.12839",
    "lng": "-83.95966"
  },
  {
    "country": "US",
    "name": "Salem",
    "lat": "40.90089",
    "lng": "-80.85675"
  },
  {
    "country": "US",
    "name": "Salineville",
    "lat": "40.62256",
    "lng": "-80.83786"
  },
  {
    "country": "US",
    "name": "Sandusky",
    "lat": "41.44894",
    "lng": "-82.70796"
  },
  {
    "country": "US",
    "name": "Sawyerwood",
    "lat": "41.03783",
    "lng": "-81.44095"
  },
  {
    "country": "US",
    "name": "Sebring",
    "lat": "40.92284",
    "lng": "-81.01898"
  },
  {
    "country": "US",
    "name": "Seven Hills",
    "lat": "41.39533",
    "lng": "-81.67624"
  },
  {
    "country": "US",
    "name": "Seville",
    "lat": "41.01006",
    "lng": "-81.86236"
  },
  {
    "country": "US",
    "name": "Shaker Heights",
    "lat": "41.47394",
    "lng": "-81.53707"
  },
  {
    "country": "US",
    "name": "Sheffield",
    "lat": "41.42115",
    "lng": "-82.09626"
  },
  {
    "country": "US",
    "name": "Sheffield Lake",
    "lat": "41.48754",
    "lng": "-82.10154"
  },
  {
    "country": "US",
    "name": "Shelby",
    "lat": "40.88145",
    "lng": "-82.66184"
  },
  {
    "country": "US",
    "name": "Shreve",
    "lat": "40.68145",
    "lng": "-82.02181"
  },
  {
    "country": "US",
    "name": "Sidney",
    "lat": "40.28422",
    "lng": "-84.1555"
  },
  {
    "country": "US",
    "name": "Silver Lake",
    "lat": "41.15895",
    "lng": "-81.45428"
  },
  {
    "country": "US",
    "name": "Smithville",
    "lat": "40.86228",
    "lng": "-81.8618"
  },
  {
    "country": "US",
    "name": "Solon",
    "lat": "41.38978",
    "lng": "-81.44123"
  },
  {
    "country": "US",
    "name": "South Amherst",
    "lat": "41.35588",
    "lng": "-82.25377"
  },
  {
    "country": "US",
    "name": "South Canal",
    "lat": "41.17728",
    "lng": "-80.98676"
  },
  {
    "country": "US",
    "name": "South Euclid",
    "lat": "41.52311",
    "lng": "-81.51846"
  },
  {
    "country": "US",
    "name": "South Russell",
    "lat": "41.43144",
    "lng": "-81.36539"
  },
  {
    "country": "US",
    "name": "Spencerville",
    "lat": "40.70894",
    "lng": "-84.35356"
  },
  {
    "country": "US",
    "name": "Steubenville",
    "lat": "40.36979",
    "lng": "-80.63396"
  },
  {
    "country": "US",
    "name": "Stony Prairie",
    "lat": "41.35144",
    "lng": "-83.1552"
  },
  {
    "country": "US",
    "name": "Stow",
    "lat": "41.1595",
    "lng": "-81.44039"
  },
  {
    "country": "US",
    "name": "Strasburg",
    "lat": "40.59478",
    "lng": "-81.52679"
  },
  {
    "country": "US",
    "name": "Streetsboro",
    "lat": "41.23922",
    "lng": "-81.34594"
  },
  {
    "country": "US",
    "name": "Strongsville",
    "lat": "41.3145",
    "lng": "-81.83569"
  },
  {
    "country": "US",
    "name": "Struthers",
    "lat": "41.05256",
    "lng": "-80.60785"
  },
  {
    "country": "US",
    "name": "Stryker",
    "lat": "41.50366",
    "lng": "-84.41412"
  },
  {
    "country": "US",
    "name": "Sugarcreek",
    "lat": "40.50312",
    "lng": "-81.64096"
  },
  {
    "country": "US",
    "name": "Sunbury",
    "lat": "40.24256",
    "lng": "-82.85907"
  },
  {
    "country": "US",
    "name": "Swanton",
    "lat": "41.58866",
    "lng": "-83.89105"
  },
  {
    "country": "US",
    "name": "Sylvania",
    "lat": "41.71894",
    "lng": "-83.71299"
  },
  {
    "country": "US",
    "name": "Tallmadge",
    "lat": "41.10145",
    "lng": "-81.44178"
  },
  {
    "country": "US",
    "name": "Tiffin",
    "lat": "41.1145",
    "lng": "-83.17797"
  },
  {
    "country": "US",
    "name": "Tiltonsville",
    "lat": "40.16674",
    "lng": "-80.6998"
  },
  {
    "country": "US",
    "name": "Toledo",
    "lat": "41.66394",
    "lng": "-83.55521"
  },
  {
    "country": "US",
    "name": "Toronto",
    "lat": "40.46423",
    "lng": "-80.60091"
  },
  {
    "country": "US",
    "name": "Troy",
    "lat": "40.0395",
    "lng": "-84.20328"
  },
  {
    "country": "US",
    "name": "Tuscarawas",
    "lat": "40.39479",
    "lng": "-81.40706"
  },
  {
    "country": "US",
    "name": "Twinsburg",
    "lat": "41.31256",
    "lng": "-81.44011"
  },
  {
    "country": "US",
    "name": "Uhrichsville",
    "lat": "40.39312",
    "lng": "-81.3465"
  },
  {
    "country": "US",
    "name": "Uniontown",
    "lat": "40.97506",
    "lng": "-81.40817"
  },
  {
    "country": "US",
    "name": "University Heights",
    "lat": "41.49783",
    "lng": "-81.53735"
  },
  {
    "country": "US",
    "name": "Upper Sandusky",
    "lat": "40.82728",
    "lng": "-83.28131"
  },
  {
    "country": "US",
    "name": "Urbana",
    "lat": "40.10839",
    "lng": "-83.75243"
  },
  {
    "country": "US",
    "name": "Utica",
    "lat": "40.23423",
    "lng": "-82.45127"
  },
  {
    "country": "US",
    "name": "Valley View",
    "lat": "41.38783",
    "lng": "-81.60457"
  },
  {
    "country": "US",
    "name": "Vermilion",
    "lat": "41.42199",
    "lng": "-82.36461"
  },
  {
    "country": "US",
    "name": "Van Wert",
    "lat": "40.86949",
    "lng": "-84.58412"
  },
  {
    "country": "US",
    "name": "Vermilion-on-the-Lake",
    "lat": "41.42838",
    "lng": "-82.32377"
  },
  {
    "country": "US",
    "name": "Versailles",
    "lat": "40.22255",
    "lng": "-84.4844"
  },
  {
    "country": "US",
    "name": "Wadsworth",
    "lat": "41.02561",
    "lng": "-81.72985"
  },
  {
    "country": "US",
    "name": "Wakeman",
    "lat": "41.2545",
    "lng": "-82.39961"
  },
  {
    "country": "US",
    "name": "Walbridge",
    "lat": "41.58783",
    "lng": "-83.49327"
  },
  {
    "country": "US",
    "name": "Walton Hills",
    "lat": "41.36561",
    "lng": "-81.56123"
  },
  {
    "country": "US",
    "name": "Wapakoneta",
    "lat": "40.56783",
    "lng": "-84.19356"
  },
  {
    "country": "US",
    "name": "Warrensville Heights",
    "lat": "41.43505",
    "lng": "-81.53623"
  },
  {
    "country": "US",
    "name": "Waterville",
    "lat": "41.50089",
    "lng": "-83.71827"
  },
  {
    "country": "US",
    "name": "Warren",
    "lat": "41.23756",
    "lng": "-80.81842"
  },
  {
    "country": "US",
    "name": "Wauseon",
    "lat": "41.54922",
    "lng": "-84.14161"
  },
  {
    "country": "US",
    "name": "Wellington",
    "lat": "41.16894",
    "lng": "-82.21794"
  },
  {
    "country": "US",
    "name": "Wellsville",
    "lat": "40.60284",
    "lng": "-80.64896"
  },
  {
    "country": "US",
    "name": "West Hill",
    "lat": "41.23283",
    "lng": "-80.51924"
  },
  {
    "country": "US",
    "name": "West Lafayette",
    "lat": "40.27535",
    "lng": "-81.75096"
  },
  {
    "country": "US",
    "name": "West Liberty",
    "lat": "40.25228",
    "lng": "-83.75577"
  },
  {
    "country": "US",
    "name": "West Salem",
    "lat": "40.97144",
    "lng": "-82.10987"
  },
  {
    "country": "US",
    "name": "West Unity",
    "lat": "41.58616",
    "lng": "-84.43495"
  },
  {
    "country": "US",
    "name": "Westerville",
    "lat": "40.12617",
    "lng": "-82.92907"
  },
  {
    "country": "US",
    "name": "Westfield Center",
    "lat": "41.02644",
    "lng": "-81.9332"
  },
  {
    "country": "US",
    "name": "Westlake",
    "lat": "41.45532",
    "lng": "-81.91792"
  },
  {
    "country": "US",
    "name": "Weston",
    "lat": "41.34477",
    "lng": "-83.79716"
  },
  {
    "country": "US",
    "name": "Whitehouse",
    "lat": "41.51894",
    "lng": "-83.80383"
  },
  {
    "country": "US",
    "name": "Wickliffe",
    "lat": "41.60533",
    "lng": "-81.45345"
  },
  {
    "country": "US",
    "name": "Willard",
    "lat": "41.05311",
    "lng": "-82.72629"
  },
  {
    "country": "US",
    "name": "Willoughby",
    "lat": "41.63977",
    "lng": "-81.4065"
  },
  {
    "country": "US",
    "name": "Willoughby Hills",
    "lat": "41.59838",
    "lng": "-81.41845"
  },
  {
    "country": "US",
    "name": "Willowick",
    "lat": "41.6331",
    "lng": "-81.46873"
  },
  {
    "country": "US",
    "name": "Windham",
    "lat": "41.23506",
    "lng": "-81.04926"
  },
  {
    "country": "US",
    "name": "Wintersville",
    "lat": "40.37535",
    "lng": "-80.70369"
  },
  {
    "country": "US",
    "name": "Wolfhurst",
    "lat": "40.06924",
    "lng": "-80.7837"
  },
  {
    "country": "US",
    "name": "Woodville",
    "lat": "41.45144",
    "lng": "-83.36576"
  },
  {
    "country": "US",
    "name": "Wooster",
    "lat": "40.80517",
    "lng": "-81.93646"
  },
  {
    "country": "US",
    "name": "Worthington",
    "lat": "40.09312",
    "lng": "-83.01796"
  },
  {
    "country": "US",
    "name": "Yorkville",
    "lat": "40.15452",
    "lng": "-80.71036"
  },
  {
    "country": "US",
    "name": "Youngstown",
    "lat": "41.09978",
    "lng": "-80.64952"
  },
  {
    "country": "US",
    "name": "Adamstown",
    "lat": "40.2412",
    "lng": "-76.05633"
  },
  {
    "country": "US",
    "name": "Akron",
    "lat": "40.15676",
    "lng": "-76.20217"
  },
  {
    "country": "US",
    "name": "Albion",
    "lat": "41.89061",
    "lng": "-80.36645"
  },
  {
    "country": "US",
    "name": "Albion",
    "lat": "40.95895",
    "lng": "-78.94698"
  },
  {
    "country": "US",
    "name": "Alburtis",
    "lat": "40.51093",
    "lng": "-75.60297"
  },
  {
    "country": "US",
    "name": "Aliquippa",
    "lat": "40.63673",
    "lng": "-80.24006"
  },
  {
    "country": "US",
    "name": "Alleghenyville",
    "lat": "40.23426",
    "lng": "-75.98855"
  },
  {
    "country": "US",
    "name": "Allentown",
    "lat": "40.60843",
    "lng": "-75.49018"
  },
  {
    "country": "US",
    "name": "Allison Park",
    "lat": "40.55951",
    "lng": "-79.95867"
  },
  {
    "country": "US",
    "name": "Almedia",
    "lat": "41.01453",
    "lng": "-76.38105"
  },
  {
    "country": "US",
    "name": "Altoona",
    "lat": "40.51868",
    "lng": "-78.39474"
  },
  {
    "country": "US",
    "name": "Ambler",
    "lat": "40.15455",
    "lng": "-75.22157"
  },
  {
    "country": "US",
    "name": "Ambridge",
    "lat": "40.58923",
    "lng": "-80.22506"
  },
  {
    "country": "US",
    "name": "Amity Gardens",
    "lat": "40.27426",
    "lng": "-75.73519"
  },
  {
    "country": "US",
    "name": "Ancient Oaks",
    "lat": "40.54732",
    "lng": "-75.58935"
  },
  {
    "country": "US",
    "name": "Annville",
    "lat": "40.32954",
    "lng": "-76.51524"
  },
  {
    "country": "US",
    "name": "Apollo",
    "lat": "40.58145",
    "lng": "-79.56643"
  },
  {
    "country": "US",
    "name": "Archbald",
    "lat": "41.4948",
    "lng": "-75.53685"
  },
  {
    "country": "US",
    "name": "Ardmore",
    "lat": "40.00678",
    "lng": "-75.28546"
  },
  {
    "country": "US",
    "name": "Arlington Heights",
    "lat": "40.99009",
    "lng": "-75.21629"
  },
  {
    "country": "US",
    "name": "Arnold",
    "lat": "40.58007",
    "lng": "-79.76672"
  },
  {
    "country": "US",
    "name": "Ashland",
    "lat": "40.78175",
    "lng": "-76.34578"
  },
  {
    "country": "US",
    "name": "Ashley",
    "lat": "41.21036",
    "lng": "-75.89659"
  },
  {
    "country": "US",
    "name": "Aspinwall",
    "lat": "40.49146",
    "lng": "-79.90477"
  },
  {
    "country": "US",
    "name": "Athens",
    "lat": "41.9573",
    "lng": "-76.518"
  },
  {
    "country": "US",
    "name": "Audubon",
    "lat": "40.12788",
    "lng": "-75.43185"
  },
  {
    "country": "US",
    "name": "Avalon",
    "lat": "40.5009",
    "lng": "-80.06756"
  },
  {
    "country": "US",
    "name": "Avis",
    "lat": "41.18479",
    "lng": "-77.31386"
  },
  {
    "country": "US",
    "name": "Avoca",
    "lat": "41.3398",
    "lng": "-75.7363"
  },
  {
    "country": "US",
    "name": "Avon",
    "lat": "40.34565",
    "lng": "-76.38996"
  },
  {
    "country": "US",
    "name": "Avonia",
    "lat": "42.04561",
    "lng": "-80.26979"
  },
  {
    "country": "US",
    "name": "Back Mountain",
    "lat": "41.33591",
    "lng": "-75.99631"
  },
  {
    "country": "US",
    "name": "Baden",
    "lat": "40.63507",
    "lng": "-80.22812"
  },
  {
    "country": "US",
    "name": "Baidland",
    "lat": "40.19479",
    "lng": "-79.97088"
  },
  {
    "country": "US",
    "name": "Bainbridge",
    "lat": "40.09093",
    "lng": "-76.66747"
  },
  {
    "country": "US",
    "name": "Bakerstown",
    "lat": "40.6509",
    "lng": "-79.93644"
  },
  {
    "country": "US",
    "name": "Bala-Cynwyd",
    "lat": "40.00761",
    "lng": "-75.23407"
  },
  {
    "country": "US",
    "name": "Baldwin",
    "lat": "40.33813",
    "lng": "-79.97894"
  },
  {
    "country": "US",
    "name": "Bally",
    "lat": "40.40232",
    "lng": "-75.58713"
  },
  {
    "country": "US",
    "name": "Bangor",
    "lat": "40.86565",
    "lng": "-75.20657"
  },
  {
    "country": "US",
    "name": "Barnesboro",
    "lat": "40.66257",
    "lng": "-78.78003"
  },
  {
    "country": "US",
    "name": "Bath",
    "lat": "40.72565",
    "lng": "-75.39407"
  },
  {
    "country": "US",
    "name": "Bear Rocks",
    "lat": "40.12285",
    "lng": "-79.4617"
  },
  {
    "country": "US",
    "name": "Beaver",
    "lat": "40.69534",
    "lng": "-80.30478"
  },
  {
    "country": "US",
    "name": "Beaver Falls",
    "lat": "40.75201",
    "lng": "-80.31923"
  },
  {
    "country": "US",
    "name": "Beaverdale",
    "lat": "40.32202",
    "lng": "-78.69696"
  },
  {
    "country": "US",
    "name": "Bedford",
    "lat": "40.01869",
    "lng": "-78.50391"
  },
  {
    "country": "US",
    "name": "Bedminster",
    "lat": "40.42594",
    "lng": "-75.17906"
  },
  {
    "country": "US",
    "name": "Bell Acres",
    "lat": "40.59007",
    "lng": "-80.16645"
  },
  {
    "country": "US",
    "name": "Belfast",
    "lat": "40.78065",
    "lng": "-75.27796"
  },
  {
    "country": "US",
    "name": "Belle Vernon",
    "lat": "40.12507",
    "lng": "-79.86644"
  },
  {
    "country": "US",
    "name": "Bellefonte",
    "lat": "40.91339",
    "lng": "-77.77833"
  },
  {
    "country": "US",
    "name": "Belleville",
    "lat": "40.60507",
    "lng": "-77.72555"
  },
  {
    "country": "US",
    "name": "Bellevue",
    "lat": "40.49396",
    "lng": "-80.05172"
  },
  {
    "country": "US",
    "name": "Bellwood",
    "lat": "40.6034",
    "lng": "-78.32474"
  },
  {
    "country": "US",
    "name": "Belmont",
    "lat": "40.2873",
    "lng": "-78.88947"
  },
  {
    "country": "US",
    "name": "Ben Avon",
    "lat": "40.50812",
    "lng": "-80.08311"
  },
  {
    "country": "US",
    "name": "Bentleyville",
    "lat": "40.11674",
    "lng": "-80.00839"
  },
  {
    "country": "US",
    "name": "Berwyn",
    "lat": "40.04483",
    "lng": "-75.43881"
  },
  {
    "country": "US",
    "name": "Bessemer",
    "lat": "40.97478",
    "lng": "-80.49368"
  },
  {
    "country": "US",
    "name": "Berwick",
    "lat": "41.05453",
    "lng": "-76.23327"
  },
  {
    "country": "US",
    "name": "Bethel Park",
    "lat": "40.32757",
    "lng": "-80.0395"
  },
  {
    "country": "US",
    "name": "Bethlehem",
    "lat": "40.62593",
    "lng": "-75.37046"
  },
  {
    "country": "US",
    "name": "Big Beaver",
    "lat": "40.82451",
    "lng": "-80.36284"
  },
  {
    "country": "US",
    "name": "Birchwood Lakes",
    "lat": "41.25454",
    "lng": "-74.9185"
  },
  {
    "country": "US",
    "name": "Birdsboro",
    "lat": "40.26454",
    "lng": "-75.80409"
  },
  {
    "country": "US",
    "name": "Black Lick",
    "lat": "40.4725",
    "lng": "-79.18688"
  },
  {
    "country": "US",
    "name": "Blairsville",
    "lat": "40.43118",
    "lng": "-79.26087"
  },
  {
    "country": "US",
    "name": "Blakely",
    "lat": "41.48091",
    "lng": "-75.59463"
  },
  {
    "country": "US",
    "name": "Blandon",
    "lat": "40.4412",
    "lng": "-75.88687"
  },
  {
    "country": "US",
    "name": "Blawnox",
    "lat": "40.4934",
    "lng": "-79.86061"
  },
  {
    "country": "US",
    "name": "Bloomfield",
    "lat": "40.4609",
    "lng": "-79.95089"
  },
  {
    "country": "US",
    "name": "Bloomsburg",
    "lat": "41.0037",
    "lng": "-76.45495"
  },
  {
    "country": "US",
    "name": "Blossburg",
    "lat": "41.67952",
    "lng": "-77.06386"
  },
  {
    "country": "US",
    "name": "Blue Ball",
    "lat": "40.11871",
    "lng": "-76.04717"
  },
  {
    "country": "US",
    "name": "Blue Bell",
    "lat": "40.15233",
    "lng": "-75.26629"
  },
  {
    "country": "US",
    "name": "Boalsburg",
    "lat": "40.77562",
    "lng": "-77.7925"
  },
  {
    "country": "US",
    "name": "Boiling Springs",
    "lat": "40.14981",
    "lng": "-77.12831"
  },
  {
    "country": "US",
    "name": "Boswell",
    "lat": "40.16147",
    "lng": "-79.02892"
  },
  {
    "country": "US",
    "name": "Bowmansville",
    "lat": "40.19676",
    "lng": "-76.01744"
  },
  {
    "country": "US",
    "name": "Boyertown",
    "lat": "40.33371",
    "lng": "-75.63741"
  },
  {
    "country": "US",
    "name": "Brackenridge",
    "lat": "40.60812",
    "lng": "-79.74116"
  },
  {
    "country": "US",
    "name": "Braddock",
    "lat": "40.4034",
    "lng": "-79.86838"
  },
  {
    "country": "US",
    "name": "Braddock Hills",
    "lat": "40.41729",
    "lng": "-79.86505"
  },
  {
    "country": "US",
    "name": "Bradford",
    "lat": "41.9559",
    "lng": "-78.64392"
  },
  {
    "country": "US",
    "name": "Bradford Woods",
    "lat": "40.63757",
    "lng": "-80.08172"
  },
  {
    "country": "US",
    "name": "Brentwood",
    "lat": "40.37063",
    "lng": "-79.97477"
  },
  {
    "country": "US",
    "name": "Bressler",
    "lat": "40.22953",
    "lng": "-76.81997"
  },
  {
    "country": "US",
    "name": "Breinigsville",
    "lat": "40.53676",
    "lng": "-75.6313"
  },
  {
    "country": "US",
    "name": "Brickerville",
    "lat": "40.22593",
    "lng": "-76.30246"
  },
  {
    "country": "US",
    "name": "Bridgeport",
    "lat": "40.10511",
    "lng": "-75.34518"
  },
  {
    "country": "US",
    "name": "Bridgeville",
    "lat": "40.35618",
    "lng": "-80.11006"
  },
  {
    "country": "US",
    "name": "Bristol",
    "lat": "40.10067",
    "lng": "-74.85183"
  },
  {
    "country": "US",
    "name": "Brockway",
    "lat": "41.24923",
    "lng": "-78.79947"
  },
  {
    "country": "US",
    "name": "Brodheadsville",
    "lat": "40.92454",
    "lng": "-75.39379"
  },
  {
    "country": "US",
    "name": "Brookville",
    "lat": "41.16117",
    "lng": "-79.08309"
  },
  {
    "country": "US",
    "name": "Brownstown",
    "lat": "40.12371",
    "lng": "-76.21384"
  },
  {
    "country": "US",
    "name": "Brownsville",
    "lat": "40.02369",
    "lng": "-79.88394"
  },
  {
    "country": "US",
    "name": "Browntown",
    "lat": "41.3098",
    "lng": "-75.78742"
  },
  {
    "country": "US",
    "name": "Bryn Athyn",
    "lat": "40.1315",
    "lng": "-75.06739"
  },
  {
    "country": "US",
    "name": "Bryn Mawr",
    "lat": "40.30396",
    "lng": "-80.08672"
  },
  {
    "country": "US",
    "name": "Bryn Mawr",
    "lat": "40.01983",
    "lng": "-75.30463"
  },
  {
    "country": "US",
    "name": "Burgettstown",
    "lat": "40.38201",
    "lng": "-80.39284"
  },
  {
    "country": "US",
    "name": "Burnham",
    "lat": "40.63868",
    "lng": "-77.56861"
  },
  {
    "country": "US",
    "name": "Butler",
    "lat": "40.86118",
    "lng": "-79.89533"
  },
  {
    "country": "US",
    "name": "California",
    "lat": "40.06563",
    "lng": "-79.89171"
  },
  {
    "country": "US",
    "name": "Calumet",
    "lat": "40.2109",
    "lng": "-79.48532"
  },
  {
    "country": "US",
    "name": "Cambridge Springs",
    "lat": "41.80367",
    "lng": "-80.05644"
  },
  {
    "country": "US",
    "name": "Camp Hill",
    "lat": "40.23981",
    "lng": "-76.91997"
  },
  {
    "country": "US",
    "name": "Campbelltown",
    "lat": "40.27759",
    "lng": "-76.58525"
  },
  {
    "country": "US",
    "name": "Canonsburg",
    "lat": "40.26257",
    "lng": "-80.18728"
  },
  {
    "country": "US",
    "name": "Canton",
    "lat": "41.65646",
    "lng": "-76.85329"
  },
  {
    "country": "US",
    "name": "Carbondale",
    "lat": "41.57369",
    "lng": "-75.50185"
  },
  {
    "country": "US",
    "name": "Carlisle",
    "lat": "40.20148",
    "lng": "-77.18887"
  },
  {
    "country": "US",
    "name": "Castanea",
    "lat": "41.12479",
    "lng": "-77.4297"
  },
  {
    "country": "US",
    "name": "Castle Shannon",
    "lat": "40.36479",
    "lng": "-80.02228"
  },
  {
    "country": "US",
    "name": "Catasauqua",
    "lat": "40.65482",
    "lng": "-75.47463"
  },
  {
    "country": "US",
    "name": "Catawissa",
    "lat": "40.95203",
    "lng": "-76.45967"
  },
  {
    "country": "US",
    "name": "Cementon",
    "lat": "40.68926",
    "lng": "-75.50768"
  },
  {
    "country": "US",
    "name": "Centerville",
    "lat": "40.04535",
    "lng": "-79.97561"
  },
  {
    "country": "US",
    "name": "Central City",
    "lat": "40.11063",
    "lng": "-78.80197"
  },
  {
    "country": "US",
    "name": "Centre Hall",
    "lat": "40.84756",
    "lng": "-77.68611"
  },
  {
    "country": "US",
    "name": "Cetronia",
    "lat": "40.58676",
    "lng": "-75.52963"
  },
  {
    "country": "US",
    "name": "Chalfont",
    "lat": "40.28844",
    "lng": "-75.20906"
  },
  {
    "country": "US",
    "name": "Charleroi",
    "lat": "40.13785",
    "lng": "-79.8981"
  },
  {
    "country": "US",
    "name": "Cherryville",
    "lat": "40.75398",
    "lng": "-75.53852"
  },
  {
    "country": "US",
    "name": "Chester Springs",
    "lat": "40.0951",
    "lng": "-75.61687"
  },
  {
    "country": "US",
    "name": "Chesterbrook",
    "lat": "40.07566",
    "lng": "-75.45908"
  },
  {
    "country": "US",
    "name": "Cheswick",
    "lat": "40.54173",
    "lng": "-79.79922"
  },
  {
    "country": "US",
    "name": "Chevy Chase Heights",
    "lat": "40.63673",
    "lng": "-79.1442"
  },
  {
    "country": "US",
    "name": "Chicora",
    "lat": "40.94812",
    "lng": "-79.74283"
  },
  {
    "country": "US",
    "name": "Chinchilla",
    "lat": "41.47508",
    "lng": "-75.67713"
  },
  {
    "country": "US",
    "name": "Church Hill",
    "lat": "40.68201",
    "lng": "-77.59861"
  },
  {
    "country": "US",
    "name": "Churchill",
    "lat": "40.4384",
    "lng": "-79.8431"
  },
  {
    "country": "US",
    "name": "Churchville",
    "lat": "40.18622",
    "lng": "-75.01878"
  },
  {
    "country": "US",
    "name": "Clairton",
    "lat": "40.29229",
    "lng": "-79.88171"
  },
  {
    "country": "US",
    "name": "Clarion",
    "lat": "41.21479",
    "lng": "-79.38532"
  },
  {
    "country": "US",
    "name": "Clarks Green",
    "lat": "41.49286",
    "lng": "-75.69964"
  },
  {
    "country": "US",
    "name": "Clarks Summit",
    "lat": "41.48869",
    "lng": "-75.70852"
  },
  {
    "country": "US",
    "name": "Clay",
    "lat": "40.21843",
    "lng": "-76.25551"
  },
  {
    "country": "US",
    "name": "Claysburg",
    "lat": "40.29674",
    "lng": "-78.44974"
  },
  {
    "country": "US",
    "name": "Clearfield",
    "lat": "41.02728",
    "lng": "-78.43919"
  },
  {
    "country": "US",
    "name": "Cleona",
    "lat": "40.33731",
    "lng": "-76.47552"
  },
  {
    "country": "US",
    "name": "Clymer",
    "lat": "40.66812",
    "lng": "-79.0117"
  },
  {
    "country": "US",
    "name": "Coaldale",
    "lat": "40.82287",
    "lng": "-75.90687"
  },
  {
    "country": "US",
    "name": "Cochranton",
    "lat": "41.52005",
    "lng": "-80.04839"
  },
  {
    "country": "US",
    "name": "Collegeville",
    "lat": "40.18566",
    "lng": "-75.45157"
  },
  {
    "country": "US",
    "name": "Collinsburg",
    "lat": "40.22424",
    "lng": "-79.76838"
  },
  {
    "country": "US",
    "name": "Colonial Park",
    "lat": "40.30064",
    "lng": "-76.80969"
  },
  {
    "country": "US",
    "name": "Columbia",
    "lat": "40.03371",
    "lng": "-76.50441"
  },
  {
    "country": "US",
    "name": "Conemaugh",
    "lat": "40.32674",
    "lng": "-78.90808"
  },
  {
    "country": "US",
    "name": "Conashaugh Lakes",
    "lat": "41.30593",
    "lng": "-74.98962"
  },
  {
    "country": "US",
    "name": "Connellsville",
    "lat": "40.01785",
    "lng": "-79.58948"
  },
  {
    "country": "US",
    "name": "Conshohocken",
    "lat": "40.07928",
    "lng": "-75.30157"
  },
  {
    "country": "US",
    "name": "Conway",
    "lat": "40.65979",
    "lng": "-80.23923"
  },
  {
    "country": "US",
    "name": "Conyngham",
    "lat": "40.99203",
    "lng": "-76.05659"
  },
  {
    "country": "US",
    "name": "Coopersburg",
    "lat": "40.51149",
    "lng": "-75.39046"
  },
  {
    "country": "US",
    "name": "Coplay",
    "lat": "40.6701",
    "lng": "-75.49546"
  },
  {
    "country": "US",
    "name": "Coraopolis",
    "lat": "40.5184",
    "lng": "-80.16672"
  },
  {
    "country": "US",
    "name": "Cornwall",
    "lat": "40.2737",
    "lng": "-76.40607"
  },
  {
    "country": "US",
    "name": "Cornwells Heights",
    "lat": "40.07678",
    "lng": "-74.94878"
  },
  {
    "country": "US",
    "name": "Corry",
    "lat": "41.92033",
    "lng": "-79.64033"
  },
  {
    "country": "US",
    "name": "Coudersport",
    "lat": "41.77479",
    "lng": "-78.02056"
  },
  {
    "country": "US",
    "name": "Crafton",
    "lat": "40.43507",
    "lng": "-80.06617"
  },
  {
    "country": "US",
    "name": "Cresson",
    "lat": "40.45979",
    "lng": "-78.59168"
  },
  {
    "country": "US",
    "name": "Cressona",
    "lat": "40.62676",
    "lng": "-76.19272"
  },
  {
    "country": "US",
    "name": "Croydon",
    "lat": "40.08733",
    "lng": "-74.9035"
  },
  {
    "country": "US",
    "name": "Curtisville",
    "lat": "40.64229",
    "lng": "-79.85089"
  },
  {
    "country": "US",
    "name": "Curwensville",
    "lat": "40.97561",
    "lng": "-78.52502"
  },
  {
    "country": "US",
    "name": "Dale",
    "lat": "40.31285",
    "lng": "-78.90419"
  },
  {
    "country": "US",
    "name": "Dallas",
    "lat": "41.33619",
    "lng": "-75.96325"
  },
  {
    "country": "US",
    "name": "Dalton",
    "lat": "41.53424",
    "lng": "-75.73603"
  },
  {
    "country": "US",
    "name": "Danville",
    "lat": "40.96342",
    "lng": "-76.61273"
  },
  {
    "country": "US",
    "name": "Davidsville",
    "lat": "40.22702",
    "lng": "-78.93641"
  },
  {
    "country": "US",
    "name": "Delmont",
    "lat": "40.41312",
    "lng": "-79.57032"
  },
  {
    "country": "US",
    "name": "Derry",
    "lat": "40.33396",
    "lng": "-79.29976"
  },
  {
    "country": "US",
    "name": "Denver",
    "lat": "40.23315",
    "lng": "-76.13717"
  },
  {
    "country": "US",
    "name": "Devon",
    "lat": "40.04928",
    "lng": "-75.42908"
  },
  {
    "country": "US",
    "name": "Dewart",
    "lat": "41.10925",
    "lng": "-76.87663"
  },
  {
    "country": "US",
    "name": "Dickson City",
    "lat": "41.47147",
    "lng": "-75.60769"
  },
  {
    "country": "US",
    "name": "Dillsburg",
    "lat": "40.11093",
    "lng": "-77.03498"
  },
  {
    "country": "US",
    "name": "Donora",
    "lat": "40.1734",
    "lng": "-79.85755"
  },
  {
    "country": "US",
    "name": "Dormont",
    "lat": "40.3959",
    "lng": "-80.03311"
  },
  {
    "country": "US",
    "name": "Dorneyville",
    "lat": "40.5751",
    "lng": "-75.51963"
  },
  {
    "country": "US",
    "name": "Dover",
    "lat": "40.00176",
    "lng": "-76.85025"
  },
  {
    "country": "US",
    "name": "Downingtown",
    "lat": "40.0065",
    "lng": "-75.70327"
  },
  {
    "country": "US",
    "name": "Doylestown",
    "lat": "40.31011",
    "lng": "-75.12989"
  },
  {
    "country": "US",
    "name": "Dravosburg",
    "lat": "40.35063",
    "lng": "-79.88616"
  },
  {
    "country": "US",
    "name": "Dresher",
    "lat": "40.14094",
    "lng": "-75.16684"
  },
  {
    "country": "US",
    "name": "DuBois",
    "lat": "41.11923",
    "lng": "-78.76003"
  },
  {
    "country": "US",
    "name": "Dublin",
    "lat": "40.37177",
    "lng": "-75.20156"
  },
  {
    "country": "US",
    "name": "Duboistown",
    "lat": "41.22258",
    "lng": "-77.03691"
  },
  {
    "country": "US",
    "name": "Duncannon",
    "lat": "40.39814",
    "lng": "-77.02303"
  },
  {
    "country": "US",
    "name": "Duncansville",
    "lat": "40.42341",
    "lng": "-78.4339"
  },
  {
    "country": "US",
    "name": "Dunmore",
    "lat": "41.4198",
    "lng": "-75.63241"
  },
  {
    "country": "US",
    "name": "Dunnstown",
    "lat": "41.1459",
    "lng": "-77.42137"
  },
  {
    "country": "US",
    "name": "Dupont",
    "lat": "41.32508",
    "lng": "-75.74547"
  },
  {
    "country": "US",
    "name": "Duquesne",
    "lat": "40.38146",
    "lng": "-79.85977"
  },
  {
    "country": "US",
    "name": "Duryea",
    "lat": "41.34397",
    "lng": "-75.73853"
  },
  {
    "country": "US",
    "name": "Eagleville",
    "lat": "40.15955",
    "lng": "-75.40824"
  },
  {
    "country": "US",
    "name": "Earlston",
    "lat": "40.00619",
    "lng": "-78.37001"
  },
  {
    "country": "US",
    "name": "East Bangor",
    "lat": "40.87954",
    "lng": "-75.18379"
  },
  {
    "country": "US",
    "name": "East Berwick",
    "lat": "41.06203",
    "lng": "-76.22243"
  },
  {
    "country": "US",
    "name": "East Conemaugh",
    "lat": "40.34868",
    "lng": "-78.88364"
  },
  {
    "country": "US",
    "name": "East Earl",
    "lat": "40.1101",
    "lng": "-76.03272"
  },
  {
    "country": "US",
    "name": "East Greenville",
    "lat": "40.40649",
    "lng": "-75.50185"
  },
  {
    "country": "US",
    "name": "East McKeesport",
    "lat": "40.38312",
    "lng": "-79.80644"
  },
  {
    "country": "US",
    "name": "East Petersburg",
    "lat": "40.1001",
    "lng": "-76.35413"
  },
  {
    "country": "US",
    "name": "East Pittsburgh",
    "lat": "40.39562",
    "lng": "-79.83866"
  },
  {
    "country": "US",
    "name": "East Stroudsburg",
    "lat": "40.99954",
    "lng": "-75.18129"
  },
  {
    "country": "US",
    "name": "East Washington",
    "lat": "40.17368",
    "lng": "-80.23756"
  },
  {
    "country": "US",
    "name": "Eastlawn Gardens",
    "lat": "40.75065",
    "lng": "-75.29573"
  },
  {
    "country": "US",
    "name": "Easton",
    "lat": "40.68843",
    "lng": "-75.22073"
  },
  {
    "country": "US",
    "name": "Ebensburg",
    "lat": "40.48507",
    "lng": "-78.72474"
  },
  {
    "country": "US",
    "name": "Economy",
    "lat": "40.60007",
    "lng": "-80.22478"
  },
  {
    "country": "US",
    "name": "Eddington",
    "lat": "40.08456",
    "lng": "-74.94489"
  },
  {
    "country": "US",
    "name": "Edgewood",
    "lat": "40.43201",
    "lng": "-79.88144"
  },
  {
    "country": "US",
    "name": "Edgewood",
    "lat": "40.78842",
    "lng": "-76.57246"
  },
  {
    "country": "US",
    "name": "Edgeworth",
    "lat": "40.55118",
    "lng": "-80.19284"
  },
  {
    "country": "US",
    "name": "Edinboro",
    "lat": "41.87422",
    "lng": "-80.13172"
  },
  {
    "country": "US",
    "name": "Effort",
    "lat": "40.93926",
    "lng": "-75.43491"
  },
  {
    "country": "US",
    "name": "Edwardsville",
    "lat": "41.26953",
    "lng": "-75.91631"
  },
  {
    "country": "US",
    "name": "Egypt",
    "lat": "40.6801",
    "lng": "-75.52991"
  },
  {
    "country": "US",
    "name": "Elizabeth",
    "lat": "40.26924",
    "lng": "-79.88977"
  },
  {
    "country": "US",
    "name": "Elim",
    "lat": "40.29785",
    "lng": "-78.94253"
  },
  {
    "country": "US",
    "name": "Elizabethtown",
    "lat": "40.15287",
    "lng": "-76.60275"
  },
  {
    "country": "US",
    "name": "Elizabethville",
    "lat": "40.54897",
    "lng": "-76.81192"
  },
  {
    "country": "US",
    "name": "Elkland",
    "lat": "41.98618",
    "lng": "-77.31081"
  },
  {
    "country": "US",
    "name": "Ellport",
    "lat": "40.86395",
    "lng": "-80.25895"
  },
  {
    "country": "US",
    "name": "Ellwood City",
    "lat": "40.86173",
    "lng": "-80.28645"
  },
  {
    "country": "US",
    "name": "Elverson",
    "lat": "40.15676",
    "lng": "-75.83271"
  },
  {
    "country": "US",
    "name": "Elysburg",
    "lat": "40.86453",
    "lng": "-76.55246"
  },
  {
    "country": "US",
    "name": "Emerald Lakes",
    "lat": "41.08842",
    "lng": "-75.41963"
  },
  {
    "country": "US",
    "name": "Emigsville",
    "lat": "40.02176",
    "lng": "-76.72802"
  },
  {
    "country": "US",
    "name": "Emmaus",
    "lat": "40.53954",
    "lng": "-75.49685"
  },
  {
    "country": "US",
    "name": "Emporium",
    "lat": "41.51145",
    "lng": "-78.23529"
  },
  {
    "country": "US",
    "name": "Emsworth",
    "lat": "40.51007",
    "lng": "-80.0945"
  },
  {
    "country": "US",
    "name": "Enhaut",
    "lat": "40.23176",
    "lng": "-76.82692"
  },
  {
    "country": "US",
    "name": "Enlow",
    "lat": "40.45423",
    "lng": "-80.23311"
  },
  {
    "country": "US",
    "name": "Enola",
    "lat": "40.29009",
    "lng": "-76.93386"
  },
  {
    "country": "US",
    "name": "Ephrata",
    "lat": "40.17982",
    "lng": "-76.17884"
  },
  {
    "country": "US",
    "name": "Erie",
    "lat": "42.12922",
    "lng": "-80.08506"
  },
  {
    "country": "US",
    "name": "Espy",
    "lat": "41.0062",
    "lng": "-76.40994"
  },
  {
    "country": "US",
    "name": "Etna",
    "lat": "40.50424",
    "lng": "-79.94894"
  },
  {
    "country": "US",
    "name": "Evans City",
    "lat": "40.76923",
    "lng": "-80.06284"
  },
  {
    "country": "US",
    "name": "Evansburg",
    "lat": "40.18094",
    "lng": "-75.42907"
  },
  {
    "country": "US",
    "name": "Everett",
    "lat": "40.01147",
    "lng": "-78.37335"
  },
  {
    "country": "US",
    "name": "Exeter",
    "lat": "41.32064",
    "lng": "-75.81908"
  },
  {
    "country": "US",
    "name": "Exton",
    "lat": "40.029",
    "lng": "-75.62077"
  },
  {
    "country": "US",
    "name": "Factoryville",
    "lat": "40.82482",
    "lng": "-75.20962"
  },
  {
    "country": "US",
    "name": "Factoryville",
    "lat": "41.56313",
    "lng": "-75.78269"
  },
  {
    "country": "US",
    "name": "Fairhope",
    "lat": "40.11368",
    "lng": "-79.83977"
  },
  {
    "country": "US",
    "name": "Fairless Hills",
    "lat": "40.17955",
    "lng": "-74.85516"
  },
  {
    "country": "US",
    "name": "Fairview",
    "lat": "42.03145",
    "lng": "-80.25534"
  },
  {
    "country": "US",
    "name": "Falls Creek",
    "lat": "41.14506",
    "lng": "-78.80447"
  },
  {
    "country": "US",
    "name": "Farrell",
    "lat": "41.21228",
    "lng": "-80.49674"
  },
  {
    "country": "US",
    "name": "Faxon",
    "lat": "41.24841",
    "lng": "-76.97719"
  },
  {
    "country": "US",
    "name": "Feasterville",
    "lat": "40.144",
    "lng": "-75.00517"
  },
  {
    "country": "US",
    "name": "Fellsburg",
    "lat": "40.18313",
    "lng": "-79.82421"
  },
  {
    "country": "US",
    "name": "Ferndale",
    "lat": "40.28896",
    "lng": "-78.91475"
  },
  {
    "country": "US",
    "name": "Fernway",
    "lat": "40.69479",
    "lng": "-80.13089"
  },
  {
    "country": "US",
    "name": "Fivepointville",
    "lat": "40.18287",
    "lng": "-76.05106"
  },
  {
    "country": "US",
    "name": "Fleetwood",
    "lat": "40.45398",
    "lng": "-75.81798"
  },
  {
    "country": "US",
    "name": "Flemington",
    "lat": "41.12646",
    "lng": "-77.47165"
  },
  {
    "country": "US",
    "name": "Flourtown",
    "lat": "40.10344",
    "lng": "-75.2124"
  },
  {
    "country": "US",
    "name": "Flying Hills",
    "lat": "40.27676",
    "lng": "-75.9141"
  },
  {
    "country": "US",
    "name": "Ford City",
    "lat": "40.77229",
    "lng": "-79.52977"
  },
  {
    "country": "US",
    "name": "Forest City",
    "lat": "41.65147",
    "lng": "-75.46657"
  },
  {
    "country": "US",
    "name": "Forest Hills",
    "lat": "40.41979",
    "lng": "-79.85005"
  },
  {
    "country": "US",
    "name": "Fort Washington",
    "lat": "40.14178",
    "lng": "-75.20906"
  },
  {
    "country": "US",
    "name": "Forty Fort",
    "lat": "41.27897",
    "lng": "-75.87825"
  },
  {
    "country": "US",
    "name": "Foster Brook",
    "lat": "41.97506",
    "lng": "-78.61725"
  },
  {
    "country": "US",
    "name": "Fountain Hill",
    "lat": "40.60149",
    "lng": "-75.39518"
  },
  {
    "country": "US",
    "name": "Fox Chapel",
    "lat": "40.5134",
    "lng": "-79.87977"
  },
  {
    "country": "US",
    "name": "Fox Run",
    "lat": "40.70229",
    "lng": "-80.08284"
  },
  {
    "country": "US",
    "name": "Frackville",
    "lat": "40.78398",
    "lng": "-76.23022"
  },
  {
    "country": "US",
    "name": "Franklin",
    "lat": "41.39784",
    "lng": "-79.83144"
  },
  {
    "country": "US",
    "name": "Franklin Park",
    "lat": "40.5834",
    "lng": "-80.08784"
  },
  {
    "country": "US",
    "name": "Fredericksburg",
    "lat": "40.4437",
    "lng": "-76.42829"
  },
  {
    "country": "US",
    "name": "Freedom",
    "lat": "40.68562",
    "lng": "-80.25173"
  },
  {
    "country": "US",
    "name": "Freeland",
    "lat": "41.01675",
    "lng": "-75.89714"
  },
  {
    "country": "US",
    "name": "Freeport",
    "lat": "40.67395",
    "lng": "-79.68477"
  },
  {
    "country": "US",
    "name": "Freemansburg",
    "lat": "40.62649",
    "lng": "-75.34574"
  },
  {
    "country": "US",
    "name": "Friedens",
    "lat": "40.05008",
    "lng": "-78.99836"
  },
  {
    "country": "US",
    "name": "Fullerton",
    "lat": "40.63176",
    "lng": "-75.47324"
  },
  {
    "country": "US",
    "name": "Galeton",
    "lat": "41.73312",
    "lng": "-77.64193"
  },
  {
    "country": "US",
    "name": "Gallitzin",
    "lat": "40.48229",
    "lng": "-78.55168"
  },
  {
    "country": "US",
    "name": "Garden View",
    "lat": "41.25424",
    "lng": "-77.04608"
  },
  {
    "country": "US",
    "name": "Gastonville",
    "lat": "40.25729",
    "lng": "-79.99588"
  },
  {
    "country": "US",
    "name": "Geistown",
    "lat": "40.29091",
    "lng": "-78.86891"
  },
  {
    "country": "US",
    "name": "Georgetown",
    "lat": "41.2273",
    "lng": "-75.86881"
  },
  {
    "country": "US",
    "name": "Gibsonia",
    "lat": "40.63007",
    "lng": "-79.9695"
  },
  {
    "country": "US",
    "name": "Gilbertsville",
    "lat": "40.3201",
    "lng": "-75.61018"
  },
  {
    "country": "US",
    "name": "Girard",
    "lat": "42.00033",
    "lng": "-80.31812"
  },
  {
    "country": "US",
    "name": "Girardville",
    "lat": "40.79148",
    "lng": "-76.28356"
  },
  {
    "country": "US",
    "name": "Glassport",
    "lat": "40.32479",
    "lng": "-79.89227"
  },
  {
    "country": "US",
    "name": "Glen Lyon",
    "lat": "41.17508",
    "lng": "-76.07465"
  },
  {
    "country": "US",
    "name": "Glenside",
    "lat": "40.10233",
    "lng": "-75.15212"
  },
  {
    "country": "US",
    "name": "Glenshaw",
    "lat": "40.53285",
    "lng": "-79.96755"
  },
  {
    "country": "US",
    "name": "Gold Key Lake",
    "lat": "41.30593",
    "lng": "-74.9385"
  },
  {
    "country": "US",
    "name": "Green Tree",
    "lat": "40.41174",
    "lng": "-80.04561"
  },
  {
    "country": "US",
    "name": "Greenock",
    "lat": "40.31229",
    "lng": "-79.80671"
  },
  {
    "country": "US",
    "name": "Greenville",
    "lat": "41.4045",
    "lng": "-80.39118"
  },
  {
    "country": "US",
    "name": "Greensburg",
    "lat": "40.30146",
    "lng": "-79.53893"
  },
  {
    "country": "US",
    "name": "Greenwood",
    "lat": "40.5359",
    "lng": "-78.35751"
  },
  {
    "country": "US",
    "name": "Grill",
    "lat": "40.2987",
    "lng": "-75.94049"
  },
  {
    "country": "US",
    "name": "Grove City",
    "lat": "41.15784",
    "lng": "-80.08867"
  },
  {
    "country": "US",
    "name": "Halfway House",
    "lat": "40.28204",
    "lng": "-75.64324"
  },
  {
    "country": "US",
    "name": "Hallam",
    "lat": "40.00482",
    "lng": "-76.60413"
  },
  {
    "country": "US",
    "name": "Hallstead",
    "lat": "41.96119",
    "lng": "-75.74324"
  },
  {
    "country": "US",
    "name": "Hamburg",
    "lat": "40.55565",
    "lng": "-75.98188"
  },
  {
    "country": "US",
    "name": "Harleigh",
    "lat": "40.98064",
    "lng": "-75.97131"
  },
  {
    "country": "US",
    "name": "Harleysville",
    "lat": "40.27955",
    "lng": "-75.38712"
  },
  {
    "country": "US",
    "name": "Harrisburg",
    "lat": "40.2737",
    "lng": "-76.88442"
  },
  {
    "country": "US",
    "name": "Harveys Lake",
    "lat": "41.38341",
    "lng": "-76.02465"
  },
  {
    "country": "US",
    "name": "Hastings",
    "lat": "40.66507",
    "lng": "-78.71225"
  },
  {
    "country": "US",
    "name": "Hasson Heights",
    "lat": "41.44895",
    "lng": "-79.677"
  },
  {
    "country": "US",
    "name": "Hatboro",
    "lat": "40.17428",
    "lng": "-75.10684"
  },
  {
    "country": "US",
    "name": "Hatfield",
    "lat": "40.27983",
    "lng": "-75.29934"
  },
  {
    "country": "US",
    "name": "Hawley",
    "lat": "41.47592",
    "lng": "-75.18212"
  },
  {
    "country": "US",
    "name": "Hazleton",
    "lat": "40.95842",
    "lng": "-75.97465"
  },
  {
    "country": "US",
    "name": "Hebron",
    "lat": "40.33898",
    "lng": "-76.3994"
  },
  {
    "country": "US",
    "name": "Heidelberg",
    "lat": "40.39229",
    "lng": "-80.09089"
  },
  {
    "country": "US",
    "name": "Hellertown",
    "lat": "40.57954",
    "lng": "-75.34073"
  },
  {
    "country": "US",
    "name": "Hemlock Farms",
    "lat": "41.32676",
    "lng": "-75.03656"
  },
  {
    "country": "US",
    "name": "Hermitage",
    "lat": "41.23339",
    "lng": "-80.44868"
  },
  {
    "country": "US",
    "name": "Hershey",
    "lat": "40.28592",
    "lng": "-76.65025"
  },
  {
    "country": "US",
    "name": "Highland Park",
    "lat": "40.62091",
    "lng": "-77.56805"
  },
  {
    "country": "US",
    "name": "Highspire",
    "lat": "40.21092",
    "lng": "-76.79108"
  },
  {
    "country": "US",
    "name": "Hilldale",
    "lat": "41.28925",
    "lng": "-75.83631"
  },
  {
    "country": "US",
    "name": "Hiller",
    "lat": "40.01035",
    "lng": "-79.90088"
  },
  {
    "country": "US",
    "name": "Hokendauqua",
    "lat": "40.66204",
    "lng": "-75.49102"
  },
  {
    "country": "US",
    "name": "Hollidaysburg",
    "lat": "40.42729",
    "lng": "-78.3889"
  },
  {
    "country": "US",
    "name": "Homer City",
    "lat": "40.5434",
    "lng": "-79.16226"
  },
  {
    "country": "US",
    "name": "Homestead",
    "lat": "40.4059",
    "lng": "-79.91199"
  },
  {
    "country": "US",
    "name": "Hometown",
    "lat": "40.8237",
    "lng": "-75.9802"
  },
  {
    "country": "US",
    "name": "Honesdale",
    "lat": "41.57676",
    "lng": "-75.25879"
  },
  {
    "country": "US",
    "name": "Honey Brook",
    "lat": "40.09427",
    "lng": "-75.91133"
  },
  {
    "country": "US",
    "name": "Horsham",
    "lat": "40.17844",
    "lng": "-75.12851"
  },
  {
    "country": "US",
    "name": "Houserville",
    "lat": "40.82395",
    "lng": "-77.82889"
  },
  {
    "country": "US",
    "name": "Houston",
    "lat": "40.24646",
    "lng": "-80.21145"
  },
  {
    "country": "US",
    "name": "Hudson",
    "lat": "41.2748",
    "lng": "-75.83603"
  },
  {
    "country": "US",
    "name": "Hughestown",
    "lat": "41.32702",
    "lng": "-75.77325"
  },
  {
    "country": "US",
    "name": "Hughesville",
    "lat": "41.24119",
    "lng": "-76.72385"
  },
  {
    "country": "US",
    "name": "Hummels Wharf",
    "lat": "40.83175",
    "lng": "-76.8358"
  },
  {
    "country": "US",
    "name": "Hummelstown",
    "lat": "40.26537",
    "lng": "-76.7083"
  },
  {
    "country": "US",
    "name": "Huntingdon",
    "lat": "40.4848",
    "lng": "-78.01028"
  },
  {
    "country": "US",
    "name": "Hyde",
    "lat": "41.00256",
    "lng": "-78.46252"
  },
  {
    "country": "US",
    "name": "Hyde Park",
    "lat": "40.37732",
    "lng": "-75.92521"
  },
  {
    "country": "US",
    "name": "Imperial",
    "lat": "40.44951",
    "lng": "-80.2445"
  },
  {
    "country": "US",
    "name": "Indian Mountain Lake",
    "lat": "41.00314",
    "lng": "-75.50824"
  },
  {
    "country": "US",
    "name": "Indiana",
    "lat": "40.62146",
    "lng": "-79.15253"
  },
  {
    "country": "US",
    "name": "Industry",
    "lat": "40.64451",
    "lng": "-80.41618"
  },
  {
    "country": "US",
    "name": "Ingram",
    "lat": "40.44618",
    "lng": "-80.06755"
  },
  {
    "country": "US",
    "name": "Industry",
    "lat": "40.26451",
    "lng": "-79.79227"
  },
  {
    "country": "US",
    "name": "Inkerman",
    "lat": "41.29897",
    "lng": "-75.81269"
  },
  {
    "country": "US",
    "name": "Intercourse",
    "lat": "40.0376",
    "lng": "-76.10495"
  },
  {
    "country": "US",
    "name": "Irwin",
    "lat": "40.32451",
    "lng": "-79.70115"
  },
  {
    "country": "US",
    "name": "Ivyland",
    "lat": "40.20789",
    "lng": "-75.07267"
  },
  {
    "country": "US",
    "name": "Jacksonwald",
    "lat": "40.32454",
    "lng": "-75.84965"
  },
  {
    "country": "US",
    "name": "Jeannette",
    "lat": "40.32812",
    "lng": "-79.61532"
  },
  {
    "country": "US",
    "name": "Jefferson Hills",
    "lat": "40.29118",
    "lng": "-79.93199"
  },
  {
    "country": "US",
    "name": "Jenkintown",
    "lat": "40.09594",
    "lng": "-75.12517"
  },
  {
    "country": "US",
    "name": "Jermyn",
    "lat": "41.53091",
    "lng": "-75.54546"
  },
  {
    "country": "US",
    "name": "Jerome",
    "lat": "40.20896",
    "lng": "-78.98364"
  },
  {
    "country": "US",
    "name": "Jersey Shore",
    "lat": "41.20202",
    "lng": "-77.26442"
  },
  {
    "country": "US",
    "name": "Jessup",
    "lat": "41.46869",
    "lng": "-75.56213"
  },
  {
    "country": "US",
    "name": "Jim Thorpe",
    "lat": "40.87592",
    "lng": "-75.73241"
  },
  {
    "country": "US",
    "name": "Johnsonburg",
    "lat": "41.49062",
    "lng": "-78.67503"
  },
  {
    "country": "US",
    "name": "Johnsonburg",
    "lat": "40.88618",
    "lng": "-78.87781"
  },
  {
    "country": "US",
    "name": "Johnstown",
    "lat": "40.32674",
    "lng": "-78.92197"
  },
  {
    "country": "US",
    "name": "Jonestown",
    "lat": "40.4137",
    "lng": "-76.4783"
  },
  {
    "country": "US",
    "name": "Kane",
    "lat": "41.66284",
    "lng": "-78.81114"
  },
  {
    "country": "US",
    "name": "Kenhorst",
    "lat": "40.31065",
    "lng": "-75.93938"
  },
  {
    "country": "US",
    "name": "Kenilworth",
    "lat": "40.23149",
    "lng": "-75.63408"
  },
  {
    "country": "US",
    "name": "Kenmar",
    "lat": "41.25341",
    "lng": "-76.95941"
  },
  {
    "country": "US",
    "name": "King of Prussia",
    "lat": "40.08927",
    "lng": "-75.39602"
  },
  {
    "country": "US",
    "name": "Kingston",
    "lat": "41.26175",
    "lng": "-75.89686"
  },
  {
    "country": "US",
    "name": "Kittanning",
    "lat": "40.81645",
    "lng": "-79.52199"
  },
  {
    "country": "US",
    "name": "Knox",
    "lat": "41.23451",
    "lng": "-79.53727"
  },
  {
    "country": "US",
    "name": "Kulpmont",
    "lat": "40.79342",
    "lng": "-76.47245"
  },
  {
    "country": "US",
    "name": "Kulpsville",
    "lat": "40.24288",
    "lng": "-75.33656"
  },
  {
    "country": "US",
    "name": "Kutztown",
    "lat": "40.51732",
    "lng": "-75.77742"
  },
  {
    "country": "US",
    "name": "Laflin",
    "lat": "41.28897",
    "lng": "-75.80547"
  },
  {
    "country": "US",
    "name": "Lake City",
    "lat": "42.01422",
    "lng": "-80.34534"
  },
  {
    "country": "US",
    "name": "Lake Wynonah",
    "lat": "40.59926",
    "lng": "-76.16383"
  },
  {
    "country": "US",
    "name": "Lakemont",
    "lat": "40.47285",
    "lng": "-78.38835"
  },
  {
    "country": "US",
    "name": "Lancaster",
    "lat": "40.03788",
    "lng": "-76.30551"
  },
  {
    "country": "US",
    "name": "Landisville",
    "lat": "40.09537",
    "lng": "-76.40996"
  },
  {
    "country": "US",
    "name": "Langhorne",
    "lat": "40.17455",
    "lng": "-74.92267"
  },
  {
    "country": "US",
    "name": "Langhorne Manor",
    "lat": "40.16705",
    "lng": "-74.91767"
  },
  {
    "country": "US",
    "name": "Lansdale",
    "lat": "40.2415",
    "lng": "-75.28379"
  },
  {
    "country": "US",
    "name": "Lansford",
    "lat": "40.83176",
    "lng": "-75.88242"
  },
  {
    "country": "US",
    "name": "Laporte",
    "lat": "41.42397",
    "lng": "-76.49411"
  },
  {
    "country": "US",
    "name": "Larksville",
    "lat": "41.24508",
    "lng": "-75.93075"
  },
  {
    "country": "US",
    "name": "Latrobe",
    "lat": "40.32118",
    "lng": "-79.37948"
  },
  {
    "country": "US",
    "name": "Laureldale",
    "lat": "40.38815",
    "lng": "-75.91798"
  },
  {
    "country": "US",
    "name": "Laurys Station",
    "lat": "40.72315",
    "lng": "-75.53018"
  },
  {
    "country": "US",
    "name": "Lawnton",
    "lat": "40.25842",
    "lng": "-76.80386"
  },
  {
    "country": "US",
    "name": "Lawrence Park",
    "lat": "40.34564",
    "lng": "-76.8008"
  },
  {
    "country": "US",
    "name": "Lawrence Park",
    "lat": "42.15228",
    "lng": "-80.02311"
  },
  {
    "country": "US",
    "name": "Lawson Heights",
    "lat": "40.29174",
    "lng": "-79.3892"
  },
  {
    "country": "US",
    "name": "Lebanon",
    "lat": "40.34093",
    "lng": "-76.41135"
  },
  {
    "country": "US",
    "name": "Leechburg",
    "lat": "40.62701",
    "lng": "-79.6056"
  },
  {
    "country": "US",
    "name": "Leesport",
    "lat": "40.44704",
    "lng": "-75.96632"
  },
  {
    "country": "US",
    "name": "Leetsdale",
    "lat": "40.56312",
    "lng": "-80.20839"
  },
  {
    "country": "US",
    "name": "Lehighton",
    "lat": "40.8337",
    "lng": "-75.7138"
  },
  {
    "country": "US",
    "name": "Lemont",
    "lat": "40.81062",
    "lng": "-77.81833"
  },
  {
    "country": "US",
    "name": "Lemoyne",
    "lat": "40.2412",
    "lng": "-76.89414"
  },
  {
    "country": "US",
    "name": "Lenape Heights",
    "lat": "40.76423",
    "lng": "-79.5206"
  },
  {
    "country": "US",
    "name": "Leola",
    "lat": "40.08787",
    "lng": "-76.18495"
  },
  {
    "country": "US",
    "name": "Level Green",
    "lat": "40.3934",
    "lng": "-79.72032"
  },
  {
    "country": "US",
    "name": "Levittown",
    "lat": "40.15511",
    "lng": "-74.82877"
  },
  {
    "country": "US",
    "name": "Lewisburg",
    "lat": "40.96453",
    "lng": "-76.88441"
  },
  {
    "country": "US",
    "name": "Lewistown",
    "lat": "40.59924",
    "lng": "-77.57138"
  },
  {
    "country": "US",
    "name": "Liberty",
    "lat": "40.32535",
    "lng": "-79.85616"
  },
  {
    "country": "US",
    "name": "Light Street",
    "lat": "41.0362",
    "lng": "-76.42356"
  },
  {
    "country": "US",
    "name": "Ligonier",
    "lat": "40.24313",
    "lng": "-79.23753"
  },
  {
    "country": "US",
    "name": "Limerick",
    "lat": "40.23093",
    "lng": "-75.52212"
  },
  {
    "country": "US",
    "name": "Lincoln",
    "lat": "40.31896",
    "lng": "-79.85477"
  },
  {
    "country": "US",
    "name": "Lincoln Park",
    "lat": "40.31481",
    "lng": "-75.98549"
  },
  {
    "country": "US",
    "name": "Linglestown",
    "lat": "40.33398",
    "lng": "-76.78914"
  },
  {
    "country": "US",
    "name": "Linntown",
    "lat": "40.95897",
    "lng": "-76.89913"
  },
  {
    "country": "US",
    "name": "Lionville",
    "lat": "40.05372",
    "lng": "-75.65993"
  },
  {
    "country": "US",
    "name": "Lititz",
    "lat": "40.15732",
    "lng": "-76.3069"
  },
  {
    "country": "US",
    "name": "Lock Haven",
    "lat": "41.13701",
    "lng": "-77.44693"
  },
  {
    "country": "US",
    "name": "Lorane",
    "lat": "40.28843",
    "lng": "-75.85465"
  },
  {
    "country": "US",
    "name": "Loretto",
    "lat": "40.50313",
    "lng": "-78.6303"
  },
  {
    "country": "US",
    "name": "Lower Allen",
    "lat": "40.22648",
    "lng": "-76.90053"
  },
  {
    "country": "US",
    "name": "Lower Burrell",
    "lat": "40.55312",
    "lng": "-79.75727"
  },
  {
    "country": "US",
    "name": "Loyalhanna",
    "lat": "40.32257",
    "lng": "-79.36226"
  },
  {
    "country": "US",
    "name": "Luzerne",
    "lat": "41.28564",
    "lng": "-75.90103"
  },
  {
    "country": "US",
    "name": "Lykens",
    "lat": "40.56675",
    "lng": "-76.70052"
  },
  {
    "country": "US",
    "name": "Macungie",
    "lat": "40.51593",
    "lng": "-75.55519"
  },
  {
    "country": "US",
    "name": "Mahanoy City",
    "lat": "40.81259",
    "lng": "-76.1416"
  },
  {
    "country": "US",
    "name": "Malvern",
    "lat": "40.03622",
    "lng": "-75.51381"
  },
  {
    "country": "US",
    "name": "Manchester",
    "lat": "40.06315",
    "lng": "-76.7183"
  },
  {
    "country": "US",
    "name": "Manheim",
    "lat": "40.16343",
    "lng": "-76.39496"
  },
  {
    "country": "US",
    "name": "Manor",
    "lat": "40.33396",
    "lng": "-79.67004"
  },
  {
    "country": "US",
    "name": "Mansfield",
    "lat": "41.8073",
    "lng": "-77.07747"
  },
  {
    "country": "US",
    "name": "Maple Glen",
    "lat": "40.01563",
    "lng": "-79.97672"
  },
  {
    "country": "US",
    "name": "Maple Glen",
    "lat": "40.17928",
    "lng": "-75.18045"
  },
  {
    "country": "US",
    "name": "Marianne",
    "lat": "41.24645",
    "lng": "-79.42893"
  },
  {
    "country": "US",
    "name": "Marienville",
    "lat": "41.46895",
    "lng": "-79.1231"
  },
  {
    "country": "US",
    "name": "Marietta",
    "lat": "40.05704",
    "lng": "-76.55219"
  },
  {
    "country": "US",
    "name": "Mars",
    "lat": "40.6959",
    "lng": "-80.01173"
  },
  {
    "country": "US",
    "name": "Marshallton",
    "lat": "40.78675",
    "lng": "-76.5394"
  },
  {
    "country": "US",
    "name": "Martinsburg",
    "lat": "40.31119",
    "lng": "-78.32418"
  },
  {
    "country": "US",
    "name": "Marysville",
    "lat": "40.34259",
    "lng": "-76.92997"
  },
  {
    "country": "US",
    "name": "Matamoras",
    "lat": "40.44009",
    "lng": "-76.93331"
  },
  {
    "country": "US",
    "name": "Matamoras",
    "lat": "41.3687",
    "lng": "-74.70016"
  },
  {
    "country": "US",
    "name": "Mayfield",
    "lat": "41.53814",
    "lng": "-75.53602"
  },
  {
    "country": "US",
    "name": "Mayfield",
    "lat": "40.13618",
    "lng": "-79.59782"
  },
  {
    "country": "US",
    "name": "Maytown",
    "lat": "40.07537",
    "lng": "-76.58219"
  },
  {
    "country": "US",
    "name": "McAdoo",
    "lat": "40.90127",
    "lng": "-75.99106"
  },
  {
    "country": "US",
    "name": "McConnellstown",
    "lat": "40.45257",
    "lng": "-78.08167"
  },
  {
    "country": "US",
    "name": "McDonald",
    "lat": "40.3709",
    "lng": "-80.23478"
  },
  {
    "country": "US",
    "name": "McGovern",
    "lat": "40.22896",
    "lng": "-80.21645"
  },
  {
    "country": "US",
    "name": "McKees Rocks",
    "lat": "40.46562",
    "lng": "-80.06561"
  },
  {
    "country": "US",
    "name": "McKeesport",
    "lat": "40.34785",
    "lng": "-79.86422"
  },
  {
    "country": "US",
    "name": "McMurray",
    "lat": "40.27785",
    "lng": "-80.08394"
  },
  {
    "country": "US",
    "name": "Meadowood",
    "lat": "40.84201",
    "lng": "-79.89394"
  },
  {
    "country": "US",
    "name": "Meadville",
    "lat": "41.64144",
    "lng": "-80.15145"
  },
  {
    "country": "US",
    "name": "Mechanicsburg",
    "lat": "40.21426",
    "lng": "-77.00859"
  },
  {
    "country": "US",
    "name": "Mechanicsville",
    "lat": "40.96648",
    "lng": "-76.58662"
  },
  {
    "country": "US",
    "name": "Mercer",
    "lat": "41.227",
    "lng": "-80.23979"
  },
  {
    "country": "US",
    "name": "Meridian",
    "lat": "40.8484",
    "lng": "-79.962"
  },
  {
    "country": "US",
    "name": "Middleburg",
    "lat": "40.78592",
    "lng": "-77.0472"
  },
  {
    "country": "US",
    "name": "Middletown",
    "lat": "40.19981",
    "lng": "-76.73108"
  },
  {
    "country": "US",
    "name": "Middletown",
    "lat": "40.64399",
    "lng": "-75.3324"
  },
  {
    "country": "US",
    "name": "Midland",
    "lat": "40.63257",
    "lng": "-80.44645"
  },
  {
    "country": "US",
    "name": "Midland",
    "lat": "40.25896",
    "lng": "-80.21811"
  },
  {
    "country": "US",
    "name": "Mifflinburg",
    "lat": "40.91758",
    "lng": "-77.04775"
  },
  {
    "country": "US",
    "name": "Mifflintown",
    "lat": "40.5698",
    "lng": "-77.39693"
  },
  {
    "country": "US",
    "name": "Mifflinville",
    "lat": "41.03231",
    "lng": "-76.30799"
  },
  {
    "country": "US",
    "name": "Milesburg",
    "lat": "40.94173",
    "lng": "-77.785"
  },
  {
    "country": "US",
    "name": "Milford",
    "lat": "41.32232",
    "lng": "-74.80239"
  },
  {
    "country": "US",
    "name": "Mill Hall",
    "lat": "41.10729",
    "lng": "-77.48443"
  },
  {
    "country": "US",
    "name": "Millersburg",
    "lat": "40.53953",
    "lng": "-76.96081"
  },
  {
    "country": "US",
    "name": "Millvale",
    "lat": "40.48007",
    "lng": "-79.97839"
  },
  {
    "country": "US",
    "name": "Milroy",
    "lat": "40.71396",
    "lng": "-77.59055"
  },
  {
    "country": "US",
    "name": "Milton",
    "lat": "41.01203",
    "lng": "-76.84774"
  },
  {
    "country": "US",
    "name": "Minersville",
    "lat": "40.69065",
    "lng": "-76.26217"
  },
  {
    "country": "US",
    "name": "Mohnton",
    "lat": "40.28593",
    "lng": "-75.98438"
  },
  {
    "country": "US",
    "name": "Monaca",
    "lat": "40.68729",
    "lng": "-80.27145"
  },
  {
    "country": "US",
    "name": "Monessen",
    "lat": "40.14841",
    "lng": "-79.88783"
  },
  {
    "country": "US",
    "name": "Monongahela",
    "lat": "40.20313",
    "lng": "-79.92616"
  },
  {
    "country": "US",
    "name": "Monroeville",
    "lat": "40.42118",
    "lng": "-79.7881"
  },
  {
    "country": "US",
    "name": "Montgomery",
    "lat": "41.17036",
    "lng": "-76.87691"
  },
  {
    "country": "US",
    "name": "Montgomeryville",
    "lat": "40.24733",
    "lng": "-75.24379"
  },
  {
    "country": "US",
    "name": "Montoursville",
    "lat": "41.25425",
    "lng": "-76.92052"
  },
  {
    "country": "US",
    "name": "Montrose",
    "lat": "40.30648",
    "lng": "-75.98771"
  },
  {
    "country": "US",
    "name": "Montrose",
    "lat": "41.83397",
    "lng": "-75.87714"
  },
  {
    "country": "US",
    "name": "Moosic",
    "lat": "41.35341",
    "lng": "-75.73825"
  },
  {
    "country": "US",
    "name": "Morrisville",
    "lat": "40.2115",
    "lng": "-74.78794"
  },
  {
    "country": "US",
    "name": "Moscow",
    "lat": "41.33675",
    "lng": "-75.51852"
  },
  {
    "country": "US",
    "name": "Mount Carmel",
    "lat": "40.79703",
    "lng": "-76.4119"
  },
  {
    "country": "US",
    "name": "Mount Cobb",
    "lat": "41.41342",
    "lng": "-75.49324"
  },
  {
    "country": "US",
    "name": "Mount Holly Springs",
    "lat": "40.11842",
    "lng": "-77.18998"
  },
  {
    "country": "US",
    "name": "Mount Joy",
    "lat": "40.10982",
    "lng": "-76.5033"
  },
  {
    "country": "US",
    "name": "Mount Lebanon",
    "lat": "40.35535",
    "lng": "-80.0495"
  },
  {
    "country": "US",
    "name": "Mount Oliver",
    "lat": "40.41424",
    "lng": "-79.98783"
  },
  {
    "country": "US",
    "name": "Mount Penn",
    "lat": "40.32815",
    "lng": "-75.89076"
  },
  {
    "country": "US",
    "name": "Mount Pleasant",
    "lat": "40.14896",
    "lng": "-79.54115"
  },
  {
    "country": "US",
    "name": "Mount Pocono",
    "lat": "41.12203",
    "lng": "-75.36463"
  },
  {
    "country": "US",
    "name": "Mount Union",
    "lat": "40.38452",
    "lng": "-77.88222"
  },
  {
    "country": "US",
    "name": "Mount Wolf",
    "lat": "40.06315",
    "lng": "-76.70386"
  },
  {
    "country": "US",
    "name": "Mountain Top",
    "lat": "41.16953",
    "lng": "-75.87742"
  },
  {
    "country": "US",
    "name": "Mountainhome",
    "lat": "41.1737",
    "lng": "-75.27102"
  },
  {
    "country": "US",
    "name": "Mountville",
    "lat": "40.03926",
    "lng": "-76.4308"
  },
  {
    "country": "US",
    "name": "Muhlenberg Park",
    "lat": "40.38482",
    "lng": "-75.94132"
  },
  {
    "country": "US",
    "name": "Muncy",
    "lat": "41.20564",
    "lng": "-76.78552"
  },
  {
    "country": "US",
    "name": "Munhall",
    "lat": "40.39229",
    "lng": "-79.90005"
  },
  {
    "country": "US",
    "name": "Mundys Corner",
    "lat": "40.44479",
    "lng": "-78.84113"
  },
  {
    "country": "US",
    "name": "Murrysville",
    "lat": "40.4284",
    "lng": "-79.69755"
  },
  {
    "country": "US",
    "name": "Muse",
    "lat": "40.29285",
    "lng": "-80.20034"
  },
  {
    "country": "US",
    "name": "Myerstown",
    "lat": "40.37454",
    "lng": "-76.30273"
  },
  {
    "country": "US",
    "name": "Nanticoke",
    "lat": "41.20536",
    "lng": "-76.00492"
  },
  {
    "country": "US",
    "name": "Nanty Glo",
    "lat": "40.47229",
    "lng": "-78.83336"
  },
  {
    "country": "US",
    "name": "Narberth",
    "lat": "40.00845",
    "lng": "-75.26046"
  },
  {
    "country": "US",
    "name": "Nazareth",
    "lat": "40.74038",
    "lng": "-75.30962"
  },
  {
    "country": "US",
    "name": "Nescopeck",
    "lat": "41.05203",
    "lng": "-76.22077"
  },
  {
    "country": "US",
    "name": "Nesquehoning",
    "lat": "40.86453",
    "lng": "-75.81103"
  },
  {
    "country": "US",
    "name": "New Beaver",
    "lat": "40.87645",
    "lng": "-80.37062"
  },
  {
    "country": "US",
    "name": "New Berlinville",
    "lat": "40.34537",
    "lng": "-75.63296"
  },
  {
    "country": "US",
    "name": "New Bloomfield",
    "lat": "40.41981",
    "lng": "-77.18637"
  },
  {
    "country": "US",
    "name": "New Brighton",
    "lat": "40.73034",
    "lng": "-80.31006"
  },
  {
    "country": "US",
    "name": "New Britain",
    "lat": "40.299",
    "lng": "-75.18101"
  },
  {
    "country": "US",
    "name": "New Castle",
    "lat": "41.00367",
    "lng": "-80.34701"
  },
  {
    "country": "US",
    "name": "New Columbia",
    "lat": "41.04092",
    "lng": "-76.86691"
  },
  {
    "country": "US",
    "name": "New Eagle",
    "lat": "40.20785",
    "lng": "-79.94699"
  },
  {
    "country": "US",
    "name": "New Cumberland",
    "lat": "40.23231",
    "lng": "-76.8847"
  },
  {
    "country": "US",
    "name": "New Hope",
    "lat": "40.36427",
    "lng": "-74.95128"
  },
  {
    "country": "US",
    "name": "New Kensington",
    "lat": "40.56979",
    "lng": "-79.76477"
  },
  {
    "country": "US",
    "name": "New Holland",
    "lat": "40.10176",
    "lng": "-76.08523"
  },
  {
    "country": "US",
    "name": "New Philadelphia",
    "lat": "40.71953",
    "lng": "-76.11577"
  },
  {
    "country": "US",
    "name": "New Stanton",
    "lat": "40.21924",
    "lng": "-79.60948"
  },
  {
    "country": "US",
    "name": "New Wilmington",
    "lat": "41.12228",
    "lng": "-80.33284"
  },
  {
    "country": "US",
    "name": "Newmanstown",
    "lat": "40.34954",
    "lng": "-76.21328"
  },
  {
    "country": "US",
    "name": "Newport",
    "lat": "40.47786",
    "lng": "-77.13054"
  },
  {
    "country": "US",
    "name": "Newtown",
    "lat": "40.22928",
    "lng": "-74.93683"
  },
  {
    "country": "US",
    "name": "Newtown Grant",
    "lat": "40.26011",
    "lng": "-74.95489"
  },
  {
    "country": "US",
    "name": "Newville",
    "lat": "40.17314",
    "lng": "-77.3986"
  },
  {
    "country": "US",
    "name": "Nixon",
    "lat": "40.7834",
    "lng": "-79.9295"
  },
  {
    "country": "US",
    "name": "Norristown",
    "lat": "40.1215",
    "lng": "-75.3399"
  },
  {
    "country": "US",
    "name": "North Apollo",
    "lat": "40.59618",
    "lng": "-79.5556"
  },
  {
    "country": "US",
    "name": "North Belle Vernon",
    "lat": "40.12924",
    "lng": "-79.8681"
  },
  {
    "country": "US",
    "name": "North Braddock",
    "lat": "40.39896",
    "lng": "-79.84088"
  },
  {
    "country": "US",
    "name": "North Charleroi",
    "lat": "40.15118",
    "lng": "-79.90755"
  },
  {
    "country": "US",
    "name": "North Catasauqua",
    "lat": "40.65982",
    "lng": "-75.47685"
  },
  {
    "country": "US",
    "name": "North East",
    "lat": "42.21561",
    "lng": "-79.83422"
  },
  {
    "country": "US",
    "name": "North Versailles",
    "lat": "40.37979",
    "lng": "-79.80949"
  },
  {
    "country": "US",
    "name": "North Wales",
    "lat": "40.21094",
    "lng": "-75.27823"
  },
  {
    "country": "US",
    "name": "North Warren",
    "lat": "41.87423",
    "lng": "-79.15227"
  },
  {
    "country": "US",
    "name": "Northampton",
    "lat": "40.68621",
    "lng": "-75.49685"
  },
  {
    "country": "US",
    "name": "Northern Cambria",
    "lat": "40.65923",
    "lng": "-78.78169"
  },
  {
    "country": "US",
    "name": "Northumberland",
    "lat": "40.89175",
    "lng": "-76.79747"
  },
  {
    "country": "US",
    "name": "Oak Hills",
    "lat": "40.82479",
    "lng": "-79.91311"
  },
  {
    "country": "US",
    "name": "Oakdale",
    "lat": "40.39812",
    "lng": "-80.18561"
  },
  {
    "country": "US",
    "name": "Oakdale",
    "lat": "40.99203",
    "lng": "-75.9202"
  },
  {
    "country": "US",
    "name": "Oakland",
    "lat": "40.30646",
    "lng": "-78.88752"
  },
  {
    "country": "US",
    "name": "Oakland",
    "lat": "40.98978",
    "lng": "-80.36951"
  },
  {
    "country": "US",
    "name": "Oakmont",
    "lat": "40.52173",
    "lng": "-79.84227"
  },
  {
    "country": "US",
    "name": "Oakwood",
    "lat": "41.01062",
    "lng": "-80.37951"
  },
  {
    "country": "US",
    "name": "Ohioville",
    "lat": "40.67923",
    "lng": "-80.49479"
  },
  {
    "country": "US",
    "name": "Oil City",
    "lat": "41.43395",
    "lng": "-79.70644"
  },
  {
    "country": "US",
    "name": "Old Forge",
    "lat": "41.37119",
    "lng": "-75.73491"
  },
  {
    "country": "US",
    "name": "Old Orchard",
    "lat": "40.65788",
    "lng": "-75.26212"
  },
  {
    "country": "US",
    "name": "Oley",
    "lat": "40.38759",
    "lng": "-75.78964"
  },
  {
    "country": "US",
    "name": "Olyphant",
    "lat": "41.46841",
    "lng": "-75.60297"
  },
  {
    "country": "US",
    "name": "Orchard Hills",
    "lat": "40.58618",
    "lng": "-79.53143"
  },
  {
    "country": "US",
    "name": "Oreland",
    "lat": "40.11844",
    "lng": "-75.17768"
  },
  {
    "country": "US",
    "name": "Orwigsburg",
    "lat": "40.65481",
    "lng": "-76.10077"
  },
  {
    "country": "US",
    "name": "Osceola Mills",
    "lat": "40.85006",
    "lng": "-78.27057"
  },
  {
    "country": "US",
    "name": "Palmdale",
    "lat": "40.29787",
    "lng": "-76.61858"
  },
  {
    "country": "US",
    "name": "Palmer Heights",
    "lat": "40.68732",
    "lng": "-75.2624"
  },
  {
    "country": "US",
    "name": "Palmerton",
    "lat": "40.8014",
    "lng": "-75.6119"
  },
  {
    "country": "US",
    "name": "Palmyra",
    "lat": "40.30898",
    "lng": "-76.5933"
  },
  {
    "country": "US",
    "name": "Palo Alto",
    "lat": "40.68731",
    "lng": "-76.17216"
  },
  {
    "country": "US",
    "name": "Paoli",
    "lat": "40.04205",
    "lng": "-75.47631"
  },
  {
    "country": "US",
    "name": "Paradise",
    "lat": "40.00982",
    "lng": "-76.12857"
  },
  {
    "country": "US",
    "name": "Park Forest Village",
    "lat": "40.80673",
    "lng": "-77.91695"
  },
  {
    "country": "US",
    "name": "Parkside",
    "lat": "41.1012",
    "lng": "-75.25046"
  },
  {
    "country": "US",
    "name": "Patton",
    "lat": "40.63396",
    "lng": "-78.6503"
  },
  {
    "country": "US",
    "name": "Paxtang",
    "lat": "40.25898",
    "lng": "-76.83192"
  },
  {
    "country": "US",
    "name": "Paxtonia",
    "lat": "40.31731",
    "lng": "-76.79442"
  },
  {
    "country": "US",
    "name": "Pen Argyl",
    "lat": "40.86871",
    "lng": "-75.2549"
  },
  {
    "country": "US",
    "name": "Penbrook",
    "lat": "40.27537",
    "lng": "-76.84803"
  },
  {
    "country": "US",
    "name": "Penn Hills",
    "lat": "40.50118",
    "lng": "-79.83922"
  },
  {
    "country": "US",
    "name": "Penndel",
    "lat": "40.15205",
    "lng": "-74.91656"
  },
  {
    "country": "US",
    "name": "Pennsburg",
    "lat": "40.39093",
    "lng": "-75.49212"
  },
  {
    "country": "US",
    "name": "Pennside",
    "lat": "40.33732",
    "lng": "-75.87854"
  },
  {
    "country": "US",
    "name": "Penryn",
    "lat": "40.20509",
    "lng": "-76.36829"
  },
  {
    "country": "US",
    "name": "Perkasie",
    "lat": "40.37205",
    "lng": "-75.29268"
  },
  {
    "country": "US",
    "name": "Perryopolis",
    "lat": "40.08702",
    "lng": "-79.7506"
  },
  {
    "country": "US",
    "name": "Philipsburg",
    "lat": "40.89645",
    "lng": "-78.22057"
  },
  {
    "country": "US",
    "name": "Phoenixville",
    "lat": "40.13038",
    "lng": "-75.51491"
  },
  {
    "country": "US",
    "name": "Pine Grove",
    "lat": "40.54842",
    "lng": "-76.38468"
  },
  {
    "country": "US",
    "name": "Pine Grove Mills",
    "lat": "40.73367",
    "lng": "-77.88556"
  },
  {
    "country": "US",
    "name": "Pitcairn",
    "lat": "40.40312",
    "lng": "-79.7781"
  },
  {
    "country": "US",
    "name": "Pittsburgh",
    "lat": "40.44062",
    "lng": "-79.99589"
  },
  {
    "country": "US",
    "name": "Pittston",
    "lat": "41.32591",
    "lng": "-75.78936"
  },
  {
    "country": "US",
    "name": "Plains",
    "lat": "41.27536",
    "lng": "-75.8502"
  },
  {
    "country": "US",
    "name": "Pleasant Gap",
    "lat": "40.86812",
    "lng": "-77.74667"
  },
  {
    "country": "US",
    "name": "Pleasant Hill",
    "lat": "40.3362",
    "lng": "-76.44163"
  },
  {
    "country": "US",
    "name": "Pleasant Hills",
    "lat": "40.33563",
    "lng": "-79.96061"
  },
  {
    "country": "US",
    "name": "Plum",
    "lat": "40.50035",
    "lng": "-79.74949"
  },
  {
    "country": "US",
    "name": "Plumsteadville",
    "lat": "40.38733",
    "lng": "-75.14656"
  },
  {
    "country": "US",
    "name": "Plymouth",
    "lat": "41.24036",
    "lng": "-75.94464"
  },
  {
    "country": "US",
    "name": "Plymouth Meeting",
    "lat": "40.10233",
    "lng": "-75.27435"
  },
  {
    "country": "US",
    "name": "Pocono Pines",
    "lat": "41.10675",
    "lng": "-75.45435"
  },
  {
    "country": "US",
    "name": "Port Carbon",
    "lat": "40.69648",
    "lng": "-76.16883"
  },
  {
    "country": "US",
    "name": "Port Allegany",
    "lat": "41.8109",
    "lng": "-78.27974"
  },
  {
    "country": "US",
    "name": "Port Vue",
    "lat": "40.3359",
    "lng": "-79.86977"
  },
  {
    "country": "US",
    "name": "Portage",
    "lat": "40.38868",
    "lng": "-78.67224"
  },
  {
    "country": "US",
    "name": "Pottsgrove",
    "lat": "40.26482",
    "lng": "-75.61185"
  },
  {
    "country": "US",
    "name": "Pottstown",
    "lat": "40.24537",
    "lng": "-75.64963"
  },
  {
    "country": "US",
    "name": "Pottsville",
    "lat": "40.68565",
    "lng": "-76.1955"
  },
  {
    "country": "US",
    "name": "Progress",
    "lat": "40.28509",
    "lng": "-76.83136"
  },
  {
    "country": "US",
    "name": "Prospect",
    "lat": "40.90451",
    "lng": "-80.04645"
  },
  {
    "country": "US",
    "name": "Punxsutawney",
    "lat": "40.94368",
    "lng": "-78.97087"
  },
  {
    "country": "US",
    "name": "Quakertown",
    "lat": "40.44177",
    "lng": "-75.34157"
  },
  {
    "country": "US",
    "name": "Radnor",
    "lat": "40.04622",
    "lng": "-75.35991"
  },
  {
    "country": "US",
    "name": "Pocono Ranch Lands",
    "lat": "41.16454",
    "lng": "-74.95212"
  },
  {
    "country": "US",
    "name": "Rankin",
    "lat": "40.41257",
    "lng": "-79.87922"
  },
  {
    "country": "US",
    "name": "Raubsville",
    "lat": "40.63566",
    "lng": "-75.19295"
  },
  {
    "country": "US",
    "name": "Reading",
    "lat": "40.33565",
    "lng": "-75.92687"
  },
  {
    "country": "US",
    "name": "Reamstown",
    "lat": "40.21148",
    "lng": "-76.12328"
  },
  {
    "country": "US",
    "name": "Red Hill",
    "lat": "40.37288",
    "lng": "-75.48101"
  },
  {
    "country": "US",
    "name": "Red Lion",
    "lat": "40.48065",
    "lng": "-75.61602"
  },
  {
    "country": "US",
    "name": "Reiffton",
    "lat": "40.31981",
    "lng": "-75.87354"
  },
  {
    "country": "US",
    "name": "Reinholds",
    "lat": "40.26676",
    "lng": "-76.1155"
  },
  {
    "country": "US",
    "name": "Rennerdale",
    "lat": "40.3984",
    "lng": "-80.14145"
  },
  {
    "country": "US",
    "name": "Renovo",
    "lat": "41.32646",
    "lng": "-77.75082"
  },
  {
    "country": "US",
    "name": "Reynolds Heights",
    "lat": "41.34506",
    "lng": "-80.39423"
  },
  {
    "country": "US",
    "name": "Reynoldsville",
    "lat": "41.09701",
    "lng": "-78.88864"
  },
  {
    "country": "US",
    "name": "Rheems",
    "lat": "40.13009",
    "lng": "-76.57052"
  },
  {
    "country": "US",
    "name": "Richboro",
    "lat": "40.21511",
    "lng": "-75.01072"
  },
  {
    "country": "US",
    "name": "Richland",
    "lat": "40.35926",
    "lng": "-76.25828"
  },
  {
    "country": "US",
    "name": "Richlandtown",
    "lat": "40.4701",
    "lng": "-75.32046"
  },
  {
    "country": "US",
    "name": "Ridgway",
    "lat": "41.42034",
    "lng": "-78.72864"
  },
  {
    "country": "US",
    "name": "River View Park",
    "lat": "40.39259",
    "lng": "-75.95882"
  },
  {
    "country": "US",
    "name": "Riverside",
    "lat": "40.95536",
    "lng": "-76.62885"
  },
  {
    "country": "US",
    "name": "Roaring Spring",
    "lat": "40.33591",
    "lng": "-78.39085"
  },
  {
    "country": "US",
    "name": "Robesonia",
    "lat": "40.35176",
    "lng": "-76.13439"
  },
  {
    "country": "US",
    "name": "Rochester",
    "lat": "40.70229",
    "lng": "-80.28645"
  },
  {
    "country": "US",
    "name": "Rockledge",
    "lat": "40.08122",
    "lng": "-75.08962"
  },
  {
    "country": "US",
    "name": "Roseto",
    "lat": "40.88065",
    "lng": "-75.21462"
  },
  {
    "country": "US",
    "name": "Rothsville",
    "lat": "40.15121",
    "lng": "-76.25107"
  },
  {
    "country": "US",
    "name": "Royalton",
    "lat": "40.18731",
    "lng": "-76.72997"
  },
  {
    "country": "US",
    "name": "Royersford",
    "lat": "40.18427",
    "lng": "-75.53796"
  },
  {
    "country": "US",
    "name": "Russell",
    "lat": "41.94145",
    "lng": "-79.13505"
  },
  {
    "country": "US",
    "name": "Russellton",
    "lat": "40.61146",
    "lng": "-79.837"
  },
  {
    "country": "US",
    "name": "Rutherford",
    "lat": "40.26898",
    "lng": "-76.76803"
  },
  {
    "country": "US",
    "name": "Saint Clair",
    "lat": "40.72065",
    "lng": "-76.19105"
  },
  {
    "country": "US",
    "name": "Saint Lawrence",
    "lat": "40.32704",
    "lng": "-75.87187"
  },
  {
    "country": "US",
    "name": "Saint Marys",
    "lat": "41.42784",
    "lng": "-78.56086"
  },
  {
    "country": "US",
    "name": "Salix",
    "lat": "40.30008",
    "lng": "-78.7653"
  },
  {
    "country": "US",
    "name": "Salunga",
    "lat": "40.10093",
    "lng": "-76.42469"
  },
  {
    "country": "US",
    "name": "Sanatoga",
    "lat": "40.2451",
    "lng": "-75.59518"
  },
  {
    "country": "US",
    "name": "Sand Hill",
    "lat": "40.35954",
    "lng": "-76.43163"
  },
  {
    "country": "US",
    "name": "Sandy",
    "lat": "41.10784",
    "lng": "-78.77114"
  },
  {
    "country": "US",
    "name": "Saw Creek",
    "lat": "41.11259",
    "lng": "-75.05073"
  },
  {
    "country": "US",
    "name": "Saxonburg",
    "lat": "40.75395",
    "lng": "-79.81005"
  },
  {
    "country": "US",
    "name": "Saylorsburg",
    "lat": "40.89565",
    "lng": "-75.32352"
  },
  {
    "country": "US",
    "name": "Sayre",
    "lat": "41.97896",
    "lng": "-76.5155"
  },
  {
    "country": "US",
    "name": "Schlusser",
    "lat": "40.24175",
    "lng": "-77.17693"
  },
  {
    "country": "US",
    "name": "Schnecksville",
    "lat": "40.67514",
    "lng": "-75.62044"
  },
  {
    "country": "US",
    "name": "Schoeneck",
    "lat": "40.24148",
    "lng": "-76.17411"
  },
  {
    "country": "US",
    "name": "Schuylkill Haven",
    "lat": "40.63065",
    "lng": "-76.17105"
  },
  {
    "country": "US",
    "name": "Schwenksville",
    "lat": "40.25621",
    "lng": "-75.46379"
  },
  {
    "country": "US",
    "name": "Scottdale",
    "lat": "40.10035",
    "lng": "-79.58698"
  },
  {
    "country": "US",
    "name": "Scranton",
    "lat": "41.40916",
    "lng": "-75.6649"
  },
  {
    "country": "US",
    "name": "Selinsgrove",
    "lat": "40.79897",
    "lng": "-76.86219"
  },
  {
    "country": "US",
    "name": "Sellersville",
    "lat": "40.35399",
    "lng": "-75.3049"
  },
  {
    "country": "US",
    "name": "Seneca",
    "lat": "41.37867",
    "lng": "-79.70394"
  },
  {
    "country": "US",
    "name": "Seven Fields",
    "lat": "40.69173",
    "lng": "-80.06256"
  },
  {
    "country": "US",
    "name": "Sewickley",
    "lat": "40.53646",
    "lng": "-80.1845"
  },
  {
    "country": "US",
    "name": "Shamokin",
    "lat": "40.78897",
    "lng": "-76.55885"
  },
  {
    "country": "US",
    "name": "Shamokin Dam",
    "lat": "40.8487",
    "lng": "-76.81969"
  },
  {
    "country": "US",
    "name": "Sharon",
    "lat": "41.23311",
    "lng": "-80.4934"
  },
  {
    "country": "US",
    "name": "Sharpsburg",
    "lat": "40.49451",
    "lng": "-79.92644"
  },
  {
    "country": "US",
    "name": "Sharpsville",
    "lat": "41.25922",
    "lng": "-80.47201"
  },
  {
    "country": "US",
    "name": "Shavertown",
    "lat": "41.3198",
    "lng": "-75.93798"
  },
  {
    "country": "US",
    "name": "Sheffield",
    "lat": "41.70395",
    "lng": "-79.0356"
  },
  {
    "country": "US",
    "name": "Shenandoah",
    "lat": "40.82037",
    "lng": "-76.20077"
  },
  {
    "country": "US",
    "name": "Shenandoah Heights",
    "lat": "40.82759",
    "lng": "-76.20688"
  },
  {
    "country": "US",
    "name": "Shillington",
    "lat": "40.30787",
    "lng": "-75.96549"
  },
  {
    "country": "US",
    "name": "Shiloh",
    "lat": "41.04172",
    "lng": "-78.2914"
  },
  {
    "country": "US",
    "name": "Shinglehouse",
    "lat": "41.96368",
    "lng": "-78.19084"
  },
  {
    "country": "US",
    "name": "Shiremanstown",
    "lat": "40.22342",
    "lng": "-76.95359"
  },
  {
    "country": "US",
    "name": "Shippensburg",
    "lat": "40.05065",
    "lng": "-77.52026"
  },
  {
    "country": "US",
    "name": "Shoemakersville",
    "lat": "40.50093",
    "lng": "-75.96993"
  },
  {
    "country": "US",
    "name": "Simpson",
    "lat": "41.59175",
    "lng": "-75.48518"
  },
  {
    "country": "US",
    "name": "Sinking Spring",
    "lat": "40.32731",
    "lng": "-76.01105"
  },
  {
    "country": "US",
    "name": "Skippack",
    "lat": "40.22288",
    "lng": "-75.39879"
  },
  {
    "country": "US",
    "name": "Skyline View",
    "lat": "40.33926",
    "lng": "-76.72553"
  },
  {
    "country": "US",
    "name": "Slatington",
    "lat": "40.74843",
    "lng": "-75.61185"
  },
  {
    "country": "US",
    "name": "Slippery Rock",
    "lat": "41.06395",
    "lng": "-80.05645"
  },
  {
    "country": "US",
    "name": "Smethport",
    "lat": "41.81117",
    "lng": "-78.44474"
  },
  {
    "country": "US",
    "name": "Somerset",
    "lat": "40.00841",
    "lng": "-79.07808"
  },
  {
    "country": "US",
    "name": "Souderton",
    "lat": "40.31177",
    "lng": "-75.32518"
  },
  {
    "country": "US",
    "name": "South Greensburg",
    "lat": "40.2784",
    "lng": "-79.54476"
  },
  {
    "country": "US",
    "name": "South Pottstown",
    "lat": "40.23954",
    "lng": "-75.65102"
  },
  {
    "country": "US",
    "name": "South Temple",
    "lat": "40.4",
    "lng": "-75.9"
  },
  {
    "country": "US",
    "name": "South Waverly",
    "lat": "41.99757",
    "lng": "-76.53717"
  },
  {
    "country": "US",
    "name": "South Williamsport",
    "lat": "41.23202",
    "lng": "-76.99913"
  },
  {
    "country": "US",
    "name": "Southmont",
    "lat": "40.31063",
    "lng": "-78.93864"
  },
  {
    "country": "US",
    "name": "Southwest Greensburg",
    "lat": "40.29118",
    "lng": "-79.54698"
  },
  {
    "country": "US",
    "name": "Spangler",
    "lat": "40.64285",
    "lng": "-78.7728"
  },
  {
    "country": "US",
    "name": "Speers",
    "lat": "40.12452",
    "lng": "-79.87977"
  },
  {
    "country": "US",
    "name": "Spinnerstown",
    "lat": "40.43899",
    "lng": "-75.43712"
  },
  {
    "country": "US",
    "name": "Spring City",
    "lat": "40.17677",
    "lng": "-75.54769"
  },
  {
    "country": "US",
    "name": "Spring House",
    "lat": "40.18539",
    "lng": "-75.22768"
  },
  {
    "country": "US",
    "name": "Spring Mount",
    "lat": "40.27566",
    "lng": "-75.45657"
  },
  {
    "country": "US",
    "name": "Spring Ridge",
    "lat": "40.35287",
    "lng": "-75.98994"
  },
  {
    "country": "US",
    "name": "Springdale",
    "lat": "40.5409",
    "lng": "-79.78394"
  },
  {
    "country": "US",
    "name": "State College",
    "lat": "40.79339",
    "lng": "-77.86"
  },
  {
    "country": "US",
    "name": "Steelton",
    "lat": "40.23537",
    "lng": "-76.84136"
  },
  {
    "country": "US",
    "name": "Stiles",
    "lat": "40.66537",
    "lng": "-75.50824"
  },
  {
    "country": "US",
    "name": "Stoneboro",
    "lat": "41.33922",
    "lng": "-80.10506"
  },
  {
    "country": "US",
    "name": "Stony Creek Mills",
    "lat": "40.34565",
    "lng": "-75.86993"
  },
  {
    "country": "US",
    "name": "Stormstown",
    "lat": "40.79339",
    "lng": "-78.01667"
  },
  {
    "country": "US",
    "name": "Stowe",
    "lat": "40.2526",
    "lng": "-75.67741"
  },
  {
    "country": "US",
    "name": "Stroudsburg",
    "lat": "40.98676",
    "lng": "-75.19462"
  },
  {
    "country": "US",
    "name": "Sturgeon",
    "lat": "40.38479",
    "lng": "-80.21089"
  },
  {
    "country": "US",
    "name": "Sugarcreek",
    "lat": "41.42145",
    "lng": "-79.88117"
  },
  {
    "country": "US",
    "name": "Summit Hill",
    "lat": "40.82481",
    "lng": "-75.87103"
  },
  {
    "country": "US",
    "name": "Sun Valley",
    "lat": "40.98203",
    "lng": "-75.46602"
  },
  {
    "country": "US",
    "name": "Sun Valley",
    "lat": "41.0112",
    "lng": "-75.46963"
  },
  {
    "country": "US",
    "name": "Sunbury",
    "lat": "40.86259",
    "lng": "-76.79441"
  },
  {
    "country": "US",
    "name": "Sunrise Lake",
    "lat": "41.30981",
    "lng": "-74.96656"
  },
  {
    "country": "US",
    "name": "Susquehanna",
    "lat": "41.94341",
    "lng": "-75.59963"
  },
  {
    "country": "US",
    "name": "Swartzville",
    "lat": "40.23315",
    "lng": "-76.07828"
  },
  {
    "country": "US",
    "name": "Swissvale",
    "lat": "40.42368",
    "lng": "-79.88283"
  },
  {
    "country": "US",
    "name": "Swoyersville",
    "lat": "41.29175",
    "lng": "-75.87464"
  },
  {
    "country": "US",
    "name": "Sykesville",
    "lat": "41.05034",
    "lng": "-78.82225"
  },
  {
    "country": "US",
    "name": "Tacony",
    "lat": "40.03122",
    "lng": "-75.04434"
  },
  {
    "country": "US",
    "name": "Tamaqua",
    "lat": "40.79731",
    "lng": "-75.96937"
  },
  {
    "country": "US",
    "name": "Tannersville",
    "lat": "41.04009",
    "lng": "-75.30574"
  },
  {
    "country": "US",
    "name": "Tarentum",
    "lat": "40.60146",
    "lng": "-79.75977"
  },
  {
    "country": "US",
    "name": "Tatamy",
    "lat": "40.74093",
    "lng": "-75.25712"
  },
  {
    "country": "US",
    "name": "Taylor",
    "lat": "41.3948",
    "lng": "-75.70658"
  },
  {
    "country": "US",
    "name": "Telford",
    "lat": "40.32205",
    "lng": "-75.32795"
  },
  {
    "country": "US",
    "name": "Temple",
    "lat": "40.4087",
    "lng": "-75.9216"
  },
  {
    "country": "US",
    "name": "Terre Hill",
    "lat": "40.15732",
    "lng": "-76.0505"
  },
  {
    "country": "US",
    "name": "Thompsonville",
    "lat": "40.2909",
    "lng": "-80.10811"
  },
  {
    "country": "US",
    "name": "Throop",
    "lat": "41.45147",
    "lng": "-75.61185"
  },
  {
    "country": "US",
    "name": "Tinicum",
    "lat": "40.44844",
    "lng": "-75.10767"
  },
  {
    "country": "US",
    "name": "Tionesta",
    "lat": "41.49534",
    "lng": "-79.45588"
  },
  {
    "country": "US",
    "name": "Tipton",
    "lat": "40.6359",
    "lng": "-78.29585"
  },
  {
    "country": "US",
    "name": "Titusville",
    "lat": "41.627",
    "lng": "-79.67366"
  },
  {
    "country": "US",
    "name": "Topton",
    "lat": "40.50343",
    "lng": "-75.7013"
  },
  {
    "country": "US",
    "name": "Towamensing Trails",
    "lat": "41.00787",
    "lng": "-75.58463"
  },
  {
    "country": "US",
    "name": "Towanda",
    "lat": "41.76758",
    "lng": "-76.44272"
  },
  {
    "country": "US",
    "name": "Tower City",
    "lat": "40.58925",
    "lng": "-76.55246"
  },
  {
    "country": "US",
    "name": "Trafford",
    "lat": "40.38562",
    "lng": "-79.75893"
  },
  {
    "country": "US",
    "name": "Trappe",
    "lat": "40.19899",
    "lng": "-75.47629"
  },
  {
    "country": "US",
    "name": "Treasure Lake",
    "lat": "41.17339",
    "lng": "-78.71586"
  },
  {
    "country": "US",
    "name": "Tremont",
    "lat": "40.62842",
    "lng": "-76.38718"
  },
  {
    "country": "US",
    "name": "Trevorton",
    "lat": "40.7812",
    "lng": "-76.67302"
  },
  {
    "country": "US",
    "name": "Trevose",
    "lat": "40.13928",
    "lng": "-74.981"
  },
  {
    "country": "US",
    "name": "Trexlertown",
    "lat": "40.54815",
    "lng": "-75.60574"
  },
  {
    "country": "US",
    "name": "Trooper",
    "lat": "40.14983",
    "lng": "-75.40185"
  },
  {
    "country": "US",
    "name": "Troy",
    "lat": "41.78591",
    "lng": "-76.78801"
  },
  {
    "country": "US",
    "name": "Troy",
    "lat": "40.91506",
    "lng": "-78.2164"
  },
  {
    "country": "US",
    "name": "Trucksville",
    "lat": "41.30397",
    "lng": "-75.93214"
  },
  {
    "country": "US",
    "name": "Tullytown",
    "lat": "40.13928",
    "lng": "-74.81461"
  },
  {
    "country": "US",
    "name": "Tunkhannock",
    "lat": "41.53869",
    "lng": "-75.94659"
  },
  {
    "country": "US",
    "name": "Turtle Creek",
    "lat": "40.4059",
    "lng": "-79.82505"
  },
  {
    "country": "US",
    "name": "Tyrone",
    "lat": "40.67062",
    "lng": "-78.23862"
  },
  {
    "country": "US",
    "name": "Union City",
    "lat": "41.8995",
    "lng": "-79.84533"
  },
  {
    "country": "US",
    "name": "Upper Saint Clair",
    "lat": "40.3359",
    "lng": "-80.08339"
  },
  {
    "country": "US",
    "name": "Valley Green",
    "lat": "40.15731",
    "lng": "-76.79275"
  },
  {
    "country": "US",
    "name": "Valley View",
    "lat": "40.64592",
    "lng": "-76.53913"
  },
  {
    "country": "US",
    "name": "Vandergrift",
    "lat": "40.60284",
    "lng": "-79.56477"
  },
  {
    "country": "US",
    "name": "Verona",
    "lat": "40.50646",
    "lng": "-79.8431"
  },
  {
    "country": "US",
    "name": "Versailles",
    "lat": "40.31563",
    "lng": "-79.83116"
  },
  {
    "country": "US",
    "name": "Village Shires",
    "lat": "40.20316",
    "lng": "-74.97045"
  },
  {
    "country": "US",
    "name": "Vinco",
    "lat": "40.40507",
    "lng": "-78.85558"
  },
  {
    "country": "US",
    "name": "Walnutport",
    "lat": "40.75426",
    "lng": "-75.5988"
  },
  {
    "country": "US",
    "name": "Warminster Heights",
    "lat": "40.18705",
    "lng": "-75.08156"
  },
  {
    "country": "US",
    "name": "Warren",
    "lat": "41.84395",
    "lng": "-79.14504"
  },
  {
    "country": "US",
    "name": "Washington",
    "lat": "40.17396",
    "lng": "-80.24617"
  },
  {
    "country": "US",
    "name": "Waterford",
    "lat": "41.94283",
    "lng": "-79.9845"
  },
  {
    "country": "US",
    "name": "Waterford",
    "lat": "40.25452",
    "lng": "-79.16753"
  },
  {
    "country": "US",
    "name": "Watsontown",
    "lat": "41.08453",
    "lng": "-76.86385"
  },
  {
    "country": "US",
    "name": "Waymart",
    "lat": "41.58036",
    "lng": "-75.40824"
  },
  {
    "country": "US",
    "name": "Wayne",
    "lat": "40.044",
    "lng": "-75.38769"
  },
  {
    "country": "US",
    "name": "Weatherly",
    "lat": "40.94175",
    "lng": "-75.82964"
  },
  {
    "country": "US",
    "name": "Wellsboro",
    "lat": "41.74868",
    "lng": "-77.30053"
  },
  {
    "country": "US",
    "name": "Wernersville",
    "lat": "40.33009",
    "lng": "-76.0805"
  },
  {
    "country": "US",
    "name": "Wescosville",
    "lat": "40.56676",
    "lng": "-75.55296"
  },
  {
    "country": "US",
    "name": "Wesleyville",
    "lat": "42.14033",
    "lng": "-80.01506"
  },
  {
    "country": "US",
    "name": "West Conshohocken",
    "lat": "40.06983",
    "lng": "-75.3163"
  },
  {
    "country": "US",
    "name": "West Easton",
    "lat": "40.67871",
    "lng": "-75.23684"
  },
  {
    "country": "US",
    "name": "West Fairview",
    "lat": "40.27509",
    "lng": "-76.91553"
  },
  {
    "country": "US",
    "name": "West Hamburg",
    "lat": "40.54759",
    "lng": "-76.00216"
  },
  {
    "country": "US",
    "name": "West Hazleton",
    "lat": "40.9587",
    "lng": "-75.99604"
  },
  {
    "country": "US",
    "name": "West Hills",
    "lat": "40.82423",
    "lng": "-79.5431"
  },
  {
    "country": "US",
    "name": "West Homestead",
    "lat": "40.39396",
    "lng": "-79.91199"
  },
  {
    "country": "US",
    "name": "West Kittanning",
    "lat": "40.81034",
    "lng": "-79.52949"
  },
  {
    "country": "US",
    "name": "West Lawn",
    "lat": "40.32981",
    "lng": "-75.99438"
  },
  {
    "country": "US",
    "name": "West Leechburg",
    "lat": "40.62229",
    "lng": "-79.61282"
  },
  {
    "country": "US",
    "name": "West Mayfield",
    "lat": "40.78006",
    "lng": "-80.3384"
  },
  {
    "country": "US",
    "name": "West Mifflin",
    "lat": "40.3634",
    "lng": "-79.86644"
  },
  {
    "country": "US",
    "name": "West Newton",
    "lat": "40.20979",
    "lng": "-79.76699"
  },
  {
    "country": "US",
    "name": "West Norriton",
    "lat": "40.12955",
    "lng": "-75.37852"
  },
  {
    "country": "US",
    "name": "West Pittston",
    "lat": "41.32758",
    "lng": "-75.79297"
  },
  {
    "country": "US",
    "name": "West Reading",
    "lat": "40.3337",
    "lng": "-75.94743"
  },
  {
    "country": "US",
    "name": "West View",
    "lat": "40.52229",
    "lng": "-80.03422"
  },
  {
    "country": "US",
    "name": "West Wyoming",
    "lat": "41.3198",
    "lng": "-75.84603"
  },
  {
    "country": "US",
    "name": "West Wyomissing",
    "lat": "40.32454",
    "lng": "-75.99077"
  },
  {
    "country": "US",
    "name": "Westfield",
    "lat": "41.91924",
    "lng": "-77.53887"
  },
  {
    "country": "US",
    "name": "Westmont",
    "lat": "40.31563",
    "lng": "-78.95169"
  },
  {
    "country": "US",
    "name": "Whitaker",
    "lat": "40.3984",
    "lng": "-79.88977"
  },
  {
    "country": "US",
    "name": "White Haven",
    "lat": "41.06064",
    "lng": "-75.77408"
  },
  {
    "country": "US",
    "name": "White Oak",
    "lat": "40.33757",
    "lng": "-79.80921"
  },
  {
    "country": "US",
    "name": "Whitehall",
    "lat": "40.36118",
    "lng": "-79.99089"
  },
  {
    "country": "US",
    "name": "Whitehall Township",
    "lat": "40.66676",
    "lng": "-75.49991"
  },
  {
    "country": "US",
    "name": "Whitfield",
    "lat": "40.33593",
    "lng": "-76.00605"
  },
  {
    "country": "US",
    "name": "Wilkes-Barre",
    "lat": "41.24591",
    "lng": "-75.88131"
  },
  {
    "country": "US",
    "name": "Wilkinsburg",
    "lat": "40.44174",
    "lng": "-79.88199"
  },
  {
    "country": "US",
    "name": "Williamsburg",
    "lat": "40.46202",
    "lng": "-78.19973"
  },
  {
    "country": "US",
    "name": "Williamsport",
    "lat": "41.24119",
    "lng": "-77.00108"
  },
  {
    "country": "US",
    "name": "Williamstown",
    "lat": "40.58009",
    "lng": "-76.61774"
  },
  {
    "country": "US",
    "name": "Willow Grove",
    "lat": "40.144",
    "lng": "-75.11573"
  },
  {
    "country": "US",
    "name": "Wilmerding",
    "lat": "40.3909",
    "lng": "-79.81005"
  },
  {
    "country": "US",
    "name": "Wilson",
    "lat": "40.31007",
    "lng": "-79.89144"
  },
  {
    "country": "US",
    "name": "Wilson",
    "lat": "40.68399",
    "lng": "-75.24184"
  },
  {
    "country": "US",
    "name": "Wind Gap",
    "lat": "40.84815",
    "lng": "-75.29157"
  },
  {
    "country": "US",
    "name": "Windber",
    "lat": "40.2398",
    "lng": "-78.83502"
  },
  {
    "country": "US",
    "name": "Wolfdale",
    "lat": "40.19285",
    "lng": "-80.28784"
  },
  {
    "country": "US",
    "name": "Womelsdorf",
    "lat": "40.36176",
    "lng": "-76.18411"
  },
  {
    "country": "US",
    "name": "Woodbourne",
    "lat": "40.19233",
    "lng": "-74.88878"
  },
  {
    "country": "US",
    "name": "Woodland Heights",
    "lat": "41.40978",
    "lng": "-79.71172"
  },
  {
    "country": "US",
    "name": "Woodside",
    "lat": "40.22178",
    "lng": "-74.87544"
  },
  {
    "country": "US",
    "name": "Wormleysburg",
    "lat": "40.26287",
    "lng": "-76.91386"
  },
  {
    "country": "US",
    "name": "Woxall",
    "lat": "40.31066",
    "lng": "-75.44879"
  },
  {
    "country": "US",
    "name": "Wrightsville",
    "lat": "40.02565",
    "lng": "-76.52997"
  },
  {
    "country": "US",
    "name": "Wyncote",
    "lat": "40.09455",
    "lng": "-75.14879"
  },
  {
    "country": "US",
    "name": "Wyndmoor",
    "lat": "40.08122",
    "lng": "-75.18934"
  },
  {
    "country": "US",
    "name": "Wyoming",
    "lat": "41.31175",
    "lng": "-75.83742"
  },
  {
    "country": "US",
    "name": "Wyomissing",
    "lat": "40.32954",
    "lng": "-75.96521"
  },
  {
    "country": "US",
    "name": "Wyomissing Hills",
    "lat": "40.33759",
    "lng": "-75.97966"
  },
  {
    "country": "US",
    "name": "Yardley",
    "lat": "40.24566",
    "lng": "-74.846"
  },
  {
    "country": "US",
    "name": "Yeagertown",
    "lat": "40.64313",
    "lng": "-77.58055"
  },
  {
    "country": "US",
    "name": "Youngsville",
    "lat": "40.78121",
    "lng": "-75.47685"
  },
  {
    "country": "US",
    "name": "Youngsville",
    "lat": "41.85228",
    "lng": "-79.31866"
  },
  {
    "country": "US",
    "name": "Youngwood",
    "lat": "40.24035",
    "lng": "-79.57671"
  },
  {
    "country": "US",
    "name": "Zelienople",
    "lat": "40.79451",
    "lng": "-80.13673"
  },
  {
    "country": "US",
    "name": "Zion",
    "lat": "40.91423",
    "lng": "-77.68472"
  },
  {
    "country": "US",
    "name": "Ashaway",
    "lat": "41.42343",
    "lng": "-71.78562"
  },
  {
    "country": "US",
    "name": "Barrington",
    "lat": "41.74066",
    "lng": "-71.30866"
  },
  {
    "country": "US",
    "name": "Bradford",
    "lat": "41.39899",
    "lng": "-71.73701"
  },
  {
    "country": "US",
    "name": "Bristol",
    "lat": "41.67705",
    "lng": "-71.26616"
  },
  {
    "country": "US",
    "name": "Central Falls",
    "lat": "41.89066",
    "lng": "-71.39228"
  },
  {
    "country": "US",
    "name": "Charlestown",
    "lat": "41.38316",
    "lng": "-71.64173"
  },
  {
    "country": "US",
    "name": "Chepachet",
    "lat": "41.9151",
    "lng": "-71.67146"
  },
  {
    "country": "US",
    "name": "Coventry",
    "lat": "41.7001",
    "lng": "-71.68284"
  },
  {
    "country": "US",
    "name": "Cranston",
    "lat": "41.77982",
    "lng": "-71.43728"
  },
  {
    "country": "US",
    "name": "Cumberland",
    "lat": "41.96677",
    "lng": "-71.43284"
  },
  {
    "country": "US",
    "name": "Cumberland Hill",
    "lat": "41.97454",
    "lng": "-71.467"
  },
  {
    "country": "US",
    "name": "East Greenwich",
    "lat": "41.66038",
    "lng": "-71.45589"
  },
  {
    "country": "US",
    "name": "East Providence",
    "lat": "41.81371",
    "lng": "-71.37005"
  },
  {
    "country": "US",
    "name": "Exeter",
    "lat": "41.5776",
    "lng": "-71.53756"
  },
  {
    "country": "US",
    "name": "Foster",
    "lat": "41.85371",
    "lng": "-71.75812"
  },
  {
    "country": "US",
    "name": "Greenville",
    "lat": "41.87121",
    "lng": "-71.55201"
  },
  {
    "country": "US",
    "name": "Harrisville",
    "lat": "41.96565",
    "lng": "-71.67451"
  },
  {
    "country": "US",
    "name": "Hope Valley",
    "lat": "41.5076",
    "lng": "-71.71618"
  },
  {
    "country": "US",
    "name": "Hopkinton",
    "lat": "41.46121",
    "lng": "-71.77757"
  },
  {
    "country": "US",
    "name": "Jamestown",
    "lat": "41.49705",
    "lng": "-71.36728"
  },
  {
    "country": "US",
    "name": "Kingston",
    "lat": "41.48038",
    "lng": "-71.52256"
  },
  {
    "country": "US",
    "name": "Melville",
    "lat": "41.58705",
    "lng": "-71.28338"
  },
  {
    "country": "US",
    "name": "Middletown",
    "lat": "41.54566",
    "lng": "-71.29144"
  },
  {
    "country": "US",
    "name": "Narragansett",
    "lat": "41.4501",
    "lng": "-71.4495"
  },
  {
    "country": "US",
    "name": "Narragansett Pier",
    "lat": "41.43232",
    "lng": "-71.45644"
  },
  {
    "country": "US",
    "name": "New Shoreham",
    "lat": "41.17233",
    "lng": "-71.55783"
  },
  {
    "country": "US",
    "name": "Newport",
    "lat": "41.4901",
    "lng": "-71.31283"
  },
  {
    "country": "US",
    "name": "North Kingstown",
    "lat": "41.5501",
    "lng": "-71.46617"
  },
  {
    "country": "US",
    "name": "North Providence",
    "lat": "41.8501",
    "lng": "-71.46617"
  },
  {
    "country": "US",
    "name": "North Scituate",
    "lat": "41.83177",
    "lng": "-71.58729"
  },
  {
    "country": "US",
    "name": "North Smithfield",
    "lat": "41.96677",
    "lng": "-71.54951"
  },
  {
    "country": "US",
    "name": "Pascoag",
    "lat": "41.95565",
    "lng": "-71.70229"
  },
  {
    "country": "US",
    "name": "Pawtucket",
    "lat": "41.87871",
    "lng": "-71.38256"
  },
  {
    "country": "US",
    "name": "Portsmouth",
    "lat": "41.60232",
    "lng": "-71.25033"
  },
  {
    "country": "US",
    "name": "Providence",
    "lat": "41.82399",
    "lng": "-71.41283"
  },
  {
    "country": "US",
    "name": "Smithfield",
    "lat": "41.92204",
    "lng": "-71.54951"
  },
  {
    "country": "US",
    "name": "Tiverton",
    "lat": "41.62594",
    "lng": "-71.21338"
  },
  {
    "country": "US",
    "name": "Valley Falls",
    "lat": "41.90677",
    "lng": "-71.39061"
  },
  {
    "country": "US",
    "name": "Warren",
    "lat": "41.73038",
    "lng": "-71.28255"
  },
  {
    "country": "US",
    "name": "Warwick",
    "lat": "41.7001",
    "lng": "-71.41617"
  },
  {
    "country": "US",
    "name": "West Warwick",
    "lat": "41.69689",
    "lng": "-71.52194"
  },
  {
    "country": "US",
    "name": "Westerly",
    "lat": "41.3776",
    "lng": "-71.82729"
  },
  {
    "country": "US",
    "name": "Woonsocket",
    "lat": "42.00288",
    "lng": "-71.51478"
  },
  {
    "country": "US",
    "name": "Aberdeen",
    "lat": "45.4647",
    "lng": "-98.48648"
  },
  {
    "country": "US",
    "name": "Alexandria",
    "lat": "43.65359",
    "lng": "-97.78285"
  },
  {
    "country": "US",
    "name": "Armour",
    "lat": "43.3186",
    "lng": "-98.34675"
  },
  {
    "country": "US",
    "name": "Baltic",
    "lat": "43.76136",
    "lng": "-96.74033"
  },
  {
    "country": "US",
    "name": "Beresford",
    "lat": "43.08054",
    "lng": "-96.77366"
  },
  {
    "country": "US",
    "name": "Brandon",
    "lat": "43.5947",
    "lng": "-96.57199"
  },
  {
    "country": "US",
    "name": "Britton",
    "lat": "45.79162",
    "lng": "-97.75094"
  },
  {
    "country": "US",
    "name": "Brookings",
    "lat": "44.31136",
    "lng": "-96.79839"
  },
  {
    "country": "US",
    "name": "Burke",
    "lat": "43.1825",
    "lng": "-99.29205"
  },
  {
    "country": "US",
    "name": "Canton",
    "lat": "43.30081",
    "lng": "-96.59282"
  },
  {
    "country": "US",
    "name": "Chamberlain",
    "lat": "43.81083",
    "lng": "-99.33066"
  },
  {
    "country": "US",
    "name": "Clark",
    "lat": "44.87774",
    "lng": "-97.73314"
  },
  {
    "country": "US",
    "name": "Clear Lake",
    "lat": "44.7458",
    "lng": "-96.68256"
  },
  {
    "country": "US",
    "name": "Crooks",
    "lat": "43.6647",
    "lng": "-96.81089"
  },
  {
    "country": "US",
    "name": "Dakota Dunes",
    "lat": "42.48749",
    "lng": "-96.48642"
  },
  {
    "country": "US",
    "name": "De Smet",
    "lat": "44.38747",
    "lng": "-97.55035"
  },
  {
    "country": "US",
    "name": "Dell Rapids",
    "lat": "43.82608",
    "lng": "-96.70616"
  },
  {
    "country": "US",
    "name": "Elk Point",
    "lat": "42.68333",
    "lng": "-96.68365"
  },
  {
    "country": "US",
    "name": "Faulkton",
    "lat": "45.03497",
    "lng": "-99.124"
  },
  {
    "country": "US",
    "name": "Flandreau",
    "lat": "44.04942",
    "lng": "-96.59532"
  },
  {
    "country": "US",
    "name": "Fort Thompson",
    "lat": "44.0686",
    "lng": "-99.43788"
  },
  {
    "country": "US",
    "name": "Freeman",
    "lat": "43.35249",
    "lng": "-97.43729"
  },
  {
    "country": "US",
    "name": "Garretson",
    "lat": "43.71747",
    "lng": "-96.50282"
  },
  {
    "country": "US",
    "name": "Gettysburg",
    "lat": "45.01165",
    "lng": "-99.95567"
  },
  {
    "country": "US",
    "name": "Gregory",
    "lat": "43.23222",
    "lng": "-99.43038"
  },
  {
    "country": "US",
    "name": "Groton",
    "lat": "45.44746",
    "lng": "-98.09871"
  },
  {
    "country": "US",
    "name": "Harrisburg",
    "lat": "43.43137",
    "lng": "-96.69727"
  },
  {
    "country": "US",
    "name": "Hartford",
    "lat": "43.62303",
    "lng": "-96.94255"
  },
  {
    "country": "US",
    "name": "Highmore",
    "lat": "44.52137",
    "lng": "-99.4415"
  },
  {
    "country": "US",
    "name": "Howard",
    "lat": "44.01081",
    "lng": "-97.52674"
  },
  {
    "country": "US",
    "name": "Huron",
    "lat": "44.36332",
    "lng": "-98.21426"
  },
  {
    "country": "US",
    "name": "Ipswich",
    "lat": "45.44442",
    "lng": "-99.02928"
  },
  {
    "country": "US",
    "name": "Kennebec",
    "lat": "43.9036",
    "lng": "-99.86178"
  },
  {
    "country": "US",
    "name": "Lake Andes",
    "lat": "43.15638",
    "lng": "-98.54147"
  },
  {
    "country": "US",
    "name": "Lennox",
    "lat": "43.35415",
    "lng": "-96.892"
  },
  {
    "country": "US",
    "name": "Leola",
    "lat": "45.72275",
    "lng": "-98.94094"
  },
  {
    "country": "US",
    "name": "Madison",
    "lat": "44.00608",
    "lng": "-97.11395"
  },
  {
    "country": "US",
    "name": "Milbank",
    "lat": "45.21913",
    "lng": "-96.63562"
  },
  {
    "country": "US",
    "name": "Miller",
    "lat": "44.51831",
    "lng": "-98.98843"
  },
  {
    "country": "US",
    "name": "Mitchell",
    "lat": "43.70943",
    "lng": "-98.0298"
  },
  {
    "country": "US",
    "name": "North Sioux City",
    "lat": "42.52722",
    "lng": "-96.48309"
  },
  {
    "country": "US",
    "name": "Olivet",
    "lat": "43.24082",
    "lng": "-97.67534"
  },
  {
    "country": "US",
    "name": "Parker",
    "lat": "43.39748",
    "lng": "-97.13645"
  },
  {
    "country": "US",
    "name": "Parkston",
    "lat": "43.39888",
    "lng": "-97.98368"
  },
  {
    "country": "US",
    "name": "Plankinton",
    "lat": "43.71555",
    "lng": "-98.48509"
  },
  {
    "country": "US",
    "name": "Platte",
    "lat": "43.38694",
    "lng": "-98.84453"
  },
  {
    "country": "US",
    "name": "Redfield",
    "lat": "44.87581",
    "lng": "-98.51871"
  },
  {
    "country": "US",
    "name": "Salem",
    "lat": "43.72415",
    "lng": "-97.38895"
  },
  {
    "country": "US",
    "name": "Sioux Falls",
    "lat": "43.54997",
    "lng": "-96.70033"
  },
  {
    "country": "US",
    "name": "Sisseton",
    "lat": "45.66468",
    "lng": "-97.0498"
  },
  {
    "country": "US",
    "name": "Springfield",
    "lat": "42.85417",
    "lng": "-97.89729"
  },
  {
    "country": "US",
    "name": "Tea",
    "lat": "43.44637",
    "lng": "-96.83588"
  },
  {
    "country": "US",
    "name": "Tyndall",
    "lat": "42.99333",
    "lng": "-97.86285"
  },
  {
    "country": "US",
    "name": "Vermillion",
    "lat": "42.77944",
    "lng": "-96.92921"
  },
  {
    "country": "US",
    "name": "Volga",
    "lat": "44.32358",
    "lng": "-96.92645"
  },
  {
    "country": "US",
    "name": "Wagner",
    "lat": "43.07972",
    "lng": "-98.29313"
  },
  {
    "country": "US",
    "name": "Watertown",
    "lat": "44.89941",
    "lng": "-97.11507"
  },
  {
    "country": "US",
    "name": "Webster",
    "lat": "45.33218",
    "lng": "-97.52009"
  },
  {
    "country": "US",
    "name": "Wessington Springs",
    "lat": "44.07916",
    "lng": "-98.56954"
  },
  {
    "country": "US",
    "name": "Winner",
    "lat": "43.37667",
    "lng": "-99.85901"
  },
  {
    "country": "US",
    "name": "Woonsocket",
    "lat": "44.0536",
    "lng": "-98.27564"
  },
  {
    "country": "US",
    "name": "Yankton",
    "lat": "42.87111",
    "lng": "-97.39728"
  },
  {
    "country": "US",
    "name": "Addison",
    "lat": "44.08867",
    "lng": "-73.30262"
  },
  {
    "country": "US",
    "name": "Arlington",
    "lat": "43.0748",
    "lng": "-73.154"
  },
  {
    "country": "US",
    "name": "Barre",
    "lat": "44.19701",
    "lng": "-72.50205"
  },
  {
    "country": "US",
    "name": "Bellows Falls",
    "lat": "43.13341",
    "lng": "-72.44398"
  },
  {
    "country": "US",
    "name": "Bennington",
    "lat": "42.87813",
    "lng": "-73.19677"
  },
  {
    "country": "US",
    "name": "Bridport",
    "lat": "43.98506",
    "lng": "-73.31262"
  },
  {
    "country": "US",
    "name": "Brandon",
    "lat": "43.79812",
    "lng": "-73.08761"
  },
  {
    "country": "US",
    "name": "Brattleboro",
    "lat": "42.85092",
    "lng": "-72.55787"
  },
  {
    "country": "US",
    "name": "Bristol",
    "lat": "44.13339",
    "lng": "-73.07901"
  },
  {
    "country": "US",
    "name": "Burlington",
    "lat": "44.47588",
    "lng": "-73.21207"
  },
  {
    "country": "US",
    "name": "Charlotte",
    "lat": "44.30977",
    "lng": "-73.26096"
  },
  {
    "country": "US",
    "name": "Chelsea",
    "lat": "43.98979",
    "lng": "-72.4476"
  },
  {
    "country": "US",
    "name": "Chester",
    "lat": "43.26285",
    "lng": "-72.59509"
  },
  {
    "country": "US",
    "name": "Chittenden",
    "lat": "43.70784",
    "lng": "-72.94816"
  },
  {
    "country": "US",
    "name": "Clarendon",
    "lat": "43.51618",
    "lng": "-72.96983"
  },
  {
    "country": "US",
    "name": "Colchester",
    "lat": "44.54394",
    "lng": "-73.14791"
  },
  {
    "country": "US",
    "name": "Danby",
    "lat": "43.34618",
    "lng": "-72.99538"
  },
  {
    "country": "US",
    "name": "Dover",
    "lat": "42.94369",
    "lng": "-72.80399"
  },
  {
    "country": "US",
    "name": "Enosburg Falls",
    "lat": "44.90699",
    "lng": "-72.80652"
  },
  {
    "country": "US",
    "name": "Essex Junction",
    "lat": "44.49061",
    "lng": "-73.11096"
  },
  {
    "country": "US",
    "name": "Fair Haven",
    "lat": "43.59479",
    "lng": "-73.26567"
  },
  {
    "country": "US",
    "name": "Ferrisburgh",
    "lat": "44.20561",
    "lng": "-73.24623"
  },
  {
    "country": "US",
    "name": "Guildhall",
    "lat": "44.56506",
    "lng": "-71.55981"
  },
  {
    "country": "US",
    "name": "Hardwick",
    "lat": "44.50478",
    "lng": "-72.36816"
  },
  {
    "country": "US",
    "name": "Hartford",
    "lat": "43.66063",
    "lng": "-72.33842"
  },
  {
    "country": "US",
    "name": "Hinesburg",
    "lat": "44.32922",
    "lng": "-73.11068"
  },
  {
    "country": "US",
    "name": "Hyde Park",
    "lat": "44.59394",
    "lng": "-72.61651"
  },
  {
    "country": "US",
    "name": "Jamaica",
    "lat": "43.10036",
    "lng": "-72.77843"
  },
  {
    "country": "US",
    "name": "Jericho",
    "lat": "44.50394",
    "lng": "-72.99763"
  },
  {
    "country": "US",
    "name": "Johnson",
    "lat": "44.63561",
    "lng": "-72.6804"
  },
  {
    "country": "US",
    "name": "Leicester",
    "lat": "43.86673",
    "lng": "-73.10789"
  },
  {
    "country": "US",
    "name": "Lincoln",
    "lat": "44.10589",
    "lng": "-72.99706"
  },
  {
    "country": "US",
    "name": "Londonderry",
    "lat": "43.22646",
    "lng": "-72.80649"
  },
  {
    "country": "US",
    "name": "Lunenburg",
    "lat": "44.46311",
    "lng": "-71.68203"
  },
  {
    "country": "US",
    "name": "Lyndon",
    "lat": "44.51422",
    "lng": "-72.01093"
  },
  {
    "country": "US",
    "name": "Lyndonville",
    "lat": "44.53367",
    "lng": "-72.00315"
  },
  {
    "country": "US",
    "name": "Manchester Center",
    "lat": "43.17702",
    "lng": "-73.05705"
  },
  {
    "country": "US",
    "name": "Mendon",
    "lat": "43.65198",
    "lng": "-72.9278"
  },
  {
    "country": "US",
    "name": "Middlebury (village)",
    "lat": "44.01553",
    "lng": "-73.16937"
  },
  {
    "country": "US",
    "name": "Milton",
    "lat": "44.63977",
    "lng": "-73.11041"
  },
  {
    "country": "US",
    "name": "Montgomery",
    "lat": "44.90255",
    "lng": "-72.63818"
  },
  {
    "country": "US",
    "name": "Montpelier",
    "lat": "44.26006",
    "lng": "-72.57539"
  },
  {
    "country": "US",
    "name": "Moretown",
    "lat": "44.25089",
    "lng": "-72.76095"
  },
  {
    "country": "US",
    "name": "Morristown",
    "lat": "44.55727",
    "lng": "-72.62373"
  },
  {
    "country": "US",
    "name": "Morrisville",
    "lat": "44.56172",
    "lng": "-72.59845"
  },
  {
    "country": "US",
    "name": "Mount Holly",
    "lat": "43.45229",
    "lng": "-72.82482"
  },
  {
    "country": "US",
    "name": "Newport",
    "lat": "44.93644",
    "lng": "-72.2051"
  },
  {
    "country": "US",
    "name": "Newfane",
    "lat": "42.98564",
    "lng": "-72.65593"
  },
  {
    "country": "US",
    "name": "North Bennington",
    "lat": "42.93036",
    "lng": "-73.24261"
  },
  {
    "country": "US",
    "name": "North Hero",
    "lat": "44.83125",
    "lng": "-73.27323"
  },
  {
    "country": "US",
    "name": "Northfield",
    "lat": "44.15117",
    "lng": "-72.6565"
  },
  {
    "country": "US",
    "name": "Pawlet",
    "lat": "43.34674",
    "lng": "-73.17622"
  },
  {
    "country": "US",
    "name": "Poultney",
    "lat": "43.51701",
    "lng": "-73.23622"
  },
  {
    "country": "US",
    "name": "Pownal",
    "lat": "42.76564",
    "lng": "-73.23594"
  },
  {
    "country": "US",
    "name": "Randolph",
    "lat": "43.92507",
    "lng": "-72.66594"
  },
  {
    "country": "US",
    "name": "Richford",
    "lat": "44.99699",
    "lng": "-72.67124"
  },
  {
    "country": "US",
    "name": "Rockingham",
    "lat": "43.18758",
    "lng": "-72.48898"
  },
  {
    "country": "US",
    "name": "Rutland",
    "lat": "43.61062",
    "lng": "-72.97261"
  },
  {
    "country": "US",
    "name": "Saint Albans",
    "lat": "44.81088",
    "lng": "-73.08319"
  },
  {
    "country": "US",
    "name": "Saint Johnsbury",
    "lat": "44.41922",
    "lng": "-72.01509"
  },
  {
    "country": "US",
    "name": "Salisbury",
    "lat": "43.89645",
    "lng": "-73.09984"
  },
  {
    "country": "US",
    "name": "South Barre",
    "lat": "44.17701",
    "lng": "-72.50566"
  },
  {
    "country": "US",
    "name": "South Burlington",
    "lat": "44.46699",
    "lng": "-73.17096"
  },
  {
    "country": "US",
    "name": "Springfield",
    "lat": "43.29841",
    "lng": "-72.48231"
  },
  {
    "country": "US",
    "name": "Starksboro",
    "lat": "44.22728",
    "lng": "-73.05734"
  },
  {
    "country": "US",
    "name": "Stowe",
    "lat": "44.46533",
    "lng": "-72.68456"
  },
  {
    "country": "US",
    "name": "Swanton",
    "lat": "44.9181",
    "lng": "-73.1243"
  },
  {
    "country": "US",
    "name": "Townshend",
    "lat": "43.0473",
    "lng": "-72.66759"
  },
  {
    "country": "US",
    "name": "Vergennes",
    "lat": "44.16728",
    "lng": "-73.25401"
  },
  {
    "country": "US",
    "name": "Washington",
    "lat": "44.10562",
    "lng": "-72.4326"
  },
  {
    "country": "US",
    "name": "Waterbury",
    "lat": "44.33783",
    "lng": "-72.75623"
  },
  {
    "country": "US",
    "name": "West Brattleboro",
    "lat": "42.85592",
    "lng": "-72.60315"
  },
  {
    "country": "US",
    "name": "West Rutland",
    "lat": "43.59312",
    "lng": "-73.04511"
  },
  {
    "country": "US",
    "name": "White River Junction",
    "lat": "43.64896",
    "lng": "-72.31926"
  },
  {
    "country": "US",
    "name": "Wilder",
    "lat": "43.67285",
    "lng": "-72.3087"
  },
  {
    "country": "US",
    "name": "Williamstown",
    "lat": "44.12173",
    "lng": "-72.54149"
  },
  {
    "country": "US",
    "name": "Williston",
    "lat": "44.43755",
    "lng": "-73.06818"
  },
  {
    "country": "US",
    "name": "Windsor",
    "lat": "43.48035",
    "lng": "-72.38481"
  },
  {
    "country": "US",
    "name": "Winooski",
    "lat": "44.49144",
    "lng": "-73.18568"
  },
  {
    "country": "US",
    "name": "Woodstock",
    "lat": "43.62424",
    "lng": "-72.51843"
  },
  {
    "country": "US",
    "name": "Abbotsford",
    "lat": "44.94636",
    "lng": "-90.31597"
  },
  {
    "country": "US",
    "name": "Adams",
    "lat": "43.95608",
    "lng": "-89.81818"
  },
  {
    "country": "US",
    "name": "Addison",
    "lat": "43.42278",
    "lng": "-88.37454"
  },
  {
    "country": "US",
    "name": "Albany",
    "lat": "42.70778",
    "lng": "-89.43706"
  },
  {
    "country": "US",
    "name": "Algoma",
    "lat": "44.60889",
    "lng": "-87.43259"
  },
  {
    "country": "US",
    "name": "Allouez",
    "lat": "44.47749",
    "lng": "-88.01621"
  },
  {
    "country": "US",
    "name": "Alma",
    "lat": "44.31997",
    "lng": "-91.91488"
  },
  {
    "country": "US",
    "name": "Alto",
    "lat": "43.67665",
    "lng": "-88.79511"
  },
  {
    "country": "US",
    "name": "Altoona",
    "lat": "44.80468",
    "lng": "-91.44321"
  },
  {
    "country": "US",
    "name": "Amery",
    "lat": "45.30691",
    "lng": "-92.36214"
  },
  {
    "country": "US",
    "name": "Amherst",
    "lat": "44.45081",
    "lng": "-89.28484"
  },
  {
    "country": "US",
    "name": "Antigo",
    "lat": "45.14025",
    "lng": "-89.15234"
  },
  {
    "country": "US",
    "name": "Appleton",
    "lat": "44.26193",
    "lng": "-88.41538"
  },
  {
    "country": "US",
    "name": "Arcadia",
    "lat": "44.25274",
    "lng": "-91.50154"
  },
  {
    "country": "US",
    "name": "Ashford",
    "lat": "43.58694",
    "lng": "-88.37066"
  },
  {
    "country": "US",
    "name": "Ashland",
    "lat": "46.59244",
    "lng": "-90.8838"
  },
  {
    "country": "US",
    "name": "Ashwaubenon",
    "lat": "44.48221",
    "lng": "-88.0701"
  },
  {
    "country": "US",
    "name": "Athens",
    "lat": "45.03302",
    "lng": "-90.07402"
  },
  {
    "country": "US",
    "name": "Augusta",
    "lat": "44.68024",
    "lng": "-91.11988"
  },
  {
    "country": "US",
    "name": "Aztalan",
    "lat": "43.07278",
    "lng": "-88.86233"
  },
  {
    "country": "US",
    "name": "Baldwin",
    "lat": "44.96663",
    "lng": "-92.37436"
  },
  {
    "country": "US",
    "name": "Balsam Lake",
    "lat": "45.45218",
    "lng": "-92.45464"
  },
  {
    "country": "US",
    "name": "Bangor",
    "lat": "43.89302",
    "lng": "-90.99041"
  },
  {
    "country": "US",
    "name": "Baraboo",
    "lat": "43.47109",
    "lng": "-89.74429"
  },
  {
    "country": "US",
    "name": "Barneveld",
    "lat": "43.01555",
    "lng": "-89.8954"
  },
  {
    "country": "US",
    "name": "Barron",
    "lat": "45.40135",
    "lng": "-91.84906"
  },
  {
    "country": "US",
    "name": "Barton",
    "lat": "43.44361",
    "lng": "-88.18065"
  },
  {
    "country": "US",
    "name": "Bayside",
    "lat": "43.18056",
    "lng": "-87.90064"
  },
  {
    "country": "US",
    "name": "Beaver Dam",
    "lat": "43.45777",
    "lng": "-88.83733"
  },
  {
    "country": "US",
    "name": "Belgium",
    "lat": "43.49972",
    "lng": "-87.85037"
  },
  {
    "country": "US",
    "name": "Belle Plaine",
    "lat": "44.71526",
    "lng": "-88.66621"
  },
  {
    "country": "US",
    "name": "Belleville",
    "lat": "42.85972",
    "lng": "-89.53818"
  },
  {
    "country": "US",
    "name": "Bellevue",
    "lat": "44.44416",
    "lng": "-87.9201"
  },
  {
    "country": "US",
    "name": "Beloit",
    "lat": "42.50835",
    "lng": "-89.03178"
  },
  {
    "country": "US",
    "name": "Berlin",
    "lat": "43.96804",
    "lng": "-88.94345"
  },
  {
    "country": "US",
    "name": "Bevent",
    "lat": "44.77053",
    "lng": "-89.38956"
  },
  {
    "country": "US",
    "name": "Big Bend",
    "lat": "42.8814",
    "lng": "-88.20676"
  },
  {
    "country": "US",
    "name": "Black Creek",
    "lat": "44.47749",
    "lng": "-88.45066"
  },
  {
    "country": "US",
    "name": "Black Earth",
    "lat": "43.13722",
    "lng": "-89.74679"
  },
  {
    "country": "US",
    "name": "Black River Falls",
    "lat": "44.29468",
    "lng": "-90.85153"
  },
  {
    "country": "US",
    "name": "Blair",
    "lat": "44.2944",
    "lng": "-91.23516"
  },
  {
    "country": "US",
    "name": "Bloomer",
    "lat": "45.10024",
    "lng": "-91.48877"
  },
  {
    "country": "US",
    "name": "Bohners Lake",
    "lat": "42.62307",
    "lng": "-88.28037"
  },
  {
    "country": "US",
    "name": "Bonduel",
    "lat": "44.74027",
    "lng": "-88.44482"
  },
  {
    "country": "US",
    "name": "Boscobel",
    "lat": "43.13443",
    "lng": "-90.7054"
  },
  {
    "country": "US",
    "name": "Boyceville",
    "lat": "45.04357",
    "lng": "-92.04101"
  },
  {
    "country": "US",
    "name": "Brice Prairie",
    "lat": "43.93857",
    "lng": "-91.29986"
  },
  {
    "country": "US",
    "name": "Brillion",
    "lat": "44.17721",
    "lng": "-88.06427"
  },
  {
    "country": "US",
    "name": "Bristol",
    "lat": "42.55891",
    "lng": "-88.04925"
  },
  {
    "country": "US",
    "name": "Brodhead",
    "lat": "42.61834",
    "lng": "-89.37623"
  },
  {
    "country": "US",
    "name": "Brookfield",
    "lat": "43.06057",
    "lng": "-88.10648"
  },
  {
    "country": "US",
    "name": "Brooklyn",
    "lat": "42.85361",
    "lng": "-89.3704"
  },
  {
    "country": "US",
    "name": "Brothertown",
    "lat": "43.96805",
    "lng": "-88.30899"
  },
  {
    "country": "US",
    "name": "Brown Deer",
    "lat": "43.16334",
    "lng": "-87.96453"
  },
  {
    "country": "US",
    "name": "Browns Lake",
    "lat": "42.69252",
    "lng": "-88.2312"
  },
  {
    "country": "US",
    "name": "Burlington",
    "lat": "42.67807",
    "lng": "-88.2762"
  },
  {
    "country": "US",
    "name": "Butler",
    "lat": "43.10584",
    "lng": "-88.06953"
  },
  {
    "country": "US",
    "name": "Cadott",
    "lat": "44.94802",
    "lng": "-91.1507"
  },
  {
    "country": "US",
    "name": "Caledonia",
    "lat": "42.8078",
    "lng": "-87.92425"
  },
  {
    "country": "US",
    "name": "Cambridge",
    "lat": "43.00361",
    "lng": "-89.0165"
  },
  {
    "country": "US",
    "name": "Cameron",
    "lat": "45.40857",
    "lng": "-91.74406"
  },
  {
    "country": "US",
    "name": "Camp Lake",
    "lat": "42.53474",
    "lng": "-88.1437"
  },
  {
    "country": "US",
    "name": "Campbellsport",
    "lat": "43.59777",
    "lng": "-88.27899"
  },
  {
    "country": "US",
    "name": "Cashton",
    "lat": "43.74191",
    "lng": "-90.7793"
  },
  {
    "country": "US",
    "name": "Cato",
    "lat": "44.14277",
    "lng": "-87.8612"
  },
  {
    "country": "US",
    "name": "Cedar Grove",
    "lat": "43.56972",
    "lng": "-87.82342"
  },
  {
    "country": "US",
    "name": "Cedarburg",
    "lat": "43.29667",
    "lng": "-87.98759"
  },
  {
    "country": "US",
    "name": "Chetek",
    "lat": "45.31413",
    "lng": "-91.651"
  },
  {
    "country": "US",
    "name": "Chilton",
    "lat": "44.02888",
    "lng": "-88.16288"
  },
  {
    "country": "US",
    "name": "Chippewa Falls",
    "lat": "44.93691",
    "lng": "-91.39293"
  },
  {
    "country": "US",
    "name": "Clear Lake",
    "lat": "45.25191",
    "lng": "-92.2713"
  },
  {
    "country": "US",
    "name": "Cleveland",
    "lat": "43.91499",
    "lng": "-87.74731"
  },
  {
    "country": "US",
    "name": "Clinton",
    "lat": "42.55779",
    "lng": "-88.86511"
  },
  {
    "country": "US",
    "name": "Clintonville",
    "lat": "44.62053",
    "lng": "-88.76232"
  },
  {
    "country": "US",
    "name": "Colby",
    "lat": "44.90997",
    "lng": "-90.31569"
  },
  {
    "country": "US",
    "name": "Colfax",
    "lat": "44.99746",
    "lng": "-91.72712"
  },
  {
    "country": "US",
    "name": "Columbus",
    "lat": "43.33805",
    "lng": "-89.01539"
  },
  {
    "country": "US",
    "name": "Combined Locks",
    "lat": "44.26582",
    "lng": "-88.31427"
  },
  {
    "country": "US",
    "name": "Como",
    "lat": "42.61224",
    "lng": "-88.48232"
  },
  {
    "country": "US",
    "name": "Concord",
    "lat": "43.06945",
    "lng": "-88.59871"
  },
  {
    "country": "US",
    "name": "Cooperstown",
    "lat": "44.31277",
    "lng": "-87.77453"
  },
  {
    "country": "US",
    "name": "Cornell",
    "lat": "45.16719",
    "lng": "-91.14931"
  },
  {
    "country": "US",
    "name": "Cottage Grove",
    "lat": "43.07611",
    "lng": "-89.19956"
  },
  {
    "country": "US",
    "name": "Crandon",
    "lat": "45.57191",
    "lng": "-88.90289"
  },
  {
    "country": "US",
    "name": "Cross Plains",
    "lat": "43.11444",
    "lng": "-89.65568"
  },
  {
    "country": "US",
    "name": "Cuba City",
    "lat": "42.60555",
    "lng": "-90.42985"
  },
  {
    "country": "US",
    "name": "Cudahy",
    "lat": "42.95974",
    "lng": "-87.86147"
  },
  {
    "country": "US",
    "name": "Cumberland",
    "lat": "45.53218",
    "lng": "-92.01935"
  },
  {
    "country": "US",
    "name": "Dakota",
    "lat": "43.99025",
    "lng": "-89.35651"
  },
  {
    "country": "US",
    "name": "Dane",
    "lat": "43.25055",
    "lng": "-89.50151"
  },
  {
    "country": "US",
    "name": "Darien",
    "lat": "42.60168",
    "lng": "-88.7076"
  },
  {
    "country": "US",
    "name": "Darlington",
    "lat": "42.68306",
    "lng": "-90.11763"
  },
  {
    "country": "US",
    "name": "De Forest",
    "lat": "43.24777",
    "lng": "-89.34373"
  },
  {
    "country": "US",
    "name": "De Pere",
    "lat": "44.44888",
    "lng": "-88.06038"
  },
  {
    "country": "US",
    "name": "Deerfield",
    "lat": "43.05194",
    "lng": "-89.07567"
  },
  {
    "country": "US",
    "name": "Delafield",
    "lat": "43.06084",
    "lng": "-88.40371"
  },
  {
    "country": "US",
    "name": "Delavan",
    "lat": "42.63307",
    "lng": "-88.64371"
  },
  {
    "country": "US",
    "name": "Delavan Lake",
    "lat": "42.58418",
    "lng": "-88.6326"
  },
  {
    "country": "US",
    "name": "Denmark",
    "lat": "44.34777",
    "lng": "-87.82732"
  },
  {
    "country": "US",
    "name": "Dickeyville",
    "lat": "42.62722",
    "lng": "-90.59207"
  },
  {
    "country": "US",
    "name": "Dodgeville",
    "lat": "42.96027",
    "lng": "-90.13012"
  },
  {
    "country": "US",
    "name": "Dousman",
    "lat": "43.01418",
    "lng": "-88.4726"
  },
  {
    "country": "US",
    "name": "Durand",
    "lat": "44.62635",
    "lng": "-91.96573"
  },
  {
    "country": "US",
    "name": "Eagle",
    "lat": "42.87946",
    "lng": "-88.47427"
  },
  {
    "country": "US",
    "name": "Eagle Lake",
    "lat": "42.70696",
    "lng": "-88.12814"
  },
  {
    "country": "US",
    "name": "Eagle River",
    "lat": "45.91718",
    "lng": "-89.2443"
  },
  {
    "country": "US",
    "name": "East Troy",
    "lat": "42.78529",
    "lng": "-88.4051"
  },
  {
    "country": "US",
    "name": "Easton",
    "lat": "43.83803",
    "lng": "-89.80679"
  },
  {
    "country": "US",
    "name": "Eau Claire",
    "lat": "44.81135",
    "lng": "-91.49849"
  },
  {
    "country": "US",
    "name": "Edgar",
    "lat": "44.92719",
    "lng": "-89.96346"
  },
  {
    "country": "US",
    "name": "Edgerton",
    "lat": "42.83528",
    "lng": "-89.06761"
  },
  {
    "country": "US",
    "name": "Eldorado",
    "lat": "43.82471",
    "lng": "-88.62178"
  },
  {
    "country": "US",
    "name": "Elkhorn",
    "lat": "42.67279",
    "lng": "-88.54454"
  },
  {
    "country": "US",
    "name": "Ellsworth",
    "lat": "44.73219",
    "lng": "-92.48741"
  },
  {
    "country": "US",
    "name": "Elm Grove",
    "lat": "43.04307",
    "lng": "-88.07898"
  },
  {
    "country": "US",
    "name": "Elroy",
    "lat": "43.7408",
    "lng": "-90.27235"
  },
  {
    "country": "US",
    "name": "Evansville",
    "lat": "42.78028",
    "lng": "-89.29928"
  },
  {
    "country": "US",
    "name": "Evergreen",
    "lat": "44.84247",
    "lng": "-89.63762"
  },
  {
    "country": "US",
    "name": "Fall Creek",
    "lat": "44.76357",
    "lng": "-91.2771"
  },
  {
    "country": "US",
    "name": "Fall River",
    "lat": "43.38443",
    "lng": "-89.04511"
  },
  {
    "country": "US",
    "name": "Fennimore",
    "lat": "42.9836",
    "lng": "-90.6554"
  },
  {
    "country": "US",
    "name": "Fitchburg",
    "lat": "42.96083",
    "lng": "-89.46984"
  },
  {
    "country": "US",
    "name": "Florence",
    "lat": "45.92218",
    "lng": "-88.2518"
  },
  {
    "country": "US",
    "name": "Fond du Lac",
    "lat": "43.775",
    "lng": "-88.43883"
  },
  {
    "country": "US",
    "name": "Fontana",
    "lat": "42.55141",
    "lng": "-88.5751"
  },
  {
    "country": "US",
    "name": "Fort Atkinson",
    "lat": "42.92889",
    "lng": "-88.83705"
  },
  {
    "country": "US",
    "name": "Fox Lake",
    "lat": "43.56554",
    "lng": "-88.9065"
  },
  {
    "country": "US",
    "name": "Fox Point",
    "lat": "43.15751",
    "lng": "-87.90175"
  },
  {
    "country": "US",
    "name": "Franklin",
    "lat": "42.88863",
    "lng": "-88.03842"
  },
  {
    "country": "US",
    "name": "Franksville",
    "lat": "42.76002",
    "lng": "-87.91341"
  },
  {
    "country": "US",
    "name": "Frederic",
    "lat": "45.65912",
    "lng": "-92.46714"
  },
  {
    "country": "US",
    "name": "Fredonia",
    "lat": "43.47056",
    "lng": "-87.95065"
  },
  {
    "country": "US",
    "name": "French Island",
    "lat": "43.8583",
    "lng": "-91.26042"
  },
  {
    "country": "US",
    "name": "Friendship",
    "lat": "43.97053",
    "lng": "-89.81679"
  },
  {
    "country": "US",
    "name": "Galesville",
    "lat": "44.08163",
    "lng": "-91.34904"
  },
  {
    "country": "US",
    "name": "Genoa City",
    "lat": "42.49835",
    "lng": "-88.32815"
  },
  {
    "country": "US",
    "name": "Germantown",
    "lat": "43.22862",
    "lng": "-88.11037"
  },
  {
    "country": "US",
    "name": "Gillett",
    "lat": "44.88999",
    "lng": "-88.30732"
  },
  {
    "country": "US",
    "name": "Glendale",
    "lat": "43.13529",
    "lng": "-87.93564"
  },
  {
    "country": "US",
    "name": "Glenmore",
    "lat": "44.38583",
    "lng": "-87.92732"
  },
  {
    "country": "US",
    "name": "Glenwood City",
    "lat": "45.05857",
    "lng": "-92.17241"
  },
  {
    "country": "US",
    "name": "Grafton",
    "lat": "43.31973",
    "lng": "-87.95342"
  },
  {
    "country": "US",
    "name": "Grantsburg",
    "lat": "45.77634",
    "lng": "-92.6827"
  },
  {
    "country": "US",
    "name": "Green Bay",
    "lat": "44.51916",
    "lng": "-88.01983"
  },
  {
    "country": "US",
    "name": "Green Lake",
    "lat": "43.84415",
    "lng": "-88.96011"
  },
  {
    "country": "US",
    "name": "Greendale",
    "lat": "42.94057",
    "lng": "-87.99592"
  },
  {
    "country": "US",
    "name": "Greenfield",
    "lat": "42.9614",
    "lng": "-88.01259"
  },
  {
    "country": "US",
    "name": "Greenwood",
    "lat": "44.77024",
    "lng": "-90.59931"
  },
  {
    "country": "US",
    "name": "Hales Corners",
    "lat": "42.93751",
    "lng": "-88.0487"
  },
  {
    "country": "US",
    "name": "Hammond",
    "lat": "44.97886",
    "lng": "-92.43575"
  },
  {
    "country": "US",
    "name": "Hartford",
    "lat": "43.31778",
    "lng": "-88.37899"
  },
  {
    "country": "US",
    "name": "Hartland",
    "lat": "43.10501",
    "lng": "-88.34204"
  },
  {
    "country": "US",
    "name": "Hayward",
    "lat": "46.01301",
    "lng": "-91.48462"
  },
  {
    "country": "US",
    "name": "Hazel Green",
    "lat": "42.53278",
    "lng": "-90.43457"
  },
  {
    "country": "US",
    "name": "Hilbert",
    "lat": "44.14027",
    "lng": "-88.16399"
  },
  {
    "country": "US",
    "name": "Hillsboro",
    "lat": "43.6522",
    "lng": "-90.34402"
  },
  {
    "country": "US",
    "name": "Holmen",
    "lat": "43.9633",
    "lng": "-91.25625"
  },
  {
    "country": "US",
    "name": "Horicon",
    "lat": "43.45138",
    "lng": "-88.63121"
  },
  {
    "country": "US",
    "name": "Hortonville",
    "lat": "44.3347",
    "lng": "-88.63816"
  },
  {
    "country": "US",
    "name": "Howard",
    "lat": "44.5436",
    "lng": "-88.08816"
  },
  {
    "country": "US",
    "name": "Howards Grove",
    "lat": "43.83388",
    "lng": "-87.82009"
  },
  {
    "country": "US",
    "name": "Hudson",
    "lat": "44.97469",
    "lng": "-92.75687"
  },
  {
    "country": "US",
    "name": "Hurley",
    "lat": "46.44967",
    "lng": "-90.18656"
  },
  {
    "country": "US",
    "name": "Hustisford",
    "lat": "43.34611",
    "lng": "-88.60066"
  },
  {
    "country": "US",
    "name": "Independence",
    "lat": "44.35691",
    "lng": "-91.42043"
  },
  {
    "country": "US",
    "name": "Iola",
    "lat": "44.50803",
    "lng": "-89.13067"
  },
  {
    "country": "US",
    "name": "Ixonia",
    "lat": "43.14389",
    "lng": "-88.59732"
  },
  {
    "country": "US",
    "name": "Jackson",
    "lat": "43.32389",
    "lng": "-88.16676"
  },
  {
    "country": "US",
    "name": "Janesville",
    "lat": "42.68279",
    "lng": "-89.01872"
  },
  {
    "country": "US",
    "name": "Jefferson",
    "lat": "43.00556",
    "lng": "-88.80733"
  },
  {
    "country": "US",
    "name": "Johnson Creek",
    "lat": "43.07611",
    "lng": "-88.77427"
  },
  {
    "country": "US",
    "name": "Juneau",
    "lat": "43.40555",
    "lng": "-88.7051"
  },
  {
    "country": "US",
    "name": "Kaukauna",
    "lat": "44.27804",
    "lng": "-88.27205"
  },
  {
    "country": "US",
    "name": "Kenosha",
    "lat": "42.58474",
    "lng": "-87.82119"
  },
  {
    "country": "US",
    "name": "Keshena",
    "lat": "44.88387",
    "lng": "-88.63372"
  },
  {
    "country": "US",
    "name": "Kewaskum",
    "lat": "43.52083",
    "lng": "-88.22899"
  },
  {
    "country": "US",
    "name": "Kewaunee",
    "lat": "44.45833",
    "lng": "-87.50314"
  },
  {
    "country": "US",
    "name": "Kiel",
    "lat": "43.91249",
    "lng": "-88.03565"
  },
  {
    "country": "US",
    "name": "Kimberly",
    "lat": "44.27221",
    "lng": "-88.339"
  },
  {
    "country": "US",
    "name": "King",
    "lat": "44.33748",
    "lng": "-89.14178"
  },
  {
    "country": "US",
    "name": "Kohler",
    "lat": "43.49639",
    "lng": "-88.02343"
  },
  {
    "country": "US",
    "name": "Kronenwetter",
    "lat": "44.82219",
    "lng": "-89.5904"
  },
  {
    "country": "US",
    "name": "La Crosse",
    "lat": "43.80136",
    "lng": "-91.23958"
  },
  {
    "country": "US",
    "name": "Lac du Flambeau",
    "lat": "45.96967",
    "lng": "-89.8921"
  },
  {
    "country": "US",
    "name": "Ladysmith",
    "lat": "45.46302",
    "lng": "-91.10404"
  },
  {
    "country": "US",
    "name": "Lake Delton",
    "lat": "43.60109",
    "lng": "-89.79374"
  },
  {
    "country": "US",
    "name": "Lake Geneva",
    "lat": "42.59168",
    "lng": "-88.43343"
  },
  {
    "country": "US",
    "name": "Lake Hallie",
    "lat": "44.87579",
    "lng": "-91.44071"
  },
  {
    "country": "US",
    "name": "Lake Koshkonong",
    "lat": "42.90973",
    "lng": "-88.91955"
  },
  {
    "country": "US",
    "name": "Lake Mills",
    "lat": "43.08139",
    "lng": "-88.91177"
  },
  {
    "country": "US",
    "name": "Lake Nebagamon",
    "lat": "46.51494",
    "lng": "-91.69991"
  },
  {
    "country": "US",
    "name": "Lake Ripley",
    "lat": "43.00583",
    "lng": "-88.98622"
  },
  {
    "country": "US",
    "name": "Lake Wazeecha",
    "lat": "44.37108",
    "lng": "-89.75651"
  },
  {
    "country": "US",
    "name": "Lake Wisconsin",
    "lat": "43.3736",
    "lng": "-89.57568"
  },
  {
    "country": "US",
    "name": "Lake Wissota",
    "lat": "44.92635",
    "lng": "-91.30099"
  },
  {
    "country": "US",
    "name": "Lamartine",
    "lat": "43.73332",
    "lng": "-88.56872"
  },
  {
    "country": "US",
    "name": "Lancaster",
    "lat": "42.84749",
    "lng": "-90.71068"
  },
  {
    "country": "US",
    "name": "Lannon",
    "lat": "43.14612",
    "lng": "-88.1662"
  },
  {
    "country": "US",
    "name": "Little Chute",
    "lat": "44.27999",
    "lng": "-88.31844"
  },
  {
    "country": "US",
    "name": "Little Round Lake",
    "lat": "45.96495",
    "lng": "-91.36795"
  },
  {
    "country": "US",
    "name": "Lodi",
    "lat": "43.31388",
    "lng": "-89.52651"
  },
  {
    "country": "US",
    "name": "Lomira",
    "lat": "43.59138",
    "lng": "-88.44371"
  },
  {
    "country": "US",
    "name": "Loyal",
    "lat": "44.73691",
    "lng": "-90.49597"
  },
  {
    "country": "US",
    "name": "Luck",
    "lat": "45.57607",
    "lng": "-92.4827"
  },
  {
    "country": "US",
    "name": "Luxemburg",
    "lat": "44.53861",
    "lng": "-87.70398"
  },
  {
    "country": "US",
    "name": "Madison",
    "lat": "43.07305",
    "lng": "-89.40123"
  },
  {
    "country": "US",
    "name": "Manawa",
    "lat": "44.46443",
    "lng": "-88.91983"
  },
  {
    "country": "US",
    "name": "Manchester",
    "lat": "43.69054",
    "lng": "-89.04845"
  },
  {
    "country": "US",
    "name": "Manitowoc",
    "lat": "44.08861",
    "lng": "-87.65758"
  },
  {
    "country": "US",
    "name": "Maple Bluff",
    "lat": "43.11833",
    "lng": "-89.37956"
  },
  {
    "country": "US",
    "name": "Marathon",
    "lat": "44.92913",
    "lng": "-89.8404"
  },
  {
    "country": "US",
    "name": "Marinette",
    "lat": "45.09998",
    "lng": "-87.63066"
  },
  {
    "country": "US",
    "name": "Marion",
    "lat": "44.67081",
    "lng": "-88.88927"
  },
  {
    "country": "US",
    "name": "Markesan",
    "lat": "43.7072",
    "lng": "-88.99011"
  },
  {
    "country": "US",
    "name": "Marshall",
    "lat": "43.16833",
    "lng": "-89.06678"
  },
  {
    "country": "US",
    "name": "Marshfield",
    "lat": "44.66885",
    "lng": "-90.1718"
  },
  {
    "country": "US",
    "name": "Mauston",
    "lat": "43.79719",
    "lng": "-90.07735"
  },
  {
    "country": "US",
    "name": "Mayville",
    "lat": "43.49416",
    "lng": "-88.54482"
  },
  {
    "country": "US",
    "name": "Mazomanie",
    "lat": "43.17666",
    "lng": "-89.79485"
  },
  {
    "country": "US",
    "name": "McFarland",
    "lat": "43.0125",
    "lng": "-89.28984"
  },
  {
    "country": "US",
    "name": "Medford",
    "lat": "45.13858",
    "lng": "-90.34014"
  },
  {
    "country": "US",
    "name": "Menasha",
    "lat": "44.20221",
    "lng": "-88.4465"
  },
  {
    "country": "US",
    "name": "Menomonee Falls",
    "lat": "43.1789",
    "lng": "-88.11731"
  },
  {
    "country": "US",
    "name": "Menomonie",
    "lat": "44.87552",
    "lng": "-91.91934"
  },
  {
    "country": "US",
    "name": "Mequon",
    "lat": "43.21555",
    "lng": "-88.03001"
  },
  {
    "country": "US",
    "name": "Merrill",
    "lat": "45.18052",
    "lng": "-89.68346"
  },
  {
    "country": "US",
    "name": "Merton",
    "lat": "43.14667",
    "lng": "-88.30676"
  },
  {
    "country": "US",
    "name": "Middleton",
    "lat": "43.09722",
    "lng": "-89.50429"
  },
  {
    "country": "US",
    "name": "Milford",
    "lat": "43.10083",
    "lng": "-88.84677"
  },
  {
    "country": "US",
    "name": "Milton",
    "lat": "42.77556",
    "lng": "-88.944"
  },
  {
    "country": "US",
    "name": "Milwaukee",
    "lat": "43.0389",
    "lng": "-87.90647"
  },
  {
    "country": "US",
    "name": "Mineral Point",
    "lat": "42.86",
    "lng": "-90.17985"
  },
  {
    "country": "US",
    "name": "Mishicot",
    "lat": "44.23916",
    "lng": "-87.64119"
  },
  {
    "country": "US",
    "name": "Mondovi",
    "lat": "44.56774",
    "lng": "-91.67099"
  },
  {
    "country": "US",
    "name": "Monona",
    "lat": "43.06222",
    "lng": "-89.33401"
  },
  {
    "country": "US",
    "name": "Monroe",
    "lat": "42.60112",
    "lng": "-89.63845"
  },
  {
    "country": "US",
    "name": "Montello",
    "lat": "43.79137",
    "lng": "-89.31984"
  },
  {
    "country": "US",
    "name": "Monticello",
    "lat": "42.74556",
    "lng": "-89.59484"
  },
  {
    "country": "US",
    "name": "Mosinee",
    "lat": "44.79302",
    "lng": "-89.70318"
  },
  {
    "country": "US",
    "name": "Mount Horeb",
    "lat": "43.00861",
    "lng": "-89.73846"
  },
  {
    "country": "US",
    "name": "Mount Morris",
    "lat": "44.11442",
    "lng": "-89.19067"
  },
  {
    "country": "US",
    "name": "Mukwonago",
    "lat": "42.86668",
    "lng": "-88.33343"
  },
  {
    "country": "US",
    "name": "Muscoda",
    "lat": "43.18499",
    "lng": "-90.44318"
  },
  {
    "country": "US",
    "name": "Muskego",
    "lat": "42.90585",
    "lng": "-88.13898"
  },
  {
    "country": "US",
    "name": "Nashotah",
    "lat": "43.09779",
    "lng": "-88.40232"
  },
  {
    "country": "US",
    "name": "Nashville",
    "lat": "45.52274",
    "lng": "-89.02484"
  },
  {
    "country": "US",
    "name": "Neenah",
    "lat": "44.18582",
    "lng": "-88.46261"
  },
  {
    "country": "US",
    "name": "Neillsville",
    "lat": "44.55996",
    "lng": "-90.59625"
  },
  {
    "country": "US",
    "name": "Nekoosa",
    "lat": "44.31246",
    "lng": "-89.90429"
  },
  {
    "country": "US",
    "name": "New Berlin",
    "lat": "42.9764",
    "lng": "-88.10842"
  },
  {
    "country": "US",
    "name": "New Glarus",
    "lat": "42.81445",
    "lng": "-89.63512"
  },
  {
    "country": "US",
    "name": "New Holstein",
    "lat": "43.94999",
    "lng": "-88.08426"
  },
  {
    "country": "US",
    "name": "New Lisbon",
    "lat": "43.87914",
    "lng": "-90.16541"
  },
  {
    "country": "US",
    "name": "New London",
    "lat": "44.39276",
    "lng": "-88.73983"
  },
  {
    "country": "US",
    "name": "New Richmond",
    "lat": "45.12302",
    "lng": "-92.53659"
  },
  {
    "country": "US",
    "name": "Newburg",
    "lat": "43.43167",
    "lng": "-88.04648"
  },
  {
    "country": "US",
    "name": "Niagara",
    "lat": "45.77135",
    "lng": "-87.99485"
  },
  {
    "country": "US",
    "name": "North Fond du Lac",
    "lat": "43.81138",
    "lng": "-88.48344"
  },
  {
    "country": "US",
    "name": "North Hudson",
    "lat": "44.99302",
    "lng": "-92.75687"
  },
  {
    "country": "US",
    "name": "North La Crosse",
    "lat": "43.84635",
    "lng": "-91.24819"
  },
  {
    "country": "US",
    "name": "North Prairie",
    "lat": "42.93446",
    "lng": "-88.40537"
  },
  {
    "country": "US",
    "name": "Oak Creek",
    "lat": "42.88585",
    "lng": "-87.86314"
  },
  {
    "country": "US",
    "name": "Oakfield",
    "lat": "43.6861",
    "lng": "-88.5465"
  },
  {
    "country": "US",
    "name": "Oconomowoc",
    "lat": "43.11167",
    "lng": "-88.49927"
  },
  {
    "country": "US",
    "name": "Oconto",
    "lat": "44.88721",
    "lng": "-87.86455"
  },
  {
    "country": "US",
    "name": "Oconto Falls",
    "lat": "44.87388",
    "lng": "-88.14288"
  },
  {
    "country": "US",
    "name": "Okauchee Lake",
    "lat": "43.12334",
    "lng": "-88.44065"
  },
  {
    "country": "US",
    "name": "Omro",
    "lat": "44.03943",
    "lng": "-88.74428"
  },
  {
    "country": "US",
    "name": "Onalaska",
    "lat": "43.88441",
    "lng": "-91.23514"
  },
  {
    "country": "US",
    "name": "Oneida",
    "lat": "44.4986",
    "lng": "-88.18288"
  },
  {
    "country": "US",
    "name": "Oostburg",
    "lat": "43.62277",
    "lng": "-87.79453"
  },
  {
    "country": "US",
    "name": "Oregon",
    "lat": "42.92611",
    "lng": "-89.38456"
  },
  {
    "country": "US",
    "name": "Orfordville",
    "lat": "42.62751",
    "lng": "-89.25317"
  },
  {
    "country": "US",
    "name": "Osceola",
    "lat": "45.32052",
    "lng": "-92.70493"
  },
  {
    "country": "US",
    "name": "Oshkosh",
    "lat": "44.02471",
    "lng": "-88.54261"
  },
  {
    "country": "US",
    "name": "Osseo",
    "lat": "44.57218",
    "lng": "-91.22738"
  },
  {
    "country": "US",
    "name": "Paddock Lake",
    "lat": "42.57752",
    "lng": "-88.10509"
  },
  {
    "country": "US",
    "name": "Palmyra",
    "lat": "42.87779",
    "lng": "-88.58621"
  },
  {
    "country": "US",
    "name": "Pardeeville",
    "lat": "43.53776",
    "lng": "-89.30012"
  },
  {
    "country": "US",
    "name": "Park Falls",
    "lat": "45.9344",
    "lng": "-90.44155"
  },
  {
    "country": "US",
    "name": "Pell Lake",
    "lat": "42.53807",
    "lng": "-88.35093"
  },
  {
    "country": "US",
    "name": "Peshtigo",
    "lat": "45.05443",
    "lng": "-87.74927"
  },
  {
    "country": "US",
    "name": "Pewaukee",
    "lat": "43.08057",
    "lng": "-88.2612"
  },
  {
    "country": "US",
    "name": "Phillips",
    "lat": "45.69663",
    "lng": "-90.40043"
  },
  {
    "country": "US",
    "name": "Pittsfield",
    "lat": "44.59944",
    "lng": "-88.2451"
  },
  {
    "country": "US",
    "name": "Platteville",
    "lat": "42.73416",
    "lng": "-90.47846"
  },
  {
    "country": "US",
    "name": "Pleasant Prairie",
    "lat": "42.55308",
    "lng": "-87.93341"
  },
  {
    "country": "US",
    "name": "Plover",
    "lat": "44.45636",
    "lng": "-89.54401"
  },
  {
    "country": "US",
    "name": "Plymouth",
    "lat": "43.74861",
    "lng": "-87.97704"
  },
  {
    "country": "US",
    "name": "Port Edwards",
    "lat": "44.3508",
    "lng": "-89.8654"
  },
  {
    "country": "US",
    "name": "Port Washington",
    "lat": "43.38722",
    "lng": "-87.87564"
  },
  {
    "country": "US",
    "name": "Portage",
    "lat": "43.53915",
    "lng": "-89.46262"
  },
  {
    "country": "US",
    "name": "Portland",
    "lat": "43.76886",
    "lng": "-90.85819"
  },
  {
    "country": "US",
    "name": "Potter Lake",
    "lat": "42.82168",
    "lng": "-88.34898"
  },
  {
    "country": "US",
    "name": "Powers Lake",
    "lat": "42.55363",
    "lng": "-88.29454"
  },
  {
    "country": "US",
    "name": "Poynette",
    "lat": "43.39026",
    "lng": "-89.4029"
  },
  {
    "country": "US",
    "name": "Prairie du Chien",
    "lat": "43.05165",
    "lng": "-91.14124"
  },
  {
    "country": "US",
    "name": "Prairie du Sac",
    "lat": "43.28693",
    "lng": "-89.72401"
  },
  {
    "country": "US",
    "name": "Prescott",
    "lat": "44.74886",
    "lng": "-92.80215"
  },
  {
    "country": "US",
    "name": "Princeton",
    "lat": "43.85081",
    "lng": "-89.12178"
  },
  {
    "country": "US",
    "name": "Pulaski",
    "lat": "44.67222",
    "lng": "-88.2426"
  },
  {
    "country": "US",
    "name": "Racine",
    "lat": "42.72613",
    "lng": "-87.78285"
  },
  {
    "country": "US",
    "name": "Randolph",
    "lat": "43.53915",
    "lng": "-89.00678"
  },
  {
    "country": "US",
    "name": "Random Lake",
    "lat": "43.55222",
    "lng": "-87.96176"
  },
  {
    "country": "US",
    "name": "Redgranite",
    "lat": "44.04192",
    "lng": "-89.09845"
  },
  {
    "country": "US",
    "name": "Reedsburg",
    "lat": "43.53248",
    "lng": "-90.00263"
  },
  {
    "country": "US",
    "name": "Reedsville",
    "lat": "44.1536",
    "lng": "-87.95676"
  },
  {
    "country": "US",
    "name": "Rhinelander",
    "lat": "45.63662",
    "lng": "-89.41208"
  },
  {
    "country": "US",
    "name": "Rib Mountain",
    "lat": "44.91275",
    "lng": "-89.6754"
  },
  {
    "country": "US",
    "name": "Rice Lake",
    "lat": "45.50607",
    "lng": "-91.73823"
  },
  {
    "country": "US",
    "name": "Richfield",
    "lat": "43.25612",
    "lng": "-88.19398"
  },
  {
    "country": "US",
    "name": "Richland Center",
    "lat": "43.33471",
    "lng": "-90.38679"
  },
  {
    "country": "US",
    "name": "Richmond",
    "lat": "42.71473",
    "lng": "-88.74927"
  },
  {
    "country": "US",
    "name": "Ripon",
    "lat": "43.8422",
    "lng": "-88.83594"
  },
  {
    "country": "US",
    "name": "Rio",
    "lat": "43.44776",
    "lng": "-89.23984"
  },
  {
    "country": "US",
    "name": "River Falls",
    "lat": "44.86136",
    "lng": "-92.62381"
  },
  {
    "country": "US",
    "name": "River Hills",
    "lat": "43.17418",
    "lng": "-87.92425"
  },
  {
    "country": "US",
    "name": "Roberts",
    "lat": "44.98386",
    "lng": "-92.55603"
  },
  {
    "country": "US",
    "name": "Rochester",
    "lat": "42.74141",
    "lng": "-88.22426"
  },
  {
    "country": "US",
    "name": "Rosendale",
    "lat": "43.80776",
    "lng": "-88.67483"
  },
  {
    "country": "US",
    "name": "Rothschild",
    "lat": "44.88719",
    "lng": "-89.62012"
  },
  {
    "country": "US",
    "name": "Roxbury",
    "lat": "43.24943",
    "lng": "-89.6754"
  },
  {
    "country": "US",
    "name": "Rutland",
    "lat": "42.87889",
    "lng": "-89.35012"
  },
  {
    "country": "US",
    "name": "Saint Croix Falls",
    "lat": "45.40996",
    "lng": "-92.63965"
  },
  {
    "country": "US",
    "name": "Saint Francis",
    "lat": "42.96752",
    "lng": "-87.87758"
  },
  {
    "country": "US",
    "name": "Saint Peter",
    "lat": "43.83638",
    "lng": "-88.34149"
  },
  {
    "country": "US",
    "name": "Salem",
    "lat": "42.55474",
    "lng": "-88.11092"
  },
  {
    "country": "US",
    "name": "Sauk City",
    "lat": "43.27082",
    "lng": "-89.72207"
  },
  {
    "country": "US",
    "name": "Saukville",
    "lat": "43.38167",
    "lng": "-87.94065"
  },
  {
    "country": "US",
    "name": "Schofield",
    "lat": "44.90969",
    "lng": "-89.60457"
  },
  {
    "country": "US",
    "name": "Seymour",
    "lat": "44.82663",
    "lng": "-91.43127"
  },
  {
    "country": "US",
    "name": "Seymour",
    "lat": "44.51499",
    "lng": "-88.33038"
  },
  {
    "country": "US",
    "name": "Sharon",
    "lat": "42.50252",
    "lng": "-88.72899"
  },
  {
    "country": "US",
    "name": "Shawano",
    "lat": "44.78221",
    "lng": "-88.60899"
  },
  {
    "country": "US",
    "name": "Sheboygan",
    "lat": "43.75083",
    "lng": "-87.71453"
  },
  {
    "country": "US",
    "name": "Sheboygan Falls",
    "lat": "43.73197",
    "lng": "-87.82213"
  },
  {
    "country": "US",
    "name": "Shell Lake",
    "lat": "45.73939",
    "lng": "-91.92545"
  },
  {
    "country": "US",
    "name": "Sherwood",
    "lat": "44.1736",
    "lng": "-88.25983"
  },
  {
    "country": "US",
    "name": "Shorewood",
    "lat": "43.08918",
    "lng": "-87.88758"
  },
  {
    "country": "US",
    "name": "Shorewood Hills",
    "lat": "43.0775",
    "lng": "-89.44568"
  },
  {
    "country": "US",
    "name": "Shullsburg",
    "lat": "42.57334",
    "lng": "-90.23096"
  },
  {
    "country": "US",
    "name": "Silver Lake",
    "lat": "42.54613",
    "lng": "-88.16564"
  },
  {
    "country": "US",
    "name": "Silver Lake",
    "lat": "44.05526",
    "lng": "-89.22623"
  },
  {
    "country": "US",
    "name": "Siren",
    "lat": "45.78578",
    "lng": "-92.38103"
  },
  {
    "country": "US",
    "name": "Slinger",
    "lat": "43.33361",
    "lng": "-88.28621"
  },
  {
    "country": "US",
    "name": "Somers",
    "lat": "42.6403",
    "lng": "-87.91036"
  },
  {
    "country": "US",
    "name": "Somerset",
    "lat": "45.12441",
    "lng": "-92.67354"
  },
  {
    "country": "US",
    "name": "South Milwaukee",
    "lat": "42.91057",
    "lng": "-87.86064"
  },
  {
    "country": "US",
    "name": "Sparta",
    "lat": "43.94413",
    "lng": "-90.81291"
  },
  {
    "country": "US",
    "name": "Spencer",
    "lat": "44.75774",
    "lng": "-90.2968"
  },
  {
    "country": "US",
    "name": "Spooner",
    "lat": "45.82245",
    "lng": "-91.88934"
  },
  {
    "country": "US",
    "name": "Spring Green",
    "lat": "43.17527",
    "lng": "-90.0679"
  },
  {
    "country": "US",
    "name": "Spring Valley",
    "lat": "44.84524",
    "lng": "-92.2388"
  },
  {
    "country": "US",
    "name": "Stanley",
    "lat": "44.95997",
    "lng": "-90.93708"
  },
  {
    "country": "US",
    "name": "Stevens Point",
    "lat": "44.52358",
    "lng": "-89.57456"
  },
  {
    "country": "US",
    "name": "Stoughton",
    "lat": "42.91695",
    "lng": "-89.21789"
  },
  {
    "country": "US",
    "name": "Stratford",
    "lat": "44.80108",
    "lng": "-90.0793"
  },
  {
    "country": "US",
    "name": "Strum",
    "lat": "44.54969",
    "lng": "-91.39266"
  },
  {
    "country": "US",
    "name": "Sturgeon Bay",
    "lat": "44.83416",
    "lng": "-87.37704"
  },
  {
    "country": "US",
    "name": "Sturtevant",
    "lat": "42.69807",
    "lng": "-87.89452"
  },
  {
    "country": "US",
    "name": "Suamico",
    "lat": "44.63194",
    "lng": "-88.03927"
  },
  {
    "country": "US",
    "name": "Sun Prairie",
    "lat": "43.1836",
    "lng": "-89.21373"
  },
  {
    "country": "US",
    "name": "Superior",
    "lat": "46.72077",
    "lng": "-92.10408"
  },
  {
    "country": "US",
    "name": "Sussex",
    "lat": "43.1339",
    "lng": "-88.22204"
  },
  {
    "country": "US",
    "name": "Tainter Lake",
    "lat": "44.98913",
    "lng": "-91.84767"
  },
  {
    "country": "US",
    "name": "Theresa",
    "lat": "43.51722",
    "lng": "-88.45121"
  },
  {
    "country": "US",
    "name": "Thiensville",
    "lat": "43.23751",
    "lng": "-87.9787"
  },
  {
    "country": "US",
    "name": "Thorp",
    "lat": "44.96108",
    "lng": "-90.79986"
  },
  {
    "country": "US",
    "name": "Tichigan",
    "lat": "42.8289",
    "lng": "-88.19759"
  },
  {
    "country": "US",
    "name": "Tomah",
    "lat": "43.97858",
    "lng": "-90.50402"
  },
  {
    "country": "US",
    "name": "Tomahawk",
    "lat": "45.47108",
    "lng": "-89.72986"
  },
  {
    "country": "US",
    "name": "Trempealeau",
    "lat": "44.00552",
    "lng": "-91.44209"
  },
  {
    "country": "US",
    "name": "Turtle Lake",
    "lat": "45.3944",
    "lng": "-92.14241"
  },
  {
    "country": "US",
    "name": "Twin Lakes",
    "lat": "42.53113",
    "lng": "-88.24815"
  },
  {
    "country": "US",
    "name": "Two Rivers",
    "lat": "44.15388",
    "lng": "-87.56925"
  },
  {
    "country": "US",
    "name": "Union Grove",
    "lat": "42.68807",
    "lng": "-88.05147"
  },
  {
    "country": "US",
    "name": "Verona",
    "lat": "42.99083",
    "lng": "-89.53318"
  },
  {
    "country": "US",
    "name": "Viroqua",
    "lat": "43.55692",
    "lng": "-90.88874"
  },
  {
    "country": "US",
    "name": "Wales",
    "lat": "43.00445",
    "lng": "-88.37676"
  },
  {
    "country": "US",
    "name": "Walworth",
    "lat": "42.53113",
    "lng": "-88.59955"
  },
  {
    "country": "US",
    "name": "Washburn",
    "lat": "46.67327",
    "lng": "-90.89491"
  },
  {
    "country": "US",
    "name": "Waterloo",
    "lat": "43.18388",
    "lng": "-88.98844"
  },
  {
    "country": "US",
    "name": "Waterford",
    "lat": "42.76307",
    "lng": "-88.21426"
  },
  {
    "country": "US",
    "name": "Watertown",
    "lat": "43.19472",
    "lng": "-88.72899"
  },
  {
    "country": "US",
    "name": "Waukesha",
    "lat": "43.01168",
    "lng": "-88.23148"
  },
  {
    "country": "US",
    "name": "Waunakee",
    "lat": "43.19194",
    "lng": "-89.45567"
  },
  {
    "country": "US",
    "name": "Waupaca",
    "lat": "44.35803",
    "lng": "-89.08595"
  },
  {
    "country": "US",
    "name": "Waupun",
    "lat": "43.63332",
    "lng": "-88.72955"
  },
  {
    "country": "US",
    "name": "Wausau",
    "lat": "44.95914",
    "lng": "-89.63012"
  },
  {
    "country": "US",
    "name": "Wautoma",
    "lat": "44.0747",
    "lng": "-89.2879"
  },
  {
    "country": "US",
    "name": "Wauwatosa",
    "lat": "43.04946",
    "lng": "-88.00759"
  },
  {
    "country": "US",
    "name": "West Baraboo",
    "lat": "43.47443",
    "lng": "-89.7704"
  },
  {
    "country": "US",
    "name": "West Allis",
    "lat": "43.01668",
    "lng": "-88.00703"
  },
  {
    "country": "US",
    "name": "West Bend",
    "lat": "43.42528",
    "lng": "-88.18343"
  },
  {
    "country": "US",
    "name": "West Milwaukee",
    "lat": "43.01251",
    "lng": "-87.97259"
  },
  {
    "country": "US",
    "name": "West Salem",
    "lat": "43.89913",
    "lng": "-91.08125"
  },
  {
    "country": "US",
    "name": "Westby",
    "lat": "43.65692",
    "lng": "-90.8543"
  },
  {
    "country": "US",
    "name": "Westfield",
    "lat": "43.88359",
    "lng": "-89.49346"
  },
  {
    "country": "US",
    "name": "Weston",
    "lat": "44.8908",
    "lng": "-89.54762"
  },
  {
    "country": "US",
    "name": "Weyauwega",
    "lat": "44.32137",
    "lng": "-88.93372"
  },
  {
    "country": "US",
    "name": "Whitefish Bay",
    "lat": "43.11334",
    "lng": "-87.90009"
  },
  {
    "country": "US",
    "name": "Whitehall",
    "lat": "44.36746",
    "lng": "-91.31655"
  },
  {
    "country": "US",
    "name": "Whitewater",
    "lat": "42.83362",
    "lng": "-88.73233"
  },
  {
    "country": "US",
    "name": "Whiting",
    "lat": "44.49358",
    "lng": "-89.55873"
  },
  {
    "country": "US",
    "name": "Williams Bay",
    "lat": "42.57807",
    "lng": "-88.54093"
  },
  {
    "country": "US",
    "name": "Wind Lake",
    "lat": "42.82946",
    "lng": "-88.1587"
  },
  {
    "country": "US",
    "name": "Wind Point",
    "lat": "42.78446",
    "lng": "-87.76619"
  },
  {
    "country": "US",
    "name": "Windsor",
    "lat": "43.21833",
    "lng": "-89.34151"
  },
  {
    "country": "US",
    "name": "Winneconne",
    "lat": "44.11082",
    "lng": "-88.71261"
  },
  {
    "country": "US",
    "name": "Wisconsin Dells",
    "lat": "43.62748",
    "lng": "-89.77096"
  },
  {
    "country": "US",
    "name": "Wisconsin Rapids",
    "lat": "44.38358",
    "lng": "-89.81735"
  },
  {
    "country": "US",
    "name": "Wittenberg",
    "lat": "44.8272",
    "lng": "-89.16956"
  },
  {
    "country": "US",
    "name": "Woodville",
    "lat": "44.95302",
    "lng": "-92.2913"
  },
  {
    "country": "US",
    "name": "Wrightstown",
    "lat": "44.32582",
    "lng": "-88.16288"
  },
  {
    "country": "US",
    "name": "Benwood",
    "lat": "40.01813",
    "lng": "-80.73425"
  },
  {
    "country": "US",
    "name": "Bethany",
    "lat": "40.20563",
    "lng": "-80.55674"
  },
  {
    "country": "US",
    "name": "Bethlehem",
    "lat": "40.04396",
    "lng": "-80.69064"
  },
  {
    "country": "US",
    "name": "Chester",
    "lat": "40.61312",
    "lng": "-80.56285"
  },
  {
    "country": "US",
    "name": "Follansbee",
    "lat": "40.32757",
    "lng": "-80.59591"
  },
  {
    "country": "US",
    "name": "Hooverson Heights",
    "lat": "40.32479",
    "lng": "-80.57757"
  },
  {
    "country": "US",
    "name": "New Cumberland",
    "lat": "40.49673",
    "lng": "-80.60674"
  },
  {
    "country": "US",
    "name": "Newell",
    "lat": "40.6184",
    "lng": "-80.60424"
  },
  {
    "country": "US",
    "name": "Weirton",
    "lat": "40.41896",
    "lng": "-80.58952"
  },
  {
    "country": "US",
    "name": "Weirton Heights",
    "lat": "40.4084",
    "lng": "-80.53924"
  },
  {
    "country": "US",
    "name": "Wellsburg",
    "lat": "40.27201",
    "lng": "-80.60952"
  },
  {
    "country": "US",
    "name": "West Liberty",
    "lat": "40.16979",
    "lng": "-80.59369"
  },
  {
    "country": "US",
    "name": "Wheeling",
    "lat": "40.06396",
    "lng": "-80.72091"
  },
  {
    "country": "US",
    "name": "Baltic",
    "lat": "41.61704",
    "lng": "-72.08452"
  },
  {
    "country": "US",
    "name": "Newtown",
    "lat": "41.41398",
    "lng": "-73.30345"
  },
  {
    "country": "US",
    "name": "Three Rivers",
    "lat": "42.1812",
    "lng": "-72.36064"
  },
  {
    "country": "US",
    "name": "South Duxbury",
    "lat": "42.02316",
    "lng": "-70.68281"
  },
  {
    "country": "US",
    "name": "Groton",
    "lat": "42.6112",
    "lng": "-71.57451"
  },
  {
    "country": "US",
    "name": "Sheffield",
    "lat": "42.11037",
    "lng": "-73.35511"
  },
  {
    "country": "US",
    "name": "Carmel",
    "lat": "44.79757",
    "lng": "-69.05115"
  },
  {
    "country": "US",
    "name": "Phillips",
    "lat": "44.82311",
    "lng": "-70.33951"
  },
  {
    "country": "US",
    "name": "West Kennebunk",
    "lat": "43.4087",
    "lng": "-70.58144"
  },
  {
    "country": "US",
    "name": "Nowthen",
    "lat": "45.32802",
    "lng": "-93.47023"
  },
  {
    "country": "US",
    "name": "Castleton",
    "lat": "43.61062",
    "lng": "-73.17983"
  },
  {
    "country": "US",
    "name": "Kohler",
    "lat": "43.73916",
    "lng": "-87.78175"
  },
  {
    "country": "US",
    "name": "Ansonia",
    "lat": "41.34621",
    "lng": "-73.079"
  },
  {
    "country": "US",
    "name": "Bethel",
    "lat": "41.37121",
    "lng": "-73.41401"
  },
  {
    "country": "US",
    "name": "Blue Hills",
    "lat": "41.81288",
    "lng": "-72.69759"
  },
  {
    "country": "US",
    "name": "Bridgeport",
    "lat": "41.16704",
    "lng": "-73.20483"
  },
  {
    "country": "US",
    "name": "Bristol",
    "lat": "41.67176",
    "lng": "-72.94927"
  },
  {
    "country": "US",
    "name": "East Windsor",
    "lat": "41.91232",
    "lng": "-72.54509"
  },
  {
    "country": "US",
    "name": "Branford",
    "lat": "41.27954",
    "lng": "-72.8151"
  },
  {
    "country": "US",
    "name": "Byram",
    "lat": "41.00426",
    "lng": "-73.65374"
  },
  {
    "country": "US",
    "name": "Canaan",
    "lat": "42.02731",
    "lng": "-73.32928"
  },
  {
    "country": "US",
    "name": "Canton Valley",
    "lat": "41.83426",
    "lng": "-72.89177"
  },
  {
    "country": "US",
    "name": "Cheshire",
    "lat": "41.49899",
    "lng": "-72.90066"
  },
  {
    "country": "US",
    "name": "Clinton",
    "lat": "41.27871",
    "lng": "-72.52759"
  },
  {
    "country": "US",
    "name": "Colchester",
    "lat": "41.57565",
    "lng": "-72.33203"
  },
  {
    "country": "US",
    "name": "Collinsville",
    "lat": "41.81288",
    "lng": "-72.9201"
  },
  {
    "country": "US",
    "name": "Holbrook",
    "lat": "34.90225",
    "lng": "-110.15818"
  },
  {
    "country": "US",
    "name": "Fillmore",
    "lat": "34.39916",
    "lng": "-118.91815"
  },
  {
    "country": "US",
    "name": "Cool",
    "lat": "38.88722",
    "lng": "-121.01472"
  },
  {
    "country": "US",
    "name": "Bisbee",
    "lat": "31.44815",
    "lng": "-109.92841"
  },
  {
    "country": "US",
    "name": "Middletown",
    "lat": "38.7524",
    "lng": "-122.61499"
  },
  {
    "country": "US",
    "name": "Black Canyon City",
    "lat": "34.07087",
    "lng": "-112.15071"
  },
  {
    "country": "US",
    "name": "South Taft",
    "lat": "35.13469",
    "lng": "-119.45623"
  },
  {
    "country": "US",
    "name": "Vine Hill",
    "lat": "38.00853",
    "lng": "-122.09608"
  },
  {
    "country": "US",
    "name": "Dighton",
    "lat": "38.48196",
    "lng": "-100.46708"
  },
  {
    "country": "US",
    "name": "Mora",
    "lat": "35.9742",
    "lng": "-105.33001"
  },
  {
    "country": "US",
    "name": "Blackwater",
    "lat": "33.03117",
    "lng": "-111.58263"
  },
  {
    "country": "US",
    "name": "Mona",
    "lat": "39.81607",
    "lng": "-111.85549"
  },
  {
    "country": "US",
    "name": "Buckeye",
    "lat": "33.37032",
    "lng": "-112.58378"
  },
  {
    "country": "US",
    "name": "Bullhead City",
    "lat": "35.14778",
    "lng": "-114.5683"
  },
  {
    "country": "US",
    "name": "Bylas",
    "lat": "33.13428",
    "lng": "-110.12004"
  },
  {
    "country": "US",
    "name": "Cactus Flat",
    "lat": "32.7584",
    "lng": "-109.71619"
  },
  {
    "country": "US",
    "name": "Camp Verde",
    "lat": "34.56364",
    "lng": "-111.85432"
  },
  {
    "country": "US",
    "name": "Canyon Day",
    "lat": "33.78477",
    "lng": "-110.02649"
  },
  {
    "country": "US",
    "name": "Carefree",
    "lat": "33.82226",
    "lng": "-111.9182"
  },
  {
    "country": "US",
    "name": "Casa Blanca",
    "lat": "33.12033",
    "lng": "-111.88819"
  },
  {
    "country": "US",
    "name": "Casa Grande",
    "lat": "32.8795",
    "lng": "-111.75735"
  },
  {
    "country": "US",
    "name": "Casas Adobes",
    "lat": "32.32341",
    "lng": "-110.9951"
  },
  {
    "country": "US",
    "name": "Catalina",
    "lat": "32.50556",
    "lng": "-110.92111"
  },
  {
    "country": "US",
    "name": "Catalina Foothills",
    "lat": "32.29785",
    "lng": "-110.9187"
  },
  {
    "country": "US",
    "name": "Cave Creek",
    "lat": "33.83333",
    "lng": "-111.95083"
  },
  {
    "country": "US",
    "name": "Chandler",
    "lat": "33.30616",
    "lng": "-111.84125"
  },
  {
    "country": "US",
    "name": "Chinle",
    "lat": "36.15445",
    "lng": "-109.55261"
  },
  {
    "country": "US",
    "name": "Chino Valley",
    "lat": "34.75752",
    "lng": "-112.45378"
  },
  {
    "country": "US",
    "name": "Cibecue",
    "lat": "34.04477",
    "lng": "-110.48539"
  },
  {
    "country": "US",
    "name": "Cienega Springs",
    "lat": "34.18863",
    "lng": "-114.22467"
  },
  {
    "country": "US",
    "name": "Citrus Park",
    "lat": "33.54865",
    "lng": "-112.44433"
  },
  {
    "country": "US",
    "name": "Clarkdale",
    "lat": "34.77113",
    "lng": "-112.05794"
  },
  {
    "country": "US",
    "name": "Claypool",
    "lat": "33.41117",
    "lng": "-110.84261"
  },
  {
    "country": "US",
    "name": "Clifton",
    "lat": "33.0509",
    "lng": "-109.29618"
  },
  {
    "country": "US",
    "name": "Colorado City",
    "lat": "36.99026",
    "lng": "-112.97577"
  },
  {
    "country": "US",
    "name": "Congress",
    "lat": "34.16253",
    "lng": "-112.85074"
  },
  {
    "country": "US",
    "name": "Coolidge",
    "lat": "32.97784",
    "lng": "-111.51762"
  },
  {
    "country": "US",
    "name": "Cordes Lakes",
    "lat": "34.30781",
    "lng": "-112.10349"
  },
  {
    "country": "US",
    "name": "Cornville",
    "lat": "34.7178",
    "lng": "-111.92154"
  },
  {
    "country": "US",
    "name": "Corona de Tucson",
    "lat": "31.96536",
    "lng": "-110.77564"
  },
  {
    "country": "US",
    "name": "Cottonwood",
    "lat": "34.73919",
    "lng": "-112.00988"
  },
  {
    "country": "US",
    "name": "Desert Hills",
    "lat": "34.5539",
    "lng": "-114.37246"
  },
  {
    "country": "US",
    "name": "Dilkon",
    "lat": "35.38529",
    "lng": "-110.32068"
  },
  {
    "country": "US",
    "name": "Dolan Springs",
    "lat": "35.59194",
    "lng": "-114.27329"
  },
  {
    "country": "US",
    "name": "Douglas",
    "lat": "31.34455",
    "lng": "-109.54534"
  },
  {
    "country": "US",
    "name": "Drexel Heights",
    "lat": "32.14119",
    "lng": "-111.02843"
  },
  {
    "country": "US",
    "name": "Eagar",
    "lat": "34.11124",
    "lng": "-109.29238"
  },
  {
    "country": "US",
    "name": "East Sahuarita",
    "lat": "31.94286",
    "lng": "-110.92842"
  },
  {
    "country": "US",
    "name": "Ehrenberg",
    "lat": "33.60419",
    "lng": "-114.52523"
  },
  {
    "country": "US",
    "name": "El Mirage",
    "lat": "33.61309",
    "lng": "-112.3246"
  },
  {
    "country": "US",
    "name": "Eloy",
    "lat": "32.7559",
    "lng": "-111.55484"
  },
  {
    "country": "US",
    "name": "First Mesa",
    "lat": "35.83667",
    "lng": "-110.38152"
  },
  {
    "country": "US",
    "name": "Flagstaff",
    "lat": "35.19807",
    "lng": "-111.65127"
  },
  {
    "country": "US",
    "name": "Florence",
    "lat": "33.03145",
    "lng": "-111.38734"
  },
  {
    "country": "US",
    "name": "Flowing Wells",
    "lat": "32.29396",
    "lng": "-111.00982"
  },
  {
    "country": "US",
    "name": "Fort Defiance",
    "lat": "35.74446",
    "lng": "-109.07648"
  },
  {
    "country": "US",
    "name": "Fortuna Foothills",
    "lat": "32.65783",
    "lng": "-114.41189"
  },
  {
    "country": "US",
    "name": "Fountain Hills",
    "lat": "33.61171",
    "lng": "-111.71736"
  },
  {
    "country": "US",
    "name": "Fredonia",
    "lat": "36.94554",
    "lng": "-112.52659"
  },
  {
    "country": "US",
    "name": "Ganado",
    "lat": "35.7114",
    "lng": "-109.54205"
  },
  {
    "country": "US",
    "name": "Gila Bend",
    "lat": "32.94782",
    "lng": "-112.71683"
  },
  {
    "country": "US",
    "name": "Gilbert",
    "lat": "33.35283",
    "lng": "-111.78903"
  },
  {
    "country": "US",
    "name": "Glendale",
    "lat": "33.53865",
    "lng": "-112.18599"
  },
  {
    "country": "US",
    "name": "Globe",
    "lat": "33.39422",
    "lng": "-110.7865"
  },
  {
    "country": "US",
    "name": "Gold Camp",
    "lat": "33.29367",
    "lng": "-111.30429"
  },
  {
    "country": "US",
    "name": "Golden Valley",
    "lat": "35.22333",
    "lng": "-114.22301"
  },
  {
    "country": "US",
    "name": "Goodyear",
    "lat": "33.43532",
    "lng": "-112.35821"
  },
  {
    "country": "US",
    "name": "Grand Canyon",
    "lat": "36.05443",
    "lng": "-112.13934"
  },
  {
    "country": "US",
    "name": "Grand Canyon Village",
    "lat": "36.04637",
    "lng": "-112.15406"
  },
  {
    "country": "US",
    "name": "Green Valley",
    "lat": "31.85425",
    "lng": "-110.9937"
  },
  {
    "country": "US",
    "name": "Guadalupe",
    "lat": "33.37088",
    "lng": "-111.96292"
  },
  {
    "country": "US",
    "name": "Houck",
    "lat": "35.28308",
    "lng": "-109.20704"
  },
  {
    "country": "US",
    "name": "Huachuca City",
    "lat": "31.62787",
    "lng": "-110.33397"
  },
  {
    "country": "US",
    "name": "Joseph City",
    "lat": "34.95586",
    "lng": "-110.33401"
  },
  {
    "country": "US",
    "name": "Kachina Village",
    "lat": "35.09696",
    "lng": "-111.69266"
  },
  {
    "country": "US",
    "name": "Kaibito",
    "lat": "36.59722",
    "lng": "-111.07431"
  },
  {
    "country": "US",
    "name": "Kayenta",
    "lat": "36.72778",
    "lng": "-110.25458"
  },
  {
    "country": "US",
    "name": "Kearny",
    "lat": "33.05701",
    "lng": "-110.91067"
  },
  {
    "country": "US",
    "name": "Kingman",
    "lat": "35.18944",
    "lng": "-114.05301"
  },
  {
    "country": "US",
    "name": "Lake Havasu City",
    "lat": "34.4839",
    "lng": "-114.32245"
  },
  {
    "country": "US",
    "name": "Lake Montezuma",
    "lat": "34.63224",
    "lng": "-111.77793"
  },
  {
    "country": "US",
    "name": "Lake of the Woods",
    "lat": "34.16393",
    "lng": "-109.98955"
  },
  {
    "country": "US",
    "name": "Laveen",
    "lat": "33.36282",
    "lng": "-112.16932"
  },
  {
    "country": "US",
    "name": "LeChee",
    "lat": "35.03224",
    "lng": "-110.75291"
  },
  {
    "country": "US",
    "name": "Linden",
    "lat": "34.28504",
    "lng": "-110.15706"
  },
  {
    "country": "US",
    "name": "Litchfield Park",
    "lat": "33.49337",
    "lng": "-112.35794"
  },
  {
    "country": "US",
    "name": "Lukachukai",
    "lat": "36.41695",
    "lng": "-109.22871"
  },
  {
    "country": "US",
    "name": "Mammoth",
    "lat": "32.72257",
    "lng": "-110.64065"
  },
  {
    "country": "US",
    "name": "Many Farms",
    "lat": "36.35278",
    "lng": "-109.61789"
  },
  {
    "country": "US",
    "name": "Marana",
    "lat": "32.43674",
    "lng": "-111.22538"
  },
  {
    "country": "US",
    "name": "Maricopa",
    "lat": "33.05811",
    "lng": "-112.04764"
  },
  {
    "country": "US",
    "name": "Mayer",
    "lat": "34.39781",
    "lng": "-112.23627"
  },
  {
    "country": "US",
    "name": "Meadview",
    "lat": "36.00221",
    "lng": "-114.06829"
  },
  {
    "country": "US",
    "name": "Mesa",
    "lat": "33.42227",
    "lng": "-111.82264"
  },
  {
    "country": "US",
    "name": "Mescal",
    "lat": "31.99008",
    "lng": "-110.43535"
  },
  {
    "country": "US",
    "name": "Miami",
    "lat": "33.39922",
    "lng": "-110.86872"
  },
  {
    "country": "US",
    "name": "Mohave Valley",
    "lat": "34.93306",
    "lng": "-114.58885"
  },
  {
    "country": "US",
    "name": "Morenci",
    "lat": "33.07867",
    "lng": "-109.36535"
  },
  {
    "country": "US",
    "name": "Mountainaire",
    "lat": "35.08529",
    "lng": "-111.66599"
  },
  {
    "country": "US",
    "name": "Naco",
    "lat": "31.33538",
    "lng": "-109.94813"
  },
  {
    "country": "US",
    "name": "New River",
    "lat": "33.91587",
    "lng": "-112.13599"
  },
  {
    "country": "US",
    "name": "Nogales",
    "lat": "31.34038",
    "lng": "-110.93425"
  },
  {
    "country": "US",
    "name": "Oracle",
    "lat": "32.61091",
    "lng": "-110.77093"
  },
  {
    "country": "US",
    "name": "Oro Valley",
    "lat": "32.39091",
    "lng": "-110.96649"
  },
  {
    "country": "US",
    "name": "Page",
    "lat": "36.91472",
    "lng": "-111.45583"
  },
  {
    "country": "US",
    "name": "Paradise Valley",
    "lat": "33.53115",
    "lng": "-111.94265"
  },
  {
    "country": "US",
    "name": "Parker",
    "lat": "34.15002",
    "lng": "-114.28912"
  },
  {
    "country": "US",
    "name": "Parks",
    "lat": "35.26057",
    "lng": "-111.94877"
  },
  {
    "country": "US",
    "name": "Paulden",
    "lat": "34.88558",
    "lng": "-112.46823"
  },
  {
    "country": "US",
    "name": "Payson",
    "lat": "34.23087",
    "lng": "-111.32514"
  },
  {
    "country": "US",
    "name": "Peach Springs",
    "lat": "35.52916",
    "lng": "-113.42549"
  },
  {
    "country": "US",
    "name": "Peoria",
    "lat": "33.5806",
    "lng": "-112.23738"
  },
  {
    "country": "US",
    "name": "Peridot",
    "lat": "33.31034",
    "lng": "-110.45538"
  },
  {
    "country": "US",
    "name": "Phoenix",
    "lat": "33.44838",
    "lng": "-112.07404"
  },
  {
    "country": "US",
    "name": "Picture Rocks",
    "lat": "32.34591",
    "lng": "-111.24621"
  },
  {
    "country": "US",
    "name": "Pima",
    "lat": "32.89656",
    "lng": "-109.82835"
  },
  {
    "country": "US",
    "name": "Pine",
    "lat": "34.38447",
    "lng": "-111.45514"
  },
  {
    "country": "US",
    "name": "Pinetop-Lakeside",
    "lat": "34.14254",
    "lng": "-109.96038"
  },
  {
    "country": "US",
    "name": "Pirtleville",
    "lat": "31.35716",
    "lng": "-109.56352"
  },
  {
    "country": "US",
    "name": "Prescott",
    "lat": "34.54002",
    "lng": "-112.4685"
  },
  {
    "country": "US",
    "name": "Prescott Valley",
    "lat": "34.61002",
    "lng": "-112.31572"
  },
  {
    "country": "US",
    "name": "Quartzsite",
    "lat": "33.66391",
    "lng": "-114.22995"
  },
  {
    "country": "US",
    "name": "Queen Creek",
    "lat": "33.24866",
    "lng": "-111.6343"
  },
  {
    "country": "US",
    "name": "Rio Verde",
    "lat": "33.72254",
    "lng": "-111.67569"
  },
  {
    "country": "US",
    "name": "Rio Rico",
    "lat": "31.47148",
    "lng": "-110.97648"
  },
  {
    "country": "US",
    "name": "Sacaton",
    "lat": "33.07672",
    "lng": "-111.7393"
  },
  {
    "country": "US",
    "name": "Safford",
    "lat": "32.83395",
    "lng": "-109.70758"
  },
  {
    "country": "US",
    "name": "Sahuarita",
    "lat": "31.95758",
    "lng": "-110.95565"
  },
  {
    "country": "US",
    "name": "Saint David",
    "lat": "31.90425",
    "lng": "-110.21424"
  },
  {
    "country": "US",
    "name": "Saint Johns",
    "lat": "34.50587",
    "lng": "-109.36093"
  },
  {
    "country": "US",
    "name": "Saint Michaels",
    "lat": "35.64474",
    "lng": "-109.09565"
  },
  {
    "country": "US",
    "name": "Salome",
    "lat": "33.78114",
    "lng": "-113.61465"
  },
  {
    "country": "US",
    "name": "San Carlos",
    "lat": "33.34562",
    "lng": "-110.45504"
  },
  {
    "country": "US",
    "name": "San Carlos",
    "lat": "33.34588",
    "lng": "-111.8507"
  },
  {
    "country": "US",
    "name": "San Luis",
    "lat": "32.487",
    "lng": "-114.78218"
  },
  {
    "country": "US",
    "name": "San Manuel",
    "lat": "32.59979",
    "lng": "-110.63093"
  },
  {
    "country": "US",
    "name": "Scottsdale",
    "lat": "33.50921",
    "lng": "-111.89903"
  },
  {
    "country": "US",
    "name": "Sedona",
    "lat": "34.86974",
    "lng": "-111.76099"
  },
  {
    "country": "US",
    "name": "Sells",
    "lat": "31.91202",
    "lng": "-111.88123"
  },
  {
    "country": "US",
    "name": "Show Low",
    "lat": "34.25421",
    "lng": "-110.02983"
  },
  {
    "country": "US",
    "name": "Sierra Vista",
    "lat": "31.55454",
    "lng": "-110.30369"
  },
  {
    "country": "US",
    "name": "Snowflake",
    "lat": "34.51337",
    "lng": "-110.07845"
  },
  {
    "country": "US",
    "name": "Somerton",
    "lat": "32.59644",
    "lng": "-114.70968"
  },
  {
    "country": "US",
    "name": "South Tucson",
    "lat": "32.19952",
    "lng": "-110.96842"
  },
  {
    "country": "US",
    "name": "Spring Valley",
    "lat": "34.34503",
    "lng": "-112.15905"
  },
  {
    "country": "US",
    "name": "Springerville",
    "lat": "34.13355",
    "lng": "-109.28834"
  },
  {
    "country": "US",
    "name": "Star Valley",
    "lat": "34.25504",
    "lng": "-111.25847"
  },
  {
    "country": "US",
    "name": "Summit",
    "lat": "32.06702",
    "lng": "-110.95148"
  },
  {
    "country": "US",
    "name": "Sun City",
    "lat": "33.59754",
    "lng": "-112.27182"
  },
  {
    "country": "US",
    "name": "Sun City West",
    "lat": "33.66198",
    "lng": "-112.34127"
  },
  {
    "country": "US",
    "name": "Sun Lakes",
    "lat": "33.21116",
    "lng": "-111.87542"
  },
  {
    "country": "US",
    "name": "Sun Valley",
    "lat": "34.2542",
    "lng": "-111.26125"
  },
  {
    "country": "US",
    "name": "Superior",
    "lat": "33.29395",
    "lng": "-111.09623"
  },
  {
    "country": "US",
    "name": "Surprise",
    "lat": "33.63059",
    "lng": "-112.33322"
  },
  {
    "country": "US",
    "name": "Swift Trail Junction",
    "lat": "32.72979",
    "lng": "-109.71397"
  },
  {
    "country": "US",
    "name": "Tanque Verde",
    "lat": "32.25174",
    "lng": "-110.73731"
  },
  {
    "country": "US",
    "name": "Taylor",
    "lat": "34.46504",
    "lng": "-110.09123"
  },
  {
    "country": "US",
    "name": "Tempe",
    "lat": "33.41477",
    "lng": "-111.90931"
  },
  {
    "country": "US",
    "name": "Tempe Junction",
    "lat": "33.41421",
    "lng": "-111.94348"
  },
  {
    "country": "US",
    "name": "Thatcher",
    "lat": "32.84923",
    "lng": "-109.75925"
  },
  {
    "country": "US",
    "name": "Three Points",
    "lat": "32.07675",
    "lng": "-111.31371"
  },
  {
    "country": "US",
    "name": "Tolleson",
    "lat": "33.45004",
    "lng": "-112.25932"
  },
  {
    "country": "US",
    "name": "Tombstone",
    "lat": "31.71287",
    "lng": "-110.06758"
  },
  {
    "country": "US",
    "name": "Tonto Basin",
    "lat": "33.83171",
    "lng": "-111.29457"
  },
  {
    "country": "US",
    "name": "Tortolita",
    "lat": "32.41035",
    "lng": "-111.01732"
  },
  {
    "country": "US",
    "name": "Tuba City",
    "lat": "36.13499",
    "lng": "-111.23986"
  },
  {
    "country": "US",
    "name": "Tubac",
    "lat": "31.61259",
    "lng": "-111.04592"
  },
  {
    "country": "US",
    "name": "Tucson",
    "lat": "32.22174",
    "lng": "-110.92648"
  },
  {
    "country": "US",
    "name": "Tucson Estates",
    "lat": "32.18758",
    "lng": "-111.09093"
  },
  {
    "country": "US",
    "name": "Vail",
    "lat": "32.04786",
    "lng": "-110.71203"
  },
  {
    "country": "US",
    "name": "Wellton",
    "lat": "32.67283",
    "lng": "-114.14688"
  },
  {
    "country": "US",
    "name": "Whetstone",
    "lat": "31.95731",
    "lng": "-110.34202"
  },
  {
    "country": "US",
    "name": "White Mountain Lake",
    "lat": "34.34865",
    "lng": "-109.99789"
  },
  {
    "country": "US",
    "name": "Whiteriver",
    "lat": "33.83699",
    "lng": "-109.96427"
  },
  {
    "country": "US",
    "name": "Wickenburg",
    "lat": "33.96864",
    "lng": "-112.72962"
  },
  {
    "country": "US",
    "name": "Willcox",
    "lat": "32.25285",
    "lng": "-109.83201"
  },
  {
    "country": "US",
    "name": "Williams",
    "lat": "35.24946",
    "lng": "-112.191"
  },
  {
    "country": "US",
    "name": "Williamson",
    "lat": "34.69002",
    "lng": "-112.54101"
  },
  {
    "country": "US",
    "name": "Willow Valley",
    "lat": "34.91195",
    "lng": "-114.60663"
  },
  {
    "country": "US",
    "name": "Window Rock",
    "lat": "35.68057",
    "lng": "-109.05259"
  },
  {
    "country": "US",
    "name": "Winslow",
    "lat": "35.02419",
    "lng": "-110.69736"
  },
  {
    "country": "US",
    "name": "Youngtown",
    "lat": "33.59393",
    "lng": "-112.30294"
  },
  {
    "country": "US",
    "name": "Yuma",
    "lat": "32.72532",
    "lng": "-114.6244"
  },
  {
    "country": "US",
    "name": "Acton",
    "lat": "34.46999",
    "lng": "-118.19674"
  },
  {
    "country": "US",
    "name": "Adelanto",
    "lat": "34.58277",
    "lng": "-117.40922"
  },
  {
    "country": "US",
    "name": "Agoura",
    "lat": "34.14306",
    "lng": "-118.73787"
  },
  {
    "country": "US",
    "name": "Agoura Hills",
    "lat": "34.13639",
    "lng": "-118.77453"
  },
  {
    "country": "US",
    "name": "Agua Dulce",
    "lat": "34.49638",
    "lng": "-118.32563"
  },
  {
    "country": "US",
    "name": "Aguanga",
    "lat": "33.44281",
    "lng": "-116.86502"
  },
  {
    "country": "US",
    "name": "Ahwahnee",
    "lat": "37.3655",
    "lng": "-119.72627"
  },
  {
    "country": "US",
    "name": "Alameda",
    "lat": "37.76521",
    "lng": "-122.24164"
  },
  {
    "country": "US",
    "name": "Alamo",
    "lat": "37.8502",
    "lng": "-122.03218"
  },
  {
    "country": "US",
    "name": "Albany",
    "lat": "37.88687",
    "lng": "-122.29775"
  },
  {
    "country": "US",
    "name": "Alhambra",
    "lat": "34.09529",
    "lng": "-118.12701"
  },
  {
    "country": "US",
    "name": "Aliso Viejo",
    "lat": "33.56504",
    "lng": "-117.72712"
  },
  {
    "country": "US",
    "name": "Allendale",
    "lat": "38.44463",
    "lng": "-121.94302"
  },
  {
    "country": "US",
    "name": "Alondra Park",
    "lat": "33.88946",
    "lng": "-118.33091"
  },
  {
    "country": "US",
    "name": "Alpaugh",
    "lat": "35.88773",
    "lng": "-119.48734"
  },
  {
    "country": "US",
    "name": "Alpine",
    "lat": "32.83505",
    "lng": "-116.76641"
  },
  {
    "country": "US",
    "name": "Alta Sierra",
    "lat": "35.73126",
    "lng": "-118.5539"
  },
  {
    "country": "US",
    "name": "Alta Sierra",
    "lat": "39.14156",
    "lng": "-121.05384"
  },
  {
    "country": "US",
    "name": "Altadena",
    "lat": "34.18973",
    "lng": "-118.13118"
  },
  {
    "country": "US",
    "name": "Alum Rock",
    "lat": "37.36605",
    "lng": "-121.82718"
  },
  {
    "country": "US",
    "name": "American Canyon",
    "lat": "38.17492",
    "lng": "-122.2608"
  },
  {
    "country": "US",
    "name": "Amesti",
    "lat": "36.96356",
    "lng": "-121.77912"
  },
  {
    "country": "US",
    "name": "Anaheim",
    "lat": "33.83529",
    "lng": "-117.9145"
  },
  {
    "country": "US",
    "name": "Angels Camp",
    "lat": "38.06826",
    "lng": "-120.53965"
  },
  {
    "country": "US",
    "name": "Angwin",
    "lat": "38.57574",
    "lng": "-122.44998"
  },
  {
    "country": "US",
    "name": "Antelope",
    "lat": "38.70824",
    "lng": "-121.32995"
  },
  {
    "country": "US",
    "name": "Antioch",
    "lat": "38.00492",
    "lng": "-121.80579"
  },
  {
    "country": "US",
    "name": "Anza",
    "lat": "33.55503",
    "lng": "-116.67363"
  },
  {
    "country": "US",
    "name": "Apple Valley",
    "lat": "34.50083",
    "lng": "-117.18588"
  },
  {
    "country": "US",
    "name": "Aptos",
    "lat": "36.97717",
    "lng": "-121.8994"
  },
  {
    "country": "US",
    "name": "Arbuckle",
    "lat": "39.0174",
    "lng": "-122.05775"
  },
  {
    "country": "US",
    "name": "Arcadia",
    "lat": "34.13973",
    "lng": "-118.03534"
  },
  {
    "country": "US",
    "name": "Armona",
    "lat": "36.31578",
    "lng": "-119.70846"
  },
  {
    "country": "US",
    "name": "Arnold",
    "lat": "38.25547",
    "lng": "-120.35103"
  },
  {
    "country": "US",
    "name": "Aromas",
    "lat": "36.88856",
    "lng": "-121.643"
  },
  {
    "country": "US",
    "name": "Arroyo Grande",
    "lat": "35.11859",
    "lng": "-120.59073"
  },
  {
    "country": "US",
    "name": "Artesia",
    "lat": "33.86585",
    "lng": "-118.08312"
  },
  {
    "country": "US",
    "name": "Arvin",
    "lat": "35.20913",
    "lng": "-118.82843"
  },
  {
    "country": "US",
    "name": "Ashland",
    "lat": "37.69465",
    "lng": "-122.11385"
  },
  {
    "country": "US",
    "name": "Atascadero",
    "lat": "35.48942",
    "lng": "-120.67073"
  },
  {
    "country": "US",
    "name": "Atherton",
    "lat": "37.46133",
    "lng": "-122.19774"
  },
  {
    "country": "US",
    "name": "Atwater",
    "lat": "37.34772",
    "lng": "-120.60908"
  },
  {
    "country": "US",
    "name": "Auberry",
    "lat": "37.08078",
    "lng": "-119.48541"
  },
  {
    "country": "US",
    "name": "Auburn",
    "lat": "38.89657",
    "lng": "-121.07689"
  },
  {
    "country": "US",
    "name": "Auburn Lake Trails",
    "lat": "38.91434",
    "lng": "-120.95244"
  },
  {
    "country": "US",
    "name": "August",
    "lat": "37.97881",
    "lng": "-121.26217"
  },
  {
    "country": "US",
    "name": "Avalon",
    "lat": "33.34281",
    "lng": "-118.32785"
  },
  {
    "country": "US",
    "name": "Avenal",
    "lat": "36.00412",
    "lng": "-120.12903"
  },
  {
    "country": "US",
    "name": "Avila Beach",
    "lat": "35.17998",
    "lng": "-120.73184"
  },
  {
    "country": "US",
    "name": "Avocado Heights",
    "lat": "34.03612",
    "lng": "-117.99118"
  },
  {
    "country": "US",
    "name": "Azusa",
    "lat": "34.13362",
    "lng": "-117.90756"
  },
  {
    "country": "US",
    "name": "Bakersfield",
    "lat": "35.37329",
    "lng": "-119.01871"
  },
  {
    "country": "US",
    "name": "Baldwin Park",
    "lat": "34.08529",
    "lng": "-117.9609"
  },
  {
    "country": "US",
    "name": "Banning",
    "lat": "33.92557",
    "lng": "-116.87641"
  },
  {
    "country": "US",
    "name": "Barstow",
    "lat": "34.89859",
    "lng": "-117.02282"
  },
  {
    "country": "US",
    "name": "Barstow Heights",
    "lat": "34.86971",
    "lng": "-117.05615"
  },
  {
    "country": "US",
    "name": "Bay Point",
    "lat": "38.02909",
    "lng": "-121.96163"
  },
  {
    "country": "US",
    "name": "Bear Valley Springs",
    "lat": "35.15913",
    "lng": "-118.62842"
  },
  {
    "country": "US",
    "name": "Beaumont",
    "lat": "33.92946",
    "lng": "-116.97725"
  },
  {
    "country": "US",
    "name": "Bell",
    "lat": "33.97751",
    "lng": "-118.18702"
  },
  {
    "country": "US",
    "name": "Bell Gardens",
    "lat": "33.96529",
    "lng": "-118.15146"
  },
  {
    "country": "US",
    "name": "Bellflower",
    "lat": "33.88168",
    "lng": "-118.11701"
  },
  {
    "country": "US",
    "name": "Belmont",
    "lat": "37.52021",
    "lng": "-122.2758"
  },
  {
    "country": "US",
    "name": "Belvedere",
    "lat": "34.04057",
    "lng": "-118.16924"
  },
  {
    "country": "US",
    "name": "Belvedere",
    "lat": "37.8727",
    "lng": "-122.46442"
  },
  {
    "country": "US",
    "name": "Ben Lomond",
    "lat": "37.08911",
    "lng": "-122.08635"
  },
  {
    "country": "US",
    "name": "Benicia",
    "lat": "38.04937",
    "lng": "-122.15858"
  },
  {
    "country": "US",
    "name": "Berkeley",
    "lat": "37.87159",
    "lng": "-122.27275"
  },
  {
    "country": "US",
    "name": "Bermuda Dunes",
    "lat": "33.7428",
    "lng": "-116.28918"
  },
  {
    "country": "US",
    "name": "Berry Creek",
    "lat": "39.64516",
    "lng": "-121.4033"
  },
  {
    "country": "US",
    "name": "Bethel Island",
    "lat": "38.01492",
    "lng": "-121.64051"
  },
  {
    "country": "US",
    "name": "Beverly Hills",
    "lat": "34.07362",
    "lng": "-118.40036"
  },
  {
    "country": "US",
    "name": "Big Bear City",
    "lat": "34.26112",
    "lng": "-116.84503"
  },
  {
    "country": "US",
    "name": "Big Bear Lake",
    "lat": "34.2439",
    "lng": "-116.91142"
  },
  {
    "country": "US",
    "name": "Big Pine",
    "lat": "37.16493",
    "lng": "-118.28955"
  },
  {
    "country": "US",
    "name": "Big River",
    "lat": "34.14002",
    "lng": "-114.36134"
  },
  {
    "country": "US",
    "name": "Biggs",
    "lat": "39.41239",
    "lng": "-121.71275"
  },
  {
    "country": "US",
    "name": "Biola",
    "lat": "36.80217",
    "lng": "-120.01627"
  },
  {
    "country": "US",
    "name": "Bishop",
    "lat": "37.36354",
    "lng": "-118.39511"
  },
  {
    "country": "US",
    "name": "Blackhawk",
    "lat": "37.82076",
    "lng": "-121.90774"
  },
  {
    "country": "US",
    "name": "Bloomington",
    "lat": "34.07029",
    "lng": "-117.39588"
  },
  {
    "country": "US",
    "name": "Blythe",
    "lat": "33.6103",
    "lng": "-114.59635"
  },
  {
    "country": "US",
    "name": "Bodega Bay",
    "lat": "38.33325",
    "lng": "-123.04806"
  },
  {
    "country": "US",
    "name": "Bodfish",
    "lat": "35.58801",
    "lng": "-118.49203"
  },
  {
    "country": "US",
    "name": "Bolinas",
    "lat": "37.90937",
    "lng": "-122.68637"
  },
  {
    "country": "US",
    "name": "Bonita",
    "lat": "32.65783",
    "lng": "-117.03003"
  },
  {
    "country": "US",
    "name": "Bonny Doon",
    "lat": "37.04162",
    "lng": "-122.15052"
  },
  {
    "country": "US",
    "name": "Bonsall",
    "lat": "33.28892",
    "lng": "-117.22559"
  },
  {
    "country": "US",
    "name": "Boonville",
    "lat": "39.00907",
    "lng": "-123.36612"
  },
  {
    "country": "US",
    "name": "Boron",
    "lat": "34.99942",
    "lng": "-117.64978"
  },
  {
    "country": "US",
    "name": "Boronda",
    "lat": "36.69885",
    "lng": "-121.67495"
  },
  {
    "country": "US",
    "name": "Borrego Springs",
    "lat": "33.25587",
    "lng": "-116.37501"
  },
  {
    "country": "US",
    "name": "Bostonia",
    "lat": "32.80755",
    "lng": "-116.93642"
  },
  {
    "country": "US",
    "name": "Boulder Creek",
    "lat": "37.12606",
    "lng": "-122.12219"
  },
  {
    "country": "US",
    "name": "Boyle Heights",
    "lat": "34.0339",
    "lng": "-118.20535"
  },
  {
    "country": "US",
    "name": "Boyes Hot Springs",
    "lat": "38.3138",
    "lng": "-122.48193"
  },
  {
    "country": "US",
    "name": "Bradbury",
    "lat": "34.14695",
    "lng": "-117.9709"
  },
  {
    "country": "US",
    "name": "Brawley",
    "lat": "32.97866",
    "lng": "-115.53027"
  },
  {
    "country": "US",
    "name": "Brea",
    "lat": "33.91668",
    "lng": "-117.90006"
  },
  {
    "country": "US",
    "name": "Brentwood",
    "lat": "37.93187",
    "lng": "-121.69579"
  },
  {
    "country": "US",
    "name": "Bridgeport",
    "lat": "38.25575",
    "lng": "-119.23127"
  },
  {
    "country": "US",
    "name": "Brisbane",
    "lat": "37.68077",
    "lng": "-122.39997"
  },
  {
    "country": "US",
    "name": "Broadmoor",
    "lat": "37.6866",
    "lng": "-122.48275"
  },
  {
    "country": "US",
    "name": "Brookdale",
    "lat": "37.10634",
    "lng": "-122.10608"
  },
  {
    "country": "US",
    "name": "Brooktrails",
    "lat": "39.44377",
    "lng": "-123.38529"
  },
  {
    "country": "US",
    "name": "Buellton",
    "lat": "34.6136",
    "lng": "-120.19265"
  },
  {
    "country": "US",
    "name": "Buena Park",
    "lat": "33.86751",
    "lng": "-117.99812"
  },
  {
    "country": "US",
    "name": "Buena Vista",
    "lat": "37.32133",
    "lng": "-121.91662"
  },
  {
    "country": "US",
    "name": "Burbank",
    "lat": "34.18084",
    "lng": "-118.30897"
  },
  {
    "country": "US",
    "name": "Burbank",
    "lat": "37.32328",
    "lng": "-121.93162"
  },
  {
    "country": "US",
    "name": "Burlingame",
    "lat": "37.5841",
    "lng": "-122.36608"
  },
  {
    "country": "US",
    "name": "Buttonwillow",
    "lat": "35.40052",
    "lng": "-119.46956"
  },
  {
    "country": "US",
    "name": "Byron",
    "lat": "37.86715",
    "lng": "-121.63801"
  },
  {
    "country": "US",
    "name": "Bystrom",
    "lat": "37.62076",
    "lng": "-120.98577"
  },
  {
    "country": "US",
    "name": "Cabazon",
    "lat": "33.91752",
    "lng": "-116.78724"
  },
  {
    "country": "US",
    "name": "Calabasas",
    "lat": "34.15778",
    "lng": "-118.63842"
  },
  {
    "country": "US",
    "name": "Calexico",
    "lat": "32.67895",
    "lng": "-115.49888"
  },
  {
    "country": "US",
    "name": "California City",
    "lat": "35.1258",
    "lng": "-117.9859"
  },
  {
    "country": "US",
    "name": "Calipatria",
    "lat": "33.1256",
    "lng": "-115.51415"
  },
  {
    "country": "US",
    "name": "Calistoga",
    "lat": "38.5788",
    "lng": "-122.57971"
  },
  {
    "country": "US",
    "name": "Calimesa",
    "lat": "34.0039",
    "lng": "-117.06198"
  },
  {
    "country": "US",
    "name": "Callender",
    "lat": "35.05303",
    "lng": "-120.59628"
  },
  {
    "country": "US",
    "name": "Camarillo",
    "lat": "34.21639",
    "lng": "-119.0376"
  },
  {
    "country": "US",
    "name": "Cambria",
    "lat": "35.56414",
    "lng": "-121.08075"
  },
  {
    "country": "US",
    "name": "Cambrian Park",
    "lat": "37.25689",
    "lng": "-121.93079"
  },
  {
    "country": "US",
    "name": "Cameron Park",
    "lat": "38.66879",
    "lng": "-120.98716"
  },
  {
    "country": "US",
    "name": "Camino",
    "lat": "38.73824",
    "lng": "-120.67493"
  },
  {
    "country": "US",
    "name": "Camp Meeker",
    "lat": "38.42519",
    "lng": "-122.95944"
  },
  {
    "country": "US",
    "name": "Campbell",
    "lat": "37.28717",
    "lng": "-121.94996"
  },
  {
    "country": "US",
    "name": "Campo",
    "lat": "32.60645",
    "lng": "-116.46891"
  },
  {
    "country": "US",
    "name": "Canoga Park",
    "lat": "34.20112",
    "lng": "-118.59814"
  },
  {
    "country": "US",
    "name": "Canyon Lake",
    "lat": "33.68502",
    "lng": "-117.27309"
  },
  {
    "country": "US",
    "name": "Capitola",
    "lat": "36.97523",
    "lng": "-121.95329"
  },
  {
    "country": "US",
    "name": "Carlsbad",
    "lat": "33.15809",
    "lng": "-117.35059"
  },
  {
    "country": "US",
    "name": "Carmel Valley Village",
    "lat": "36.50605",
    "lng": "-121.76594"
  },
  {
    "country": "US",
    "name": "Carmel-by-the-Sea",
    "lat": "36.55524",
    "lng": "-121.92329"
  },
  {
    "country": "US",
    "name": "Carmichael",
    "lat": "38.61713",
    "lng": "-121.32828"
  },
  {
    "country": "US",
    "name": "Carpinteria",
    "lat": "34.39888",
    "lng": "-119.51846"
  },
  {
    "country": "US",
    "name": "Carson",
    "lat": "33.83141",
    "lng": "-118.28202"
  },
  {
    "country": "US",
    "name": "Caruthers",
    "lat": "36.54273",
    "lng": "-119.8332"
  },
  {
    "country": "US",
    "name": "Casa Conejo",
    "lat": "34.18362",
    "lng": "-118.94343"
  },
  {
    "country": "US",
    "name": "Castaic",
    "lat": "34.48888",
    "lng": "-118.62287"
  },
  {
    "country": "US",
    "name": "Castro Valley",
    "lat": "37.6941",
    "lng": "-122.08635"
  },
  {
    "country": "US",
    "name": "Castroville",
    "lat": "36.76579",
    "lng": "-121.758"
  },
  {
    "country": "US",
    "name": "Cathedral City",
    "lat": "33.77974",
    "lng": "-116.46529"
  },
  {
    "country": "US",
    "name": "Cayucos",
    "lat": "35.44275",
    "lng": "-120.89213"
  },
  {
    "country": "US",
    "name": "Cedar Ridge",
    "lat": "38.06576",
    "lng": "-120.27686"
  },
  {
    "country": "US",
    "name": "Ceres",
    "lat": "37.59493",
    "lng": "-120.95771"
  },
  {
    "country": "US",
    "name": "Century City",
    "lat": "34.05557",
    "lng": "-118.41786"
  },
  {
    "country": "US",
    "name": "Cerritos",
    "lat": "33.85835",
    "lng": "-118.06479"
  },
  {
    "country": "US",
    "name": "Channel Islands Beach",
    "lat": "34.15806",
    "lng": "-119.22316"
  },
  {
    "country": "US",
    "name": "Charter Oak",
    "lat": "34.10306",
    "lng": "-117.84589"
  },
  {
    "country": "US",
    "name": "Chatsworth",
    "lat": "34.25723",
    "lng": "-118.6012"
  },
  {
    "country": "US",
    "name": "Cherry Valley",
    "lat": "33.97252",
    "lng": "-116.97725"
  },
  {
    "country": "US",
    "name": "Cherryland",
    "lat": "37.67938",
    "lng": "-122.1033"
  },
  {
    "country": "US",
    "name": "Chico",
    "lat": "39.72849",
    "lng": "-121.83748"
  },
  {
    "country": "US",
    "name": "China Lake Acres",
    "lat": "35.64051",
    "lng": "-117.76395"
  },
  {
    "country": "US",
    "name": "Chinatown",
    "lat": "37.7966",
    "lng": "-122.40858"
  },
  {
    "country": "US",
    "name": "Chino",
    "lat": "34.01223",
    "lng": "-117.68894"
  },
  {
    "country": "US",
    "name": "Chino Hills",
    "lat": "33.9938",
    "lng": "-117.75888"
  },
  {
    "country": "US",
    "name": "Chowchilla",
    "lat": "37.123",
    "lng": "-120.26018"
  },
  {
    "country": "US",
    "name": "Chualar",
    "lat": "36.57052",
    "lng": "-121.51855"
  },
  {
    "country": "US",
    "name": "Chula Vista",
    "lat": "32.64005",
    "lng": "-117.0842"
  },
  {
    "country": "US",
    "name": "Citrus",
    "lat": "34.11501",
    "lng": "-117.89173"
  },
  {
    "country": "US",
    "name": "Citrus Heights",
    "lat": "38.70712",
    "lng": "-121.28106"
  },
  {
    "country": "US",
    "name": "Claremont",
    "lat": "34.09668",
    "lng": "-117.71978"
  },
  {
    "country": "US",
    "name": "Clay",
    "lat": "38.33602",
    "lng": "-121.15939"
  },
  {
    "country": "US",
    "name": "Clayton",
    "lat": "37.94103",
    "lng": "-121.93579"
  },
  {
    "country": "US",
    "name": "Clear Lake Riviera",
    "lat": "38.95406",
    "lng": "-122.72082"
  },
  {
    "country": "US",
    "name": "Clearlake",
    "lat": "38.95823",
    "lng": "-122.62637"
  },
  {
    "country": "US",
    "name": "Clearlake Oaks",
    "lat": "39.02628",
    "lng": "-122.67193"
  },
  {
    "country": "US",
    "name": "Cloverdale",
    "lat": "38.80546",
    "lng": "-123.01722"
  },
  {
    "country": "US",
    "name": "Clovis",
    "lat": "36.82523",
    "lng": "-119.70292"
  },
  {
    "country": "US",
    "name": "Coachella",
    "lat": "33.6803",
    "lng": "-116.17389"
  },
  {
    "country": "US",
    "name": "Coalinga",
    "lat": "36.13968",
    "lng": "-120.36015"
  },
  {
    "country": "US",
    "name": "Coarsegold",
    "lat": "37.26217",
    "lng": "-119.70098"
  },
  {
    "country": "US",
    "name": "Cobb",
    "lat": "38.82213",
    "lng": "-122.72305"
  },
  {
    "country": "US",
    "name": "Colfax",
    "lat": "39.10073",
    "lng": "-120.95328"
  },
  {
    "country": "US",
    "name": "Collierville",
    "lat": "38.21464",
    "lng": "-121.26884"
  },
  {
    "country": "US",
    "name": "Colma",
    "lat": "37.67688",
    "lng": "-122.45969"
  },
  {
    "country": "US",
    "name": "Colton",
    "lat": "34.0739",
    "lng": "-117.31365"
  },
  {
    "country": "US",
    "name": "Columbia",
    "lat": "38.03631",
    "lng": "-120.40131"
  },
  {
    "country": "US",
    "name": "Colusa",
    "lat": "39.21433",
    "lng": "-122.00942"
  },
  {
    "country": "US",
    "name": "Commerce",
    "lat": "34.00057",
    "lng": "-118.15979"
  },
  {
    "country": "US",
    "name": "Compton",
    "lat": "33.89585",
    "lng": "-118.22007"
  },
  {
    "country": "US",
    "name": "Concord",
    "lat": "37.97798",
    "lng": "-122.03107"
  },
  {
    "country": "US",
    "name": "Copperopolis",
    "lat": "37.98104",
    "lng": "-120.64187"
  },
  {
    "country": "US",
    "name": "Corcoran",
    "lat": "36.09801",
    "lng": "-119.5604"
  },
  {
    "country": "US",
    "name": "Corning",
    "lat": "39.92766",
    "lng": "-122.17916"
  },
  {
    "country": "US",
    "name": "Corona",
    "lat": "33.87529",
    "lng": "-117.56644"
  },
  {
    "country": "US",
    "name": "Coronado",
    "lat": "32.68589",
    "lng": "-117.18309"
  },
  {
    "country": "US",
    "name": "Corralitos",
    "lat": "36.98856",
    "lng": "-121.80634"
  },
  {
    "country": "US",
    "name": "Corte Madera",
    "lat": "37.92548",
    "lng": "-122.52748"
  },
  {
    "country": "US",
    "name": "Costa Mesa",
    "lat": "33.64113",
    "lng": "-117.91867"
  },
  {
    "country": "US",
    "name": "Cotati",
    "lat": "38.32686",
    "lng": "-122.70721"
  },
  {
    "country": "US",
    "name": "Coto De Caza",
    "lat": "33.60419",
    "lng": "-117.58699"
  },
  {
    "country": "US",
    "name": "Cottonwood",
    "lat": "38.65824",
    "lng": "-121.97108"
  },
  {
    "country": "US",
    "name": "Country Club",
    "lat": "37.96881",
    "lng": "-121.34078"
  },
  {
    "country": "US",
    "name": "Covelo",
    "lat": "39.79327",
    "lng": "-123.24922"
  },
  {
    "country": "US",
    "name": "Covina",
    "lat": "34.09001",
    "lng": "-117.89034"
  },
  {
    "country": "US",
    "name": "Crest",
    "lat": "32.80727",
    "lng": "-116.86808"
  },
  {
    "country": "US",
    "name": "Crestline",
    "lat": "34.24195",
    "lng": "-117.2856"
  },
  {
    "country": "US",
    "name": "Crockett",
    "lat": "38.05242",
    "lng": "-122.21302"
  },
  {
    "country": "US",
    "name": "Cudahy",
    "lat": "33.96057",
    "lng": "-118.18535"
  },
  {
    "country": "US",
    "name": "Culver City",
    "lat": "34.02112",
    "lng": "-118.39647"
  },
  {
    "country": "US",
    "name": "Cupertino",
    "lat": "37.323",
    "lng": "-122.03218"
  },
  {
    "country": "US",
    "name": "Cutler",
    "lat": "36.52328",
    "lng": "-119.28678"
  },
  {
    "country": "US",
    "name": "Cypress",
    "lat": "33.81696",
    "lng": "-118.03729"
  },
  {
    "country": "US",
    "name": "Daly City",
    "lat": "37.70577",
    "lng": "-122.46192"
  },
  {
    "country": "US",
    "name": "Dana Point",
    "lat": "33.46697",
    "lng": "-117.69811"
  },
  {
    "country": "US",
    "name": "Danville",
    "lat": "37.82159",
    "lng": "-121.99996"
  },
  {
    "country": "US",
    "name": "Davis",
    "lat": "38.54491",
    "lng": "-121.74052"
  },
  {
    "country": "US",
    "name": "Day Valley",
    "lat": "37.03578",
    "lng": "-121.86246"
  },
  {
    "country": "US",
    "name": "Deer Park",
    "lat": "38.68185",
    "lng": "-120.82327"
  },
  {
    "country": "US",
    "name": "Deer Park",
    "lat": "38.53269",
    "lng": "-122.4697"
  },
  {
    "country": "US",
    "name": "Del Mar",
    "lat": "32.95949",
    "lng": "-117.26531"
  },
  {
    "country": "US",
    "name": "Del Monte Forest",
    "lat": "36.58635",
    "lng": "-121.94746"
  },
  {
    "country": "US",
    "name": "Del Aire",
    "lat": "33.91613",
    "lng": "-118.36952"
  },
  {
    "country": "US",
    "name": "Del Rey",
    "lat": "36.65912",
    "lng": "-119.59374"
  },
  {
    "country": "US",
    "name": "Del Rey Oaks",
    "lat": "36.59329",
    "lng": "-121.83495"
  },
  {
    "country": "US",
    "name": "Del Rio",
    "lat": "37.74354",
    "lng": "-121.01188"
  },
  {
    "country": "US",
    "name": "Delano",
    "lat": "35.76884",
    "lng": "-119.24705"
  },
  {
    "country": "US",
    "name": "Delhi",
    "lat": "37.43216",
    "lng": "-120.77854"
  },
  {
    "country": "US",
    "name": "Denair",
    "lat": "37.52632",
    "lng": "-120.79687"
  },
  {
    "country": "US",
    "name": "Descanso",
    "lat": "32.85283",
    "lng": "-116.61585"
  },
  {
    "country": "US",
    "name": "Desert Hot Springs",
    "lat": "33.96173",
    "lng": "-116.50353"
  },
  {
    "country": "US",
    "name": "Desert Shores",
    "lat": "33.4042",
    "lng": "-116.03972"
  },
  {
    "country": "US",
    "name": "Desert View Highlands",
    "lat": "34.59082",
    "lng": "-118.15257"
  },
  {
    "country": "US",
    "name": "Diablo",
    "lat": "37.83493",
    "lng": "-121.95801"
  },
  {
    "country": "US",
    "name": "Diamond Bar",
    "lat": "34.02862",
    "lng": "-117.81034"
  },
  {
    "country": "US",
    "name": "Diamond Springs",
    "lat": "38.69463",
    "lng": "-120.81494"
  },
  {
    "country": "US",
    "name": "Dinuba",
    "lat": "36.54328",
    "lng": "-119.38707"
  },
  {
    "country": "US",
    "name": "Discovery Bay",
    "lat": "37.90854",
    "lng": "-121.60023"
  },
  {
    "country": "US",
    "name": "Dixon",
    "lat": "38.44546",
    "lng": "-121.8233"
  },
  {
    "country": "US",
    "name": "Dogtown",
    "lat": "38.21381",
    "lng": "-121.08855"
  },
  {
    "country": "US",
    "name": "Dollar Point",
    "lat": "39.18796",
    "lng": "-120.09991"
  },
  {
    "country": "US",
    "name": "Dos Palos",
    "lat": "36.98606",
    "lng": "-120.62657"
  },
  {
    "country": "US",
    "name": "Downey",
    "lat": "33.94001",
    "lng": "-118.13257"
  },
  {
    "country": "US",
    "name": "Downieville",
    "lat": "39.55934",
    "lng": "-120.82689"
  },
  {
    "country": "US",
    "name": "Duarte",
    "lat": "34.13945",
    "lng": "-117.97729"
  },
  {
    "country": "US",
    "name": "Dublin",
    "lat": "37.70215",
    "lng": "-121.93579"
  },
  {
    "country": "US",
    "name": "Dunnigan",
    "lat": "38.88518",
    "lng": "-121.96969"
  },
  {
    "country": "US",
    "name": "Durham",
    "lat": "39.64627",
    "lng": "-121.79998"
  },
  {
    "country": "US",
    "name": "Earlimart",
    "lat": "35.88412",
    "lng": "-119.27233"
  },
  {
    "country": "US",
    "name": "East Rancho Dominguez",
    "lat": "33.89807",
    "lng": "-118.19535"
  },
  {
    "country": "US",
    "name": "East Foothills",
    "lat": "37.38105",
    "lng": "-121.81745"
  },
  {
    "country": "US",
    "name": "East Hemet",
    "lat": "33.74002",
    "lng": "-116.93891"
  },
  {
    "country": "US",
    "name": "East La Mirada",
    "lat": "33.92446",
    "lng": "-117.98895"
  },
  {
    "country": "US",
    "name": "East Los Angeles",
    "lat": "34.0239",
    "lng": "-118.17202"
  },
  {
    "country": "US",
    "name": "East Oakdale",
    "lat": "37.78798",
    "lng": "-120.80382"
  },
  {
    "country": "US",
    "name": "East Palo Alto",
    "lat": "37.46883",
    "lng": "-122.14108"
  },
  {
    "country": "US",
    "name": "East Pasadena",
    "lat": "34.13814",
    "lng": "-118.07384"
  },
  {
    "country": "US",
    "name": "East Porterville",
    "lat": "36.05745",
    "lng": "-118.97566"
  },
  {
    "country": "US",
    "name": "East Quincy",
    "lat": "39.93406",
    "lng": "-120.89801"
  },
  {
    "country": "US",
    "name": "East Richmond Heights",
    "lat": "37.94492",
    "lng": "-122.31358"
  },
  {
    "country": "US",
    "name": "East San Gabriel",
    "lat": "34.09168",
    "lng": "-118.09118"
  },
  {
    "country": "US",
    "name": "East Sonora",
    "lat": "37.9777",
    "lng": "-120.3613"
  },
  {
    "country": "US",
    "name": "Easton",
    "lat": "36.65023",
    "lng": "-119.7907"
  },
  {
    "country": "US",
    "name": "El Cajon",
    "lat": "32.79477",
    "lng": "-116.96253"
  },
  {
    "country": "US",
    "name": "El Centro",
    "lat": "32.792",
    "lng": "-115.56305"
  },
  {
    "country": "US",
    "name": "El Cerrito",
    "lat": "37.91576",
    "lng": "-122.31164"
  },
  {
    "country": "US",
    "name": "El Cerrito Corona",
    "lat": "33.84057",
    "lng": "-117.52283"
  },
  {
    "country": "US",
    "name": "El Dorado Hills",
    "lat": "38.68574",
    "lng": "-121.08217"
  },
  {
    "country": "US",
    "name": "El Granada",
    "lat": "37.50272",
    "lng": "-122.46942"
  },
  {
    "country": "US",
    "name": "El Monte",
    "lat": "34.06862",
    "lng": "-118.02757"
  },
  {
    "country": "US",
    "name": "El Rio",
    "lat": "34.23578",
    "lng": "-119.16383"
  },
  {
    "country": "US",
    "name": "El Segundo",
    "lat": "33.91918",
    "lng": "-118.41647"
  },
  {
    "country": "US",
    "name": "El Sobrante",
    "lat": "37.97715",
    "lng": "-122.29525"
  },
  {
    "country": "US",
    "name": "El Verano",
    "lat": "38.29769",
    "lng": "-122.49165"
  },
  {
    "country": "US",
    "name": "Eldridge",
    "lat": "38.3488",
    "lng": "-122.51081"
  },
  {
    "country": "US",
    "name": "Elk Grove",
    "lat": "38.4088",
    "lng": "-121.37162"
  },
  {
    "country": "US",
    "name": "Elkhorn",
    "lat": "36.8244",
    "lng": "-121.7405"
  },
  {
    "country": "US",
    "name": "Elverta",
    "lat": "38.71379",
    "lng": "-121.46273"
  },
  {
    "country": "US",
    "name": "Emerald Lake Hills",
    "lat": "37.46466",
    "lng": "-122.26802"
  },
  {
    "country": "US",
    "name": "Emeryville",
    "lat": "37.83132",
    "lng": "-122.28525"
  },
  {
    "country": "US",
    "name": "Empire",
    "lat": "37.63826",
    "lng": "-120.90215"
  },
  {
    "country": "US",
    "name": "Encinitas",
    "lat": "33.03699",
    "lng": "-117.29198"
  },
  {
    "country": "US",
    "name": "Encino",
    "lat": "34.15917",
    "lng": "-118.50119"
  },
  {
    "country": "US",
    "name": "Escalon",
    "lat": "37.79781",
    "lng": "-120.99792"
  },
  {
    "country": "US",
    "name": "Escondido",
    "lat": "33.11921",
    "lng": "-117.08642"
  },
  {
    "country": "US",
    "name": "Esparto",
    "lat": "38.69213",
    "lng": "-122.01719"
  },
  {
    "country": "US",
    "name": "Eucalyptus Hills",
    "lat": "32.87977",
    "lng": "-116.94669"
  },
  {
    "country": "US",
    "name": "Exeter",
    "lat": "36.29606",
    "lng": "-119.14205"
  },
  {
    "country": "US",
    "name": "Fair Oaks",
    "lat": "38.64463",
    "lng": "-121.27217"
  },
  {
    "country": "US",
    "name": "Fairbanks Ranch",
    "lat": "32.99393",
    "lng": "-117.18726"
  },
  {
    "country": "US",
    "name": "Fairfax",
    "lat": "37.98715",
    "lng": "-122.58887"
  },
  {
    "country": "US",
    "name": "Fairfield",
    "lat": "38.24936",
    "lng": "-122.03997"
  },
  {
    "country": "US",
    "name": "Fairmead",
    "lat": "37.07633",
    "lng": "-120.19295"
  },
  {
    "country": "US",
    "name": "Fairview",
    "lat": "37.67854",
    "lng": "-122.0458"
  },
  {
    "country": "US",
    "name": "Fallbrook",
    "lat": "33.37642",
    "lng": "-117.25115"
  },
  {
    "country": "US",
    "name": "Farmersville",
    "lat": "36.29773",
    "lng": "-119.20678"
  },
  {
    "country": "US",
    "name": "Felton",
    "lat": "37.05134",
    "lng": "-122.0733"
  },
  {
    "country": "US",
    "name": "Firebaugh",
    "lat": "36.85884",
    "lng": "-120.45601"
  },
  {
    "country": "US",
    "name": "Florin",
    "lat": "38.49602",
    "lng": "-121.40884"
  },
  {
    "country": "US",
    "name": "Folsom",
    "lat": "38.67796",
    "lng": "-121.17606"
  },
  {
    "country": "US",
    "name": "Fontana",
    "lat": "34.09223",
    "lng": "-117.43505"
  },
  {
    "country": "US",
    "name": "Foothill Farms",
    "lat": "38.67877",
    "lng": "-121.35114"
  },
  {
    "country": "US",
    "name": "Foothill Ranch",
    "lat": "33.68641",
    "lng": "-117.66088"
  },
  {
    "country": "US",
    "name": "Ford City",
    "lat": "35.15441",
    "lng": "-119.45623"
  },
  {
    "country": "US",
    "name": "Forest Meadows",
    "lat": "38.16851",
    "lng": "-120.40659"
  },
  {
    "country": "US",
    "name": "Forest Ranch",
    "lat": "39.88211",
    "lng": "-121.67275"
  },
  {
    "country": "US",
    "name": "Foresthill",
    "lat": "39.02018",
    "lng": "-120.81799"
  },
  {
    "country": "US",
    "name": "Forestville",
    "lat": "38.47352",
    "lng": "-122.89027"
  },
  {
    "country": "US",
    "name": "Fort Bragg",
    "lat": "39.44572",
    "lng": "-123.80529"
  },
  {
    "country": "US",
    "name": "Fort Irwin",
    "lat": "35.26275",
    "lng": "-116.68475"
  },
  {
    "country": "US",
    "name": "Foster City",
    "lat": "37.55855",
    "lng": "-122.27108"
  },
  {
    "country": "US",
    "name": "Fountain Valley",
    "lat": "33.70918",
    "lng": "-117.95367"
  },
  {
    "country": "US",
    "name": "Fowler",
    "lat": "36.63051",
    "lng": "-119.67847"
  },
  {
    "country": "US",
    "name": "Frazier Park",
    "lat": "34.82276",
    "lng": "-118.94482"
  },
  {
    "country": "US",
    "name": "Freedom",
    "lat": "36.93523",
    "lng": "-121.77301"
  },
  {
    "country": "US",
    "name": "Fremont",
    "lat": "37.54827",
    "lng": "-121.98857"
  },
  {
    "country": "US",
    "name": "French Camp",
    "lat": "37.88409",
    "lng": "-121.27106"
  },
  {
    "country": "US",
    "name": "Fresno",
    "lat": "36.74773",
    "lng": "-119.77237"
  },
  {
    "country": "US",
    "name": "Fullerton",
    "lat": "33.87029",
    "lng": "-117.92534"
  },
  {
    "country": "US",
    "name": "Galt",
    "lat": "38.25464",
    "lng": "-121.29995"
  },
  {
    "country": "US",
    "name": "Garden Acres",
    "lat": "37.96381",
    "lng": "-121.22939"
  },
  {
    "country": "US",
    "name": "Garden Grove",
    "lat": "33.77391",
    "lng": "-117.94145"
  },
  {
    "country": "US",
    "name": "Gardena",
    "lat": "33.88835",
    "lng": "-118.30896"
  },
  {
    "country": "US",
    "name": "Garnet",
    "lat": "33.90196",
    "lng": "-116.54557"
  },
  {
    "country": "US",
    "name": "Georgetown",
    "lat": "38.90684",
    "lng": "-120.83855"
  },
  {
    "country": "US",
    "name": "Gilroy",
    "lat": "37.00578",
    "lng": "-121.56828"
  },
  {
    "country": "US",
    "name": "Glen Avon",
    "lat": "34.01168",
    "lng": "-117.48477"
  },
  {
    "country": "US",
    "name": "Glendale",
    "lat": "34.14251",
    "lng": "-118.25508"
  },
  {
    "country": "US",
    "name": "Glendora",
    "lat": "34.13612",
    "lng": "-117.86534"
  },
  {
    "country": "US",
    "name": "Gold River",
    "lat": "38.62629",
    "lng": "-121.24662"
  },
  {
    "country": "US",
    "name": "Golden Hills",
    "lat": "35.14247",
    "lng": "-118.49036"
  },
  {
    "country": "US",
    "name": "Goleta",
    "lat": "34.43583",
    "lng": "-119.82764"
  },
  {
    "country": "US",
    "name": "Gonzales",
    "lat": "36.50663",
    "lng": "-121.44438"
  },
  {
    "country": "US",
    "name": "Good Hope",
    "lat": "33.76474",
    "lng": "-117.26698"
  },
  {
    "country": "US",
    "name": "Goshen",
    "lat": "36.35106",
    "lng": "-119.42012"
  },
  {
    "country": "US",
    "name": "Grand Terrace",
    "lat": "34.0339",
    "lng": "-117.31365"
  },
  {
    "country": "US",
    "name": "Granite Bay",
    "lat": "38.76323",
    "lng": "-121.16384"
  },
  {
    "country": "US",
    "name": "Granite Hills",
    "lat": "32.80311",
    "lng": "-116.90475"
  },
  {
    "country": "US",
    "name": "Grass Valley",
    "lat": "39.21906",
    "lng": "-121.06106"
  },
  {
    "country": "US",
    "name": "Graton",
    "lat": "38.4363",
    "lng": "-122.86972"
  },
  {
    "country": "US",
    "name": "Green Acres",
    "lat": "33.73808",
    "lng": "-117.07642"
  },
  {
    "country": "US",
    "name": "Green Valley",
    "lat": "34.62165",
    "lng": "-118.41397"
  },
  {
    "country": "US",
    "name": "Green Valley",
    "lat": "38.25297",
    "lng": "-122.16219"
  },
  {
    "country": "US",
    "name": "Greenacres",
    "lat": "35.38329",
    "lng": "-119.10983"
  },
  {
    "country": "US",
    "name": "Greenfield",
    "lat": "35.26885",
    "lng": "-119.00288"
  },
  {
    "country": "US",
    "name": "Greenfield",
    "lat": "36.3208",
    "lng": "-121.24381"
  },
  {
    "country": "US",
    "name": "Gridley",
    "lat": "39.36378",
    "lng": "-121.69358"
  },
  {
    "country": "US",
    "name": "Grover Beach",
    "lat": "35.12164",
    "lng": "-120.62128"
  },
  {
    "country": "US",
    "name": "Guadalupe",
    "lat": "34.97164",
    "lng": "-120.57184"
  },
  {
    "country": "US",
    "name": "Guerneville",
    "lat": "38.50186",
    "lng": "-122.99611"
  },
  {
    "country": "US",
    "name": "Gustine",
    "lat": "37.25772",
    "lng": "-120.99882"
  },
  {
    "country": "US",
    "name": "Hacienda Heights",
    "lat": "33.99307",
    "lng": "-117.96868"
  },
  {
    "country": "US",
    "name": "Half Moon Bay",
    "lat": "37.46355",
    "lng": "-122.42859"
  },
  {
    "country": "US",
    "name": "Hamilton City",
    "lat": "39.74266",
    "lng": "-122.01359"
  },
  {
    "country": "US",
    "name": "Hanford",
    "lat": "36.32745",
    "lng": "-119.64568"
  },
  {
    "country": "US",
    "name": "Harbison Canyon",
    "lat": "32.82033",
    "lng": "-116.83002"
  },
  {
    "country": "US",
    "name": "Hartley",
    "lat": "38.41713",
    "lng": "-121.94691"
  },
  {
    "country": "US",
    "name": "Hawaiian Gardens",
    "lat": "33.8314",
    "lng": "-118.07284"
  },
  {
    "country": "US",
    "name": "Hawthorne",
    "lat": "33.9164",
    "lng": "-118.35257"
  },
  {
    "country": "US",
    "name": "Hayward",
    "lat": "37.66882",
    "lng": "-122.0808"
  },
  {
    "country": "US",
    "name": "Healdsburg",
    "lat": "38.61047",
    "lng": "-122.86916"
  },
  {
    "country": "US",
    "name": "Heber",
    "lat": "32.73089",
    "lng": "-115.52972"
  },
  {
    "country": "US",
    "name": "Hemet",
    "lat": "33.74761",
    "lng": "-116.97307"
  },
  {
    "country": "US",
    "name": "Herald",
    "lat": "38.29575",
    "lng": "-121.24439"
  },
  {
    "country": "US",
    "name": "Hercules",
    "lat": "38.01714",
    "lng": "-122.28858"
  },
  {
    "country": "US",
    "name": "Hermosa Beach",
    "lat": "33.86224",
    "lng": "-118.39952"
  },
  {
    "country": "US",
    "name": "Hesperia",
    "lat": "34.42639",
    "lng": "-117.30088"
  },
  {
    "country": "US",
    "name": "Hidden Hills",
    "lat": "34.16028",
    "lng": "-118.65231"
  },
  {
    "country": "US",
    "name": "Hidden Meadows",
    "lat": "33.22531",
    "lng": "-117.11253"
  },
  {
    "country": "US",
    "name": "Hidden Valley Lake",
    "lat": "38.80796",
    "lng": "-122.55832"
  },
  {
    "country": "US",
    "name": "Highgrove",
    "lat": "34.01585",
    "lng": "-117.33338"
  },
  {
    "country": "US",
    "name": "Highland",
    "lat": "34.12834",
    "lng": "-117.20865"
  },
  {
    "country": "US",
    "name": "Hillsborough",
    "lat": "37.5741",
    "lng": "-122.37942"
  },
  {
    "country": "US",
    "name": "Hollister",
    "lat": "36.85245",
    "lng": "-121.4016"
  },
  {
    "country": "US",
    "name": "Hollywood",
    "lat": "34.09834",
    "lng": "-118.32674"
  },
  {
    "country": "US",
    "name": "Holtville",
    "lat": "32.81116",
    "lng": "-115.38026"
  },
  {
    "country": "US",
    "name": "Home Garden",
    "lat": "36.30328",
    "lng": "-119.63624"
  },
  {
    "country": "US",
    "name": "Home Gardens",
    "lat": "33.87807",
    "lng": "-117.52088"
  },
  {
    "country": "US",
    "name": "Homeland",
    "lat": "33.74308",
    "lng": "-117.1092"
  },
  {
    "country": "US",
    "name": "Hughson",
    "lat": "37.59688",
    "lng": "-120.86604"
  },
  {
    "country": "US",
    "name": "Huntington Beach",
    "lat": "33.6603",
    "lng": "-117.99923"
  },
  {
    "country": "US",
    "name": "Huntington Park",
    "lat": "33.98168",
    "lng": "-118.22507"
  },
  {
    "country": "US",
    "name": "Huron",
    "lat": "36.20273",
    "lng": "-120.10292"
  },
  {
    "country": "US",
    "name": "Idyllwild",
    "lat": "33.74002",
    "lng": "-116.71891"
  },
  {
    "country": "US",
    "name": "Imperial",
    "lat": "32.84755",
    "lng": "-115.56944"
  },
  {
    "country": "US",
    "name": "Imperial Beach",
    "lat": "32.58394",
    "lng": "-117.11308"
  },
  {
    "country": "US",
    "name": "Indian Wells",
    "lat": "33.71791",
    "lng": "-116.34311"
  },
  {
    "country": "US",
    "name": "Indio",
    "lat": "33.7207",
    "lng": "-116.21677"
  },
  {
    "country": "US",
    "name": "Inglewood",
    "lat": "33.96168",
    "lng": "-118.35313"
  },
  {
    "country": "US",
    "name": "Interlaken",
    "lat": "36.95134",
    "lng": "-121.73384"
  },
  {
    "country": "US",
    "name": "Inverness",
    "lat": "38.10103",
    "lng": "-122.85694"
  },
  {
    "country": "US",
    "name": "Inyokern",
    "lat": "35.6469",
    "lng": "-117.81257"
  },
  {
    "country": "US",
    "name": "Ione",
    "lat": "38.35269",
    "lng": "-120.93272"
  },
  {
    "country": "US",
    "name": "Irvine",
    "lat": "33.66946",
    "lng": "-117.82311"
  },
  {
    "country": "US",
    "name": "Irwindale",
    "lat": "34.10695",
    "lng": "-117.93534"
  },
  {
    "country": "US",
    "name": "Isla Vista",
    "lat": "34.41333",
    "lng": "-119.86097"
  },
  {
    "country": "US",
    "name": "Ivanhoe",
    "lat": "36.38717",
    "lng": "-119.21789"
  },
  {
    "country": "US",
    "name": "Jackson",
    "lat": "38.3488",
    "lng": "-120.7741"
  },
  {
    "country": "US",
    "name": "Jamestown",
    "lat": "37.95326",
    "lng": "-120.4227"
  },
  {
    "country": "US",
    "name": "Jamul",
    "lat": "32.717",
    "lng": "-116.87613"
  },
  {
    "country": "US",
    "name": "Joshua Tree",
    "lat": "34.13473",
    "lng": "-116.31307"
  },
  {
    "country": "US",
    "name": "Julian",
    "lat": "33.07866",
    "lng": "-116.60196"
  },
  {
    "country": "US",
    "name": "Kelseyville",
    "lat": "38.97795",
    "lng": "-122.83944"
  },
  {
    "country": "US",
    "name": "Kennedy",
    "lat": "37.92992",
    "lng": "-121.25272"
  },
  {
    "country": "US",
    "name": "Kensington",
    "lat": "37.91048",
    "lng": "-122.28025"
  },
  {
    "country": "US",
    "name": "Kentfield",
    "lat": "37.95215",
    "lng": "-122.5572"
  },
  {
    "country": "US",
    "name": "Kenwood",
    "lat": "38.4138",
    "lng": "-122.54609"
  },
  {
    "country": "US",
    "name": "Kerman",
    "lat": "36.72356",
    "lng": "-120.05988"
  },
  {
    "country": "US",
    "name": "Kernville",
    "lat": "35.75467",
    "lng": "-118.42536"
  },
  {
    "country": "US",
    "name": "Kettleman City",
    "lat": "36.00829",
    "lng": "-119.9618"
  },
  {
    "country": "US",
    "name": "Keyes",
    "lat": "37.5566",
    "lng": "-120.91549"
  },
  {
    "country": "US",
    "name": "King City",
    "lat": "36.21274",
    "lng": "-121.12603"
  },
  {
    "country": "US",
    "name": "Kings Beach",
    "lat": "39.23768",
    "lng": "-120.02658"
  },
  {
    "country": "US",
    "name": "Kingsburg",
    "lat": "36.51384",
    "lng": "-119.55402"
  },
  {
    "country": "US",
    "name": "Knightsen",
    "lat": "37.96881",
    "lng": "-121.66801"
  },
  {
    "country": "US",
    "name": "Koreatown",
    "lat": "34.05779",
    "lng": "-118.30091"
  },
  {
    "country": "US",
    "name": "La Cañada Flintridge",
    "lat": "34.19917",
    "lng": "-118.18785"
  },
  {
    "country": "US",
    "name": "La Habra",
    "lat": "33.93196",
    "lng": "-117.94617"
  },
  {
    "country": "US",
    "name": "La Habra Heights",
    "lat": "33.96085",
    "lng": "-117.95062"
  },
  {
    "country": "US",
    "name": "La Jolla",
    "lat": "32.84727",
    "lng": "-117.2742"
  },
  {
    "country": "US",
    "name": "La Mesa",
    "lat": "32.76783",
    "lng": "-117.02308"
  },
  {
    "country": "US",
    "name": "La Mirada",
    "lat": "33.91724",
    "lng": "-118.01201"
  },
  {
    "country": "US",
    "name": "La Palma",
    "lat": "33.8464",
    "lng": "-118.04673"
  },
  {
    "country": "US",
    "name": "La Presa",
    "lat": "32.70811",
    "lng": "-116.99725"
  },
  {
    "country": "US",
    "name": "La Puente",
    "lat": "34.02001",
    "lng": "-117.94951"
  },
  {
    "country": "US",
    "name": "La Quinta",
    "lat": "33.66336",
    "lng": "-116.31001"
  },
  {
    "country": "US",
    "name": "La Riviera",
    "lat": "38.56685",
    "lng": "-121.3569"
  },
  {
    "country": "US",
    "name": "La Selva Beach",
    "lat": "36.93662",
    "lng": "-121.86468"
  },
  {
    "country": "US",
    "name": "La Verne",
    "lat": "34.10084",
    "lng": "-117.76784"
  },
  {
    "country": "US",
    "name": "Ladera",
    "lat": "37.39994",
    "lng": "-122.1983"
  },
  {
    "country": "US",
    "name": "Ladera Heights",
    "lat": "33.99418",
    "lng": "-118.37535"
  },
  {
    "country": "US",
    "name": "Ladera Ranch",
    "lat": "33.57086",
    "lng": "-117.63561"
  },
  {
    "country": "US",
    "name": "Lafayette",
    "lat": "37.88576",
    "lng": "-122.11802"
  },
  {
    "country": "US",
    "name": "Laguna",
    "lat": "38.42102",
    "lng": "-121.42384"
  },
  {
    "country": "US",
    "name": "Laguna Beach",
    "lat": "33.54225",
    "lng": "-117.78311"
  },
  {
    "country": "US",
    "name": "Laguna Hills",
    "lat": "33.61252",
    "lng": "-117.71283"
  },
  {
    "country": "US",
    "name": "Laguna Niguel",
    "lat": "33.52253",
    "lng": "-117.70755"
  },
  {
    "country": "US",
    "name": "Laguna Woods",
    "lat": "33.6103",
    "lng": "-117.72533"
  },
  {
    "country": "US",
    "name": "Lake Arrowhead",
    "lat": "34.24834",
    "lng": "-117.18921"
  },
  {
    "country": "US",
    "name": "Lake Elsinore",
    "lat": "33.66808",
    "lng": "-117.32726"
  },
  {
    "country": "US",
    "name": "Lake Forest",
    "lat": "33.64697",
    "lng": "-117.68922"
  },
  {
    "country": "US",
    "name": "Lake Isabella",
    "lat": "35.61801",
    "lng": "-118.47314"
  },
  {
    "country": "US",
    "name": "Lake Los Angeles",
    "lat": "34.61249",
    "lng": "-117.82812"
  },
  {
    "country": "US",
    "name": "Lake Nacimiento",
    "lat": "35.7283",
    "lng": "-120.87963"
  },
  {
    "country": "US",
    "name": "Lake San Marcos",
    "lat": "33.12615",
    "lng": "-117.20837"
  },
  {
    "country": "US",
    "name": "Lake Wildwood",
    "lat": "39.23295",
    "lng": "-121.20051"
  },
  {
    "country": "US",
    "name": "Lake of the Pines",
    "lat": "39.03962",
    "lng": "-121.05661"
  },
  {
    "country": "US",
    "name": "Lakeland Village",
    "lat": "33.63863",
    "lng": "-117.34393"
  },
  {
    "country": "US",
    "name": "Lakeport",
    "lat": "39.04295",
    "lng": "-122.91583"
  },
  {
    "country": "US",
    "name": "Lakeside",
    "lat": "32.85727",
    "lng": "-116.92225"
  },
  {
    "country": "US",
    "name": "Lakeview",
    "lat": "33.83863",
    "lng": "-117.11809"
  },
  {
    "country": "US",
    "name": "Lakewood",
    "lat": "33.85363",
    "lng": "-118.13396"
  },
  {
    "country": "US",
    "name": "Lamont",
    "lat": "35.25968",
    "lng": "-118.91427"
  },
  {
    "country": "US",
    "name": "Lancaster",
    "lat": "34.69804",
    "lng": "-118.13674"
  },
  {
    "country": "US",
    "name": "Larkspur",
    "lat": "37.93409",
    "lng": "-122.53525"
  },
  {
    "country": "US",
    "name": "Las Flores",
    "lat": "34.03723",
    "lng": "-118.63592"
  },
  {
    "country": "US",
    "name": "Las Flores",
    "lat": "33.58808",
    "lng": "-117.62672"
  },
  {
    "country": "US",
    "name": "Las Lomas",
    "lat": "36.86523",
    "lng": "-121.73495"
  },
  {
    "country": "US",
    "name": "Lathrop",
    "lat": "37.8227",
    "lng": "-121.27661"
  },
  {
    "country": "US",
    "name": "Laton",
    "lat": "36.43328",
    "lng": "-119.6868"
  },
  {
    "country": "US",
    "name": "Lawndale",
    "lat": "33.88724",
    "lng": "-118.35257"
  },
  {
    "country": "US",
    "name": "Laytonville",
    "lat": "39.68821",
    "lng": "-123.48279"
  },
  {
    "country": "US",
    "name": "Le Grand",
    "lat": "37.22855",
    "lng": "-120.24823"
  },
  {
    "country": "US",
    "name": "Lebec",
    "lat": "34.84164",
    "lng": "-118.86482"
  },
  {
    "country": "US",
    "name": "Lemon Grove",
    "lat": "32.74255",
    "lng": "-117.03142"
  },
  {
    "country": "US",
    "name": "Lemoore",
    "lat": "36.30078",
    "lng": "-119.78291"
  },
  {
    "country": "US",
    "name": "Lennox",
    "lat": "33.93807",
    "lng": "-118.35258"
  },
  {
    "country": "US",
    "name": "Lenwood",
    "lat": "34.87665",
    "lng": "-117.10393"
  },
  {
    "country": "US",
    "name": "Leona Valley",
    "lat": "34.61832",
    "lng": "-118.28813"
  },
  {
    "country": "US",
    "name": "Lexington Hills",
    "lat": "37.16467",
    "lng": "-121.97301"
  },
  {
    "country": "US",
    "name": "Lincoln",
    "lat": "38.89156",
    "lng": "-121.29301"
  },
  {
    "country": "US",
    "name": "Lincoln Village",
    "lat": "38.0052",
    "lng": "-121.32828"
  },
  {
    "country": "US",
    "name": "Linda",
    "lat": "39.12767",
    "lng": "-121.5508"
  },
  {
    "country": "US",
    "name": "Linden",
    "lat": "38.02131",
    "lng": "-121.08383"
  },
  {
    "country": "US",
    "name": "Lindsay",
    "lat": "36.20301",
    "lng": "-119.08816"
  },
  {
    "country": "US",
    "name": "Littlerock",
    "lat": "34.5211",
    "lng": "-117.98368"
  },
  {
    "country": "US",
    "name": "Live Oak",
    "lat": "36.98356",
    "lng": "-121.98052"
  },
  {
    "country": "US",
    "name": "Live Oak",
    "lat": "39.27572",
    "lng": "-121.65997"
  },
  {
    "country": "US",
    "name": "Livingston",
    "lat": "37.38688",
    "lng": "-120.72353"
  },
  {
    "country": "US",
    "name": "Livermore",
    "lat": "37.68187",
    "lng": "-121.76801"
  },
  {
    "country": "US",
    "name": "Lockeford",
    "lat": "38.16353",
    "lng": "-121.14994"
  },
  {
    "country": "US",
    "name": "Lodi",
    "lat": "38.1302",
    "lng": "-121.27245"
  },
  {
    "country": "US",
    "name": "Loma Linda",
    "lat": "34.04835",
    "lng": "-117.26115"
  },
  {
    "country": "US",
    "name": "Loma Rica",
    "lat": "39.31183",
    "lng": "-121.41774"
  },
  {
    "country": "US",
    "name": "Lomita",
    "lat": "33.79224",
    "lng": "-118.31507"
  },
  {
    "country": "US",
    "name": "Lompico",
    "lat": "37.1055",
    "lng": "-122.05274"
  },
  {
    "country": "US",
    "name": "Lompoc",
    "lat": "34.63915",
    "lng": "-120.45794"
  },
  {
    "country": "US",
    "name": "London",
    "lat": "36.47606",
    "lng": "-119.44318"
  },
  {
    "country": "US",
    "name": "Lone Pine",
    "lat": "36.60626",
    "lng": "-118.06462"
  },
  {
    "country": "US",
    "name": "Long Beach",
    "lat": "33.76696",
    "lng": "-118.18923"
  },
  {
    "country": "US",
    "name": "Loomis",
    "lat": "38.82129",
    "lng": "-121.193"
  },
  {
    "country": "US",
    "name": "Los Alamitos",
    "lat": "33.80307",
    "lng": "-118.07256"
  },
  {
    "country": "US",
    "name": "Los Alamos",
    "lat": "34.74443",
    "lng": "-120.27821"
  },
  {
    "country": "US",
    "name": "Los Altos",
    "lat": "37.38522",
    "lng": "-122.11413"
  },
  {
    "country": "US",
    "name": "Los Altos Hills",
    "lat": "37.37966",
    "lng": "-122.13746"
  },
  {
    "country": "US",
    "name": "Los Angeles",
    "lat": "34.05223",
    "lng": "-118.24368"
  },
  {
    "country": "US",
    "name": "Los Banos",
    "lat": "37.05828",
    "lng": "-120.84992"
  },
  {
    "country": "US",
    "name": "Los Gatos",
    "lat": "37.22661",
    "lng": "-121.97468"
  },
  {
    "country": "US",
    "name": "Los Olivos",
    "lat": "34.66776",
    "lng": "-120.11487"
  },
  {
    "country": "US",
    "name": "Los Osos",
    "lat": "35.31109",
    "lng": "-120.8324"
  },
  {
    "country": "US",
    "name": "Los Serranos",
    "lat": "33.97279",
    "lng": "-117.70811"
  },
  {
    "country": "US",
    "name": "Lost Hills",
    "lat": "35.61635",
    "lng": "-119.69429"
  },
  {
    "country": "US",
    "name": "Lower Lake",
    "lat": "38.91045",
    "lng": "-122.61026"
  },
  {
    "country": "US",
    "name": "Loyola",
    "lat": "37.35133",
    "lng": "-122.10052"
  },
  {
    "country": "US",
    "name": "Lucerne",
    "lat": "36.38078",
    "lng": "-119.6643"
  },
  {
    "country": "US",
    "name": "Lucerne",
    "lat": "39.09017",
    "lng": "-122.79638"
  },
  {
    "country": "US",
    "name": "Lucerne Valley",
    "lat": "34.44389",
    "lng": "-116.96781"
  },
  {
    "country": "US",
    "name": "Lynwood",
    "lat": "33.93029",
    "lng": "-118.21146"
  },
  {
    "country": "US",
    "name": "Madera",
    "lat": "36.96134",
    "lng": "-120.06072"
  },
  {
    "country": "US",
    "name": "Madera Acres",
    "lat": "37.01911",
    "lng": "-120.06683"
  },
  {
    "country": "US",
    "name": "Magalia",
    "lat": "39.81211",
    "lng": "-121.57831"
  },
  {
    "country": "US",
    "name": "Malibu",
    "lat": "34.02577",
    "lng": "-118.7804"
  },
  {
    "country": "US",
    "name": "Mammoth Lakes",
    "lat": "37.64855",
    "lng": "-118.97208"
  },
  {
    "country": "US",
    "name": "Manhattan Beach",
    "lat": "33.88474",
    "lng": "-118.41091"
  },
  {
    "country": "US",
    "name": "Manteca",
    "lat": "37.79743",
    "lng": "-121.21605"
  },
  {
    "country": "US",
    "name": "Maricopa",
    "lat": "35.05886",
    "lng": "-119.40095"
  },
  {
    "country": "US",
    "name": "Marin City",
    "lat": "37.86854",
    "lng": "-122.50914"
  },
  {
    "country": "US",
    "name": "Marina",
    "lat": "36.6844",
    "lng": "-121.80217"
  },
  {
    "country": "US",
    "name": "Marina del Rey",
    "lat": "33.98029",
    "lng": "-118.45174"
  },
  {
    "country": "US",
    "name": "Mariposa",
    "lat": "37.48494",
    "lng": "-119.96628"
  },
  {
    "country": "US",
    "name": "Martinez",
    "lat": "38.01937",
    "lng": "-122.13413"
  },
  {
    "country": "US",
    "name": "Marysville",
    "lat": "39.14573",
    "lng": "-121.59135"
  },
  {
    "country": "US",
    "name": "Maxwell",
    "lat": "39.27628",
    "lng": "-122.19137"
  },
  {
    "country": "US",
    "name": "Mayflower Village",
    "lat": "34.11501",
    "lng": "-118.00979"
  },
  {
    "country": "US",
    "name": "Maywood",
    "lat": "33.98668",
    "lng": "-118.18535"
  },
  {
    "country": "US",
    "name": "McFarland",
    "lat": "35.67801",
    "lng": "-119.22927"
  },
  {
    "country": "US",
    "name": "Mead Valley",
    "lat": "33.83335",
    "lng": "-117.29615"
  },
  {
    "country": "US",
    "name": "Meadow Vista",
    "lat": "39.00101",
    "lng": "-121.02189"
  },
  {
    "country": "US",
    "name": "Mecca",
    "lat": "33.57219",
    "lng": "-116.0782"
  },
  {
    "country": "US",
    "name": "Meiners Oaks",
    "lat": "34.44694",
    "lng": "-119.27928"
  },
  {
    "country": "US",
    "name": "Mendota",
    "lat": "36.75356",
    "lng": "-120.38156"
  },
  {
    "country": "US",
    "name": "Menifee",
    "lat": "33.72835",
    "lng": "-117.14642"
  },
  {
    "country": "US",
    "name": "Menlo Park",
    "lat": "37.45383",
    "lng": "-122.18219"
  },
  {
    "country": "US",
    "name": "Mentone",
    "lat": "34.07001",
    "lng": "-117.13448"
  },
  {
    "country": "US",
    "name": "Merced",
    "lat": "37.30216",
    "lng": "-120.48297"
  },
  {
    "country": "US",
    "name": "Mesa Verde",
    "lat": "33.60586",
    "lng": "-114.73107"
  },
  {
    "country": "US",
    "name": "Midpines",
    "lat": "37.54438",
    "lng": "-119.92045"
  },
  {
    "country": "US",
    "name": "Midway City",
    "lat": "33.74474",
    "lng": "-117.98923"
  },
  {
    "country": "US",
    "name": "Mill Valley",
    "lat": "37.90604",
    "lng": "-122.54498"
  },
  {
    "country": "US",
    "name": "Millbrae",
    "lat": "37.59855",
    "lng": "-122.38719"
  },
  {
    "country": "US",
    "name": "Milpitas",
    "lat": "37.42827",
    "lng": "-121.90662"
  },
  {
    "country": "US",
    "name": "Minkler",
    "lat": "36.72384",
    "lng": "-119.45818"
  },
  {
    "country": "US",
    "name": "Jurupa Valley",
    "lat": "33.99251",
    "lng": "-117.51644"
  },
  {
    "country": "US",
    "name": "Mira Mesa",
    "lat": "32.9156",
    "lng": "-117.14392"
  },
  {
    "country": "US",
    "name": "Mira Monte",
    "lat": "34.43361",
    "lng": "-119.28511"
  },
  {
    "country": "US",
    "name": "Mission Canyon",
    "lat": "34.45083",
    "lng": "-119.71291"
  },
  {
    "country": "US",
    "name": "Mission District",
    "lat": "37.75993",
    "lng": "-122.41914"
  },
  {
    "country": "US",
    "name": "Mission Hills",
    "lat": "34.68609",
    "lng": "-120.43683"
  },
  {
    "country": "US",
    "name": "Mission Viejo",
    "lat": "33.60002",
    "lng": "-117.672"
  },
  {
    "country": "US",
    "name": "Modesto",
    "lat": "37.6391",
    "lng": "-120.99688"
  },
  {
    "country": "US",
    "name": "Mojave",
    "lat": "35.05247",
    "lng": "-118.17396"
  },
  {
    "country": "US",
    "name": "Mono Vista",
    "lat": "37.9977",
    "lng": "-120.26991"
  },
  {
    "country": "US",
    "name": "Monrovia",
    "lat": "34.14806",
    "lng": "-117.99895"
  },
  {
    "country": "US",
    "name": "Montalvin",
    "lat": "37.99548",
    "lng": "-122.33275"
  },
  {
    "country": "US",
    "name": "Montara",
    "lat": "37.54216",
    "lng": "-122.51609"
  },
  {
    "country": "US",
    "name": "Montclair",
    "lat": "34.07751",
    "lng": "-117.68978"
  },
  {
    "country": "US",
    "name": "Monte Rio",
    "lat": "38.46547",
    "lng": "-123.00889"
  },
  {
    "country": "US",
    "name": "Monte Sereno",
    "lat": "37.23633",
    "lng": "-121.99246"
  },
  {
    "country": "US",
    "name": "Montebello",
    "lat": "34.00946",
    "lng": "-118.10535"
  },
  {
    "country": "US",
    "name": "Montecito",
    "lat": "34.43666",
    "lng": "-119.63208"
  },
  {
    "country": "US",
    "name": "Monterey",
    "lat": "36.60024",
    "lng": "-121.89468"
  },
  {
    "country": "US",
    "name": "Monterey Park",
    "lat": "34.06251",
    "lng": "-118.12285"
  },
  {
    "country": "US",
    "name": "Moorpark",
    "lat": "34.28556",
    "lng": "-118.88204"
  },
  {
    "country": "US",
    "name": "Morada",
    "lat": "38.03853",
    "lng": "-121.24578"
  },
  {
    "country": "US",
    "name": "Moraga",
    "lat": "37.83493",
    "lng": "-122.12969"
  },
  {
    "country": "US",
    "name": "Moreno Valley",
    "lat": "33.93752",
    "lng": "-117.23059"
  },
  {
    "country": "US",
    "name": "Morgan Hill",
    "lat": "37.1305",
    "lng": "-121.65439"
  },
  {
    "country": "US",
    "name": "Morongo Valley",
    "lat": "34.04695",
    "lng": "-116.58085"
  },
  {
    "country": "US",
    "name": "Morro Bay",
    "lat": "35.36581",
    "lng": "-120.8499"
  },
  {
    "country": "US",
    "name": "Moss Beach",
    "lat": "37.52744",
    "lng": "-122.51331"
  },
  {
    "country": "US",
    "name": "Mount Hermon",
    "lat": "37.05106",
    "lng": "-122.05857"
  },
  {
    "country": "US",
    "name": "Mountain House",
    "lat": "37.78326",
    "lng": "-121.54273"
  },
  {
    "country": "US",
    "name": "Mountain Ranch",
    "lat": "38.22825",
    "lng": "-120.54076"
  },
  {
    "country": "US",
    "name": "Mountain View",
    "lat": "38.00881",
    "lng": "-122.11746"
  },
  {
    "country": "US",
    "name": "Mountain View",
    "lat": "37.38605",
    "lng": "-122.08385"
  },
  {
    "country": "US",
    "name": "Mountain View Acres",
    "lat": "34.49666",
    "lng": "-117.34894"
  },
  {
    "country": "US",
    "name": "Murphys",
    "lat": "38.13762",
    "lng": "-120.46105"
  },
  {
    "country": "US",
    "name": "Murrieta",
    "lat": "33.55391",
    "lng": "-117.21392"
  },
  {
    "country": "US",
    "name": "Murrieta Hot Springs",
    "lat": "33.56058",
    "lng": "-117.15809"
  },
  {
    "country": "US",
    "name": "Muscoy",
    "lat": "34.15418",
    "lng": "-117.34421"
  },
  {
    "country": "US",
    "name": "Napa",
    "lat": "38.29714",
    "lng": "-122.28553"
  },
  {
    "country": "US",
    "name": "National City",
    "lat": "32.67811",
    "lng": "-117.0992"
  },
  {
    "country": "US",
    "name": "Needles",
    "lat": "34.84806",
    "lng": "-114.61413"
  },
  {
    "country": "US",
    "name": "Nevada City",
    "lat": "39.26173",
    "lng": "-121.01779"
  },
  {
    "country": "US",
    "name": "Newark",
    "lat": "37.52966",
    "lng": "-122.04024"
  },
  {
    "country": "US",
    "name": "Newcastle",
    "lat": "38.87407",
    "lng": "-121.13328"
  },
  {
    "country": "US",
    "name": "Newman",
    "lat": "37.31383",
    "lng": "-121.02076"
  },
  {
    "country": "US",
    "name": "Newport Beach",
    "lat": "33.61891",
    "lng": "-117.92895"
  },
  {
    "country": "US",
    "name": "Nice",
    "lat": "39.12323",
    "lng": "-122.84833"
  },
  {
    "country": "US",
    "name": "Niland",
    "lat": "33.24004",
    "lng": "-115.51888"
  },
  {
    "country": "US",
    "name": "Nipomo",
    "lat": "35.04275",
    "lng": "-120.476"
  },
  {
    "country": "US",
    "name": "Norco",
    "lat": "33.93113",
    "lng": "-117.54866"
  },
  {
    "country": "US",
    "name": "North Auburn",
    "lat": "38.93129",
    "lng": "-121.08189"
  },
  {
    "country": "US",
    "name": "North Edwards",
    "lat": "35.01664",
    "lng": "-117.83284"
  },
  {
    "country": "US",
    "name": "North El Monte",
    "lat": "34.10279",
    "lng": "-118.02423"
  },
  {
    "country": "US",
    "name": "North Fair Oaks",
    "lat": "37.47438",
    "lng": "-122.19663"
  },
  {
    "country": "US",
    "name": "North Highlands",
    "lat": "38.68574",
    "lng": "-121.37217"
  },
  {
    "country": "US",
    "name": "North Hollywood",
    "lat": "34.17223",
    "lng": "-118.37897"
  },
  {
    "country": "US",
    "name": "North Richmond",
    "lat": "37.95881",
    "lng": "-122.36747"
  },
  {
    "country": "US",
    "name": "Northridge",
    "lat": "34.22834",
    "lng": "-118.53675"
  },
  {
    "country": "US",
    "name": "Norwalk",
    "lat": "33.90224",
    "lng": "-118.08173"
  },
  {
    "country": "US",
    "name": "Novato",
    "lat": "38.10742",
    "lng": "-122.5697"
  },
  {
    "country": "US",
    "name": "Nuevo",
    "lat": "33.80141",
    "lng": "-117.14587"
  },
  {
    "country": "US",
    "name": "Oak Hills",
    "lat": "34.38313",
    "lng": "-117.38135"
  },
  {
    "country": "US",
    "name": "Oak Park",
    "lat": "34.17917",
    "lng": "-118.76287"
  },
  {
    "country": "US",
    "name": "Oak View",
    "lat": "34.4",
    "lng": "-119.30011"
  },
  {
    "country": "US",
    "name": "Oakdale",
    "lat": "37.76659",
    "lng": "-120.84715"
  },
  {
    "country": "US",
    "name": "Oakhurst",
    "lat": "37.328",
    "lng": "-119.64932"
  },
  {
    "country": "US",
    "name": "Oakland",
    "lat": "37.80437",
    "lng": "-122.2708"
  },
  {
    "country": "US",
    "name": "Oakley",
    "lat": "37.99742",
    "lng": "-121.71245"
  },
  {
    "country": "US",
    "name": "Oasis",
    "lat": "33.46586",
    "lng": "-116.09889"
  },
  {
    "country": "US",
    "name": "Occidental",
    "lat": "38.40741",
    "lng": "-122.94833"
  },
  {
    "country": "US",
    "name": "Oceano",
    "lat": "35.09886",
    "lng": "-120.61239"
  },
  {
    "country": "US",
    "name": "Oceanside",
    "lat": "33.19587",
    "lng": "-117.37948"
  },
  {
    "country": "US",
    "name": "Oildale",
    "lat": "35.41968",
    "lng": "-119.01955"
  },
  {
    "country": "US",
    "name": "Ojai",
    "lat": "34.44805",
    "lng": "-119.24289"
  },
  {
    "country": "US",
    "name": "Olivehurst",
    "lat": "39.09545",
    "lng": "-121.55219"
  },
  {
    "country": "US",
    "name": "Ontario",
    "lat": "34.06334",
    "lng": "-117.65089"
  },
  {
    "country": "US",
    "name": "Opal Cliffs",
    "lat": "36.96078",
    "lng": "-121.96413"
  },
  {
    "country": "US",
    "name": "Orange",
    "lat": "33.78779",
    "lng": "-117.85311"
  },
  {
    "country": "US",
    "name": "Orange Cove",
    "lat": "36.62439",
    "lng": "-119.31373"
  },
  {
    "country": "US",
    "name": "Orangevale",
    "lat": "38.67851",
    "lng": "-121.22578"
  },
  {
    "country": "US",
    "name": "Orcutt",
    "lat": "34.86526",
    "lng": "-120.436"
  },
  {
    "country": "US",
    "name": "Orinda",
    "lat": "37.87715",
    "lng": "-122.17969"
  },
  {
    "country": "US",
    "name": "Orland",
    "lat": "39.74738",
    "lng": "-122.19637"
  },
  {
    "country": "US",
    "name": "Orosi",
    "lat": "36.54495",
    "lng": "-119.28734"
  },
  {
    "country": "US",
    "name": "Oroville",
    "lat": "39.51394",
    "lng": "-121.55776"
  },
  {
    "country": "US",
    "name": "Oxnard",
    "lat": "34.1975",
    "lng": "-119.17705"
  },
  {
    "country": "US",
    "name": "Pacheco",
    "lat": "37.98353",
    "lng": "-122.07524"
  },
  {
    "country": "US",
    "name": "Pacifica",
    "lat": "37.61383",
    "lng": "-122.48692"
  },
  {
    "country": "US",
    "name": "Pacific Grove",
    "lat": "36.61774",
    "lng": "-121.91662"
  },
  {
    "country": "US",
    "name": "Pajaro",
    "lat": "36.90412",
    "lng": "-121.74856"
  },
  {
    "country": "US",
    "name": "Palermo",
    "lat": "39.43544",
    "lng": "-121.53802"
  },
  {
    "country": "US",
    "name": "Palm Desert",
    "lat": "33.72255",
    "lng": "-116.37697"
  },
  {
    "country": "US",
    "name": "Palm Springs",
    "lat": "33.8303",
    "lng": "-116.54529"
  },
  {
    "country": "US",
    "name": "Palmdale",
    "lat": "34.57943",
    "lng": "-118.11646"
  },
  {
    "country": "US",
    "name": "Palo Alto",
    "lat": "37.44188",
    "lng": "-122.14302"
  },
  {
    "country": "US",
    "name": "Palos Verdes Estates",
    "lat": "33.80105",
    "lng": "-118.39245"
  },
  {
    "country": "US",
    "name": "Paradise",
    "lat": "39.75961",
    "lng": "-121.62192"
  },
  {
    "country": "US",
    "name": "Paramount",
    "lat": "33.88946",
    "lng": "-118.15979"
  },
  {
    "country": "US",
    "name": "Parksdale",
    "lat": "36.94717",
    "lng": "-120.02294"
  },
  {
    "country": "US",
    "name": "Parkway",
    "lat": "38.49602",
    "lng": "-121.45884"
  },
  {
    "country": "US",
    "name": "Parkwood",
    "lat": "36.92689",
    "lng": "-120.04461"
  },
  {
    "country": "US",
    "name": "Parlier",
    "lat": "36.61162",
    "lng": "-119.52707"
  },
  {
    "country": "US",
    "name": "Pasadena",
    "lat": "34.14778",
    "lng": "-118.14452"
  },
  {
    "country": "US",
    "name": "Pasatiempo",
    "lat": "37.00439",
    "lng": "-122.0258"
  },
  {
    "country": "US",
    "name": "Paso Robles",
    "lat": "35.62664",
    "lng": "-120.691"
  },
  {
    "country": "US",
    "name": "Patterson",
    "lat": "37.4716",
    "lng": "-121.12966"
  },
  {
    "country": "US",
    "name": "Pedley",
    "lat": "33.97529",
    "lng": "-117.47588"
  },
  {
    "country": "US",
    "name": "Penn Valley",
    "lat": "39.196",
    "lng": "-121.19107"
  },
  {
    "country": "US",
    "name": "Penngrove",
    "lat": "38.29964",
    "lng": "-122.66665"
  },
  {
    "country": "US",
    "name": "Perris",
    "lat": "33.78252",
    "lng": "-117.22865"
  },
  {
    "country": "US",
    "name": "Petaluma",
    "lat": "38.23242",
    "lng": "-122.63665"
  },
  {
    "country": "US",
    "name": "Phelan",
    "lat": "34.42611",
    "lng": "-117.57228"
  },
  {
    "country": "US",
    "name": "Pico Rivera",
    "lat": "33.98307",
    "lng": "-118.09673"
  },
  {
    "country": "US",
    "name": "Piedmont",
    "lat": "37.82437",
    "lng": "-122.23163"
  },
  {
    "country": "US",
    "name": "Pine Grove",
    "lat": "38.41297",
    "lng": "-120.65882"
  },
  {
    "country": "US",
    "name": "Pine Mountain Club",
    "lat": "34.84637",
    "lng": "-119.14955"
  },
  {
    "country": "US",
    "name": "Pine Valley",
    "lat": "32.82144",
    "lng": "-116.52918"
  },
  {
    "country": "US",
    "name": "Pinole",
    "lat": "38.00437",
    "lng": "-122.29886"
  },
  {
    "country": "US",
    "name": "Pioneer",
    "lat": "38.43186",
    "lng": "-120.57187"
  },
  {
    "country": "US",
    "name": "Piru",
    "lat": "34.41527",
    "lng": "-118.79398"
  },
  {
    "country": "US",
    "name": "Pismo Beach",
    "lat": "35.14275",
    "lng": "-120.64128"
  },
  {
    "country": "US",
    "name": "Pittsburg",
    "lat": "38.02798",
    "lng": "-121.88468"
  },
  {
    "country": "US",
    "name": "Pixley",
    "lat": "35.96856",
    "lng": "-119.29178"
  },
  {
    "country": "US",
    "name": "Piñon Hills",
    "lat": "34.43333",
    "lng": "-117.64672"
  },
  {
    "country": "US",
    "name": "Placentia",
    "lat": "33.87224",
    "lng": "-117.87034"
  },
  {
    "country": "US",
    "name": "Placerville",
    "lat": "38.72963",
    "lng": "-120.79855"
  },
  {
    "country": "US",
    "name": "Planada",
    "lat": "37.29077",
    "lng": "-120.31852"
  },
  {
    "country": "US",
    "name": "Pleasant Hill",
    "lat": "37.94798",
    "lng": "-122.0608"
  },
  {
    "country": "US",
    "name": "Pleasanton",
    "lat": "37.66243",
    "lng": "-121.87468"
  },
  {
    "country": "US",
    "name": "Plumas Lake",
    "lat": "39.02073",
    "lng": "-121.55802"
  },
  {
    "country": "US",
    "name": "Pollock Pines",
    "lat": "38.76158",
    "lng": "-120.58611"
  },
  {
    "country": "US",
    "name": "Pomona",
    "lat": "34.05529",
    "lng": "-117.75228"
  },
  {
    "country": "US",
    "name": "Port Hueneme",
    "lat": "34.14778",
    "lng": "-119.19511"
  },
  {
    "country": "US",
    "name": "Portola",
    "lat": "39.81046",
    "lng": "-120.4691"
  },
  {
    "country": "US",
    "name": "Portola Hills",
    "lat": "33.67919",
    "lng": "-117.63116"
  },
  {
    "country": "US",
    "name": "Porterville",
    "lat": "36.06523",
    "lng": "-119.01677"
  },
  {
    "country": "US",
    "name": "Portola Valley",
    "lat": "37.38411",
    "lng": "-122.23524"
  },
  {
    "country": "US",
    "name": "Poway",
    "lat": "32.96282",
    "lng": "-117.03586"
  },
  {
    "country": "US",
    "name": "Prunedale",
    "lat": "36.77579",
    "lng": "-121.66967"
  },
  {
    "country": "US",
    "name": "Quail Valley",
    "lat": "33.70697",
    "lng": "-117.24504"
  },
  {
    "country": "US",
    "name": "Quartz Hill",
    "lat": "34.64526",
    "lng": "-118.21813"
  },
  {
    "country": "US",
    "name": "Quincy",
    "lat": "39.93682",
    "lng": "-120.94647"
  },
  {
    "country": "US",
    "name": "Rainbow",
    "lat": "33.41031",
    "lng": "-117.14781"
  },
  {
    "country": "US",
    "name": "Ramona",
    "lat": "33.04171",
    "lng": "-116.86808"
  },
  {
    "country": "US",
    "name": "Rancho Calaveras",
    "lat": "38.12742",
    "lng": "-120.85827"
  },
  {
    "country": "US",
    "name": "Rancho Cordova",
    "lat": "38.58907",
    "lng": "-121.30273"
  },
  {
    "country": "US",
    "name": "Rancho Cucamonga",
    "lat": "34.1064",
    "lng": "-117.59311"
  },
  {
    "country": "US",
    "name": "Rancho Mirage",
    "lat": "33.73974",
    "lng": "-116.41279"
  },
  {
    "country": "US",
    "name": "Rancho Murieta",
    "lat": "38.50185",
    "lng": "-121.09467"
  },
  {
    "country": "US",
    "name": "Rancho Palos Verdes",
    "lat": "33.74446",
    "lng": "-118.38702"
  },
  {
    "country": "US",
    "name": "Rancho Penasquitos",
    "lat": "32.95949",
    "lng": "-117.11531"
  },
  {
    "country": "US",
    "name": "Rancho San Diego",
    "lat": "32.74727",
    "lng": "-116.9353"
  },
  {
    "country": "US",
    "name": "Rancho Santa Fe",
    "lat": "33.02032",
    "lng": "-117.20281"
  },
  {
    "country": "US",
    "name": "Rancho Santa Margarita",
    "lat": "33.64086",
    "lng": "-117.6031"
  },
  {
    "country": "US",
    "name": "Redlands",
    "lat": "34.05557",
    "lng": "-117.18254"
  },
  {
    "country": "US",
    "name": "Redondo Beach",
    "lat": "33.84918",
    "lng": "-118.38841"
  },
  {
    "country": "US",
    "name": "Redwood City",
    "lat": "37.48522",
    "lng": "-122.23635"
  },
  {
    "country": "US",
    "name": "Redwood Shores",
    "lat": "37.53188",
    "lng": "-122.24802"
  },
  {
    "country": "US",
    "name": "Redwood Valley",
    "lat": "39.26544",
    "lng": "-123.20445"
  },
  {
    "country": "US",
    "name": "Reedley",
    "lat": "36.59634",
    "lng": "-119.4504"
  },
  {
    "country": "US",
    "name": "Rialto",
    "lat": "34.1064",
    "lng": "-117.37032"
  },
  {
    "country": "US",
    "name": "Richgrove",
    "lat": "35.79662",
    "lng": "-119.10788"
  },
  {
    "country": "US",
    "name": "Richmond",
    "lat": "37.93576",
    "lng": "-122.34775"
  },
  {
    "country": "US",
    "name": "Ridgecrest",
    "lat": "35.62246",
    "lng": "-117.6709"
  },
  {
    "country": "US",
    "name": "Ridgemark",
    "lat": "36.81246",
    "lng": "-121.36577"
  },
  {
    "country": "US",
    "name": "Rio Del Mar",
    "lat": "36.96828",
    "lng": "-121.90023"
  },
  {
    "country": "US",
    "name": "Rio Linda",
    "lat": "38.69101",
    "lng": "-121.44857"
  },
  {
    "country": "US",
    "name": "Ripon",
    "lat": "37.74159",
    "lng": "-121.12438"
  },
  {
    "country": "US",
    "name": "Riverbank",
    "lat": "37.73604",
    "lng": "-120.93549"
  },
  {
    "country": "US",
    "name": "Riverdale",
    "lat": "36.43106",
    "lng": "-119.85958"
  },
  {
    "country": "US",
    "name": "Riverdale Park",
    "lat": "37.60938",
    "lng": "-121.05188"
  },
  {
    "country": "US",
    "name": "Riverside",
    "lat": "33.95335",
    "lng": "-117.39616"
  },
  {
    "country": "US",
    "name": "Rocklin",
    "lat": "38.79073",
    "lng": "-121.23578"
  },
  {
    "country": "US",
    "name": "Rodeo",
    "lat": "38.03298",
    "lng": "-122.26691"
  },
  {
    "country": "US",
    "name": "Rohnert Park",
    "lat": "38.33964",
    "lng": "-122.7011"
  },
  {
    "country": "US",
    "name": "Rolling Hills",
    "lat": "33.75739",
    "lng": "-118.35752"
  },
  {
    "country": "US",
    "name": "Rolling Hills Estates",
    "lat": "33.78779",
    "lng": "-118.35813"
  },
  {
    "country": "US",
    "name": "Rollingwood",
    "lat": "37.9652",
    "lng": "-122.32997"
  },
  {
    "country": "US",
    "name": "Romoland",
    "lat": "33.74585",
    "lng": "-117.17503"
  },
  {
    "country": "US",
    "name": "Rosamond",
    "lat": "34.86414",
    "lng": "-118.16341"
  },
  {
    "country": "US",
    "name": "Rosedale",
    "lat": "35.38357",
    "lng": "-119.14538"
  },
  {
    "country": "US",
    "name": "Roseland",
    "lat": "38.42213",
    "lng": "-122.72804"
  },
  {
    "country": "US",
    "name": "Rosemead",
    "lat": "34.08057",
    "lng": "-118.07285"
  },
  {
    "country": "US",
    "name": "Rosemont",
    "lat": "38.55185",
    "lng": "-121.36467"
  },
  {
    "country": "US",
    "name": "Roseville",
    "lat": "38.75212",
    "lng": "-121.28801"
  },
  {
    "country": "US",
    "name": "Ross",
    "lat": "37.96242",
    "lng": "-122.55498"
  },
  {
    "country": "US",
    "name": "Rossmoor",
    "lat": "33.78557",
    "lng": "-118.08506"
  },
  {
    "country": "US",
    "name": "Rowland Heights",
    "lat": "33.97612",
    "lng": "-117.90534"
  },
  {
    "country": "US",
    "name": "Rubidoux",
    "lat": "33.99613",
    "lng": "-117.4056"
  },
  {
    "country": "US",
    "name": "Running Springs",
    "lat": "34.20779",
    "lng": "-117.1092"
  },
  {
    "country": "US",
    "name": "Sacramento",
    "lat": "38.58157",
    "lng": "-121.4944"
  },
  {
    "country": "US",
    "name": "Saint Helena",
    "lat": "38.50519",
    "lng": "-122.47026"
  },
  {
    "country": "US",
    "name": "Salida",
    "lat": "37.70576",
    "lng": "-121.08494"
  },
  {
    "country": "US",
    "name": "Salinas",
    "lat": "36.67774",
    "lng": "-121.6555"
  },
  {
    "country": "US",
    "name": "Salton City",
    "lat": "33.29865",
    "lng": "-115.95611"
  },
  {
    "country": "US",
    "name": "San Andreas",
    "lat": "38.19603",
    "lng": "-120.68049"
  },
  {
    "country": "US",
    "name": "San Anselmo",
    "lat": "37.97465",
    "lng": "-122.56164"
  },
  {
    "country": "US",
    "name": "San Antonio Heights",
    "lat": "34.15556",
    "lng": "-117.65644"
  },
  {
    "country": "US",
    "name": "San Bernardino",
    "lat": "34.10834",
    "lng": "-117.28977"
  },
  {
    "country": "US",
    "name": "San Bruno",
    "lat": "37.63049",
    "lng": "-122.41108"
  },
  {
    "country": "US",
    "name": "San Carlos",
    "lat": "37.50716",
    "lng": "-122.26052"
  },
  {
    "country": "US",
    "name": "San Clemente",
    "lat": "33.42697",
    "lng": "-117.61199"
  },
  {
    "country": "US",
    "name": "San Diego",
    "lat": "32.71571",
    "lng": "-117.16472"
  },
  {
    "country": "US",
    "name": "San Diego Country Estates",
    "lat": "33.00671",
    "lng": "-116.78364"
  },
  {
    "country": "US",
    "name": "San Dimas",
    "lat": "34.10668",
    "lng": "-117.80673"
  },
  {
    "country": "US",
    "name": "San Fernando",
    "lat": "34.28195",
    "lng": "-118.43897"
  },
  {
    "country": "US",
    "name": "San Francisco",
    "lat": "37.77493",
    "lng": "-122.41942"
  },
  {
    "country": "US",
    "name": "San Gabriel",
    "lat": "34.09611",
    "lng": "-118.10583"
  },
  {
    "country": "US",
    "name": "San Jacinto",
    "lat": "33.78391",
    "lng": "-116.95864"
  },
  {
    "country": "US",
    "name": "San Joaquin",
    "lat": "36.60662",
    "lng": "-120.18904"
  },
  {
    "country": "US",
    "name": "San Joaquin Hills",
    "lat": "33.61169",
    "lng": "-117.83672"
  },
  {
    "country": "US",
    "name": "San Jose",
    "lat": "37.33939",
    "lng": "-121.89496"
  },
  {
    "country": "US",
    "name": "San Juan Bautista",
    "lat": "36.84551",
    "lng": "-121.538"
  },
  {
    "country": "US",
    "name": "San Juan Capistrano",
    "lat": "33.50169",
    "lng": "-117.66255"
  },
  {
    "country": "US",
    "name": "San Leandro",
    "lat": "37.72493",
    "lng": "-122.15608"
  },
  {
    "country": "US",
    "name": "San Lorenzo",
    "lat": "37.68104",
    "lng": "-122.12441"
  },
  {
    "country": "US",
    "name": "San Luis Obispo",
    "lat": "35.28275",
    "lng": "-120.65962"
  },
  {
    "country": "US",
    "name": "San Marcos",
    "lat": "33.14337",
    "lng": "-117.16614"
  },
  {
    "country": "US",
    "name": "San Marino",
    "lat": "34.1214",
    "lng": "-118.10646"
  },
  {
    "country": "US",
    "name": "San Martin",
    "lat": "37.08495",
    "lng": "-121.61022"
  },
  {
    "country": "US",
    "name": "San Mateo",
    "lat": "37.56299",
    "lng": "-122.32553"
  },
  {
    "country": "US",
    "name": "San Miguel",
    "lat": "35.75247",
    "lng": "-120.69628"
  },
  {
    "country": "US",
    "name": "San Pablo",
    "lat": "37.96215",
    "lng": "-122.34553"
  },
  {
    "country": "US",
    "name": "San Pasqual",
    "lat": "33.09171",
    "lng": "-116.95392"
  },
  {
    "country": "US",
    "name": "San Pedro",
    "lat": "33.73585",
    "lng": "-118.29229"
  },
  {
    "country": "US",
    "name": "San Rafael",
    "lat": "37.97353",
    "lng": "-122.53109"
  },
  {
    "country": "US",
    "name": "San Ramon",
    "lat": "37.77993",
    "lng": "-121.97802"
  },
  {
    "country": "US",
    "name": "Sanger",
    "lat": "36.70801",
    "lng": "-119.55597"
  },
  {
    "country": "US",
    "name": "Santa Ana",
    "lat": "33.74557",
    "lng": "-117.86783"
  },
  {
    "country": "US",
    "name": "Santa Barbara",
    "lat": "34.42083",
    "lng": "-119.69819"
  },
  {
    "country": "US",
    "name": "Santa Clara",
    "lat": "37.35411",
    "lng": "-121.95524"
  },
  {
    "country": "US",
    "name": "Santa Clarita",
    "lat": "34.39166",
    "lng": "-118.54259"
  },
  {
    "country": "US",
    "name": "Santa Cruz",
    "lat": "36.97412",
    "lng": "-122.0308"
  },
  {
    "country": "US",
    "name": "Santa Fe Springs",
    "lat": "33.94724",
    "lng": "-118.08535"
  },
  {
    "country": "US",
    "name": "Santa Margarita",
    "lat": "35.38997",
    "lng": "-120.60906"
  },
  {
    "country": "US",
    "name": "Santa Maria",
    "lat": "34.95303",
    "lng": "-120.43572"
  },
  {
    "country": "US",
    "name": "Santa Monica",
    "lat": "34.01945",
    "lng": "-118.49119"
  },
  {
    "country": "US",
    "name": "Santa Paula",
    "lat": "34.35417",
    "lng": "-119.05927"
  },
  {
    "country": "US",
    "name": "Santa Rosa",
    "lat": "38.44047",
    "lng": "-122.71443"
  },
  {
    "country": "US",
    "name": "Santa Susana",
    "lat": "34.27167",
    "lng": "-118.70898"
  },
  {
    "country": "US",
    "name": "Santa Venetia",
    "lat": "37.99853",
    "lng": "-122.52525"
  },
  {
    "country": "US",
    "name": "Santa Ynez",
    "lat": "34.61443",
    "lng": "-120.07987"
  },
  {
    "country": "US",
    "name": "Santee",
    "lat": "32.83838",
    "lng": "-116.97392"
  },
  {
    "country": "US",
    "name": "Saranap",
    "lat": "37.88492",
    "lng": "-122.07607"
  },
  {
    "country": "US",
    "name": "Saratoga",
    "lat": "37.26383",
    "lng": "-122.02301"
  },
  {
    "country": "US",
    "name": "Saticoy",
    "lat": "34.28306",
    "lng": "-119.14983"
  },
  {
    "country": "US",
    "name": "Sausalito",
    "lat": "37.85909",
    "lng": "-122.48525"
  },
  {
    "country": "US",
    "name": "Scotts Valley",
    "lat": "37.05106",
    "lng": "-122.01468"
  },
  {
    "country": "US",
    "name": "Sea Ranch",
    "lat": "38.71519",
    "lng": "-123.45445"
  },
  {
    "country": "US",
    "name": "Seacliff",
    "lat": "36.97412",
    "lng": "-121.91579"
  },
  {
    "country": "US",
    "name": "Seal Beach",
    "lat": "33.74141",
    "lng": "-118.10479"
  },
  {
    "country": "US",
    "name": "Searles Valley",
    "lat": "35.76745",
    "lng": "-117.40395"
  },
  {
    "country": "US",
    "name": "Seaside",
    "lat": "36.61107",
    "lng": "-121.85162"
  },
  {
    "country": "US",
    "name": "Sebastopol",
    "lat": "38.40214",
    "lng": "-122.82388"
  },
  {
    "country": "US",
    "name": "Sedco Hills",
    "lat": "33.64169",
    "lng": "-117.29087"
  },
  {
    "country": "US",
    "name": "Seeley",
    "lat": "32.79311",
    "lng": "-115.69111"
  },
  {
    "country": "US",
    "name": "Selma",
    "lat": "36.57078",
    "lng": "-119.61208"
  },
  {
    "country": "US",
    "name": "North Hills",
    "lat": "34.23639",
    "lng": "-118.48472"
  },
  {
    "country": "US",
    "name": "Seven Trees",
    "lat": "37.28605",
    "lng": "-121.83856"
  },
  {
    "country": "US",
    "name": "Shackelford",
    "lat": "37.61382",
    "lng": "-120.99271"
  },
  {
    "country": "US",
    "name": "Shadow Hills",
    "lat": "34.26195",
    "lng": "-118.35175"
  },
  {
    "country": "US",
    "name": "Shafter",
    "lat": "35.50051",
    "lng": "-119.27178"
  },
  {
    "country": "US",
    "name": "Shandon",
    "lat": "35.65525",
    "lng": "-120.37543"
  },
  {
    "country": "US",
    "name": "Sherman Oaks",
    "lat": "34.15112",
    "lng": "-118.44925"
  },
  {
    "country": "US",
    "name": "Shingle Springs",
    "lat": "38.66574",
    "lng": "-120.92605"
  },
  {
    "country": "US",
    "name": "Sierra Madre",
    "lat": "34.16167",
    "lng": "-118.05285"
  },
  {
    "country": "US",
    "name": "Signal Hill",
    "lat": "33.80446",
    "lng": "-118.16785"
  },
  {
    "country": "US",
    "name": "Simi Valley",
    "lat": "34.26945",
    "lng": "-118.78148"
  },
  {
    "country": "US",
    "name": "Sky Valley",
    "lat": "33.89001",
    "lng": "-116.35251"
  },
  {
    "country": "US",
    "name": "Sleepy Hollow",
    "lat": "38.01048",
    "lng": "-122.58442"
  },
  {
    "country": "US",
    "name": "Soda Bay",
    "lat": "39.00101",
    "lng": "-122.78916"
  },
  {
    "country": "US",
    "name": "Solana Beach",
    "lat": "32.99115",
    "lng": "-117.27115"
  },
  {
    "country": "US",
    "name": "Soledad",
    "lat": "36.42469",
    "lng": "-121.32632"
  },
  {
    "country": "US",
    "name": "Solvang",
    "lat": "34.59582",
    "lng": "-120.13765"
  },
  {
    "country": "US",
    "name": "Sonoma",
    "lat": "38.29186",
    "lng": "-122.45804"
  },
  {
    "country": "US",
    "name": "Sonora",
    "lat": "37.98409",
    "lng": "-120.38214"
  },
  {
    "country": "US",
    "name": "Soquel",
    "lat": "36.98801",
    "lng": "-121.95663"
  },
  {
    "country": "US",
    "name": "Sorrento Valley",
    "lat": "32.89991",
    "lng": "-117.19451"
  },
  {
    "country": "US",
    "name": "Soulsbyville",
    "lat": "37.98465",
    "lng": "-120.2638"
  },
  {
    "country": "US",
    "name": "South Dos Palos",
    "lat": "36.96439",
    "lng": "-120.65324"
  },
  {
    "country": "US",
    "name": "South El Monte",
    "lat": "34.05195",
    "lng": "-118.04673"
  },
  {
    "country": "US",
    "name": "South Gate",
    "lat": "33.95474",
    "lng": "-118.21202"
  },
  {
    "country": "US",
    "name": "South Lake Tahoe",
    "lat": "38.93324",
    "lng": "-119.98435"
  },
  {
    "country": "US",
    "name": "South Oroville",
    "lat": "39.49655",
    "lng": "-121.55219"
  },
  {
    "country": "US",
    "name": "South Pasadena",
    "lat": "34.11612",
    "lng": "-118.15035"
  },
  {
    "country": "US",
    "name": "South San Francisco",
    "lat": "37.65466",
    "lng": "-122.40775"
  },
  {
    "country": "US",
    "name": "South San Gabriel",
    "lat": "34.04915",
    "lng": "-118.09462"
  },
  {
    "country": "US",
    "name": "South San Jose Hills",
    "lat": "34.01279",
    "lng": "-117.90478"
  },
  {
    "country": "US",
    "name": "South Whittier",
    "lat": "33.95015",
    "lng": "-118.03917"
  },
  {
    "country": "US",
    "name": "South Yuba City",
    "lat": "39.11656",
    "lng": "-121.63913"
  },
  {
    "country": "US",
    "name": "Spring Valley",
    "lat": "32.74477",
    "lng": "-116.99892"
  },
  {
    "country": "US",
    "name": "Squaw Valley",
    "lat": "36.74023",
    "lng": "-119.24679"
  },
  {
    "country": "US",
    "name": "Stallion Springs",
    "lat": "35.08886",
    "lng": "-118.64259"
  },
  {
    "country": "US",
    "name": "Stanford",
    "lat": "37.42411",
    "lng": "-122.16608"
  },
  {
    "country": "US",
    "name": "Stanton",
    "lat": "33.80252",
    "lng": "-117.99312"
  },
  {
    "country": "US",
    "name": "Stockton",
    "lat": "37.9577",
    "lng": "-121.29078"
  },
  {
    "country": "US",
    "name": "Stratford",
    "lat": "36.1894",
    "lng": "-119.82319"
  },
  {
    "country": "US",
    "name": "Strathmore",
    "lat": "36.14551",
    "lng": "-119.06066"
  },
  {
    "country": "US",
    "name": "Strawberry",
    "lat": "37.89687",
    "lng": "-122.50886"
  },
  {
    "country": "US",
    "name": "Studio City",
    "lat": "34.14862",
    "lng": "-118.39647"
  },
  {
    "country": "US",
    "name": "Suisun",
    "lat": "38.23825",
    "lng": "-122.04024"
  },
  {
    "country": "US",
    "name": "Summerland",
    "lat": "34.42138",
    "lng": "-119.59652"
  },
  {
    "country": "US",
    "name": "Sun City",
    "lat": "33.70919",
    "lng": "-117.19726"
  },
  {
    "country": "US",
    "name": "Sunland",
    "lat": "34.26695",
    "lng": "-118.3023"
  },
  {
    "country": "US",
    "name": "Sunnyside",
    "lat": "36.74912",
    "lng": "-119.69931"
  },
  {
    "country": "US",
    "name": "Sunnyslope",
    "lat": "34.01196",
    "lng": "-117.43338"
  },
  {
    "country": "US",
    "name": "Sunnyvale",
    "lat": "37.36883",
    "lng": "-122.03635"
  },
  {
    "country": "US",
    "name": "Sutter",
    "lat": "39.15989",
    "lng": "-121.75275"
  },
  {
    "country": "US",
    "name": "Sutter Creek",
    "lat": "38.39297",
    "lng": "-120.80244"
  },
  {
    "country": "US",
    "name": "Taft",
    "lat": "35.14247",
    "lng": "-119.45651"
  },
  {
    "country": "US",
    "name": "Taft Heights",
    "lat": "35.13469",
    "lng": "-119.47262"
  },
  {
    "country": "US",
    "name": "Tahoe Vista",
    "lat": "39.23991",
    "lng": "-120.05102"
  },
  {
    "country": "US",
    "name": "Tahoma",
    "lat": "39.06741",
    "lng": "-120.12824"
  },
  {
    "country": "US",
    "name": "Talmage",
    "lat": "39.13323",
    "lng": "-123.16778"
  },
  {
    "country": "US",
    "name": "Tamalpais Valley",
    "lat": "37.87965",
    "lng": "-122.54581"
  },
  {
    "country": "US",
    "name": "Tara Hills",
    "lat": "37.99353",
    "lng": "-122.31636"
  },
  {
    "country": "US",
    "name": "Tarpey Village",
    "lat": "36.79301",
    "lng": "-119.70097"
  },
  {
    "country": "US",
    "name": "Tehachapi",
    "lat": "35.13219",
    "lng": "-118.44897"
  },
  {
    "country": "US",
    "name": "Temecula",
    "lat": "33.49364",
    "lng": "-117.14836"
  },
  {
    "country": "US",
    "name": "Temelec",
    "lat": "38.26658",
    "lng": "-122.49276"
  },
  {
    "country": "US",
    "name": "Temple City",
    "lat": "34.10723",
    "lng": "-118.05785"
  },
  {
    "country": "US",
    "name": "Templeton",
    "lat": "35.54969",
    "lng": "-120.706"
  },
  {
    "country": "US",
    "name": "Terra Bella",
    "lat": "35.96245",
    "lng": "-119.04427"
  },
  {
    "country": "US",
    "name": "Thermal",
    "lat": "33.6403",
    "lng": "-116.13945"
  },
  {
    "country": "US",
    "name": "Thermalito",
    "lat": "39.51128",
    "lng": "-121.58692"
  },
  {
    "country": "US",
    "name": "Thornton",
    "lat": "38.22603",
    "lng": "-121.42467"
  },
  {
    "country": "US",
    "name": "Thousand Oaks",
    "lat": "34.17056",
    "lng": "-118.83759"
  },
  {
    "country": "US",
    "name": "Thousand Palms",
    "lat": "33.82002",
    "lng": "-116.39029"
  },
  {
    "country": "US",
    "name": "Tiburon",
    "lat": "37.87354",
    "lng": "-122.45664"
  },
  {
    "country": "US",
    "name": "Tierra Buena",
    "lat": "39.14878",
    "lng": "-121.66691"
  },
  {
    "country": "US",
    "name": "Tipton",
    "lat": "36.0594",
    "lng": "-119.31206"
  },
  {
    "country": "US",
    "name": "Topanga",
    "lat": "34.09362",
    "lng": "-118.60147"
  },
  {
    "country": "US",
    "name": "Toro Canyon",
    "lat": "34.42",
    "lng": "-119.56707"
  },
  {
    "country": "US",
    "name": "Torrance",
    "lat": "33.83585",
    "lng": "-118.34063"
  },
  {
    "country": "US",
    "name": "Trabuco Canyon",
    "lat": "33.66252",
    "lng": "-117.59033"
  },
  {
    "country": "US",
    "name": "Tracy",
    "lat": "37.73987",
    "lng": "-121.42618"
  },
  {
    "country": "US",
    "name": "Truckee",
    "lat": "39.32796",
    "lng": "-120.18325"
  },
  {
    "country": "US",
    "name": "Tujunga",
    "lat": "34.25223",
    "lng": "-118.28841"
  },
  {
    "country": "US",
    "name": "Tulare",
    "lat": "36.20773",
    "lng": "-119.34734"
  },
  {
    "country": "US",
    "name": "Tuolumne City",
    "lat": "37.9627",
    "lng": "-120.2413"
  },
  {
    "country": "US",
    "name": "Turlock",
    "lat": "37.49466",
    "lng": "-120.84659"
  },
  {
    "country": "US",
    "name": "Tustin",
    "lat": "33.74585",
    "lng": "-117.82617"
  },
  {
    "country": "US",
    "name": "North Tustin",
    "lat": "33.76446",
    "lng": "-117.79394"
  },
  {
    "country": "US",
    "name": "Twain Harte",
    "lat": "38.03965",
    "lng": "-120.23269"
  },
  {
    "country": "US",
    "name": "Twentynine Palms",
    "lat": "34.13556",
    "lng": "-116.05417"
  },
  {
    "country": "US",
    "name": "Twin Lakes",
    "lat": "36.96745",
    "lng": "-121.99802"
  },
  {
    "country": "US",
    "name": "Ukiah",
    "lat": "39.15017",
    "lng": "-123.20778"
  },
  {
    "country": "US",
    "name": "Union City",
    "lat": "37.59577",
    "lng": "-122.01913"
  },
  {
    "country": "US",
    "name": "Universal City",
    "lat": "34.1389",
    "lng": "-118.35341"
  },
  {
    "country": "US",
    "name": "Upland",
    "lat": "34.09751",
    "lng": "-117.64839"
  },
  {
    "country": "US",
    "name": "Upper Lake",
    "lat": "39.16461",
    "lng": "-122.91055"
  },
  {
    "country": "US",
    "name": "Vacaville",
    "lat": "38.35658",
    "lng": "-121.98774"
  },
  {
    "country": "US",
    "name": "Val Verde",
    "lat": "34.445",
    "lng": "-118.65759"
  },
  {
    "country": "US",
    "name": "Valencia",
    "lat": "34.44361",
    "lng": "-118.60953"
  },
  {
    "country": "US",
    "name": "Valinda",
    "lat": "34.04529",
    "lng": "-117.94367"
  },
  {
    "country": "US",
    "name": "Valle Vista",
    "lat": "33.7478",
    "lng": "-116.89336"
  },
  {
    "country": "US",
    "name": "Vallejo",
    "lat": "38.10409",
    "lng": "-122.25664"
  },
  {
    "country": "US",
    "name": "Valley Center",
    "lat": "33.21837",
    "lng": "-117.0342"
  },
  {
    "country": "US",
    "name": "Valley Springs",
    "lat": "38.19159",
    "lng": "-120.8291"
  },
  {
    "country": "US",
    "name": "Van Nuys",
    "lat": "34.18667",
    "lng": "-118.44897"
  },
  {
    "country": "US",
    "name": "Vandenberg Village",
    "lat": "34.70832",
    "lng": "-120.46766"
  },
  {
    "country": "US",
    "name": "Venice",
    "lat": "33.99084",
    "lng": "-118.46008"
  },
  {
    "country": "US",
    "name": "Ventura",
    "lat": "34.27834",
    "lng": "-119.29317"
  },
  {
    "country": "US",
    "name": "Victorville",
    "lat": "34.53611",
    "lng": "-117.29116"
  },
  {
    "country": "US",
    "name": "Villa Park",
    "lat": "33.81446",
    "lng": "-117.81311"
  },
  {
    "country": "US",
    "name": "Vincent",
    "lat": "34.50055",
    "lng": "-118.11646"
  },
  {
    "country": "US",
    "name": "Visalia",
    "lat": "36.33023",
    "lng": "-119.29206"
  },
  {
    "country": "US",
    "name": "Vista",
    "lat": "33.20004",
    "lng": "-117.24254"
  },
  {
    "country": "US",
    "name": "Vista Santa Rosa",
    "lat": "33.6278",
    "lng": "-116.21806"
  },
  {
    "country": "US",
    "name": "Waldon",
    "lat": "37.92631",
    "lng": "-122.05552"
  },
  {
    "country": "US",
    "name": "Walnut",
    "lat": "34.02029",
    "lng": "-117.86534"
  },
  {
    "country": "US",
    "name": "Walnut Creek",
    "lat": "37.90631",
    "lng": "-122.06496"
  },
  {
    "country": "US",
    "name": "Walnut Grove",
    "lat": "38.24214",
    "lng": "-121.51162"
  },
  {
    "country": "US",
    "name": "Walnut Park",
    "lat": "33.96807",
    "lng": "-118.22507"
  },
  {
    "country": "US",
    "name": "Waterford",
    "lat": "37.64132",
    "lng": "-120.76048"
  },
  {
    "country": "US",
    "name": "Watsonville",
    "lat": "36.91023",
    "lng": "-121.75689"
  },
  {
    "country": "US",
    "name": "Weedpatch",
    "lat": "35.23802",
    "lng": "-118.9151"
  },
  {
    "country": "US",
    "name": "Weldon",
    "lat": "35.66579",
    "lng": "-118.29036"
  },
  {
    "country": "US",
    "name": "West Athens",
    "lat": "33.92335",
    "lng": "-118.30341"
  },
  {
    "country": "US",
    "name": "West Carson",
    "lat": "33.82168",
    "lng": "-118.29257"
  },
  {
    "country": "US",
    "name": "West Rancho Dominguez",
    "lat": "33.8939",
    "lng": "-118.27063"
  },
  {
    "country": "US",
    "name": "West Covina",
    "lat": "34.06862",
    "lng": "-117.93895"
  },
  {
    "country": "US",
    "name": "West Hollywood",
    "lat": "34.09001",
    "lng": "-118.36174"
  },
  {
    "country": "US",
    "name": "West Menlo Park",
    "lat": "37.43355",
    "lng": "-122.20302"
  },
  {
    "country": "US",
    "name": "West Park",
    "lat": "36.71023",
    "lng": "-119.85126"
  },
  {
    "country": "US",
    "name": "West Puente Valley",
    "lat": "34.05168",
    "lng": "-117.9684"
  },
  {
    "country": "US",
    "name": "West Sacramento",
    "lat": "38.58046",
    "lng": "-121.53023"
  },
  {
    "country": "US",
    "name": "Westlake Village",
    "lat": "34.14584",
    "lng": "-118.80565"
  },
  {
    "country": "US",
    "name": "Westminster",
    "lat": "33.75918",
    "lng": "-118.00673"
  },
  {
    "country": "US",
    "name": "Westmont",
    "lat": "33.9414",
    "lng": "-118.3023"
  },
  {
    "country": "US",
    "name": "Westmorland",
    "lat": "33.03727",
    "lng": "-115.62138"
  },
  {
    "country": "US",
    "name": "Westwood",
    "lat": "34.05612",
    "lng": "-118.43063"
  },
  {
    "country": "US",
    "name": "Wheatland",
    "lat": "39.00989",
    "lng": "-121.42301"
  },
  {
    "country": "US",
    "name": "Whittier",
    "lat": "33.97918",
    "lng": "-118.03284"
  },
  {
    "country": "US",
    "name": "Wildomar",
    "lat": "33.59891",
    "lng": "-117.28004"
  },
  {
    "country": "US",
    "name": "Williams",
    "lat": "39.15461",
    "lng": "-122.14942"
  },
  {
    "country": "US",
    "name": "Willits",
    "lat": "39.40961",
    "lng": "-123.35557"
  },
  {
    "country": "US",
    "name": "Willowbrook",
    "lat": "33.91696",
    "lng": "-118.25507"
  },
  {
    "country": "US",
    "name": "Willows",
    "lat": "39.52433",
    "lng": "-122.19359"
  },
  {
    "country": "US",
    "name": "Wilton",
    "lat": "38.41186",
    "lng": "-121.27217"
  },
  {
    "country": "US",
    "name": "Winchester",
    "lat": "33.70697",
    "lng": "-117.08447"
  },
  {
    "country": "US",
    "name": "Windsor",
    "lat": "38.54713",
    "lng": "-122.81638"
  },
  {
    "country": "US",
    "name": "Winters",
    "lat": "38.52491",
    "lng": "-121.9708"
  },
  {
    "country": "US",
    "name": "Winter Gardens",
    "lat": "32.83116",
    "lng": "-116.93336"
  },
  {
    "country": "US",
    "name": "Winton",
    "lat": "37.38938",
    "lng": "-120.61325"
  },
  {
    "country": "US",
    "name": "Wofford Heights",
    "lat": "35.7069",
    "lng": "-118.4562"
  },
  {
    "country": "US",
    "name": "Woodacre",
    "lat": "38.0127",
    "lng": "-122.64526"
  },
  {
    "country": "US",
    "name": "Woodbridge",
    "lat": "38.15408",
    "lng": "-121.30134"
  },
  {
    "country": "US",
    "name": "Woodcrest",
    "lat": "33.88224",
    "lng": "-117.35727"
  },
  {
    "country": "US",
    "name": "Woodlake",
    "lat": "36.41356",
    "lng": "-119.09872"
  },
  {
    "country": "US",
    "name": "Woodland",
    "lat": "38.67852",
    "lng": "-121.7733"
  },
  {
    "country": "US",
    "name": "Woodland Hills",
    "lat": "34.16834",
    "lng": "-118.60592"
  },
  {
    "country": "US",
    "name": "Woodside",
    "lat": "37.42994",
    "lng": "-122.25386"
  },
  {
    "country": "US",
    "name": "Woodville",
    "lat": "36.09356",
    "lng": "-119.199"
  },
  {
    "country": "US",
    "name": "Wrightwood",
    "lat": "34.36083",
    "lng": "-117.63339"
  },
  {
    "country": "US",
    "name": "Yorba Linda",
    "lat": "33.88863",
    "lng": "-117.81311"
  },
  {
    "country": "US",
    "name": "Yosemite Lakes",
    "lat": "37.19106",
    "lng": "-119.77265"
  },
  {
    "country": "US",
    "name": "Yountville",
    "lat": "38.40158",
    "lng": "-122.36081"
  },
  {
    "country": "US",
    "name": "Yuba City",
    "lat": "39.14045",
    "lng": "-121.61691"
  },
  {
    "country": "US",
    "name": "Yucaipa",
    "lat": "34.03363",
    "lng": "-117.04309"
  },
  {
    "country": "US",
    "name": "Yucca Valley",
    "lat": "34.11417",
    "lng": "-116.43224"
  },
  {
    "country": "US",
    "name": "Acres Green",
    "lat": "39.55666",
    "lng": "-104.89609"
  },
  {
    "country": "US",
    "name": "Alamosa",
    "lat": "37.46945",
    "lng": "-105.87002"
  },
  {
    "country": "US",
    "name": "Applewood",
    "lat": "39.75778",
    "lng": "-105.1625"
  },
  {
    "country": "US",
    "name": "Arvada",
    "lat": "39.80276",
    "lng": "-105.08748"
  },
  {
    "country": "US",
    "name": "Aspen",
    "lat": "39.1911",
    "lng": "-106.81754"
  },
  {
    "country": "US",
    "name": "Aurora",
    "lat": "39.72943",
    "lng": "-104.83192"
  },
  {
    "country": "US",
    "name": "Avon",
    "lat": "39.63137",
    "lng": "-106.52225"
  },
  {
    "country": "US",
    "name": "Basalt",
    "lat": "39.36887",
    "lng": "-107.03282"
  },
  {
    "country": "US",
    "name": "Battlement Mesa",
    "lat": "39.44137",
    "lng": "-108.02507"
  },
  {
    "country": "US",
    "name": "Bayfield",
    "lat": "37.22556",
    "lng": "-107.59811"
  },
  {
    "country": "US",
    "name": "Bennett",
    "lat": "39.75887",
    "lng": "-104.42746"
  },
  {
    "country": "US",
    "name": "Berkley",
    "lat": "39.80443",
    "lng": "-105.02609"
  },
  {
    "country": "US",
    "name": "Black Forest",
    "lat": "39.01305",
    "lng": "-104.70081"
  },
  {
    "country": "US",
    "name": "Breckenridge",
    "lat": "39.48165",
    "lng": "-106.03835"
  },
  {
    "country": "US",
    "name": "Brighton",
    "lat": "39.98526",
    "lng": "-104.82053"
  },
  {
    "country": "US",
    "name": "Broomfield",
    "lat": "39.92054",
    "lng": "-105.08665"
  },
  {
    "country": "US",
    "name": "Buena Vista",
    "lat": "38.84222",
    "lng": "-106.13113"
  },
  {
    "country": "US",
    "name": "Burlington",
    "lat": "39.30611",
    "lng": "-102.26936"
  },
  {
    "country": "US",
    "name": "Byers",
    "lat": "39.71137",
    "lng": "-104.22774"
  },
  {
    "country": "US",
    "name": "Cañon City",
    "lat": "38.44098",
    "lng": "-105.24245"
  },
  {
    "country": "US",
    "name": "Carbondale",
    "lat": "39.40221",
    "lng": "-107.21116"
  },
  {
    "country": "US",
    "name": "Carriage Club",
    "lat": "39.53249",
    "lng": "-104.90109"
  },
  {
    "country": "US",
    "name": "Castle Pines",
    "lat": "39.45804",
    "lng": "-104.89609"
  },
  {
    "country": "US",
    "name": "Castle Rock",
    "lat": "39.37221",
    "lng": "-104.85609"
  },
  {
    "country": "US",
    "name": "Castlewood",
    "lat": "39.58471",
    "lng": "-104.90109"
  },
  {
    "country": "US",
    "name": "Cedaredge",
    "lat": "38.90165",
    "lng": "-107.92645"
  },
  {
    "country": "US",
    "name": "Centennial",
    "lat": "39.57916",
    "lng": "-104.87692"
  },
  {
    "country": "US",
    "name": "Center",
    "lat": "37.75306",
    "lng": "-106.10864"
  },
  {
    "country": "US",
    "name": "Central City",
    "lat": "39.80193",
    "lng": "-105.51416"
  },
  {
    "country": "US",
    "name": "Cherry Hills Village",
    "lat": "39.64165",
    "lng": "-104.95943"
  },
  {
    "country": "US",
    "name": "Cheyenne Wells",
    "lat": "38.8214",
    "lng": "-102.35324"
  },
  {
    "country": "US",
    "name": "Cimarron Hills",
    "lat": "38.85861",
    "lng": "-104.69886"
  },
  {
    "country": "US",
    "name": "Clifton",
    "lat": "39.09193",
    "lng": "-108.44898"
  },
  {
    "country": "US",
    "name": "Coal Creek",
    "lat": "39.90638",
    "lng": "-105.37749"
  },
  {
    "country": "US",
    "name": "Colorado City",
    "lat": "37.94529",
    "lng": "-104.83526"
  },
  {
    "country": "US",
    "name": "Colorado Springs",
    "lat": "38.83388",
    "lng": "-104.82136"
  },
  {
    "country": "US",
    "name": "Columbine",
    "lat": "39.58777",
    "lng": "-105.06943"
  },
  {
    "country": "US",
    "name": "Columbine Valley",
    "lat": "39.6011",
    "lng": "-105.03221"
  },
  {
    "country": "US",
    "name": "Commerce City",
    "lat": "39.80832",
    "lng": "-104.93387"
  },
  {
    "country": "US",
    "name": "Conejos",
    "lat": "37.08835",
    "lng": "-106.01974"
  },
  {
    "country": "US",
    "name": "Cortez",
    "lat": "37.34888",
    "lng": "-108.58593"
  },
  {
    "country": "US",
    "name": "Creede",
    "lat": "37.84917",
    "lng": "-106.92643"
  },
  {
    "country": "US",
    "name": "Crested Butte",
    "lat": "38.86971",
    "lng": "-106.98782"
  },
  {
    "country": "US",
    "name": "Cripple Creek",
    "lat": "38.74666",
    "lng": "-105.17831"
  },
  {
    "country": "US",
    "name": "Del Norte",
    "lat": "37.67889",
    "lng": "-106.35337"
  },
  {
    "country": "US",
    "name": "Delta",
    "lat": "38.74221",
    "lng": "-108.06896"
  },
  {
    "country": "US",
    "name": "Denver",
    "lat": "39.73915",
    "lng": "-104.9847"
  },
  {
    "country": "US",
    "name": "Derby",
    "lat": "39.83943",
    "lng": "-104.91859"
  },
  {
    "country": "US",
    "name": "Dove Creek",
    "lat": "37.7661",
    "lng": "-108.90594"
  },
  {
    "country": "US",
    "name": "Durango",
    "lat": "37.27528",
    "lng": "-107.88007"
  },
  {
    "country": "US",
    "name": "Eads",
    "lat": "38.48056",
    "lng": "-102.78186"
  },
  {
    "country": "US",
    "name": "Eagle",
    "lat": "39.65526",
    "lng": "-106.82865"
  },
  {
    "country": "US",
    "name": "Edgewater",
    "lat": "39.75304",
    "lng": "-105.06415"
  },
  {
    "country": "US",
    "name": "Edwards",
    "lat": "39.64499",
    "lng": "-106.5942"
  },
  {
    "country": "US",
    "name": "El Jebel",
    "lat": "39.39498",
    "lng": "-107.09033"
  },
  {
    "country": "US",
    "name": "Elizabeth",
    "lat": "39.36027",
    "lng": "-104.59691"
  },
  {
    "country": "US",
    "name": "Ellicott",
    "lat": "38.83833",
    "lng": "-104.38691"
  },
  {
    "country": "US",
    "name": "Englewood",
    "lat": "39.64777",
    "lng": "-104.98776"
  },
  {
    "country": "US",
    "name": "Evergreen",
    "lat": "39.63332",
    "lng": "-105.31721"
  },
  {
    "country": "US",
    "name": "Fairplay",
    "lat": "39.22471",
    "lng": "-106.00196"
  },
  {
    "country": "US",
    "name": "Federal Heights",
    "lat": "39.85137",
    "lng": "-104.99859"
  },
  {
    "country": "US",
    "name": "Florence",
    "lat": "38.39028",
    "lng": "-105.1186"
  },
  {
    "country": "US",
    "name": "Fort Carson",
    "lat": "38.73749",
    "lng": "-104.78886"
  },
  {
    "country": "US",
    "name": "Fountain",
    "lat": "38.68222",
    "lng": "-104.70081"
  },
  {
    "country": "US",
    "name": "Fowler",
    "lat": "38.12917",
    "lng": "-104.02329"
  },
  {
    "country": "US",
    "name": "Fraser",
    "lat": "39.94499",
    "lng": "-105.81723"
  },
  {
    "country": "US",
    "name": "Frisco",
    "lat": "39.57443",
    "lng": "-106.09752"
  },
  {
    "country": "US",
    "name": "Fruita",
    "lat": "39.15887",
    "lng": "-108.72899"
  },
  {
    "country": "US",
    "name": "Fruitvale",
    "lat": "39.08165",
    "lng": "-108.49676"
  },
  {
    "country": "US",
    "name": "Genesee",
    "lat": "39.68582",
    "lng": "-105.27277"
  },
  {
    "country": "US",
    "name": "Georgetown",
    "lat": "39.7061",
    "lng": "-105.6975"
  },
  {
    "country": "US",
    "name": "Glendale",
    "lat": "39.70499",
    "lng": "-104.93359"
  },
  {
    "country": "US",
    "name": "Gleneagle",
    "lat": "39.04527",
    "lng": "-104.82442"
  },
  {
    "country": "US",
    "name": "Glenwood Springs",
    "lat": "39.55054",
    "lng": "-107.32478"
  },
  {
    "country": "US",
    "name": "Golden",
    "lat": "39.75554",
    "lng": "-105.2211"
  },
  {
    "country": "US",
    "name": "Grand Junction",
    "lat": "39.06387",
    "lng": "-108.55065"
  },
  {
    "country": "US",
    "name": "Greenwood Village",
    "lat": "39.61721",
    "lng": "-104.95081"
  },
  {
    "country": "US",
    "name": "Gunnison",
    "lat": "38.54582",
    "lng": "-106.92532"
  },
  {
    "country": "US",
    "name": "Gypsum",
    "lat": "39.64693",
    "lng": "-106.95171"
  },
  {
    "country": "US",
    "name": "Highlands Ranch",
    "lat": "39.55388",
    "lng": "-104.96943"
  },
  {
    "country": "US",
    "name": "Hugo",
    "lat": "39.1361",
    "lng": "-103.46994"
  },
  {
    "country": "US",
    "name": "Idaho Springs",
    "lat": "39.74249",
    "lng": "-105.51361"
  },
  {
    "country": "US",
    "name": "Indian Hills",
    "lat": "39.61665",
    "lng": "-105.23721"
  },
  {
    "country": "US",
    "name": "Ken Caryl",
    "lat": "39.57582",
    "lng": "-105.11221"
  },
  {
    "country": "US",
    "name": "Keystone",
    "lat": "39.59943",
    "lng": "-105.98724"
  },
  {
    "country": "US",
    "name": "Kiowa",
    "lat": "39.34721",
    "lng": "-104.46441"
  },
  {
    "country": "US",
    "name": "Kittredge",
    "lat": "39.65471",
    "lng": "-105.29971"
  },
  {
    "country": "US",
    "name": "La Junta",
    "lat": "37.98501",
    "lng": "-103.54383"
  },
  {
    "country": "US",
    "name": "Lafayette",
    "lat": "39.9936",
    "lng": "-105.08971"
  },
  {
    "country": "US",
    "name": "Lake City",
    "lat": "38.03",
    "lng": "-107.31533"
  },
  {
    "country": "US",
    "name": "Lakewood",
    "lat": "39.70471",
    "lng": "-105.08137"
  },
  {
    "country": "US",
    "name": "Lamar",
    "lat": "38.08723",
    "lng": "-102.62075"
  },
  {
    "country": "US",
    "name": "Las Animas",
    "lat": "38.06667",
    "lng": "-103.22271"
  },
  {
    "country": "US",
    "name": "Leadville",
    "lat": "39.25082",
    "lng": "-106.29252"
  },
  {
    "country": "US",
    "name": "Limon",
    "lat": "39.26388",
    "lng": "-103.69217"
  },
  {
    "country": "US",
    "name": "Lincoln Park",
    "lat": "38.42916",
    "lng": "-105.21999"
  },
  {
    "country": "US",
    "name": "Littleton",
    "lat": "39.61332",
    "lng": "-105.01665"
  },
  {
    "country": "US",
    "name": "Loma",
    "lat": "39.19581",
    "lng": "-108.81316"
  },
  {
    "country": "US",
    "name": "Lone Tree",
    "lat": "39.55171",
    "lng": "-104.8863"
  },
  {
    "country": "US",
    "name": "Louisville",
    "lat": "39.97776",
    "lng": "-105.13193"
  },
  {
    "country": "US",
    "name": "Mancos",
    "lat": "37.345",
    "lng": "-108.28925"
  },
  {
    "country": "US",
    "name": "Manitou Springs",
    "lat": "38.85971",
    "lng": "-104.9172"
  },
  {
    "country": "US",
    "name": "Meridian",
    "lat": "39.53957",
    "lng": "-104.84528"
  },
  {
    "country": "US",
    "name": "Minturn",
    "lat": "39.58637",
    "lng": "-106.43086"
  },
  {
    "country": "US",
    "name": "Monte Vista",
    "lat": "37.57917",
    "lng": "-106.14808"
  },
  {
    "country": "US",
    "name": "Montrose",
    "lat": "38.47832",
    "lng": "-107.87617"
  },
  {
    "country": "US",
    "name": "Monument",
    "lat": "39.09166",
    "lng": "-104.87276"
  },
  {
    "country": "US",
    "name": "Mountain Village",
    "lat": "37.93138",
    "lng": "-107.85645"
  },
  {
    "country": "US",
    "name": "Nederland",
    "lat": "39.96138",
    "lng": "-105.51083"
  },
  {
    "country": "US",
    "name": "New Castle",
    "lat": "39.57276",
    "lng": "-107.53644"
  },
  {
    "country": "US",
    "name": "Northglenn",
    "lat": "39.88554",
    "lng": "-104.9872"
  },
  {
    "country": "US",
    "name": "Olathe",
    "lat": "38.60499",
    "lng": "-107.98229"
  },
  {
    "country": "US",
    "name": "Orchard Mesa",
    "lat": "39.04304",
    "lng": "-108.55232"
  },
  {
    "country": "US",
    "name": "Orchard City",
    "lat": "38.82832",
    "lng": "-107.9709"
  },
  {
    "country": "US",
    "name": "Ordway",
    "lat": "38.21806",
    "lng": "-103.75606"
  },
  {
    "country": "US",
    "name": "Ouray",
    "lat": "38.02277",
    "lng": "-107.67145"
  },
  {
    "country": "US",
    "name": "Pagosa Springs",
    "lat": "37.26945",
    "lng": "-107.00976"
  },
  {
    "country": "US",
    "name": "Palisade",
    "lat": "39.11026",
    "lng": "-108.35092"
  },
  {
    "country": "US",
    "name": "Palmer Lake",
    "lat": "39.12221",
    "lng": "-104.9172"
  },
  {
    "country": "US",
    "name": "Parachute",
    "lat": "39.45192",
    "lng": "-108.05285"
  },
  {
    "country": "US",
    "name": "Parker",
    "lat": "39.5186",
    "lng": "-104.76136"
  },
  {
    "country": "US",
    "name": "Penrose",
    "lat": "38.425",
    "lng": "-105.02276"
  },
  {
    "country": "US",
    "name": "Perry Park",
    "lat": "39.25666",
    "lng": "-104.99248"
  },
  {
    "country": "US",
    "name": "Ponderosa Park",
    "lat": "39.40832",
    "lng": "-104.65108"
  },
  {
    "country": "US",
    "name": "Pueblo",
    "lat": "38.25445",
    "lng": "-104.60914"
  },
  {
    "country": "US",
    "name": "Pueblo West",
    "lat": "38.35",
    "lng": "-104.72275"
  },
  {
    "country": "US",
    "name": "Redlands",
    "lat": "39.07887",
    "lng": "-108.63565"
  },
  {
    "country": "US",
    "name": "Rifle",
    "lat": "39.5347",
    "lng": "-107.78312"
  },
  {
    "country": "US",
    "name": "Rocky Ford",
    "lat": "38.05251",
    "lng": "-103.72023"
  },
  {
    "country": "US",
    "name": "Roxborough Park",
    "lat": "39.47388",
    "lng": "-105.08526"
  },
  {
    "country": "US",
    "name": "Saguache",
    "lat": "38.0875",
    "lng": "-106.14197"
  },
  {
    "country": "US",
    "name": "Salida",
    "lat": "38.53472",
    "lng": "-105.9989"
  },
  {
    "country": "US",
    "name": "San Luis",
    "lat": "37.20085",
    "lng": "-105.4239"
  },
  {
    "country": "US",
    "name": "Sheridan",
    "lat": "39.64693",
    "lng": "-105.02526"
  },
  {
    "country": "US",
    "name": "Sherrelwood",
    "lat": "39.83776",
    "lng": "-105.00137"
  },
  {
    "country": "US",
    "name": "Silt",
    "lat": "39.54859",
    "lng": "-107.65617"
  },
  {
    "country": "US",
    "name": "Silverthorne",
    "lat": "39.63214",
    "lng": "-106.07428"
  },
  {
    "country": "US",
    "name": "Silverton",
    "lat": "37.81194",
    "lng": "-107.66451"
  },
  {
    "country": "US",
    "name": "Snowmass Village",
    "lat": "39.21304",
    "lng": "-106.93782"
  },
  {
    "country": "US",
    "name": "Southglenn",
    "lat": "39.58721",
    "lng": "-104.95276"
  },
  {
    "country": "US",
    "name": "Springfield",
    "lat": "37.40835",
    "lng": "-102.61436"
  },
  {
    "country": "US",
    "name": "Stonegate",
    "lat": "39.53082",
    "lng": "-104.80386"
  },
  {
    "country": "US",
    "name": "Strasburg",
    "lat": "39.73832",
    "lng": "-104.32329"
  },
  {
    "country": "US",
    "name": "Stratmoor",
    "lat": "38.77388",
    "lng": "-104.7797"
  },
  {
    "country": "US",
    "name": "Superior",
    "lat": "39.95276",
    "lng": "-105.1686"
  },
  {
    "country": "US",
    "name": "Telluride",
    "lat": "37.93749",
    "lng": "-107.81229"
  },
  {
    "country": "US",
    "name": "The Pinery",
    "lat": "39.45527",
    "lng": "-104.73442"
  },
  {
    "country": "US",
    "name": "Thornton",
    "lat": "39.86804",
    "lng": "-104.97192"
  },
  {
    "country": "US",
    "name": "Todd Creek",
    "lat": "39.97804",
    "lng": "-104.87331"
  },
  {
    "country": "US",
    "name": "Towaoc",
    "lat": "37.20444",
    "lng": "-108.72954"
  },
  {
    "country": "US",
    "name": "Trinidad",
    "lat": "37.16946",
    "lng": "-104.50054"
  },
  {
    "country": "US",
    "name": "Twin Lakes",
    "lat": "39.82499",
    "lng": "-105.0047"
  },
  {
    "country": "US",
    "name": "Vail",
    "lat": "39.64026",
    "lng": "-106.3742"
  },
  {
    "country": "US",
    "name": "Walsenburg",
    "lat": "37.62418",
    "lng": "-104.78026"
  },
  {
    "country": "US",
    "name": "Welby",
    "lat": "39.83665",
    "lng": "-104.95915"
  },
  {
    "country": "US",
    "name": "Westcliffe",
    "lat": "38.13472",
    "lng": "-105.46584"
  },
  {
    "country": "US",
    "name": "Westminster",
    "lat": "39.83665",
    "lng": "-105.0372"
  },
  {
    "country": "US",
    "name": "Wheat Ridge",
    "lat": "39.7661",
    "lng": "-105.07721"
  },
  {
    "country": "US",
    "name": "Woodland Park",
    "lat": "38.99388",
    "lng": "-105.05693"
  },
  {
    "country": "US",
    "name": "Woodmoor",
    "lat": "39.10138",
    "lng": "-104.84748"
  },
  {
    "country": "US",
    "name": "Atwood",
    "lat": "39.80667",
    "lng": "-101.0421"
  },
  {
    "country": "US",
    "name": "Colby",
    "lat": "39.39584",
    "lng": "-101.05238"
  },
  {
    "country": "US",
    "name": "Dodge City",
    "lat": "37.7528",
    "lng": "-100.01708"
  },
  {
    "country": "US",
    "name": "Elkhart",
    "lat": "37.00808",
    "lng": "-101.89017"
  },
  {
    "country": "US",
    "name": "Garden City",
    "lat": "37.97169",
    "lng": "-100.87266"
  },
  {
    "country": "US",
    "name": "Goodland",
    "lat": "39.35083",
    "lng": "-101.71017"
  },
  {
    "country": "US",
    "name": "Gove",
    "lat": "38.95779",
    "lng": "-100.48875"
  },
  {
    "country": "US",
    "name": "Holcomb",
    "lat": "37.98614",
    "lng": "-100.98933"
  },
  {
    "country": "US",
    "name": "Hoxie",
    "lat": "39.3575",
    "lng": "-100.44181"
  },
  {
    "country": "US",
    "name": "Hugoton",
    "lat": "37.1753",
    "lng": "-101.3496"
  },
  {
    "country": "US",
    "name": "Johnson",
    "lat": "37.57057",
    "lng": "-101.751"
  },
  {
    "country": "US",
    "name": "Lakin",
    "lat": "37.94058",
    "lng": "-101.25489"
  },
  {
    "country": "US",
    "name": "Leoti",
    "lat": "38.47974",
    "lng": "-101.35877"
  },
  {
    "country": "US",
    "name": "Liberal",
    "lat": "37.04308",
    "lng": "-100.921"
  },
  {
    "country": "US",
    "name": "Meade",
    "lat": "37.28558",
    "lng": "-100.34015"
  },
  {
    "country": "US",
    "name": "Oakley",
    "lat": "39.13334",
    "lng": "-100.86376"
  },
  {
    "country": "US",
    "name": "Oberlin",
    "lat": "39.81834",
    "lng": "-100.5282"
  },
  {
    "country": "US",
    "name": "Plains",
    "lat": "37.2603",
    "lng": "-100.59265"
  },
  {
    "country": "US",
    "name": "Saint Francis",
    "lat": "39.77222",
    "lng": "-101.7999"
  },
  {
    "country": "US",
    "name": "Satanta",
    "lat": "37.43725",
    "lng": "-100.97211"
  },
  {
    "country": "US",
    "name": "Scott City",
    "lat": "38.48252",
    "lng": "-100.90709"
  },
  {
    "country": "US",
    "name": "Sharon Springs",
    "lat": "38.89779",
    "lng": "-101.75212"
  },
  {
    "country": "US",
    "name": "Syracuse",
    "lat": "37.98071",
    "lng": "-101.7543"
  },
  {
    "country": "US",
    "name": "Sublette",
    "lat": "37.48169",
    "lng": "-100.84377"
  },
  {
    "country": "US",
    "name": "Tribune",
    "lat": "38.46974",
    "lng": "-101.75267"
  },
  {
    "country": "US",
    "name": "Ulysses",
    "lat": "37.58141",
    "lng": "-101.35517"
  },
  {
    "country": "US",
    "name": "Agua Fria",
    "lat": "35.65448",
    "lng": "-106.02224"
  },
  {
    "country": "US",
    "name": "Alamo",
    "lat": "34.42089",
    "lng": "-107.51088"
  },
  {
    "country": "US",
    "name": "Alamogordo",
    "lat": "32.89953",
    "lng": "-105.96027"
  },
  {
    "country": "US",
    "name": "Albuquerque",
    "lat": "35.08449",
    "lng": "-106.65114"
  },
  {
    "country": "US",
    "name": "Angel Fire",
    "lat": "36.39309",
    "lng": "-105.28501"
  },
  {
    "country": "US",
    "name": "Anthony",
    "lat": "32.00399",
    "lng": "-106.60583"
  },
  {
    "country": "US",
    "name": "Arenas Valley",
    "lat": "32.79396",
    "lng": "-108.18421"
  },
  {
    "country": "US",
    "name": "Arroyo Seco",
    "lat": "36.51669",
    "lng": "-105.56918"
  },
  {
    "country": "US",
    "name": "Artesia",
    "lat": "32.84233",
    "lng": "-104.4033"
  },
  {
    "country": "US",
    "name": "Atoka",
    "lat": "32.76956",
    "lng": "-104.38885"
  },
  {
    "country": "US",
    "name": "Aztec",
    "lat": "36.82223",
    "lng": "-107.99285"
  },
  {
    "country": "US",
    "name": "Bayard",
    "lat": "32.76174",
    "lng": "-108.1306"
  },
  {
    "country": "US",
    "name": "Belen",
    "lat": "34.66284",
    "lng": "-106.77642"
  },
  {
    "country": "US",
    "name": "Berino",
    "lat": "32.07093",
    "lng": "-106.62138"
  },
  {
    "country": "US",
    "name": "Bernalillo",
    "lat": "35.30004",
    "lng": "-106.55114"
  },
  {
    "country": "US",
    "name": "Black Rock",
    "lat": "35.08837",
    "lng": "-108.79119"
  },
  {
    "country": "US",
    "name": "Bloomfield",
    "lat": "36.71112",
    "lng": "-107.98451"
  },
  {
    "country": "US",
    "name": "Boles Acres",
    "lat": "32.80703",
    "lng": "-105.9861"
  },
  {
    "country": "US",
    "name": "Bosque Farms",
    "lat": "34.85478",
    "lng": "-106.7053"
  },
  {
    "country": "US",
    "name": "Capitan",
    "lat": "33.54536",
    "lng": "-105.5722"
  },
  {
    "country": "US",
    "name": "Carlsbad",
    "lat": "32.42067",
    "lng": "-104.22884"
  },
  {
    "country": "US",
    "name": "Carnuel",
    "lat": "35.06394",
    "lng": "-106.45725"
  },
  {
    "country": "US",
    "name": "Carrizozo",
    "lat": "33.64174",
    "lng": "-105.87721"
  },
  {
    "country": "US",
    "name": "Chama",
    "lat": "36.90307",
    "lng": "-106.57948"
  },
  {
    "country": "US",
    "name": "Chaparral",
    "lat": "32.02376",
    "lng": "-106.38566"
  },
  {
    "country": "US",
    "name": "Chimayo",
    "lat": "36.00391",
    "lng": "-105.94697"
  },
  {
    "country": "US",
    "name": "Church Rock",
    "lat": "35.53391",
    "lng": "-108.5998"
  },
  {
    "country": "US",
    "name": "Clayton",
    "lat": "36.45169",
    "lng": "-103.1841"
  },
  {
    "country": "US",
    "name": "Clovis",
    "lat": "34.4048",
    "lng": "-103.20523"
  },
  {
    "country": "US",
    "name": "Columbus",
    "lat": "31.8276",
    "lng": "-107.64002"
  },
  {
    "country": "US",
    "name": "Corrales",
    "lat": "35.23782",
    "lng": "-106.60669"
  },
  {
    "country": "US",
    "name": "Crownpoint",
    "lat": "35.67808",
    "lng": "-108.15118"
  },
  {
    "country": "US",
    "name": "Deming",
    "lat": "32.2687",
    "lng": "-107.75864"
  },
  {
    "country": "US",
    "name": "Dexter",
    "lat": "33.19733",
    "lng": "-104.37302"
  },
  {
    "country": "US",
    "name": "Doña Ana",
    "lat": "32.38954",
    "lng": "-106.8139"
  },
  {
    "country": "US",
    "name": "Dulce",
    "lat": "36.93362",
    "lng": "-106.99893"
  },
  {
    "country": "US",
    "name": "Edgewood",
    "lat": "35.06144",
    "lng": "-106.19141"
  },
  {
    "country": "US",
    "name": "El Cerro",
    "lat": "34.727",
    "lng": "-106.71086"
  },
  {
    "country": "US",
    "name": "El Rancho",
    "lat": "35.88919",
    "lng": "-106.07975"
  },
  {
    "country": "US",
    "name": "El Valle de Arroyo Seco",
    "lat": "35.9628",
    "lng": "-106.02947"
  },
  {
    "country": "US",
    "name": "Eldorado at Santa Fe",
    "lat": "35.52642",
    "lng": "-105.93474"
  },
  {
    "country": "US",
    "name": "Elephant Butte",
    "lat": "33.14868",
    "lng": "-107.18475"
  },
  {
    "country": "US",
    "name": "Española",
    "lat": "35.99113",
    "lng": "-106.08058"
  },
  {
    "country": "US",
    "name": "Estancia",
    "lat": "34.75839",
    "lng": "-106.05585"
  },
  {
    "country": "US",
    "name": "Eunice",
    "lat": "32.43734",
    "lng": "-103.15908"
  },
  {
    "country": "US",
    "name": "Farmington",
    "lat": "36.72806",
    "lng": "-108.21869"
  },
  {
    "country": "US",
    "name": "Flora Vista",
    "lat": "36.79445",
    "lng": "-108.08035"
  },
  {
    "country": "US",
    "name": "Fort Sumner",
    "lat": "34.47173",
    "lng": "-104.24553"
  },
  {
    "country": "US",
    "name": "Gallup",
    "lat": "35.52808",
    "lng": "-108.74258"
  },
  {
    "country": "US",
    "name": "Grants",
    "lat": "35.1476",
    "lng": "-107.85261"
  },
  {
    "country": "US",
    "name": "Hagerman",
    "lat": "33.11511",
    "lng": "-104.32691"
  },
  {
    "country": "US",
    "name": "Hatch",
    "lat": "32.66536",
    "lng": "-107.15307"
  },
  {
    "country": "US",
    "name": "Hobbs",
    "lat": "32.70261",
    "lng": "-103.13604"
  },
  {
    "country": "US",
    "name": "Hurley",
    "lat": "32.69924",
    "lng": "-108.13199"
  },
  {
    "country": "US",
    "name": "Jal",
    "lat": "32.11318",
    "lng": "-103.19351"
  },
  {
    "country": "US",
    "name": "Jarales",
    "lat": "34.61312",
    "lng": "-106.76364"
  },
  {
    "country": "US",
    "name": "Jemez Pueblo",
    "lat": "35.61422",
    "lng": "-106.72832"
  },
  {
    "country": "US",
    "name": "Kirtland",
    "lat": "36.73417",
    "lng": "-108.3598"
  },
  {
    "country": "US",
    "name": "La Cienega",
    "lat": "35.56281",
    "lng": "-106.13086"
  },
  {
    "country": "US",
    "name": "La Huerta",
    "lat": "32.4429",
    "lng": "-104.22106"
  },
  {
    "country": "US",
    "name": "La Luz",
    "lat": "32.97787",
    "lng": "-105.94193"
  },
  {
    "country": "US",
    "name": "La Mesilla",
    "lat": "35.94836",
    "lng": "-106.07058"
  },
  {
    "country": "US",
    "name": "La Puebla",
    "lat": "35.98919",
    "lng": "-105.99641"
  },
  {
    "country": "US",
    "name": "La Union",
    "lat": "31.95066",
    "lng": "-106.66166"
  },
  {
    "country": "US",
    "name": "Laguna",
    "lat": "35.03671",
    "lng": "-107.38282"
  },
  {
    "country": "US",
    "name": "Las Cruces",
    "lat": "32.31232",
    "lng": "-106.77834"
  },
  {
    "country": "US",
    "name": "Las Vegas",
    "lat": "35.59393",
    "lng": "-105.2239"
  },
  {
    "country": "US",
    "name": "Lee Acres",
    "lat": "35.14866",
    "lng": "-106.64697"
  },
  {
    "country": "US",
    "name": "Lee Acres",
    "lat": "36.69889",
    "lng": "-108.03674"
  },
  {
    "country": "US",
    "name": "Lordsburg",
    "lat": "32.35036",
    "lng": "-108.70866"
  },
  {
    "country": "US",
    "name": "Los Alamos",
    "lat": "35.88808",
    "lng": "-106.30697"
  },
  {
    "country": "US",
    "name": "Los Chavez",
    "lat": "34.72571",
    "lng": "-106.75726"
  },
  {
    "country": "US",
    "name": "Los Lunas",
    "lat": "34.80617",
    "lng": "-106.73336"
  },
  {
    "country": "US",
    "name": "Los Ranchos de Albuquerque",
    "lat": "35.16199",
    "lng": "-106.6428"
  },
  {
    "country": "US",
    "name": "Loving",
    "lat": "32.28623",
    "lng": "-104.09577"
  },
  {
    "country": "US",
    "name": "Lovington",
    "lat": "32.94401",
    "lng": "-103.34855"
  },
  {
    "country": "US",
    "name": "McIntosh",
    "lat": "34.86478",
    "lng": "-106.05169"
  },
  {
    "country": "US",
    "name": "Meadow Lake",
    "lat": "34.80144",
    "lng": "-106.54363"
  },
  {
    "country": "US",
    "name": "Mescalero",
    "lat": "33.15759",
    "lng": "-105.77415"
  },
  {
    "country": "US",
    "name": "Mesilla",
    "lat": "32.27009",
    "lng": "-106.80084"
  },
  {
    "country": "US",
    "name": "Mesquite",
    "lat": "32.16454",
    "lng": "-106.69666"
  },
  {
    "country": "US",
    "name": "Milan",
    "lat": "35.16976",
    "lng": "-107.89089"
  },
  {
    "country": "US",
    "name": "Moriarty",
    "lat": "34.99005",
    "lng": "-106.04919"
  },
  {
    "country": "US",
    "name": "Mosquero",
    "lat": "35.77698",
    "lng": "-103.95664"
  },
  {
    "country": "US",
    "name": "Nambe",
    "lat": "35.89336",
    "lng": "-105.98252"
  },
  {
    "country": "US",
    "name": "Navajo",
    "lat": "35.90001",
    "lng": "-109.03398"
  },
  {
    "country": "US",
    "name": "Navajo",
    "lat": "36.94612",
    "lng": "-107.06309"
  },
  {
    "country": "US",
    "name": "North Valley",
    "lat": "35.17338",
    "lng": "-106.62336"
  },
  {
    "country": "US",
    "name": "Paradise Hills",
    "lat": "35.2006",
    "lng": "-106.70114"
  },
  {
    "country": "US",
    "name": "Pecos",
    "lat": "35.5742",
    "lng": "-105.67502"
  },
  {
    "country": "US",
    "name": "Peralta",
    "lat": "34.837",
    "lng": "-106.69058"
  },
  {
    "country": "US",
    "name": "Placitas",
    "lat": "35.30698",
    "lng": "-106.42475"
  },
  {
    "country": "US",
    "name": "Ponderosa Pine",
    "lat": "34.97699",
    "lng": "-106.32419"
  },
  {
    "country": "US",
    "name": "Portales",
    "lat": "34.18619",
    "lng": "-103.3344"
  },
  {
    "country": "US",
    "name": "Questa",
    "lat": "36.70391",
    "lng": "-105.59501"
  },
  {
    "country": "US",
    "name": "Radium Springs",
    "lat": "32.5012",
    "lng": "-106.92807"
  },
  {
    "country": "US",
    "name": "Ranchos de Taos",
    "lat": "36.35864",
    "lng": "-105.60946"
  },
  {
    "country": "US",
    "name": "Raton",
    "lat": "36.90336",
    "lng": "-104.43915"
  },
  {
    "country": "US",
    "name": "Reserve",
    "lat": "33.71311",
    "lng": "-108.75784"
  },
  {
    "country": "US",
    "name": "Rio Rancho",
    "lat": "35.23338",
    "lng": "-106.66447"
  },
  {
    "country": "US",
    "name": "Roswell",
    "lat": "33.39437",
    "lng": "-104.52491"
  },
  {
    "country": "US",
    "name": "Ruidoso",
    "lat": "33.33175",
    "lng": "-105.67304"
  },
  {
    "country": "US",
    "name": "Ruidoso Downs",
    "lat": "33.32897",
    "lng": "-105.60443"
  },
  {
    "country": "US",
    "name": "San Felipe Pueblo",
    "lat": "35.43392",
    "lng": "-106.44669"
  },
  {
    "country": "US",
    "name": "San Miguel",
    "lat": "32.15538",
    "lng": "-106.735"
  },
  {
    "country": "US",
    "name": "San Ysidro",
    "lat": "32.35093",
    "lng": "-106.81112"
  },
  {
    "country": "US",
    "name": "Sandia Heights",
    "lat": "35.17699",
    "lng": "-106.49141"
  },
  {
    "country": "US",
    "name": "Sandia Knolls",
    "lat": "35.16393",
    "lng": "-106.31141"
  },
  {
    "country": "US",
    "name": "Santa Clara",
    "lat": "32.77952",
    "lng": "-108.15032"
  },
  {
    "country": "US",
    "name": "Santa Clara Pueblo",
    "lat": "35.96558",
    "lng": "-106.08863"
  },
  {
    "country": "US",
    "name": "Santa Fe",
    "lat": "35.68698",
    "lng": "-105.9378"
  },
  {
    "country": "US",
    "name": "Santa Rosa",
    "lat": "34.93867",
    "lng": "-104.68249"
  },
  {
    "country": "US",
    "name": "Santa Teresa",
    "lat": "36.15335",
    "lng": "-106.67948"
  },
  {
    "country": "US",
    "name": "Santa Teresa",
    "lat": "31.85594",
    "lng": "-106.63916"
  },
  {
    "country": "US",
    "name": "Santo Domingo Pueblo",
    "lat": "35.51476",
    "lng": "-106.36586"
  },
  {
    "country": "US",
    "name": "Shiprock",
    "lat": "36.78555",
    "lng": "-108.68703"
  },
  {
    "country": "US",
    "name": "Silver City",
    "lat": "32.77007",
    "lng": "-108.28033"
  },
  {
    "country": "US",
    "name": "Socorro",
    "lat": "34.0584",
    "lng": "-106.89142"
  },
  {
    "country": "US",
    "name": "South Valley",
    "lat": "35.01005",
    "lng": "-106.67808"
  },
  {
    "country": "US",
    "name": "Spencerville",
    "lat": "36.82",
    "lng": "-108.05813"
  },
  {
    "country": "US",
    "name": "Sunland Park",
    "lat": "31.7965",
    "lng": "-106.57999"
  },
  {
    "country": "US",
    "name": "Taos Pueblo",
    "lat": "36.43864",
    "lng": "-105.54445"
  },
  {
    "country": "US",
    "name": "Taos",
    "lat": "36.40725",
    "lng": "-105.57307"
  },
  {
    "country": "US",
    "name": "Texico",
    "lat": "34.38869",
    "lng": "-103.05134"
  },
  {
    "country": "US",
    "name": "Thoreau",
    "lat": "35.40253",
    "lng": "-108.2234"
  },
  {
    "country": "US",
    "name": "Tierra Amarilla",
    "lat": "36.70029",
    "lng": "-106.54976"
  },
  {
    "country": "US",
    "name": "Tome",
    "lat": "34.74089",
    "lng": "-106.72836"
  },
  {
    "country": "US",
    "name": "Truth or Consequences",
    "lat": "33.1284",
    "lng": "-107.25281"
  },
  {
    "country": "US",
    "name": "Tucumcari",
    "lat": "35.17191",
    "lng": "-103.72686"
  },
  {
    "country": "US",
    "name": "Tularosa",
    "lat": "33.07397",
    "lng": "-106.0186"
  },
  {
    "country": "US",
    "name": "Twin Lakes",
    "lat": "35.70919",
    "lng": "-108.77481"
  },
  {
    "country": "US",
    "name": "University Park",
    "lat": "32.28343",
    "lng": "-106.75334"
  },
  {
    "country": "US",
    "name": "Upper Fruitland",
    "lat": "36.71584",
    "lng": "-108.31424"
  },
  {
    "country": "US",
    "name": "Vado",
    "lat": "32.11176",
    "lng": "-106.6625"
  },
  {
    "country": "US",
    "name": "Valencia",
    "lat": "34.7995",
    "lng": "-106.7003"
  },
  {
    "country": "US",
    "name": "Waterflow",
    "lat": "36.75972",
    "lng": "-108.48175"
  },
  {
    "country": "US",
    "name": "White Rock",
    "lat": "35.82753",
    "lng": "-106.20391"
  },
  {
    "country": "US",
    "name": "White Sands",
    "lat": "32.38093",
    "lng": "-106.47944"
  },
  {
    "country": "US",
    "name": "Zuni Pueblo",
    "lat": "35.07253",
    "lng": "-108.85064"
  },
  {
    "country": "US",
    "name": "Alamo",
    "lat": "37.36496",
    "lng": "-115.16446"
  },
  {
    "country": "US",
    "name": "Boulder City",
    "lat": "35.97859",
    "lng": "-114.83249"
  },
  {
    "country": "US",
    "name": "Bunkerville",
    "lat": "36.77303",
    "lng": "-114.12802"
  },
  {
    "country": "US",
    "name": "Caliente",
    "lat": "37.61496",
    "lng": "-114.51194"
  },
  {
    "country": "US",
    "name": "Carson City",
    "lat": "39.1638",
    "lng": "-119.7674"
  },
  {
    "country": "US",
    "name": "Cold Springs",
    "lat": "39.68019",
    "lng": "-119.97659"
  },
  {
    "country": "US",
    "name": "Dayton",
    "lat": "39.23714",
    "lng": "-119.59295"
  },
  {
    "country": "US",
    "name": "Ely",
    "lat": "39.24744",
    "lng": "-114.88863"
  },
  {
    "country": "US",
    "name": "Enterprise",
    "lat": "36.02525",
    "lng": "-115.24194"
  },
  {
    "country": "US",
    "name": "Eureka",
    "lat": "39.51271",
    "lng": "-115.96061"
  },
  {
    "country": "US",
    "name": "Fallon",
    "lat": "39.47353",
    "lng": "-118.77737"
  },
  {
    "country": "US",
    "name": "Fernley",
    "lat": "39.60797",
    "lng": "-119.25183"
  },
  {
    "country": "US",
    "name": "Gardnerville",
    "lat": "38.9413",
    "lng": "-119.74962"
  },
  {
    "country": "US",
    "name": "Gardnerville Ranchos",
    "lat": "38.88824",
    "lng": "-119.74129"
  },
  {
    "country": "US",
    "name": "Golden Valley",
    "lat": "39.61547",
    "lng": "-119.82658"
  },
  {
    "country": "US",
    "name": "Goldfield",
    "lat": "37.70854",
    "lng": "-117.23563"
  },
  {
    "country": "US",
    "name": "Hawthorne",
    "lat": "38.52464",
    "lng": "-118.62458"
  },
  {
    "country": "US",
    "name": "Henderson",
    "lat": "36.0397",
    "lng": "-114.98194"
  },
  {
    "country": "US",
    "name": "Incline Village",
    "lat": "39.2513",
    "lng": "-119.97297"
  },
  {
    "country": "US",
    "name": "Johnson Lane",
    "lat": "39.04796",
    "lng": "-119.72212"
  },
  {
    "country": "US",
    "name": "Kingsbury",
    "lat": "38.97713",
    "lng": "-119.90685"
  },
  {
    "country": "US",
    "name": "Las Vegas",
    "lat": "36.17497",
    "lng": "-115.13722"
  },
  {
    "country": "US",
    "name": "Laughlin",
    "lat": "35.16778",
    "lng": "-114.57302"
  },
  {
    "country": "US",
    "name": "Lemmon Valley",
    "lat": "39.63602",
    "lng": "-119.84325"
  },
  {
    "country": "US",
    "name": "McGill",
    "lat": "39.40494",
    "lng": "-114.77863"
  },
  {
    "country": "US",
    "name": "Mesquite",
    "lat": "36.80553",
    "lng": "-114.06719"
  },
  {
    "country": "US",
    "name": "Minden",
    "lat": "38.95407",
    "lng": "-119.76573"
  },
  {
    "country": "US",
    "name": "Moapa Town",
    "lat": "36.68219",
    "lng": "-114.59416"
  },
  {
    "country": "US",
    "name": "Moapa Valley",
    "lat": "36.58053",
    "lng": "-114.47026"
  },
  {
    "country": "US",
    "name": "Mogul",
    "lat": "39.5138",
    "lng": "-119.92603"
  },
  {
    "country": "US",
    "name": "North Las Vegas",
    "lat": "36.19886",
    "lng": "-115.1175"
  },
  {
    "country": "US",
    "name": "Pahrump",
    "lat": "36.20829",
    "lng": "-115.98391"
  },
  {
    "country": "US",
    "name": "Paradise",
    "lat": "36.09719",
    "lng": "-115.14666"
  },
  {
    "country": "US",
    "name": "Pioche",
    "lat": "37.92969",
    "lng": "-114.45221"
  },
  {
    "country": "US",
    "name": "Reno",
    "lat": "39.52963",
    "lng": "-119.8138"
  },
  {
    "country": "US",
    "name": "Sandy Valley",
    "lat": "35.81692",
    "lng": "-115.63223"
  },
  {
    "country": "US",
    "name": "Silver Springs",
    "lat": "39.41547",
    "lng": "-119.22461"
  },
  {
    "country": "US",
    "name": "Smith",
    "lat": "38.80047",
    "lng": "-119.32738"
  },
  {
    "country": "US",
    "name": "Spanish Springs",
    "lat": "39.64908",
    "lng": "-119.70741"
  },
  {
    "country": "US",
    "name": "Sparks",
    "lat": "39.53491",
    "lng": "-119.75269"
  },
  {
    "country": "US",
    "name": "Spring Valley",
    "lat": "36.10803",
    "lng": "-115.245"
  },
  {
    "country": "US",
    "name": "Stagecoach",
    "lat": "39.3738",
    "lng": "-119.37406"
  },
  {
    "country": "US",
    "name": "Sun Valley",
    "lat": "39.5963",
    "lng": "-119.77602"
  },
  {
    "country": "US",
    "name": "Sunrise Manor",
    "lat": "36.21108",
    "lng": "-115.07306"
  },
  {
    "country": "US",
    "name": "Tonopah",
    "lat": "38.06716",
    "lng": "-117.23008"
  },
  {
    "country": "US",
    "name": "Verdi",
    "lat": "39.51824",
    "lng": "-119.98881"
  },
  {
    "country": "US",
    "name": "Virginia City",
    "lat": "39.30963",
    "lng": "-119.64962"
  },
  {
    "country": "US",
    "name": "Whitney",
    "lat": "36.09831",
    "lng": "-115.0363"
  },
  {
    "country": "US",
    "name": "Winchester",
    "lat": "36.12997",
    "lng": "-115.11889"
  },
  {
    "country": "US",
    "name": "Yerington",
    "lat": "38.98575",
    "lng": "-119.16293"
  },
  {
    "country": "US",
    "name": "Beaver",
    "lat": "36.81614",
    "lng": "-100.51987"
  },
  {
    "country": "US",
    "name": "Boise City",
    "lat": "36.72947",
    "lng": "-102.51324"
  },
  {
    "country": "US",
    "name": "Goodwell",
    "lat": "36.5953",
    "lng": "-101.63655"
  },
  {
    "country": "US",
    "name": "Guymon",
    "lat": "36.6828",
    "lng": "-101.48155"
  },
  {
    "country": "US",
    "name": "Hooker",
    "lat": "36.86003",
    "lng": "-101.2135"
  },
  {
    "country": "US",
    "name": "Abernathy",
    "lat": "33.8323",
    "lng": "-101.84295"
  },
  {
    "country": "US",
    "name": "Agua Dulce",
    "lat": "31.65511",
    "lng": "-106.13887"
  },
  {
    "country": "US",
    "name": "Alpine",
    "lat": "30.35862",
    "lng": "-103.66206"
  },
  {
    "country": "US",
    "name": "Amarillo",
    "lat": "35.222",
    "lng": "-101.8313"
  },
  {
    "country": "US",
    "name": "Andrews",
    "lat": "32.31872",
    "lng": "-102.54572"
  },
  {
    "country": "US",
    "name": "Anthony",
    "lat": "31.99927",
    "lng": "-106.60555"
  },
  {
    "country": "US",
    "name": "Aspermont",
    "lat": "33.13343",
    "lng": "-100.22733"
  },
  {
    "country": "US",
    "name": "Big Lake",
    "lat": "31.19154",
    "lng": "-101.46039"
  },
  {
    "country": "US",
    "name": "Big Spring",
    "lat": "32.2504",
    "lng": "-101.47874"
  },
  {
    "country": "US",
    "name": "Booker",
    "lat": "36.45336",
    "lng": "-100.53737"
  },
  {
    "country": "US",
    "name": "Borger",
    "lat": "35.66782",
    "lng": "-101.39739"
  },
  {
    "country": "US",
    "name": "Bovina",
    "lat": "34.51368",
    "lng": "-102.883"
  },
  {
    "country": "US",
    "name": "Brackettville",
    "lat": "29.31051",
    "lng": "-100.41786"
  },
  {
    "country": "US",
    "name": "Brownfield",
    "lat": "33.1812",
    "lng": "-102.27435"
  },
  {
    "country": "US",
    "name": "Bushland",
    "lat": "35.192",
    "lng": "-102.06464"
  },
  {
    "country": "US",
    "name": "Cactus",
    "lat": "36.05226",
    "lng": "-102.0024"
  },
  {
    "country": "US",
    "name": "Canadian",
    "lat": "35.91282",
    "lng": "-100.38208"
  },
  {
    "country": "US",
    "name": "Canutillo",
    "lat": "31.91149",
    "lng": "-106.60027"
  },
  {
    "country": "US",
    "name": "Canyon",
    "lat": "34.98033",
    "lng": "-101.9188"
  },
  {
    "country": "US",
    "name": "Channing",
    "lat": "35.68365",
    "lng": "-102.3302"
  },
  {
    "country": "US",
    "name": "Childress",
    "lat": "34.42645",
    "lng": "-100.204"
  },
  {
    "country": "US",
    "name": "Cienegas Terrace",
    "lat": "29.36745",
    "lng": "-100.94371"
  },
  {
    "country": "US",
    "name": "Clarendon",
    "lat": "34.93783",
    "lng": "-100.8882"
  },
  {
    "country": "US",
    "name": "Claude",
    "lat": "35.11172",
    "lng": "-101.36322"
  },
  {
    "country": "US",
    "name": "Clint",
    "lat": "31.59234",
    "lng": "-106.22414"
  },
  {
    "country": "US",
    "name": "Colorado City",
    "lat": "32.38817",
    "lng": "-100.86456"
  },
  {
    "country": "US",
    "name": "Crane",
    "lat": "31.39736",
    "lng": "-102.35014"
  },
  {
    "country": "US",
    "name": "Crosbyton",
    "lat": "33.66008",
    "lng": "-101.23793"
  },
  {
    "country": "US",
    "name": "Dalhart",
    "lat": "36.05948",
    "lng": "-102.51325"
  },
  {
    "country": "US",
    "name": "Del Rio",
    "lat": "29.36273",
    "lng": "-100.89676"
  },
  {
    "country": "US",
    "name": "Denver City",
    "lat": "32.96455",
    "lng": "-102.8291"
  },
  {
    "country": "US",
    "name": "Dickens",
    "lat": "33.62175",
    "lng": "-100.83652"
  },
  {
    "country": "US",
    "name": "Dimmitt",
    "lat": "34.5509",
    "lng": "-102.31186"
  },
  {
    "country": "US",
    "name": "Dumas",
    "lat": "35.86559",
    "lng": "-101.97324"
  },
  {
    "country": "US",
    "name": "Eagle Pass",
    "lat": "28.70914",
    "lng": "-100.49952"
  },
  {
    "country": "US",
    "name": "Earth",
    "lat": "34.23314",
    "lng": "-102.41075"
  },
  {
    "country": "US",
    "name": "Eidson Road",
    "lat": "28.6772",
    "lng": "-100.48702"
  },
  {
    "country": "US",
    "name": "El Paso",
    "lat": "31.75872",
    "lng": "-106.48693"
  },
  {
    "country": "US",
    "name": "Eldorado",
    "lat": "30.86017",
    "lng": "-100.60093"
  },
  {
    "country": "US",
    "name": "Elm Creek",
    "lat": "28.77442",
    "lng": "-100.49174"
  },
  {
    "country": "US",
    "name": "Fabens",
    "lat": "31.50234",
    "lng": "-106.15859"
  },
  {
    "country": "US",
    "name": "Farwell",
    "lat": "34.38341",
    "lng": "-103.038"
  },
  {
    "country": "US",
    "name": "Floydada",
    "lat": "33.98452",
    "lng": "-101.33766"
  },
  {
    "country": "US",
    "name": "Fort Clark Springs",
    "lat": "29.30607",
    "lng": "-100.42202"
  },
  {
    "country": "US",
    "name": "Fort Davis",
    "lat": "30.58821",
    "lng": "-103.89463"
  },
  {
    "country": "US",
    "name": "Fort Hancock",
    "lat": "31.29846",
    "lng": "-105.84525"
  },
  {
    "country": "US",
    "name": "Fort Stockton",
    "lat": "30.89404",
    "lng": "-102.87932"
  },
  {
    "country": "US",
    "name": "Friona",
    "lat": "34.64173",
    "lng": "-102.7241"
  },
  {
    "country": "US",
    "name": "Fritch",
    "lat": "35.63977",
    "lng": "-101.60323"
  },
  {
    "country": "US",
    "name": "Gail",
    "lat": "32.77038",
    "lng": "-101.44541"
  },
  {
    "country": "US",
    "name": "Garden City",
    "lat": "31.86402",
    "lng": "-101.48123"
  },
  {
    "country": "US",
    "name": "Gardendale",
    "lat": "32.0204",
    "lng": "-102.38015"
  },
  {
    "country": "US",
    "name": "Grape Creek",
    "lat": "31.57932",
    "lng": "-100.5476"
  },
  {
    "country": "US",
    "name": "Guthrie",
    "lat": "33.62064",
    "lng": "-100.32289"
  },
  {
    "country": "US",
    "name": "Hale Center",
    "lat": "34.06424",
    "lng": "-101.84379"
  },
  {
    "country": "US",
    "name": "Hamlin",
    "lat": "32.88483",
    "lng": "-100.12649"
  },
  {
    "country": "US",
    "name": "Hart",
    "lat": "34.38507",
    "lng": "-102.11574"
  },
  {
    "country": "US",
    "name": "Hereford",
    "lat": "34.81521",
    "lng": "-102.39932"
  },
  {
    "country": "US",
    "name": "Homestead Meadows North",
    "lat": "31.84963",
    "lng": "-106.17285"
  },
  {
    "country": "US",
    "name": "Homestead Meadows South",
    "lat": "31.81097",
    "lng": "-106.16427"
  },
  {
    "country": "US",
    "name": "Horizon City",
    "lat": "31.69261",
    "lng": "-106.20748"
  },
  {
    "country": "US",
    "name": "Idalou",
    "lat": "33.66647",
    "lng": "-101.68294"
  },
  {
    "country": "US",
    "name": "Iraan",
    "lat": "30.91405",
    "lng": "-101.89791"
  },
  {
    "country": "US",
    "name": "Jayton",
    "lat": "33.24815",
    "lng": "-100.57373"
  },
  {
    "country": "US",
    "name": "Kermit",
    "lat": "31.85763",
    "lng": "-103.09267"
  },
  {
    "country": "US",
    "name": "Lamesa",
    "lat": "32.7376",
    "lng": "-101.95099"
  },
  {
    "country": "US",
    "name": "Las Quintas Fronterizas",
    "lat": "28.69053",
    "lng": "-100.46869"
  },
  {
    "country": "US",
    "name": "Las Quintas Fronterizas Colonia",
    "lat": "28.69137",
    "lng": "-100.46924"
  },
  {
    "country": "US",
    "name": "Levelland",
    "lat": "33.58732",
    "lng": "-102.37796"
  },
  {
    "country": "US",
    "name": "Littlefield",
    "lat": "33.91731",
    "lng": "-102.3249"
  },
  {
    "country": "US",
    "name": "Lockney",
    "lat": "34.12452",
    "lng": "-101.44155"
  },
  {
    "country": "US",
    "name": "Lorenzo",
    "lat": "33.67064",
    "lng": "-101.53516"
  },
  {
    "country": "US",
    "name": "Lubbock",
    "lat": "33.57786",
    "lng": "-101.85517"
  },
  {
    "country": "US",
    "name": "Marfa",
    "lat": "30.30973",
    "lng": "-104.02134"
  },
  {
    "country": "US",
    "name": "Matador",
    "lat": "34.01202",
    "lng": "-100.82208"
  },
  {
    "country": "US",
    "name": "McCamey",
    "lat": "31.13598",
    "lng": "-102.2243"
  },
  {
    "country": "US",
    "name": "Memphis",
    "lat": "34.72478",
    "lng": "-100.53401"
  },
  {
    "country": "US",
    "name": "Mentone",
    "lat": "31.70513",
    "lng": "-103.59935"
  },
  {
    "country": "US",
    "name": "Merkel",
    "lat": "32.47068",
    "lng": "-100.01287"
  },
  {
    "country": "US",
    "name": "Mertzon",
    "lat": "31.26183",
    "lng": "-100.81733"
  },
  {
    "country": "US",
    "name": "Miami",
    "lat": "35.69143",
    "lng": "-100.63819"
  },
  {
    "country": "US",
    "name": "Midland",
    "lat": "31.99735",
    "lng": "-102.07791"
  },
  {
    "country": "US",
    "name": "Monahans",
    "lat": "31.5943",
    "lng": "-102.89265"
  },
  {
    "country": "US",
    "name": "Morton",
    "lat": "33.7251",
    "lng": "-102.75938"
  },
  {
    "country": "US",
    "name": "Muleshoe",
    "lat": "34.22647",
    "lng": "-102.72383"
  },
  {
    "country": "US",
    "name": "Odessa",
    "lat": "31.84568",
    "lng": "-102.36764"
  },
  {
    "country": "US",
    "name": "Olton",
    "lat": "34.18341",
    "lng": "-102.13463"
  },
  {
    "country": "US",
    "name": "Ozona",
    "lat": "30.71017",
    "lng": "-101.20067"
  },
  {
    "country": "US",
    "name": "Paducah",
    "lat": "34.0123",
    "lng": "-100.30206"
  },
  {
    "country": "US",
    "name": "Pampa",
    "lat": "35.53616",
    "lng": "-100.95987"
  },
  {
    "country": "US",
    "name": "Panhandle",
    "lat": "35.3456",
    "lng": "-101.38044"
  },
  {
    "country": "US",
    "name": "Pecos",
    "lat": "31.42291",
    "lng": "-103.49323"
  },
  {
    "country": "US",
    "name": "Perryton",
    "lat": "36.40003",
    "lng": "-100.80265"
  },
  {
    "country": "US",
    "name": "Petersburg",
    "lat": "33.86952",
    "lng": "-101.59739"
  },
  {
    "country": "US",
    "name": "Plains",
    "lat": "33.18871",
    "lng": "-102.82799"
  },
  {
    "country": "US",
    "name": "Plainview",
    "lat": "34.18479",
    "lng": "-101.70684"
  },
  {
    "country": "US",
    "name": "Post",
    "lat": "33.19122",
    "lng": "-101.379"
  },
  {
    "country": "US",
    "name": "Presidio",
    "lat": "29.56074",
    "lng": "-104.37215"
  },
  {
    "country": "US",
    "name": "Rankin",
    "lat": "31.22265",
    "lng": "-101.93791"
  },
  {
    "country": "US",
    "name": "Ransom Canyon",
    "lat": "33.53342",
    "lng": "-101.67961"
  },
  {
    "country": "US",
    "name": "Robert Lee",
    "lat": "31.89237",
    "lng": "-100.48482"
  },
  {
    "country": "US",
    "name": "Roby",
    "lat": "32.74483",
    "lng": "-100.37761"
  },
  {
    "country": "US",
    "name": "Rocksprings",
    "lat": "30.01576",
    "lng": "-100.20536"
  },
  {
    "country": "US",
    "name": "Roscoe",
    "lat": "32.44595",
    "lng": "-100.53872"
  },
  {
    "country": "US",
    "name": "Rosita North",
    "lat": "28.65644",
    "lng": "-100.42218"
  },
  {
    "country": "US",
    "name": "Rosita South",
    "lat": "28.62375",
    "lng": "-100.42837"
  },
  {
    "country": "US",
    "name": "Rotan",
    "lat": "32.85205",
    "lng": "-100.46566"
  },
  {
    "country": "US",
    "name": "San Angelo",
    "lat": "31.46377",
    "lng": "-100.43704"
  },
  {
    "country": "US",
    "name": "San Elizario",
    "lat": "31.58511",
    "lng": "-106.27276"
  },
  {
    "country": "US",
    "name": "Sanderson",
    "lat": "30.14241",
    "lng": "-102.39403"
  },
  {
    "country": "US",
    "name": "Seagraves",
    "lat": "32.94427",
    "lng": "-102.56491"
  },
  {
    "country": "US",
    "name": "Seminole",
    "lat": "32.71899",
    "lng": "-102.64491"
  },
  {
    "country": "US",
    "name": "Seth Ward",
    "lat": "34.21174",
    "lng": "-101.69017"
  },
  {
    "country": "US",
    "name": "Shallowater",
    "lat": "33.68897",
    "lng": "-101.99823"
  },
  {
    "country": "US",
    "name": "Shamrock",
    "lat": "35.21422",
    "lng": "-100.24901"
  },
  {
    "country": "US",
    "name": "Sierra Blanca",
    "lat": "31.17457",
    "lng": "-105.35718"
  },
  {
    "country": "US",
    "name": "Silverton",
    "lat": "34.47423",
    "lng": "-101.30461"
  },
  {
    "country": "US",
    "name": "Slaton",
    "lat": "33.43731",
    "lng": "-101.64349"
  },
  {
    "country": "US",
    "name": "Snyder",
    "lat": "32.71789",
    "lng": "-100.91762"
  },
  {
    "country": "US",
    "name": "Socorro",
    "lat": "31.65456",
    "lng": "-106.30331"
  },
  {
    "country": "US",
    "name": "Socorro Mission Number 1 Colonia",
    "lat": "31.63622",
    "lng": "-106.29054"
  },
  {
    "country": "US",
    "name": "Sonora",
    "lat": "30.56685",
    "lng": "-100.64343"
  },
  {
    "country": "US",
    "name": "Sparks",
    "lat": "31.67261",
    "lng": "-106.2397"
  },
  {
    "country": "US",
    "name": "Spearman",
    "lat": "36.19837",
    "lng": "-101.19238"
  },
  {
    "country": "US",
    "name": "Stanton",
    "lat": "32.12929",
    "lng": "-101.78846"
  },
  {
    "country": "US",
    "name": "Sterling City",
    "lat": "31.83625",
    "lng": "-100.98483"
  },
  {
    "country": "US",
    "name": "Stinnett",
    "lat": "35.82698",
    "lng": "-101.44294"
  },
  {
    "country": "US",
    "name": "Stratford",
    "lat": "36.33614",
    "lng": "-102.07212"
  },
  {
    "country": "US",
    "name": "Sundown",
    "lat": "33.45621",
    "lng": "-102.48936"
  },
  {
    "country": "US",
    "name": "Sunray",
    "lat": "36.0167",
    "lng": "-101.82462"
  },
  {
    "country": "US",
    "name": "Sweetwater",
    "lat": "32.47095",
    "lng": "-100.40594"
  },
  {
    "country": "US",
    "name": "Tahoka",
    "lat": "33.16676",
    "lng": "-101.79377"
  },
  {
    "country": "US",
    "name": "Tornillo",
    "lat": "31.4454",
    "lng": "-106.08831"
  },
  {
    "country": "US",
    "name": "Tulia",
    "lat": "34.53589",
    "lng": "-101.75852"
  },
  {
    "country": "US",
    "name": "Val Verde Park",
    "lat": "29.37495",
    "lng": "-100.83176"
  },
  {
    "country": "US",
    "name": "Van Horn",
    "lat": "31.04029",
    "lng": "-104.83073"
  },
  {
    "country": "US",
    "name": "Vega",
    "lat": "35.24283",
    "lng": "-102.42826"
  },
  {
    "country": "US",
    "name": "Vinton",
    "lat": "31.95121",
    "lng": "-106.60249"
  },
  {
    "country": "US",
    "name": "Wellington",
    "lat": "34.85617",
    "lng": "-100.21373"
  },
  {
    "country": "US",
    "name": "West Odessa",
    "lat": "31.84235",
    "lng": "-102.49876"
  },
  {
    "country": "US",
    "name": "Westway",
    "lat": "31.95871",
    "lng": "-106.57805"
  },
  {
    "country": "US",
    "name": "Wheeler",
    "lat": "35.44533",
    "lng": "-100.27096"
  },
  {
    "country": "US",
    "name": "Wink",
    "lat": "31.75124",
    "lng": "-103.15989"
  },
  {
    "country": "US",
    "name": "Wolfforth",
    "lat": "33.50592",
    "lng": "-102.00906"
  },
  {
    "country": "US",
    "name": "Aurora",
    "lat": "38.92219",
    "lng": "-111.93409"
  },
  {
    "country": "US",
    "name": "Beaver",
    "lat": "38.27691",
    "lng": "-112.64105"
  },
  {
    "country": "US",
    "name": "Blanding",
    "lat": "37.62433",
    "lng": "-109.47966"
  },
  {
    "country": "US",
    "name": "Carbonville",
    "lat": "39.61996",
    "lng": "-110.83433"
  },
  {
    "country": "US",
    "name": "Castle Dale",
    "lat": "39.21219",
    "lng": "-111.01961"
  },
  {
    "country": "US",
    "name": "Cedar City",
    "lat": "37.67748",
    "lng": "-113.06189"
  },
  {
    "country": "US",
    "name": "Delta",
    "lat": "39.35218",
    "lng": "-112.57717"
  },
  {
    "country": "US",
    "name": "East Carbon City",
    "lat": "39.54774",
    "lng": "-110.41488"
  },
  {
    "country": "US",
    "name": "Enoch",
    "lat": "37.77331",
    "lng": "-113.02439"
  },
  {
    "country": "US",
    "name": "Ephraim",
    "lat": "39.35968",
    "lng": "-111.58631"
  },
  {
    "country": "US",
    "name": "Enterprise",
    "lat": "37.57359",
    "lng": "-113.71913"
  },
  {
    "country": "US",
    "name": "Fairview",
    "lat": "39.62635",
    "lng": "-111.43963"
  },
  {
    "country": "US",
    "name": "Ferron",
    "lat": "39.09358",
    "lng": "-111.13322"
  },
  {
    "country": "US",
    "name": "Fillmore",
    "lat": "38.96885",
    "lng": "-112.32355"
  },
  {
    "country": "US",
    "name": "Fountain Green",
    "lat": "39.62996",
    "lng": "-111.6352"
  },
  {
    "country": "US",
    "name": "Genola",
    "lat": "39.99634",
    "lng": "-111.84327"
  },
  {
    "country": "US",
    "name": "Gunnison",
    "lat": "39.15524",
    "lng": "-111.81826"
  },
  {
    "country": "US",
    "name": "Helper",
    "lat": "39.68413",
    "lng": "-110.85461"
  },
  {
    "country": "US",
    "name": "Hildale",
    "lat": "37.0036",
    "lng": "-112.96688"
  },
  {
    "country": "US",
    "name": "Huntington",
    "lat": "39.32664",
    "lng": "-110.96461"
  },
  {
    "country": "US",
    "name": "Hurricane",
    "lat": "37.17526",
    "lng": "-113.28995"
  },
  {
    "country": "US",
    "name": "Ivins",
    "lat": "37.16859",
    "lng": "-113.67941"
  },
  {
    "country": "US",
    "name": "Junction",
    "lat": "38.23748",
    "lng": "-112.21993"
  },
  {
    "country": "US",
    "name": "Kanab",
    "lat": "37.04749",
    "lng": "-112.52631"
  },
  {
    "country": "US",
    "name": "LaVerkin",
    "lat": "37.20109",
    "lng": "-113.26967"
  },
  {
    "country": "US",
    "name": "Loa",
    "lat": "38.40276",
    "lng": "-111.64296"
  },
  {
    "country": "US",
    "name": "Manti",
    "lat": "39.2683",
    "lng": "-111.63686"
  },
  {
    "country": "US",
    "name": "Milford",
    "lat": "38.39691",
    "lng": "-113.01079"
  },
  {
    "country": "US",
    "name": "Moab",
    "lat": "38.57332",
    "lng": "-109.54984"
  },
  {
    "country": "US",
    "name": "Monroe",
    "lat": "38.62997",
    "lng": "-112.12076"
  },
  {
    "country": "US",
    "name": "Monticello",
    "lat": "37.87138",
    "lng": "-109.34289"
  },
  {
    "country": "US",
    "name": "Moroni",
    "lat": "39.52496",
    "lng": "-111.59047"
  },
  {
    "country": "US",
    "name": "Mount Pleasant",
    "lat": "39.54691",
    "lng": "-111.45547"
  },
  {
    "country": "US",
    "name": "Nephi",
    "lat": "39.71023",
    "lng": "-111.83632"
  },
  {
    "country": "US",
    "name": "Orangeville",
    "lat": "39.22719",
    "lng": "-111.0535"
  },
  {
    "country": "US",
    "name": "Panguitch",
    "lat": "37.82276",
    "lng": "-112.43576"
  },
  {
    "country": "US",
    "name": "Parowan",
    "lat": "37.8422",
    "lng": "-112.828"
  },
  {
    "country": "US",
    "name": "Price",
    "lat": "39.59941",
    "lng": "-110.81071"
  },
  {
    "country": "US",
    "name": "Richfield",
    "lat": "38.77247",
    "lng": "-112.08409"
  },
  {
    "country": "US",
    "name": "Saint George",
    "lat": "37.10415",
    "lng": "-113.58412"
  },
  {
    "country": "US",
    "name": "Salina",
    "lat": "38.95774",
    "lng": "-111.85993"
  },
  {
    "country": "US",
    "name": "Santa Clara",
    "lat": "37.13304",
    "lng": "-113.65413"
  },
  {
    "country": "US",
    "name": "Santaquin",
    "lat": "39.97551",
    "lng": "-111.78521"
  },
  {
    "country": "US",
    "name": "Spring City",
    "lat": "39.48246",
    "lng": "-111.49602"
  },
  {
    "country": "US",
    "name": "Spring Glen",
    "lat": "39.65941",
    "lng": "-110.85349"
  },
  {
    "country": "US",
    "name": "Toquerville",
    "lat": "37.25332",
    "lng": "-113.28467"
  },
  {
    "country": "US",
    "name": "Washington",
    "lat": "37.13054",
    "lng": "-113.50829"
  },
  {
    "country": "US",
    "name": "Wellington",
    "lat": "39.54247",
    "lng": "-110.73543"
  },
  {
    "country": "US",
    "name": "West Sedona",
    "lat": "34.86724",
    "lng": "-111.80543"
  },
  {
    "country": "US",
    "name": "Sheridan",
    "lat": "38.97962",
    "lng": "-121.37551"
  },
  {
    "country": "US",
    "name": "Three Rivers",
    "lat": "36.43884",
    "lng": "-118.90454"
  },
  {
    "country": "US",
    "name": "Wasco",
    "lat": "35.59412",
    "lng": "-119.34095"
  },
  {
    "country": "US",
    "name": "West Bishop",
    "lat": "37.36104",
    "lng": "-118.45511"
  },
  {
    "country": "US",
    "name": "Paonia",
    "lat": "38.86832",
    "lng": "-107.592"
  },
  {
    "country": "US",
    "name": "Cimarron",
    "lat": "37.80669",
    "lng": "-100.3482"
  },
  {
    "country": "US",
    "name": "Pojoaque",
    "lat": "35.8928",
    "lng": "-106.02308"
  },
  {
    "country": "US",
    "name": "Beatty",
    "lat": "36.90856",
    "lng": "-116.75923"
  },
  {
    "country": "US",
    "name": "Indian Hills",
    "lat": "39.08602",
    "lng": "-119.78407"
  },
  {
    "country": "US",
    "name": "Anton",
    "lat": "33.8112",
    "lng": "-102.16379"
  },
  {
    "country": "US",
    "name": "Gruver",
    "lat": "36.26503",
    "lng": "-101.40627"
  },
  {
    "country": "US",
    "name": "Ralls",
    "lat": "33.67425",
    "lng": "-101.38766"
  },
  {
    "country": "US",
    "name": "Spur",
    "lat": "33.47648",
    "lng": "-100.85569"
  },
  {
    "country": "US",
    "name": "Centerfield",
    "lat": "39.12524",
    "lng": "-111.81909"
  },
  {
    "country": "US",
    "name": "Ajo",
    "lat": "32.37172",
    "lng": "-112.86071"
  },
  {
    "country": "US",
    "name": "Anthem",
    "lat": "33.86726",
    "lng": "-112.14682"
  },
  {
    "country": "US",
    "name": "Apache Junction",
    "lat": "33.41505",
    "lng": "-111.54958"
  },
  {
    "country": "US",
    "name": "Arivaca Junction",
    "lat": "31.72731",
    "lng": "-111.0612"
  },
  {
    "country": "US",
    "name": "Arizona City",
    "lat": "32.75589",
    "lng": "-111.67096"
  },
  {
    "country": "US",
    "name": "Avondale",
    "lat": "33.4356",
    "lng": "-112.3496"
  },
  {
    "country": "US",
    "name": "Avra Valley",
    "lat": "32.43785",
    "lng": "-111.31539"
  },
  {
    "country": "US",
    "name": "Bagdad",
    "lat": "34.58113",
    "lng": "-113.20464"
  },
  {
    "country": "US",
    "name": "Beaver Dam",
    "lat": "36.89942",
    "lng": "-113.93274"
  },
  {
    "country": "US",
    "name": "Benson",
    "lat": "31.96786",
    "lng": "-110.29452"
  },
  {
    "country": "US",
    "name": "Big Park",
    "lat": "34.7803",
    "lng": "-111.76265"
  },
  {
    "country": "US",
    "name": "Wray",
    "lat": "40.07582",
    "lng": "-102.22325"
  },
  {
    "country": "US",
    "name": "Rathdrum",
    "lat": "47.8124",
    "lng": "-116.89659"
  },
  {
    "country": "US",
    "name": "Juneau",
    "lat": "58.30194",
    "lng": "-134.41972"
  },
  {
    "country": "US",
    "name": "Beach",
    "lat": "46.91807",
    "lng": "-104.00437"
  },
  {
    "country": "US",
    "name": "Ketchikan",
    "lat": "55.3418",
    "lng": "-131.64757"
  },
  {
    "country": "US",
    "name": "Little Cottonwood Creek Valley",
    "lat": "40.60439",
    "lng": "-111.82938"
  },
  {
    "country": "US",
    "name": "Salem",
    "lat": "40.05301",
    "lng": "-111.67354"
  },
  {
    "country": "US",
    "name": "Wellsville",
    "lat": "41.63854",
    "lng": "-111.93383"
  },
  {
    "country": "US",
    "name": "Lea Hill",
    "lat": "47.32621",
    "lng": "-122.18151"
  },
  {
    "country": "US",
    "name": "Metlakatla",
    "lat": "55.12848",
    "lng": "-131.57519"
  },
  {
    "country": "US",
    "name": "Petersburg",
    "lat": "56.8125",
    "lng": "-132.95556"
  },
  {
    "country": "US",
    "name": "Sitka",
    "lat": "57.05315",
    "lng": "-135.33088"
  },
  {
    "country": "US",
    "name": "Wrangell",
    "lat": "56.47083",
    "lng": "-132.37667"
  },
  {
    "country": "US",
    "name": "Alturas",
    "lat": "41.48714",
    "lng": "-120.54349"
  },
  {
    "country": "US",
    "name": "Anderson",
    "lat": "40.44821",
    "lng": "-122.29778"
  },
  {
    "country": "US",
    "name": "Arcata",
    "lat": "40.86652",
    "lng": "-124.08284"
  },
  {
    "country": "US",
    "name": "Bayside",
    "lat": "40.84235",
    "lng": "-124.06367"
  },
  {
    "country": "US",
    "name": "Bayview",
    "lat": "40.77263",
    "lng": "-124.18395"
  },
  {
    "country": "US",
    "name": "Bella Vista",
    "lat": "40.64071",
    "lng": "-122.2325"
  },
  {
    "country": "US",
    "name": "Blue Lake",
    "lat": "40.88291",
    "lng": "-123.98395"
  },
  {
    "country": "US",
    "name": "Burney",
    "lat": "40.88238",
    "lng": "-121.66082"
  },
  {
    "country": "US",
    "name": "Central Valley (historical)",
    "lat": "40.68043",
    "lng": "-122.37112"
  },
  {
    "country": "US",
    "name": "Chester",
    "lat": "40.30627",
    "lng": "-121.23191"
  },
  {
    "country": "US",
    "name": "Cottonwood",
    "lat": "40.38571",
    "lng": "-122.28084"
  },
  {
    "country": "US",
    "name": "Crescent City",
    "lat": "41.75595",
    "lng": "-124.20175"
  },
  {
    "country": "US",
    "name": "Cutten",
    "lat": "40.76985",
    "lng": "-124.14284"
  },
  {
    "country": "US",
    "name": "Dunsmuir",
    "lat": "41.20821",
    "lng": "-122.27195"
  },
  {
    "country": "US",
    "name": "Eureka",
    "lat": "40.80207",
    "lng": "-124.16367"
  },
  {
    "country": "US",
    "name": "Ferndale",
    "lat": "40.57624",
    "lng": "-124.26394"
  },
  {
    "country": "US",
    "name": "Fortuna",
    "lat": "40.59819",
    "lng": "-124.15728"
  },
  {
    "country": "US",
    "name": "Gerber",
    "lat": "40.05627",
    "lng": "-122.15027"
  },
  {
    "country": "US",
    "name": "Greenville",
    "lat": "40.13961",
    "lng": "-120.95107"
  },
  {
    "country": "US",
    "name": "Happy Camp",
    "lat": "41.79275",
    "lng": "-123.3808"
  },
  {
    "country": "US",
    "name": "Hayfork",
    "lat": "40.55431",
    "lng": "-123.18308"
  },
  {
    "country": "US",
    "name": "Humboldt Hill",
    "lat": "40.72596",
    "lng": "-124.18978"
  },
  {
    "country": "US",
    "name": "Hydesville",
    "lat": "40.54763",
    "lng": "-124.09727"
  },
  {
    "country": "US",
    "name": "Janesville",
    "lat": "40.29656",
    "lng": "-120.52411"
  },
  {
    "country": "US",
    "name": "Johnstonville",
    "lat": "40.38434",
    "lng": "-120.58745"
  },
  {
    "country": "US",
    "name": "Lewiston",
    "lat": "40.70737",
    "lng": "-122.80752"
  },
  {
    "country": "US",
    "name": "Los Molinos",
    "lat": "40.02127",
    "lng": "-122.10027"
  },
  {
    "country": "US",
    "name": "McCloud",
    "lat": "41.25571",
    "lng": "-122.13945"
  },
  {
    "country": "US",
    "name": "McKinleyville",
    "lat": "40.94652",
    "lng": "-124.10062"
  },
  {
    "country": "US",
    "name": "Montague",
    "lat": "41.7282",
    "lng": "-122.5278"
  },
  {
    "country": "US",
    "name": "Mount Shasta",
    "lat": "41.31024",
    "lng": "-122.31225"
  },
  {
    "country": "US",
    "name": "Myrtletown",
    "lat": "40.78874",
    "lng": "-124.13034"
  },
  {
    "country": "US",
    "name": "Palo Cedro",
    "lat": "40.56376",
    "lng": "-122.23889"
  },
  {
    "country": "US",
    "name": "Pine Hills",
    "lat": "40.73318",
    "lng": "-124.15228"
  },
  {
    "country": "US",
    "name": "Red Bluff",
    "lat": "40.17849",
    "lng": "-122.23583"
  },
  {
    "country": "US",
    "name": "Redding",
    "lat": "40.58654",
    "lng": "-122.39168"
  },
  {
    "country": "US",
    "name": "Redway",
    "lat": "40.12014",
    "lng": "-123.82336"
  },
  {
    "country": "US",
    "name": "Rio Dell",
    "lat": "40.4993",
    "lng": "-124.10644"
  },
  {
    "country": "US",
    "name": "Shasta",
    "lat": "40.59932",
    "lng": "-122.49196"
  },
  {
    "country": "US",
    "name": "Shasta Lake",
    "lat": "40.68043",
    "lng": "-122.37084"
  },
  {
    "country": "US",
    "name": "Shingletown",
    "lat": "40.49238",
    "lng": "-121.88916"
  },
  {
    "country": "US",
    "name": "Susanville",
    "lat": "40.41628",
    "lng": "-120.65301"
  },
  {
    "country": "US",
    "name": "Weaverville",
    "lat": "40.73098",
    "lng": "-122.94197"
  },
  {
    "country": "US",
    "name": "Weed",
    "lat": "41.42265",
    "lng": "-122.38613"
  },
  {
    "country": "US",
    "name": "Westwood",
    "lat": "40.306",
    "lng": "-121.00579"
  },
  {
    "country": "US",
    "name": "Willow Creek",
    "lat": "40.93958",
    "lng": "-123.63144"
  },
  {
    "country": "US",
    "name": "Yreka",
    "lat": "41.73542",
    "lng": "-122.63447"
  },
  {
    "country": "US",
    "name": "Akron",
    "lat": "40.16054",
    "lng": "-103.21438"
  },
  {
    "country": "US",
    "name": "Aristocrat Ranchettes",
    "lat": "40.10915",
    "lng": "-104.76247"
  },
  {
    "country": "US",
    "name": "Ault",
    "lat": "40.58248",
    "lng": "-104.73191"
  },
  {
    "country": "US",
    "name": "Berthoud",
    "lat": "40.30832",
    "lng": "-105.08109"
  },
  {
    "country": "US",
    "name": "Boulder",
    "lat": "40.01499",
    "lng": "-105.27055"
  },
  {
    "country": "US",
    "name": "Brush",
    "lat": "40.25887",
    "lng": "-103.62384"
  },
  {
    "country": "US",
    "name": "Campion",
    "lat": "40.34943",
    "lng": "-105.07776"
  },
  {
    "country": "US",
    "name": "Craig",
    "lat": "40.51525",
    "lng": "-107.54645"
  },
  {
    "country": "US",
    "name": "Dacono",
    "lat": "40.08471",
    "lng": "-104.93942"
  },
  {
    "country": "US",
    "name": "Eaton",
    "lat": "40.53026",
    "lng": "-104.71135"
  },
  {
    "country": "US",
    "name": "Erie",
    "lat": "40.05026",
    "lng": "-105.04998"
  },
  {
    "country": "US",
    "name": "Estes Park",
    "lat": "40.37721",
    "lng": "-105.52167"
  },
  {
    "country": "US",
    "name": "Evans",
    "lat": "40.37637",
    "lng": "-104.69219"
  },
  {
    "country": "US",
    "name": "Firestone",
    "lat": "40.11248",
    "lng": "-104.93664"
  },
  {
    "country": "US",
    "name": "Fort Collins",
    "lat": "40.58526",
    "lng": "-105.08442"
  },
  {
    "country": "US",
    "name": "Fort Lupton",
    "lat": "40.08471",
    "lng": "-104.81303"
  },
  {
    "country": "US",
    "name": "Fort Morgan",
    "lat": "40.25026",
    "lng": "-103.79995"
  },
  {
    "country": "US",
    "name": "Frederick",
    "lat": "40.09915",
    "lng": "-104.9372"
  },
  {
    "country": "US",
    "name": "Gilcrest",
    "lat": "40.28193",
    "lng": "-104.77775"
  },
  {
    "country": "US",
    "name": "Granby",
    "lat": "40.0861",
    "lng": "-105.93946"
  },
  {
    "country": "US",
    "name": "Greeley",
    "lat": "40.42331",
    "lng": "-104.70913"
  },
  {
    "country": "US",
    "name": "Hayden",
    "lat": "40.49529",
    "lng": "-107.25729"
  },
  {
    "country": "US",
    "name": "Holyoke",
    "lat": "40.58444",
    "lng": "-102.30241"
  },
  {
    "country": "US",
    "name": "Hot Sulphur Springs",
    "lat": "40.07304",
    "lng": "-106.1028"
  },
  {
    "country": "US",
    "name": "Hudson",
    "lat": "40.07359",
    "lng": "-104.64302"
  },
  {
    "country": "US",
    "name": "Johnstown",
    "lat": "40.33693",
    "lng": "-104.9122"
  },
  {
    "country": "US",
    "name": "Julesburg",
    "lat": "40.98833",
    "lng": "-102.26435"
  },
  {
    "country": "US",
    "name": "Keenesburg",
    "lat": "40.10832",
    "lng": "-104.51996"
  },
  {
    "country": "US",
    "name": "Kersey",
    "lat": "40.38748",
    "lng": "-104.56163"
  },
  {
    "country": "US",
    "name": "Kremmling",
    "lat": "40.05887",
    "lng": "-106.38892"
  },
  {
    "country": "US",
    "name": "La Salle",
    "lat": "40.34887",
    "lng": "-104.70191"
  },
  {
    "country": "US",
    "name": "Laporte",
    "lat": "40.62633",
    "lng": "-105.13916"
  },
  {
    "country": "US",
    "name": "Lochbuie",
    "lat": "40.00721",
    "lng": "-104.71608"
  },
  {
    "country": "US",
    "name": "Longmont",
    "lat": "40.16721",
    "lng": "-105.10193"
  },
  {
    "country": "US",
    "name": "Loveland",
    "lat": "40.39776",
    "lng": "-105.07498"
  },
  {
    "country": "US",
    "name": "Lyons",
    "lat": "40.22471",
    "lng": "-105.27138"
  },
  {
    "country": "US",
    "name": "Mead",
    "lat": "40.23332",
    "lng": "-104.99859"
  },
  {
    "country": "US",
    "name": "Meeker",
    "lat": "40.03747",
    "lng": "-107.91313"
  },
  {
    "country": "US",
    "name": "Milliken",
    "lat": "40.32943",
    "lng": "-104.85525"
  },
  {
    "country": "US",
    "name": "Niwot",
    "lat": "40.10387",
    "lng": "-105.17082"
  },
  {
    "country": "US",
    "name": "Platteville",
    "lat": "40.21498",
    "lng": "-104.82275"
  },
  {
    "country": "US",
    "name": "Rangely",
    "lat": "40.08748",
    "lng": "-108.80483"
  },
  {
    "country": "US",
    "name": "Severance",
    "lat": "40.52415",
    "lng": "-104.85108"
  },
  {
    "country": "US",
    "name": "Steamboat Springs",
    "lat": "40.48498",
    "lng": "-106.83172"
  },
  {
    "country": "US",
    "name": "Sterling",
    "lat": "40.62554",
    "lng": "-103.20771"
  },
  {
    "country": "US",
    "name": "Walden",
    "lat": "40.73164",
    "lng": "-106.28364"
  },
  {
    "country": "US",
    "name": "Wellington",
    "lat": "40.70387",
    "lng": "-105.00859"
  },
  {
    "country": "US",
    "name": "Windsor",
    "lat": "40.47748",
    "lng": "-104.90136"
  },
  {
    "country": "US",
    "name": "Yuma",
    "lat": "40.12221",
    "lng": "-102.72521"
  },
  {
    "country": "US",
    "name": "Aberdeen",
    "lat": "42.94408",
    "lng": "-112.83833"
  },
  {
    "country": "US",
    "name": "American Falls",
    "lat": "42.78602",
    "lng": "-112.85444"
  },
  {
    "country": "US",
    "name": "Ammon",
    "lat": "43.46964",
    "lng": "-111.96664"
  },
  {
    "country": "US",
    "name": "Arco",
    "lat": "43.63657",
    "lng": "-113.30028"
  },
  {
    "country": "US",
    "name": "Ashton",
    "lat": "44.07158",
    "lng": "-111.44829"
  },
  {
    "country": "US",
    "name": "Bellevue",
    "lat": "43.46352",
    "lng": "-114.2606"
  },
  {
    "country": "US",
    "name": "Blackfoot",
    "lat": "43.19047",
    "lng": "-112.34498"
  },
  {
    "country": "US",
    "name": "Boise",
    "lat": "43.6135",
    "lng": "-116.20345"
  },
  {
    "country": "US",
    "name": "Bonners Ferry",
    "lat": "48.69133",
    "lng": "-116.31631"
  },
  {
    "country": "US",
    "name": "Buhl",
    "lat": "42.59907",
    "lng": "-114.75949"
  },
  {
    "country": "US",
    "name": "Burley",
    "lat": "42.53574",
    "lng": "-113.79279"
  },
  {
    "country": "US",
    "name": "Caldwell",
    "lat": "43.66294",
    "lng": "-116.68736"
  },
  {
    "country": "US",
    "name": "Cascade",
    "lat": "44.51628",
    "lng": "-116.0418"
  },
  {
    "country": "US",
    "name": "Challis",
    "lat": "44.50464",
    "lng": "-114.23173"
  },
  {
    "country": "US",
    "name": "Chubbuck",
    "lat": "42.92075",
    "lng": "-112.46609"
  },
  {
    "country": "US",
    "name": "Coeur d'Alene",
    "lat": "47.67768",
    "lng": "-116.78047"
  },
  {
    "country": "US",
    "name": "Council",
    "lat": "44.72989",
    "lng": "-116.4382"
  },
  {
    "country": "US",
    "name": "Dalton Gardens",
    "lat": "47.72963",
    "lng": "-116.77019"
  },
  {
    "country": "US",
    "name": "Driggs",
    "lat": "43.72325",
    "lng": "-111.11133"
  },
  {
    "country": "US",
    "name": "Dubois",
    "lat": "44.1763",
    "lng": "-112.23082"
  },
  {
    "country": "US",
    "name": "Eagle",
    "lat": "43.69544",
    "lng": "-116.35401"
  },
  {
    "country": "US",
    "name": "Emmett",
    "lat": "43.8735",
    "lng": "-116.4993"
  },
  {
    "country": "US",
    "name": "Fairfield",
    "lat": "43.34657",
    "lng": "-114.79173"
  },
  {
    "country": "US",
    "name": "Filer",
    "lat": "42.57019",
    "lng": "-114.60782"
  },
  {
    "country": "US",
    "name": "Fort Hall",
    "lat": "43.03325",
    "lng": "-112.43831"
  },
  {
    "country": "US",
    "name": "Fruitland",
    "lat": "44.00766",
    "lng": "-116.91655"
  },
  {
    "country": "US",
    "name": "Garden City",
    "lat": "43.62211",
    "lng": "-116.23817"
  },
  {
    "country": "US",
    "name": "Glenns Ferry",
    "lat": "42.9549",
    "lng": "-115.3009"
  },
  {
    "country": "US",
    "name": "Gooding",
    "lat": "42.93879",
    "lng": "-114.71311"
  },
  {
    "country": "US",
    "name": "Grangeville",
    "lat": "45.92655",
    "lng": "-116.12237"
  },
  {
    "country": "US",
    "name": "Hailey",
    "lat": "43.51963",
    "lng": "-114.31532"
  },
  {
    "country": "US",
    "name": "Hansen",
    "lat": "42.53068",
    "lng": "-114.30101"
  },
  {
    "country": "US",
    "name": "Hayden",
    "lat": "47.76602",
    "lng": "-116.78658"
  },
  {
    "country": "US",
    "name": "Heyburn",
    "lat": "42.55852",
    "lng": "-113.7639"
  },
  {
    "country": "US",
    "name": "Homedale",
    "lat": "43.61766",
    "lng": "-116.93376"
  },
  {
    "country": "US",
    "name": "Idaho City",
    "lat": "43.8285",
    "lng": "-115.83455"
  },
  {
    "country": "US",
    "name": "Idaho Falls",
    "lat": "43.46658",
    "lng": "-112.03414"
  },
  {
    "country": "US",
    "name": "Iona",
    "lat": "43.5263",
    "lng": "-111.93302"
  },
  {
    "country": "US",
    "name": "Jerome",
    "lat": "42.72407",
    "lng": "-114.51865"
  },
  {
    "country": "US",
    "name": "Kamiah",
    "lat": "46.22712",
    "lng": "-116.02931"
  },
  {
    "country": "US",
    "name": "Kellogg",
    "lat": "47.53826",
    "lng": "-116.11933"
  },
  {
    "country": "US",
    "name": "Ketchum",
    "lat": "43.68074",
    "lng": "-114.36366"
  },
  {
    "country": "US",
    "name": "Kimberly",
    "lat": "42.5338",
    "lng": "-114.36476"
  },
  {
    "country": "US",
    "name": "Kuna",
    "lat": "43.49183",
    "lng": "-116.42012"
  },
  {
    "country": "US",
    "name": "Lapwai",
    "lat": "46.40489",
    "lng": "-116.80487"
  },
  {
    "country": "US",
    "name": "Lewiston",
    "lat": "46.41655",
    "lng": "-117.01766"
  },
  {
    "country": "US",
    "name": "Lewiston Orchards",
    "lat": "46.38044",
    "lng": "-116.97543"
  },
  {
    "country": "US",
    "name": "Lincoln",
    "lat": "43.51297",
    "lng": "-111.96441"
  },
  {
    "country": "US",
    "name": "Malad City",
    "lat": "42.19159",
    "lng": "-112.2508"
  },
  {
    "country": "US",
    "name": "Marsing",
    "lat": "43.54544",
    "lng": "-116.8132"
  },
  {
    "country": "US",
    "name": "McCall",
    "lat": "44.91101",
    "lng": "-116.09874"
  },
  {
    "country": "US",
    "name": "Meridian",
    "lat": "43.61211",
    "lng": "-116.39151"
  },
  {
    "country": "US",
    "name": "Middleton",
    "lat": "43.70683",
    "lng": "-116.62014"
  },
  {
    "country": "US",
    "name": "Montpelier",
    "lat": "42.32215",
    "lng": "-111.2977"
  },
  {
    "country": "US",
    "name": "Moreland",
    "lat": "43.22269",
    "lng": "-112.44248"
  },
  {
    "country": "US",
    "name": "Moscow",
    "lat": "46.73239",
    "lng": "-117.00017"
  },
  {
    "country": "US",
    "name": "Mountain Home",
    "lat": "43.13295",
    "lng": "-115.6912"
  },
  {
    "country": "US",
    "name": "Murphy",
    "lat": "43.21822",
    "lng": "-116.55234"
  },
  {
    "country": "US",
    "name": "Nampa",
    "lat": "43.54072",
    "lng": "-116.56346"
  },
  {
    "country": "US",
    "name": "New Plymouth",
    "lat": "43.96989",
    "lng": "-116.81904"
  },
  {
    "country": "US",
    "name": "Nezperce",
    "lat": "46.23489",
    "lng": "-116.2407"
  },
  {
    "country": "US",
    "name": "Orofino",
    "lat": "46.47935",
    "lng": "-116.25514"
  },
  {
    "country": "US",
    "name": "Osburn",
    "lat": "47.50604",
    "lng": "-115.99933"
  },
  {
    "country": "US",
    "name": "Paris",
    "lat": "42.22715",
    "lng": "-111.40104"
  },
  {
    "country": "US",
    "name": "Parma",
    "lat": "43.78516",
    "lng": "-116.94321"
  },
  {
    "country": "US",
    "name": "Paul",
    "lat": "42.60796",
    "lng": "-113.78335"
  },
  {
    "country": "US",
    "name": "Payette",
    "lat": "44.07822",
    "lng": "-116.93377"
  },
  {
    "country": "US",
    "name": "Pinehurst",
    "lat": "47.53881",
    "lng": "-116.23739"
  },
  {
    "country": "US",
    "name": "Plummer",
    "lat": "47.33518",
    "lng": "-116.88851"
  },
  {
    "country": "US",
    "name": "Pocatello",
    "lat": "42.8713",
    "lng": "-112.44553"
  },
  {
    "country": "US",
    "name": "Ponderay",
    "lat": "48.30548",
    "lng": "-116.5338"
  },
  {
    "country": "US",
    "name": "Post Falls",
    "lat": "47.71796",
    "lng": "-116.95159"
  },
  {
    "country": "US",
    "name": "Preston",
    "lat": "42.09631",
    "lng": "-111.87662"
  },
  {
    "country": "US",
    "name": "Priest River",
    "lat": "48.18097",
    "lng": "-116.91157"
  },
  {
    "country": "US",
    "name": "Rexburg",
    "lat": "43.82602",
    "lng": "-111.78969"
  },
  {
    "country": "US",
    "name": "Rigby",
    "lat": "43.67241",
    "lng": "-111.91497"
  },
  {
    "country": "US",
    "name": "Rupert",
    "lat": "42.61908",
    "lng": "-113.67723"
  },
  {
    "country": "US",
    "name": "Saint Anthony",
    "lat": "43.9663",
    "lng": "-111.68218"
  },
  {
    "country": "US",
    "name": "Saint Maries",
    "lat": "47.31435",
    "lng": "-116.56267"
  },
  {
    "country": "US",
    "name": "Salmon",
    "lat": "45.17575",
    "lng": "-113.8959"
  },
  {
    "country": "US",
    "name": "Sandpoint",
    "lat": "48.27659",
    "lng": "-116.55325"
  },
  {
    "country": "US",
    "name": "Shelley",
    "lat": "43.3813",
    "lng": "-112.12331"
  },
  {
    "country": "US",
    "name": "Shoshone",
    "lat": "42.93602",
    "lng": "-114.40588"
  },
  {
    "country": "US",
    "name": "Soda Springs",
    "lat": "42.65437",
    "lng": "-111.60467"
  },
  {
    "country": "US",
    "name": "Spirit Lake",
    "lat": "47.96629",
    "lng": "-116.86853"
  },
  {
    "country": "US",
    "name": "Star",
    "lat": "43.69211",
    "lng": "-116.49346"
  },
  {
    "country": "US",
    "name": "Sugar City",
    "lat": "43.87297",
    "lng": "-111.7483"
  },
  {
    "country": "US",
    "name": "Sun Valley",
    "lat": "43.69713",
    "lng": "-114.35172"
  },
  {
    "country": "US",
    "name": "Twin Falls",
    "lat": "42.56297",
    "lng": "-114.46087"
  },
  {
    "country": "US",
    "name": "Tyhee",
    "lat": "42.95158",
    "lng": "-112.46637"
  },
  {
    "country": "US",
    "name": "Ucon",
    "lat": "43.5963",
    "lng": "-111.96386"
  },
  {
    "country": "US",
    "name": "Victor",
    "lat": "43.6027",
    "lng": "-111.11133"
  },
  {
    "country": "US",
    "name": "Wallace",
    "lat": "47.47409",
    "lng": "-115.92794"
  },
  {
    "country": "US",
    "name": "Weiser",
    "lat": "44.251",
    "lng": "-116.96933"
  },
  {
    "country": "US",
    "name": "Wendell",
    "lat": "42.77574",
    "lng": "-114.70422"
  },
  {
    "country": "US",
    "name": "Wilder",
    "lat": "43.67655",
    "lng": "-116.91182"
  },
  {
    "country": "US",
    "name": "Absarokee",
    "lat": "45.5205",
    "lng": "-109.44294"
  },
  {
    "country": "US",
    "name": "Anaconda",
    "lat": "46.12854",
    "lng": "-112.94226"
  },
  {
    "country": "US",
    "name": "Baker",
    "lat": "46.36695",
    "lng": "-104.28466"
  },
  {
    "country": "US",
    "name": "Belgrade",
    "lat": "45.77604",
    "lng": "-111.1769"
  },
  {
    "country": "US",
    "name": "Big Sky",
    "lat": "45.28465",
    "lng": "-111.36829"
  },
  {
    "country": "US",
    "name": "Big Timber",
    "lat": "45.83494",
    "lng": "-109.95546"
  },
  {
    "country": "US",
    "name": "Bigfork",
    "lat": "48.06329",
    "lng": "-114.07261"
  },
  {
    "country": "US",
    "name": "Billings",
    "lat": "45.78329",
    "lng": "-108.50069"
  },
  {
    "country": "US",
    "name": "Boulder",
    "lat": "46.23659",
    "lng": "-112.12083"
  },
  {
    "country": "US",
    "name": "Bozeman",
    "lat": "45.67965",
    "lng": "-111.03856"
  },
  {
    "country": "US",
    "name": "Broadus",
    "lat": "45.44387",
    "lng": "-105.41133"
  },
  {
    "country": "US",
    "name": "Browning",
    "lat": "48.55692",
    "lng": "-113.01342"
  },
  {
    "country": "US",
    "name": "Butte",
    "lat": "46.00382",
    "lng": "-112.53474"
  },
  {
    "country": "US",
    "name": "Chester",
    "lat": "48.51054",
    "lng": "-110.96747"
  },
  {
    "country": "US",
    "name": "Chinook",
    "lat": "48.59",
    "lng": "-109.23128"
  },
  {
    "country": "US",
    "name": "Choteau",
    "lat": "47.81245",
    "lng": "-112.18363"
  },
  {
    "country": "US",
    "name": "Circle",
    "lat": "47.41667",
    "lng": "-105.59222"
  },
  {
    "country": "US",
    "name": "Clancy",
    "lat": "46.46521",
    "lng": "-111.98638"
  },
  {
    "country": "US",
    "name": "Clinton",
    "lat": "46.76909",
    "lng": "-113.7126"
  },
  {
    "country": "US",
    "name": "Colstrip",
    "lat": "45.88416",
    "lng": "-106.62364"
  },
  {
    "country": "US",
    "name": "Columbia Falls",
    "lat": "48.37246",
    "lng": "-114.18152"
  },
  {
    "country": "US",
    "name": "Columbus",
    "lat": "45.63661",
    "lng": "-109.25211"
  },
  {
    "country": "US",
    "name": "Conrad",
    "lat": "48.17025",
    "lng": "-111.94613"
  },
  {
    "country": "US",
    "name": "Crow Agency",
    "lat": "45.60164",
    "lng": "-107.46119"
  },
  {
    "country": "US",
    "name": "Cut Bank",
    "lat": "48.63304",
    "lng": "-112.32616"
  },
  {
    "country": "US",
    "name": "Deer Lodge",
    "lat": "46.39576",
    "lng": "-112.73004"
  },
  {
    "country": "US",
    "name": "Dillon",
    "lat": "45.21631",
    "lng": "-112.63752"
  },
  {
    "country": "US",
    "name": "East Helena",
    "lat": "46.58966",
    "lng": "-111.91555"
  },
  {
    "country": "US",
    "name": "East Missoula",
    "lat": "46.87076",
    "lng": "-113.94455"
  },
  {
    "country": "US",
    "name": "Ekalaka",
    "lat": "45.88889",
    "lng": "-104.55273"
  },
  {
    "country": "US",
    "name": "Eureka",
    "lat": "48.87996",
    "lng": "-115.0535"
  },
  {
    "country": "US",
    "name": "Evergreen",
    "lat": "48.22579",
    "lng": "-114.27624"
  },
  {
    "country": "US",
    "name": "Forsyth",
    "lat": "46.26638",
    "lng": "-106.67781"
  },
  {
    "country": "US",
    "name": "Fort Belknap Agency",
    "lat": "48.4825",
    "lng": "-108.76544"
  },
  {
    "country": "US",
    "name": "Fort Benton",
    "lat": "47.8183",
    "lng": "-110.66744"
  },
  {
    "country": "US",
    "name": "Four Corners",
    "lat": "45.62965",
    "lng": "-111.18606"
  },
  {
    "country": "US",
    "name": "Frenchtown",
    "lat": "47.01492",
    "lng": "-114.22984"
  },
  {
    "country": "US",
    "name": "Glasgow",
    "lat": "48.19696",
    "lng": "-106.63671"
  },
  {
    "country": "US",
    "name": "Glendive",
    "lat": "47.10529",
    "lng": "-104.71246"
  },
  {
    "country": "US",
    "name": "Great Falls",
    "lat": "47.50024",
    "lng": "-111.30081"
  },
  {
    "country": "US",
    "name": "Hamilton",
    "lat": "46.24687",
    "lng": "-114.16037"
  },
  {
    "country": "US",
    "name": "Hardin",
    "lat": "45.73248",
    "lng": "-107.61203"
  },
  {
    "country": "US",
    "name": "Harlowton",
    "lat": "46.43551",
    "lng": "-109.83435"
  },
  {
    "country": "US",
    "name": "Havre",
    "lat": "48.55",
    "lng": "-109.68409"
  },
  {
    "country": "US",
    "name": "Helena",
    "lat": "46.59271",
    "lng": "-112.03611"
  },
  {
    "country": "US",
    "name": "Hysham",
    "lat": "46.29277",
    "lng": "-107.23423"
  },
  {
    "country": "US",
    "name": "Jordan",
    "lat": "47.32083",
    "lng": "-106.91007"
  },
  {
    "country": "US",
    "name": "Kalispell",
    "lat": "48.19579",
    "lng": "-114.31291"
  },
  {
    "country": "US",
    "name": "Lakeside",
    "lat": "48.01939",
    "lng": "-114.22457"
  },
  {
    "country": "US",
    "name": "Lame Deer",
    "lat": "45.62305",
    "lng": "-106.6667"
  },
  {
    "country": "US",
    "name": "Laurel",
    "lat": "45.66912",
    "lng": "-108.77153"
  },
  {
    "country": "US",
    "name": "Lewistown",
    "lat": "47.06247",
    "lng": "-109.42824"
  },
  {
    "country": "US",
    "name": "Libby",
    "lat": "48.38829",
    "lng": "-115.556"
  },
  {
    "country": "US",
    "name": "Lincoln",
    "lat": "46.95494",
    "lng": "-112.68171"
  },
  {
    "country": "US",
    "name": "Livingston",
    "lat": "45.66244",
    "lng": "-110.56104"
  },
  {
    "country": "US",
    "name": "Lockwood",
    "lat": "45.81912",
    "lng": "-108.41486"
  },
  {
    "country": "US",
    "name": "Lolo",
    "lat": "46.75881",
    "lng": "-114.08094"
  },
  {
    "country": "US",
    "name": "Malta",
    "lat": "48.35972",
    "lng": "-107.87428"
  },
  {
    "country": "US",
    "name": "Manhattan",
    "lat": "45.8566",
    "lng": "-111.33246"
  },
  {
    "country": "US",
    "name": "Miles City",
    "lat": "46.40834",
    "lng": "-105.84056"
  },
  {
    "country": "US",
    "name": "Missoula",
    "lat": "46.87215",
    "lng": "-113.994"
  },
  {
    "country": "US",
    "name": "Montana City",
    "lat": "46.53771",
    "lng": "-111.93277"
  },
  {
    "country": "US",
    "name": "North Browning",
    "lat": "48.57025",
    "lng": "-113.00953"
  },
  {
    "country": "US",
    "name": "Orchard Homes",
    "lat": "46.86326",
    "lng": "-114.04844"
  },
  {
    "country": "US",
    "name": "Pablo",
    "lat": "47.60021",
    "lng": "-114.119"
  },
  {
    "country": "US",
    "name": "Philipsburg",
    "lat": "46.33215",
    "lng": "-113.29423"
  },
  {
    "country": "US",
    "name": "Plains",
    "lat": "47.46021",
    "lng": "-114.88291"
  },
  {
    "country": "US",
    "name": "Plentywood",
    "lat": "48.77475",
    "lng": "-104.56246"
  },
  {
    "country": "US",
    "name": "Polson",
    "lat": "47.69355",
    "lng": "-114.16317"
  },
  {
    "country": "US",
    "name": "Red Lodge",
    "lat": "45.18578",
    "lng": "-109.24682"
  },
  {
    "country": "US",
    "name": "Ronan",
    "lat": "47.52882",
    "lng": "-114.1015"
  },
  {
    "country": "US",
    "name": "Roundup",
    "lat": "46.44524",
    "lng": "-108.5418"
  },
  {
    "country": "US",
    "name": "Ryegate",
    "lat": "46.29718",
    "lng": "-109.25879"
  },
  {
    "country": "US",
    "name": "Scobey",
    "lat": "48.79252",
    "lng": "-105.42083"
  },
  {
    "country": "US",
    "name": "Seeley Lake",
    "lat": "47.17938",
    "lng": "-113.48452"
  },
  {
    "country": "US",
    "name": "Shelby",
    "lat": "48.50526",
    "lng": "-111.85697"
  },
  {
    "country": "US",
    "name": "Sidney",
    "lat": "47.71668",
    "lng": "-104.15633"
  },
  {
    "country": "US",
    "name": "Somers",
    "lat": "48.08023",
    "lng": "-114.22151"
  },
  {
    "country": "US",
    "name": "South Browning",
    "lat": "48.54608",
    "lng": "-113.01425"
  },
  {
    "country": "US",
    "name": "Stanford",
    "lat": "47.15358",
    "lng": "-110.21826"
  },
  {
    "country": "US",
    "name": "Stevensville",
    "lat": "46.50992",
    "lng": "-114.09316"
  },
  {
    "country": "US",
    "name": "Sun Prairie",
    "lat": "47.5369",
    "lng": "-111.48136"
  },
  {
    "country": "US",
    "name": "Superior",
    "lat": "47.19159",
    "lng": "-114.8918"
  },
  {
    "country": "US",
    "name": "Terry",
    "lat": "46.79306",
    "lng": "-105.31221"
  },
  {
    "country": "US",
    "name": "Thompson Falls",
    "lat": "47.59489",
    "lng": "-115.33834"
  },
  {
    "country": "US",
    "name": "Three Forks",
    "lat": "45.89243",
    "lng": "-111.55219"
  },
  {
    "country": "US",
    "name": "Townsend",
    "lat": "46.3191",
    "lng": "-111.5208"
  },
  {
    "country": "US",
    "name": "Virginia City",
    "lat": "45.29381",
    "lng": "-111.94609"
  },
  {
    "country": "US",
    "name": "Warm Springs",
    "lat": "46.18131",
    "lng": "-112.78476"
  },
  {
    "country": "US",
    "name": "West Glendive",
    "lat": "47.11085",
    "lng": "-104.74968"
  },
  {
    "country": "US",
    "name": "West Yellowstone",
    "lat": "44.66215",
    "lng": "-111.10411"
  },
  {
    "country": "US",
    "name": "White Sulphur Springs",
    "lat": "46.54828",
    "lng": "-110.90216"
  },
  {
    "country": "US",
    "name": "Whitefish",
    "lat": "48.41108",
    "lng": "-114.33763"
  },
  {
    "country": "US",
    "name": "Whitehall",
    "lat": "45.87076",
    "lng": "-112.09749"
  },
  {
    "country": "US",
    "name": "Wibaux",
    "lat": "46.98501",
    "lng": "-104.18827"
  },
  {
    "country": "US",
    "name": "Winnett",
    "lat": "47.00276",
    "lng": "-108.35207"
  },
  {
    "country": "US",
    "name": "Wolf Point",
    "lat": "48.09057",
    "lng": "-105.64056"
  },
  {
    "country": "US",
    "name": "Amidon",
    "lat": "46.48223",
    "lng": "-103.32185"
  },
  {
    "country": "US",
    "name": "Belfield",
    "lat": "46.88529",
    "lng": "-103.19962"
  },
  {
    "country": "US",
    "name": "Beulah",
    "lat": "47.26334",
    "lng": "-101.77795"
  },
  {
    "country": "US",
    "name": "Bismarck",
    "lat": "46.80833",
    "lng": "-100.78374"
  },
  {
    "country": "US",
    "name": "Bottineau",
    "lat": "48.82723",
    "lng": "-100.4457"
  },
  {
    "country": "US",
    "name": "Bowbells",
    "lat": "48.80308",
    "lng": "-102.246"
  },
  {
    "country": "US",
    "name": "Bowman",
    "lat": "46.18306",
    "lng": "-103.39491"
  },
  {
    "country": "US",
    "name": "Burlington",
    "lat": "48.27529",
    "lng": "-101.42878"
  },
  {
    "country": "US",
    "name": "Carson",
    "lat": "46.41778",
    "lng": "-101.56487"
  },
  {
    "country": "US",
    "name": "Center",
    "lat": "47.11638",
    "lng": "-101.29959"
  },
  {
    "country": "US",
    "name": "Crosby",
    "lat": "48.9142",
    "lng": "-103.29491"
  },
  {
    "country": "US",
    "name": "Dickinson",
    "lat": "46.87918",
    "lng": "-102.78962"
  },
  {
    "country": "US",
    "name": "Fort Yates",
    "lat": "46.08694",
    "lng": "-100.63013"
  },
  {
    "country": "US",
    "name": "Garrison",
    "lat": "47.65222",
    "lng": "-101.41572"
  },
  {
    "country": "US",
    "name": "Hazen",
    "lat": "47.29445",
    "lng": "-101.62266"
  },
  {
    "country": "US",
    "name": "Hettinger",
    "lat": "46.00139",
    "lng": "-102.63682"
  },
  {
    "country": "US",
    "name": "Kenmare",
    "lat": "48.67475",
    "lng": "-102.08266"
  },
  {
    "country": "US",
    "name": "Killdeer",
    "lat": "47.37196",
    "lng": "-102.75408"
  },
  {
    "country": "US",
    "name": "Lincoln",
    "lat": "46.76249",
    "lng": "-100.7004"
  },
  {
    "country": "US",
    "name": "Linton",
    "lat": "46.26666",
    "lng": "-100.23289"
  },
  {
    "country": "US",
    "name": "Mandan",
    "lat": "46.82666",
    "lng": "-100.88958"
  },
  {
    "country": "US",
    "name": "Manning",
    "lat": "47.23001",
    "lng": "-102.77019"
  },
  {
    "country": "US",
    "name": "McClusky",
    "lat": "47.48583",
    "lng": "-100.44318"
  },
  {
    "country": "US",
    "name": "Medora",
    "lat": "46.9139",
    "lng": "-103.52435"
  },
  {
    "country": "US",
    "name": "Minot",
    "lat": "48.23251",
    "lng": "-101.29627"
  },
  {
    "country": "US",
    "name": "Mohall",
    "lat": "48.76336",
    "lng": "-101.51322"
  },
  {
    "country": "US",
    "name": "Mott",
    "lat": "46.3725",
    "lng": "-102.32711"
  },
  {
    "country": "US",
    "name": "New Town",
    "lat": "47.98085",
    "lng": "-102.49018"
  },
  {
    "country": "US",
    "name": "Parshall",
    "lat": "47.95335",
    "lng": "-102.13489"
  },
  {
    "country": "US",
    "name": "Stanley",
    "lat": "48.31724",
    "lng": "-102.39045"
  },
  {
    "country": "US",
    "name": "Stanton",
    "lat": "47.32111",
    "lng": "-101.38155"
  },
  {
    "country": "US",
    "name": "Surrey",
    "lat": "48.2364",
    "lng": "-101.13349"
  },
  {
    "country": "US",
    "name": "Tioga",
    "lat": "48.39724",
    "lng": "-102.93824"
  },
  {
    "country": "US",
    "name": "Towner",
    "lat": "48.34583",
    "lng": "-100.40541"
  },
  {
    "country": "US",
    "name": "Velva",
    "lat": "48.05612",
    "lng": "-100.92932"
  },
  {
    "country": "US",
    "name": "Washburn",
    "lat": "47.28916",
    "lng": "-101.02903"
  },
  {
    "country": "US",
    "name": "Watford City",
    "lat": "47.80224",
    "lng": "-103.28325"
  },
  {
    "country": "US",
    "name": "Williston",
    "lat": "48.14697",
    "lng": "-103.61797"
  },
  {
    "country": "US",
    "name": "Alliance",
    "lat": "42.10163",
    "lng": "-102.87215"
  },
  {
    "country": "US",
    "name": "Arthur",
    "lat": "41.57165",
    "lng": "-101.69156"
  },
  {
    "country": "US",
    "name": "Bayard",
    "lat": "41.75497",
    "lng": "-103.3241"
  },
  {
    "country": "US",
    "name": "Benkelman",
    "lat": "40.04916",
    "lng": "-101.53294"
  },
  {
    "country": "US",
    "name": "Bridgeport",
    "lat": "41.66525",
    "lng": "-103.0991"
  },
  {
    "country": "US",
    "name": "Cambridge",
    "lat": "40.28195",
    "lng": "-100.16569"
  },
  {
    "country": "US",
    "name": "Chadron",
    "lat": "42.82942",
    "lng": "-102.99991"
  },
  {
    "country": "US",
    "name": "Chappell",
    "lat": "41.09277",
    "lng": "-102.47074"
  },
  {
    "country": "US",
    "name": "Gering",
    "lat": "41.8258",
    "lng": "-103.6605"
  },
  {
    "country": "US",
    "name": "Gordon",
    "lat": "42.80472",
    "lng": "-102.20322"
  },
  {
    "country": "US",
    "name": "Gothenburg",
    "lat": "40.92945",
    "lng": "-100.16068"
  },
  {
    "country": "US",
    "name": "Grant",
    "lat": "40.84194",
    "lng": "-101.72517"
  },
  {
    "country": "US",
    "name": "Harrisburg",
    "lat": "41.55636",
    "lng": "-103.73856"
  },
  {
    "country": "US",
    "name": "Harrison",
    "lat": "42.68719",
    "lng": "-103.88271"
  },
  {
    "country": "US",
    "name": "Hayes Center",
    "lat": "40.51084",
    "lng": "-101.0196"
  },
  {
    "country": "US",
    "name": "Hyannis",
    "lat": "42.00054",
    "lng": "-101.76184"
  },
  {
    "country": "US",
    "name": "Imperial",
    "lat": "40.51694",
    "lng": "-101.64323"
  },
  {
    "country": "US",
    "name": "Kimball",
    "lat": "41.23581",
    "lng": "-103.663"
  },
  {
    "country": "US",
    "name": "McCook",
    "lat": "40.20195",
    "lng": "-100.62571"
  },
  {
    "country": "US",
    "name": "Mitchell",
    "lat": "41.94024",
    "lng": "-103.80856"
  },
  {
    "country": "US",
    "name": "Mullen",
    "lat": "42.04278",
    "lng": "-101.04266"
  },
  {
    "country": "US",
    "name": "North Platte",
    "lat": "41.12389",
    "lng": "-100.76542"
  },
  {
    "country": "US",
    "name": "Ogallala",
    "lat": "41.12805",
    "lng": "-101.71962"
  },
  {
    "country": "US",
    "name": "Oshkosh",
    "lat": "41.40498",
    "lng": "-102.34436"
  },
  {
    "country": "US",
    "name": "Rushville",
    "lat": "42.71832",
    "lng": "-102.46406"
  },
  {
    "country": "US",
    "name": "Scottsbluff",
    "lat": "41.86663",
    "lng": "-103.66717"
  },
  {
    "country": "US",
    "name": "Sidney",
    "lat": "41.14276",
    "lng": "-102.97798"
  },
  {
    "country": "US",
    "name": "Stapleton",
    "lat": "41.48028",
    "lng": "-100.51292"
  },
  {
    "country": "US",
    "name": "Stockville",
    "lat": "40.53279",
    "lng": "-100.38348"
  },
  {
    "country": "US",
    "name": "Sutherland",
    "lat": "41.15694",
    "lng": "-101.12627"
  },
  {
    "country": "US",
    "name": "Terrytown",
    "lat": "41.84747",
    "lng": "-103.66161"
  },
  {
    "country": "US",
    "name": "Thedford",
    "lat": "41.97833",
    "lng": "-100.57625"
  },
  {
    "country": "US",
    "name": "Trenton",
    "lat": "40.17555",
    "lng": "-101.01294"
  },
  {
    "country": "US",
    "name": "Tryon",
    "lat": "41.55277",
    "lng": "-100.95765"
  },
  {
    "country": "US",
    "name": "Valentine",
    "lat": "42.87278",
    "lng": "-100.55097"
  },
  {
    "country": "US",
    "name": "Battle Mountain",
    "lat": "40.64213",
    "lng": "-116.93427"
  },
  {
    "country": "US",
    "name": "Carlin",
    "lat": "40.71381",
    "lng": "-116.10397"
  },
  {
    "country": "US",
    "name": "Elko",
    "lat": "40.83242",
    "lng": "-115.76312"
  },
  {
    "country": "US",
    "name": "Jackpot",
    "lat": "41.98324",
    "lng": "-114.67476"
  },
  {
    "country": "US",
    "name": "Lovelock",
    "lat": "40.17935",
    "lng": "-118.47348"
  },
  {
    "country": "US",
    "name": "Spring Creek",
    "lat": "40.72659",
    "lng": "-115.5859"
  },
  {
    "country": "US",
    "name": "Wells",
    "lat": "41.11159",
    "lng": "-114.96449"
  },
  {
    "country": "US",
    "name": "West Wendover",
    "lat": "40.7391",
    "lng": "-114.07335"
  },
  {
    "country": "US",
    "name": "Winnemucca",
    "lat": "40.97296",
    "lng": "-117.73568"
  },
  {
    "country": "US",
    "name": "Albany",
    "lat": "44.63651",
    "lng": "-123.10593"
  },
  {
    "country": "US",
    "name": "Aloha",
    "lat": "45.49428",
    "lng": "-122.86705"
  },
  {
    "country": "US",
    "name": "Altamont",
    "lat": "42.20681",
    "lng": "-121.73722"
  },
  {
    "country": "US",
    "name": "Amity",
    "lat": "45.11567",
    "lng": "-123.20733"
  },
  {
    "country": "US",
    "name": "Ashland",
    "lat": "42.19458",
    "lng": "-122.70948"
  },
  {
    "country": "US",
    "name": "Astoria",
    "lat": "46.18788",
    "lng": "-123.83125"
  },
  {
    "country": "US",
    "name": "Athena",
    "lat": "45.8118",
    "lng": "-118.49053"
  },
  {
    "country": "US",
    "name": "Aumsville",
    "lat": "44.84095",
    "lng": "-122.87092"
  },
  {
    "country": "US",
    "name": "Baker City",
    "lat": "44.77487",
    "lng": "-117.83438"
  },
  {
    "country": "US",
    "name": "Bandon",
    "lat": "43.119",
    "lng": "-124.40845"
  },
  {
    "country": "US",
    "name": "Banks",
    "lat": "45.61872",
    "lng": "-123.11428"
  },
  {
    "country": "US",
    "name": "Barview",
    "lat": "43.35428",
    "lng": "-124.31317"
  },
  {
    "country": "US",
    "name": "Bay City",
    "lat": "45.5226",
    "lng": "-123.8893"
  },
  {
    "country": "US",
    "name": "Beavercreek",
    "lat": "45.2879",
    "lng": "-122.53564"
  },
  {
    "country": "US",
    "name": "Beaverton",
    "lat": "45.48706",
    "lng": "-122.80371"
  },
  {
    "country": "US",
    "name": "Bend",
    "lat": "44.05817",
    "lng": "-121.31531"
  },
  {
    "country": "US",
    "name": "Bethany",
    "lat": "45.55789",
    "lng": "-122.8676"
  },
  {
    "country": "US",
    "name": "Boardman",
    "lat": "45.83986",
    "lng": "-119.70058"
  },
  {
    "country": "US",
    "name": "Brookings",
    "lat": "42.05261",
    "lng": "-124.28398"
  },
  {
    "country": "US",
    "name": "Brownsville",
    "lat": "44.39346",
    "lng": "-122.98481"
  },
  {
    "country": "US",
    "name": "Bunker Hill",
    "lat": "43.35595",
    "lng": "-124.20483"
  },
  {
    "country": "US",
    "name": "Burns",
    "lat": "43.58626",
    "lng": "-119.0541"
  },
  {
    "country": "US",
    "name": "Canby",
    "lat": "45.2629",
    "lng": "-122.69259"
  },
  {
    "country": "US",
    "name": "Cannon Beach",
    "lat": "45.89177",
    "lng": "-123.96153"
  },
  {
    "country": "US",
    "name": "Canyon City",
    "lat": "44.3896",
    "lng": "-118.95023"
  },
  {
    "country": "US",
    "name": "Canyonville",
    "lat": "42.92734",
    "lng": "-123.28117"
  },
  {
    "country": "US",
    "name": "Carlton",
    "lat": "45.29428",
    "lng": "-123.17649"
  },
  {
    "country": "US",
    "name": "Cascade Locks",
    "lat": "45.66984",
    "lng": "-121.89064"
  },
  {
    "country": "US",
    "name": "Cave Junction",
    "lat": "42.16289",
    "lng": "-123.64812"
  },
  {
    "country": "US",
    "name": "Cedar Hills",
    "lat": "45.50484",
    "lng": "-122.79843"
  },
  {
    "country": "US",
    "name": "Cedar Mill",
    "lat": "45.52484",
    "lng": "-122.81093"
  },
  {
    "country": "US",
    "name": "Central Point",
    "lat": "42.37596",
    "lng": "-122.91643"
  },
  {
    "country": "US",
    "name": "Chenoweth",
    "lat": "45.62762",
    "lng": "-121.24341"
  },
  {
    "country": "US",
    "name": "Clackamas",
    "lat": "45.40762",
    "lng": "-122.57037"
  },
  {
    "country": "US",
    "name": "Clatskanie",
    "lat": "46.10122",
    "lng": "-123.20679"
  },
  {
    "country": "US",
    "name": "Coburg",
    "lat": "44.13707",
    "lng": "-123.06648"
  },
  {
    "country": "US",
    "name": "Columbia City",
    "lat": "45.89011",
    "lng": "-122.80705"
  },
  {
    "country": "US",
    "name": "Condon",
    "lat": "45.2343",
    "lng": "-120.18503"
  },
  {
    "country": "US",
    "name": "Coos Bay",
    "lat": "43.3665",
    "lng": "-124.21789"
  },
  {
    "country": "US",
    "name": "Coquille",
    "lat": "43.17705",
    "lng": "-124.18761"
  },
  {
    "country": "US",
    "name": "Cornelius",
    "lat": "45.51984",
    "lng": "-123.05983"
  },
  {
    "country": "US",
    "name": "Corvallis",
    "lat": "44.56457",
    "lng": "-123.26204"
  },
  {
    "country": "US",
    "name": "Cottage Grove",
    "lat": "43.79762",
    "lng": "-123.05952"
  },
  {
    "country": "US",
    "name": "Creswell",
    "lat": "43.9179",
    "lng": "-123.02453"
  },
  {
    "country": "US",
    "name": "Culp Creek",
    "lat": "43.70346",
    "lng": "-122.84757"
  },
  {
    "country": "US",
    "name": "Culver",
    "lat": "44.52568",
    "lng": "-121.2131"
  },
  {
    "country": "US",
    "name": "Dallas",
    "lat": "44.91928",
    "lng": "-123.31705"
  },
  {
    "country": "US",
    "name": "Damascus",
    "lat": "45.41762",
    "lng": "-122.45898"
  },
  {
    "country": "US",
    "name": "Dayton",
    "lat": "45.22067",
    "lng": "-123.07621"
  },
  {
    "country": "US",
    "name": "Depoe Bay",
    "lat": "44.80845",
    "lng": "-124.06317"
  },
  {
    "country": "US",
    "name": "Deschutes River Woods",
    "lat": "43.99151",
    "lng": "-121.35836"
  },
  {
    "country": "US",
    "name": "Donald",
    "lat": "45.22234",
    "lng": "-122.83926"
  },
  {
    "country": "US",
    "name": "Drain",
    "lat": "43.65873",
    "lng": "-123.3187"
  },
  {
    "country": "US",
    "name": "Dundee",
    "lat": "45.27817",
    "lng": "-123.01094"
  },
  {
    "country": "US",
    "name": "Dunes City",
    "lat": "43.88318",
    "lng": "-124.11512"
  },
  {
    "country": "US",
    "name": "Durham",
    "lat": "45.40206",
    "lng": "-122.75287"
  },
  {
    "country": "US",
    "name": "Eagle Point",
    "lat": "42.47263",
    "lng": "-122.80282"
  },
  {
    "country": "US",
    "name": "Elgin",
    "lat": "45.56486",
    "lng": "-117.91743"
  },
  {
    "country": "US",
    "name": "Enterprise",
    "lat": "45.42626",
    "lng": "-117.27878"
  },
  {
    "country": "US",
    "name": "Estacada",
    "lat": "45.28957",
    "lng": "-122.3337"
  },
  {
    "country": "US",
    "name": "Eugene",
    "lat": "44.05207",
    "lng": "-123.08675"
  },
  {
    "country": "US",
    "name": "Fairview",
    "lat": "45.53845",
    "lng": "-122.43398"
  },
  {
    "country": "US",
    "name": "Florence",
    "lat": "43.98262",
    "lng": "-124.09984"
  },
  {
    "country": "US",
    "name": "Forest Grove",
    "lat": "45.51984",
    "lng": "-123.11066"
  },
  {
    "country": "US",
    "name": "Fossil",
    "lat": "44.99819",
    "lng": "-120.21614"
  },
  {
    "country": "US",
    "name": "Four Corners",
    "lat": "44.9279",
    "lng": "-122.98371"
  },
  {
    "country": "US",
    "name": "Gearhart",
    "lat": "46.02427",
    "lng": "-123.91125"
  },
  {
    "country": "US",
    "name": "Gervais",
    "lat": "45.10818",
    "lng": "-122.8976"
  },
  {
    "country": "US",
    "name": "Gladstone",
    "lat": "45.38068",
    "lng": "-122.59481"
  },
  {
    "country": "US",
    "name": "Glide",
    "lat": "43.30151",
    "lng": "-123.10118"
  },
  {
    "country": "US",
    "name": "Gold Hill",
    "lat": "42.43179",
    "lng": "-123.0506"
  },
  {
    "country": "US",
    "name": "Grand Ronde",
    "lat": "45.06011",
    "lng": "-123.60928"
  },
  {
    "country": "US",
    "name": "Grants Pass",
    "lat": "42.43933",
    "lng": "-123.33067"
  },
  {
    "country": "US",
    "name": "Green",
    "lat": "43.16039",
    "lng": "-123.36785"
  },
  {
    "country": "US",
    "name": "Gresham",
    "lat": "45.49818",
    "lng": "-122.43148"
  },
  {
    "country": "US",
    "name": "Happy Valley",
    "lat": "45.44679",
    "lng": "-122.53037"
  },
  {
    "country": "US",
    "name": "Harbor",
    "lat": "42.05317",
    "lng": "-124.26759"
  },
  {
    "country": "US",
    "name": "Harrisburg",
    "lat": "44.27401",
    "lng": "-123.17065"
  },
  {
    "country": "US",
    "name": "Hayesville",
    "lat": "44.98595",
    "lng": "-122.98287"
  },
  {
    "country": "US",
    "name": "Heppner",
    "lat": "45.35318",
    "lng": "-119.5578"
  },
  {
    "country": "US",
    "name": "Hermiston",
    "lat": "45.84041",
    "lng": "-119.28946"
  },
  {
    "country": "US",
    "name": "Hillsboro",
    "lat": "45.52289",
    "lng": "-122.98983"
  },
  {
    "country": "US",
    "name": "Hines",
    "lat": "43.56404",
    "lng": "-119.08105"
  },
  {
    "country": "US",
    "name": "Hood River",
    "lat": "45.7054",
    "lng": "-121.52146"
  },
  {
    "country": "US",
    "name": "Hubbard",
    "lat": "45.18234",
    "lng": "-122.80787"
  },
  {
    "country": "US",
    "name": "Independence",
    "lat": "44.85123",
    "lng": "-123.18677"
  },
  {
    "country": "US",
    "name": "Irrigon",
    "lat": "45.89569",
    "lng": "-119.49141"
  },
  {
    "country": "US",
    "name": "Island City",
    "lat": "45.34097",
    "lng": "-118.04466"
  },
  {
    "country": "US",
    "name": "Jacksonville",
    "lat": "42.31346",
    "lng": "-122.96699"
  },
  {
    "country": "US",
    "name": "Jefferson",
    "lat": "44.71957",
    "lng": "-123.01037"
  },
  {
    "country": "US",
    "name": "Jennings Lodge",
    "lat": "45.39123",
    "lng": "-122.61259"
  },
  {
    "country": "US",
    "name": "John Day",
    "lat": "44.41599",
    "lng": "-118.95301"
  },
  {
    "country": "US",
    "name": "Joseph",
    "lat": "45.35432",
    "lng": "-117.22961"
  },
  {
    "country": "US",
    "name": "Junction City",
    "lat": "44.21929",
    "lng": "-123.20565"
  },
  {
    "country": "US",
    "name": "Keizer",
    "lat": "44.99012",
    "lng": "-123.02621"
  },
  {
    "country": "US",
    "name": "Kenton",
    "lat": "45.58178",
    "lng": "-122.68149"
  },
  {
    "country": "US",
    "name": "King City",
    "lat": "45.40262",
    "lng": "-122.80399"
  },
  {
    "country": "US",
    "name": "Klamath Falls",
    "lat": "42.22487",
    "lng": "-121.78167"
  },
  {
    "country": "US",
    "name": "La Grande",
    "lat": "45.32458",
    "lng": "-118.08772"
  },
  {
    "country": "US",
    "name": "La Pine",
    "lat": "43.6704",
    "lng": "-121.50364"
  },
  {
    "country": "US",
    "name": "Lafayette",
    "lat": "45.24428",
    "lng": "-123.11483"
  },
  {
    "country": "US",
    "name": "Lake Oswego",
    "lat": "45.42067",
    "lng": "-122.67065"
  },
  {
    "country": "US",
    "name": "Lakeside",
    "lat": "43.57567",
    "lng": "-124.17511"
  },
  {
    "country": "US",
    "name": "Lakeview",
    "lat": "42.18877",
    "lng": "-120.34579"
  },
  {
    "country": "US",
    "name": "Lebanon",
    "lat": "44.53651",
    "lng": "-122.90703"
  },
  {
    "country": "US",
    "name": "Lents",
    "lat": "45.47984",
    "lng": "-122.56731"
  },
  {
    "country": "US",
    "name": "Lincoln Beach",
    "lat": "44.85039",
    "lng": "-124.04678"
  },
  {
    "country": "US",
    "name": "Lincoln City",
    "lat": "44.95816",
    "lng": "-124.01789"
  },
  {
    "country": "US",
    "name": "Lowell",
    "lat": "43.91846",
    "lng": "-122.78368"
  },
  {
    "country": "US",
    "name": "Lyons",
    "lat": "44.77457",
    "lng": "-122.61509"
  },
  {
    "country": "US",
    "name": "Madras",
    "lat": "44.63345",
    "lng": "-121.12949"
  },
  {
    "country": "US",
    "name": "McMinnville",
    "lat": "45.21012",
    "lng": "-123.19872"
  },
  {
    "country": "US",
    "name": "Medford",
    "lat": "42.32652",
    "lng": "-122.87559"
  },
  {
    "country": "US",
    "name": "Merlin",
    "lat": "42.51734",
    "lng": "-123.41979"
  },
  {
    "country": "US",
    "name": "Metzger",
    "lat": "45.44651",
    "lng": "-122.75899"
  },
  {
    "country": "US",
    "name": "Mill City",
    "lat": "44.75401",
    "lng": "-122.47814"
  },
  {
    "country": "US",
    "name": "Millersburg",
    "lat": "44.68095",
    "lng": "-123.06148"
  },
  {
    "country": "US",
    "name": "Milton-Freewater",
    "lat": "45.93263",
    "lng": "-118.38774"
  },
  {
    "country": "US",
    "name": "Milwaukie",
    "lat": "45.44623",
    "lng": "-122.63926"
  },
  {
    "country": "US",
    "name": "Mission",
    "lat": "45.67041",
    "lng": "-118.68359"
  },
  {
    "country": "US",
    "name": "Molalla",
    "lat": "45.14734",
    "lng": "-122.57703"
  },
  {
    "country": "US",
    "name": "Monmouth",
    "lat": "44.84845",
    "lng": "-123.23399"
  },
  {
    "country": "US",
    "name": "Moro",
    "lat": "45.48401",
    "lng": "-120.73117"
  },
  {
    "country": "US",
    "name": "Mount Angel",
    "lat": "45.0679",
    "lng": "-122.80009"
  },
  {
    "country": "US",
    "name": "Mount Hood Village",
    "lat": "45.3554",
    "lng": "-121.98064"
  },
  {
    "country": "US",
    "name": "Mulino",
    "lat": "45.22151",
    "lng": "-122.58203"
  },
  {
    "country": "US",
    "name": "Myrtle Creek",
    "lat": "43.02012",
    "lng": "-123.29312"
  },
  {
    "country": "US",
    "name": "Myrtle Point",
    "lat": "43.06483",
    "lng": "-124.13899"
  },
  {
    "country": "US",
    "name": "New Hope",
    "lat": "42.36234",
    "lng": "-123.36784"
  },
  {
    "country": "US",
    "name": "Newberg",
    "lat": "45.30012",
    "lng": "-122.97316"
  },
  {
    "country": "US",
    "name": "Newport",
    "lat": "44.63678",
    "lng": "-124.05345"
  },
  {
    "country": "US",
    "name": "North Bend",
    "lat": "43.4065",
    "lng": "-124.22428"
  },
  {
    "country": "US",
    "name": "North Plains",
    "lat": "45.59706",
    "lng": "-122.99344"
  },
  {
    "country": "US",
    "name": "North Portland",
    "lat": "45.61039",
    "lng": "-122.70343"
  },
  {
    "country": "US",
    "name": "Nyssa",
    "lat": "43.87683",
    "lng": "-116.99488"
  },
  {
    "country": "US",
    "name": "Oak Grove",
    "lat": "45.41679",
    "lng": "-122.64009"
  },
  {
    "country": "US",
    "name": "Oak Hills",
    "lat": "45.54123",
    "lng": "-122.84121"
  },
  {
    "country": "US",
    "name": "Oakridge",
    "lat": "43.74651",
    "lng": "-122.46172"
  },
  {
    "country": "US",
    "name": "Odell",
    "lat": "45.62706",
    "lng": "-121.54313"
  },
  {
    "country": "US",
    "name": "Ontario",
    "lat": "44.02655",
    "lng": "-116.96294"
  },
  {
    "country": "US",
    "name": "Oregon City",
    "lat": "45.35734",
    "lng": "-122.60676"
  },
  {
    "country": "US",
    "name": "Pacific City",
    "lat": "45.20233",
    "lng": "-123.96289"
  },
  {
    "country": "US",
    "name": "Pendleton",
    "lat": "45.67207",
    "lng": "-118.7886"
  },
  {
    "country": "US",
    "name": "Philomath",
    "lat": "44.54012",
    "lng": "-123.3676"
  },
  {
    "country": "US",
    "name": "Phoenix",
    "lat": "42.27541",
    "lng": "-122.81809"
  },
  {
    "country": "US",
    "name": "Pilot Rock",
    "lat": "45.48318",
    "lng": "-118.82998"
  },
  {
    "country": "US",
    "name": "Port Orford",
    "lat": "42.74566",
    "lng": "-124.49733"
  },
  {
    "country": "US",
    "name": "Portland",
    "lat": "45.52345",
    "lng": "-122.67621"
  },
  {
    "country": "US",
    "name": "Prineville",
    "lat": "44.29985",
    "lng": "-120.83447"
  },
  {
    "country": "US",
    "name": "Rainier",
    "lat": "46.089",
    "lng": "-122.93594"
  },
  {
    "country": "US",
    "name": "Raleigh Hills",
    "lat": "45.48067",
    "lng": "-122.76204"
  },
  {
    "country": "US",
    "name": "Redmond",
    "lat": "44.27262",
    "lng": "-121.17392"
  },
  {
    "country": "US",
    "name": "Redwood",
    "lat": "42.42206",
    "lng": "-123.38728"
  },
  {
    "country": "US",
    "name": "Reedsport",
    "lat": "43.70234",
    "lng": "-124.09678"
  },
  {
    "country": "US",
    "name": "Riddle",
    "lat": "42.95095",
    "lng": "-123.36423"
  },
  {
    "country": "US",
    "name": "Rockcreek",
    "lat": "45.55012",
    "lng": "-122.87705"
  },
  {
    "country": "US",
    "name": "Rockaway Beach",
    "lat": "45.61344",
    "lng": "-123.94291"
  },
  {
    "country": "US",
    "name": "Rogue River",
    "lat": "42.43595",
    "lng": "-123.172"
  },
  {
    "country": "US",
    "name": "Rose Lodge",
    "lat": "45.01039",
    "lng": "-123.88039"
  },
  {
    "country": "US",
    "name": "Roseburg",
    "lat": "43.2165",
    "lng": "-123.34174"
  },
  {
    "country": "US",
    "name": "Saint Helens",
    "lat": "45.864",
    "lng": "-122.80649"
  },
  {
    "country": "US",
    "name": "Salem",
    "lat": "44.9429",
    "lng": "-123.0351"
  },
  {
    "country": "US",
    "name": "Sandy",
    "lat": "45.39734",
    "lng": "-122.26148"
  },
  {
    "country": "US",
    "name": "Scappoose",
    "lat": "45.75428",
    "lng": "-122.8776"
  },
  {
    "country": "US",
    "name": "Seaside",
    "lat": "45.99316",
    "lng": "-123.92264"
  },
  {
    "country": "US",
    "name": "Shady Cove",
    "lat": "42.61068",
    "lng": "-122.81254"
  },
  {
    "country": "US",
    "name": "Sheridan",
    "lat": "45.09928",
    "lng": "-123.39483"
  },
  {
    "country": "US",
    "name": "Sherwood",
    "lat": "45.35651",
    "lng": "-122.8401"
  },
  {
    "country": "US",
    "name": "Siletz",
    "lat": "44.72178",
    "lng": "-123.92011"
  },
  {
    "country": "US",
    "name": "Silverton",
    "lat": "45.00512",
    "lng": "-122.78315"
  },
  {
    "country": "US",
    "name": "Sisters",
    "lat": "44.29095",
    "lng": "-121.54921"
  },
  {
    "country": "US",
    "name": "South Lebanon",
    "lat": "44.50623",
    "lng": "-122.90314"
  },
  {
    "country": "US",
    "name": "Springfield",
    "lat": "44.04624",
    "lng": "-123.02203"
  },
  {
    "country": "US",
    "name": "Stafford",
    "lat": "45.35734",
    "lng": "-122.72259"
  },
  {
    "country": "US",
    "name": "Stanfield",
    "lat": "45.78041",
    "lng": "-119.21724"
  },
  {
    "country": "US",
    "name": "Stayton",
    "lat": "44.80068",
    "lng": "-122.79453"
  },
  {
    "country": "US",
    "name": "Sublimity",
    "lat": "44.82957",
    "lng": "-122.79453"
  },
  {
    "country": "US",
    "name": "Sunriver",
    "lat": "43.88401",
    "lng": "-121.43864"
  },
  {
    "country": "US",
    "name": "Sutherlin",
    "lat": "43.39012",
    "lng": "-123.31258"
  },
  {
    "country": "US",
    "name": "Sweet Home",
    "lat": "44.39762",
    "lng": "-122.7362"
  },
  {
    "country": "US",
    "name": "Talent",
    "lat": "42.24568",
    "lng": "-122.78865"
  },
  {
    "country": "US",
    "name": "Tangent",
    "lat": "44.54123",
    "lng": "-123.10815"
  },
  {
    "country": "US",
    "name": "Terrebonne",
    "lat": "44.3529",
    "lng": "-121.17781"
  },
  {
    "country": "US",
    "name": "The Dalles",
    "lat": "45.59456",
    "lng": "-121.17868"
  },
  {
    "country": "US",
    "name": "Three Rivers",
    "lat": "43.82012",
    "lng": "-121.46919"
  },
  {
    "country": "US",
    "name": "Tigard",
    "lat": "45.43123",
    "lng": "-122.77149"
  },
  {
    "country": "US",
    "name": "Tillamook",
    "lat": "45.4564",
    "lng": "-123.84553"
  },
  {
    "country": "US",
    "name": "Toledo",
    "lat": "44.62151",
    "lng": "-123.93845"
  },
  {
    "country": "US",
    "name": "Tri-City",
    "lat": "42.98456",
    "lng": "-123.31173"
  },
  {
    "country": "US",
    "name": "Troutdale",
    "lat": "45.53929",
    "lng": "-122.38731"
  },
  {
    "country": "US",
    "name": "Tualatin",
    "lat": "45.38401",
    "lng": "-122.76399"
  },
  {
    "country": "US",
    "name": "Turner",
    "lat": "44.84318",
    "lng": "-122.95287"
  },
  {
    "country": "US",
    "name": "Umatilla",
    "lat": "45.91735",
    "lng": "-119.34252"
  },
  {
    "country": "US",
    "name": "Union",
    "lat": "45.20847",
    "lng": "-117.86521"
  },
  {
    "country": "US",
    "name": "Vale",
    "lat": "43.98211",
    "lng": "-117.23823"
  },
  {
    "country": "US",
    "name": "Veneta",
    "lat": "44.04873",
    "lng": "-123.35093"
  },
  {
    "country": "US",
    "name": "Vernonia",
    "lat": "45.85872",
    "lng": "-123.19289"
  },
  {
    "country": "US",
    "name": "Waldport",
    "lat": "44.42679",
    "lng": "-124.06873"
  },
  {
    "country": "US",
    "name": "Warm Springs",
    "lat": "44.76345",
    "lng": "-121.26616"
  },
  {
    "country": "US",
    "name": "Warren",
    "lat": "45.819",
    "lng": "-122.84899"
  },
  {
    "country": "US",
    "name": "Warrenton",
    "lat": "46.1651",
    "lng": "-123.92376"
  },
  {
    "country": "US",
    "name": "West Haven",
    "lat": "45.51762",
    "lng": "-122.76954"
  },
  {
    "country": "US",
    "name": "West Linn",
    "lat": "45.36568",
    "lng": "-122.61231"
  },
  {
    "country": "US",
    "name": "West Slope",
    "lat": "45.49873",
    "lng": "-122.76454"
  },
  {
    "country": "US",
    "name": "White City",
    "lat": "42.43735",
    "lng": "-122.85893"
  },
  {
    "country": "US",
    "name": "Willamina",
    "lat": "45.07873",
    "lng": "-123.48594"
  },
  {
    "country": "US",
    "name": "Williams",
    "lat": "42.21873",
    "lng": "-123.27394"
  },
  {
    "country": "US",
    "name": "Wilsonville",
    "lat": "45.29984",
    "lng": "-122.77371"
  },
  {
    "country": "US",
    "name": "Winston",
    "lat": "43.12234",
    "lng": "-123.41257"
  },
  {
    "country": "US",
    "name": "Wood Village",
    "lat": "45.53429",
    "lng": "-122.4187"
  },
  {
    "country": "US",
    "name": "Woodburn",
    "lat": "45.14373",
    "lng": "-122.85537"
  },
  {
    "country": "US",
    "name": "Yamhill",
    "lat": "45.3415",
    "lng": "-123.18733"
  },
  {
    "country": "US",
    "name": "Yoncalla",
    "lat": "43.59845",
    "lng": "-123.28342"
  },
  {
    "country": "US",
    "name": "Belle Fourche",
    "lat": "44.67137",
    "lng": "-103.85215"
  },
  {
    "country": "US",
    "name": "Bison",
    "lat": "45.52026",
    "lng": "-102.46127"
  },
  {
    "country": "US",
    "name": "Blackhawk",
    "lat": "44.1511",
    "lng": "-103.30796"
  },
  {
    "country": "US",
    "name": "Box Elder",
    "lat": "44.11249",
    "lng": "-103.06823"
  },
  {
    "country": "US",
    "name": "Buffalo",
    "lat": "45.58416",
    "lng": "-103.54603"
  },
  {
    "country": "US",
    "name": "Colonial Pine Hills",
    "lat": "44.00777",
    "lng": "-103.31546"
  },
  {
    "country": "US",
    "name": "Custer",
    "lat": "43.76665",
    "lng": "-103.59881"
  },
  {
    "country": "US",
    "name": "Deadwood",
    "lat": "44.37665",
    "lng": "-103.72964"
  },
  {
    "country": "US",
    "name": "Dupree",
    "lat": "45.04748",
    "lng": "-101.60099"
  },
  {
    "country": "US",
    "name": "Eagle Butte",
    "lat": "45.00248",
    "lng": "-101.23349"
  },
  {
    "country": "US",
    "name": "Fort Pierre",
    "lat": "44.35359",
    "lng": "-100.37374"
  },
  {
    "country": "US",
    "name": "Hot Springs",
    "lat": "43.43165",
    "lng": "-103.47436"
  },
  {
    "country": "US",
    "name": "Kadoka",
    "lat": "43.83388",
    "lng": "-101.50987"
  },
  {
    "country": "US",
    "name": "Lead",
    "lat": "44.35221",
    "lng": "-103.7652"
  },
  {
    "country": "US",
    "name": "Lemmon",
    "lat": "45.94083",
    "lng": "-102.15932"
  },
  {
    "country": "US",
    "name": "Martin",
    "lat": "43.1725",
    "lng": "-101.73265"
  },
  {
    "country": "US",
    "name": "McIntosh",
    "lat": "45.92139",
    "lng": "-101.34958"
  },
  {
    "country": "US",
    "name": "Mission",
    "lat": "43.30584",
    "lng": "-100.65819"
  },
  {
    "country": "US",
    "name": "Mobridge",
    "lat": "45.53722",
    "lng": "-100.42791"
  },
  {
    "country": "US",
    "name": "Mound City",
    "lat": "45.72527",
    "lng": "-100.06845"
  },
  {
    "country": "US",
    "name": "Murdo",
    "lat": "43.88832",
    "lng": "-100.71291"
  },
  {
    "country": "US",
    "name": "North Eagle Butte",
    "lat": "45.00415",
    "lng": "-101.23376"
  },
  {
    "country": "US",
    "name": "North Spearfish",
    "lat": "44.50665",
    "lng": "-103.89215"
  },
  {
    "country": "US",
    "name": "Oglala",
    "lat": "43.18859",
    "lng": "-102.73962"
  },
  {
    "country": "US",
    "name": "Onida",
    "lat": "44.70804",
    "lng": "-100.05984"
  },
  {
    "country": "US",
    "name": "Philip",
    "lat": "44.03943",
    "lng": "-101.66514"
  },
  {
    "country": "US",
    "name": "Pierre",
    "lat": "44.36832",
    "lng": "-100.35097"
  },
  {
    "country": "US",
    "name": "Pine Ridge",
    "lat": "43.02554",
    "lng": "-102.55627"
  },
  {
    "country": "US",
    "name": "Porcupine",
    "lat": "43.23971",
    "lng": "-102.33099"
  },
  {
    "country": "US",
    "name": "Rapid City",
    "lat": "44.08054",
    "lng": "-103.23101"
  },
  {
    "country": "US",
    "name": "Rapid Valley",
    "lat": "44.06249",
    "lng": "-103.14629"
  },
  {
    "country": "US",
    "name": "Rosebud",
    "lat": "43.23278",
    "lng": "-100.85348"
  },
  {
    "country": "US",
    "name": "Selby",
    "lat": "45.50638",
    "lng": "-100.03207"
  },
  {
    "country": "US",
    "name": "Spearfish",
    "lat": "44.49082",
    "lng": "-103.85937"
  },
  {
    "country": "US",
    "name": "Sturgis",
    "lat": "44.40971",
    "lng": "-103.50908"
  },
  {
    "country": "US",
    "name": "Timber Lake",
    "lat": "45.42915",
    "lng": "-101.07403"
  },
  {
    "country": "US",
    "name": "White River",
    "lat": "43.56805",
    "lng": "-100.74542"
  },
  {
    "country": "US",
    "name": "Alpine",
    "lat": "40.45328",
    "lng": "-111.77799"
  },
  {
    "country": "US",
    "name": "Ballard",
    "lat": "40.2894",
    "lng": "-109.9432"
  },
  {
    "country": "US",
    "name": "Benjamin",
    "lat": "40.09829",
    "lng": "-111.73132"
  },
  {
    "country": "US",
    "name": "Benson",
    "lat": "41.78743",
    "lng": "-111.93022"
  },
  {
    "country": "US",
    "name": "Bluffdale",
    "lat": "40.48967",
    "lng": "-111.93882"
  },
  {
    "country": "US",
    "name": "Bountiful",
    "lat": "40.88939",
    "lng": "-111.88077"
  },
  {
    "country": "US",
    "name": "Brigham City",
    "lat": "41.51021",
    "lng": "-112.0155"
  },
  {
    "country": "US",
    "name": "Canyon Rim",
    "lat": "40.70661",
    "lng": "-111.82188"
  },
  {
    "country": "US",
    "name": "Cedar Hills",
    "lat": "40.41412",
    "lng": "-111.75854"
  },
  {
    "country": "US",
    "name": "Centerfield",
    "lat": "40.69134",
    "lng": "-111.89799"
  },
  {
    "country": "US",
    "name": "Centerville",
    "lat": "40.918",
    "lng": "-111.87216"
  },
  {
    "country": "US",
    "name": "Clearfield",
    "lat": "41.11078",
    "lng": "-112.02605"
  },
  {
    "country": "US",
    "name": "Clinton",
    "lat": "41.13967",
    "lng": "-112.0505"
  },
  {
    "country": "US",
    "name": "Coalville",
    "lat": "40.91773",
    "lng": "-111.39936"
  },
  {
    "country": "US",
    "name": "Cottonwood Heights",
    "lat": "40.61967",
    "lng": "-111.81021"
  },
  {
    "country": "US",
    "name": "Daniel",
    "lat": "40.47079",
    "lng": "-111.41463"
  },
  {
    "country": "US",
    "name": "Draper",
    "lat": "40.52467",
    "lng": "-111.86382"
  },
  {
    "country": "US",
    "name": "Duchesne",
    "lat": "40.16329",
    "lng": "-110.40293"
  },
  {
    "country": "US",
    "name": "Eagle Mountain",
    "lat": "40.31412",
    "lng": "-112.00688"
  },
  {
    "country": "US",
    "name": "East Millcreek",
    "lat": "40.69995",
    "lng": "-111.81049"
  },
  {
    "country": "US",
    "name": "Elk Ridge",
    "lat": "40.01134",
    "lng": "-111.67687"
  },
  {
    "country": "US",
    "name": "Elwood",
    "lat": "41.69048",
    "lng": "-112.14106"
  },
  {
    "country": "US",
    "name": "Erda",
    "lat": "40.61272",
    "lng": "-112.30439"
  },
  {
    "country": "US",
    "name": "Farmington",
    "lat": "40.9805",
    "lng": "-111.88744"
  },
  {
    "country": "US",
    "name": "Farr West",
    "lat": "41.29717",
    "lng": "-112.02772"
  },
  {
    "country": "US",
    "name": "Francis",
    "lat": "40.61051",
    "lng": "-111.28074"
  },
  {
    "country": "US",
    "name": "Fruit Heights",
    "lat": "41.03217",
    "lng": "-111.90216"
  },
  {
    "country": "US",
    "name": "Garland",
    "lat": "41.74104",
    "lng": "-112.16162"
  },
  {
    "country": "US",
    "name": "Granite",
    "lat": "40.573",
    "lng": "-111.80604"
  },
  {
    "country": "US",
    "name": "Grantsville",
    "lat": "40.59994",
    "lng": "-112.4644"
  },
  {
    "country": "US",
    "name": "Harrisville",
    "lat": "41.28133",
    "lng": "-111.98828"
  },
  {
    "country": "US",
    "name": "Heber City",
    "lat": "40.5069",
    "lng": "-111.41324"
  },
  {
    "country": "US",
    "name": "Herriman",
    "lat": "40.51411",
    "lng": "-112.03299"
  },
  {
    "country": "US",
    "name": "Highland",
    "lat": "40.42548",
    "lng": "-111.79447"
  },
  {
    "country": "US",
    "name": "Holladay",
    "lat": "40.66884",
    "lng": "-111.82466"
  },
  {
    "country": "US",
    "name": "Honeyville",
    "lat": "41.63854",
    "lng": "-112.07939"
  },
  {
    "country": "US",
    "name": "Hooper",
    "lat": "41.16383",
    "lng": "-112.12244"
  },
  {
    "country": "US",
    "name": "Hyde Park",
    "lat": "41.79882",
    "lng": "-111.81911"
  },
  {
    "country": "US",
    "name": "Hyrum",
    "lat": "41.6341",
    "lng": "-111.85217"
  },
  {
    "country": "US",
    "name": "Kamas",
    "lat": "40.64301",
    "lng": "-111.28074"
  },
  {
    "country": "US",
    "name": "Kaysville",
    "lat": "41.03522",
    "lng": "-111.93855"
  },
  {
    "country": "US",
    "name": "Kearns",
    "lat": "40.65995",
    "lng": "-111.99633"
  },
  {
    "country": "US",
    "name": "Layton",
    "lat": "41.06022",
    "lng": "-111.97105"
  },
  {
    "country": "US",
    "name": "Lehi",
    "lat": "40.39162",
    "lng": "-111.85077"
  },
  {
    "country": "US",
    "name": "Lewiston",
    "lat": "41.97576",
    "lng": "-111.85634"
  },
  {
    "country": "US",
    "name": "Liberty",
    "lat": "41.33355",
    "lng": "-111.86355"
  },
  {
    "country": "US",
    "name": "Lindon",
    "lat": "40.34329",
    "lng": "-111.72076"
  },
  {
    "country": "US",
    "name": "Logan",
    "lat": "41.73549",
    "lng": "-111.83439"
  },
  {
    "country": "US",
    "name": "Maeser",
    "lat": "40.47718",
    "lng": "-109.58681"
  },
  {
    "country": "US",
    "name": "Magna",
    "lat": "40.70911",
    "lng": "-112.10161"
  },
  {
    "country": "US",
    "name": "Manila",
    "lat": "40.98801",
    "lng": "-109.72265"
  },
  {
    "country": "US",
    "name": "Mapleton",
    "lat": "40.13023",
    "lng": "-111.57853"
  },
  {
    "country": "US",
    "name": "Marriott-Slaterville",
    "lat": "41.25161",
    "lng": "-112.0255"
  },
  {
    "country": "US",
    "name": "Mendon",
    "lat": "41.70993",
    "lng": "-111.97773"
  },
  {
    "country": "US",
    "name": "Midvale",
    "lat": "40.61106",
    "lng": "-111.89994"
  },
  {
    "country": "US",
    "name": "Midway",
    "lat": "40.51218",
    "lng": "-111.47435"
  },
  {
    "country": "US",
    "name": "Millcreek",
    "lat": "40.68689",
    "lng": "-111.87549"
  },
  {
    "country": "US",
    "name": "Millville",
    "lat": "41.6816",
    "lng": "-111.823"
  },
  {
    "country": "US",
    "name": "Morgan",
    "lat": "41.03606",
    "lng": "-111.67688"
  },
  {
    "country": "US",
    "name": "Mount Olympus",
    "lat": "40.6855",
    "lng": "-111.78854"
  },
  {
    "country": "US",
    "name": "Mountain Green",
    "lat": "41.143",
    "lng": "-111.7916"
  },
  {
    "country": "US",
    "name": "Murray",
    "lat": "40.66689",
    "lng": "-111.88799"
  },
  {
    "country": "US",
    "name": "Naples",
    "lat": "40.42691",
    "lng": "-109.4993"
  },
  {
    "country": "US",
    "name": "Nibley",
    "lat": "41.67438",
    "lng": "-111.833"
  },
  {
    "country": "US",
    "name": "North Logan",
    "lat": "41.76937",
    "lng": "-111.80467"
  },
  {
    "country": "US",
    "name": "North Ogden",
    "lat": "41.30716",
    "lng": "-111.96022"
  },
  {
    "country": "US",
    "name": "North Salt Lake",
    "lat": "40.84856",
    "lng": "-111.90688"
  },
  {
    "country": "US",
    "name": "Oakley",
    "lat": "40.71467",
    "lng": "-111.30074"
  },
  {
    "country": "US",
    "name": "Ogden",
    "lat": "41.223",
    "lng": "-111.97383"
  },
  {
    "country": "US",
    "name": "Oquirrh",
    "lat": "40.6305",
    "lng": "-112.03383"
  },
  {
    "country": "US",
    "name": "Orem",
    "lat": "40.2969",
    "lng": "-111.69465"
  },
  {
    "country": "US",
    "name": "Park City",
    "lat": "40.64606",
    "lng": "-111.49797"
  },
  {
    "country": "US",
    "name": "Payson",
    "lat": "40.0444",
    "lng": "-111.73215"
  },
  {
    "country": "US",
    "name": "Perry",
    "lat": "41.46494",
    "lng": "-112.03245"
  },
  {
    "country": "US",
    "name": "Plain City",
    "lat": "41.298",
    "lng": "-112.08605"
  },
  {
    "country": "US",
    "name": "Pleasant Grove",
    "lat": "40.36412",
    "lng": "-111.73854"
  },
  {
    "country": "US",
    "name": "Pleasant View",
    "lat": "41.31828",
    "lng": "-111.99216"
  },
  {
    "country": "US",
    "name": "Providence",
    "lat": "41.70632",
    "lng": "-111.81717"
  },
  {
    "country": "US",
    "name": "Provo",
    "lat": "40.23384",
    "lng": "-111.65853"
  },
  {
    "country": "US",
    "name": "Randolph",
    "lat": "41.66578",
    "lng": "-111.18214"
  },
  {
    "country": "US",
    "name": "Richmond",
    "lat": "41.92271",
    "lng": "-111.81356"
  },
  {
    "country": "US",
    "name": "River Heights",
    "lat": "41.7216",
    "lng": "-111.82133"
  },
  {
    "country": "US",
    "name": "Riverdale",
    "lat": "41.17689",
    "lng": "-112.00383"
  },
  {
    "country": "US",
    "name": "Riverton",
    "lat": "40.52189",
    "lng": "-111.9391"
  },
  {
    "country": "US",
    "name": "Roosevelt",
    "lat": "40.2994",
    "lng": "-109.98876"
  },
  {
    "country": "US",
    "name": "Roy",
    "lat": "41.16161",
    "lng": "-112.02633"
  },
  {
    "country": "US",
    "name": "Salt Lake City",
    "lat": "40.76078",
    "lng": "-111.89105"
  },
  {
    "country": "US",
    "name": "Sandy",
    "lat": "40.59161",
    "lng": "-111.8841"
  },
  {
    "country": "US",
    "name": "Sandy Hills",
    "lat": "40.58106",
    "lng": "-111.85077"
  },
  {
    "country": "US",
    "name": "Saratoga Springs",
    "lat": "40.34912",
    "lng": "-111.90466"
  },
  {
    "country": "US",
    "name": "Smithfield",
    "lat": "41.83826",
    "lng": "-111.83272"
  },
  {
    "country": "US",
    "name": "Snyderville",
    "lat": "40.69439",
    "lng": "-111.54381"
  },
  {
    "country": "US",
    "name": "South Jordan Heights",
    "lat": "40.56384",
    "lng": "-111.94938"
  },
  {
    "country": "US",
    "name": "South Jordan",
    "lat": "40.56217",
    "lng": "-111.92966"
  },
  {
    "country": "US",
    "name": "South Ogden",
    "lat": "41.19189",
    "lng": "-111.97133"
  },
  {
    "country": "US",
    "name": "South Salt Lake",
    "lat": "40.71884",
    "lng": "-111.88827"
  },
  {
    "country": "US",
    "name": "South Weber",
    "lat": "41.13244",
    "lng": "-111.93022"
  },
  {
    "country": "US",
    "name": "South Willard",
    "lat": "41.36327",
    "lng": "-112.03578"
  },
  {
    "country": "US",
    "name": "Spanish Fork",
    "lat": "40.11496",
    "lng": "-111.65492"
  },
  {
    "country": "US",
    "name": "Springville",
    "lat": "40.16523",
    "lng": "-111.61075"
  },
  {
    "country": "US",
    "name": "Stansbury park",
    "lat": "40.63772",
    "lng": "-112.29606"
  },
  {
    "country": "US",
    "name": "Summit Park",
    "lat": "40.74578",
    "lng": "-111.61159"
  },
  {
    "country": "US",
    "name": "Sunset",
    "lat": "41.13633",
    "lng": "-112.03105"
  },
  {
    "country": "US",
    "name": "Syracuse",
    "lat": "41.08939",
    "lng": "-112.06467"
  },
  {
    "country": "US",
    "name": "Taylorsville",
    "lat": "40.66772",
    "lng": "-111.93883"
  },
  {
    "country": "US",
    "name": "Tooele",
    "lat": "40.53078",
    "lng": "-112.29828"
  },
  {
    "country": "US",
    "name": "Tremonton",
    "lat": "41.71187",
    "lng": "-112.16551"
  },
  {
    "country": "US",
    "name": "Uintah",
    "lat": "41.14411",
    "lng": "-111.92327"
  },
  {
    "country": "US",
    "name": "Vernal",
    "lat": "40.45552",
    "lng": "-109.52875"
  },
  {
    "country": "US",
    "name": "Washington Terrace",
    "lat": "41.17272",
    "lng": "-111.97661"
  },
  {
    "country": "US",
    "name": "Wendover",
    "lat": "40.73715",
    "lng": "-114.03751"
  },
  {
    "country": "US",
    "name": "West Bountiful",
    "lat": "40.89383",
    "lng": "-111.90188"
  },
  {
    "country": "US",
    "name": "West Haven",
    "lat": "41.203",
    "lng": "-112.05105"
  },
  {
    "country": "US",
    "name": "West Jordan",
    "lat": "40.60967",
    "lng": "-111.9391"
  },
  {
    "country": "US",
    "name": "West Mountain",
    "lat": "40.06079",
    "lng": "-111.78827"
  },
  {
    "country": "US",
    "name": "West Point",
    "lat": "41.11828",
    "lng": "-112.08411"
  },
  {
    "country": "US",
    "name": "West Valley City",
    "lat": "40.69161",
    "lng": "-112.00105"
  },
  {
    "country": "US",
    "name": "White City",
    "lat": "40.56578",
    "lng": "-111.86438"
  },
  {
    "country": "US",
    "name": "Willard",
    "lat": "41.40911",
    "lng": "-112.03606"
  },
  {
    "country": "US",
    "name": "Willard",
    "lat": "40.70634",
    "lng": "-111.83743"
  },
  {
    "country": "US",
    "name": "Wolf Creek",
    "lat": "41.33327",
    "lng": "-111.82716"
  },
  {
    "country": "US",
    "name": "Woodland Hills",
    "lat": "40.01532",
    "lng": "-111.64868"
  },
  {
    "country": "US",
    "name": "Woods Cross",
    "lat": "40.87161",
    "lng": "-111.89216"
  },
  {
    "country": "US",
    "name": "Aberdeen",
    "lat": "46.97537",
    "lng": "-123.81572"
  },
  {
    "country": "US",
    "name": "Ahtanum",
    "lat": "46.55957",
    "lng": "-120.62201"
  },
  {
    "country": "US",
    "name": "Airway Heights",
    "lat": "47.64461",
    "lng": "-117.59327"
  },
  {
    "country": "US",
    "name": "Alderton",
    "lat": "47.16955",
    "lng": "-122.22928"
  },
  {
    "country": "US",
    "name": "Alderwood Manor",
    "lat": "47.82204",
    "lng": "-122.28207"
  },
  {
    "country": "US",
    "name": "Algona",
    "lat": "47.27899",
    "lng": "-122.25206"
  },
  {
    "country": "US",
    "name": "Allyn",
    "lat": "47.38565",
    "lng": "-122.82764"
  },
  {
    "country": "US",
    "name": "Amboy",
    "lat": "45.91011",
    "lng": "-122.44649"
  },
  {
    "country": "US",
    "name": "Ames Lake",
    "lat": "47.63288",
    "lng": "-121.96623"
  },
  {
    "country": "US",
    "name": "Anacortes",
    "lat": "48.5126",
    "lng": "-122.61267"
  },
  {
    "country": "US",
    "name": "Arlington Heights",
    "lat": "48.20205",
    "lng": "-122.06208"
  },
  {
    "country": "US",
    "name": "Arlington",
    "lat": "48.19871",
    "lng": "-122.12514"
  },
  {
    "country": "US",
    "name": "Artondale",
    "lat": "47.29954",
    "lng": "-122.62069"
  },
  {
    "country": "US",
    "name": "Asotin",
    "lat": "46.33933",
    "lng": "-117.04821"
  },
  {
    "country": "US",
    "name": "Auburn",
    "lat": "47.30732",
    "lng": "-122.22845"
  },
  {
    "country": "US",
    "name": "Barberton",
    "lat": "45.69317",
    "lng": "-122.59899"
  },
  {
    "country": "US",
    "name": "Basin City",
    "lat": "46.59403",
    "lng": "-119.15223"
  },
  {
    "country": "US",
    "name": "Battle Ground",
    "lat": "45.78095",
    "lng": "-122.53343"
  },
  {
    "country": "US",
    "name": "Belfair",
    "lat": "47.45065",
    "lng": "-122.82737"
  },
  {
    "country": "US",
    "name": "Bellevue",
    "lat": "47.61038",
    "lng": "-122.20068"
  },
  {
    "country": "US",
    "name": "Bellingham",
    "lat": "48.75955",
    "lng": "-122.48822"
  },
  {
    "country": "US",
    "name": "Benton City",
    "lat": "46.26319",
    "lng": "-119.4878"
  },
  {
    "country": "US",
    "name": "Bethel",
    "lat": "47.49398",
    "lng": "-122.63125"
  },
  {
    "country": "US",
    "name": "Big Lake",
    "lat": "48.40288",
    "lng": "-122.24127"
  },
  {
    "country": "US",
    "name": "Birch Bay",
    "lat": "48.91789",
    "lng": "-122.74462"
  },
  {
    "country": "US",
    "name": "Black Diamond",
    "lat": "47.30871",
    "lng": "-122.00317"
  },
  {
    "country": "US",
    "name": "Blaine",
    "lat": "48.99372",
    "lng": "-122.74712"
  },
  {
    "country": "US",
    "name": "Bonney Lake",
    "lat": "47.17705",
    "lng": "-122.18651"
  },
  {
    "country": "US",
    "name": "Bothell",
    "lat": "47.76232",
    "lng": "-122.2054"
  },
  {
    "country": "US",
    "name": "Boulevard Park",
    "lat": "47.48927",
    "lng": "-122.31512"
  },
  {
    "country": "US",
    "name": "Bremerton",
    "lat": "47.56732",
    "lng": "-122.63264"
  },
  {
    "country": "US",
    "name": "Brewster",
    "lat": "48.09598",
    "lng": "-119.78062"
  },
  {
    "country": "US",
    "name": "Bridgeport",
    "lat": "48.0082",
    "lng": "-119.67116"
  },
  {
    "country": "US",
    "name": "Brier",
    "lat": "47.78454",
    "lng": "-122.27429"
  },
  {
    "country": "US",
    "name": "Browns Point",
    "lat": "47.30038",
    "lng": "-122.44124"
  },
  {
    "country": "US",
    "name": "Brush Prairie",
    "lat": "45.73289",
    "lng": "-122.54649"
  },
  {
    "country": "US",
    "name": "Bryant",
    "lat": "48.23899",
    "lng": "-122.15792"
  },
  {
    "country": "US",
    "name": "Buckley",
    "lat": "47.16316",
    "lng": "-122.02678"
  },
  {
    "country": "US",
    "name": "Burbank",
    "lat": "46.19986",
    "lng": "-119.01306"
  },
  {
    "country": "US",
    "name": "Burien",
    "lat": "47.47038",
    "lng": "-122.34679"
  },
  {
    "country": "US",
    "name": "Burley",
    "lat": "47.41787",
    "lng": "-122.63097"
  },
  {
    "country": "US",
    "name": "Burlington",
    "lat": "48.47566",
    "lng": "-122.32544"
  },
  {
    "country": "US",
    "name": "Camano",
    "lat": "48.17399",
    "lng": "-122.52821"
  },
  {
    "country": "US",
    "name": "Camas",
    "lat": "45.58706",
    "lng": "-122.39954"
  },
  {
    "country": "US",
    "name": "Canterwood",
    "lat": "47.3751",
    "lng": "-122.5893"
  },
  {
    "country": "US",
    "name": "Carnation",
    "lat": "47.64788",
    "lng": "-121.91401"
  },
  {
    "country": "US",
    "name": "Carson",
    "lat": "45.72539",
    "lng": "-121.81924"
  },
  {
    "country": "US",
    "name": "Cascade Valley",
    "lat": "47.13459",
    "lng": "-119.32808"
  },
  {
    "country": "US",
    "name": "Cashmere",
    "lat": "47.52235",
    "lng": "-120.4698"
  },
  {
    "country": "US",
    "name": "Castle Rock",
    "lat": "46.27511",
    "lng": "-122.90761"
  },
  {
    "country": "US",
    "name": "Cathcart",
    "lat": "47.84788",
    "lng": "-122.09929"
  },
  {
    "country": "US",
    "name": "Cathlamet",
    "lat": "46.20317",
    "lng": "-123.38318"
  },
  {
    "country": "US",
    "name": "Central Park",
    "lat": "46.97343",
    "lng": "-123.69239"
  },
  {
    "country": "US",
    "name": "Centralia",
    "lat": "46.71621",
    "lng": "-122.9543"
  },
  {
    "country": "US",
    "name": "Chehalis",
    "lat": "46.66205",
    "lng": "-122.96402"
  },
  {
    "country": "US",
    "name": "Chelan",
    "lat": "47.84097",
    "lng": "-120.01646"
  },
  {
    "country": "US",
    "name": "Cheney",
    "lat": "47.48739",
    "lng": "-117.57576"
  },
  {
    "country": "US",
    "name": "Chewelah",
    "lat": "48.27629",
    "lng": "-117.71552"
  },
  {
    "country": "US",
    "name": "Chico",
    "lat": "47.61148",
    "lng": "-122.71042"
  },
  {
    "country": "US",
    "name": "Clarkston",
    "lat": "46.41629",
    "lng": "-117.04557"
  },
  {
    "country": "US",
    "name": "Cle Elum",
    "lat": "47.1954",
    "lng": "-120.93925"
  },
  {
    "country": "US",
    "name": "Clear Lake",
    "lat": "48.46427",
    "lng": "-122.23404"
  },
  {
    "country": "US",
    "name": "Clearview",
    "lat": "47.83371",
    "lng": "-122.12596"
  },
  {
    "country": "US",
    "name": "Clyde Hill",
    "lat": "47.63177",
    "lng": "-122.2179"
  },
  {
    "country": "US",
    "name": "Colfax",
    "lat": "46.88017",
    "lng": "-117.36435"
  },
  {
    "country": "US",
    "name": "College Place",
    "lat": "46.0493",
    "lng": "-118.3883"
  },
  {
    "country": "US",
    "name": "Colville",
    "lat": "48.54657",
    "lng": "-117.90554"
  },
  {
    "country": "US",
    "name": "Connell",
    "lat": "46.66347",
    "lng": "-118.86111"
  },
  {
    "country": "US",
    "name": "Cosmopolis",
    "lat": "46.95537",
    "lng": "-123.77378"
  },
  {
    "country": "US",
    "name": "Cottage Lake",
    "lat": "47.74427",
    "lng": "-122.07735"
  },
  {
    "country": "US",
    "name": "Coulee Dam",
    "lat": "47.96543",
    "lng": "-118.97613"
  },
  {
    "country": "US",
    "name": "Country Homes",
    "lat": "47.7485",
    "lng": "-117.40439"
  },
  {
    "country": "US",
    "name": "Coupeville",
    "lat": "48.21982",
    "lng": "-122.68628"
  },
  {
    "country": "US",
    "name": "Covington",
    "lat": "47.35818",
    "lng": "-122.12216"
  },
  {
    "country": "US",
    "name": "Dallesport",
    "lat": "45.61734",
    "lng": "-121.17952"
  },
  {
    "country": "US",
    "name": "Darrington",
    "lat": "48.25539",
    "lng": "-121.60151"
  },
  {
    "country": "US",
    "name": "Davenport",
    "lat": "47.65405",
    "lng": "-118.14997"
  },
  {
    "country": "US",
    "name": "Dayton",
    "lat": "46.32375",
    "lng": "-117.97244"
  },
  {
    "country": "US",
    "name": "Deer Park",
    "lat": "47.95434",
    "lng": "-117.47689"
  },
  {
    "country": "US",
    "name": "Des Moines",
    "lat": "47.40177",
    "lng": "-122.32429"
  },
  {
    "country": "US",
    "name": "Desert Aire",
    "lat": "46.6793",
    "lng": "-119.91727"
  },
  {
    "country": "US",
    "name": "Dishman",
    "lat": "47.66007",
    "lng": "-117.27596"
  },
  {
    "country": "US",
    "name": "Dollar Corner",
    "lat": "45.78012",
    "lng": "-122.6001"
  },
  {
    "country": "US",
    "name": "DuPont",
    "lat": "47.09676",
    "lng": "-122.63124"
  },
  {
    "country": "US",
    "name": "Duvall",
    "lat": "47.74232",
    "lng": "-121.98568"
  },
  {
    "country": "US",
    "name": "East Port Orchard",
    "lat": "47.52343",
    "lng": "-122.6243"
  },
  {
    "country": "US",
    "name": "East Renton Highlands",
    "lat": "47.48482",
    "lng": "-122.11234"
  },
  {
    "country": "US",
    "name": "East Wenatchee",
    "lat": "47.41568",
    "lng": "-120.29313"
  },
  {
    "country": "US",
    "name": "East Wenatchee Bench",
    "lat": "47.42568",
    "lng": "-120.28118"
  },
  {
    "country": "US",
    "name": "Eastgate",
    "lat": "47.57266",
    "lng": "-122.14578"
  },
  {
    "country": "US",
    "name": "Eatonville",
    "lat": "46.86733",
    "lng": "-122.2665"
  },
  {
    "country": "US",
    "name": "Edgewood",
    "lat": "47.2501",
    "lng": "-122.29373"
  },
  {
    "country": "US",
    "name": "Edmonds",
    "lat": "47.81065",
    "lng": "-122.37736"
  },
  {
    "country": "US",
    "name": "Electric City",
    "lat": "47.93237",
    "lng": "-119.03808"
  },
  {
    "country": "US",
    "name": "Elk Plain",
    "lat": "47.05316",
    "lng": "-122.39762"
  },
  {
    "country": "US",
    "name": "Ellensburg",
    "lat": "46.99651",
    "lng": "-120.54785"
  },
  {
    "country": "US",
    "name": "Elma",
    "lat": "47.00343",
    "lng": "-123.40877"
  },
  {
    "country": "US",
    "name": "Enetai",
    "lat": "47.58482",
    "lng": "-122.59875"
  },
  {
    "country": "US",
    "name": "Entiat",
    "lat": "47.67596",
    "lng": "-120.20841"
  },
  {
    "country": "US",
    "name": "Enumclaw",
    "lat": "47.20427",
    "lng": "-121.9915"
  },
  {
    "country": "US",
    "name": "Ephrata",
    "lat": "47.31764",
    "lng": "-119.55365"
  },
  {
    "country": "US",
    "name": "Esperance",
    "lat": "47.78899",
    "lng": "-122.35541"
  },
  {
    "country": "US",
    "name": "Everett",
    "lat": "47.97898",
    "lng": "-122.20208"
  },
  {
    "country": "US",
    "name": "Everson",
    "lat": "48.92012",
    "lng": "-122.34266"
  },
  {
    "country": "US",
    "name": "Fairwood",
    "lat": "47.44843",
    "lng": "-122.15734"
  },
  {
    "country": "US",
    "name": "Fairwood",
    "lat": "47.76684",
    "lng": "-117.41744"
  },
  {
    "country": "US",
    "name": "Fall City",
    "lat": "47.56732",
    "lng": "-121.88873"
  },
  {
    "country": "US",
    "name": "Felida",
    "lat": "45.70956",
    "lng": "-122.70732"
  },
  {
    "country": "US",
    "name": "Federal Way",
    "lat": "47.32232",
    "lng": "-122.31262"
  },
  {
    "country": "US",
    "name": "Fern Prairie",
    "lat": "45.63651",
    "lng": "-122.3987"
  },
  {
    "country": "US",
    "name": "Ferndale",
    "lat": "48.8465",
    "lng": "-122.59101"
  },
  {
    "country": "US",
    "name": "Fife",
    "lat": "47.23927",
    "lng": "-122.35707"
  },
  {
    "country": "US",
    "name": "Fife Heights",
    "lat": "47.25899",
    "lng": "-122.34568"
  },
  {
    "country": "US",
    "name": "Finley",
    "lat": "46.15402",
    "lng": "-119.0339"
  },
  {
    "country": "US",
    "name": "Fircrest",
    "lat": "47.23954",
    "lng": "-122.51596"
  },
  {
    "country": "US",
    "name": "Five Corners",
    "lat": "45.68456",
    "lng": "-122.5751"
  },
  {
    "country": "US",
    "name": "Fobes Hill",
    "lat": "47.94899",
    "lng": "-122.11985"
  },
  {
    "country": "US",
    "name": "Fords Prairie",
    "lat": "46.7351",
    "lng": "-122.98902"
  },
  {
    "country": "US",
    "name": "Forks",
    "lat": "47.95036",
    "lng": "-124.38549"
  },
  {
    "country": "US",
    "name": "Fox Island",
    "lat": "47.25149",
    "lng": "-122.62902"
  },
  {
    "country": "US",
    "name": "Frederickson",
    "lat": "47.09621",
    "lng": "-122.35873"
  },
  {
    "country": "US",
    "name": "Freeland",
    "lat": "48.00954",
    "lng": "-122.52598"
  },
  {
    "country": "US",
    "name": "Friday Harbor",
    "lat": "48.53427",
    "lng": "-123.01712"
  },
  {
    "country": "US",
    "name": "Garrett",
    "lat": "46.05208",
    "lng": "-118.40275"
  },
  {
    "country": "US",
    "name": "Geneva",
    "lat": "48.74567",
    "lng": "-122.40183"
  },
  {
    "country": "US",
    "name": "Gig Harbor",
    "lat": "47.32926",
    "lng": "-122.58013"
  },
  {
    "country": "US",
    "name": "Gleed",
    "lat": "46.65818",
    "lng": "-120.6134"
  },
  {
    "country": "US",
    "name": "Gold Bar",
    "lat": "47.85677",
    "lng": "-121.69706"
  },
  {
    "country": "US",
    "name": "Goldendale",
    "lat": "45.82068",
    "lng": "-120.82173"
  },
  {
    "country": "US",
    "name": "Graham",
    "lat": "47.05288",
    "lng": "-122.29428"
  },
  {
    "country": "US",
    "name": "Grand Coulee",
    "lat": "47.94154",
    "lng": "-119.00335"
  },
  {
    "country": "US",
    "name": "Grand Mound",
    "lat": "46.78788",
    "lng": "-123.01125"
  },
  {
    "country": "US",
    "name": "Grandview",
    "lat": "46.25097",
    "lng": "-119.9017"
  },
  {
    "country": "US",
    "name": "Granger",
    "lat": "46.34207",
    "lng": "-120.18727"
  },
  {
    "country": "US",
    "name": "Granite Falls",
    "lat": "47.89013",
    "lng": "-120.21369"
  },
  {
    "country": "US",
    "name": "Granite Falls",
    "lat": "48.08399",
    "lng": "-121.96874"
  },
  {
    "country": "US",
    "name": "Hansville",
    "lat": "47.9187",
    "lng": "-122.55431"
  },
  {
    "country": "US",
    "name": "Hazel Dell",
    "lat": "45.67151",
    "lng": "-122.66288"
  },
  {
    "country": "US",
    "name": "Highland",
    "lat": "46.13152",
    "lng": "-119.11418"
  },
  {
    "country": "US",
    "name": "Hobart",
    "lat": "47.42177",
    "lng": "-121.97289"
  },
  {
    "country": "US",
    "name": "Hockinson",
    "lat": "45.73789",
    "lng": "-122.48704"
  },
  {
    "country": "US",
    "name": "Home",
    "lat": "47.27482",
    "lng": "-122.76375"
  },
  {
    "country": "US",
    "name": "Hoquiam",
    "lat": "46.98092",
    "lng": "-123.88933"
  },
  {
    "country": "US",
    "name": "Indianola",
    "lat": "47.74704",
    "lng": "-122.52569"
  },
  {
    "country": "US",
    "name": "Issaquah",
    "lat": "47.5301",
    "lng": "-122.03262"
  },
  {
    "country": "US",
    "name": "Kalama",
    "lat": "46.00845",
    "lng": "-122.84455"
  },
  {
    "country": "US",
    "name": "Kelso",
    "lat": "46.14678",
    "lng": "-122.90844"
  },
  {
    "country": "US",
    "name": "Kenmore",
    "lat": "47.75732",
    "lng": "-122.24401"
  },
  {
    "country": "US",
    "name": "Kennewick",
    "lat": "46.21125",
    "lng": "-119.13723"
  },
  {
    "country": "US",
    "name": "Kent",
    "lat": "47.38093",
    "lng": "-122.23484"
  },
  {
    "country": "US",
    "name": "Kettle Falls",
    "lat": "48.61074",
    "lng": "-118.05582"
  },
  {
    "country": "US",
    "name": "Key Center",
    "lat": "47.34065",
    "lng": "-122.74541"
  },
  {
    "country": "US",
    "name": "Kingston",
    "lat": "47.7985",
    "lng": "-122.49806"
  },
  {
    "country": "US",
    "name": "Kingsgate",
    "lat": "47.72704",
    "lng": "-122.17957"
  },
  {
    "country": "US",
    "name": "Kirkland",
    "lat": "47.68149",
    "lng": "-122.20874"
  },
  {
    "country": "US",
    "name": "Kittitas",
    "lat": "46.98318",
    "lng": "-120.41701"
  },
  {
    "country": "US",
    "name": "Klahanie",
    "lat": "47.43121",
    "lng": "-122.43652"
  },
  {
    "country": "US",
    "name": "La Center",
    "lat": "45.86234",
    "lng": "-122.67038"
  },
  {
    "country": "US",
    "name": "Lacey",
    "lat": "47.03426",
    "lng": "-122.82319"
  },
  {
    "country": "US",
    "name": "Lake Forest Park",
    "lat": "47.75676",
    "lng": "-122.28096"
  },
  {
    "country": "US",
    "name": "Lake Shore",
    "lat": "45.69067",
    "lng": "-122.69093"
  },
  {
    "country": "US",
    "name": "Lake Stevens",
    "lat": "48.0151",
    "lng": "-122.06374"
  },
  {
    "country": "US",
    "name": "Lakewood",
    "lat": "47.17176",
    "lng": "-122.51846"
  },
  {
    "country": "US",
    "name": "Langley",
    "lat": "48.04009",
    "lng": "-122.40626"
  },
  {
    "country": "US",
    "name": "Leavenworth",
    "lat": "47.59623",
    "lng": "-120.66148"
  },
  {
    "country": "US",
    "name": "Lewisville",
    "lat": "45.80984",
    "lng": "-122.52315"
  },
  {
    "country": "US",
    "name": "Liberty Lake",
    "lat": "47.67591",
    "lng": "-117.11821"
  },
  {
    "country": "US",
    "name": "Lochsloy",
    "lat": "48.05149",
    "lng": "-122.03208"
  },
  {
    "country": "US",
    "name": "Lofall",
    "lat": "47.81204",
    "lng": "-122.65821"
  },
  {
    "country": "US",
    "name": "Long Beach",
    "lat": "46.35232",
    "lng": "-124.05432"
  },
  {
    "country": "US",
    "name": "Longbranch",
    "lat": "47.20898",
    "lng": "-122.7568"
  },
  {
    "country": "US",
    "name": "Longview",
    "lat": "46.13817",
    "lng": "-122.93817"
  },
  {
    "country": "US",
    "name": "Longview Heights",
    "lat": "46.18039",
    "lng": "-122.95706"
  },
  {
    "country": "US",
    "name": "Lynden",
    "lat": "48.9465",
    "lng": "-122.45211"
  },
  {
    "country": "US",
    "name": "Lynnwood",
    "lat": "47.82093",
    "lng": "-122.31513"
  },
  {
    "country": "US",
    "name": "Mabton",
    "lat": "46.21485",
    "lng": "-119.99671"
  },
  {
    "country": "US",
    "name": "Machias",
    "lat": "47.98149",
    "lng": "-122.04596"
  },
  {
    "country": "US",
    "name": "Maltby",
    "lat": "47.8051",
    "lng": "-122.11318"
  },
  {
    "country": "US",
    "name": "Manchester",
    "lat": "47.55566",
    "lng": "-122.54507"
  },
  {
    "country": "US",
    "name": "Manson",
    "lat": "47.88486",
    "lng": "-120.15841"
  },
  {
    "country": "US",
    "name": "Maple Valley",
    "lat": "47.39272",
    "lng": "-122.04641"
  },
  {
    "country": "US",
    "name": "Maplewood",
    "lat": "47.40176",
    "lng": "-122.55707"
  },
  {
    "country": "US",
    "name": "Marietta",
    "lat": "48.78705",
    "lng": "-122.58045"
  },
  {
    "country": "US",
    "name": "Martha Lake",
    "lat": "47.85093",
    "lng": "-122.2393"
  },
  {
    "country": "US",
    "name": "Marysville",
    "lat": "48.05176",
    "lng": "-122.17708"
  },
  {
    "country": "US",
    "name": "Mattawa",
    "lat": "46.73791",
    "lng": "-119.90282"
  },
  {
    "country": "US",
    "name": "McCleary",
    "lat": "47.05315",
    "lng": "-123.26543"
  },
  {
    "country": "US",
    "name": "McMillin",
    "lat": "47.13982",
    "lng": "-122.23651"
  },
  {
    "country": "US",
    "name": "Mead",
    "lat": "47.76739",
    "lng": "-117.35494"
  },
  {
    "country": "US",
    "name": "Meadow Glade",
    "lat": "45.75845",
    "lng": "-122.56038"
  },
  {
    "country": "US",
    "name": "Meadowdale",
    "lat": "47.85287",
    "lng": "-122.33347"
  },
  {
    "country": "US",
    "name": "Medical Lake",
    "lat": "47.57294",
    "lng": "-117.68216"
  },
  {
    "country": "US",
    "name": "Medina",
    "lat": "47.62093",
    "lng": "-122.22762"
  },
  {
    "country": "US",
    "name": "Mercer Island",
    "lat": "47.57065",
    "lng": "-122.22207"
  },
  {
    "country": "US",
    "name": "Midland",
    "lat": "47.16704",
    "lng": "-122.40484"
  },
  {
    "country": "US",
    "name": "Mill Creek",
    "lat": "47.8601",
    "lng": "-122.2043"
  },
  {
    "country": "US",
    "name": "Mill Plain",
    "lat": "45.6429",
    "lng": "-122.49398"
  },
  {
    "country": "US",
    "name": "Millwood",
    "lat": "47.68128",
    "lng": "-117.28271"
  },
  {
    "country": "US",
    "name": "Milton",
    "lat": "47.24816",
    "lng": "-122.3129"
  },
  {
    "country": "US",
    "name": "Minnehaha",
    "lat": "45.65901",
    "lng": "-122.64871"
  },
  {
    "country": "US",
    "name": "Mirrormont",
    "lat": "47.46232",
    "lng": "-121.99567"
  },
  {
    "country": "US",
    "name": "Monroe",
    "lat": "47.85538",
    "lng": "-121.97096"
  },
  {
    "country": "US",
    "name": "Montesano",
    "lat": "46.98121",
    "lng": "-123.60266"
  },
  {
    "country": "US",
    "name": "Morton",
    "lat": "46.55844",
    "lng": "-122.2751"
  },
  {
    "country": "US",
    "name": "Moses Lake",
    "lat": "47.13014",
    "lng": "-119.27808"
  },
  {
    "country": "US",
    "name": "Mount Vernon",
    "lat": "48.42122",
    "lng": "-122.33405"
  },
  {
    "country": "US",
    "name": "Mount Vista",
    "lat": "45.73428",
    "lng": "-122.63288"
  },
  {
    "country": "US",
    "name": "Mountlake Terrace",
    "lat": "47.78815",
    "lng": "-122.30874"
  },
  {
    "country": "US",
    "name": "Mukilteo",
    "lat": "47.94454",
    "lng": "-122.30458"
  },
  {
    "country": "US",
    "name": "Napavine",
    "lat": "46.57455",
    "lng": "-122.90818"
  },
  {
    "country": "US",
    "name": "Navy Yard City",
    "lat": "47.55343",
    "lng": "-122.66458"
  },
  {
    "country": "US",
    "name": "Newcastle",
    "lat": "47.53899",
    "lng": "-122.15568"
  },
  {
    "country": "US",
    "name": "Newport",
    "lat": "47.57121",
    "lng": "-122.18068"
  },
  {
    "country": "US",
    "name": "Newport",
    "lat": "48.17963",
    "lng": "-117.04326"
  },
  {
    "country": "US",
    "name": "Nooksack",
    "lat": "48.92762",
    "lng": "-122.32155"
  },
  {
    "country": "US",
    "name": "Normandy Park",
    "lat": "47.43621",
    "lng": "-122.34068"
  },
  {
    "country": "US",
    "name": "North Bend",
    "lat": "47.49566",
    "lng": "-121.78678"
  },
  {
    "country": "US",
    "name": "North Creek",
    "lat": "47.81954",
    "lng": "-122.17624"
  },
  {
    "country": "US",
    "name": "North Puyallup",
    "lat": "47.20677",
    "lng": "-122.28234"
  },
  {
    "country": "US",
    "name": "North Yelm",
    "lat": "46.96315",
    "lng": "-122.6029"
  },
  {
    "country": "US",
    "name": "Oak Harbor",
    "lat": "48.29316",
    "lng": "-122.64322"
  },
  {
    "country": "US",
    "name": "Ocean Park",
    "lat": "46.49177",
    "lng": "-124.05208"
  },
  {
    "country": "US",
    "name": "Ocean Shores",
    "lat": "46.9737",
    "lng": "-124.15629"
  },
  {
    "country": "US",
    "name": "Okanogan",
    "lat": "48.36126",
    "lng": "-119.58339"
  },
  {
    "country": "US",
    "name": "Olympia",
    "lat": "47.03787",
    "lng": "-122.9007"
  },
  {
    "country": "US",
    "name": "Omak",
    "lat": "48.41099",
    "lng": "-119.52755"
  },
  {
    "country": "US",
    "name": "Opportunity",
    "lat": "47.64995",
    "lng": "-117.23991"
  },
  {
    "country": "US",
    "name": "Orchards",
    "lat": "45.66651",
    "lng": "-122.56093"
  },
  {
    "country": "US",
    "name": "Oroville",
    "lat": "48.93905",
    "lng": "-119.43562"
  },
  {
    "country": "US",
    "name": "Orting",
    "lat": "47.09788",
    "lng": "-122.20428"
  },
  {
    "country": "US",
    "name": "Othello",
    "lat": "46.82597",
    "lng": "-119.17529"
  },
  {
    "country": "US",
    "name": "Pacific",
    "lat": "47.26455",
    "lng": "-122.25012"
  },
  {
    "country": "US",
    "name": "Parkland",
    "lat": "47.15538",
    "lng": "-122.43401"
  },
  {
    "country": "US",
    "name": "Parkwood",
    "lat": "47.53315",
    "lng": "-122.61014"
  },
  {
    "country": "US",
    "name": "Pasco",
    "lat": "46.23958",
    "lng": "-119.10057"
  },
  {
    "country": "US",
    "name": "Point Roberts",
    "lat": "48.98538",
    "lng": "-123.07797"
  },
  {
    "country": "US",
    "name": "Pomeroy",
    "lat": "46.47487",
    "lng": "-117.60269"
  },
  {
    "country": "US",
    "name": "Port Angeles",
    "lat": "48.11815",
    "lng": "-123.43074"
  },
  {
    "country": "US",
    "name": "Port Ludlow",
    "lat": "47.92537",
    "lng": "-122.68349"
  },
  {
    "country": "US",
    "name": "Port Orchard",
    "lat": "47.54037",
    "lng": "-122.63625"
  },
  {
    "country": "US",
    "name": "Port Townsend",
    "lat": "48.11704",
    "lng": "-122.76045"
  },
  {
    "country": "US",
    "name": "Poulsbo",
    "lat": "47.73593",
    "lng": "-122.64654"
  },
  {
    "country": "US",
    "name": "Prairie Ridge",
    "lat": "47.1376",
    "lng": "-122.14873"
  },
  {
    "country": "US",
    "name": "Prosser",
    "lat": "46.2068",
    "lng": "-119.76892"
  },
  {
    "country": "US",
    "name": "Pullman",
    "lat": "46.73127",
    "lng": "-117.17962"
  },
  {
    "country": "US",
    "name": "Purdy",
    "lat": "47.38899",
    "lng": "-122.62541"
  },
  {
    "country": "US",
    "name": "Puyallup",
    "lat": "47.18538",
    "lng": "-122.2929"
  },
  {
    "country": "US",
    "name": "Quincy",
    "lat": "47.2343",
    "lng": "-119.85255"
  },
  {
    "country": "US",
    "name": "Rainier",
    "lat": "46.88815",
    "lng": "-122.68846"
  },
  {
    "country": "US",
    "name": "Ravensdale",
    "lat": "47.35232",
    "lng": "-121.98373"
  },
  {
    "country": "US",
    "name": "Raymond",
    "lat": "46.68649",
    "lng": "-123.73294"
  },
  {
    "country": "US",
    "name": "Redmond",
    "lat": "47.67399",
    "lng": "-122.12151"
  },
  {
    "country": "US",
    "name": "Renton",
    "lat": "47.48288",
    "lng": "-122.21707"
  },
  {
    "country": "US",
    "name": "Republic",
    "lat": "48.64822",
    "lng": "-118.73781"
  },
  {
    "country": "US",
    "name": "Richland",
    "lat": "46.28569",
    "lng": "-119.28446"
  },
  {
    "country": "US",
    "name": "Ridgefield",
    "lat": "45.81511",
    "lng": "-122.7426"
  },
  {
    "country": "US",
    "name": "Riverbend",
    "lat": "47.46649",
    "lng": "-121.75039"
  },
  {
    "country": "US",
    "name": "Riverton",
    "lat": "47.48427",
    "lng": "-122.29457"
  },
  {
    "country": "US",
    "name": "Ritzville",
    "lat": "47.12755",
    "lng": "-118.37999"
  },
  {
    "country": "US",
    "name": "Rochester",
    "lat": "46.82177",
    "lng": "-123.09625"
  },
  {
    "country": "US",
    "name": "Rocky Point",
    "lat": "47.59287",
    "lng": "-122.66848"
  },
  {
    "country": "US",
    "name": "Rosedale",
    "lat": "47.33149",
    "lng": "-122.65235"
  },
  {
    "country": "US",
    "name": "Royal City",
    "lat": "46.90097",
    "lng": "-119.63059"
  },
  {
    "country": "US",
    "name": "Salmon Creek",
    "lat": "45.71067",
    "lng": "-122.64899"
  },
  {
    "country": "US",
    "name": "Sammamish",
    "lat": "47.64177",
    "lng": "-122.0804"
  },
  {
    "country": "US",
    "name": "SeaTac",
    "lat": "47.44846",
    "lng": "-122.29217"
  },
  {
    "country": "US",
    "name": "Seabeck",
    "lat": "47.63954",
    "lng": "-122.82849"
  },
  {
    "country": "US",
    "name": "Seattle",
    "lat": "47.60621",
    "lng": "-122.33207"
  },
  {
    "country": "US",
    "name": "Sedro-Woolley",
    "lat": "48.50389",
    "lng": "-122.23611"
  },
  {
    "country": "US",
    "name": "Selah",
    "lat": "46.65402",
    "lng": "-120.53007"
  },
  {
    "country": "US",
    "name": "Sequim",
    "lat": "48.07963",
    "lng": "-123.10234"
  },
  {
    "country": "US",
    "name": "Shelton",
    "lat": "47.21509",
    "lng": "-123.10071"
  },
  {
    "country": "US",
    "name": "Shoreline",
    "lat": "47.75565",
    "lng": "-122.34152"
  },
  {
    "country": "US",
    "name": "Silverdale",
    "lat": "47.64454",
    "lng": "-122.69487"
  },
  {
    "country": "US",
    "name": "Sisco Heights",
    "lat": "48.11538",
    "lng": "-122.09708"
  },
  {
    "country": "US",
    "name": "Smokey Point",
    "lat": "48.15232",
    "lng": "-122.18264"
  },
  {
    "country": "US",
    "name": "Snohomish",
    "lat": "47.91288",
    "lng": "-122.09818"
  },
  {
    "country": "US",
    "name": "Snoqualmie",
    "lat": "47.52871",
    "lng": "-121.82539"
  },
  {
    "country": "US",
    "name": "Soap Lake",
    "lat": "47.38931",
    "lng": "-119.49059"
  },
  {
    "country": "US",
    "name": "South Bend",
    "lat": "46.66315",
    "lng": "-123.80461"
  },
  {
    "country": "US",
    "name": "South Hill",
    "lat": "47.14121",
    "lng": "-122.27012"
  },
  {
    "country": "US",
    "name": "Southworth",
    "lat": "47.51204",
    "lng": "-122.5018"
  },
  {
    "country": "US",
    "name": "Spanaway",
    "lat": "47.10399",
    "lng": "-122.43457"
  },
  {
    "country": "US",
    "name": "Spokane",
    "lat": "47.65966",
    "lng": "-117.42908"
  },
  {
    "country": "US",
    "name": "Spokane Valley",
    "lat": "47.67323",
    "lng": "-117.23937"
  },
  {
    "country": "US",
    "name": "Stanwood",
    "lat": "48.24121",
    "lng": "-122.37071"
  },
  {
    "country": "US",
    "name": "Steilacoom",
    "lat": "47.16982",
    "lng": "-122.60263"
  },
  {
    "country": "US",
    "name": "Stevenson",
    "lat": "45.69567",
    "lng": "-121.88452"
  },
  {
    "country": "US",
    "name": "Sudden Valley",
    "lat": "48.72289",
    "lng": "-122.34655"
  },
  {
    "country": "US",
    "name": "Sultan",
    "lat": "47.8626",
    "lng": "-121.81651"
  },
  {
    "country": "US",
    "name": "Sumas",
    "lat": "49.00012",
    "lng": "-122.26488"
  },
  {
    "country": "US",
    "name": "Summit",
    "lat": "47.16177",
    "lng": "-122.35707"
  },
  {
    "country": "US",
    "name": "Sumner",
    "lat": "47.20316",
    "lng": "-122.2404"
  },
  {
    "country": "US",
    "name": "Sunnyside",
    "lat": "46.32374",
    "lng": "-120.00865"
  },
  {
    "country": "US",
    "name": "Sunnyslope",
    "lat": "47.4729",
    "lng": "-120.33674"
  },
  {
    "country": "US",
    "name": "Suquamish",
    "lat": "47.73121",
    "lng": "-122.55236"
  },
  {
    "country": "US",
    "name": "Tacoma",
    "lat": "47.25288",
    "lng": "-122.44429"
  },
  {
    "country": "US",
    "name": "Tanner",
    "lat": "47.47538",
    "lng": "-121.74622"
  },
  {
    "country": "US",
    "name": "Tenino",
    "lat": "46.85677",
    "lng": "-122.85291"
  },
  {
    "country": "US",
    "name": "Terrace Heights",
    "lat": "46.60624",
    "lng": "-120.43979"
  },
  {
    "country": "US",
    "name": "Three Lakes",
    "lat": "47.94482",
    "lng": "-122.01152"
  },
  {
    "country": "US",
    "name": "Tieton",
    "lat": "46.70207",
    "lng": "-120.75535"
  },
  {
    "country": "US",
    "name": "Tonasket",
    "lat": "48.70515",
    "lng": "-119.4395"
  },
  {
    "country": "US",
    "name": "Toppenish",
    "lat": "46.37735",
    "lng": "-120.30867"
  },
  {
    "country": "US",
    "name": "Town and Country",
    "lat": "47.72739",
    "lng": "-117.42161"
  },
  {
    "country": "US",
    "name": "Tracyton",
    "lat": "47.60898",
    "lng": "-122.65514"
  },
  {
    "country": "US",
    "name": "Trentwood",
    "lat": "47.69656",
    "lng": "-117.21076"
  },
  {
    "country": "US",
    "name": "Tukwila",
    "lat": "47.47399",
    "lng": "-122.26096"
  },
  {
    "country": "US",
    "name": "Tulalip",
    "lat": "48.06843",
    "lng": "-122.29181"
  },
  {
    "country": "US",
    "name": "Tulalip Bay",
    "lat": "48.03732",
    "lng": "-122.31014"
  },
  {
    "country": "US",
    "name": "Tumwater",
    "lat": "47.00732",
    "lng": "-122.90931"
  },
  {
    "country": "US",
    "name": "Union Gap",
    "lat": "46.55735",
    "lng": "-120.47506"
  },
  {
    "country": "US",
    "name": "University Place",
    "lat": "47.23565",
    "lng": "-122.5504"
  },
  {
    "country": "US",
    "name": "Vancouver",
    "lat": "45.63873",
    "lng": "-122.66149"
  },
  {
    "country": "US",
    "name": "Vashon",
    "lat": "47.44732",
    "lng": "-122.45985"
  },
  {
    "country": "US",
    "name": "Veradale",
    "lat": "47.64995",
    "lng": "-117.20738"
  },
  {
    "country": "US",
    "name": "Venersborg",
    "lat": "45.77373",
    "lng": "-122.42454"
  },
  {
    "country": "US",
    "name": "Waitsburg",
    "lat": "46.27042",
    "lng": "-118.15329"
  },
  {
    "country": "US",
    "name": "Walla Walla",
    "lat": "46.06458",
    "lng": "-118.34302"
  },
  {
    "country": "US",
    "name": "Waller",
    "lat": "47.20066",
    "lng": "-122.36929"
  },
  {
    "country": "US",
    "name": "Walnut Grove",
    "lat": "45.66789",
    "lng": "-122.59899"
  },
  {
    "country": "US",
    "name": "Wapato",
    "lat": "46.44763",
    "lng": "-120.42034"
  },
  {
    "country": "US",
    "name": "Warden",
    "lat": "46.96764",
    "lng": "-119.03973"
  },
  {
    "country": "US",
    "name": "Warm Beach",
    "lat": "48.17065",
    "lng": "-122.3646"
  },
  {
    "country": "US",
    "name": "Washougal",
    "lat": "45.58262",
    "lng": "-122.35342"
  },
  {
    "country": "US",
    "name": "Waterville",
    "lat": "47.64708",
    "lng": "-120.07118"
  },
  {
    "country": "US",
    "name": "Wauna",
    "lat": "47.37899",
    "lng": "-122.64263"
  },
  {
    "country": "US",
    "name": "Wenatchee",
    "lat": "47.42346",
    "lng": "-120.31035"
  },
  {
    "country": "US",
    "name": "West Lake Sammamish",
    "lat": "47.5776",
    "lng": "-122.10123"
  },
  {
    "country": "US",
    "name": "West Lake Stevens",
    "lat": "47.99343",
    "lng": "-122.1018"
  },
  {
    "country": "US",
    "name": "West Longview",
    "lat": "46.16789",
    "lng": "-122.999"
  },
  {
    "country": "US",
    "name": "West Pasco",
    "lat": "46.24541",
    "lng": "-119.18279"
  },
  {
    "country": "US",
    "name": "West Richland",
    "lat": "46.3043",
    "lng": "-119.36141"
  },
  {
    "country": "US",
    "name": "West Valley",
    "lat": "46.59207",
    "lng": "-120.60507"
  },
  {
    "country": "US",
    "name": "West Wenatchee",
    "lat": "47.44374",
    "lng": "-120.35341"
  },
  {
    "country": "US",
    "name": "Westport",
    "lat": "46.89009",
    "lng": "-124.10406"
  },
  {
    "country": "US",
    "name": "White Center",
    "lat": "47.51732",
    "lng": "-122.35485"
  },
  {
    "country": "US",
    "name": "White Salmon",
    "lat": "45.72762",
    "lng": "-121.48646"
  },
  {
    "country": "US",
    "name": "Winlock",
    "lat": "46.49122",
    "lng": "-122.9379"
  },
  {
    "country": "US",
    "name": "Bainbridge Island",
    "lat": "47.62621",
    "lng": "-122.52124"
  },
  {
    "country": "US",
    "name": "Wollochet",
    "lat": "47.26871",
    "lng": "-122.58402"
  },
  {
    "country": "US",
    "name": "Woodinville",
    "lat": "47.75427",
    "lng": "-122.16346"
  },
  {
    "country": "US",
    "name": "Woodland",
    "lat": "45.90456",
    "lng": "-122.74399"
  },
  {
    "country": "US",
    "name": "Woods Creek",
    "lat": "47.87871",
    "lng": "-121.89846"
  },
  {
    "country": "US",
    "name": "Woodway",
    "lat": "47.79621",
    "lng": "-122.38291"
  },
  {
    "country": "US",
    "name": "Yacolt",
    "lat": "45.86595",
    "lng": "-122.40621"
  },
  {
    "country": "US",
    "name": "Yakima",
    "lat": "46.60207",
    "lng": "-120.5059"
  },
  {
    "country": "US",
    "name": "Yarrow Point",
    "lat": "47.64621",
    "lng": "-122.21735"
  },
  {
    "country": "US",
    "name": "Yelm",
    "lat": "46.94204",
    "lng": "-122.60596"
  },
  {
    "country": "US",
    "name": "Zillah",
    "lat": "46.40207",
    "lng": "-120.262"
  },
  {
    "country": "US",
    "name": "Afton",
    "lat": "42.72493",
    "lng": "-110.93187"
  },
  {
    "country": "US",
    "name": "Arapahoe",
    "lat": "42.96218",
    "lng": "-108.48983"
  },
  {
    "country": "US",
    "name": "Bar Nunn",
    "lat": "42.91358",
    "lng": "-106.34336"
  },
  {
    "country": "US",
    "name": "Basin",
    "lat": "44.37996",
    "lng": "-108.03899"
  },
  {
    "country": "US",
    "name": "Buffalo",
    "lat": "44.34831",
    "lng": "-106.69894"
  },
  {
    "country": "US",
    "name": "Casper",
    "lat": "42.86663",
    "lng": "-106.31308"
  },
  {
    "country": "US",
    "name": "Cheyenne",
    "lat": "41.13998",
    "lng": "-104.82025"
  },
  {
    "country": "US",
    "name": "Cody",
    "lat": "44.52634",
    "lng": "-109.05653"
  },
  {
    "country": "US",
    "name": "Douglas",
    "lat": "42.75969",
    "lng": "-105.38221"
  },
  {
    "country": "US",
    "name": "Ethete",
    "lat": "43.02496",
    "lng": "-108.77262"
  },
  {
    "country": "US",
    "name": "Evanston",
    "lat": "41.26828",
    "lng": "-110.96324"
  },
  {
    "country": "US",
    "name": "Evansville",
    "lat": "42.85997",
    "lng": "-106.26836"
  },
  {
    "country": "US",
    "name": "Fort Washakie",
    "lat": "43.00635",
    "lng": "-108.88235"
  },
  {
    "country": "US",
    "name": "Gillette",
    "lat": "44.29109",
    "lng": "-105.50222"
  },
  {
    "country": "US",
    "name": "Glenrock",
    "lat": "42.86136",
    "lng": "-105.87223"
  },
  {
    "country": "US",
    "name": "Green River",
    "lat": "41.52858",
    "lng": "-109.46625"
  },
  {
    "country": "US",
    "name": "Greybull",
    "lat": "44.48912",
    "lng": "-108.05621"
  },
  {
    "country": "US",
    "name": "Guernsey",
    "lat": "42.26969",
    "lng": "-104.74163"
  },
  {
    "country": "US",
    "name": "Hoback",
    "lat": "43.28187",
    "lng": "-110.78381"
  },
  {
    "country": "US",
    "name": "Jackson",
    "lat": "43.47993",
    "lng": "-110.76243"
  },
  {
    "country": "US",
    "name": "Kemmerer",
    "lat": "41.79245",
    "lng": "-110.53767"
  },
  {
    "country": "US",
    "name": "Lander",
    "lat": "42.83301",
    "lng": "-108.73067"
  },
  {
    "country": "US",
    "name": "Laramie",
    "lat": "41.31137",
    "lng": "-105.5911"
  },
  {
    "country": "US",
    "name": "Lovell",
    "lat": "44.83745",
    "lng": "-108.38956"
  },
  {
    "country": "US",
    "name": "Lusk",
    "lat": "42.76247",
    "lng": "-104.45217"
  },
  {
    "country": "US",
    "name": "Lyman",
    "lat": "41.32745",
    "lng": "-110.29293"
  },
  {
    "country": "US",
    "name": "Marbleton",
    "lat": "42.55355",
    "lng": "-110.10932"
  },
  {
    "country": "US",
    "name": "Mills",
    "lat": "42.84052",
    "lng": "-106.36586"
  },
  {
    "country": "US",
    "name": "Moorcroft",
    "lat": "44.26331",
    "lng": "-104.95025"
  },
  {
    "country": "US",
    "name": "Moose Wilson Road",
    "lat": "43.52521",
    "lng": "-110.84466"
  },
  {
    "country": "US",
    "name": "Mountain View",
    "lat": "41.26884",
    "lng": "-110.33988"
  },
  {
    "country": "US",
    "name": "Newcastle",
    "lat": "43.8547",
    "lng": "-104.20494"
  },
  {
    "country": "US",
    "name": "North Rock Springs",
    "lat": "41.64358",
    "lng": "-109.26568"
  },
  {
    "country": "US",
    "name": "Pine Bluffs",
    "lat": "41.18193",
    "lng": "-104.06912"
  },
  {
    "country": "US",
    "name": "Pinedale",
    "lat": "42.86661",
    "lng": "-109.86099"
  },
  {
    "country": "US",
    "name": "Powell",
    "lat": "44.75384",
    "lng": "-108.75735"
  },
  {
    "country": "US",
    "name": "Rafter J Ranch",
    "lat": "43.42604",
    "lng": "-110.79909"
  },
  {
    "country": "US",
    "name": "Ranchettes",
    "lat": "41.21859",
    "lng": "-104.79025"
  },
  {
    "country": "US",
    "name": "Rawlins",
    "lat": "41.79107",
    "lng": "-107.23866"
  },
  {
    "country": "US",
    "name": "Riverton",
    "lat": "43.02496",
    "lng": "-108.3801"
  },
  {
    "country": "US",
    "name": "Rock Springs",
    "lat": "41.58746",
    "lng": "-109.2029"
  },
  {
    "country": "US",
    "name": "Saratoga",
    "lat": "41.45496",
    "lng": "-106.80643"
  },
  {
    "country": "US",
    "name": "Sheridan",
    "lat": "44.79719",
    "lng": "-106.95618"
  },
  {
    "country": "US",
    "name": "Sleepy Hollow",
    "lat": "44.24109",
    "lng": "-105.42222"
  },
  {
    "country": "US",
    "name": "South Greeley",
    "lat": "41.09693",
    "lng": "-104.80636"
  },
  {
    "country": "US",
    "name": "South Park",
    "lat": "43.42215",
    "lng": "-110.79326"
  },
  {
    "country": "US",
    "name": "Sundance",
    "lat": "44.40637",
    "lng": "-104.37578"
  },
  {
    "country": "US",
    "name": "Thermopolis",
    "lat": "43.64607",
    "lng": "-108.21204"
  },
  {
    "country": "US",
    "name": "Torrington",
    "lat": "42.06246",
    "lng": "-104.18439"
  },
  {
    "country": "US",
    "name": "Upton",
    "lat": "44.0997",
    "lng": "-104.62802"
  },
  {
    "country": "US",
    "name": "Wheatland",
    "lat": "42.05407",
    "lng": "-104.95295"
  },
  {
    "country": "US",
    "name": "Wilson",
    "lat": "43.50076",
    "lng": "-110.87521"
  },
  {
    "country": "US",
    "name": "Worland",
    "lat": "44.0169",
    "lng": "-107.95537"
  },
  {
    "country": "US",
    "name": "Wright",
    "lat": "43.75124",
    "lng": "-105.49201"
  },
  {
    "country": "US",
    "name": "Vineyard",
    "lat": "40.29704",
    "lng": "-111.7467"
  },
  {
    "country": "US",
    "name": "Fruitdale",
    "lat": "42.42206",
    "lng": "-123.30811"
  },
  {
    "country": "US",
    "name": "Gold Beach",
    "lat": "42.40733",
    "lng": "-124.42177"
  },
  {
    "country": "US",
    "name": "American Fork",
    "lat": "40.3769",
    "lng": "-111.79576"
  },
  {
    "country": "US",
    "name": "Palouse",
    "lat": "46.91017",
    "lng": "-117.07573"
  },
  {
    "country": "US",
    "name": "Craig",
    "lat": "55.47639",
    "lng": "-133.14833"
  },
  {
    "country": "US",
    "name": "Haines",
    "lat": "59.23595",
    "lng": "-135.44533"
  },
  {
    "country": "US",
    "name": "Kahalu‘u",
    "lat": "21.45759",
    "lng": "-157.84431"
  },
  {
    "country": "US",
    "name": "Kahuku",
    "lat": "21.68048",
    "lng": "-157.95237"
  },
  {
    "country": "US",
    "name": "Kahului",
    "lat": "20.88953",
    "lng": "-156.47432"
  },
  {
    "country": "US",
    "name": "Kailua",
    "lat": "21.40241",
    "lng": "-157.74054"
  },
  {
    "country": "US",
    "name": "Kailua-Kona",
    "lat": "19.64016",
    "lng": "-155.99912"
  },
  {
    "country": "US",
    "name": "Kalāheo",
    "lat": "21.92416",
    "lng": "-159.52686"
  },
  {
    "country": "US",
    "name": "Kalaoa",
    "lat": "19.72861",
    "lng": "-155.98167"
  },
  {
    "country": "US",
    "name": "Kaneohe",
    "lat": "21.39994",
    "lng": "-157.79895"
  },
  {
    "country": "US",
    "name": "Kapa‘a",
    "lat": "22.07521",
    "lng": "-159.31895"
  },
  {
    "country": "US",
    "name": "Kapaau",
    "lat": "20.23389",
    "lng": "-155.80194"
  },
  {
    "country": "US",
    "name": "Kaunakakai",
    "lat": "21.09363",
    "lng": "-157.02613"
  },
  {
    "country": "US",
    "name": "Kea‘au",
    "lat": "19.62265",
    "lng": "-155.03744"
  },
  {
    "country": "US",
    "name": "Kealakekua",
    "lat": "19.52083",
    "lng": "-155.9225"
  },
  {
    "country": "US",
    "name": "Kekaha",
    "lat": "21.96686",
    "lng": "-159.71186"
  },
  {
    "country": "US",
    "name": "Kēōkea",
    "lat": "20.70711",
    "lng": "-156.35446"
  },
  {
    "country": "US",
    "name": "Kīhei",
    "lat": "20.76462",
    "lng": "-156.44578"
  },
  {
    "country": "US",
    "name": "Kīlauea",
    "lat": "22.21208",
    "lng": "-159.41342"
  },
  {
    "country": "US",
    "name": "Koloa",
    "lat": "21.9069",
    "lng": "-159.46994"
  },
  {
    "country": "US",
    "name": "Kualapu‘u",
    "lat": "21.15306",
    "lng": "-157.03677"
  },
  {
    "country": "US",
    "name": "Kurtistown",
    "lat": "19.60361",
    "lng": "-155.05722"
  },
  {
    "country": "US",
    "name": "Lahaina",
    "lat": "20.87429",
    "lng": "-156.67663"
  },
  {
    "country": "US",
    "name": "Lā‘ie",
    "lat": "21.64547",
    "lng": "-157.9225"
  },
  {
    "country": "US",
    "name": "Lanai City",
    "lat": "20.82757",
    "lng": "-156.92399"
  },
  {
    "country": "US",
    "name": "Lawai",
    "lat": "21.92159",
    "lng": "-159.50376"
  },
  {
    "country": "US",
    "name": "Leilani Estates",
    "lat": "19.46972",
    "lng": "-154.91778"
  },
  {
    "country": "US",
    "name": "Lihue",
    "lat": "21.98121",
    "lng": "-159.3721"
  },
  {
    "country": "US",
    "name": "Mā‘ili",
    "lat": "21.41629",
    "lng": "-158.17531"
  },
  {
    "country": "US",
    "name": "Mākaha",
    "lat": "21.46627",
    "lng": "-158.21037"
  },
  {
    "country": "US",
    "name": "Mākaha Valley",
    "lat": "21.47583",
    "lng": "-158.19918"
  },
  {
    "country": "US",
    "name": "Makakilo City",
    "lat": "21.34694",
    "lng": "-158.08583"
  },
  {
    "country": "US",
    "name": "Makawao",
    "lat": "20.85694",
    "lng": "-156.31306"
  },
  {
    "country": "US",
    "name": "Maunawili",
    "lat": "21.37278",
    "lng": "-157.77056"
  },
  {
    "country": "US",
    "name": "Mililani Town",
    "lat": "21.45",
    "lng": "-158.00111"
  },
  {
    "country": "US",
    "name": "Mokulēia",
    "lat": "21.57967",
    "lng": "-158.15313"
  },
  {
    "country": "US",
    "name": "Mountain View",
    "lat": "19.55583",
    "lng": "-155.10806"
  },
  {
    "country": "US",
    "name": "Nānākuli",
    "lat": "21.39362",
    "lng": "-158.15429"
  },
  {
    "country": "US",
    "name": "Nanawale Estates",
    "lat": "19.50611",
    "lng": "-154.91194"
  },
  {
    "country": "US",
    "name": "‘Ōma‘o",
    "lat": "21.92581",
    "lng": "-159.48818"
  },
  {
    "country": "US",
    "name": "Orchidlands Estates",
    "lat": "19.56084",
    "lng": "-155.01527"
  },
  {
    "country": "US",
    "name": "Pāhala",
    "lat": "19.20297",
    "lng": "-155.4786"
  },
  {
    "country": "US",
    "name": "Paia",
    "lat": "20.90333",
    "lng": "-156.36944"
  },
  {
    "country": "US",
    "name": "Pāpa‘ikou",
    "lat": "19.78718",
    "lng": "-155.09326"
  },
  {
    "country": "US",
    "name": "Pearl City",
    "lat": "21.39734",
    "lng": "-157.97516"
  },
  {
    "country": "US",
    "name": "Pepeekeo",
    "lat": "19.83361",
    "lng": "-155.10722"
  },
  {
    "country": "US",
    "name": "Princeville",
    "lat": "22.21758",
    "lng": "-159.47888"
  },
  {
    "country": "US",
    "name": "Puhi",
    "lat": "21.96888",
    "lng": "-159.40012"
  },
  {
    "country": "US",
    "name": "Pukalani",
    "lat": "20.83667",
    "lng": "-156.33667"
  },
  {
    "country": "US",
    "name": "Punalu‘u",
    "lat": "21.57045",
    "lng": "-157.87557"
  },
  {
    "country": "US",
    "name": "Punaluu",
    "lat": "21.57389",
    "lng": "-157.87861"
  },
  {
    "country": "US",
    "name": "Pupukea",
    "lat": "21.65456",
    "lng": "-158.06065"
  },
  {
    "country": "US",
    "name": "Village Park",
    "lat": "21.39806",
    "lng": "-158.03028"
  },
  {
    "country": "US",
    "name": "Volcano",
    "lat": "19.44276",
    "lng": "-155.23398"
  },
  {
    "country": "US",
    "name": "Wahiawā",
    "lat": "21.50279",
    "lng": "-158.02464"
  },
  {
    "country": "US",
    "name": "Waialua",
    "lat": "21.57688",
    "lng": "-158.13154"
  },
  {
    "country": "US",
    "name": "Waialua",
    "lat": "21.10028",
    "lng": "-156.76139"
  },
  {
    "country": "US",
    "name": "Waianae",
    "lat": "21.43621",
    "lng": "-158.1863"
  },
  {
    "country": "US",
    "name": "Waikapū",
    "lat": "20.85806",
    "lng": "-156.50694"
  },
  {
    "country": "US",
    "name": "Waikoloa",
    "lat": "19.93942",
    "lng": "-155.78931"
  },
  {
    "country": "US",
    "name": "Wailea",
    "lat": "20.68973",
    "lng": "-156.4419"
  },
  {
    "country": "US",
    "name": "Wailua",
    "lat": "22.05271",
    "lng": "-159.33781"
  },
  {
    "country": "US",
    "name": "Wailua",
    "lat": "20.84861",
    "lng": "-156.13639"
  },
  {
    "country": "US",
    "name": "Wailuku",
    "lat": "20.89133",
    "lng": "-156.50604"
  },
  {
    "country": "US",
    "name": "Waimalu",
    "lat": "21.40472",
    "lng": "-157.94333"
  },
  {
    "country": "US",
    "name": "Waimanalo",
    "lat": "21.34614",
    "lng": "-157.7238"
  },
  {
    "country": "US",
    "name": "Waimānalo Beach",
    "lat": "21.33407",
    "lng": "-157.70003"
  },
  {
    "country": "US",
    "name": "Waimea",
    "lat": "21.95707",
    "lng": "-159.66893"
  },
  {
    "country": "US",
    "name": "Waimea",
    "lat": "20.02323",
    "lng": "-155.67288"
  },
  {
    "country": "US",
    "name": "Wainaku",
    "lat": "19.74472",
    "lng": "-155.095"
  },
  {
    "country": "US",
    "name": "Waipahu",
    "lat": "21.38667",
    "lng": "-158.00917"
  },
  {
    "country": "US",
    "name": "Waipio",
    "lat": "21.41823",
    "lng": "-157.99906"
  },
  {
    "country": "US",
    "name": "Waipi‘o Acres",
    "lat": "21.46485",
    "lng": "-158.01331"
  },
  {
    "country": "US",
    "name": "Whitmore Village",
    "lat": "21.51429",
    "lng": "-158.02464"
  },
  {
    "country": "US",
    "name": "‘Ele‘ele",
    "lat": "21.90738",
    "lng": "-159.58322"
  },
  {
    "country": "US",
    "name": "‘Ewa Beach",
    "lat": "21.31556",
    "lng": "-158.00722"
  },
  {
    "country": "US",
    "name": "‘Ewa Gentry",
    "lat": "21.33999",
    "lng": "-158.03039"
  },
  {
    "country": "US",
    "name": "‘Ewa Villages",
    "lat": "21.34127",
    "lng": "-158.0397"
  },
  {
    "country": "US",
    "name": "Fern Acres",
    "lat": "19.51222",
    "lng": "-155.08028"
  },
  {
    "country": "US",
    "name": "Hālawa",
    "lat": "21.37944",
    "lng": "-157.92167"
  },
  {
    "country": "US",
    "name": "Hālawa Heights",
    "lat": "21.37848",
    "lng": "-157.91388"
  },
  {
    "country": "US",
    "name": "Hale‘iwa",
    "lat": "21.59284",
    "lng": "-158.10339"
  },
  {
    "country": "US",
    "name": "Hana",
    "lat": "20.75806",
    "lng": "-155.99028"
  },
  {
    "country": "US",
    "name": "Hanamā‘ulu",
    "lat": "21.99773",
    "lng": "-159.35918"
  },
  {
    "country": "US",
    "name": "Hanapēpē",
    "lat": "21.90733",
    "lng": "-159.5944"
  },
  {
    "country": "US",
    "name": "Hanapēpē Heights",
    "lat": "21.91633",
    "lng": "-159.58995"
  },
  {
    "country": "US",
    "name": "Hau‘ula",
    "lat": "21.6076",
    "lng": "-157.90868"
  },
  {
    "country": "US",
    "name": "Hawaiian Beaches",
    "lat": "19.54306",
    "lng": "-154.91583"
  },
  {
    "country": "US",
    "name": "Hawaiian Acres",
    "lat": "19.53806",
    "lng": "-155.05222"
  },
  {
    "country": "US",
    "name": "Hawaiian Paradise Park",
    "lat": "19.59333",
    "lng": "-154.97306"
  },
  {
    "country": "US",
    "name": "Hawaiian Ocean View",
    "lat": "19.06861",
    "lng": "-155.765"
  },
  {
    "country": "US",
    "name": "Hāwī",
    "lat": "20.24122",
    "lng": "-155.83351"
  },
  {
    "country": "US",
    "name": "He‘eia",
    "lat": "21.43054",
    "lng": "-157.81611"
  },
  {
    "country": "US",
    "name": "Hilo",
    "lat": "19.72991",
    "lng": "-155.09073"
  },
  {
    "country": "US",
    "name": "Hōlualoa",
    "lat": "19.61979",
    "lng": "-155.94831"
  },
  {
    "country": "US",
    "name": "Honalo",
    "lat": "19.54639",
    "lng": "-155.93194"
  },
  {
    "country": "US",
    "name": "Honoka‘a",
    "lat": "20.07931",
    "lng": "-155.46691"
  },
  {
    "country": "US",
    "name": "Honolulu",
    "lat": "21.30694",
    "lng": "-157.85833"
  },
  {
    "country": "US",
    "name": "‘Aiea",
    "lat": "21.38222",
    "lng": "-157.93361"
  },
  {
    "country": "US",
    "name": "‘Āhuimanu",
    "lat": "21.44472",
    "lng": "-157.83778"
  },
  {
    "country": "US",
    "name": "Iroquois Point",
    "lat": "21.32776",
    "lng": "-157.98301"
  },
  {
    "country": "US",
    "name": "Ka‘a‘awa",
    "lat": "21.55445",
    "lng": "-157.85103"
  },
  {
    "country": "US",
    "name": "Kā‘anapali",
    "lat": "20.92881",
    "lng": "-156.69422"
  },
  {
    "country": "US",
    "name": "Kaanapali Landing",
    "lat": "20.9309",
    "lng": "-156.68778"
  },
  {
    "country": "US",
    "name": "Ainaloa",
    "lat": "19.52694",
    "lng": "-154.99306"
  },
  {
    "country": "US",
    "name": "Anahola",
    "lat": "22.14226",
    "lng": "-159.31388"
  },
  {
    "country": "US",
    "name": "Captain Cook",
    "lat": "19.49694",
    "lng": "-155.92167"
  },
  {
    "country": "US",
    "name": "Butte",
    "lat": "61.54222",
    "lng": "-149.03333"
  },
  {
    "country": "US",
    "name": "Chevak",
    "lat": "61.52778",
    "lng": "-165.58639"
  },
  {
    "country": "US",
    "name": "Cohoe",
    "lat": "60.36861",
    "lng": "-151.30639"
  },
  {
    "country": "US",
    "name": "College",
    "lat": "64.85694",
    "lng": "-147.80278"
  },
  {
    "country": "US",
    "name": "Cordova",
    "lat": "60.5432",
    "lng": "-145.75867"
  },
  {
    "country": "US",
    "name": "Diamond Ridge",
    "lat": "59.67611",
    "lng": "-151.5575"
  },
  {
    "country": "US",
    "name": "Dillingham",
    "lat": "59.03972",
    "lng": "-158.4575"
  },
  {
    "country": "US",
    "name": "Dutch Harbor",
    "lat": "53.8898",
    "lng": "-166.5422"
  },
  {
    "country": "US",
    "name": "Eagle River",
    "lat": "61.32139",
    "lng": "-149.56778"
  },
  {
    "country": "US",
    "name": "Ester",
    "lat": "64.84722",
    "lng": "-148.01444"
  },
  {
    "country": "US",
    "name": "Fairbanks",
    "lat": "64.83778",
    "lng": "-147.71639"
  },
  {
    "country": "US",
    "name": "Fritz Creek",
    "lat": "59.73611",
    "lng": "-151.29528"
  },
  {
    "country": "US",
    "name": "Gateway",
    "lat": "61.57278",
    "lng": "-149.24083"
  },
  {
    "country": "US",
    "name": "Girdwood",
    "lat": "60.9425",
    "lng": "-149.16639"
  },
  {
    "country": "US",
    "name": "Healy",
    "lat": "63.85694",
    "lng": "-148.96611"
  },
  {
    "country": "US",
    "name": "Homer",
    "lat": "59.6425",
    "lng": "-151.5494"
  },
  {
    "country": "US",
    "name": "Hooper Bay",
    "lat": "61.53111",
    "lng": "-166.09667"
  },
  {
    "country": "US",
    "name": "Houston",
    "lat": "61.63028",
    "lng": "-149.81806"
  },
  {
    "country": "US",
    "name": "Kalifornsky",
    "lat": "60.41833",
    "lng": "-151.29"
  },
  {
    "country": "US",
    "name": "Kenai",
    "lat": "60.55444",
    "lng": "-151.25833"
  },
  {
    "country": "US",
    "name": "King Cove",
    "lat": "55.06087",
    "lng": "-162.31853"
  },
  {
    "country": "US",
    "name": "Kodiak",
    "lat": "57.79",
    "lng": "-152.40722"
  },
  {
    "country": "US",
    "name": "Kotzebue",
    "lat": "66.89846",
    "lng": "-162.59809"
  },
  {
    "country": "US",
    "name": "Lazy Mountain",
    "lat": "61.62611",
    "lng": "-148.94556"
  },
  {
    "country": "US",
    "name": "Meadow Lakes",
    "lat": "61.62472",
    "lng": "-149.60111"
  },
  {
    "country": "US",
    "name": "Nikiski",
    "lat": "60.69028",
    "lng": "-151.28889"
  },
  {
    "country": "US",
    "name": "Nome",
    "lat": "64.50111",
    "lng": "-165.40639"
  },
  {
    "country": "US",
    "name": "North Pole",
    "lat": "64.75111",
    "lng": "-147.34944"
  },
  {
    "country": "US",
    "name": "Palmer",
    "lat": "61.59941",
    "lng": "-149.11456"
  },
  {
    "country": "US",
    "name": "Prudhoe Bay",
    "lat": "70.25528",
    "lng": "-148.33722"
  },
  {
    "country": "US",
    "name": "Ridgeway",
    "lat": "60.53194",
    "lng": "-151.08528"
  },
  {
    "country": "US",
    "name": "Sand Point",
    "lat": "55.33655",
    "lng": "-160.4988"
  },
  {
    "country": "US",
    "name": "Seward",
    "lat": "60.10426",
    "lng": "-149.4435"
  },
  {
    "country": "US",
    "name": "Soldotna",
    "lat": "60.48778",
    "lng": "-151.05833"
  },
  {
    "country": "US",
    "name": "Sterling",
    "lat": "60.53722",
    "lng": "-150.76472"
  },
  {
    "country": "US",
    "name": "Tanaina",
    "lat": "61.62694",
    "lng": "-149.42806"
  },
  {
    "country": "US",
    "name": "Tok",
    "lat": "63.33667",
    "lng": "-142.98556"
  },
  {
    "country": "US",
    "name": "Unalaska",
    "lat": "53.87361",
    "lng": "-166.53667"
  },
  {
    "country": "US",
    "name": "Valdez",
    "lat": "61.13083",
    "lng": "-146.34833"
  },
  {
    "country": "US",
    "name": "Wasilla",
    "lat": "61.5809",
    "lng": "-149.4415"
  },
  {
    "country": "US",
    "name": "Willow",
    "lat": "61.74722",
    "lng": "-150.0375"
  },
  {
    "country": "US",
    "name": "Akutan",
    "lat": "54.1335",
    "lng": "-165.77686"
  },
  {
    "country": "US",
    "name": "Anchorage",
    "lat": "61.21806",
    "lng": "-149.90028"
  },
  {
    "country": "US",
    "name": "Anchor Point",
    "lat": "59.77667",
    "lng": "-151.83139"
  },
  {
    "country": "US",
    "name": "Badger",
    "lat": "64.8",
    "lng": "-147.53333"
  },
  {
    "country": "US",
    "name": "Barrow",
    "lat": "71.29058",
    "lng": "-156.78872"
  },
  {
    "country": "US",
    "name": "Bear Creek",
    "lat": "60.16417",
    "lng": "-149.395"
  },
  {
    "country": "US",
    "name": "Bethel",
    "lat": "60.79222",
    "lng": "-161.75583"
  },
  {
    "country": "US",
    "name": "Big Lake",
    "lat": "61.52139",
    "lng": "-149.95444"
  },
  {
    "country": "US",
    "name": "Milton",
    "lat": "34.13216",
    "lng": "-84.30067"
  },
  {
    "country": "US",
    "name": "Johns Creek",
    "lat": "34.02893",
    "lng": "-84.19858"
  },
  {
    "country": "US",
    "name": "Grant-Valkaria",
    "lat": "27.9398",
    "lng": "-80.57104"
  },
  {
    "country": "US",
    "name": "Helena-West Helena",
    "lat": "34.5291",
    "lng": "-90.59"
  },
  {
    "country": "US",
    "name": "Summerset",
    "lat": "44.18998",
    "lng": "-103.34384"
  },
  {
    "country": "US",
    "name": "Columbus",
    "lat": "45.26522",
    "lng": "-93.05015"
  },
  {
    "country": "US",
    "name": "Cutler Bay",
    "lat": "25.5783",
    "lng": "-80.3377"
  },
  {
    "country": "US",
    "name": "Morningside Heights",
    "lat": "40.81",
    "lng": "-73.9625"
  },
  {
    "country": "US",
    "name": "East Harlem",
    "lat": "40.79472",
    "lng": "-73.9425"
  },
  {
    "country": "US",
    "name": "Alafaya",
    "lat": "28.5641",
    "lng": "-81.2114"
  },
  {
    "country": "US",
    "name": "New Fairview",
    "lat": "33.09917",
    "lng": "-97.44639"
  },
  {
    "country": "US",
    "name": "Cobb Island",
    "lat": "38.25846",
    "lng": "-76.84386"
  },
  {
    "country": "US",
    "name": "St Johnsbury",
    "lat": "44.42526",
    "lng": "-72.01512"
  },
  {
    "country": "US",
    "name": "Dayton",
    "lat": "43.54972",
    "lng": "-70.57555"
  },
  {
    "country": "US",
    "name": "Briarwood",
    "lat": "40.70935",
    "lng": "-73.81529"
  },
  {
    "country": "US",
    "name": "Stevenson Ranch",
    "lat": "34.39048",
    "lng": "-118.57372"
  },
  {
    "country": "US",
    "name": "Holly Lake Ranch",
    "lat": "32.71336",
    "lng": "-95.19756"
  },
  {
    "country": "US",
    "name": "Village of Campton Hills",
    "lat": "41.9366",
    "lng": "-88.3975"
  },
  {
    "country": "US",
    "name": "Fort Bragg",
    "lat": "35.139",
    "lng": "-79.00603"
  },
  {
    "country": "US",
    "name": "Kapolei",
    "lat": "21.33555",
    "lng": "-158.0582"
  },
  {
    "country": "US",
    "name": "Elko New Market",
    "lat": "44.56472",
    "lng": "-93.32694"
  },
  {
    "country": "US",
    "name": "South Blooming Grove",
    "lat": "41.37337",
    "lng": "-74.17843"
  },
  {
    "country": "US",
    "name": "Dewey-Humboldt",
    "lat": "34.53",
    "lng": "-112.24222"
  },
  {
    "country": "US",
    "name": "City of Milford (balance)",
    "lat": "41.22374",
    "lng": "-73.06164"
  },
  {
    "country": "US",
    "name": "Peppermill Village",
    "lat": "38.89472",
    "lng": "-76.88654"
  },
  {
    "country": "US",
    "name": "Boulevard Gardens",
    "lat": "26.12326",
    "lng": "-80.17997"
  },
  {
    "country": "US",
    "name": "High Point",
    "lat": "28.54687",
    "lng": "-82.52468"
  },
  {
    "country": "US",
    "name": "Roosevelt Gardens",
    "lat": "26.14087",
    "lng": "-80.18027"
  },
  {
    "country": "US",
    "name": "Butte-Silver Bow (Balance)",
    "lat": "45.90194",
    "lng": "-112.65708"
  },
  {
    "country": "US",
    "name": "City of Sammamish",
    "lat": "47.60444",
    "lng": "-122.03768"
  },
  {
    "country": "US",
    "name": "Bayview",
    "lat": "38.00702",
    "lng": "-122.31878"
  },
  {
    "country": "US",
    "name": "Las Maravillas",
    "lat": "34.73815",
    "lng": "-106.66854"
  },
  {
    "country": "US",
    "name": "Monterey Park",
    "lat": "34.75898",
    "lng": "-106.64085"
  },
  {
    "country": "US",
    "name": "Peaceful Valley",
    "lat": "48.93815",
    "lng": "-122.14733"
  },
  {
    "country": "US",
    "name": "Rancho Tehama Reserve",
    "lat": "40.01569",
    "lng": "-122.40072"
  },
  {
    "country": "US",
    "name": "Rio Communities",
    "lat": "34.64959",
    "lng": "-106.73403"
  },
  {
    "country": "US",
    "name": "Silver Firs",
    "lat": "47.86602",
    "lng": "-122.1551"
  },
  {
    "country": "US",
    "name": "Verde Village",
    "lat": "34.7105",
    "lng": "-112.01152"
  },
  {
    "country": "US",
    "name": "Vineyard",
    "lat": "38.46449",
    "lng": "-121.34692"
  },
  {
    "country": "US",
    "name": "Chattahoochee Hills",
    "lat": "33.55063",
    "lng": "-84.76049"
  },
  {
    "country": "US",
    "name": "Gramercy Park",
    "lat": "40.7375",
    "lng": "-73.98611"
  },
  {
    "country": "US",
    "name": "Desert Edge",
    "lat": "33.92417",
    "lng": "-116.44139"
  },
  {
    "country": "US",
    "name": "Fox Chase",
    "lat": "40.39557",
    "lng": "-75.96216"
  },
  {
    "country": "US",
    "name": "Saint Augustine South",
    "lat": "29.84249",
    "lng": "-81.31448"
  },
  {
    "country": "US",
    "name": "Captains Cove",
    "lat": "37.98996",
    "lng": "-75.42272"
  },
  {
    "country": "US",
    "name": "Weston Lakes",
    "lat": "29.68324",
    "lng": "-95.93571"
  },
  {
    "country": "US",
    "name": "North Castle",
    "lat": "41.14",
    "lng": "-73.68389"
  },
  {
    "country": "US",
    "name": "Saddle Brooke",
    "lat": "32.53472",
    "lng": "-110.87361"
  },
  {
    "country": "US",
    "name": "Kew Gardens Hills",
    "lat": "40.73002",
    "lng": "-73.8234"
  },
  {
    "country": "US",
    "name": "Conning Towers-Nautilus Park",
    "lat": "41.38548",
    "lng": "-72.06877"
  },
  {
    "country": "US",
    "name": "Deep River Center",
    "lat": "41.38221",
    "lng": "-72.43862"
  },
  {
    "country": "US",
    "name": "Essex Village",
    "lat": "41.35544",
    "lng": "-72.39101"
  },
  {
    "country": "US",
    "name": "Guilford Center",
    "lat": "41.28156",
    "lng": "-72.67619"
  },
  {
    "country": "US",
    "name": "Madison Center",
    "lat": "41.27925",
    "lng": "-72.60048"
  },
  {
    "country": "US",
    "name": "New Hartford Center",
    "lat": "41.87996",
    "lng": "-72.9753"
  },
  {
    "country": "US",
    "name": "Northwest Harwinton",
    "lat": "41.77685",
    "lng": "-73.07922"
  },
  {
    "country": "US",
    "name": "Old Saybrook Center",
    "lat": "41.2915",
    "lng": "-72.36528"
  },
  {
    "country": "US",
    "name": "Oxoboxo River",
    "lat": "41.44391",
    "lng": "-72.12502"
  },
  {
    "country": "US",
    "name": "Plainfield Village",
    "lat": "41.67686",
    "lng": "-71.92489"
  },
  {
    "country": "US",
    "name": "Simsbury Center",
    "lat": "41.88088",
    "lng": "-72.81116"
  },
  {
    "country": "US",
    "name": "Wallingford Center",
    "lat": "41.44987",
    "lng": "-72.81892"
  },
  {
    "country": "US",
    "name": "Westbrook Center",
    "lat": "41.27997",
    "lng": "-72.44254"
  },
  {
    "country": "US",
    "name": "Woodbury Center",
    "lat": "41.54453",
    "lng": "-73.20476"
  },
  {
    "country": "US",
    "name": "Acushnet Center",
    "lat": "41.68508",
    "lng": "-70.90642"
  },
  {
    "country": "US",
    "name": "Green Harbor-Cedar Crest",
    "lat": "42.07495",
    "lng": "-70.65843"
  },
  {
    "country": "US",
    "name": "Harwich Center",
    "lat": "41.69235",
    "lng": "-70.06938"
  },
  {
    "country": "US",
    "name": "Hillsborough",
    "lat": "43.1141",
    "lng": "-71.8992"
  },
  {
    "country": "US",
    "name": "Tilton-Northfield",
    "lat": "43.443",
    "lng": "-71.59364"
  },
  {
    "country": "US",
    "name": "Newport East",
    "lat": "41.51579",
    "lng": "-71.28752"
  },
  {
    "country": "US",
    "name": "Wakefield-Peacedale",
    "lat": "41.44606",
    "lng": "-71.5004"
  },
  {
    "country": "US",
    "name": "Mansfield Center",
    "lat": "42.02262",
    "lng": "-71.21808"
  },
  {
    "country": "US",
    "name": "Marion Center",
    "lat": "41.70424",
    "lng": "-70.76286"
  },
  {
    "country": "US",
    "name": "Mattapoisett Center",
    "lat": "41.66595",
    "lng": "-70.8072"
  },
  {
    "country": "US",
    "name": "Middleborough Center",
    "lat": "41.8946",
    "lng": "-70.92618"
  },
  {
    "country": "US",
    "name": "Millis-Clicquot",
    "lat": "42.1648",
    "lng": "-71.35442"
  },
  {
    "country": "US",
    "name": "Monson Center",
    "lat": "42.09898",
    "lng": "-72.30481"
  },
  {
    "country": "US",
    "name": "North Attleborough Center",
    "lat": "41.97263",
    "lng": "-71.32474"
  },
  {
    "country": "US",
    "name": "Northwest Harwich",
    "lat": "41.69029",
    "lng": "-70.1025"
  },
  {
    "country": "US",
    "name": "Norton Center",
    "lat": "41.97254",
    "lng": "-71.18535"
  },
  {
    "country": "US",
    "name": "Ocean Bluff-Brant Rock",
    "lat": "42.10234",
    "lng": "-70.65736"
  },
  {
    "country": "US",
    "name": "Bethlehem Village",
    "lat": "41.6401",
    "lng": "-73.20308"
  },
  {
    "country": "US",
    "name": "Branford Center",
    "lat": "41.27738",
    "lng": "-72.81511"
  },
  {
    "country": "US",
    "name": "Central Waterford",
    "lat": "41.34504",
    "lng": "-72.12948"
  },
  {
    "country": "US",
    "name": "Cheshire Village",
    "lat": "41.5026",
    "lng": "-72.89952"
  },
  {
    "country": "US",
    "name": "Chester Center",
    "lat": "41.40132",
    "lng": "-72.4527"
  },
  {
    "country": "US",
    "name": "Fairview-Ferndale",
    "lat": "40.78037",
    "lng": "-76.57528"
  },
  {
    "country": "US",
    "name": "Fort Belvoir",
    "lat": "38.7119",
    "lng": "-77.14589"
  },
  {
    "country": "US",
    "name": "Fort Drum",
    "lat": "44.05843",
    "lng": "-75.76189"
  },
  {
    "country": "US",
    "name": "Fort Lee",
    "lat": "37.24694",
    "lng": "-77.33442"
  },
  {
    "country": "US",
    "name": "Fort Meade",
    "lat": "39.10815",
    "lng": "-76.74323"
  },
  {
    "country": "US",
    "name": "Aberdeen Proving Ground",
    "lat": "39.46686",
    "lng": "-76.13066"
  },
  {
    "country": "US",
    "name": "Andrews AFB",
    "lat": "38.80531",
    "lng": "-76.8746"
  },
  {
    "country": "US",
    "name": "Ashton-Sandy Spring",
    "lat": "39.14976",
    "lng": "-77.00504"
  },
  {
    "country": "US",
    "name": "Beaverdam Lake-Salisbury Mills",
    "lat": "41.44162",
    "lng": "-74.11629"
  },
  {
    "country": "US",
    "name": "Bel Air North",
    "lat": "39.55429",
    "lng": "-76.37309"
  },
  {
    "country": "US",
    "name": "Bel Air South",
    "lat": "39.50506",
    "lng": "-76.31977"
  },
  {
    "country": "US",
    "name": "Brittany Farms-Highlands",
    "lat": "40.26901",
    "lng": "-75.21401"
  },
  {
    "country": "US",
    "name": "Carmel Hamlet",
    "lat": "41.41485",
    "lng": "-73.68524"
  },
  {
    "country": "US",
    "name": "Carnot-Moon",
    "lat": "40.51856",
    "lng": "-80.21736"
  },
  {
    "country": "US",
    "name": "Cecil-Bishop",
    "lat": "40.31819",
    "lng": "-80.19331"
  },
  {
    "country": "US",
    "name": "Coeymans",
    "lat": "42.47491",
    "lng": "-73.79562"
  },
  {
    "country": "US",
    "name": "Conneaut Lakeshore",
    "lat": "41.62711",
    "lng": "-80.31008"
  },
  {
    "country": "US",
    "name": "Cortland West",
    "lat": "42.59431",
    "lng": "-76.22587"
  },
  {
    "country": "US",
    "name": "Dover Base Housing",
    "lat": "39.11763",
    "lng": "-75.48393"
  },
  {
    "country": "US",
    "name": "East Hampton North",
    "lat": "40.97276",
    "lng": "-72.18911"
  },
  {
    "country": "US",
    "name": "McGuire AFB",
    "lat": "40.03977",
    "lng": "-74.58174"
  },
  {
    "country": "US",
    "name": "Mercerville-Hamilton Square",
    "lat": "40.23126",
    "lng": "-74.67223"
  },
  {
    "country": "US",
    "name": "Moorestown-Lenola",
    "lat": "39.96591",
    "lng": "-74.96441"
  },
  {
    "country": "US",
    "name": "Mount Gay-Shamrock",
    "lat": "37.83857",
    "lng": "-82.0297"
  },
  {
    "country": "US",
    "name": "Mount Vernon",
    "lat": "38.71919",
    "lng": "-77.10726"
  },
  {
    "country": "US",
    "name": "Naval Academy",
    "lat": "38.98568",
    "lng": "-76.48774"
  },
  {
    "country": "US",
    "name": "New Castle Northwest",
    "lat": "41.02208",
    "lng": "-80.35682"
  },
  {
    "country": "US",
    "name": "North Ballston Spa",
    "lat": "43.01969",
    "lng": "-73.85109"
  },
  {
    "country": "US",
    "name": "Northeast Ithaca",
    "lat": "42.47032",
    "lng": "-76.46228"
  },
  {
    "country": "US",
    "name": "Northwest Harborcreek",
    "lat": "42.14944",
    "lng": "-79.99463"
  },
  {
    "country": "US",
    "name": "Northwest Ithaca",
    "lat": "42.47059",
    "lng": "-76.54145"
  },
  {
    "country": "US",
    "name": "Oxon Hill-Glassmanor",
    "lat": "38.79615",
    "lng": "-76.97499"
  },
  {
    "country": "US",
    "name": "Paramount-Long Meadow",
    "lat": "39.68042",
    "lng": "-77.6929"
  },
  {
    "country": "US",
    "name": "Plattsburgh West",
    "lat": "44.68315",
    "lng": "-73.50295"
  },
  {
    "country": "US",
    "name": "Pymatuning Central",
    "lat": "41.58546",
    "lng": "-80.4796"
  },
  {
    "country": "US",
    "name": "Quantico Station",
    "lat": "38.52263",
    "lng": "-77.31834"
  },
  {
    "country": "US",
    "name": "Remsenburg-Speonk",
    "lat": "40.82642",
    "lng": "-72.69673"
  },
  {
    "country": "US",
    "name": "Rising Sun-Lebanon",
    "lat": "39.09977",
    "lng": "-75.50488"
  },
  {
    "country": "US",
    "name": "Rosendale Village",
    "lat": "41.85038",
    "lng": "-74.07379"
  },
  {
    "country": "US",
    "name": "Leisure World",
    "lat": "39.1023",
    "lng": "-77.06898"
  },
  {
    "country": "US",
    "name": "Fountainhead-Orchard Hills",
    "lat": "39.68636",
    "lng": "-77.71901"
  },
  {
    "country": "US",
    "name": "Gates-North Gates",
    "lat": "43.16547",
    "lng": "-77.70066"
  },
  {
    "country": "US",
    "name": "Glens Falls North",
    "lat": "43.33506",
    "lng": "-73.68251"
  },
  {
    "country": "US",
    "name": "Greater Upper Marlboro",
    "lat": "38.83142",
    "lng": "-76.74827"
  },
  {
    "country": "US",
    "name": "Greenport West",
    "lat": "41.10178",
    "lng": "-72.37195"
  },
  {
    "country": "US",
    "name": "Guilford",
    "lat": "39.91541",
    "lng": "-77.60105"
  },
  {
    "country": "US",
    "name": "Holiday City South",
    "lat": "39.95324",
    "lng": "-74.23778"
  },
  {
    "country": "US",
    "name": "Holiday City-Berkeley",
    "lat": "39.9638",
    "lng": "-74.27803"
  },
  {
    "country": "US",
    "name": "Homeacre-Lyndora",
    "lat": "40.87206",
    "lng": "-79.9206"
  },
  {
    "country": "US",
    "name": "Horseheads North",
    "lat": "42.19278",
    "lng": "-76.80782"
  },
  {
    "country": "US",
    "name": "Jamestown West",
    "lat": "42.08851",
    "lng": "-79.2811"
  },
  {
    "country": "US",
    "name": "Jefferson Valley-Yorktown",
    "lat": "41.31797",
    "lng": "-73.80066"
  },
  {
    "country": "US",
    "name": "Lanham-Seabrook",
    "lat": "38.96835",
    "lng": "-76.85108"
  },
  {
    "country": "US",
    "name": "Lebanon South",
    "lat": "40.32804",
    "lng": "-76.40644"
  },
  {
    "country": "US",
    "name": "Leisure Village West-Pine Lake Park",
    "lat": "40.00416",
    "lng": "-74.26629"
  },
  {
    "country": "US",
    "name": "Leith-Hatfield",
    "lat": "39.87744",
    "lng": "-79.73133"
  },
  {
    "country": "US",
    "name": "Lutherville-Timonium",
    "lat": "39.43997",
    "lng": "-76.61099"
  },
  {
    "country": "US",
    "name": "Lynnwood-Pricedale",
    "lat": "40.13071",
    "lng": "-79.85135"
  },
  {
    "country": "US",
    "name": "Saugerties South",
    "lat": "42.06139",
    "lng": "-73.95067"
  },
  {
    "country": "US",
    "name": "Setauket-East Setauket",
    "lat": "40.93064",
    "lng": "-73.10179"
  },
  {
    "country": "US",
    "name": "Shanor-Northvue",
    "lat": "40.91045",
    "lng": "-79.91562"
  },
  {
    "country": "US",
    "name": "South Park Township",
    "lat": "40.29864",
    "lng": "-79.99405"
  },
  {
    "country": "US",
    "name": "St. Charles",
    "lat": "38.60728",
    "lng": "-76.92478"
  },
  {
    "country": "US",
    "name": "Suitland-Silver Hill",
    "lat": "38.84685",
    "lng": "-76.92591"
  },
  {
    "country": "US",
    "name": "Village Green-Green Ridge",
    "lat": "39.86363",
    "lng": "-75.42548"
  },
  {
    "country": "US",
    "name": "Weissport East",
    "lat": "40.83697",
    "lng": "-75.68643"
  },
  {
    "country": "US",
    "name": "Whitesboro-Burleigh",
    "lat": "39.04305",
    "lng": "-74.86538"
  },
  {
    "country": "US",
    "name": "Whittingham",
    "lat": "40.32982",
    "lng": "-74.44511"
  },
  {
    "country": "US",
    "name": "Wickerham Manor-Fisher",
    "lat": "40.17749",
    "lng": "-79.90684"
  },
  {
    "country": "US",
    "name": "Wilson-Conococheague",
    "lat": "39.65351",
    "lng": "-77.83157"
  },
  {
    "country": "US",
    "name": "Woodside East",
    "lat": "39.06756",
    "lng": "-75.53748"
  },
  {
    "country": "US",
    "name": "Fort Leonard Wood",
    "lat": "37.70573",
    "lng": "-92.15717"
  },
  {
    "country": "US",
    "name": "Fort Riley North",
    "lat": "39.11081",
    "lng": "-96.81392"
  },
  {
    "country": "US",
    "name": "Grand Forks Air Force Base",
    "lat": "47.95493",
    "lng": "-97.38664"
  },
  {
    "country": "US",
    "name": "Granville South",
    "lat": "40.05207",
    "lng": "-82.54166"
  },
  {
    "country": "US",
    "name": "Grissom Air Force Base",
    "lat": "40.65753",
    "lng": "-86.14755"
  },
  {
    "country": "US",
    "name": "K. I. Sawyer Air Force Base",
    "lat": "46.34651",
    "lng": "-87.38632"
  },
  {
    "country": "US",
    "name": "Legend Lake",
    "lat": "44.89095",
    "lng": "-88.54406"
  },
  {
    "country": "US",
    "name": "Level Park-Oak Park",
    "lat": "42.36418",
    "lng": "-85.2665"
  },
  {
    "country": "US",
    "name": "Manitou Beach-Devils Lake",
    "lat": "41.97565",
    "lng": "-84.28616"
  },
  {
    "country": "US",
    "name": "Minot Air Force Base",
    "lat": "48.42087",
    "lng": "-101.33914"
  },
  {
    "country": "US",
    "name": "Montrose-Ghent",
    "lat": "41.1538",
    "lng": "-81.64378"
  },
  {
    "country": "US",
    "name": "Offutt Air Force Base",
    "lat": "41.12024",
    "lng": "-95.92095"
  },
  {
    "country": "US",
    "name": "Saginaw Township North",
    "lat": "43.46004",
    "lng": "-84.00674"
  },
  {
    "country": "US",
    "name": "Scott Air Force Base",
    "lat": "38.5427",
    "lng": "-89.85035"
  },
  {
    "country": "US",
    "name": "Shorewood-Tower Hills-Harbert",
    "lat": "41.88169",
    "lng": "-86.61409"
  },
  {
    "country": "US",
    "name": "Barnes Lake-Millers Lake",
    "lat": "43.17956",
    "lng": "-83.3123"
  },
  {
    "country": "US",
    "name": "Champion Heights",
    "lat": "41.28999",
    "lng": "-80.84595"
  },
  {
    "country": "US",
    "name": "Comstock Northwest",
    "lat": "42.32182",
    "lng": "-85.51759"
  },
  {
    "country": "US",
    "name": "West Bloomfield Township",
    "lat": "42.56891",
    "lng": "-83.38356"
  },
  {
    "country": "US",
    "name": "Whiteman Air Force Base",
    "lat": "38.73018",
    "lng": "-93.55895"
  },
  {
    "country": "US",
    "name": "Wright-Patterson AFB",
    "lat": "39.81113",
    "lng": "-84.05731"
  },
  {
    "country": "US",
    "name": "Dade City North",
    "lat": "28.38334",
    "lng": "-82.19389"
  },
  {
    "country": "US",
    "name": "De Land Southwest",
    "lat": "29.0077",
    "lng": "-81.31129"
  },
  {
    "country": "US",
    "name": "East Bronson",
    "lat": "29.45928",
    "lng": "-82.5904"
  },
  {
    "country": "US",
    "name": "East Lake-Orient Park",
    "lat": "27.98269",
    "lng": "-82.37878"
  },
  {
    "country": "US",
    "name": "Eglin Air Force Base",
    "lat": "30.45907",
    "lng": "-86.55026"
  },
  {
    "country": "US",
    "name": "Fort Campbell North",
    "lat": "36.65429",
    "lng": "-87.46056"
  },
  {
    "country": "US",
    "name": "Fort Knox",
    "lat": "37.89113",
    "lng": "-85.96363"
  },
  {
    "country": "US",
    "name": "Fort Pierce North",
    "lat": "27.47364",
    "lng": "-80.3593"
  },
  {
    "country": "US",
    "name": "Fort Pierce South",
    "lat": "27.40962",
    "lng": "-80.35483"
  },
  {
    "country": "US",
    "name": "Fort Polk North",
    "lat": "31.10302",
    "lng": "-93.17913"
  },
  {
    "country": "US",
    "name": "Fort Polk South",
    "lat": "31.0511",
    "lng": "-93.21578"
  },
  {
    "country": "US",
    "name": "Fort Rucker",
    "lat": "31.34282",
    "lng": "-85.71538"
  },
  {
    "country": "US",
    "name": "Fort Stewart",
    "lat": "31.87217",
    "lng": "-81.61001"
  },
  {
    "country": "US",
    "name": "Four Corners",
    "lat": "28.33287",
    "lng": "-81.64738"
  },
  {
    "country": "US",
    "name": "Greater Northdale",
    "lat": "28.10545",
    "lng": "-82.52594"
  },
  {
    "country": "US",
    "name": "Hutchinson Island South",
    "lat": "27.29949",
    "lng": "-80.22045"
  },
  {
    "country": "US",
    "name": "Inverness Highlands North",
    "lat": "28.8642",
    "lng": "-82.37688"
  },
  {
    "country": "US",
    "name": "Inverness Highlands South",
    "lat": "28.80055",
    "lng": "-82.3371"
  },
  {
    "country": "US",
    "name": "Bellair-Meadowbrook Terrace",
    "lat": "30.17881",
    "lng": "-81.74341"
  },
  {
    "country": "US",
    "name": "Candler-McAfee",
    "lat": "33.72672",
    "lng": "-84.27246"
  },
  {
    "country": "US",
    "name": "Cocoa West",
    "lat": "28.35942",
    "lng": "-80.77109"
  },
  {
    "country": "US",
    "name": "Columbus Air Force Base",
    "lat": "33.63239",
    "lng": "-88.45153"
  },
  {
    "country": "US",
    "name": "Samsula-Spruce Creek",
    "lat": "29.04932",
    "lng": "-81.06192"
  },
  {
    "country": "US",
    "name": "Sandalfoot Cove",
    "lat": "26.33863",
    "lng": "-80.1869"
  },
  {
    "country": "US",
    "name": "Selmont-West Selmont",
    "lat": "32.37843",
    "lng": "-87.0074"
  },
  {
    "country": "US",
    "name": "Slater-Marietta",
    "lat": "35.03472",
    "lng": "-82.49265"
  },
  {
    "country": "US",
    "name": "Southeast Arcadia",
    "lat": "27.18629",
    "lng": "-81.8521"
  },
  {
    "country": "US",
    "name": "Tyndall Air Force Base",
    "lat": "30.08535",
    "lng": "-85.60731"
  },
  {
    "country": "US",
    "name": "Underwood-Petersville",
    "lat": "34.87695",
    "lng": "-87.69717"
  },
  {
    "country": "US",
    "name": "University",
    "lat": "28.07389",
    "lng": "-82.43902"
  },
  {
    "country": "US",
    "name": "Vero Beach South",
    "lat": "27.61638",
    "lng": "-80.41308"
  },
  {
    "country": "US",
    "name": "Watts Mills",
    "lat": "34.51641",
    "lng": "-81.9858"
  },
  {
    "country": "US",
    "name": "West End-Cobb Town",
    "lat": "33.6525",
    "lng": "-85.8742"
  },
  {
    "country": "US",
    "name": "Zephyrhills North",
    "lat": "28.25172",
    "lng": "-82.16557"
  },
  {
    "country": "US",
    "name": "Zephyrhills South",
    "lat": "28.21492",
    "lng": "-82.18873"
  },
  {
    "country": "US",
    "name": "Zephyrhills West",
    "lat": "28.23081",
    "lng": "-82.20556"
  },
  {
    "country": "US",
    "name": "Kendall West",
    "lat": "25.7065",
    "lng": "-80.4388"
  },
  {
    "country": "US",
    "name": "Kings Bay Base",
    "lat": "30.79836",
    "lng": "-81.56589"
  },
  {
    "country": "US",
    "name": "Lake Mack-Forest Hills",
    "lat": "29.00074",
    "lng": "-81.42397"
  },
  {
    "country": "US",
    "name": "Lake Murray of Richland",
    "lat": "34.12048",
    "lng": "-81.2645"
  },
  {
    "country": "US",
    "name": "Lake Norman of Catawba",
    "lat": "35.58043",
    "lng": "-81.01654"
  },
  {
    "country": "US",
    "name": "Meridian Station",
    "lat": "32.55049",
    "lng": "-88.61849"
  },
  {
    "country": "US",
    "name": "Monarch Mill",
    "lat": "34.7161",
    "lng": "-81.585"
  },
  {
    "country": "US",
    "name": "Nassau Village-Ratliff",
    "lat": "30.51111",
    "lng": "-81.80925"
  },
  {
    "country": "US",
    "name": "New Port Richey East",
    "lat": "28.26027",
    "lng": "-82.69261"
  },
  {
    "country": "US",
    "name": "North Weeki Wachee",
    "lat": "28.55014",
    "lng": "-82.55888"
  },
  {
    "country": "US",
    "name": "Oak Grove",
    "lat": "33.9809",
    "lng": "-81.14286"
  },
  {
    "country": "US",
    "name": "Palm River-Clair Mel",
    "lat": "27.92386",
    "lng": "-82.37939"
  },
  {
    "country": "US",
    "name": "Redstone Arsenal",
    "lat": "34.68387",
    "lng": "-86.64764"
  },
  {
    "country": "US",
    "name": "Robins Air Force Base",
    "lat": "32.60911",
    "lng": "-83.58444"
  },
  {
    "country": "US",
    "name": "Clarkston Heights-Vineland",
    "lat": "46.38742",
    "lng": "-117.083"
  },
  {
    "country": "US",
    "name": "Air Force Academy",
    "lat": "38.99425",
    "lng": "-104.86375"
  },
  {
    "country": "US",
    "name": "Alamosa East",
    "lat": "37.47735",
    "lng": "-105.84217"
  },
  {
    "country": "US",
    "name": "Antelope Valley-Crestview",
    "lat": "44.22488",
    "lng": "-105.47409"
  },
  {
    "country": "US",
    "name": "Aptos Hills-Larkin Valley",
    "lat": "36.96064",
    "lng": "-121.83404"
  },
  {
    "country": "US",
    "name": "Arden-Arcade",
    "lat": "38.6025",
    "lng": "-121.37854"
  },
  {
    "country": "US",
    "name": "Ault Field",
    "lat": "48.33812",
    "lng": "-122.67441"
  },
  {
    "country": "US",
    "name": "Bangor Trident Base",
    "lat": "47.72274",
    "lng": "-122.71446"
  },
  {
    "country": "US",
    "name": "Beale Air Force Base",
    "lat": "39.10917",
    "lng": "-121.35444"
  },
  {
    "country": "US",
    "name": "Bertsch-Oceanview",
    "lat": "41.7525",
    "lng": "-124.15875"
  },
  {
    "country": "US",
    "name": "Village of Oak Creek (Big Park)",
    "lat": "34.7809",
    "lng": "-111.76227"
  },
  {
    "country": "US",
    "name": "Black Point-Green Point",
    "lat": "38.11547",
    "lng": "-122.51318"
  },
  {
    "country": "US",
    "name": "Bonadelle Ranchos-Madera Ranchos",
    "lat": "36.98467",
    "lng": "-119.87463"
  },
  {
    "country": "US",
    "name": "Bonner-West Riverside",
    "lat": "46.87669",
    "lng": "-113.88678"
  },
  {
    "country": "US",
    "name": "Bret Harte",
    "lat": "37.60207",
    "lng": "-121.00519"
  },
  {
    "country": "US",
    "name": "Bryn Mawr-Skyway",
    "lat": "47.4943",
    "lng": "-122.24092"
  },
  {
    "country": "US",
    "name": "Camp Pendleton North",
    "lat": "33.31465",
    "lng": "-117.31603"
  },
  {
    "country": "US",
    "name": "Camp Pendleton South",
    "lat": "33.22844",
    "lng": "-117.37929"
  },
  {
    "country": "US",
    "name": "Cannon Air Force Base",
    "lat": "34.39689",
    "lng": "-103.32444"
  },
  {
    "country": "US",
    "name": "Casa de Oro-Mount Helix",
    "lat": "32.76397",
    "lng": "-116.96877"
  },
  {
    "country": "US",
    "name": "Cascade-Chipita Park",
    "lat": "38.94354",
    "lng": "-105.00237"
  },
  {
    "country": "US",
    "name": "Central Heights-Midland City",
    "lat": "33.40372",
    "lng": "-110.81541"
  },
  {
    "country": "US",
    "name": "Challenge-Brownsville",
    "lat": "39.46447",
    "lng": "-121.26338"
  },
  {
    "country": "US",
    "name": "Edwards Air Force Base",
    "lat": "34.91637",
    "lng": "-117.93535"
  },
  {
    "country": "US",
    "name": "El Cerro Mission",
    "lat": "34.76227",
    "lng": "-106.6445"
  },
  {
    "country": "US",
    "name": "Erlands Point-Kitsap Lake",
    "lat": "47.59719",
    "lng": "-122.70225"
  },
  {
    "country": "US",
    "name": "Fairchild Air Force Base",
    "lat": "47.61879",
    "lng": "-117.64826"
  },
  {
    "country": "US",
    "name": "Lucas Valley-Marinwood",
    "lat": "38.04011",
    "lng": "-122.5755"
  },
  {
    "country": "US",
    "name": "Malmstrom Air Force Base",
    "lat": "47.50549",
    "lng": "-111.18302"
  },
  {
    "country": "US",
    "name": "Maple Heights-Lake Desire",
    "lat": "47.44413",
    "lng": "-122.09736"
  },
  {
    "country": "US",
    "name": "March Air Force Base",
    "lat": "33.89209",
    "lng": "-117.2631"
  },
  {
    "country": "US",
    "name": "Marietta-Alderwood",
    "lat": "48.78965",
    "lng": "-122.55369"
  },
  {
    "country": "US",
    "name": "McChord Air Force Base",
    "lat": "47.13397",
    "lng": "-122.49157"
  },
  {
    "country": "US",
    "name": "Fetters Hot Springs-Agua Caliente",
    "lat": "38.3214",
    "lng": "-122.48682"
  },
  {
    "country": "US",
    "name": "Florence-Graham",
    "lat": "33.96772",
    "lng": "-118.24438"
  },
  {
    "country": "US",
    "name": "Fort Bliss",
    "lat": "31.81357",
    "lng": "-106.41224"
  },
  {
    "country": "US",
    "name": "Fort Hood",
    "lat": "31.13489",
    "lng": "-97.77561"
  },
  {
    "country": "US",
    "name": "Joint Base Lewis McChord",
    "lat": "47.10787",
    "lng": "-122.57694"
  },
  {
    "country": "US",
    "name": "Fox Farm-College",
    "lat": "41.11203",
    "lng": "-104.78546"
  },
  {
    "country": "US",
    "name": "Garden Home-Whitford",
    "lat": "45.464",
    "lng": "-122.75891"
  },
  {
    "country": "US",
    "name": "Gold Canyon",
    "lat": "33.37145",
    "lng": "-111.43691"
  },
  {
    "country": "US",
    "name": "Gunbarrel",
    "lat": "40.06335",
    "lng": "-105.17107"
  },
  {
    "country": "US",
    "name": "Heber-Overgaard",
    "lat": "34.41414",
    "lng": "-110.56956"
  },
  {
    "country": "US",
    "name": "Helena Valley Northeast",
    "lat": "46.69882",
    "lng": "-111.95207"
  },
  {
    "country": "US",
    "name": "Helena Valley Northwest",
    "lat": "46.72894",
    "lng": "-112.06275"
  },
  {
    "country": "US",
    "name": "Helena Valley Southeast",
    "lat": "46.61527",
    "lng": "-111.92156"
  },
  {
    "country": "US",
    "name": "Helena Valley West Central",
    "lat": "46.66291",
    "lng": "-112.06044"
  },
  {
    "country": "US",
    "name": "Helena West Side",
    "lat": "46.59672",
    "lng": "-112.11304"
  },
  {
    "country": "US",
    "name": "Highlands-Baywood Park",
    "lat": "37.52272",
    "lng": "-122.34506"
  },
  {
    "country": "US",
    "name": "Hilmar-Irwin",
    "lat": "37.40454",
    "lng": "-120.85042"
  },
  {
    "country": "US",
    "name": "Holloman Air Force Base",
    "lat": "32.84827",
    "lng": "-106.09977"
  },
  {
    "country": "US",
    "name": "Idyllwild-Pine Cove",
    "lat": "33.74429",
    "lng": "-116.72587"
  },
  {
    "country": "US",
    "name": "Inglewood-Finn Hill",
    "lat": "47.72049",
    "lng": "-122.23167"
  },
  {
    "country": "US",
    "name": "La Crescenta-Montrose",
    "lat": "34.23216",
    "lng": "-118.23529"
  },
  {
    "country": "US",
    "name": "Lackland Air Force Base",
    "lat": "29.38663",
    "lng": "-98.61797"
  },
  {
    "country": "US",
    "name": "Lagunitas-Forest Knolls",
    "lat": "38.01793",
    "lng": "-122.69124"
  },
  {
    "country": "US",
    "name": "Lake Marcel-Stillwater",
    "lat": "47.69263",
    "lng": "-121.91513"
  },
  {
    "country": "US",
    "name": "Lake Morton-Berrydale",
    "lat": "47.33251",
    "lng": "-122.10286"
  },
  {
    "country": "US",
    "name": "Lakeland North",
    "lat": "47.33343",
    "lng": "-122.27695"
  },
  {
    "country": "US",
    "name": "Lakeland South",
    "lat": "47.27843",
    "lng": "-122.28326"
  },
  {
    "country": "US",
    "name": "Larkfield-Wikiup",
    "lat": "38.51342",
    "lng": "-122.75094"
  },
  {
    "country": "US",
    "name": "Laughlin Air Force Base",
    "lat": "29.35663",
    "lng": "-100.78353"
  },
  {
    "country": "US",
    "name": "Leadville North",
    "lat": "39.2576",
    "lng": "-106.30138"
  },
  {
    "country": "US",
    "name": "LeChee",
    "lat": "36.86211",
    "lng": "-111.44063"
  },
  {
    "country": "US",
    "name": "Lemoore Station",
    "lat": "36.26326",
    "lng": "-119.90476"
  },
  {
    "country": "US",
    "name": "Dixon Lane-Meadow Creek",
    "lat": "37.38639",
    "lng": "-118.41527"
  },
  {
    "country": "US",
    "name": "East Hill-Meridian",
    "lat": "47.41052",
    "lng": "-122.17369"
  },
  {
    "country": "US",
    "name": "Sierra Vista Southeast",
    "lat": "31.45385",
    "lng": "-110.21637"
  },
  {
    "country": "US",
    "name": "Skyline-Ganipa",
    "lat": "35.03279",
    "lng": "-107.61396"
  },
  {
    "country": "US",
    "name": "Smith Valley",
    "lat": "38.78421",
    "lng": "-119.34425"
  },
  {
    "country": "US",
    "name": "South Wenatchee",
    "lat": "47.39012",
    "lng": "-120.28958"
  },
  {
    "country": "US",
    "name": "Moses Lake North",
    "lat": "47.19433",
    "lng": "-119.31719"
  },
  {
    "country": "US",
    "name": "Nellis Air Force Base",
    "lat": "36.24607",
    "lng": "-115.05721"
  },
  {
    "country": "US",
    "name": "New Kingman-Butler",
    "lat": "35.26504",
    "lng": "-114.03226"
  },
  {
    "country": "US",
    "name": "North Lakeport",
    "lat": "39.08831",
    "lng": "-122.90538"
  },
  {
    "country": "US",
    "name": "Oatfield",
    "lat": "45.41418",
    "lng": "-122.60007"
  },
  {
    "country": "US",
    "name": "Ohkay Owingeh",
    "lat": "36.05082",
    "lng": "-106.06897"
  },
  {
    "country": "US",
    "name": "Oroville East",
    "lat": "39.51126",
    "lng": "-121.47519"
  },
  {
    "country": "US",
    "name": "Otis Orchards-East Farms",
    "lat": "47.70988",
    "lng": "-117.07975"
  },
  {
    "country": "US",
    "name": "Picnic Point-North Lynnwood",
    "lat": "47.86278",
    "lng": "-122.29497"
  },
  {
    "country": "US",
    "name": "Poplar-Cotton Center",
    "lat": "36.05635",
    "lng": "-119.14919"
  },
  {
    "country": "US",
    "name": "Port Angeles East",
    "lat": "48.10667",
    "lng": "-123.37172"
  },
  {
    "country": "US",
    "name": "Port Hadlock-Irondale",
    "lat": "48.03273",
    "lng": "-122.78529"
  },
  {
    "country": "US",
    "name": "Roseburg North",
    "lat": "43.26452",
    "lng": "-123.30331"
  },
  {
    "country": "US",
    "name": "Security-Widefield",
    "lat": "38.74728",
    "lng": "-104.71439"
  },
  {
    "country": "US",
    "name": "Tsaile",
    "lat": "36.3033",
    "lng": "-109.21566"
  },
  {
    "country": "US",
    "name": "Union Hill-Novelty Hill",
    "lat": "47.67887",
    "lng": "-122.02833"
  },
  {
    "country": "US",
    "name": "Valencia West",
    "lat": "32.13238",
    "lng": "-111.11414"
  },
  {
    "country": "US",
    "name": "Vandenberg Air Force Base",
    "lat": "34.7483",
    "lng": "-120.51817"
  },
  {
    "country": "US",
    "name": "View Park-Windsor Hills",
    "lat": "33.99551",
    "lng": "-118.34835"
  },
  {
    "country": "US",
    "name": "Vincent",
    "lat": "34.09836",
    "lng": "-117.92383"
  },
  {
    "country": "US",
    "name": "Walla Walla East",
    "lat": "46.05184",
    "lng": "-118.30403"
  },
  {
    "country": "US",
    "name": "West Clarkston-Highland",
    "lat": "46.40287",
    "lng": "-117.06395"
  },
  {
    "country": "US",
    "name": "West Haven-Sylvan",
    "lat": "45.51613",
    "lng": "-122.76809"
  },
  {
    "country": "US",
    "name": "West Modesto",
    "lat": "37.61754",
    "lng": "-121.03914"
  },
  {
    "country": "US",
    "name": "West Pleasant View",
    "lat": "39.73256",
    "lng": "-105.17852"
  },
  {
    "country": "US",
    "name": "West Side Highway",
    "lat": "46.18399",
    "lng": "-122.91715"
  },
  {
    "country": "US",
    "name": "West Whittier-Los Nietos",
    "lat": "33.976",
    "lng": "-118.06909"
  },
  {
    "country": "US",
    "name": "Westhaven-Moonstone",
    "lat": "41.04489",
    "lng": "-124.10239"
  },
  {
    "country": "US",
    "name": "Whetstone",
    "lat": "31.70105",
    "lng": "-110.33987"
  },
  {
    "country": "US",
    "name": "Yosemite Valley",
    "lat": "37.74075",
    "lng": "-119.57788"
  },
  {
    "country": "US",
    "name": "Summerlin South",
    "lat": "36.11708",
    "lng": "-115.33001"
  },
  {
    "country": "US",
    "name": "Sunnyside-Tahoe City",
    "lat": "39.15023",
    "lng": "-120.1612"
  },
  {
    "country": "US",
    "name": "Taft Mosswood",
    "lat": "37.91385",
    "lng": "-121.28316"
  },
  {
    "country": "US",
    "name": "Tamalpais-Homestead Valley",
    "lat": "37.87834",
    "lng": "-122.53625"
  },
  {
    "country": "US",
    "name": "Tanglewilde-Thompson Place",
    "lat": "47.05116",
    "lng": "-122.78081"
  },
  {
    "country": "US",
    "name": "Haiku-Pauwela",
    "lat": "20.92187",
    "lng": "-156.30508"
  },
  {
    "country": "US",
    "name": "Hickam Field",
    "lat": "21.33967",
    "lng": "-157.96018"
  },
  {
    "country": "US",
    "name": "Honaunau-Napoopoo",
    "lat": "19.45627",
    "lng": "-155.86466"
  },
  {
    "country": "US",
    "name": "Kahaluu-Keauhou",
    "lat": "19.57181",
    "lng": "-155.96172"
  },
  {
    "country": "US",
    "name": "Marine Corps Base Hawaii - MCBH",
    "lat": "21.44336",
    "lng": "-157.74981"
  },
  {
    "country": "US",
    "name": "Makakilo",
    "lat": "21.35237",
    "lng": "-158.08655"
  },
  {
    "country": "US",
    "name": "Napili-Honokowai",
    "lat": "20.97533",
    "lng": "-156.67826"
  },
  {
    "country": "US",
    "name": "Schofield Barracks",
    "lat": "21.49837",
    "lng": "-158.06515"
  },
  {
    "country": "US",
    "name": "Royal Kunia",
    "lat": "21.39392",
    "lng": "-158.0267"
  },
  {
    "country": "US",
    "name": "Waihee-Waiehu",
    "lat": "20.93022",
    "lng": "-156.50458"
  },
  {
    "country": "US",
    "name": "Wailua Homesteads",
    "lat": "22.07244",
    "lng": "-159.37677"
  },
  {
    "country": "US",
    "name": "Deltana",
    "lat": "63.87217",
    "lng": "-145.21773"
  },
  {
    "country": "US",
    "name": "Eielson Air Force Base",
    "lat": "64.66327",
    "lng": "-147.05442"
  },
  {
    "country": "US",
    "name": "Farm Loop",
    "lat": "61.63891",
    "lng": "-149.14215"
  },
  {
    "country": "US",
    "name": "Fishhook",
    "lat": "61.74402",
    "lng": "-149.23613"
  },
  {
    "country": "US",
    "name": "Knik-Fairview",
    "lat": "61.51262",
    "lng": "-149.60012"
  },
  {
    "country": "US",
    "name": "Kodiak Station",
    "lat": "57.76587",
    "lng": "-152.60004"
  },
  {
    "country": "US",
    "name": "Lakes",
    "lat": "61.60713",
    "lng": "-149.30861"
  },
  {
    "country": "US",
    "name": "Salcha",
    "lat": "64.52399",
    "lng": "-146.9021"
  },
  {
    "country": "US",
    "name": "Sutton-Alpine",
    "lat": "61.77789",
    "lng": "-148.7645"
  },
  {
    "country": "US",
    "name": "Y",
    "lat": "62.16129",
    "lng": "-149.85075"
  },
  {
    "country": "US",
    "name": "National Harbor",
    "lat": "38.78264",
    "lng": "-77.01506"
  },
  {
    "country": "US",
    "name": "San Tan Valley",
    "lat": "33.1911",
    "lng": "-111.528"
  },
  {
    "country": "US",
    "name": "Carlisle-Rockledge",
    "lat": "34.11445",
    "lng": "-86.12407"
  },
  {
    "country": "US",
    "name": "Emerald Mountain",
    "lat": "32.44793",
    "lng": "-86.09429"
  },
  {
    "country": "US",
    "name": "Highland Lakes",
    "lat": "33.39838",
    "lng": "-86.6513"
  },
  {
    "country": "US",
    "name": "Farmers Loop",
    "lat": "64.90822",
    "lng": "-147.69866"
  },
  {
    "country": "US",
    "name": "Avenue B and C",
    "lat": "32.71904",
    "lng": "-114.66005"
  },
  {
    "country": "US",
    "name": "Centennial Park",
    "lat": "36.95381",
    "lng": "-112.98132"
  },
  {
    "country": "US",
    "name": "Donovan Estates",
    "lat": "32.70935",
    "lng": "-114.67822"
  },
  {
    "country": "US",
    "name": "Golden Shores",
    "lat": "34.78188",
    "lng": "-114.47775"
  },
  {
    "country": "US",
    "name": "North Fork",
    "lat": "34.00167",
    "lng": "-109.96355"
  },
  {
    "country": "US",
    "name": "Scenic",
    "lat": "36.79359",
    "lng": "-114.01275"
  },
  {
    "country": "US",
    "name": "Six Shooter Canyon",
    "lat": "33.36678",
    "lng": "-110.7746"
  },
  {
    "country": "US",
    "name": "Valle Vista",
    "lat": "35.41088",
    "lng": "-113.86271"
  },
  {
    "country": "US",
    "name": "Acalanes Ridge",
    "lat": "37.90472",
    "lng": "-122.07857"
  },
  {
    "country": "US",
    "name": "Fruitridge Pocket",
    "lat": "38.53265",
    "lng": "-121.45581"
  },
  {
    "country": "US",
    "name": "Meadowbrook",
    "lat": "33.72578",
    "lng": "-117.28509"
  },
  {
    "country": "US",
    "name": "Monument Hills",
    "lat": "38.66429",
    "lng": "-121.87566"
  },
  {
    "country": "US",
    "name": "Old Fig Garden",
    "lat": "36.79885",
    "lng": "-119.80515"
  },
  {
    "country": "US",
    "name": "Red Corral",
    "lat": "38.41165",
    "lng": "-120.60552"
  },
  {
    "country": "US",
    "name": "Sun Village",
    "lat": "34.55952",
    "lng": "-117.95676"
  },
  {
    "country": "US",
    "name": "Upper Bear Creek",
    "lat": "39.62385",
    "lng": "-105.4178"
  },
  {
    "country": "US",
    "name": "Connerton",
    "lat": "28.31441",
    "lng": "-82.47539"
  },
  {
    "country": "US",
    "name": "Flagler Estates",
    "lat": "29.64553",
    "lng": "-81.457"
  },
  {
    "country": "US",
    "name": "Greenbriar",
    "lat": "28.01128",
    "lng": "-82.75272"
  },
  {
    "country": "US",
    "name": "Heritage Pines",
    "lat": "28.42522",
    "lng": "-82.62111"
  },
  {
    "country": "US",
    "name": "Horizon West",
    "lat": "28.43383",
    "lng": "-81.6227"
  },
  {
    "country": "US",
    "name": "Island Walk",
    "lat": "26.25099",
    "lng": "-81.71101"
  },
  {
    "country": "US",
    "name": "Key Vista",
    "lat": "28.1947",
    "lng": "-82.77038"
  },
  {
    "country": "US",
    "name": "Meadow Oaks",
    "lat": "28.34619",
    "lng": "-82.60284"
  },
  {
    "country": "US",
    "name": "Midway",
    "lat": "30.40648",
    "lng": "-87.00553"
  },
  {
    "country": "US",
    "name": "Nocatee",
    "lat": "30.0832",
    "lng": "-81.40283"
  },
  {
    "country": "US",
    "name": "Oakleaf Plantation",
    "lat": "30.17083",
    "lng": "-81.83549"
  },
  {
    "country": "US",
    "name": "Pasadena Hills",
    "lat": "28.28001",
    "lng": "-82.22438"
  },
  {
    "country": "US",
    "name": "Quail Ridge",
    "lat": "28.34905",
    "lng": "-82.55532"
  },
  {
    "country": "US",
    "name": "Verona Walk",
    "lat": "26.08412",
    "lng": "-81.67985"
  },
  {
    "country": "US",
    "name": "Viera East",
    "lat": "28.26234",
    "lng": "-80.71449"
  },
  {
    "country": "US",
    "name": "Viera West",
    "lat": "28.24504",
    "lng": "-80.7338"
  },
  {
    "country": "US",
    "name": "Henderson",
    "lat": "32.00813",
    "lng": "-81.25887"
  },
  {
    "country": "US",
    "name": "East Honolulu",
    "lat": "21.28906",
    "lng": "-157.71734"
  },
  {
    "country": "US",
    "name": "Ocean Pointe",
    "lat": "21.31066",
    "lng": "-158.03638"
  },
  {
    "country": "US",
    "name": "The Galena Territory",
    "lat": "42.39343",
    "lng": "-90.32582"
  },
  {
    "country": "US",
    "name": "Smithville-Sanders",
    "lat": "39.05969",
    "lng": "-86.51077"
  },
  {
    "country": "US",
    "name": "McConnell AFB",
    "lat": "37.63007",
    "lng": "-97.25869"
  },
  {
    "country": "US",
    "name": "Fairwood",
    "lat": "38.95665",
    "lng": "-76.77772"
  },
  {
    "country": "US",
    "name": "Marlboro Village",
    "lat": "38.83054",
    "lng": "-76.76965"
  },
  {
    "country": "US",
    "name": "Queenland",
    "lat": "38.80524",
    "lng": "-76.79126"
  },
  {
    "country": "US",
    "name": "Summerfield",
    "lat": "38.90454",
    "lng": "-76.8683"
  },
  {
    "country": "US",
    "name": "LaBarque Creek",
    "lat": "38.41701",
    "lng": "-90.67989"
  },
  {
    "country": "US",
    "name": "Old Jamestown",
    "lat": "38.83494",
    "lng": "-90.28511"
  },
  {
    "country": "US",
    "name": "East Valley",
    "lat": "38.9434",
    "lng": "-119.69923"
  },
  {
    "country": "US",
    "name": "Topaz Ranch Estates",
    "lat": "38.73565",
    "lng": "-119.50079"
  },
  {
    "country": "US",
    "name": "East Franklin",
    "lat": "40.4933",
    "lng": "-74.4711"
  },
  {
    "country": "US",
    "name": "Franklin Center",
    "lat": "40.53153",
    "lng": "-74.54141"
  },
  {
    "country": "US",
    "name": "Upper Pohatcong",
    "lat": "40.67747",
    "lng": "-75.1558"
  },
  {
    "country": "US",
    "name": "Vernon Center",
    "lat": "41.18879",
    "lng": "-74.50405"
  },
  {
    "country": "US",
    "name": "Keeler Farm",
    "lat": "32.31607",
    "lng": "-107.76023"
  },
  {
    "country": "US",
    "name": "West Hammond",
    "lat": "36.68071",
    "lng": "-108.04921"
  },
  {
    "country": "US",
    "name": "Fort Covington Hamlet",
    "lat": "44.97178",
    "lng": "-74.50757"
  },
  {
    "country": "US",
    "name": "Merritt Park",
    "lat": "41.53848",
    "lng": "-73.87238"
  },
  {
    "country": "US",
    "name": "Northchase",
    "lat": "34.30782",
    "lng": "-77.87749"
  },
  {
    "country": "US",
    "name": "Eagleview",
    "lat": "40.05938",
    "lng": "-75.68076"
  },
  {
    "country": "US",
    "name": "Mowbray Mountain",
    "lat": "35.27536",
    "lng": "-85.22246"
  },
  {
    "country": "US",
    "name": "Tellico Village",
    "lat": "35.68321",
    "lng": "-84.25518"
  },
  {
    "country": "US",
    "name": "Lantana",
    "lat": "33.09073",
    "lng": "-97.12416"
  },
  {
    "country": "US",
    "name": "Las Palmas II",
    "lat": "26.20171",
    "lng": "-97.7376"
  },
  {
    "country": "US",
    "name": "Paloma Creek",
    "lat": "33.2253",
    "lng": "-96.93742"
  },
  {
    "country": "US",
    "name": "Paloma Creek South",
    "lat": "33.21136",
    "lng": "-96.93554"
  },
  {
    "country": "US",
    "name": "Providence",
    "lat": "33.2334",
    "lng": "-96.96158"
  },
  {
    "country": "US",
    "name": "Savannah",
    "lat": "33.22603",
    "lng": "-96.90786"
  },
  {
    "country": "US",
    "name": "Travis Ranch",
    "lat": "32.80356",
    "lng": "-96.47347"
  },
  {
    "country": "US",
    "name": "Silver Summit",
    "lat": "40.74144",
    "lng": "-111.48775"
  },
  {
    "country": "US",
    "name": "Boswell's Corner",
    "lat": "38.50541",
    "lng": "-77.37263"
  },
  {
    "country": "US",
    "name": "Kings Park West",
    "lat": "38.81443",
    "lng": "-77.29582"
  },
  {
    "country": "US",
    "name": "Loudoun Valley Estates",
    "lat": "38.98081",
    "lng": "-77.5079"
  },
  {
    "country": "US",
    "name": "Southern Gateway",
    "lat": "38.34507",
    "lng": "-77.50352"
  },
  {
    "country": "US",
    "name": "Bothell East",
    "lat": "47.80631",
    "lng": "-122.18427"
  },
  {
    "country": "US",
    "name": "Bothell West",
    "lat": "47.80527",
    "lng": "-122.24064"
  },
  {
    "country": "US",
    "name": "Bunk Foss",
    "lat": "47.96171",
    "lng": "-122.09441"
  },
  {
    "country": "US",
    "name": "Crocker",
    "lat": "47.08091",
    "lng": "-122.10383"
  },
  {
    "country": "US",
    "name": "Eastmont",
    "lat": "47.8974",
    "lng": "-122.18154"
  },
  {
    "country": "US",
    "name": "Klahanie",
    "lat": "47.57097",
    "lng": "-122.00839"
  },
  {
    "country": "US",
    "name": "Larch Way",
    "lat": "47.8429",
    "lng": "-122.25275"
  },
  {
    "country": "US",
    "name": "Mill Creek East",
    "lat": "47.83602",
    "lng": "-122.18766"
  },
  {
    "country": "US",
    "name": "Monroe North",
    "lat": "47.88225",
    "lng": "-121.98729"
  },
  {
    "country": "US",
    "name": "North Fort Lewis",
    "lat": "47.12131",
    "lng": "-122.59452"
  },
  {
    "country": "US",
    "name": "Prairie Heights",
    "lat": "47.14933",
    "lng": "-122.1053"
  },
  {
    "country": "US",
    "name": "Summit View",
    "lat": "47.13632",
    "lng": "-122.35202"
  },
  {
    "country": "US",
    "name": "Wilderness Rim",
    "lat": "47.44697",
    "lng": "-121.76857"
  },
  {
    "country": "US",
    "name": "Matheny",
    "lat": "36.17066",
    "lng": "-119.35158"
  },
  {
    "country": "US",
    "name": "Patterson Tract",
    "lat": "36.37952",
    "lng": "-119.2956"
  },
  {
    "country": "US",
    "name": "Teviston",
    "lat": "35.92894",
    "lng": "-119.27831"
  },
  {
    "country": "US",
    "name": "Hidden Spring",
    "lat": "43.72216",
    "lng": "-116.25093"
  },
  {
    "country": "US",
    "name": "Circle D-KC Estates",
    "lat": "30.161",
    "lng": "-97.23473"
  },
  {
    "country": "US",
    "name": "University Park",
    "lat": "41.44298",
    "lng": "-87.6836"
  },
  {
    "country": "US",
    "name": "Rio Vista",
    "lat": "38.16389",
    "lng": "-121.69583"
  },
  {
    "country": "US",
    "name": "Shorewood Forest",
    "lat": "41.46315",
    "lng": "-87.14472"
  },
  {
    "country": "US",
    "name": "Woodlake",
    "lat": "37.42106",
    "lng": "-77.67931"
  },
  {
    "country": "US",
    "name": "Cordry Sweetwater Lakes",
    "lat": "39.30464",
    "lng": "-86.11837"
  },
  {
    "country": "US",
    "name": "Dove Valley",
    "lat": "39.57771",
    "lng": "-104.8294"
  },
  {
    "country": "US",
    "name": "Doe Valley",
    "lat": "37.95665",
    "lng": "-86.11653"
  },
  {
    "country": "US",
    "name": "Enchanted Hills",
    "lat": "35.33676",
    "lng": "-106.59296"
  },
  {
    "country": "US",
    "name": "Oak Cliff Place",
    "lat": "29.92712",
    "lng": "-95.62672"
  },
  {
    "country": "US",
    "name": "West Hills",
    "lat": "34.19731",
    "lng": "-118.64398"
  },
  {
    "country": "US",
    "name": "Detroit-Shoreway",
    "lat": "41.47772",
    "lng": "-81.72991"
  },
  {
    "country": "US",
    "name": "Clark-Fulton",
    "lat": "41.46402",
    "lng": "-81.70979"
  },
  {
    "country": "US",
    "name": "Beech Mountain Lakes",
    "lat": "41.04158",
    "lng": "-75.93545"
  },
  {
    "country": "US",
    "name": "The Hideout",
    "lat": "41.42736",
    "lng": "-75.35255"
  },
  {
    "country": "US",
    "name": "Wallenpaupack Lake Estates",
    "lat": "41.39898",
    "lng": "-75.27402"
  },
  {
    "country": "US",
    "name": "Penn Estates",
    "lat": "41.0375",
    "lng": "-75.23956"
  },
  {
    "country": "US",
    "name": "Sierra View",
    "lat": "41.01207",
    "lng": "-75.459"
  },
  {
    "country": "US",
    "name": "Pine Ridge",
    "lat": "41.14598",
    "lng": "-74.99116"
  },
  {
    "country": "US",
    "name": "The Acreage",
    "lat": "26.79404",
    "lng": "-80.26749"
  },
  {
    "country": "US",
    "name": "Eastvale",
    "lat": "33.96358",
    "lng": "-117.56418"
  },
  {
    "country": "US",
    "name": "Oak Hill",
    "lat": "38.9258",
    "lng": "-77.40156"
  },
  {
    "country": "US",
    "name": "Beaver Dam Lake",
    "lat": "41.44743",
    "lng": "-74.11463"
  },
  {
    "country": "US",
    "name": "Contra Costa Centre",
    "lat": "37.92752",
    "lng": "-122.05786"
  },
  {
    "country": "US",
    "name": "Belmont Estates",
    "lat": "38.45271",
    "lng": "-78.91979"
  },
  {
    "country": "US",
    "name": "Siesta Acres",
    "lat": "28.75799",
    "lng": "-100.49019"
  },
  {
    "country": "US",
    "name": "West Greenwich",
    "lat": "41.637",
    "lng": "-71.66004"
  },
  {
    "country": "US",
    "name": "Bridgewater",
    "lat": "40.60079",
    "lng": "-74.64815"
  },
  {
    "country": "US",
    "name": "Warren Township",
    "lat": "40.60822",
    "lng": "-74.51803"
  },
  {
    "country": "US",
    "name": "Limestone",
    "lat": "41.13237",
    "lng": "-87.9684"
  },
  {
    "country": "US",
    "name": "Castle Pines North",
    "lat": "39.47174",
    "lng": "-104.89482"
  },
  {
    "country": "US",
    "name": "Fairfield Heights",
    "lat": "39.82861",
    "lng": "-86.38224"
  },
  {
    "country": "US",
    "name": "Chicago Loop",
    "lat": "41.88407",
    "lng": "-87.6333"
  },
  {
    "country": "US",
    "name": "Greater Grand Crossing",
    "lat": "41.76113",
    "lng": "-87.61485"
  },
  {
    "country": "US",
    "name": "Auburn Gresham",
    "lat": "41.74179",
    "lng": "-87.65322"
  },
  {
    "country": "US",
    "name": "Financial District",
    "lat": "40.70789",
    "lng": "-74.00857"
  },
  {
    "country": "US",
    "name": "Sunset Park",
    "lat": "40.64548",
    "lng": "-74.01241"
  },
  {
    "country": "US",
    "name": "South Kingstown",
    "lat": "41.44718",
    "lng": "-71.52494"
  },
  {
    "country": "US",
    "name": "Noe Valley",
    "lat": "37.75018",
    "lng": "-122.43369"
  },
  {
    "country": "US",
    "name": "Visitacion Valley",
    "lat": "37.71715",
    "lng": "-122.40433"
  },
  {
    "country": "US",
    "name": "La Porte",
    "lat": "41.60774",
    "lng": "-86.71389"
  },
  {
    "country": "US",
    "name": "Notre Dame",
    "lat": "41.70019",
    "lng": "-86.23793"
  },
  {
    "country": "US",
    "name": "Randolph",
    "lat": "40.84829",
    "lng": "-74.58148"
  },
  {
    "country": "US",
    "name": "Hobart",
    "lat": "44.49925",
    "lng": "-88.14986"
  },
  {
    "country": "US",
    "name": "Mount Pleasant",
    "lat": "42.69743",
    "lng": "-87.85577"
  },
  {
    "country": "US",
    "name": "Western Lake",
    "lat": "32.62338",
    "lng": "-97.81155"
  },
  {
    "country": "US",
    "name": "Star Valley Ranch",
    "lat": "42.97139",
    "lng": "-110.95556"
  },
  {
    "country": "US",
    "name": "Shaw Heights",
    "lat": "39.8525",
    "lng": "-105.04306"
  },
  {
    "country": "US",
    "name": "Northdale",
    "lat": "28.0939",
    "lng": "-82.50561"
  },
  {
    "country": "US",
    "name": "Lake Stickney",
    "lat": "47.87655",
    "lng": "-122.26214"
  },
  {
    "country": "US",
    "name": "Phoenix Lake",
    "lat": "38.00594",
    "lng": "-120.30702"
  },
  {
    "country": "US",
    "name": "Picnic Point",
    "lat": "47.88111",
    "lng": "-122.3284"
  },
  {
    "country": "US",
    "name": "Roma",
    "lat": "26.40526",
    "lng": "-99.01581"
  },
  {
    "country": "US",
    "name": "Tanglewilde",
    "lat": "47.0515",
    "lng": "-122.78241"
  },
  {
    "country": "US",
    "name": "Tiki Island",
    "lat": "29.29709",
    "lng": "-94.91709"
  },
  {
    "country": "US",
    "name": "Waterford",
    "lat": "41.3417",
    "lng": "-72.13597"
  },
  {
    "country": "US",
    "name": "Devens",
    "lat": "42.5447",
    "lng": "-71.61318"
  },
  {
    "country": "US",
    "name": "Lake Holiday",
    "lat": "41.61292",
    "lng": "-88.67209"
  },
  {
    "country": "US",
    "name": "Prestbury",
    "lat": "41.78329",
    "lng": "-88.41764"
  },
  {
    "country": "US",
    "name": "Lake Camelot",
    "lat": "40.63065",
    "lng": "-89.7421"
  },
  {
    "country": "US",
    "name": "Heritage Lake",
    "lat": "40.54745",
    "lng": "-89.32581"
  },
  {
    "country": "US",
    "name": "Twin Lakes",
    "lat": "38.24927",
    "lng": "-78.44378"
  },
  {
    "country": "US",
    "name": "Heritage Lake",
    "lat": "39.72779",
    "lng": "-86.71022"
  },
  {
    "country": "US",
    "name": "Watchtower",
    "lat": "41.63776",
    "lng": "-74.26027"
  },
  {
    "country": "US",
    "name": "Cherry Creek",
    "lat": "39.63455",
    "lng": "-104.88286"
  },
  {
    "country": "US",
    "name": "Holly Hills",
    "lat": "39.66757",
    "lng": "-104.91797"
  },
  {
    "country": "US",
    "name": "Inverness",
    "lat": "39.57738",
    "lng": "-104.86135"
  },
  {
    "country": "US",
    "name": "Lake Panorama",
    "lat": "41.71105",
    "lng": "-94.39059"
  },
  {
    "country": "US",
    "name": "Lake Lakengren",
    "lat": "39.68843",
    "lng": "-84.69347"
  },
  {
    "country": "US",
    "name": "Apple Valley",
    "lat": "40.4389",
    "lng": "-82.35391"
  },
  {
    "country": "US",
    "name": "Quail Creek",
    "lat": "28.7764",
    "lng": "-97.08232"
  },
  {
    "country": "US",
    "name": "Meadowbrook",
    "lat": "37.44882",
    "lng": "-77.47353"
  },
  {
    "country": "US",
    "name": "Plum Creek",
    "lat": "37.12984",
    "lng": "-80.5006"
  },
  {
    "country": "US",
    "name": "Woodburn",
    "lat": "38.84745",
    "lng": "-77.23605"
  },
  {
    "country": "US",
    "name": "Big Bass Lake",
    "lat": "41.25383",
    "lng": "-75.47644"
  },
  {
    "country": "US",
    "name": "Toftrees",
    "lat": "40.82604",
    "lng": "-77.8811"
  },
  {
    "country": "US",
    "name": "Lake Latonka",
    "lat": "41.29039",
    "lng": "-80.18129"
  },
  {
    "country": "US",
    "name": "Buckhorn",
    "lat": "38.45216",
    "lng": "-120.52854"
  },
  {
    "country": "US",
    "name": "Silver Lakes",
    "lat": "34.74558",
    "lng": "-117.34098"
  },
  {
    "country": "US",
    "name": "Spring Valley Lake",
    "lat": "34.49364",
    "lng": "-117.26832"
  },
  {
    "country": "US",
    "name": "Hide-A-Way Lake",
    "lat": "30.56492",
    "lng": "-89.6402"
  },
  {
    "country": "US",
    "name": "Tunica Resorts",
    "lat": "34.83613",
    "lng": "-90.34723"
  },
  {
    "country": "US",
    "name": "Colony Park",
    "lat": "40.34683",
    "lng": "-75.9824"
  },
  {
    "country": "US",
    "name": "Greenfields",
    "lat": "40.3599",
    "lng": "-75.95199"
  },
  {
    "country": "US",
    "name": "Rome",
    "lat": "44.2206",
    "lng": "-89.80843"
  },
  {
    "country": "US",
    "name": "Farley",
    "lat": "37.04634",
    "lng": "-88.56856"
  },
  {
    "country": "US",
    "name": "Lincoln",
    "lat": "41.92111",
    "lng": "-71.435"
  },
  {
    "country": "US",
    "name": "Kula",
    "lat": "20.79094",
    "lng": "-156.32695"
  },
  {
    "country": "US",
    "name": "Ko Olina",
    "lat": "21.33993",
    "lng": "-158.12562"
  },
  {
    "country": "US",
    "name": "Firing Range",
    "lat": "33.43752",
    "lng": "-82.69068"
  },
  {
    "country": "US",
    "name": "West Warrenton",
    "lat": "33.41217",
    "lng": "-82.67517"
  },
  {
    "country": "US",
    "name": "Johnston",
    "lat": "41.82186",
    "lng": "-71.50675"
  },
  {
    "country": "US",
    "name": "Hill Air Force Base",
    "lat": "41.11118",
    "lng": "-111.97712"
  },
  {
    "country": "US",
    "name": "Elmendorf Air Force Base",
    "lat": "61.25703",
    "lng": "-149.63139"
  },
  {
    "country": "US",
    "name": "Hot Springs National Park",
    "lat": "34.5317",
    "lng": "-93.06377"
  },
  {
    "country": "US",
    "name": "Dixiana",
    "lat": "33.74021",
    "lng": "-86.64938"
  },
  {
    "country": "US",
    "name": "Shoal Creek",
    "lat": "33.43076",
    "lng": "-86.61092"
  },
  {
    "country": "US",
    "name": "Little Rock Air Force Base",
    "lat": "34.89149",
    "lng": "-92.15955"
  },
  {
    "country": "US",
    "name": "Cranberry Township",
    "lat": "40.68496",
    "lng": "-80.10714"
  },
  {
    "country": "US",
    "name": "Woodstock",
    "lat": "44.37494",
    "lng": "-70.60849"
  },
  {
    "country": "US",
    "name": "St Marys",
    "lat": "30.75677",
    "lng": "-81.57173"
  },
  {
    "country": "US",
    "name": "Laurel Hill",
    "lat": "38.71663",
    "lng": "-77.23686"
  },
  {
    "country": "US",
    "name": "Harrison",
    "lat": "44.22776",
    "lng": "-88.33591"
  },
  {
    "country": "US",
    "name": "Pantops",
    "lat": "38.03379",
    "lng": "-78.45507"
  },
  {
    "country": "US",
    "name": "Decatur",
    "lat": "42.63433",
    "lng": "-89.41155"
  },
  {
    "country": "US",
    "name": "Center City",
    "lat": "39.9512",
    "lng": "-75.15923"
  },
  {
    "country": "US",
    "name": "Pryor Creek",
    "lat": "36.30862",
    "lng": "-95.31777"
  },
  {
    "country": "US",
    "name": "Silver Lake",
    "lat": "34.08668",
    "lng": "-118.27023"
  },
  {
    "country": "US",
    "name": "Echo Park",
    "lat": "34.07808",
    "lng": "-118.26066"
  },
  {
    "country": "US",
    "name": "Sugarcreek Police Dept",
    "lat": "40.50253",
    "lng": "-81.64176"
  },
  {
    "country": "US",
    "name": "Scotts Mill",
    "lat": "35.72666",
    "lng": "-78.8839"
  },
  {
    "country": "US",
    "name": "Maine",
    "lat": "45.02716",
    "lng": "-89.69039"
  },
  {
    "country": "US",
    "name": "Plainview",
    "lat": "36.17731",
    "lng": "-83.79534"
  },
  {
    "country": "US",
    "name": "Washington Street Courthouse Annex",
    "lat": "34.80264",
    "lng": "-86.97298"
  },
  {
    "country": "US",
    "name": "Allenstown",
    "lat": "43.15673",
    "lng": "-71.40478"
  },
  {
    "country": "US",
    "name": "Bay Harbor",
    "lat": "45.36413",
    "lng": "-85.08208"
  },
  {
    "country": "US",
    "name": "St. Johns",
    "lat": "30.0815",
    "lng": "-81.54774"
  },
  {
    "country": "US",
    "name": "Stonecrest",
    "lat": "33.70849",
    "lng": "-84.13485"
  },
  {
    "country": "US",
    "name": "Union City",
    "lat": "40.19938",
    "lng": "-84.80353"
  },
  {
    "country": "US",
    "name": "New Century, KS",
    "lat": "38.82253",
    "lng": "-94.89971"
  },
  {
    "country": "UY",
    "name": "Young",
    "lat": "-32.69844",
    "lng": "-57.62693"
  },
  {
    "country": "UY",
    "name": "Villa Sara",
    "lat": "-33.2534",
    "lng": "-54.41947"
  },
  {
    "country": "UY",
    "name": "Villa del Carmen",
    "lat": "-33.23943",
    "lng": "-56.00936"
  },
  {
    "country": "UY",
    "name": "Vichadero",
    "lat": "-31.77794",
    "lng": "-54.69183"
  },
  {
    "country": "UY",
    "name": "Vergara",
    "lat": "-32.94419",
    "lng": "-53.9381"
  },
  {
    "country": "UY",
    "name": "Velázquez",
    "lat": "-34.03631",
    "lng": "-54.28054"
  },
  {
    "country": "UY",
    "name": "25 de Mayo",
    "lat": "-34.18917",
    "lng": "-56.33944"
  },
  {
    "country": "UY",
    "name": "25 de Agosto",
    "lat": "-34.41167",
    "lng": "-56.40222"
  },
  {
    "country": "UY",
    "name": "Tupambaé",
    "lat": "-32.83333",
    "lng": "-54.76667"
  },
  {
    "country": "UY",
    "name": "Trinidad",
    "lat": "-33.5165",
    "lng": "-56.89957"
  },
  {
    "country": "UY",
    "name": "Treinta y Tres",
    "lat": "-33.23333",
    "lng": "-54.38333"
  },
  {
    "country": "UY",
    "name": "Tranqueras",
    "lat": "-31.2",
    "lng": "-55.75"
  },
  {
    "country": "UY",
    "name": "Tomás Gomensoro",
    "lat": "-30.4287",
    "lng": "-57.43609"
  },
  {
    "country": "UY",
    "name": "Toledo",
    "lat": "-34.73807",
    "lng": "-56.09469"
  },
  {
    "country": "UY",
    "name": "Tarariras",
    "lat": "-34.26555",
    "lng": "-57.61866"
  },
  {
    "country": "UY",
    "name": "Tala",
    "lat": "-34.34349",
    "lng": "-55.76375"
  },
  {
    "country": "UY",
    "name": "Tacuarembó",
    "lat": "-31.71694",
    "lng": "-55.98111"
  },
  {
    "country": "UY",
    "name": "Villa Soriano",
    "lat": "-33.39811",
    "lng": "-58.32177"
  },
  {
    "country": "UY",
    "name": "Solís de Mataojo",
    "lat": "-34.59951",
    "lng": "-55.46808"
  },
  {
    "country": "UY",
    "name": "Soca",
    "lat": "-34.68432",
    "lng": "-55.702"
  },
  {
    "country": "UY",
    "name": "Sauce",
    "lat": "-34.65191",
    "lng": "-56.06431"
  },
  {
    "country": "UY",
    "name": "Sarandí Grande",
    "lat": "-33.73333",
    "lng": "-56.33333"
  },
  {
    "country": "UY",
    "name": "Sarandí del Yi",
    "lat": "-33.35",
    "lng": "-55.63333"
  },
  {
    "country": "UY",
    "name": "Santiago Vázquez",
    "lat": "-34.79028",
    "lng": "-56.35"
  },
  {
    "country": "UY",
    "name": "Santa Rosa",
    "lat": "-34.49819",
    "lng": "-56.03795"
  },
  {
    "country": "UY",
    "name": "Santa Lucía",
    "lat": "-34.45333",
    "lng": "-56.39056"
  },
  {
    "country": "UY",
    "name": "Santa Clara de Olimar",
    "lat": "-32.92254",
    "lng": "-54.94447"
  },
  {
    "country": "UY",
    "name": "Santa Catalina",
    "lat": "-33.791",
    "lng": "-57.48824"
  },
  {
    "country": "UY",
    "name": "Santa Bernardina",
    "lat": "-33.3536",
    "lng": "-56.52498"
  },
  {
    "country": "UY",
    "name": "San Ramón",
    "lat": "-34.29155",
    "lng": "-55.95571"
  },
  {
    "country": "UY",
    "name": "San José de Mayo",
    "lat": "-34.3375",
    "lng": "-56.71361"
  },
  {
    "country": "UY",
    "name": "San Javier",
    "lat": "-32.66523",
    "lng": "-58.1332"
  },
  {
    "country": "UY",
    "name": "San Jacinto",
    "lat": "-34.54465",
    "lng": "-55.87151"
  },
  {
    "country": "UY",
    "name": "San Félix",
    "lat": "-32.34631",
    "lng": "-58.10094"
  },
  {
    "country": "UY",
    "name": "San Carlos",
    "lat": "-34.79123",
    "lng": "-54.91824"
  },
  {
    "country": "UY",
    "name": "San Bautista",
    "lat": "-34.44016",
    "lng": "-55.95861"
  },
  {
    "country": "UY",
    "name": "San Antonio",
    "lat": "-34.4513",
    "lng": "-56.08036"
  },
  {
    "country": "UY",
    "name": "Salto",
    "lat": "-31.38333",
    "lng": "-57.96667"
  },
  {
    "country": "UY",
    "name": "Rosario",
    "lat": "-34.31667",
    "lng": "-57.35"
  },
  {
    "country": "UY",
    "name": "Rodríguez",
    "lat": "-34.381",
    "lng": "-56.53797"
  },
  {
    "country": "UY",
    "name": "Rocha",
    "lat": "-34.48333",
    "lng": "-54.33333"
  },
  {
    "country": "UY",
    "name": "Rivera",
    "lat": "-30.90534",
    "lng": "-55.55076"
  },
  {
    "country": "UY",
    "name": "Río Branco",
    "lat": "-32.59802",
    "lng": "-53.38583"
  },
  {
    "country": "UY",
    "name": "Rafael Perazza",
    "lat": "-34.52335",
    "lng": "-56.7971"
  },
  {
    "country": "UY",
    "name": "Quebracho",
    "lat": "-31.93526",
    "lng": "-57.9014"
  },
  {
    "country": "UY",
    "name": "Punta del Este",
    "lat": "-34.94747",
    "lng": "-54.93382"
  },
  {
    "country": "UY",
    "name": "Progreso",
    "lat": "-34.66737",
    "lng": "-56.21758"
  },
  {
    "country": "UY",
    "name": "Estación Porvenir",
    "lat": "-32.37085",
    "lng": "-57.85371"
  },
  {
    "country": "UY",
    "name": "Piriápolis",
    "lat": "-34.86287",
    "lng": "-55.27471"
  },
  {
    "country": "UY",
    "name": "Piedras Coloradas",
    "lat": "-32.37183",
    "lng": "-57.60901"
  },
  {
    "country": "UY",
    "name": "Paysandú",
    "lat": "-32.32139",
    "lng": "-58.07556"
  },
  {
    "country": "UY",
    "name": "Paso de los Toros",
    "lat": "-32.81667",
    "lng": "-56.51667"
  },
  {
    "country": "UY",
    "name": "Paso de Carrasco",
    "lat": "-34.86028",
    "lng": "-56.05222"
  },
  {
    "country": "UY",
    "name": "Pando",
    "lat": "-34.71716",
    "lng": "-55.9584"
  },
  {
    "country": "UY",
    "name": "Pan de Azúcar",
    "lat": "-34.7787",
    "lng": "-55.23582"
  },
  {
    "country": "UY",
    "name": "Palmitas",
    "lat": "-33.50719",
    "lng": "-57.80079"
  },
  {
    "country": "UY",
    "name": "Ombúes de Lavalle",
    "lat": "-33.93783",
    "lng": "-57.80959"
  },
  {
    "country": "UY",
    "name": "Nuevo Berlín",
    "lat": "-32.97974",
    "lng": "-58.05858"
  },
  {
    "country": "UY",
    "name": "Nueva Palmira",
    "lat": "-33.87031",
    "lng": "-58.41176"
  },
  {
    "country": "UY",
    "name": "Nueva Helvecia",
    "lat": "-34.3",
    "lng": "-57.23333"
  },
  {
    "country": "UY",
    "name": "Montevideo",
    "lat": "-34.90328",
    "lng": "-56.18816"
  },
  {
    "country": "UY",
    "name": "Montes",
    "lat": "-34.49339",
    "lng": "-55.56219"
  },
  {
    "country": "UY",
    "name": "Minas de Corrales",
    "lat": "-31.57375",
    "lng": "-55.47075"
  },
  {
    "country": "UY",
    "name": "Minas",
    "lat": "-34.37589",
    "lng": "-55.23771"
  },
  {
    "country": "UY",
    "name": "Migues",
    "lat": "-34.48759",
    "lng": "-55.62793"
  },
  {
    "country": "UY",
    "name": "Mercedes",
    "lat": "-33.2524",
    "lng": "-58.03047"
  },
  {
    "country": "UY",
    "name": "Melo",
    "lat": "-32.37028",
    "lng": "-54.1675"
  },
  {
    "country": "UY",
    "name": "Mariscala",
    "lat": "-34.04085",
    "lng": "-54.77732"
  },
  {
    "country": "UY",
    "name": "Maldonado",
    "lat": "-34.9",
    "lng": "-54.95"
  },
  {
    "country": "UY",
    "name": "Los Cerrillos",
    "lat": "-34.605",
    "lng": "-56.35639"
  },
  {
    "country": "UY",
    "name": "Libertad",
    "lat": "-34.63459",
    "lng": "-56.61739"
  },
  {
    "country": "UY",
    "name": "Las Toscas",
    "lat": "-34.73333",
    "lng": "-55.71667"
  },
  {
    "country": "UY",
    "name": "Las Piedras",
    "lat": "-34.7302",
    "lng": "-56.21915"
  },
  {
    "country": "UY",
    "name": "Las Piedras",
    "lat": "-30.26204",
    "lng": "-57.58174"
  },
  {
    "country": "UY",
    "name": "Lascano",
    "lat": "-33.67235",
    "lng": "-54.2065"
  },
  {
    "country": "UY",
    "name": "La Paz",
    "lat": "-34.76031",
    "lng": "-56.2259"
  },
  {
    "country": "UY",
    "name": "La Paloma",
    "lat": "-34.66268",
    "lng": "-54.16452"
  },
  {
    "country": "UY",
    "name": "La Paloma",
    "lat": "-32.72689",
    "lng": "-55.5827"
  },
  {
    "country": "UY",
    "name": "La Floresta",
    "lat": "-34.75572",
    "lng": "-55.68141"
  },
  {
    "country": "UY",
    "name": "Juan L. Lacaze",
    "lat": "-34.41888",
    "lng": "-57.45285"
  },
  {
    "country": "UY",
    "name": "José Pedro Varela",
    "lat": "-33.45451",
    "lng": "-54.53586"
  },
  {
    "country": "UY",
    "name": "José Enrique Rodó",
    "lat": "-33.69618",
    "lng": "-57.53153"
  },
  {
    "country": "UY",
    "name": "José Batlle y Ordóñez",
    "lat": "-33.46667",
    "lng": "-55.11667"
  },
  {
    "country": "UY",
    "name": "Joaquín Suárez",
    "lat": "-34.73501",
    "lng": "-56.0347"
  },
  {
    "country": "UY",
    "name": "Juanicó",
    "lat": "-34.59454",
    "lng": "-56.25334"
  },
  {
    "country": "UY",
    "name": "Isidoro Noblía",
    "lat": "-31.96218",
    "lng": "-54.12309"
  },
  {
    "country": "UY",
    "name": "Guichón",
    "lat": "-32.35846",
    "lng": "-57.19778"
  },
  {
    "country": "UY",
    "name": "Fray Bentos",
    "lat": "-33.11651",
    "lng": "-58.31067"
  },
  {
    "country": "UY",
    "name": "Florida",
    "lat": "-34.09556",
    "lng": "-56.21417"
  },
  {
    "country": "UY",
    "name": "Florencio Sánchez",
    "lat": "-33.87785",
    "lng": "-57.37166"
  },
  {
    "country": "UY",
    "name": "Empalme Olmos",
    "lat": "-34.69753",
    "lng": "-55.89268"
  },
  {
    "country": "UY",
    "name": "Ecilda Paullier",
    "lat": "-34.35778",
    "lng": "-57.04883"
  },
  {
    "country": "UY",
    "name": "Durazno",
    "lat": "-33.38056",
    "lng": "-56.52361"
  },
  {
    "country": "UY",
    "name": "Dolores",
    "lat": "-33.53009",
    "lng": "-58.21701"
  },
  {
    "country": "UY",
    "name": "Dieciocho de Julio",
    "lat": "-33.68216",
    "lng": "-53.55325"
  },
  {
    "country": "UY",
    "name": "Delta del Tigre",
    "lat": "-34.76488",
    "lng": "-56.3645"
  },
  {
    "country": "UY",
    "name": "Curtina",
    "lat": "-32.15",
    "lng": "-56.11667"
  },
  {
    "country": "UY",
    "name": "Villa Constitución",
    "lat": "-31.06913",
    "lng": "-57.84946"
  },
  {
    "country": "UY",
    "name": "Colonia del Sacramento",
    "lat": "-34.46262",
    "lng": "-57.83976"
  },
  {
    "country": "UY",
    "name": "Chui",
    "lat": "-33.69792",
    "lng": "-53.45926"
  },
  {
    "country": "UY",
    "name": "Alejandro Gallinal",
    "lat": "-33.86252",
    "lng": "-55.54264"
  },
  {
    "country": "UY",
    "name": "Cebollatí",
    "lat": "-33.26703",
    "lng": "-53.79425"
  },
  {
    "country": "UY",
    "name": "Casupá",
    "lat": "-34.09994",
    "lng": "-55.64811"
  },
  {
    "country": "UY",
    "name": "Castillos",
    "lat": "-34.19871",
    "lng": "-53.85919"
  },
  {
    "country": "UY",
    "name": "Carmelo",
    "lat": "-34.00023",
    "lng": "-58.28402"
  },
  {
    "country": "UY",
    "name": "Carlos Reyles",
    "lat": "-33.05658",
    "lng": "-56.47652"
  },
  {
    "country": "UY",
    "name": "Cardona",
    "lat": "-33.87049",
    "lng": "-57.36954"
  },
  {
    "country": "UY",
    "name": "Cardal",
    "lat": "-34.29056",
    "lng": "-56.38889"
  },
  {
    "country": "UY",
    "name": "Canelones",
    "lat": "-34.52278",
    "lng": "-56.27778"
  },
  {
    "country": "UY",
    "name": "Blanquillo",
    "lat": "-32.76667",
    "lng": "-55.63333"
  },
  {
    "country": "UY",
    "name": "Bella Unión",
    "lat": "-30.25966",
    "lng": "-57.59919"
  },
  {
    "country": "UY",
    "name": "Belén",
    "lat": "-30.78716",
    "lng": "-57.77577"
  },
  {
    "country": "UY",
    "name": "Baltasar Brum",
    "lat": "-30.71905",
    "lng": "-57.32596"
  },
  {
    "country": "UY",
    "name": "Atlántida",
    "lat": "-34.7719",
    "lng": "-55.7584"
  },
  {
    "country": "UY",
    "name": "Artigas",
    "lat": "-30.4",
    "lng": "-56.46667"
  },
  {
    "country": "UY",
    "name": "Aiguá",
    "lat": "-34.20498",
    "lng": "-54.75665"
  },
  {
    "country": "UY",
    "name": "Aguas Corrientes",
    "lat": "-34.52194",
    "lng": "-56.39361"
  },
  {
    "country": "UY",
    "name": "Aceguá",
    "lat": "-31.87178",
    "lng": "-54.16351"
  },
  {
    "country": "UY",
    "name": "Puntas de Valdéz",
    "lat": "-34.5855",
    "lng": "-56.70097"
  },
  {
    "country": "UY",
    "name": "Colonia Nicolich",
    "lat": "-34.81516",
    "lng": "-56.02435"
  },
  {
    "country": "UY",
    "name": "Barra de Carrasco",
    "lat": "-34.87722",
    "lng": "-56.02972"
  },
  {
    "country": "UY",
    "name": "Pajas Blancas",
    "lat": "-34.80167",
    "lng": "-56.33417"
  },
  {
    "country": "UY",
    "name": "Barros Blancos",
    "lat": "-34.7524",
    "lng": "-56.00259"
  },
  {
    "country": "UZ",
    "name": "Nukus",
    "lat": "42.45306",
    "lng": "59.61028"
  },
  {
    "country": "UZ",
    "name": "Mŭynoq",
    "lat": "43.76833",
    "lng": "59.02139"
  },
  {
    "country": "UZ",
    "name": "Qanliko‘l",
    "lat": "42.8395",
    "lng": "59.00093"
  },
  {
    "country": "UZ",
    "name": "Khŭjayli",
    "lat": "42.40043",
    "lng": "59.46005"
  },
  {
    "country": "UZ",
    "name": "Kegeyli Shahar",
    "lat": "42.77667",
    "lng": "59.60778"
  },
  {
    "country": "UZ",
    "name": "Qozonketkan",
    "lat": "43.01907",
    "lng": "59.36425"
  },
  {
    "country": "UZ",
    "name": "Oltinko‘l",
    "lat": "43.06874",
    "lng": "58.90372"
  },
  {
    "country": "UZ",
    "name": "Oqmang‘it",
    "lat": "42.59889",
    "lng": "59.53444"
  },
  {
    "country": "UZ",
    "name": "Qo‘ng‘irot Shahri",
    "lat": "43.05207",
    "lng": "58.84596"
  },
  {
    "country": "UZ",
    "name": "Xo‘jayli Shahri",
    "lat": "42.40881",
    "lng": "59.44544"
  },
  {
    "country": "UZ",
    "name": "Chimboy Shahri",
    "lat": "42.92952",
    "lng": "59.78199"
  },
  {
    "country": "UZ",
    "name": "Mo‘ynoq Shahri",
    "lat": "43.77877",
    "lng": "59.03039"
  },
  {
    "country": "UZ",
    "name": "Shumanay Shahri",
    "lat": "42.63433",
    "lng": "58.9306"
  },
  {
    "country": "UZ",
    "name": "Zomin",
    "lat": "39.96056",
    "lng": "68.39583"
  },
  {
    "country": "UZ",
    "name": "Nishon Tumani",
    "lat": "38.69395",
    "lng": "65.67512"
  },
  {
    "country": "UZ",
    "name": "Urgut",
    "lat": "39.40222",
    "lng": "67.24306"
  },
  {
    "country": "UZ",
    "name": "Mug‘lon Shahar",
    "lat": "38.91878",
    "lng": "65.41217"
  },
  {
    "country": "UZ",
    "name": "Tirmiz",
    "lat": "37.22417",
    "lng": "67.27833"
  },
  {
    "country": "UZ",
    "name": "Sho‘rchi",
    "lat": "37.99944",
    "lng": "67.7875"
  },
  {
    "country": "UZ",
    "name": "Shahrisabz",
    "lat": "39.05778",
    "lng": "66.83417"
  },
  {
    "country": "UZ",
    "name": "Shohimardon",
    "lat": "39.98322",
    "lng": "71.80512"
  },
  {
    "country": "UZ",
    "name": "Samarqand",
    "lat": "39.65417",
    "lng": "66.95972"
  },
  {
    "country": "UZ",
    "name": "Romiton",
    "lat": "39.92944",
    "lng": "64.37944"
  },
  {
    "country": "UZ",
    "name": "Qarshi",
    "lat": "38.86056",
    "lng": "65.78905"
  },
  {
    "country": "UZ",
    "name": "Muborak",
    "lat": "39.25528",
    "lng": "65.15278"
  },
  {
    "country": "UZ",
    "name": "Yangi Mirishkor",
    "lat": "38.85143",
    "lng": "65.27789"
  },
  {
    "country": "UZ",
    "name": "Kitob",
    "lat": "39.08425",
    "lng": "66.83318"
  },
  {
    "country": "UZ",
    "name": "Kattaqo‘rg‘on",
    "lat": "39.89889",
    "lng": "66.25611"
  },
  {
    "country": "UZ",
    "name": "Koson",
    "lat": "39.0375",
    "lng": "65.585"
  },
  {
    "country": "UZ",
    "name": "Qorovulbozor",
    "lat": "39.50056",
    "lng": "64.79361"
  },
  {
    "country": "UZ",
    "name": "Karakul’",
    "lat": "39.53333",
    "lng": "63.83333"
  },
  {
    "country": "UZ",
    "name": "Qorako’l",
    "lat": "39.49944",
    "lng": "63.85389"
  },
  {
    "country": "UZ",
    "name": "Kogon",
    "lat": "39.72278",
    "lng": "64.55167"
  },
  {
    "country": "UZ",
    "name": "Ishtixon",
    "lat": "39.96639",
    "lng": "66.48611"
  },
  {
    "country": "UZ",
    "name": "G‘uzor",
    "lat": "38.62083",
    "lng": "66.24806"
  },
  {
    "country": "UZ",
    "name": "Galaosiyo",
    "lat": "39.85778",
    "lng": "64.44833"
  },
  {
    "country": "UZ",
    "name": "Juma",
    "lat": "39.71611",
    "lng": "66.66417"
  },
  {
    "country": "UZ",
    "name": "Jomboy",
    "lat": "39.69889",
    "lng": "67.09333"
  },
  {
    "country": "UZ",
    "name": "Denov",
    "lat": "38.26746",
    "lng": "67.89886"
  },
  {
    "country": "UZ",
    "name": "Daxbet",
    "lat": "39.76389",
    "lng": "66.9125"
  },
  {
    "country": "UZ",
    "name": "Chiroqchi",
    "lat": "39.03361",
    "lng": "66.57222"
  },
  {
    "country": "UZ",
    "name": "Chelak",
    "lat": "39.92028",
    "lng": "66.86111"
  },
  {
    "country": "UZ",
    "name": "Charxin",
    "lat": "39.69667",
    "lng": "66.76861"
  },
  {
    "country": "UZ",
    "name": "Bulung’ur",
    "lat": "39.76472",
    "lng": "67.27139"
  },
  {
    "country": "UZ",
    "name": "Bukhara",
    "lat": "39.77472",
    "lng": "64.42861"
  },
  {
    "country": "UZ",
    "name": "Beshkent",
    "lat": "38.82139",
    "lng": "65.65306"
  },
  {
    "country": "UZ",
    "name": "Boysun",
    "lat": "38.20835",
    "lng": "67.20664"
  },
  {
    "country": "UZ",
    "name": "Olot",
    "lat": "39.415",
    "lng": "63.80333"
  },
  {
    "country": "UZ",
    "name": "Oqtosh",
    "lat": "39.92139",
    "lng": "65.92528"
  },
  {
    "country": "UZ",
    "name": "Qorovulbozor Shahri",
    "lat": "39.50308",
    "lng": "64.81142"
  },
  {
    "country": "UZ",
    "name": "Qorashina",
    "lat": "38.34185",
    "lng": "66.56342"
  },
  {
    "country": "UZ",
    "name": "Shahrisabz Shahri",
    "lat": "39.05206",
    "lng": "66.82083"
  },
  {
    "country": "UZ",
    "name": "Koson Shahri",
    "lat": "39.04472",
    "lng": "65.59082"
  },
  {
    "country": "UZ",
    "name": "Kitob Shahri",
    "lat": "39.12251",
    "lng": "66.8757"
  },
  {
    "country": "UZ",
    "name": "Muborak Shahri",
    "lat": "39.25778",
    "lng": "65.15674"
  },
  {
    "country": "UZ",
    "name": "Beshkent Shahri",
    "lat": "38.81107",
    "lng": "65.64246"
  },
  {
    "country": "UZ",
    "name": "G‘uzor Shahri",
    "lat": "38.62596",
    "lng": "66.24515"
  },
  {
    "country": "UZ",
    "name": "Qamashi Shahri",
    "lat": "38.81998",
    "lng": "66.46441"
  },
  {
    "country": "UZ",
    "name": "Chiroqchi Shahri",
    "lat": "39.02727",
    "lng": "66.58083"
  },
  {
    "country": "UZ",
    "name": "Yakkabog‘ Shahri",
    "lat": "38.97664",
    "lng": "66.68867"
  },
  {
    "country": "UZ",
    "name": "Yangi-Nishon Shahri",
    "lat": "38.64501",
    "lng": "65.68952"
  },
  {
    "country": "UZ",
    "name": "Ravon",
    "lat": "39.97724",
    "lng": "71.13467"
  },
  {
    "country": "UZ",
    "name": "Zafar",
    "lat": "40.98333",
    "lng": "68.9"
  },
  {
    "country": "UZ",
    "name": "Yozyovon",
    "lat": "40.66139",
    "lng": "71.74361"
  },
  {
    "country": "UZ",
    "name": "Yaypan",
    "lat": "40.37583",
    "lng": "70.81556"
  },
  {
    "country": "UZ",
    "name": "Yangiyŭl",
    "lat": "41.11202",
    "lng": "69.0471"
  },
  {
    "country": "UZ",
    "name": "Yangiyer",
    "lat": "40.275",
    "lng": "68.8225"
  },
  {
    "country": "UZ",
    "name": "Yangirabot",
    "lat": "40.02539",
    "lng": "65.96095"
  },
  {
    "country": "UZ",
    "name": "Yangiqo‘rg‘on",
    "lat": "41.19474",
    "lng": "71.72385"
  },
  {
    "country": "UZ",
    "name": "Yangiqo‘rg‘on",
    "lat": "40.55389",
    "lng": "71.14667"
  },
  {
    "country": "UZ",
    "name": "Yangiobod",
    "lat": "41.11919",
    "lng": "70.09406"
  },
  {
    "country": "UZ",
    "name": "Vodil",
    "lat": "40.17424",
    "lng": "71.73013"
  },
  {
    "country": "UZ",
    "name": "Wobkent",
    "lat": "40.03028",
    "lng": "64.515"
  },
  {
    "country": "UZ",
    "name": "Uychi",
    "lat": "41.08073",
    "lng": "71.92331"
  },
  {
    "country": "UZ",
    "name": "Ŭrtaowul",
    "lat": "41.18667",
    "lng": "69.14528"
  },
  {
    "country": "UZ",
    "name": "Urganch",
    "lat": "41.55",
    "lng": "60.63333"
  },
  {
    "country": "UZ",
    "name": "Dashtobod",
    "lat": "40.12694",
    "lng": "68.49444"
  },
  {
    "country": "UZ",
    "name": "Uchqŭrghon Shahri",
    "lat": "41.11371",
    "lng": "72.07915"
  },
  {
    "country": "UZ",
    "name": "Uchko‘prik",
    "lat": "40.54222",
    "lng": "71.06083"
  },
  {
    "country": "UZ",
    "name": "Tŭytepa",
    "lat": "41.0321",
    "lng": "69.36253"
  },
  {
    "country": "UZ",
    "name": "To‘rqao‘rg‘on",
    "lat": "40.99984",
    "lng": "71.51162"
  },
  {
    "country": "UZ",
    "name": "Toshloq",
    "lat": "40.47722",
    "lng": "71.76778"
  },
  {
    "country": "UZ",
    "name": "Tashkent",
    "lat": "41.26465",
    "lng": "69.21627"
  },
  {
    "country": "UZ",
    "name": "Toshbuloq",
    "lat": "40.91617",
    "lng": "71.57819"
  },
  {
    "country": "UZ",
    "name": "Tomdibuloq",
    "lat": "41.7508",
    "lng": "64.61711"
  },
  {
    "country": "UZ",
    "name": "Taxtako‘pir",
    "lat": "43.01171",
    "lng": "60.30111"
  },
  {
    "country": "UZ",
    "name": "Sirdaryo",
    "lat": "40.84361",
    "lng": "68.66167"
  },
  {
    "country": "UZ",
    "name": "Showot",
    "lat": "41.65583",
    "lng": "60.3025"
  },
  {
    "country": "UZ",
    "name": "Shahrixon",
    "lat": "40.71331",
    "lng": "72.05706"
  },
  {
    "country": "UZ",
    "name": "Shofirkon",
    "lat": "40.12",
    "lng": "64.50139"
  },
  {
    "country": "UZ",
    "name": "Salor",
    "lat": "41.37222",
    "lng": "69.38167"
  },
  {
    "country": "UZ",
    "name": "Rishton",
    "lat": "40.35667",
    "lng": "71.28472"
  },
  {
    "country": "UZ",
    "name": "Qŭshkŭpir",
    "lat": "41.535",
    "lng": "60.34556"
  },
  {
    "country": "UZ",
    "name": "Qo‘qon",
    "lat": "40.52861",
    "lng": "70.9425"
  },
  {
    "country": "UZ",
    "name": "Piskent",
    "lat": "40.89722",
    "lng": "69.35056"
  },
  {
    "country": "UZ",
    "name": "Poytug‘",
    "lat": "40.8977",
    "lng": "72.2449"
  },
  {
    "country": "UZ",
    "name": "Payshanba",
    "lat": "40.00778",
    "lng": "66.23694"
  },
  {
    "country": "UZ",
    "name": "Parkent",
    "lat": "41.29444",
    "lng": "69.67639"
  },
  {
    "country": "UZ",
    "name": "Pop",
    "lat": "40.87361",
    "lng": "71.10889"
  },
  {
    "country": "UZ",
    "name": "Paxtakor",
    "lat": "40.31528",
    "lng": "67.95444"
  },
  {
    "country": "UZ",
    "name": "Paxtaobod",
    "lat": "40.92936",
    "lng": "72.49687"
  },
  {
    "country": "UZ",
    "name": "Olmaliq",
    "lat": "40.84472",
    "lng": "69.59833"
  },
  {
    "country": "UZ",
    "name": "Ohangaron",
    "lat": "40.90639",
    "lng": "69.63833"
  },
  {
    "country": "UZ",
    "name": "Nurota",
    "lat": "40.56139",
    "lng": "65.68861"
  },
  {
    "country": "UZ",
    "name": "Novyy Turtkul’",
    "lat": "41.55",
    "lng": "61.01667"
  },
  {
    "country": "UZ",
    "name": "Navoiy",
    "lat": "40.08444",
    "lng": "65.37917"
  },
  {
    "country": "UZ",
    "name": "Navbahor",
    "lat": "40.48104",
    "lng": "70.77093"
  },
  {
    "country": "UZ",
    "name": "Namangan",
    "lat": "40.9983",
    "lng": "71.67257"
  },
  {
    "country": "UZ",
    "name": "Marhamat",
    "lat": "40.50236",
    "lng": "72.32646"
  },
  {
    "country": "UZ",
    "name": "Marhamat",
    "lat": "40.48048",
    "lng": "72.31388"
  },
  {
    "country": "UZ",
    "name": "Marg‘ilon",
    "lat": "40.47237",
    "lng": "71.72463"
  },
  {
    "country": "UZ",
    "name": "Manghit",
    "lat": "42.11556",
    "lng": "60.05972"
  },
  {
    "country": "UZ",
    "name": "Asaka",
    "lat": "40.64153",
    "lng": "72.23868"
  },
  {
    "country": "UZ",
    "name": "Qiziltepa",
    "lat": "40.03306",
    "lng": "64.85"
  },
  {
    "country": "UZ",
    "name": "Kuyganyor",
    "lat": "40.85444",
    "lng": "72.30734"
  },
  {
    "country": "UZ",
    "name": "Quvasoy",
    "lat": "40.29721",
    "lng": "71.98026"
  },
  {
    "country": "UZ",
    "name": "Qo‘rg‘ontepa",
    "lat": "40.73192",
    "lng": "72.76177"
  },
  {
    "country": "UZ",
    "name": "Yangi Marg‘ilon",
    "lat": "40.42722",
    "lng": "71.71889"
  },
  {
    "country": "UZ",
    "name": "Kirguli",
    "lat": "40.43553",
    "lng": "71.76721"
  },
  {
    "country": "UZ",
    "name": "Qibray",
    "lat": "41.38972",
    "lng": "69.465"
  },
  {
    "country": "UZ",
    "name": "Xo‘jaobod",
    "lat": "40.66886",
    "lng": "72.56002"
  },
  {
    "country": "UZ",
    "name": "Khiwa",
    "lat": "41.37833",
    "lng": "60.36389"
  },
  {
    "country": "UZ",
    "name": "Hamza",
    "lat": "40.42762",
    "lng": "71.50534"
  },
  {
    "country": "UZ",
    "name": "Haqqulobod",
    "lat": "40.91667",
    "lng": "72.11667"
  },
  {
    "country": "UZ",
    "name": "Kosonsoy",
    "lat": "41.24944",
    "lng": "71.54738"
  },
  {
    "country": "UZ",
    "name": "Qorao‘zak",
    "lat": "43.02207",
    "lng": "60.01701"
  },
  {
    "country": "UZ",
    "name": "Konimex",
    "lat": "40.27593",
    "lng": "65.14511"
  },
  {
    "country": "UZ",
    "name": "Jizzax",
    "lat": "40.11583",
    "lng": "67.84222"
  },
  {
    "country": "UZ",
    "name": "Iskandar",
    "lat": "41.55389",
    "lng": "69.70083"
  },
  {
    "country": "UZ",
    "name": "Hazorasp",
    "lat": "41.31944",
    "lng": "61.07417"
  },
  {
    "country": "UZ",
    "name": "Gurlan",
    "lat": "41.84472",
    "lng": "60.39194"
  },
  {
    "country": "UZ",
    "name": "Guliston",
    "lat": "40.48972",
    "lng": "68.78417"
  },
  {
    "country": "UZ",
    "name": "Ghijduwon",
    "lat": "40.1",
    "lng": "64.68333"
  },
  {
    "country": "UZ",
    "name": "Gazli",
    "lat": "40.13333",
    "lng": "63.45"
  },
  {
    "country": "UZ",
    "name": "G‘azalkent",
    "lat": "41.55806",
    "lng": "69.77083"
  },
  {
    "country": "UZ",
    "name": "Gagarin",
    "lat": "40.66194",
    "lng": "68.17222"
  },
  {
    "country": "UZ",
    "name": "Fergana",
    "lat": "40.38421",
    "lng": "71.78432"
  },
  {
    "country": "UZ",
    "name": "Amir Timur",
    "lat": "41.01944",
    "lng": "68.94083"
  },
  {
    "country": "UZ",
    "name": "Dŭstlik",
    "lat": "40.52472",
    "lng": "68.03583"
  },
  {
    "country": "UZ",
    "name": "Dang‘ara",
    "lat": "40.58389",
    "lng": "70.91444"
  },
  {
    "country": "UZ",
    "name": "Chust",
    "lat": "41.00329",
    "lng": "71.23791"
  },
  {
    "country": "UZ",
    "name": "Chirchiq",
    "lat": "41.46889",
    "lng": "69.58222"
  },
  {
    "country": "UZ",
    "name": "Chinoz",
    "lat": "40.93633",
    "lng": "68.76128"
  },
  {
    "country": "UZ",
    "name": "Kyzyldzhar",
    "lat": "41.56667",
    "lng": "70.01667"
  },
  {
    "country": "UZ",
    "name": "Chortoq",
    "lat": "41.06924",
    "lng": "71.82372"
  },
  {
    "country": "UZ",
    "name": "Buloqboshi",
    "lat": "40.62907",
    "lng": "72.50212"
  },
  {
    "country": "UZ",
    "name": "Bo‘ka",
    "lat": "40.81108",
    "lng": "69.19417"
  },
  {
    "country": "UZ",
    "name": "Beshrabot",
    "lat": "40.19761",
    "lng": "65.33527"
  },
  {
    "country": "UZ",
    "name": "Beshariq",
    "lat": "40.43583",
    "lng": "70.61028"
  },
  {
    "country": "UZ",
    "name": "Beruniy",
    "lat": "41.69111",
    "lng": "60.7525"
  },
  {
    "country": "UZ",
    "name": "Bektemir",
    "lat": "41.20972",
    "lng": "69.33417"
  },
  {
    "country": "UZ",
    "name": "Bekobod",
    "lat": "40.22083",
    "lng": "69.26972"
  },
  {
    "country": "UZ",
    "name": "Baliqchi",
    "lat": "40.90499",
    "lng": "71.84737"
  },
  {
    "country": "UZ",
    "name": "Bag‘dod",
    "lat": "40.46306",
    "lng": "71.21222"
  },
  {
    "country": "UZ",
    "name": "Angren",
    "lat": "41.01667",
    "lng": "70.14361"
  },
  {
    "country": "UZ",
    "name": "Andijon",
    "lat": "40.78206",
    "lng": "72.34424"
  },
  {
    "country": "UZ",
    "name": "Oltinko‘l",
    "lat": "40.80104",
    "lng": "72.17306"
  },
  {
    "country": "UZ",
    "name": "Oltiariq",
    "lat": "40.39194",
    "lng": "71.47417"
  },
  {
    "country": "UZ",
    "name": "Oxunboboyev",
    "lat": "40.71984",
    "lng": "72.64282"
  },
  {
    "country": "UZ",
    "name": "Oqoltin",
    "lat": "40.74649",
    "lng": "71.70031"
  },
  {
    "country": "UZ",
    "name": "Quva",
    "lat": "40.52204",
    "lng": "72.07292"
  },
  {
    "country": "UZ",
    "name": "Beruniy Shahri",
    "lat": "41.69904",
    "lng": "60.75501"
  },
  {
    "country": "UZ",
    "name": "To‘rtko‘l Shahri",
    "lat": "41.56055",
    "lng": "61.0018"
  },
  {
    "country": "UZ",
    "name": "Bo‘ston Shahri",
    "lat": "41.84607",
    "lng": "60.94744"
  },
  {
    "country": "UZ",
    "name": "Mang‘it Shahri",
    "lat": "42.12215",
    "lng": "60.06276"
  },
  {
    "country": "UZ",
    "name": "Uchquduq Shahri",
    "lat": "42.15001",
    "lng": "63.55221"
  },
  {
    "country": "UZ",
    "name": "Karmana Shahri",
    "lat": "40.13782",
    "lng": "65.37545"
  },
  {
    "country": "UZ",
    "name": "Qiziltepa Shahri",
    "lat": "40.0254",
    "lng": "64.82885"
  },
  {
    "country": "UZ",
    "name": "Nurota Shahri",
    "lat": "40.56762",
    "lng": "65.67947"
  },
  {
    "country": "UZ",
    "name": "Kosonsoy Shahri",
    "lat": "41.26327",
    "lng": "71.54239"
  },
  {
    "country": "UZ",
    "name": "Chortoq Shahri",
    "lat": "41.07703",
    "lng": "71.81772"
  },
  {
    "country": "UZ",
    "name": "Pop Shahri",
    "lat": "40.87642",
    "lng": "71.1022"
  },
  {
    "country": "UZ",
    "name": "Tŭragŭrghon Shahri",
    "lat": "41.00334",
    "lng": "71.51056"
  },
  {
    "country": "UZ",
    "name": "Langar",
    "lat": "40.5205",
    "lng": "71.66015"
  },
  {
    "country": "VA",
    "name": "Vatican City",
    "lat": "41.90268",
    "lng": "12.45414"
  },
  {
    "country": "VC",
    "name": "Port Elizabeth",
    "lat": "13.01102",
    "lng": "-61.23548"
  },
  {
    "country": "VC",
    "name": "Layou",
    "lat": "13.20175",
    "lng": "-61.27014"
  },
  {
    "country": "VC",
    "name": "Kingstown",
    "lat": "13.15527",
    "lng": "-61.22742"
  },
  {
    "country": "VC",
    "name": "Georgetown",
    "lat": "13.28054",
    "lng": "-61.1185"
  },
  {
    "country": "VC",
    "name": "Chateaubelair",
    "lat": "13.29069",
    "lng": "-61.24043"
  },
  {
    "country": "VC",
    "name": "Byera Village",
    "lat": "13.25636",
    "lng": "-61.11954"
  },
  {
    "country": "VC",
    "name": "Biabou",
    "lat": "13.1943",
    "lng": "-61.13904"
  },
  {
    "country": "VC",
    "name": "Barrouallie",
    "lat": "13.23676",
    "lng": "-61.27275"
  },
  {
    "country": "VC",
    "name": "Kingstown Park",
    "lat": "13.15924",
    "lng": "-61.23161"
  },
  {
    "country": "VE",
    "name": "La Asunción",
    "lat": "11.03333",
    "lng": "-63.86278"
  },
  {
    "country": "VE",
    "name": "Caricuao",
    "lat": "10.43337",
    "lng": "-66.98313"
  },
  {
    "country": "VE",
    "name": "Tocuyito",
    "lat": "10.11347",
    "lng": "-68.06783"
  },
  {
    "country": "VE",
    "name": "El Chaparro",
    "lat": "9.15204",
    "lng": "-65.01732"
  },
  {
    "country": "VE",
    "name": "Anaco",
    "lat": "9.42958",
    "lng": "-64.46428"
  },
  {
    "country": "VE",
    "name": "Santa Cruz de Guacas",
    "lat": "7.44329",
    "lng": "-71.30139"
  },
  {
    "country": "VE",
    "name": "El Real",
    "lat": "8.43525",
    "lng": "-69.99633"
  },
  {
    "country": "VE",
    "name": "Puerto Vivas",
    "lat": "7.50005",
    "lng": "-71.84446"
  },
  {
    "country": "VE",
    "name": "La Mula",
    "lat": "8.57084",
    "lng": "-70.37524"
  },
  {
    "country": "VE",
    "name": "Los Guasimitos",
    "lat": "8.66435",
    "lng": "-70.23216"
  },
  {
    "country": "VE",
    "name": "Alto Barinas",
    "lat": "8.5931",
    "lng": "-70.2261"
  },
  {
    "country": "VE",
    "name": "Zea",
    "lat": "8.37706",
    "lng": "-71.78398"
  },
  {
    "country": "VE",
    "name": "Zaraza",
    "lat": "9.35029",
    "lng": "-65.32452"
  },
  {
    "country": "VE",
    "name": "Yumare",
    "lat": "10.59703",
    "lng": "-68.67328"
  },
  {
    "country": "VE",
    "name": "Yaritagua",
    "lat": "10.08081",
    "lng": "-69.1242"
  },
  {
    "country": "VE",
    "name": "Yaracal",
    "lat": "10.96985",
    "lng": "-68.54648"
  },
  {
    "country": "VE",
    "name": "Yaguaraparo",
    "lat": "10.56839",
    "lng": "-62.82628"
  },
  {
    "country": "VE",
    "name": "Villa de Cura",
    "lat": "10.03863",
    "lng": "-67.48938"
  },
  {
    "country": "VE",
    "name": "Villa Bruzual",
    "lat": "9.33186",
    "lng": "-69.11968"
  },
  {
    "country": "VE",
    "name": "Las Casitas del Vegon de Nutrias",
    "lat": "8.23704",
    "lng": "-69.4183"
  },
  {
    "country": "VE",
    "name": "Valle de La Pascua",
    "lat": "9.21554",
    "lng": "-66.00734"
  },
  {
    "country": "VE",
    "name": "Valle de Guanape",
    "lat": "9.90999",
    "lng": "-65.67405"
  },
  {
    "country": "VE",
    "name": "Valera",
    "lat": "9.31778",
    "lng": "-70.60361"
  },
  {
    "country": "VE",
    "name": "Valencia",
    "lat": "10.16202",
    "lng": "-68.00765"
  },
  {
    "country": "VE",
    "name": "Urumaco",
    "lat": "11.2007",
    "lng": "-70.25597"
  },
  {
    "country": "VE",
    "name": "Ureña",
    "lat": "7.91857",
    "lng": "-72.44708"
  },
  {
    "country": "VE",
    "name": "Uracoa",
    "lat": "8.99432",
    "lng": "-62.35202"
  },
  {
    "country": "VE",
    "name": "Urachiche",
    "lat": "10.15847",
    "lng": "-69.00782"
  },
  {
    "country": "VE",
    "name": "Upata",
    "lat": "8.0162",
    "lng": "-62.40561"
  },
  {
    "country": "VE",
    "name": "Umuquena",
    "lat": "8.26648",
    "lng": "-72.06432"
  },
  {
    "country": "VE",
    "name": "Turmero",
    "lat": "10.22856",
    "lng": "-67.47421"
  },
  {
    "country": "VE",
    "name": "Tunapuy",
    "lat": "10.5748",
    "lng": "-63.10751"
  },
  {
    "country": "VE",
    "name": "Tumeremo",
    "lat": "7.29861",
    "lng": "-61.50497"
  },
  {
    "country": "VE",
    "name": "Tucupita",
    "lat": "9.05806",
    "lng": "-62.05"
  },
  {
    "country": "VE",
    "name": "Tucupido",
    "lat": "9.27304",
    "lng": "-65.77153"
  },
  {
    "country": "VE",
    "name": "Tucaní",
    "lat": "8.97003",
    "lng": "-71.27277"
  },
  {
    "country": "VE",
    "name": "Tucacas",
    "lat": "10.79006",
    "lng": "-68.32564"
  },
  {
    "country": "VE",
    "name": "Trujillo",
    "lat": "9.36583",
    "lng": "-70.43694"
  },
  {
    "country": "VE",
    "name": "Tovar",
    "lat": "8.33015",
    "lng": "-71.75277"
  },
  {
    "country": "VE",
    "name": "Torunos",
    "lat": "8.50015",
    "lng": "-70.08056"
  },
  {
    "country": "VE",
    "name": "Torondoy",
    "lat": "9.03457",
    "lng": "-71.01412"
  },
  {
    "country": "VE",
    "name": "Tocópero",
    "lat": "11.49946",
    "lng": "-69.259"
  },
  {
    "country": "VE",
    "name": "Tinaquillo",
    "lat": "9.91861",
    "lng": "-68.30472"
  },
  {
    "country": "VE",
    "name": "Tinaco",
    "lat": "9.69894",
    "lng": "-68.43273"
  },
  {
    "country": "VE",
    "name": "Timotes",
    "lat": "8.98224",
    "lng": "-70.73926"
  },
  {
    "country": "VE",
    "name": "Tía Juana",
    "lat": "10.25927",
    "lng": "-71.36343"
  },
  {
    "country": "VE",
    "name": "Temblador",
    "lat": "9.00525",
    "lng": "-62.64493"
  },
  {
    "country": "VE",
    "name": "Táriba",
    "lat": "7.8188",
    "lng": "-72.22427"
  },
  {
    "country": "VE",
    "name": "Tabay",
    "lat": "8.6317",
    "lng": "-71.07833"
  },
  {
    "country": "VE",
    "name": "Soledad",
    "lat": "8.16206",
    "lng": "-63.5654"
  },
  {
    "country": "VE",
    "name": "Socopó",
    "lat": "8.23062",
    "lng": "-70.82198"
  },
  {
    "country": "VE",
    "name": "Siquisique",
    "lat": "10.57112",
    "lng": "-69.70172"
  },
  {
    "country": "VE",
    "name": "Sinamaica",
    "lat": "11.08656",
    "lng": "-71.85595"
  },
  {
    "country": "VE",
    "name": "Seboruco",
    "lat": "8.14514",
    "lng": "-72.07332"
  },
  {
    "country": "VE",
    "name": "Sarare",
    "lat": "9.78129",
    "lng": "-69.1633"
  },
  {
    "country": "VE",
    "name": "Santo Domingo",
    "lat": "8.86052",
    "lng": "-70.6948"
  },
  {
    "country": "VE",
    "name": "San Timoteo",
    "lat": "9.7901",
    "lng": "-71.07084"
  },
  {
    "country": "VE",
    "name": "Santa Teresa del Tuy",
    "lat": "10.23291",
    "lng": "-66.66474"
  },
  {
    "country": "VE",
    "name": "Santa Rosa",
    "lat": "8.44033",
    "lng": "-69.70105"
  },
  {
    "country": "VE",
    "name": "Santa Rita",
    "lat": "10.53642",
    "lng": "-71.51104"
  },
  {
    "country": "VE",
    "name": "Santa María de Ipire",
    "lat": "8.81556",
    "lng": "-65.3225"
  },
  {
    "country": "VE",
    "name": "Santa María de Caparo",
    "lat": "7.71412",
    "lng": "-71.46466"
  },
  {
    "country": "VE",
    "name": "Santa Lucía",
    "lat": "10.30494",
    "lng": "-66.65998"
  },
  {
    "country": "VE",
    "name": "Santa Lucía",
    "lat": "8.10155",
    "lng": "-69.77752"
  },
  {
    "country": "VE",
    "name": "Santa Isabel",
    "lat": "9.63163",
    "lng": "-70.80837"
  },
  {
    "country": "VE",
    "name": "Santa Inés",
    "lat": "8.26241",
    "lng": "-69.89795"
  },
  {
    "country": "VE",
    "name": "Santa Elena de Uairén",
    "lat": "4.60226",
    "lng": "-61.11025"
  },
  {
    "country": "VE",
    "name": "Santa Elena de Arenales",
    "lat": "8.82062",
    "lng": "-71.46572"
  },
  {
    "country": "VE",
    "name": "Santa Cruz de Mora",
    "lat": "8.39925",
    "lng": "-71.64082"
  },
  {
    "country": "VE",
    "name": "Santa Cruz de Bucaral",
    "lat": "10.81919",
    "lng": "-69.27679"
  },
  {
    "country": "VE",
    "name": "Santa Cruz",
    "lat": "10.18",
    "lng": "-67.51184"
  },
  {
    "country": "VE",
    "name": "Santa Catalina",
    "lat": "7.92408",
    "lng": "-68.91745"
  },
  {
    "country": "VE",
    "name": "Santa Bárbara",
    "lat": "9.60745",
    "lng": "-63.60938"
  },
  {
    "country": "VE",
    "name": "Santa Bárbara",
    "lat": "7.81348",
    "lng": "-71.17788"
  },
  {
    "country": "VE",
    "name": "Santa Apolonia",
    "lat": "9.47135",
    "lng": "-71.01213"
  },
  {
    "country": "VE",
    "name": "Santa Ana",
    "lat": "11.06828",
    "lng": "-63.92239"
  },
  {
    "country": "VE",
    "name": "Santa Ana",
    "lat": "9.3056",
    "lng": "-64.65478"
  },
  {
    "country": "VE",
    "name": "Santa Ana",
    "lat": "8.11697",
    "lng": "-72.02174"
  },
  {
    "country": "VE",
    "name": "Santa Ana",
    "lat": "7.6422",
    "lng": "-72.27694"
  },
  {
    "country": "VE",
    "name": "San Simón",
    "lat": "8.35018",
    "lng": "-71.85114"
  },
  {
    "country": "VE",
    "name": "San Silvestre",
    "lat": "8.27585",
    "lng": "-70.11027"
  },
  {
    "country": "VE",
    "name": "San Rafael de Onoto",
    "lat": "9.67813",
    "lng": "-68.97278"
  },
  {
    "country": "VE",
    "name": "Carvajal",
    "lat": "9.3067",
    "lng": "-70.59042"
  },
  {
    "country": "VE",
    "name": "San Rafael de Canaguá",
    "lat": "8.02667",
    "lng": "-70.00861"
  },
  {
    "country": "VE",
    "name": "San Pedro de Coche",
    "lat": "10.78131",
    "lng": "-63.99675"
  },
  {
    "country": "VE",
    "name": "San Pablo",
    "lat": "10.24929",
    "lng": "-68.84427"
  },
  {
    "country": "VE",
    "name": "San Mateo",
    "lat": "10.21302",
    "lng": "-67.42365"
  },
  {
    "country": "VE",
    "name": "San Mateo",
    "lat": "9.74004",
    "lng": "-64.54937"
  },
  {
    "country": "VE",
    "name": "San Luis",
    "lat": "11.12034",
    "lng": "-69.68397"
  },
  {
    "country": "VE",
    "name": "San Juan de Manapiare",
    "lat": "5.32665",
    "lng": "-66.05402"
  },
  {
    "country": "VE",
    "name": "San Juan de los Morros",
    "lat": "9.91152",
    "lng": "-67.35381"
  },
  {
    "country": "VE",
    "name": "San Juan de los Cayos",
    "lat": "11.17203",
    "lng": "-68.4128"
  },
  {
    "country": "VE",
    "name": "Colón",
    "lat": "8.03125",
    "lng": "-72.26053"
  },
  {
    "country": "VE",
    "name": "San Juan Bautista",
    "lat": "11.01422",
    "lng": "-63.94383"
  },
  {
    "country": "VE",
    "name": "San José de Barlovento",
    "lat": "10.30125",
    "lng": "-65.99053"
  },
  {
    "country": "VE",
    "name": "San José de Guanipa",
    "lat": "8.88724",
    "lng": "-64.16512"
  },
  {
    "country": "VE",
    "name": "San José de Aerocuar",
    "lat": "10.59973",
    "lng": "-63.32852"
  },
  {
    "country": "VE",
    "name": "San Joaquín",
    "lat": "10.26061",
    "lng": "-67.79348"
  },
  {
    "country": "VE",
    "name": "San Francisco de Yare",
    "lat": "10.17793",
    "lng": "-66.74649"
  },
  {
    "country": "VE",
    "name": "San Francisco",
    "lat": "10.55363",
    "lng": "-71.70364"
  },
  {
    "country": "VE",
    "name": "San Fernando de Atabapo",
    "lat": "4.04564",
    "lng": "-67.69934"
  },
  {
    "country": "VE",
    "name": "San Felipe",
    "lat": "10.33991",
    "lng": "-68.74247"
  },
  {
    "country": "VE",
    "name": "San Diego",
    "lat": "10.26057",
    "lng": "-67.95363"
  },
  {
    "country": "VE",
    "name": "San Cristóbal",
    "lat": "7.76694",
    "lng": "-72.225"
  },
  {
    "country": "VE",
    "name": "San Casimiro",
    "lat": "10.00169",
    "lng": "-67.01464"
  },
  {
    "country": "VE",
    "name": "San Carlos de Río Negro",
    "lat": "1.92027",
    "lng": "-67.06089"
  },
  {
    "country": "VE",
    "name": "San Carlos del Zulia",
    "lat": "9.00098",
    "lng": "-71.92683"
  },
  {
    "country": "VE",
    "name": "San Carlos",
    "lat": "9.66124",
    "lng": "-68.58268"
  },
  {
    "country": "VE",
    "name": "Sanare",
    "lat": "9.75209",
    "lng": "-69.6524"
  },
  {
    "country": "VE",
    "name": "San Antonio del Táchira",
    "lat": "7.81454",
    "lng": "-72.4431"
  },
  {
    "country": "VE",
    "name": "San Antonio de Los Altos",
    "lat": "10.38853",
    "lng": "-66.95179"
  },
  {
    "country": "VE",
    "name": "San Antonio del Golfo",
    "lat": "10.44198",
    "lng": "-63.78874"
  },
  {
    "country": "VE",
    "name": "San Antonio",
    "lat": "10.11914",
    "lng": "-63.72535"
  },
  {
    "country": "VE",
    "name": "San Antonio",
    "lat": "7.96378",
    "lng": "-68.43384"
  },
  {
    "country": "VE",
    "name": "Sabaneta",
    "lat": "8.75234",
    "lng": "-69.93351"
  },
  {
    "country": "VE",
    "name": "Sabana Grande",
    "lat": "9.4018",
    "lng": "-70.79812"
  },
  {
    "country": "VE",
    "name": "Sabana de Parra",
    "lat": "10.12111",
    "lng": "-69.03639"
  },
  {
    "country": "VE",
    "name": "Sabana de Mendoza",
    "lat": "9.43494",
    "lng": "-70.77495"
  },
  {
    "country": "VE",
    "name": "Rubio",
    "lat": "7.70131",
    "lng": "-72.35569"
  },
  {
    "country": "VE",
    "name": "La Villa del Rosario",
    "lat": "10.3258",
    "lng": "-72.31343"
  },
  {
    "country": "VE",
    "name": "Río Chico",
    "lat": "10.31899",
    "lng": "-65.97751"
  },
  {
    "country": "VE",
    "name": "Río Caribe",
    "lat": "10.6977",
    "lng": "-63.10871"
  },
  {
    "country": "VE",
    "name": "Quiriquire",
    "lat": "9.9795",
    "lng": "-63.21991"
  },
  {
    "country": "VE",
    "name": "Quíbor",
    "lat": "9.92866",
    "lng": "-69.6201"
  },
  {
    "country": "VE",
    "name": "Queniquea",
    "lat": "7.91659",
    "lng": "-72.0138"
  },
  {
    "country": "VE",
    "name": "Quebrada Seca",
    "lat": "8.70015",
    "lng": "-70.31941"
  },
  {
    "country": "VE",
    "name": "Punto Fijo",
    "lat": "11.69152",
    "lng": "-70.19918"
  },
  {
    "country": "VE",
    "name": "Punta de Piedras",
    "lat": "10.90123",
    "lng": "-64.0969"
  },
  {
    "country": "VE",
    "name": "Punta de Piedra",
    "lat": "7.61759",
    "lng": "-71.49164"
  },
  {
    "country": "VE",
    "name": "Punta de Mata",
    "lat": "9.69131",
    "lng": "-63.60921"
  },
  {
    "country": "VE",
    "name": "Punta Cardón",
    "lat": "11.65806",
    "lng": "-70.215"
  },
  {
    "country": "VE",
    "name": "Puerto Píritu",
    "lat": "10.05896",
    "lng": "-65.03698"
  },
  {
    "country": "VE",
    "name": "Puerto La Cruz",
    "lat": "10.21382",
    "lng": "-64.6328"
  },
  {
    "country": "VE",
    "name": "Puerto de Nutrias",
    "lat": "8.07281",
    "lng": "-69.30246"
  },
  {
    "country": "VE",
    "name": "Puerto Cumarebo",
    "lat": "11.48614",
    "lng": "-69.35319"
  },
  {
    "country": "VE",
    "name": "Puerto Cabello",
    "lat": "10.47051",
    "lng": "-68.02958"
  },
  {
    "country": "VE",
    "name": "Puerto Ayacucho",
    "lat": "5.66049",
    "lng": "-67.58343"
  },
  {
    "country": "VE",
    "name": "Pueblo Nuevo",
    "lat": "11.94788",
    "lng": "-69.92306"
  },
  {
    "country": "VE",
    "name": "Pueblo Nuevo El Chivo",
    "lat": "8.96249",
    "lng": "-71.60754"
  },
  {
    "country": "VE",
    "name": "Pueblo Llano",
    "lat": "8.9152",
    "lng": "-70.65919"
  },
  {
    "country": "VE",
    "name": "Pregonero",
    "lat": "8.01909",
    "lng": "-71.76595"
  },
  {
    "country": "VE",
    "name": "Porlamar",
    "lat": "10.95771",
    "lng": "-63.86971"
  },
  {
    "country": "VE",
    "name": "Píritu",
    "lat": "11.36648",
    "lng": "-69.13807"
  },
  {
    "country": "VE",
    "name": "Píritu",
    "lat": "10.0395",
    "lng": "-65.03037"
  },
  {
    "country": "VE",
    "name": "Píritu",
    "lat": "9.37083",
    "lng": "-69.21028"
  },
  {
    "country": "VE",
    "name": "Petare",
    "lat": "10.48269",
    "lng": "-66.81468"
  },
  {
    "country": "VE",
    "name": "Pedregal",
    "lat": "11.02012",
    "lng": "-70.11997"
  },
  {
    "country": "VE",
    "name": "Pedraza La Vieja",
    "lat": "7.9168",
    "lng": "-71.05934"
  },
  {
    "country": "VE",
    "name": "Pedernales",
    "lat": "9.971",
    "lng": "-62.252"
  },
  {
    "country": "VE",
    "name": "Pariaguán",
    "lat": "8.84357",
    "lng": "-64.71053"
  },
  {
    "country": "VE",
    "name": "Paraíso de Chabasquén",
    "lat": "9.43326",
    "lng": "-69.94728"
  },
  {
    "country": "VE",
    "name": "La Plaza Paraguachi",
    "lat": "11.10783",
    "lng": "-63.85537"
  },
  {
    "country": "VE",
    "name": "Papelón",
    "lat": "8.94109",
    "lng": "-69.46021"
  },
  {
    "country": "VE",
    "name": "Pampatar",
    "lat": "11.00122",
    "lng": "-63.79297"
  },
  {
    "country": "VE",
    "name": "Pampanito",
    "lat": "9.41037",
    "lng": "-70.50116"
  },
  {
    "country": "VE",
    "name": "Pampán",
    "lat": "9.44519",
    "lng": "-70.47556"
  },
  {
    "country": "VE",
    "name": "Palo Negro",
    "lat": "10.17389",
    "lng": "-67.54194"
  },
  {
    "country": "VE",
    "name": "Palmira",
    "lat": "7.8373",
    "lng": "-72.22802"
  },
  {
    "country": "VE",
    "name": "Palmasola",
    "lat": "9.23333",
    "lng": "-66.71667"
  },
  {
    "country": "VE",
    "name": "Ospino",
    "lat": "9.29572",
    "lng": "-69.45434"
  },
  {
    "country": "VE",
    "name": "Ortiz",
    "lat": "9.62168",
    "lng": "-67.29047"
  },
  {
    "country": "VE",
    "name": "Onoto",
    "lat": "9.59714",
    "lng": "-65.1935"
  },
  {
    "country": "VE",
    "name": "Ocumare del Tuy",
    "lat": "10.1182",
    "lng": "-66.77513"
  },
  {
    "country": "VE",
    "name": "Ocumare de la Costa",
    "lat": "10.46127",
    "lng": "-67.76872"
  },
  {
    "country": "VE",
    "name": "Obispos",
    "lat": "8.60701",
    "lng": "-70.10489"
  },
  {
    "country": "VE",
    "name": "Nueva Bolivia",
    "lat": "9.14007",
    "lng": "-71.09143"
  },
  {
    "country": "VE",
    "name": "Nirgua",
    "lat": "10.15039",
    "lng": "-68.56478"
  },
  {
    "country": "VE",
    "name": "Naiguatá",
    "lat": "10.62026",
    "lng": "-66.73833"
  },
  {
    "country": "VE",
    "name": "Naguanagua",
    "lat": "10.25604",
    "lng": "-68.01649"
  },
  {
    "country": "VE",
    "name": "Mucumpiz",
    "lat": "8.41667",
    "lng": "-71.13333"
  },
  {
    "country": "VE",
    "name": "Mucuchíes",
    "lat": "8.74921",
    "lng": "-70.91978"
  },
  {
    "country": "VE",
    "name": "Motatán",
    "lat": "9.39182",
    "lng": "-70.59061"
  },
  {
    "country": "VE",
    "name": "Morón",
    "lat": "10.48715",
    "lng": "-68.20078"
  },
  {
    "country": "VE",
    "name": "Monte Carmelo",
    "lat": "9.18821",
    "lng": "-70.81229"
  },
  {
    "country": "VE",
    "name": "Montalbán",
    "lat": "10.21313",
    "lng": "-68.32669"
  },
  {
    "country": "VE",
    "name": "Mirimire",
    "lat": "11.1602",
    "lng": "-68.72604"
  },
  {
    "country": "VE",
    "name": "Miranda",
    "lat": "10.15077",
    "lng": "-68.39325"
  },
  {
    "country": "VE",
    "name": "Michelena",
    "lat": "7.95655",
    "lng": "-72.24299"
  },
  {
    "country": "VE",
    "name": "Mérida",
    "lat": "8.58972",
    "lng": "-71.15611"
  },
  {
    "country": "VE",
    "name": "Mene de Mauroa",
    "lat": "10.68091",
    "lng": "-71.03609"
  },
  {
    "country": "VE",
    "name": "Masparrito",
    "lat": "9.00194",
    "lng": "-70.30139"
  },
  {
    "country": "VE",
    "name": "Maroa",
    "lat": "2.7188",
    "lng": "-67.56046"
  },
  {
    "country": "VE",
    "name": "Maripa",
    "lat": "7.41584",
    "lng": "-65.19034"
  },
  {
    "country": "VE",
    "name": "Marigüitar",
    "lat": "10.44789",
    "lng": "-63.90161"
  },
  {
    "country": "VE",
    "name": "Mariara",
    "lat": "10.29532",
    "lng": "-67.7177"
  },
  {
    "country": "VE",
    "name": "Maracay",
    "lat": "10.23535",
    "lng": "-67.59113"
  },
  {
    "country": "VE",
    "name": "Maracaibo",
    "lat": "10.66663",
    "lng": "-71.61245"
  },
  {
    "country": "VE",
    "name": "Maporal",
    "lat": "7.645",
    "lng": "-70.41985"
  },
  {
    "country": "VE",
    "name": "Mapire",
    "lat": "7.74085",
    "lng": "-64.71047"
  },
  {
    "country": "VE",
    "name": "Mamporal",
    "lat": "10.36556",
    "lng": "-66.13391"
  },
  {
    "country": "VE",
    "name": "Maiquetía",
    "lat": "10.5945",
    "lng": "-66.95624"
  },
  {
    "country": "VE",
    "name": "Macuto",
    "lat": "10.60508",
    "lng": "-66.89745"
  },
  {
    "country": "VE",
    "name": "Machiques",
    "lat": "10.06077",
    "lng": "-72.55212"
  },
  {
    "country": "VE",
    "name": "Los Teques",
    "lat": "10.34447",
    "lng": "-67.04325"
  },
  {
    "country": "VE",
    "name": "Los Rastrojos",
    "lat": "10.02588",
    "lng": "-69.24166"
  },
  {
    "country": "VE",
    "name": "Los Guayos",
    "lat": "10.18932",
    "lng": "-67.93828"
  },
  {
    "country": "VE",
    "name": "Los Dos Caminos",
    "lat": "10.49389",
    "lng": "-66.82863"
  },
  {
    "country": "VE",
    "name": "Lobatera",
    "lat": "7.92978",
    "lng": "-72.24731"
  },
  {
    "country": "VE",
    "name": "Libertad",
    "lat": "9.35654",
    "lng": "-68.69221"
  },
  {
    "country": "VE",
    "name": "Libertad",
    "lat": "8.32709",
    "lng": "-69.63093"
  },
  {
    "country": "VE",
    "name": "Canaguá",
    "lat": "8.12489",
    "lng": "-71.46041"
  },
  {
    "country": "VE",
    "name": "Capacho Viejo",
    "lat": "7.82893",
    "lng": "-72.31942"
  },
  {
    "country": "VE",
    "name": "La Yuca",
    "lat": "8.73109",
    "lng": "-70.18072"
  },
  {
    "country": "VE",
    "name": "La Victoria",
    "lat": "10.22677",
    "lng": "-67.33122"
  },
  {
    "country": "VE",
    "name": "La Vela de Coro",
    "lat": "11.46077",
    "lng": "-69.5657"
  },
  {
    "country": "VE",
    "name": "Veguitas",
    "lat": "8.82391",
    "lng": "-69.99581"
  },
  {
    "country": "VE",
    "name": "La Unión",
    "lat": "8.21573",
    "lng": "-67.76653"
  },
  {
    "country": "VE",
    "name": "Las Vegas",
    "lat": "9.53724",
    "lng": "-68.63022"
  },
  {
    "country": "VE",
    "name": "Las Tejerías",
    "lat": "10.25416",
    "lng": "-67.17333"
  },
  {
    "country": "VE",
    "name": "Las Mercedes",
    "lat": "9.11037",
    "lng": "-66.39607"
  },
  {
    "country": "VE",
    "name": "La Sabana",
    "lat": "10.61867",
    "lng": "-66.38194"
  },
  {
    "country": "VE",
    "name": "La Quebrada",
    "lat": "9.15522",
    "lng": "-70.57702"
  },
  {
    "country": "VE",
    "name": "La Plata",
    "lat": "10.32025",
    "lng": "-71.2721"
  },
  {
    "country": "VE",
    "name": "La Luz",
    "lat": "8.39419",
    "lng": "-69.82358"
  },
  {
    "country": "VE",
    "name": "Lagunillas",
    "lat": "10.13008",
    "lng": "-71.25946"
  },
  {
    "country": "VE",
    "name": "Lagunillas",
    "lat": "8.50457",
    "lng": "-71.3894"
  },
  {
    "country": "VE",
    "name": "La Guaira",
    "lat": "10.59901",
    "lng": "-66.9346"
  },
  {
    "country": "VE",
    "name": "La Esmeralda",
    "lat": "3.17453",
    "lng": "-65.54517"
  },
  {
    "country": "VE",
    "name": "La Cruz de Taratara",
    "lat": "11.06302",
    "lng": "-69.71287"
  },
  {
    "country": "VE",
    "name": "La Concepción",
    "lat": "10.61919",
    "lng": "-71.83814"
  },
  {
    "country": "VE",
    "name": "Concepción",
    "lat": "10.4119",
    "lng": "-71.68919"
  },
  {
    "country": "VE",
    "name": "Chameta",
    "lat": "8.10023",
    "lng": "-70.90671"
  },
  {
    "country": "VE",
    "name": "Caramuca",
    "lat": "8.59708",
    "lng": "-70.32056"
  },
  {
    "country": "VE",
    "name": "La Azulita",
    "lat": "8.71364",
    "lng": "-71.44421"
  },
  {
    "country": "VE",
    "name": "Juan Griego",
    "lat": "11.08172",
    "lng": "-63.96549"
  },
  {
    "country": "VE",
    "name": "Jacura",
    "lat": "11.07446",
    "lng": "-68.85583"
  },
  {
    "country": "VE",
    "name": "Irapa",
    "lat": "10.57006",
    "lng": "-62.58204"
  },
  {
    "country": "VE",
    "name": "Higuerote",
    "lat": "10.48287",
    "lng": "-66.10096"
  },
  {
    "country": "VE",
    "name": "Güiria",
    "lat": "10.57721",
    "lng": "-62.29841"
  },
  {
    "country": "VE",
    "name": "Güigüe",
    "lat": "10.08344",
    "lng": "-67.77799"
  },
  {
    "country": "VE",
    "name": "Guayabal",
    "lat": "8.00077",
    "lng": "-67.39732"
  },
  {
    "country": "VE",
    "name": "Guatire",
    "lat": "10.474",
    "lng": "-66.54241"
  },
  {
    "country": "VE",
    "name": "Guasipati",
    "lat": "7.47702",
    "lng": "-61.89666"
  },
  {
    "country": "VE",
    "name": "Guarenas",
    "lat": "10.47027",
    "lng": "-66.61934"
  },
  {
    "country": "VE",
    "name": "Guaraque",
    "lat": "8.15405",
    "lng": "-71.73562"
  },
  {
    "country": "VE",
    "name": "Guanta",
    "lat": "10.23453",
    "lng": "-64.59708"
  },
  {
    "country": "VE",
    "name": "Guanarito",
    "lat": "8.69625",
    "lng": "-69.20832"
  },
  {
    "country": "VE",
    "name": "Guanare",
    "lat": "9.04183",
    "lng": "-69.74206"
  },
  {
    "country": "VE",
    "name": "Guama",
    "lat": "10.26638",
    "lng": "-68.81986"
  },
  {
    "country": "VE",
    "name": "Guadarrama",
    "lat": "8.53508",
    "lng": "-68.04923"
  },
  {
    "country": "VE",
    "name": "Guacara",
    "lat": "10.22609",
    "lng": "-67.877"
  },
  {
    "country": "VE",
    "name": "Farriar",
    "lat": "10.47016",
    "lng": "-68.55885"
  },
  {
    "country": "VE",
    "name": "Escuque",
    "lat": "9.29687",
    "lng": "-70.67189"
  },
  {
    "country": "VE",
    "name": "Encontrados",
    "lat": "9.05983",
    "lng": "-72.2346"
  },
  {
    "country": "VE",
    "name": "El Vigía",
    "lat": "8.6135",
    "lng": "-71.65702"
  },
  {
    "country": "VE",
    "name": "El Valle del Espíritu Santo",
    "lat": "10.9832",
    "lng": "-63.88292"
  },
  {
    "country": "VE",
    "name": "El Toro",
    "lat": "10.95423",
    "lng": "-71.64843"
  },
  {
    "country": "VE",
    "name": "El Tocuyo",
    "lat": "9.78709",
    "lng": "-69.79294"
  },
  {
    "country": "VE",
    "name": "El Tigre",
    "lat": "8.88902",
    "lng": "-64.2527"
  },
  {
    "country": "VE",
    "name": "El Sombrero",
    "lat": "9.3863",
    "lng": "-67.05818"
  },
  {
    "country": "VE",
    "name": "El Socorro",
    "lat": "8.99352",
    "lng": "-65.74247"
  },
  {
    "country": "VE",
    "name": "El Regalo",
    "lat": "8.43455",
    "lng": "-69.1767"
  },
  {
    "country": "VE",
    "name": "San Rafael del Piñal",
    "lat": "7.52987",
    "lng": "-71.95922"
  },
  {
    "country": "VE",
    "name": "El Pilar",
    "lat": "10.54782",
    "lng": "-63.15424"
  },
  {
    "country": "VE",
    "name": "El Paradero",
    "lat": "9.77278",
    "lng": "-70.61541"
  },
  {
    "country": "VE",
    "name": "El Pao",
    "lat": "9.63926",
    "lng": "-68.12917"
  },
  {
    "country": "VE",
    "name": "El Palmer",
    "lat": "8.03333",
    "lng": "-61.88333"
  },
  {
    "country": "VE",
    "name": "El Palmar",
    "lat": "8.01082",
    "lng": "-61.90713"
  },
  {
    "country": "VE",
    "name": "Elorza",
    "lat": "7.06088",
    "lng": "-69.49765"
  },
  {
    "country": "VE",
    "name": "Lecherías",
    "lat": "10.19167",
    "lng": "-64.69207"
  },
  {
    "country": "VE",
    "name": "El Limón",
    "lat": "10.30589",
    "lng": "-67.63212"
  },
  {
    "country": "VE",
    "name": "El Hatillo",
    "lat": "10.42369",
    "lng": "-66.82616"
  },
  {
    "country": "VE",
    "name": "El Dividive",
    "lat": "9.4751",
    "lng": "-70.73493"
  },
  {
    "country": "VE",
    "name": "El Corozo",
    "lat": "10.12061",
    "lng": "-71.04422"
  },
  {
    "country": "VE",
    "name": "El Corozo",
    "lat": "8.5675",
    "lng": "-70.35778"
  },
  {
    "country": "VE",
    "name": "El Consejo",
    "lat": "10.23777",
    "lng": "-67.27008"
  },
  {
    "country": "VE",
    "name": "El Cobre",
    "lat": "8.0349",
    "lng": "-72.05718"
  },
  {
    "country": "VE",
    "name": "El Cantón",
    "lat": "7.47801",
    "lng": "-71.29693"
  },
  {
    "country": "VE",
    "name": "El Callao",
    "lat": "7.34706",
    "lng": "-61.82684"
  },
  {
    "country": "VE",
    "name": "El Baúl",
    "lat": "8.96225",
    "lng": "-68.29511"
  },
  {
    "country": "VE",
    "name": "Ejido",
    "lat": "8.54665",
    "lng": "-71.24087"
  },
  {
    "country": "VE",
    "name": "Duaca",
    "lat": "10.28554",
    "lng": "-69.16244"
  },
  {
    "country": "VE",
    "name": "Dolores",
    "lat": "8.28623",
    "lng": "-69.56633"
  },
  {
    "country": "VE",
    "name": "Dabajuro",
    "lat": "11.02273",
    "lng": "-70.67769"
  },
  {
    "country": "VE",
    "name": "Curiapo",
    "lat": "8.58057",
    "lng": "-60.99778"
  },
  {
    "country": "VE",
    "name": "Curbatí",
    "lat": "8.45443",
    "lng": "-70.55441"
  },
  {
    "country": "VE",
    "name": "Cúpira",
    "lat": "10.16128",
    "lng": "-65.70013"
  },
  {
    "country": "VE",
    "name": "Cumanacoa",
    "lat": "10.25056",
    "lng": "-63.91938"
  },
  {
    "country": "VE",
    "name": "Cumaná",
    "lat": "10.45397",
    "lng": "-64.18256"
  },
  {
    "country": "VE",
    "name": "Cúa",
    "lat": "10.16245",
    "lng": "-66.88248"
  },
  {
    "country": "VE",
    "name": "Coro",
    "lat": "11.4045",
    "lng": "-69.67344"
  },
  {
    "country": "VE",
    "name": "Concepción",
    "lat": "10.8",
    "lng": "-71.76667"
  },
  {
    "country": "VE",
    "name": "Coloncito",
    "lat": "8.32611",
    "lng": "-72.08742"
  },
  {
    "country": "VE",
    "name": "Cojedes",
    "lat": "9.62232",
    "lng": "-68.91805"
  },
  {
    "country": "VE",
    "name": "Cocorote",
    "lat": "10.31954",
    "lng": "-68.78298"
  },
  {
    "country": "VE",
    "name": "Clarines",
    "lat": "9.93991",
    "lng": "-65.16517"
  },
  {
    "country": "VE",
    "name": "Ciudad Piar",
    "lat": "7.45209",
    "lng": "-63.31992"
  },
  {
    "country": "VE",
    "name": "Ciudad Ojeda",
    "lat": "10.20161",
    "lng": "-71.3148"
  },
  {
    "country": "VE",
    "name": "Ciudad Guayana",
    "lat": "8.35122",
    "lng": "-62.64102"
  },
  {
    "country": "VE",
    "name": "Ciudad De Nutrias",
    "lat": "8.09535",
    "lng": "-69.30798"
  },
  {
    "country": "VE",
    "name": "Ciudad Bolivia",
    "lat": "8.35304",
    "lng": "-70.57121"
  },
  {
    "country": "VE",
    "name": "Ciudad Bolívar",
    "lat": "8.12923",
    "lng": "-63.54086"
  },
  {
    "country": "VE",
    "name": "Churuguara",
    "lat": "10.81231",
    "lng": "-69.53734"
  },
  {
    "country": "VE",
    "name": "Chivacoa",
    "lat": "10.15951",
    "lng": "-68.89453"
  },
  {
    "country": "VE",
    "name": "Chichiriviche",
    "lat": "10.92872",
    "lng": "-68.27283"
  },
  {
    "country": "VE",
    "name": "Chejendé",
    "lat": "9.6186",
    "lng": "-70.35682"
  },
  {
    "country": "VE",
    "name": "Charallave",
    "lat": "10.24247",
    "lng": "-66.85723"
  },
  {
    "country": "VE",
    "name": "Chaguaramas",
    "lat": "9.33754",
    "lng": "-66.25282"
  },
  {
    "country": "VE",
    "name": "Chacao",
    "lat": "10.49598",
    "lng": "-66.85347"
  },
  {
    "country": "VE",
    "name": "Tacarigua",
    "lat": "10.08621",
    "lng": "-67.91982"
  },
  {
    "country": "VE",
    "name": "Caucagüito",
    "lat": "10.48666",
    "lng": "-66.73799"
  },
  {
    "country": "VE",
    "name": "Caucagua",
    "lat": "10.2831",
    "lng": "-66.37591"
  },
  {
    "country": "VE",
    "name": "Catia La Mar",
    "lat": "10.60545",
    "lng": "-67.03238"
  },
  {
    "country": "VE",
    "name": "Casigua El Cubo",
    "lat": "8.74602",
    "lng": "-72.51889"
  },
  {
    "country": "VE",
    "name": "Casanay",
    "lat": "10.5042",
    "lng": "-63.41729"
  },
  {
    "country": "VE",
    "name": "Carúpano",
    "lat": "10.66516",
    "lng": "-63.25387"
  },
  {
    "country": "VE",
    "name": "Carrizal",
    "lat": "10.34985",
    "lng": "-66.98632"
  },
  {
    "country": "VE",
    "name": "Carora",
    "lat": "10.17283",
    "lng": "-70.081"
  },
  {
    "country": "VE",
    "name": "Caripito",
    "lat": "10.11135",
    "lng": "-63.09985"
  },
  {
    "country": "VE",
    "name": "Caripe",
    "lat": "10.17335",
    "lng": "-63.50048"
  },
  {
    "country": "VE",
    "name": "Cariaco",
    "lat": "10.49682",
    "lng": "-63.55286"
  },
  {
    "country": "VE",
    "name": "Carache",
    "lat": "9.62857",
    "lng": "-70.22864"
  },
  {
    "country": "VE",
    "name": "Caracas",
    "lat": "10.48801",
    "lng": "-66.87919"
  },
  {
    "country": "VE",
    "name": "Caraballeda",
    "lat": "10.61216",
    "lng": "-66.85192"
  },
  {
    "country": "VE",
    "name": "Capitanejo",
    "lat": "8.01171",
    "lng": "-71.00458"
  },
  {
    "country": "VE",
    "name": "Canape Capatárida",
    "lat": "11.1755",
    "lng": "-70.62072"
  },
  {
    "country": "VE",
    "name": "Cantaura",
    "lat": "9.30571",
    "lng": "-64.35841"
  },
  {
    "country": "VE",
    "name": "Campo Elías",
    "lat": "9.39458",
    "lng": "-70.05872"
  },
  {
    "country": "VE",
    "name": "Camatagua",
    "lat": "9.78762",
    "lng": "-66.90619"
  },
  {
    "country": "VE",
    "name": "Camaguán",
    "lat": "8.10732",
    "lng": "-67.60738"
  },
  {
    "country": "VE",
    "name": "Calderas",
    "lat": "8.91426",
    "lng": "-70.44745"
  },
  {
    "country": "VE",
    "name": "Calabozo",
    "lat": "8.92416",
    "lng": "-67.42929"
  },
  {
    "country": "VE",
    "name": "Caicara",
    "lat": "9.81755",
    "lng": "-63.61331"
  },
  {
    "country": "VE",
    "name": "Caicara del Orinoco",
    "lat": "7.63501",
    "lng": "-66.16815"
  },
  {
    "country": "VE",
    "name": "Cagua",
    "lat": "10.18634",
    "lng": "-67.45935"
  },
  {
    "country": "VE",
    "name": "Cabure",
    "lat": "11.1453",
    "lng": "-69.61191"
  },
  {
    "country": "VE",
    "name": "Cabudare",
    "lat": "10.02658",
    "lng": "-69.26203"
  },
  {
    "country": "VE",
    "name": "Cabimas",
    "lat": "10.39907",
    "lng": "-71.45206"
  },
  {
    "country": "VE",
    "name": "Bum Bum",
    "lat": "8.27664",
    "lng": "-70.76664"
  },
  {
    "country": "VE",
    "name": "Bruzual",
    "lat": "8.05052",
    "lng": "-69.33257"
  },
  {
    "country": "VE",
    "name": "Boraure",
    "lat": "10.24752",
    "lng": "-68.76966"
  },
  {
    "country": "VE",
    "name": "Boconoito",
    "lat": "8.84659",
    "lng": "-69.98032"
  },
  {
    "country": "VE",
    "name": "Boconó",
    "lat": "9.25385",
    "lng": "-70.25105"
  },
  {
    "country": "VE",
    "name": "Boca de Uchire",
    "lat": "10.13191",
    "lng": "-65.42236"
  },
  {
    "country": "VE",
    "name": "Boca de Río",
    "lat": "10.96757",
    "lng": "-64.1805"
  },
  {
    "country": "VE",
    "name": "Bobures",
    "lat": "9.24173",
    "lng": "-71.17506"
  },
  {
    "country": "VE",
    "name": "Biscucuy",
    "lat": "9.36",
    "lng": "-69.98302"
  },
  {
    "country": "VE",
    "name": "Biruaca",
    "lat": "7.84483",
    "lng": "-67.51679"
  },
  {
    "country": "VE",
    "name": "Betijoque",
    "lat": "9.38121",
    "lng": "-70.73283"
  },
  {
    "country": "VE",
    "name": "Bejuma",
    "lat": "10.17383",
    "lng": "-68.25892"
  },
  {
    "country": "VE",
    "name": "Nuestra Señora del Rosario de Baruta",
    "lat": "10.43398",
    "lng": "-66.87662"
  },
  {
    "country": "VE",
    "name": "Barrancas",
    "lat": "8.76962",
    "lng": "-70.11086"
  },
  {
    "country": "VE",
    "name": "Barrancas",
    "lat": "8.6989",
    "lng": "-62.19656"
  },
  {
    "country": "VE",
    "name": "Barquisimeto",
    "lat": "10.0647",
    "lng": "-69.35703"
  },
  {
    "country": "VE",
    "name": "Barinitas",
    "lat": "8.76171",
    "lng": "-70.41199"
  },
  {
    "country": "VE",
    "name": "Barinas",
    "lat": "8.62261",
    "lng": "-70.20749"
  },
  {
    "country": "VE",
    "name": "Barcelona",
    "lat": "10.13625",
    "lng": "-64.68618"
  },
  {
    "country": "VE",
    "name": "Barbacoas",
    "lat": "9.47855",
    "lng": "-66.97458"
  },
  {
    "country": "VE",
    "name": "Bailadores",
    "lat": "8.25347",
    "lng": "-71.82818"
  },
  {
    "country": "VE",
    "name": "Bachaquero",
    "lat": "9.96209",
    "lng": "-71.12377"
  },
  {
    "country": "VE",
    "name": "Aroa",
    "lat": "10.43949",
    "lng": "-68.89496"
  },
  {
    "country": "VE",
    "name": "Arismendi",
    "lat": "8.47974",
    "lng": "-68.36996"
  },
  {
    "country": "VE",
    "name": "Aricagua",
    "lat": "8.22432",
    "lng": "-71.13721"
  },
  {
    "country": "VE",
    "name": "Araya",
    "lat": "10.57998",
    "lng": "-64.25548"
  },
  {
    "country": "VE",
    "name": "Araure",
    "lat": "9.58144",
    "lng": "-69.23851"
  },
  {
    "country": "VE",
    "name": "Arauquita",
    "lat": "8.70833",
    "lng": "-69.65722"
  },
  {
    "country": "VE",
    "name": "Aragua",
    "lat": "9.97026",
    "lng": "-63.48727"
  },
  {
    "country": "VE",
    "name": "Aragua de Barcelona",
    "lat": "9.45588",
    "lng": "-64.82928"
  },
  {
    "country": "VE",
    "name": "Altamira",
    "lat": "8.82359",
    "lng": "-70.50244"
  },
  {
    "country": "VE",
    "name": "Altagracia de Orituco",
    "lat": "9.86005",
    "lng": "-66.38139"
  },
  {
    "country": "VE",
    "name": "Los Puertos de Altagracia",
    "lat": "10.71492",
    "lng": "-71.52168"
  },
  {
    "country": "VE",
    "name": "Aguasay",
    "lat": "9.42489",
    "lng": "-63.73077"
  },
  {
    "country": "VE",
    "name": "Achaguas",
    "lat": "7.77917",
    "lng": "-68.22373"
  },
  {
    "country": "VE",
    "name": "Acarigua",
    "lat": "9.55451",
    "lng": "-69.19564"
  },
  {
    "country": "VE",
    "name": "Abejales",
    "lat": "7.6233",
    "lng": "-71.51031"
  },
  {
    "country": "VE",
    "name": "Las Mesas",
    "lat": "8.17123",
    "lng": "-72.15948"
  },
  {
    "country": "VE",
    "name": "San José de Bolívar",
    "lat": "7.91242",
    "lng": "-71.97251"
  },
  {
    "country": "VE",
    "name": "Santa Rita",
    "lat": "10.2054",
    "lng": "-67.55948"
  },
  {
    "country": "VE",
    "name": "Isla Ratón",
    "lat": "5.06862",
    "lng": "-67.81295"
  },
  {
    "country": "VE",
    "name": "San Josecito",
    "lat": "7.66106",
    "lng": "-72.22009"
  },
  {
    "country": "VE",
    "name": "Cordero",
    "lat": "7.85689",
    "lng": "-72.181"
  },
  {
    "country": "VE",
    "name": "Sierra Imataca",
    "lat": "8.39352",
    "lng": "-62.45439"
  },
  {
    "country": "VE",
    "name": "San José de Guaribe",
    "lat": "9.86025",
    "lng": "-65.81306"
  },
  {
    "country": "VE",
    "name": "Maturín",
    "lat": "9.74569",
    "lng": "-63.18323"
  },
  {
    "country": "VE",
    "name": "Palmasola",
    "lat": "10.59363",
    "lng": "-68.54422"
  },
  {
    "country": "VE",
    "name": "Delicias",
    "lat": "7.56505",
    "lng": "-72.44754"
  },
  {
    "country": "VE",
    "name": "La Fría",
    "lat": "8.21523",
    "lng": "-72.24888"
  },
  {
    "country": "VE",
    "name": "La Grita",
    "lat": "8.13316",
    "lng": "-71.9839"
  },
  {
    "country": "VE",
    "name": "Capacho Nuevo",
    "lat": "7.82472",
    "lng": "-72.3084"
  },
  {
    "country": "VE",
    "name": "La Tendida",
    "lat": "8.50734",
    "lng": "-71.83201"
  },
  {
    "country": "VE",
    "name": "Agua Blanca",
    "lat": "9.66205",
    "lng": "-69.10677"
  },
  {
    "country": "VE",
    "name": "El Playón",
    "lat": "9.10049",
    "lng": "-69.04564"
  },
  {
    "country": "VE",
    "name": "Arapuey",
    "lat": "9.25934",
    "lng": "-70.95248"
  },
  {
    "country": "VE",
    "name": "Macapo",
    "lat": "9.82533",
    "lng": "-68.43866"
  },
  {
    "country": "VE",
    "name": "El Cafetal",
    "lat": "10.46941",
    "lng": "-66.83063"
  },
  {
    "country": "VE",
    "name": "Caucaguita",
    "lat": "10.35782",
    "lng": "-66.80252"
  },
  {
    "country": "VE",
    "name": "La Dolorita",
    "lat": "10.4883",
    "lng": "-66.78608"
  },
  {
    "country": "VE",
    "name": "Guasdualito",
    "lat": "7.24241",
    "lng": "-70.73235"
  },
  {
    "country": "VE",
    "name": "San Fernando de Apure",
    "lat": "7.88782",
    "lng": "-67.47236"
  },
  {
    "country": "VE",
    "name": "San Juan de Payara",
    "lat": "7.64636",
    "lng": "-67.6072"
  },
  {
    "country": "VE",
    "name": "San Sebastián",
    "lat": "9.94108",
    "lng": "-67.17183"
  },
  {
    "country": "VE",
    "name": "Santa Cruz de los Taques",
    "lat": "11.8235",
    "lng": "-70.25637"
  },
  {
    "country": "VE",
    "name": "Independencia",
    "lat": "10.33432",
    "lng": "-68.75512"
  },
  {
    "country": "VE",
    "name": "El Junko",
    "lat": "10.47249",
    "lng": "-67.08361"
  },
  {
    "country": "VG",
    "name": "Road Town",
    "lat": "18.42693",
    "lng": "-64.62079"
  },
  {
    "country": "VI",
    "name": "Charlotte Amalie",
    "lat": "18.3419",
    "lng": "-64.9307"
  },
  {
    "country": "VI",
    "name": "Cruz Bay",
    "lat": "18.33134",
    "lng": "-64.79375"
  },
  {
    "country": "VI",
    "name": "Saint Croix",
    "lat": "17.72751",
    "lng": "-64.74698"
  },
  {
    "country": "VN",
    "name": "Yên Vinh",
    "lat": "18.66667",
    "lng": "105.66667"
  },
  {
    "country": "VN",
    "name": "Yên Thành",
    "lat": "18.99856",
    "lng": "105.47116"
  },
  {
    "country": "VN",
    "name": "Yên Ninh",
    "lat": "20.18396",
    "lng": "106.06121"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Yên Minh",
    "lat": "23.11792",
    "lng": "105.14159"
  },
  {
    "country": "VN",
    "name": "Yến Lạc",
    "lat": "22.23693",
    "lng": "106.18149"
  },
  {
    "country": "VN",
    "name": "Yên Lạc",
    "lat": "21.23646",
    "lng": "105.57297"
  },
  {
    "country": "VN",
    "name": "Yên Châu",
    "lat": "21.04584",
    "lng": "104.30101"
  },
  {
    "country": "VN",
    "name": "Yên Bái",
    "lat": "21.72288",
    "lng": "104.9113"
  },
  {
    "country": "VN",
    "name": "Cai Doi Vam",
    "lat": "8.85707",
    "lng": "104.81199"
  },
  {
    "country": "VN",
    "name": "Trảng Bom",
    "lat": "10.95358",
    "lng": "107.00589"
  },
  {
    "country": "VN",
    "name": "Gia Ray",
    "lat": "10.92615",
    "lng": "107.40172"
  },
  {
    "country": "VN",
    "name": "Vũng Tàu",
    "lat": "10.34599",
    "lng": "107.08426"
  },
  {
    "country": "VN",
    "name": "Vũng Liêm",
    "lat": "10.09576",
    "lng": "106.18548"
  },
  {
    "country": "VN",
    "name": "Vụ Bản",
    "lat": "20.4642",
    "lng": "105.44348"
  },
  {
    "country": "VN",
    "name": "Võ Xu",
    "lat": "11.18691",
    "lng": "107.56025"
  },
  {
    "country": "VN",
    "name": "Vị Thanh",
    "lat": "9.78449",
    "lng": "105.47012"
  },
  {
    "country": "VN",
    "name": "Vĩnh Yên",
    "lat": "21.30891",
    "lng": "105.60489"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Vĩnh Tuy",
    "lat": "22.27441",
    "lng": "104.89091"
  },
  {
    "country": "VN",
    "name": "Vĩnh Thuận",
    "lat": "9.50802",
    "lng": "105.25747"
  },
  {
    "country": "VN",
    "name": "Vĩnh Thạnh",
    "lat": "14.10884",
    "lng": "108.78381"
  },
  {
    "country": "VN",
    "name": "Vĩnh Long",
    "lat": "10.25369",
    "lng": "105.9722"
  },
  {
    "country": "VN",
    "name": "Vĩnh Lộc",
    "lat": "20.05438",
    "lng": "105.61567"
  },
  {
    "country": "VN",
    "name": "Vĩnh Châu",
    "lat": "9.32439",
    "lng": "105.98006"
  },
  {
    "country": "VN",
    "name": "Vĩnh Bình",
    "lat": "10.34498",
    "lng": "106.58056"
  },
  {
    "country": "VN",
    "name": "Vinh",
    "lat": "18.67337",
    "lng": "105.69232"
  },
  {
    "country": "VN",
    "name": "Việt Trì",
    "lat": "21.32274",
    "lng": "105.40198"
  },
  {
    "country": "VN",
    "name": "Văn Quan",
    "lat": "21.86516",
    "lng": "106.53925"
  },
  {
    "country": "VN",
    "name": "Vạn Giã",
    "lat": "12.69203",
    "lng": "109.22069"
  },
  {
    "country": "VN",
    "name": "Vân Đình",
    "lat": "20.73514",
    "lng": "105.77236"
  },
  {
    "country": "VN",
    "name": "Văn Điển",
    "lat": "20.9463",
    "lng": "105.845"
  },
  {
    "country": "VN",
    "name": "Vân Canh",
    "lat": "13.61945",
    "lng": "108.99805"
  },
  {
    "country": "VN",
    "name": "Thành Phố Uông Bí",
    "lat": "21.03433",
    "lng": "106.77049"
  },
  {
    "country": "VN",
    "name": "Tuy Phước",
    "lat": "13.82738",
    "lng": "109.16651"
  },
  {
    "country": "VN",
    "name": "Tuy Hòa",
    "lat": "13.09546",
    "lng": "109.32094"
  },
  {
    "country": "VN",
    "name": "Thành Phố Tuyên Quang",
    "lat": "21.82356",
    "lng": "105.21424"
  },
  {
    "country": "VN",
    "name": "Hòa Bình",
    "lat": "19.26393",
    "lng": "104.47232"
  },
  {
    "country": "VN",
    "name": "Tư Nghĩa",
    "lat": "15.08451",
    "lng": "108.826"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Trùng Khánh",
    "lat": "22.83514",
    "lng": "106.52496"
  },
  {
    "country": "VN",
    "name": "Tri Tôn",
    "lat": "10.4202",
    "lng": "105.00073"
  },
  {
    "country": "VN",
    "name": "Trà Vinh",
    "lat": "9.94719",
    "lng": "106.34225"
  },
  {
    "country": "VN",
    "name": "Trà Ôn",
    "lat": "9.96261",
    "lng": "105.92168"
  },
  {
    "country": "VN",
    "name": "Trảng Bàng",
    "lat": "11.02987",
    "lng": "106.35751"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Trạm Tấu",
    "lat": "21.46659",
    "lng": "104.37966"
  },
  {
    "country": "VN",
    "name": "Trà My",
    "lat": "15.33965",
    "lng": "108.22065"
  },
  {
    "country": "VN",
    "name": "Tràm Chim",
    "lat": "10.67001",
    "lng": "105.56469"
  },
  {
    "country": "VN",
    "name": "Trà Cú",
    "lat": "9.69774",
    "lng": "106.25834"
  },
  {
    "country": "VN",
    "name": "Trà Bồng",
    "lat": "15.25569",
    "lng": "108.51722"
  },
  {
    "country": "VN",
    "name": "Tĩnh Gia",
    "lat": "19.44645",
    "lng": "105.77861"
  },
  {
    "country": "VN",
    "name": "Tiểu Cần",
    "lat": "9.81166",
    "lng": "106.19067"
  },
  {
    "country": "VN",
    "name": "Tiên Phước",
    "lat": "15.48819",
    "lng": "108.30736"
  },
  {
    "country": "VN",
    "name": "Thủ Thừa",
    "lat": "10.60232",
    "lng": "106.40207"
  },
  {
    "country": "VN",
    "name": "Thường Xuân",
    "lat": "19.90294",
    "lng": "105.34723"
  },
  {
    "country": "VN",
    "name": "Thủ Đức",
    "lat": "10.84863",
    "lng": "106.77209"
  },
  {
    "country": "VN",
    "name": "Thủ Dầu Một",
    "lat": "10.9804",
    "lng": "106.6519"
  },
  {
    "country": "VN",
    "name": "Thọ Xuân",
    "lat": "19.93133",
    "lng": "105.52179"
  },
  {
    "country": "VN",
    "name": "Thốt Nốt",
    "lat": "10.27213",
    "lng": "105.5338"
  },
  {
    "country": "VN",
    "name": "Thới Lai",
    "lat": "10.06522",
    "lng": "105.55863"
  },
  {
    "country": "VN",
    "name": "Thới Bình",
    "lat": "9.35584",
    "lng": "105.09929"
  },
  {
    "country": "VN",
    "name": "Ái Tử",
    "lat": "16.76886",
    "lng": "107.16504"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Thất Khê",
    "lat": "22.25525",
    "lng": "106.47359"
  },
  {
    "country": "VN",
    "name": "Than Uyên",
    "lat": "21.95907",
    "lng": "103.88001"
  },
  {
    "country": "VN",
    "name": "Phú Lộc",
    "lat": "9.42838",
    "lng": "105.74111"
  },
  {
    "country": "VN",
    "name": "Thanh Sơn",
    "lat": "21.19867",
    "lng": "105.17892"
  },
  {
    "country": "VN",
    "name": "Thạnh Phú",
    "lat": "9.94827",
    "lng": "106.51629"
  },
  {
    "country": "VN",
    "name": "Ho Chi Minh City",
    "lat": "10.82302",
    "lng": "106.62965"
  },
  {
    "country": "VN",
    "name": "Thanh Nê",
    "lat": "20.3881",
    "lng": "106.43834"
  },
  {
    "country": "VN",
    "name": "Thanh Hóa",
    "lat": "19.8",
    "lng": "105.76667"
  },
  {
    "country": "VN",
    "name": "Thanh Chương",
    "lat": "18.77877",
    "lng": "105.33356"
  },
  {
    "country": "VN",
    "name": "Thanh Bình",
    "lat": "10.5619",
    "lng": "105.48411"
  },
  {
    "country": "VN",
    "name": "Thành Phố Thái Nguyên",
    "lat": "21.59422",
    "lng": "105.84817"
  },
  {
    "country": "VN",
    "name": "Thành Phố Thái Bình",
    "lat": "20.45",
    "lng": "106.34002"
  },
  {
    "country": "VN",
    "name": "Kim Tân",
    "lat": "20.13053",
    "lng": "105.67454"
  },
  {
    "country": "VN",
    "name": "Thạch Hà",
    "lat": "18.36788",
    "lng": "105.86122"
  },
  {
    "country": "VN",
    "name": "Tây Ninh",
    "lat": "11.31004",
    "lng": "106.09828"
  },
  {
    "country": "VN",
    "name": "Tây Hồ",
    "lat": "21.06895",
    "lng": "105.81053"
  },
  {
    "country": "VN",
    "name": "Tây Đằng",
    "lat": "21.19809",
    "lng": "105.42217"
  },
  {
    "country": "VN",
    "name": "Đầm Dơi",
    "lat": "8.99214",
    "lng": "105.19602"
  },
  {
    "country": "VN",
    "name": "Tân Kỳ",
    "lat": "19.04756",
    "lng": "105.26807"
  },
  {
    "country": "VN",
    "name": "Tánh Linh",
    "lat": "11.08421",
    "lng": "107.68095"
  },
  {
    "country": "VN",
    "name": "Tân Hiệp",
    "lat": "10.44905",
    "lng": "106.34386"
  },
  {
    "country": "VN",
    "name": "Tân Hiệp",
    "lat": "10.11709",
    "lng": "105.28578"
  },
  {
    "country": "VN",
    "name": "Tân Châu",
    "lat": "10.79832",
    "lng": "105.23887"
  },
  {
    "country": "VN",
    "name": "Tân An",
    "lat": "10.53589",
    "lng": "106.41366"
  },
  {
    "country": "VN",
    "name": "Tam Kỳ",
    "lat": "15.57364",
    "lng": "108.47403"
  },
  {
    "country": "VN",
    "name": "Trai Ngau",
    "lat": "21.39324",
    "lng": "105.61441"
  },
  {
    "country": "VN",
    "name": "Tam Bình",
    "lat": "10.04811",
    "lng": "106.00017"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Tà Lùng",
    "lat": "22.4979",
    "lng": "106.5669"
  },
  {
    "country": "VN",
    "name": "Sơn Tịnh",
    "lat": "15.15856",
    "lng": "108.79582"
  },
  {
    "country": "VN",
    "name": "Sơn Tây",
    "lat": "21.14053",
    "lng": "105.50686"
  },
  {
    "country": "VN",
    "name": "Sơn Hà",
    "lat": "15.04193",
    "lng": "108.46973"
  },
  {
    "country": "VN",
    "name": "Sơn Dương",
    "lat": "21.69676",
    "lng": "105.39901"
  },
  {
    "country": "VN",
    "name": "Sơn La",
    "lat": "21.3256",
    "lng": "103.91882"
  },
  {
    "country": "VN",
    "name": "Sông Mã",
    "lat": "21.05091",
    "lng": "103.74987"
  },
  {
    "country": "VN",
    "name": "Sông Cầu",
    "lat": "13.4556",
    "lng": "109.22348"
  },
  {
    "country": "VN",
    "name": "Sóc Trăng",
    "lat": "9.59995",
    "lng": "105.97193"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Sìn Hồ",
    "lat": "22.36647",
    "lng": "103.23438"
  },
  {
    "country": "VN",
    "name": "Si Ma Cai",
    "lat": "22.6951",
    "lng": "104.27857"
  },
  {
    "country": "VN",
    "name": "Sa Pá",
    "lat": "22.34023",
    "lng": "103.84415"
  },
  {
    "country": "VN",
    "name": "Sa Dec",
    "lat": "10.29085",
    "lng": "105.75635"
  },
  {
    "country": "VN",
    "name": "Rạch Giá",
    "lat": "10.01245",
    "lng": "105.08091"
  },
  {
    "country": "VN",
    "name": "Mường Chiên",
    "lat": "21.8424",
    "lng": "103.56608"
  },
  {
    "country": "VN",
    "name": "Quỳnh Côi",
    "lat": "20.66192",
    "lng": "106.32744"
  },
  {
    "country": "VN",
    "name": "Qui Nhon",
    "lat": "13.77648",
    "lng": "109.22367"
  },
  {
    "country": "VN",
    "name": "Quỳ Hợp",
    "lat": "19.32546",
    "lng": "105.18251"
  },
  {
    "country": "VN",
    "name": "Oui Dat",
    "lat": "17.80459",
    "lng": "105.97044"
  },
  {
    "country": "VN",
    "name": "Quỳ Châu",
    "lat": "19.55206",
    "lng": "105.09387"
  },
  {
    "country": "VN",
    "name": "Quế Sơn",
    "lat": "15.67356",
    "lng": "108.2201"
  },
  {
    "country": "VN",
    "name": "Kim Sơn",
    "lat": "19.60409",
    "lng": "104.91903"
  },
  {
    "country": "VN",
    "name": "Quan Hóa",
    "lat": "20.38481",
    "lng": "105.10024"
  },
  {
    "country": "VN",
    "name": "Quảng Yên",
    "lat": "20.9421",
    "lng": "106.8027"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Quảng Uyên",
    "lat": "22.69499",
    "lng": "106.44235"
  },
  {
    "country": "VN",
    "name": "Ba Đồn",
    "lat": "17.75353",
    "lng": "106.42355"
  },
  {
    "country": "VN",
    "name": "Quán Hàu",
    "lat": "17.40438",
    "lng": "106.64072"
  },
  {
    "country": "VN",
    "name": "Quảng Ngãi",
    "lat": "15.12047",
    "lng": "108.79232"
  },
  {
    "country": "VN",
    "name": "Plei Kần",
    "lat": "14.70495",
    "lng": "107.6862"
  },
  {
    "country": "VN",
    "name": "Pleiku",
    "lat": "13.98333",
    "lng": "108"
  },
  {
    "country": "VN",
    "name": "Phù Yên",
    "lat": "21.26331",
    "lng": "104.64439"
  },
  {
    "country": "VN",
    "name": "Phú Vang",
    "lat": "16.43911",
    "lng": "107.71438"
  },
  {
    "country": "VN",
    "name": "Phú Túc",
    "lat": "13.19682",
    "lng": "108.69043"
  },
  {
    "country": "VN",
    "name": "Phủ Thông",
    "lat": "22.27314",
    "lng": "105.87943"
  },
  {
    "country": "VN",
    "name": "Phú Thọ",
    "lat": "21.39963",
    "lng": "105.22221"
  },
  {
    "country": "VN",
    "name": "Dương Đông",
    "lat": "10.21716",
    "lng": "103.95929"
  },
  {
    "country": "VN",
    "name": "Phú Phong",
    "lat": "13.90964",
    "lng": "108.91903"
  },
  {
    "country": "VN",
    "name": "Phước An",
    "lat": "12.71298",
    "lng": "108.30148"
  },
  {
    "country": "VN",
    "name": "Phù Ninh",
    "lat": "21.08333",
    "lng": "105.95"
  },
  {
    "country": "VN",
    "name": "Phụng Hiệp",
    "lat": "9.77972",
    "lng": "105.7338"
  },
  {
    "country": "VN",
    "name": "Phù Mỹ",
    "lat": "14.17182",
    "lng": "109.04888"
  },
  {
    "country": "VN",
    "name": "Thành Phố Phủ Lý",
    "lat": "20.54531",
    "lng": "105.91221"
  },
  {
    "country": "VN",
    "name": "Phú Lộc",
    "lat": "16.28035",
    "lng": "107.85898"
  },
  {
    "country": "VN",
    "name": "Phú Khương",
    "lat": "11.28333",
    "lng": "106.13333"
  },
  {
    "country": "VN",
    "name": "Phúc Yên",
    "lat": "21.23695",
    "lng": "105.70483"
  },
  {
    "country": "VN",
    "name": "Phù Cát",
    "lat": "14.00316",
    "lng": "109.05804"
  },
  {
    "country": "VN",
    "name": "Phong Thổ",
    "lat": "22.54433",
    "lng": "103.29776"
  },
  {
    "country": "VN",
    "name": "Phong Điền",
    "lat": "16.58321",
    "lng": "107.36438"
  },
  {
    "country": "VN",
    "name": "Phong Điền",
    "lat": "9.99753",
    "lng": "105.6673"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Phố Lu",
    "lat": "22.31918",
    "lng": "104.18719"
  },
  {
    "country": "VN",
    "name": "Phố Châu",
    "lat": "18.51335",
    "lng": "105.42411"
  },
  {
    "country": "VN",
    "name": "Bến Sung",
    "lat": "19.63141",
    "lng": "105.57815"
  },
  {
    "country": "VN",
    "name": "Phát Diệm",
    "lat": "20.09054",
    "lng": "106.08323"
  },
  {
    "country": "VN",
    "name": "Phan Thiết",
    "lat": "10.92889",
    "lng": "108.10208"
  },
  {
    "country": "VN",
    "name": "Phan Rang-Tháp Chàm",
    "lat": "11.56432",
    "lng": "108.98858"
  },
  {
    "country": "VN",
    "name": "Ô Môn",
    "lat": "10.10974",
    "lng": "105.62318"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Nước Hai",
    "lat": "22.73738",
    "lng": "106.15216"
  },
  {
    "country": "VN",
    "name": "Núi Đèo",
    "lat": "20.91569",
    "lng": "106.6744"
  },
  {
    "country": "VN",
    "name": "Ninh Hòa",
    "lat": "12.49187",
    "lng": "109.12495"
  },
  {
    "country": "VN",
    "name": "Ninh Giang",
    "lat": "20.73083",
    "lng": "106.39789"
  },
  {
    "country": "VN",
    "name": "Thành Phố Ninh Bình",
    "lat": "20.25809",
    "lng": "105.97965"
  },
  {
    "country": "VN",
    "name": "Như Quỳnh",
    "lat": "20.98167",
    "lng": "105.98486"
  },
  {
    "country": "VN",
    "name": "Nho Quan",
    "lat": "20.32279",
    "lng": "105.75189"
  },
  {
    "country": "VN",
    "name": "Nhơn Trạch",
    "lat": "10.72294",
    "lng": "106.88341"
  },
  {
    "country": "VN",
    "name": "Nha Trang",
    "lat": "12.24507",
    "lng": "109.19432"
  },
  {
    "country": "VN",
    "name": "Nhà Bè",
    "lat": "10.69672",
    "lng": "106.74032"
  },
  {
    "country": "VN",
    "name": "Nhà Bàng",
    "lat": "10.62502",
    "lng": "105.00854"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Nguyên Bình",
    "lat": "22.64995",
    "lng": "105.95985"
  },
  {
    "country": "VN",
    "name": "Ngô Đồng",
    "lat": "20.28296",
    "lng": "106.44347"
  },
  {
    "country": "VN",
    "name": "Ngọc Lặc",
    "lat": "20.09189",
    "lng": "105.36761"
  },
  {
    "country": "VN",
    "name": "Tiền Hải",
    "lat": "20.40557",
    "lng": "106.50365"
  },
  {
    "country": "VN",
    "name": "Nghi Xuân",
    "lat": "18.66206",
    "lng": "105.75575"
  },
  {
    "country": "VN",
    "name": "Quán Hành",
    "lat": "18.77927",
    "lng": "105.64597"
  },
  {
    "country": "VN",
    "name": "Nghĩa Hành",
    "lat": "15.04568",
    "lng": "108.77724"
  },
  {
    "country": "VN",
    "name": "Nga Sơn",
    "lat": "20.00722",
    "lng": "105.97044"
  },
  {
    "country": "VN",
    "name": "Vân Tùng",
    "lat": "22.43082",
    "lng": "105.99687"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Ngải Giao",
    "lat": "10.6471",
    "lng": "107.24577"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Na Sầm",
    "lat": "22.05639",
    "lng": "106.6151"
  },
  {
    "country": "VN",
    "name": "Thành Phố Nam Định",
    "lat": "20.43389",
    "lng": "106.17729"
  },
  {
    "country": "VN",
    "name": "Nam Đàn",
    "lat": "18.69799",
    "lng": "105.49881"
  },
  {
    "country": "VN",
    "name": "Năm Căn",
    "lat": "8.75899",
    "lng": "104.99285"
  },
  {
    "country": "VN",
    "name": "Mỹ Xuyên",
    "lat": "9.56006",
    "lng": "105.98984"
  },
  {
    "country": "VN",
    "name": "Mỹ Tho",
    "lat": "10.36004",
    "lng": "106.35996"
  },
  {
    "country": "VN",
    "name": "Mỹ Thọ",
    "lat": "10.44267",
    "lng": "105.69508"
  },
  {
    "country": "VN",
    "name": "Mỹ Lộc",
    "lat": "20.44111",
    "lng": "106.10238"
  },
  {
    "country": "VN",
    "name": "Thạnh Mỹ",
    "lat": "15.74889",
    "lng": "107.83678"
  },
  {
    "country": "VN",
    "name": "Mường Nhé",
    "lat": "22.19236",
    "lng": "102.4579"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Mường Khương",
    "lat": "22.76141",
    "lng": "104.12156"
  },
  {
    "country": "VN",
    "name": "Mường Lát",
    "lat": "20.52915",
    "lng": "104.60138"
  },
  {
    "country": "VN",
    "name": "Mù Cang Chải",
    "lat": "21.85125",
    "lng": "104.08954"
  },
  {
    "country": "VN",
    "name": "Móng Cái",
    "lat": "21.52471",
    "lng": "107.96619"
  },
  {
    "country": "VN",
    "name": "Mộ Đức",
    "lat": "14.95513",
    "lng": "108.88586"
  },
  {
    "country": "VN",
    "name": "Mộc Châu",
    "lat": "20.85199",
    "lng": "104.62177"
  },
  {
    "country": "VN",
    "name": "Mỏ Cày",
    "lat": "10.13312",
    "lng": "106.33519"
  },
  {
    "country": "VN",
    "name": "Minh Lương",
    "lat": "9.90248",
    "lng": "105.1595"
  },
  {
    "country": "VN",
    "name": "Minh Long",
    "lat": "14.93218",
    "lng": "108.70328"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Mèo Vạc",
    "lat": "23.16411",
    "lng": "105.40993"
  },
  {
    "country": "VN",
    "name": "Ma Đa Gui",
    "lat": "11.38702",
    "lng": "107.53508"
  },
  {
    "country": "VN",
    "name": "Long Xuyên",
    "lat": "10.38639",
    "lng": "105.43518"
  },
  {
    "country": "VN",
    "name": "Long Thành",
    "lat": "10.78909",
    "lng": "106.95029"
  },
  {
    "country": "VN",
    "name": "Long Phú",
    "lat": "9.61025",
    "lng": "106.11881"
  },
  {
    "country": "VN",
    "name": "Long Mỹ",
    "lat": "9.68141",
    "lng": "105.57226"
  },
  {
    "country": "VN",
    "name": "Lộc Ninh",
    "lat": "11.84476",
    "lng": "106.59073"
  },
  {
    "country": "VN",
    "name": "Lộc Bình",
    "lat": "21.75873",
    "lng": "106.92335"
  },
  {
    "country": "VN",
    "name": "Lien De",
    "lat": "20.22095",
    "lng": "106.18747"
  },
  {
    "country": "VN",
    "name": "Liên Hương",
    "lat": "11.22761",
    "lng": "108.72366"
  },
  {
    "country": "VN",
    "name": "Kiến Giang",
    "lat": "17.22328",
    "lng": "106.79011"
  },
  {
    "country": "VN",
    "name": "Lấp Vò",
    "lat": "10.36161",
    "lng": "105.51924"
  },
  {
    "country": "VN",
    "name": "Lao Chải",
    "lat": "22.31377",
    "lng": "103.86844"
  },
  {
    "country": "VN",
    "name": "Lào Cai",
    "lat": "22.48556",
    "lng": "103.97066"
  },
  {
    "country": "VN",
    "name": "Thành Phố Lạng Sơn",
    "lat": "21.85264",
    "lng": "106.76101"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Phước Bửu",
    "lat": "10.53472",
    "lng": "107.40202"
  },
  {
    "country": "VN",
    "name": "Lũng Hồ",
    "lat": "22.98479",
    "lng": "105.23983"
  },
  {
    "country": "VN",
    "name": "Lang Chánh",
    "lat": "20.15611",
    "lng": "105.24223"
  },
  {
    "country": "VN",
    "name": "Lai Vung",
    "lat": "10.28701",
    "lng": "105.6617"
  },
  {
    "country": "VN",
    "name": "Lái Thiêu",
    "lat": "10.90512",
    "lng": "106.69949"
  },
  {
    "country": "VN",
    "name": "Lai Cách",
    "lat": "20.93252",
    "lng": "106.24756"
  },
  {
    "country": "VN",
    "name": "La Gi",
    "lat": "10.65993",
    "lng": "107.77206"
  },
  {
    "country": "VN",
    "name": "Lắk",
    "lat": "12.41086",
    "lng": "108.17682"
  },
  {
    "country": "VN",
    "name": "Lạc Dương",
    "lat": "12.00405",
    "lng": "108.41905"
  },
  {
    "country": "VN",
    "name": "Mường Xén",
    "lat": "19.39795",
    "lng": "104.15239"
  },
  {
    "country": "VN",
    "name": "Kỳ Anh",
    "lat": "18.06243",
    "lng": "106.29832"
  },
  {
    "country": "VN",
    "name": "Kon Tum",
    "lat": "14.35451",
    "lng": "108.00759"
  },
  {
    "country": "VN",
    "name": "Kinh Môn",
    "lat": "20.98962",
    "lng": "106.5551"
  },
  {
    "country": "VN",
    "name": "Kim Bài",
    "lat": "20.85265",
    "lng": "105.76963"
  },
  {
    "country": "VN",
    "name": "Kiên Lương",
    "lat": "10.28624",
    "lng": "104.64616"
  },
  {
    "country": "VN",
    "name": "Khe Sanh",
    "lat": "16.62825",
    "lng": "106.73884"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Khánh Yên",
    "lat": "22.08935",
    "lng": "104.25149"
  },
  {
    "country": "VN",
    "name": "Kẻ Sặt",
    "lat": "20.91007",
    "lng": "106.14771"
  },
  {
    "country": "VN",
    "name": "Kế Sách",
    "lat": "9.76743",
    "lng": "105.98574"
  },
  {
    "country": "VN",
    "name": "Hữu Lũng",
    "lat": "21.5056",
    "lng": "106.34459"
  },
  {
    "country": "VN",
    "name": "Hương Trà",
    "lat": "16.52539",
    "lng": "107.4755"
  },
  {
    "country": "VN",
    "name": "Hương Khê",
    "lat": "18.17669",
    "lng": "105.70019"
  },
  {
    "country": "VN",
    "name": "Hương Canh",
    "lat": "21.27882",
    "lng": "105.64697"
  },
  {
    "country": "VN",
    "name": "Hưng Yên",
    "lat": "20.64637",
    "lng": "106.05112"
  },
  {
    "country": "VN",
    "name": "Huế",
    "lat": "16.4619",
    "lng": "107.59546"
  },
  {
    "country": "VN",
    "name": "Hồ Xá",
    "lat": "17.06836",
    "lng": "107.0052"
  },
  {
    "country": "VN",
    "name": "Bình Long",
    "lat": "11.64711",
    "lng": "106.60586"
  },
  {
    "country": "VN",
    "name": "Thành Phố Hạ Long",
    "lat": "20.95045",
    "lng": "107.07336"
  },
  {
    "country": "VN",
    "name": "Ngoc Hon Doc",
    "lat": "10.18462",
    "lng": "104.92959"
  },
  {
    "country": "VN",
    "name": "Hội An",
    "lat": "15.87944",
    "lng": "108.335"
  },
  {
    "country": "VN",
    "name": "Hóc Môn",
    "lat": "10.8891",
    "lng": "106.59533"
  },
  {
    "country": "VN",
    "name": "Hòa Vang",
    "lat": "15.98764",
    "lng": "108.13893"
  },
  {
    "country": "VN",
    "name": "Hòa Mạc",
    "lat": "20.64173",
    "lng": "105.989"
  },
  {
    "country": "VN",
    "name": "Hoài Ân",
    "lat": "14.36352",
    "lng": "108.96476"
  },
  {
    "country": "VN",
    "name": "Thành Phố Hòa Bình",
    "lat": "20.81717",
    "lng": "105.33759"
  },
  {
    "country": "VN",
    "name": "Doug An",
    "lat": "15.58224",
    "lng": "108.11422"
  },
  {
    "country": "VN",
    "name": "Hà Tĩnh",
    "lat": "18.34282",
    "lng": "105.90569"
  },
  {
    "country": "VN",
    "name": "Hà Tiên",
    "lat": "10.3831",
    "lng": "104.48753"
  },
  {
    "country": "VN",
    "name": "Hanoi",
    "lat": "21.0245",
    "lng": "105.84117"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Thanh Nhật",
    "lat": "22.68749",
    "lng": "106.67004"
  },
  {
    "country": "VN",
    "name": "Hà Lam",
    "lat": "15.73871",
    "lng": "108.35062"
  },
  {
    "country": "VN",
    "name": "Haiphong",
    "lat": "20.86481",
    "lng": "106.68345"
  },
  {
    "country": "VN",
    "name": "Hải Lăng",
    "lat": "16.69347",
    "lng": "107.25124"
  },
  {
    "country": "VN",
    "name": "Thành Phố Hải Dương",
    "lat": "20.94099",
    "lng": "106.33302"
  },
  {
    "country": "VN",
    "name": "Hạ Hòa",
    "lat": "21.56302",
    "lng": "105.00512"
  },
  {
    "country": "VN",
    "name": "Thành Phố Hà Giang",
    "lat": "22.82333",
    "lng": "104.98357"
  },
  {
    "country": "VN",
    "name": "Hà Đông",
    "lat": "20.97136",
    "lng": "105.77876"
  },
  {
    "country": "VN",
    "name": "Gò Quao",
    "lat": "9.7332",
    "lng": "105.27393"
  },
  {
    "country": "VN",
    "name": "Giồng Riềng",
    "lat": "9.90974",
    "lng": "105.31433"
  },
  {
    "country": "VN",
    "name": "Gio Linh",
    "lat": "16.9248",
    "lng": "107.08438"
  },
  {
    "country": "VN",
    "name": "Gia Nghĩa",
    "lat": "12.00423",
    "lng": "107.69074"
  },
  {
    "country": "VN",
    "name": "Duy Xuyên",
    "lat": "15.82898",
    "lng": "108.25956"
  },
  {
    "country": "VN",
    "name": "Đưc Trọng",
    "lat": "11.73559",
    "lng": "108.3733"
  },
  {
    "country": "VN",
    "name": "Đức Thọ",
    "lat": "18.53957",
    "lng": "105.58302"
  },
  {
    "country": "VN",
    "name": "Đức Phong",
    "lat": "11.81346",
    "lng": "107.24433"
  },
  {
    "country": "VN",
    "name": "Pho Duc",
    "lat": "14.81355",
    "lng": "108.95931"
  },
  {
    "country": "VN",
    "name": "Tram de Dak Mil",
    "lat": "12.44957",
    "lng": "107.62237"
  },
  {
    "country": "VN",
    "name": "La Hai",
    "lat": "13.37732",
    "lng": "109.10807"
  },
  {
    "country": "VN",
    "name": "Don Luan",
    "lat": "11.53495",
    "lng": "106.88324"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Đồng Văn",
    "lat": "23.27841",
    "lng": "105.36291"
  },
  {
    "country": "VN",
    "name": "Đồng Mỏ",
    "lat": "21.65701",
    "lng": "106.57832"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Đông Khê",
    "lat": "22.42939",
    "lng": "106.43194"
  },
  {
    "country": "VN",
    "name": "Kwang Binh",
    "lat": "17.46885",
    "lng": "106.62226"
  },
  {
    "country": "VN",
    "name": "Ðông Hà",
    "lat": "16.81625",
    "lng": "107.10031"
  },
  {
    "country": "VN",
    "name": "Anh Son",
    "lat": "18.96961",
    "lng": "105.05505"
  },
  {
    "country": "VN",
    "name": "Đoan Hùng",
    "lat": "21.62254",
    "lng": "105.18462"
  },
  {
    "country": "VN",
    "name": "Đình Lập",
    "lat": "21.54633",
    "lng": "107.09812"
  },
  {
    "country": "VN",
    "name": "Di Linh",
    "lat": "11.58153",
    "lng": "108.07641"
  },
  {
    "country": "VN",
    "name": "Diên Khánh",
    "lat": "12.2549",
    "lng": "109.09332"
  },
  {
    "country": "VN",
    "name": "Diễn Châu",
    "lat": "18.97652",
    "lng": "105.60034"
  },
  {
    "country": "VN",
    "name": "Dien Bien Phu",
    "lat": "21.38602",
    "lng": "103.02301"
  },
  {
    "country": "VN",
    "name": "Quang Nam",
    "lat": "15.88853",
    "lng": "108.25447"
  },
  {
    "country": "VN",
    "name": "Giemdiem",
    "lat": "20.55832",
    "lng": "106.56882"
  },
  {
    "country": "VN",
    "name": "Dĩ An",
    "lat": "10.90682",
    "lng": "106.7694"
  },
  {
    "country": "VN",
    "name": "Dầu Tiếng",
    "lat": "11.2741",
    "lng": "106.35879"
  },
  {
    "country": "VN",
    "name": "Phuoc Tho",
    "lat": "10.49093",
    "lng": "107.27014"
  },
  {
    "country": "VN",
    "name": "Da Nang",
    "lat": "16.06778",
    "lng": "108.22083"
  },
  {
    "country": "VN",
    "name": "Ðà Lạt",
    "lat": "11.94646",
    "lng": "108.44193"
  },
  {
    "country": "VN",
    "name": "Đắk Song",
    "lat": "12.25518",
    "lng": "107.60924"
  },
  {
    "country": "VN",
    "name": "Đại Lộc",
    "lat": "15.88214",
    "lng": "108.12092"
  },
  {
    "country": "VN",
    "name": "Đắk Tô",
    "lat": "14.66092",
    "lng": "107.8389"
  },
  {
    "country": "VN",
    "name": "Củng Sơn",
    "lat": "13.04998",
    "lng": "108.97895"
  },
  {
    "country": "VN",
    "name": "Củ Chi",
    "lat": "10.97333",
    "lng": "106.49325"
  },
  {
    "country": "VN",
    "name": "Cờ Đỏ",
    "lat": "10.09377",
    "lng": "105.42916"
  },
  {
    "country": "VN",
    "name": "Côn Sơn",
    "lat": "8.68641",
    "lng": "106.60824"
  },
  {
    "country": "VN",
    "name": "Con Cuông",
    "lat": "19.04996",
    "lng": "104.88124"
  },
  {
    "country": "VN",
    "name": "Chúc Sơn",
    "lat": "20.92375",
    "lng": "105.70155"
  },
  {
    "country": "VN",
    "name": "Chũ",
    "lat": "21.37379",
    "lng": "106.56649"
  },
  {
    "country": "VN",
    "name": "Chơn Thành",
    "lat": "11.42821",
    "lng": "106.63536"
  },
  {
    "country": "VN",
    "name": "Chợ Mới",
    "lat": "21.88374",
    "lng": "105.77281"
  },
  {
    "country": "VN",
    "name": "Chợ Mới",
    "lat": "10.55123",
    "lng": "105.40441"
  },
  {
    "country": "VN",
    "name": "Chợ Lách",
    "lat": "10.26032",
    "lng": "106.11892"
  },
  {
    "country": "VN",
    "name": "Giồng Trôm",
    "lat": "10.15021",
    "lng": "106.50606"
  },
  {
    "country": "VN",
    "name": "Chợ Gạo",
    "lat": "10.34984",
    "lng": "106.4634"
  },
  {
    "country": "VN",
    "name": "Chợ Chu",
    "lat": "21.90724",
    "lng": "105.64219"
  },
  {
    "country": "VN",
    "name": "Chí Thạnh",
    "lat": "13.30845",
    "lng": "109.21522"
  },
  {
    "country": "VN",
    "name": "Chi Nê",
    "lat": "20.49056",
    "lng": "105.778"
  },
  {
    "country": "VN",
    "name": "Huyện Chiêm Hóa",
    "lat": "22.14413",
    "lng": "105.27277"
  },
  {
    "country": "VN",
    "name": "Cho Dok",
    "lat": "10.7",
    "lng": "105.11667"
  },
  {
    "country": "VN",
    "name": "Cầu Kè",
    "lat": "9.8724",
    "lng": "106.05497"
  },
  {
    "country": "VN",
    "name": "Cầu Giát",
    "lat": "19.146",
    "lng": "105.63089"
  },
  {
    "country": "VN",
    "name": "Cát Bà",
    "lat": "20.72779",
    "lng": "107.04819"
  },
  {
    "country": "VN",
    "name": "Cao Thượng",
    "lat": "21.38707",
    "lng": "106.12931"
  },
  {
    "country": "VN",
    "name": "Cao Lãnh",
    "lat": "10.46017",
    "lng": "105.63294"
  },
  {
    "country": "VN",
    "name": "Thành Phố Cao Bằng",
    "lat": "22.66568",
    "lng": "106.25786"
  },
  {
    "country": "VN",
    "name": "Cần Thơ",
    "lat": "10.03711",
    "lng": "105.78825"
  },
  {
    "country": "VN",
    "name": "Cần Giờ",
    "lat": "10.41115",
    "lng": "106.95474"
  },
  {
    "country": "VN",
    "name": "Cần Đước",
    "lat": "10.50966",
    "lng": "106.60308"
  },
  {
    "country": "VN",
    "name": "Cần Giuộc",
    "lat": "10.60857",
    "lng": "106.67135"
  },
  {
    "country": "VN",
    "name": "Cẩm Xuyên",
    "lat": "18.25029",
    "lng": "106.00132"
  },
  {
    "country": "VN",
    "name": "Cẩm Thủy",
    "lat": "20.20866",
    "lng": "105.4695"
  },
  {
    "country": "VN",
    "name": "Cam Ranh",
    "lat": "11.92144",
    "lng": "109.15913"
  },
  {
    "country": "VN",
    "name": "Cẩm Phả Mines",
    "lat": "21.01667",
    "lng": "107.3"
  },
  {
    "country": "VN",
    "name": "Cẩm Phả",
    "lat": "21.01004",
    "lng": "107.27345"
  },
  {
    "country": "VN",
    "name": "Cam Lộ",
    "lat": "16.80797",
    "lng": "106.99405"
  },
  {
    "country": "VN",
    "name": "Cà Mau",
    "lat": "9.17682",
    "lng": "105.15242"
  },
  {
    "country": "VN",
    "name": "Cái Tàu Hạ",
    "lat": "10.25973",
    "lng": "105.87044"
  },
  {
    "country": "VN",
    "name": "Cái Răng",
    "lat": "10.0009",
    "lng": "105.75095"
  },
  {
    "country": "VN",
    "name": "Cái Nước",
    "lat": "8.94231",
    "lng": "105.01411"
  },
  {
    "country": "VN",
    "name": "Cái Nhum",
    "lat": "10.17412",
    "lng": "106.11051"
  },
  {
    "country": "VN",
    "name": "Buôn Trấp",
    "lat": "12.48478",
    "lng": "108.02982"
  },
  {
    "country": "VN",
    "name": "Buôn Ma Thuột",
    "lat": "12.66747",
    "lng": "108.03775"
  },
  {
    "country": "VN",
    "name": "Hoàn Lão",
    "lat": "17.58436",
    "lng": "106.53425"
  },
  {
    "country": "VN",
    "name": "Bồng Sơn",
    "lat": "14.42907",
    "lng": "109.0156"
  },
  {
    "country": "VN",
    "name": "Bù Đốp",
    "lat": "11.95486",
    "lng": "106.80018"
  },
  {
    "country": "VN",
    "name": "Bình Thủy",
    "lat": "10.07431",
    "lng": "105.73974"
  },
  {
    "country": "VN",
    "name": "Bình Sơn",
    "lat": "15.29776",
    "lng": "108.76124"
  },
  {
    "country": "VN",
    "name": "Bình Gia",
    "lat": "21.96094",
    "lng": "106.36448"
  },
  {
    "country": "VN",
    "name": "Bình Đại",
    "lat": "10.18964",
    "lng": "106.69149"
  },
  {
    "country": "VN",
    "name": "Tân Túc",
    "lat": "10.69541",
    "lng": "106.59128"
  },
  {
    "country": "VN",
    "name": "Bỉm Sơn",
    "lat": "20.07806",
    "lng": "105.86028"
  },
  {
    "country": "VN",
    "name": "Biên Hòa",
    "lat": "10.94469",
    "lng": "106.82432"
  },
  {
    "country": "VN",
    "name": "Bến Tre",
    "lat": "10.24147",
    "lng": "106.37585"
  },
  {
    "country": "VN",
    "name": "Bến Cầu",
    "lat": "11.11051",
    "lng": "106.17924"
  },
  {
    "country": "VN",
    "name": "Ba Tri",
    "lat": "10.04427",
    "lng": "106.5902"
  },
  {
    "country": "VN",
    "name": "Ba Tơ",
    "lat": "14.7636",
    "lng": "108.73223"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Phố Ràng",
    "lat": "22.23429",
    "lng": "104.47643"
  },
  {
    "country": "VN",
    "name": "Bảo Lộc",
    "lat": "11.54798",
    "lng": "107.80772"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Bảo Lạc",
    "lat": "22.94924",
    "lng": "105.68046"
  },
  {
    "country": "VN",
    "name": "Bẩn Yên Nhân",
    "lat": "20.93653",
    "lng": "106.05711"
  },
  {
    "country": "VN",
    "name": "Ít Ong",
    "lat": "21.5175",
    "lng": "104.02701"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Thuận Châu",
    "lat": "21.43849",
    "lng": "103.69"
  },
  {
    "country": "VN",
    "name": "Bắc Yên",
    "lat": "21.24626",
    "lng": "104.43281"
  },
  {
    "country": "VN",
    "name": "Bắc Sơn",
    "lat": "21.89999",
    "lng": "106.32077"
  },
  {
    "country": "VN",
    "name": "Bắc Ninh",
    "lat": "21.18608",
    "lng": "106.07631"
  },
  {
    "country": "VN",
    "name": "Thành phố Bạc Liêu",
    "lat": "9.29414",
    "lng": "105.72776"
  },
  {
    "country": "VN",
    "name": "Bắc Hà",
    "lat": "22.53911",
    "lng": "104.29305"
  },
  {
    "country": "VN",
    "name": "Bắc Giang",
    "lat": "21.27307",
    "lng": "106.1946"
  },
  {
    "country": "VN",
    "name": "Bắc Kạn",
    "lat": "22.14701",
    "lng": "105.83481"
  },
  {
    "country": "VN",
    "name": "Tân Trụ",
    "lat": "10.51271",
    "lng": "106.50762"
  },
  {
    "country": "VN",
    "name": "Ấp Tân Ngãi",
    "lat": "10.23333",
    "lng": "106.28333"
  },
  {
    "country": "VN",
    "name": "An Hòa",
    "lat": "10.29693",
    "lng": "105.74435"
  },
  {
    "country": "VN",
    "name": "An Nhơn",
    "lat": "13.88579",
    "lng": "109.10823"
  },
  {
    "country": "VN",
    "name": "An Lão",
    "lat": "14.61241",
    "lng": "108.8899"
  },
  {
    "country": "VN",
    "name": "An Dương",
    "lat": "20.86382",
    "lng": "106.6133"
  },
  {
    "country": "VN",
    "name": "An Châu",
    "lat": "21.33465",
    "lng": "106.84934"
  },
  {
    "country": "VN",
    "name": "An Biên",
    "lat": "9.81532",
    "lng": "105.06366"
  },
  {
    "country": "VN",
    "name": "A Lưới",
    "lat": "16.27228",
    "lng": "107.23385"
  },
  {
    "country": "VN",
    "name": "Quận Bảy",
    "lat": "10.7118",
    "lng": "106.73643"
  },
  {
    "country": "VN",
    "name": "Tam Điệp",
    "lat": "20.15635",
    "lng": "105.91737"
  },
  {
    "country": "VN",
    "name": "Châu Thành",
    "lat": "9.86989",
    "lng": "106.34939"
  },
  {
    "country": "VN",
    "name": "Uyen Hung",
    "lat": "11.08416",
    "lng": "106.78834"
  },
  {
    "country": "VN",
    "name": "Yên Lập",
    "lat": "21.34705",
    "lng": "105.05739"
  },
  {
    "country": "VN",
    "name": "Thanh Ba",
    "lat": "21.49881",
    "lng": "105.14104"
  },
  {
    "country": "VN",
    "name": "Sông Thao",
    "lat": "21.4213",
    "lng": "105.13374"
  },
  {
    "country": "VN",
    "name": "Hưng Hóa",
    "lat": "21.25487",
    "lng": "105.2953"
  },
  {
    "country": "VN",
    "name": "Phong Châu",
    "lat": "21.4068",
    "lng": "105.31228"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Tân Yên",
    "lat": "22.0655",
    "lng": "105.0345"
  },
  {
    "country": "VN",
    "name": "Tân Việt",
    "lat": "22.86407",
    "lng": "105.45905"
  },
  {
    "country": "VN",
    "name": "Pác Miầu",
    "lat": "22.82968",
    "lng": "105.49334"
  },
  {
    "country": "VN",
    "name": "Lập Thạch",
    "lat": "21.41539",
    "lng": "105.46081"
  },
  {
    "country": "VN",
    "name": "An Châu",
    "lat": "10.44559",
    "lng": "105.38622"
  },
  {
    "country": "VN",
    "name": "Núi Sập",
    "lat": "10.26478",
    "lng": "105.26676"
  },
  {
    "country": "VN",
    "name": "Tầm Vu",
    "lat": "10.44114",
    "lng": "106.46793"
  },
  {
    "country": "VN",
    "name": "Gia Bình",
    "lat": "21.05938",
    "lng": "106.17468"
  },
  {
    "country": "VN",
    "name": "Thứa",
    "lat": "21.01937",
    "lng": "106.20044"
  },
  {
    "country": "VN",
    "name": "Chờ",
    "lat": "21.19491",
    "lng": "105.95471"
  },
  {
    "country": "VN",
    "name": "Phố Mới",
    "lat": "21.15328",
    "lng": "106.15164"
  },
  {
    "country": "VN",
    "name": "Hồ",
    "lat": "21.06308",
    "lng": "106.0857"
  },
  {
    "country": "VN",
    "name": "Lim",
    "lat": "21.14388",
    "lng": "106.02018"
  },
  {
    "country": "VN",
    "name": "Cung Kiệm",
    "lat": "21.18697",
    "lng": "106.16076"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Gành Hào",
    "lat": "9.03183",
    "lng": "105.42115"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Ngan Dừa",
    "lat": "9.56703",
    "lng": "105.45019"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Phước Long",
    "lat": "9.43753",
    "lng": "105.46217"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Giá Rai",
    "lat": "9.23789",
    "lng": "105.45524"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Hòa Bình",
    "lat": "9.28471",
    "lng": "105.62916"
  },
  {
    "country": "VN",
    "name": "Cái Dầu",
    "lat": "10.57428",
    "lng": "105.24005"
  },
  {
    "country": "VN",
    "name": "Cầu Gồ",
    "lat": "21.47679",
    "lng": "106.12653"
  },
  {
    "country": "VN",
    "name": "Đồi Ngô",
    "lat": "21.30626",
    "lng": "106.38673"
  },
  {
    "country": "VN",
    "name": "Neo",
    "lat": "21.20048",
    "lng": "106.24739"
  },
  {
    "country": "VN",
    "name": "Bích Động",
    "lat": "21.27421",
    "lng": "106.10069"
  },
  {
    "country": "VN",
    "name": "Thắng",
    "lat": "21.35505",
    "lng": "105.98344"
  },
  {
    "country": "VN",
    "name": "Bộc Bố",
    "lat": "22.61206",
    "lng": "105.66707"
  },
  {
    "country": "VN",
    "name": "Bằng Lũng",
    "lat": "22.15777",
    "lng": "105.59559"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Long Điền",
    "lat": "10.48557",
    "lng": "107.21226"
  },
  {
    "country": "VN",
    "name": "Mường Chà",
    "lat": "21.76172",
    "lng": "103.09783"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Tủa Chùa",
    "lat": "21.85771",
    "lng": "103.3426"
  },
  {
    "country": "VN",
    "name": "Điện Biên Đông",
    "lat": "21.29673",
    "lng": "103.22009"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Điện Biên",
    "lat": "21.2596",
    "lng": "103.0344"
  },
  {
    "country": "VN",
    "name": "Tam Đường",
    "lat": "22.31812",
    "lng": "103.62619"
  },
  {
    "country": "VN",
    "name": "Lai Châu",
    "lat": "22.39644",
    "lng": "103.45824"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Mường Tè",
    "lat": "22.38067",
    "lng": "102.82011"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Tam Sơn",
    "lat": "23.0674",
    "lng": "104.98926"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Vị Xuyên",
    "lat": "22.66762",
    "lng": "104.98191"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Việt Lâm",
    "lat": "22.62486",
    "lng": "104.95988"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Việt Quang",
    "lat": "22.41509",
    "lng": "104.80682"
  },
  {
    "country": "VN",
    "name": "Yên Phú",
    "lat": "22.73223",
    "lng": "105.37145"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Vinh Quang",
    "lat": "22.74085",
    "lng": "104.67956"
  },
  {
    "country": "VN",
    "name": "Yên Bình",
    "lat": "22.40989",
    "lng": "104.57949"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Thông Nông",
    "lat": "22.7841",
    "lng": "105.9832"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Xuân Hoà",
    "lat": "22.90243",
    "lng": "106.07737"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Hùng Quốc",
    "lat": "22.82898",
    "lng": "106.32335"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Cao Lộc",
    "lat": "21.8665",
    "lng": "106.76833"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Vĩnh Lộc",
    "lat": "22.1436",
    "lng": "105.27192"
  },
  {
    "country": "VN",
    "name": "Sơn Thịnh",
    "lat": "21.56252",
    "lng": "104.5948"
  },
  {
    "country": "VN",
    "name": "Cổ Phúc",
    "lat": "21.75585",
    "lng": "104.82768"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Yên Thế",
    "lat": "22.11075",
    "lng": "104.76748"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Na Hang",
    "lat": "22.34917",
    "lng": "105.38241"
  },
  {
    "country": "VN",
    "name": "Bình Minh",
    "lat": "10.06821",
    "lng": "105.82221"
  },
  {
    "country": "VN",
    "name": "An Phú",
    "lat": "10.81591",
    "lng": "105.09038"
  },
  {
    "country": "VN",
    "name": "Phú Mỹ",
    "lat": "10.59236",
    "lng": "105.35573"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Phú Mỹ",
    "lat": "10.6036",
    "lng": "107.054"
  },
  {
    "country": "VN",
    "name": "Bát Xát",
    "lat": "22.54311",
    "lng": "103.88989"
  },
  {
    "country": "VN",
    "name": "Hát Lót",
    "lat": "21.19733",
    "lng": "104.10595"
  },
  {
    "country": "VN",
    "name": "Quảng Xương",
    "lat": "19.72948",
    "lng": "105.78273"
  },
  {
    "country": "VN",
    "name": "Nông Cống",
    "lat": "19.62403",
    "lng": "105.64941"
  },
  {
    "country": "VN",
    "name": "Quan Sơn",
    "lat": "20.25909",
    "lng": "104.94521"
  },
  {
    "country": "VN",
    "name": "Yên Cát",
    "lat": "19.66327",
    "lng": "105.42854"
  },
  {
    "country": "VN",
    "name": "Bút Sơn",
    "lat": "19.85797",
    "lng": "105.85482"
  },
  {
    "country": "VN",
    "name": "Cành Nàng",
    "lat": "20.34803",
    "lng": "105.22881"
  },
  {
    "country": "VN",
    "name": "Hậu Lộc",
    "lat": "19.91444",
    "lng": "105.88615"
  },
  {
    "country": "VN",
    "name": "Triệu Sơn",
    "lat": "19.81913",
    "lng": "105.60392"
  },
  {
    "country": "VN",
    "name": "Quán Lào",
    "lat": "19.97153",
    "lng": "105.65106"
  },
  {
    "country": "VN",
    "name": "Hà Trung",
    "lat": "20.01285",
    "lng": "105.85322"
  },
  {
    "country": "VN",
    "name": "Rừng Thông",
    "lat": "19.81906",
    "lng": "105.73279"
  },
  {
    "country": "VN",
    "name": "Vạn Hà",
    "lat": "19.88659",
    "lng": "105.67879"
  },
  {
    "country": "VN",
    "name": "Đà Bắc",
    "lat": "20.87714",
    "lng": "105.25417"
  },
  {
    "country": "VN",
    "name": "Mường Khến",
    "lat": "20.61441",
    "lng": "105.27948"
  },
  {
    "country": "VN",
    "name": "Hàng Trạm",
    "lat": "20.39472",
    "lng": "105.6224"
  },
  {
    "country": "VN",
    "name": "Bo",
    "lat": "20.67264",
    "lng": "105.53625"
  },
  {
    "country": "VN",
    "name": "Lương Sơn",
    "lat": "20.87148",
    "lng": "105.52568"
  },
  {
    "country": "VN",
    "name": "Kỳ Sơn",
    "lat": "20.88668",
    "lng": "105.35244"
  },
  {
    "country": "VN",
    "name": "Cao Phong",
    "lat": "20.70446",
    "lng": "105.32063"
  },
  {
    "country": "VN",
    "name": "Me",
    "lat": "20.34697",
    "lng": "105.83615"
  },
  {
    "country": "VN",
    "name": "Thiên Tồn",
    "lat": "20.29905",
    "lng": "105.95198"
  },
  {
    "country": "VN",
    "name": "Yên Thịnh",
    "lat": "20.16245",
    "lng": "106.00697"
  },
  {
    "country": "VN",
    "name": "Xuân Trường",
    "lat": "20.29227",
    "lng": "106.33275"
  },
  {
    "country": "VN",
    "name": "Yên Định",
    "lat": "20.20145",
    "lng": "106.29578"
  },
  {
    "country": "VN",
    "name": "Lâm",
    "lat": "20.32773",
    "lng": "106.01208"
  },
  {
    "country": "VN",
    "name": "Gôi",
    "lat": "20.33335",
    "lng": "106.07826"
  },
  {
    "country": "VN",
    "name": "Nam Giang",
    "lat": "20.33322",
    "lng": "106.17754"
  },
  {
    "country": "VN",
    "name": "Cổ Lễ",
    "lat": "20.32336",
    "lng": "106.26584"
  },
  {
    "country": "VN",
    "name": "Quế",
    "lat": "20.58064",
    "lng": "105.87266"
  },
  {
    "country": "VN",
    "name": "Vĩnh Trụ",
    "lat": "20.5602",
    "lng": "106.02812"
  },
  {
    "country": "VN",
    "name": "Bình Mỹ",
    "lat": "20.49121",
    "lng": "106.00955"
  },
  {
    "country": "VN",
    "name": "Thanh Lưu",
    "lat": "20.47398",
    "lng": "105.95268"
  },
  {
    "country": "VN",
    "name": "Hưng Hà",
    "lat": "20.5904",
    "lng": "106.22445"
  },
  {
    "country": "VN",
    "name": "Vũ Thư",
    "lat": "20.43671",
    "lng": "106.29116"
  },
  {
    "country": "VN",
    "name": "Đông Hưng",
    "lat": "20.55651",
    "lng": "106.35532"
  },
  {
    "country": "VN",
    "name": "Thành Phố Bà Rịa",
    "lat": "10.49629",
    "lng": "107.16841"
  },
  {
    "country": "VN",
    "name": "Thị Trấn Tuần Giáo",
    "lat": "21.58992",
    "lng": "103.42179"
  },
  {
    "country": "VN",
    "name": "Mường Ảng",
    "lat": "21.51993",
    "lng": "103.22294"
  },
  {
    "country": "VN",
    "name": "An Lão",
    "lat": "20.82294",
    "lng": "106.55575"
  },
  {
    "country": "VN",
    "name": "Tiên Lãng",
    "lat": "20.72464",
    "lng": "106.55391"
  },
  {
    "country": "VN",
    "name": "Núi Đối",
    "lat": "20.75078",
    "lng": "106.66894"
  },
  {
    "country": "VN",
    "name": "Quảng Hà",
    "lat": "21.4506",
    "lng": "107.75592"
  },
  {
    "country": "VN",
    "name": "Trới",
    "lat": "21.03141",
    "lng": "106.99101"
  },
  {
    "country": "VN",
    "name": "Cô Tô",
    "lat": "20.97268",
    "lng": "107.76578"
  },
  {
    "country": "VN",
    "name": "Thanh Miện",
    "lat": "20.78714",
    "lng": "106.24623"
  },
  {
    "country": "VN",
    "name": "Nam Sách",
    "lat": "20.99205",
    "lng": "106.33613"
  },
  {
    "country": "VN",
    "name": "Gia Lộc",
    "lat": "20.86783",
    "lng": "106.3"
  },
  {
    "country": "VN",
    "name": "Tứ Kỳ",
    "lat": "20.81914",
    "lng": "106.40661"
  },
  {
    "country": "VN",
    "name": "Thanh Hà",
    "lat": "20.89816",
    "lng": "106.42612"
  },
  {
    "country": "VN",
    "name": "Phú Thái",
    "lat": "20.96278",
    "lng": "106.5095"
  },
  {
    "country": "VN",
    "name": "Đu",
    "lat": "21.73847",
    "lng": "105.70388"
  },
  {
    "country": "VN",
    "name": "Hương Sơn",
    "lat": "21.46014",
    "lng": "105.97814"
  },
  {
    "country": "VN",
    "name": "Chùa Hang",
    "lat": "21.62384",
    "lng": "105.84168"
  },
  {
    "country": "VN",
    "name": "Thanh Thủy",
    "lat": "21.17548",
    "lng": "105.28388"
  },
  {
    "country": "VN",
    "name": "Lâm Thao",
    "lat": "21.3201",
    "lng": "105.29156"
  },
  {
    "country": "VN",
    "name": "Mê Linh",
    "lat": "21.1831",
    "lng": "105.72041"
  },
  {
    "country": "VN",
    "name": "Vĩnh Tường",
    "lat": "21.2165",
    "lng": "105.51249"
  },
  {
    "country": "VN",
    "name": "Hợp Hòa",
    "lat": "21.37525",
    "lng": "105.54256"
  },
  {
    "country": "VN",
    "name": "Văn Giang",
    "lat": "20.94301",
    "lng": "105.93119"
  },
  {
    "country": "VN",
    "name": "Yên Mỹ",
    "lat": "20.88557",
    "lng": "106.0356"
  },
  {
    "country": "VN",
    "name": "Khoái Châu",
    "lat": "20.83912",
    "lng": "105.97755"
  },
  {
    "country": "VN",
    "name": "Lương Bằng",
    "lat": "20.74003",
    "lng": "106.05998"
  },
  {
    "country": "VN",
    "name": "Ân Thi",
    "lat": "20.81835",
    "lng": "106.09118"
  },
  {
    "country": "VN",
    "name": "Trần Cao",
    "lat": "20.72952",
    "lng": "106.17971"
  },
  {
    "country": "VN",
    "name": "Vương",
    "lat": "20.7011",
    "lng": "106.11751"
  },
  {
    "country": "VN",
    "name": "Liên Quan",
    "lat": "21.05723",
    "lng": "105.57919"
  },
  {
    "country": "VN",
    "name": "Phúc Thọ",
    "lat": "21.10345",
    "lng": "105.54551"
  },
  {
    "country": "VN",
    "name": "Phùng",
    "lat": "21.08902",
    "lng": "105.65901"
  },
  {
    "country": "VN",
    "name": "Trôi",
    "lat": "21.06953",
    "lng": "105.70646"
  },
  {
    "country": "VN",
    "name": "Quốc Oai",
    "lat": "20.99019",
    "lng": "105.64088"
  },
  {
    "country": "VN",
    "name": "Thường Tín",
    "lat": "20.86874",
    "lng": "105.86125"
  },
  {
    "country": "VN",
    "name": "Phú Xuyên",
    "lat": "20.74549",
    "lng": "105.91363"
  },
  {
    "country": "VN",
    "name": "Đại Nghĩa",
    "lat": "20.68667",
    "lng": "105.74471"
  },
  {
    "country": "VN",
    "name": "Sóc Sơn",
    "lat": "21.25782",
    "lng": "105.84894"
  },
  {
    "country": "VN",
    "name": "Đông Anh",
    "lat": "21.13962",
    "lng": "105.84926"
  },
  {
    "country": "VN",
    "name": "Cầu Diễn",
    "lat": "21.03929",
    "lng": "105.76659"
  },
  {
    "country": "VN",
    "name": "Trâu Quỳ",
    "lat": "21.01951",
    "lng": "105.93694"
  },
  {
    "country": "VN",
    "name": "Cầu Giấy",
    "lat": "21.03228",
    "lng": "105.80073"
  },
  {
    "country": "VN",
    "name": "Thanh Xuân",
    "lat": "20.99472",
    "lng": "105.79977"
  },
  {
    "country": "VN",
    "name": "Đống Đa",
    "lat": "21.02009",
    "lng": "105.83097"
  },
  {
    "country": "VN",
    "name": "Hoàn Kiếm",
    "lat": "21.02857",
    "lng": "105.85064"
  },
  {
    "country": "VN",
    "name": "Hai BàTrưng",
    "lat": "21.01341",
    "lng": "105.84772"
  },
  {
    "country": "VN",
    "name": "Hưng Nguyên",
    "lat": "18.67165",
    "lng": "105.62882"
  },
  {
    "country": "VN",
    "name": "Vũ Quang",
    "lat": "18.38385",
    "lng": "105.5059"
  },
  {
    "country": "VN",
    "name": "Nghèn",
    "lat": "18.45119",
    "lng": "105.77969"
  },
  {
    "country": "VN",
    "name": "Đồng Lê",
    "lat": "17.88389",
    "lng": "106.02536"
  },
  {
    "country": "VN",
    "name": "Krông Klang",
    "lat": "16.68906",
    "lng": "106.8874"
  },
  {
    "country": "VN",
    "name": "Khe Tre",
    "lat": "16.1691",
    "lng": "107.71793"
  },
  {
    "country": "VN",
    "name": "Sịa",
    "lat": "16.57452",
    "lng": "107.51066"
  },
  {
    "country": "VN",
    "name": "Thanh Khê",
    "lat": "16.0706",
    "lng": "108.19102"
  },
  {
    "country": "VN",
    "name": "Cẩm Lệ",
    "lat": "16.01771",
    "lng": "108.20381"
  },
  {
    "country": "VN",
    "name": "Sơn Trà",
    "lat": "16.06068",
    "lng": "108.23256"
  },
  {
    "country": "VN",
    "name": "Liên Chiểu",
    "lat": "16.07272",
    "lng": "108.15815"
  },
  {
    "country": "VN",
    "name": "Ngũ Hành Sơn",
    "lat": "16.01618",
    "lng": "108.25335"
  },
  {
    "country": "VN",
    "name": "Prao",
    "lat": "15.92438",
    "lng": "107.64814"
  },
  {
    "country": "VN",
    "name": "Khâm Đức",
    "lat": "15.44508",
    "lng": "107.79337"
  },
  {
    "country": "VN",
    "name": "Núi Thành",
    "lat": "15.43194",
    "lng": "108.65946"
  },
  {
    "country": "VN",
    "name": "Phú Ninh",
    "lat": "15.55473",
    "lng": "108.41142"
  },
  {
    "country": "VN",
    "name": "Tây Trà",
    "lat": "15.16948",
    "lng": "108.35998"
  },
  {
    "country": "VN",
    "name": "Lý Sơn",
    "lat": "15.37198",
    "lng": "109.11891"
  },
  {
    "country": "VN",
    "name": "Đắk Glei",
    "lat": "15.08642",
    "lng": "107.73577"
  },
  {
    "country": "VN",
    "name": "Sa Thầy",
    "lat": "14.41377",
    "lng": "107.79339"
  },
  {
    "country": "VN",
    "name": "Đắk Hà",
    "lat": "14.51345",
    "lng": "107.92102"
  },
  {
    "country": "VN",
    "name": "Đắk Rve",
    "lat": "14.50717",
    "lng": "108.2473"
  },
  {
    "country": "VN",
    "name": "Măng Đen",
    "lat": "14.60064",
    "lng": "108.29088"
  },
  {
    "country": "VN",
    "name": "Đăk Đoa",
    "lat": "13.99501",
    "lng": "108.11207"
  },
  {
    "country": "VN",
    "name": "K Bang",
    "lat": "14.14453",
    "lng": "108.59908"
  },
  {
    "country": "VN",
    "name": "Kông Chro",
    "lat": "13.77532",
    "lng": "108.52558"
  },
  {
    "country": "VN",
    "name": "Ia Pa",
    "lat": "13.53361",
    "lng": "108.45529"
  },
  {
    "country": "VN",
    "name": "A Yun Pa",
    "lat": "13.40025",
    "lng": "108.43503"
  },
  {
    "country": "VN",
    "name": "Chư Sê",
    "lat": "13.69153",
    "lng": "108.08023"
  },
  {
    "country": "VN",
    "name": "Chư Prông",
    "lat": "13.75684",
    "lng": "107.88624"
  },
  {
    "country": "VN",
    "name": "Chư Ty",
    "lat": "13.80507",
    "lng": "107.6961"
  },
  {
    "country": "VN",
    "name": "Ia Kha",
    "lat": "13.96242",
    "lng": "107.84484"
  },
  {
    "country": "VN",
    "name": "Phú Hòa",
    "lat": "14.10005",
    "lng": "107.96896"
  },
  {
    "country": "VN",
    "name": "Kon Dơng",
    "lat": "14.03886",
    "lng": "108.25011"
  },
  {
    "country": "VN",
    "name": "Hai Riêng",
    "lat": "12.97908",
    "lng": "108.89732"
  },
  {
    "country": "VN",
    "name": "Ea Súp",
    "lat": "13.06616",
    "lng": "107.88546"
  },
  {
    "country": "VN",
    "name": "Ea Drăng",
    "lat": "13.2045",
    "lng": "108.21029"
  },
  {
    "country": "VN",
    "name": "Krông Năng",
    "lat": "12.9517",
    "lng": "108.34425"
  },
  {
    "country": "VN",
    "name": "Quảng Phú",
    "lat": "12.81965",
    "lng": "108.07738"
  },
  {
    "country": "VN",
    "name": "Ea Kar",
    "lat": "12.80816",
    "lng": "108.44901"
  },
  {
    "country": "VN",
    "name": "Krông Kmar",
    "lat": "12.5045",
    "lng": "108.33288"
  },
  {
    "country": "VN",
    "name": "M’Đrăk",
    "lat": "12.74624",
    "lng": "108.74281"
  },
  {
    "country": "VN",
    "name": "Khánh Vĩnh",
    "lat": "12.28355",
    "lng": "108.9047"
  },
  {
    "country": "VN",
    "name": "Tô Hạp",
    "lat": "12.00582",
    "lng": "108.94868"
  },
  {
    "country": "VN",
    "name": "Cam Lâm",
    "lat": "12.05398",
    "lng": "109.16004"
  },
  {
    "country": "VN",
    "name": "Ea T’ling",
    "lat": "12.58904",
    "lng": "107.89578"
  },
  {
    "country": "VN",
    "name": "Đắk Mâm",
    "lat": "12.45789",
    "lng": "107.86246"
  },
  {
    "country": "VN",
    "name": "Đinh Văn",
    "lat": "11.78624",
    "lng": "108.24282"
  },
  {
    "country": "VN",
    "name": "Thạnh Mỹ",
    "lat": "11.76165",
    "lng": "108.49473"
  },
  {
    "country": "VN",
    "name": "Lộc Thắng",
    "lat": "11.62836",
    "lng": "107.83508"
  },
  {
    "country": "VN",
    "name": "Đồng Nai",
    "lat": "11.57981",
    "lng": "107.36518"
  },
  {
    "country": "VN",
    "name": "Đạ Tẻh",
    "lat": "11.51148",
    "lng": "107.49092"
  },
  {
    "country": "VN",
    "name": "Bác Ái",
    "lat": "11.84104",
    "lng": "108.90316"
  },
  {
    "country": "VN",
    "name": "Tân Sơn",
    "lat": "11.77521",
    "lng": "108.7848"
  },
  {
    "country": "VN",
    "name": "Phước Dân",
    "lat": "11.52696",
    "lng": "108.92996"
  },
  {
    "country": "VN",
    "name": "Khánh Hải",
    "lat": "11.59105",
    "lng": "109.04052"
  },
  {
    "country": "VN",
    "name": "Chợ Lầu",
    "lat": "11.22158",
    "lng": "108.50707"
  },
  {
    "country": "VN",
    "name": "Ma Lâm",
    "lat": "11.07297",
    "lng": "108.12997"
  },
  {
    "country": "VN",
    "name": "Thuận Nam",
    "lat": "10.85004",
    "lng": "107.87864"
  },
  {
    "country": "VN",
    "name": "Phú Quý",
    "lat": "10.5166",
    "lng": "108.93292"
  },
  {
    "country": "VN",
    "name": "Tân Phú",
    "lat": "11.27221",
    "lng": "107.43655"
  },
  {
    "country": "VN",
    "name": "Vĩnh An",
    "lat": "11.08901",
    "lng": "107.03516"
  },
  {
    "country": "VN",
    "name": "Thống Nhất",
    "lat": "10.95055",
    "lng": "107.14571"
  },
  {
    "country": "VN",
    "name": "Long Khánh",
    "lat": "10.92655",
    "lng": "107.24783"
  },
  {
    "country": "VN",
    "name": "Tân Phú",
    "lat": "11.45119",
    "lng": "106.86811"
  },
  {
    "country": "VN",
    "name": "Tân Châu",
    "lat": "11.55202",
    "lng": "106.17245"
  },
  {
    "country": "VN",
    "name": "Tân Biên",
    "lat": "11.54441",
    "lng": "106.01161"
  },
  {
    "country": "VN",
    "name": "Châu Thành",
    "lat": "11.31167",
    "lng": "106.0295"
  },
  {
    "country": "VN",
    "name": "Hòa Thành",
    "lat": "11.28696",
    "lng": "106.12936"
  },
  {
    "country": "VN",
    "name": "Gò Dầu",
    "lat": "11.0885",
    "lng": "106.26346"
  },
  {
    "country": "VN",
    "name": "Dương Minh Châu",
    "lat": "11.38414",
    "lng": "106.23078"
  },
  {
    "country": "VN",
    "name": "Tân Hưng",
    "lat": "10.83476",
    "lng": "105.66135"
  },
  {
    "country": "VN",
    "name": "Vĩnh Hưng",
    "lat": "10.89067",
    "lng": "105.78495"
  },
  {
    "country": "VN",
    "name": "Tân Thạnh",
    "lat": "10.60666",
    "lng": "106.04714"
  },
  {
    "country": "VN",
    "name": "Thạnh Hóa",
    "lat": "10.65744",
    "lng": "106.18081"
  },
  {
    "country": "VN",
    "name": "Đông Thành",
    "lat": "10.89221",
    "lng": "106.30614"
  },
  {
    "country": "VN",
    "name": "Hậu Nghĩa",
    "lat": "10.89434",
    "lng": "106.39695"
  },
  {
    "country": "VN",
    "name": "Mỹ Phước",
    "lat": "10.47711",
    "lng": "106.19256"
  },
  {
    "country": "VN",
    "name": "Tân Hòa",
    "lat": "10.31906",
    "lng": "106.71128"
  },
  {
    "country": "VN",
    "name": "Thứ Mười Một",
    "lat": "9.61144",
    "lng": "104.9465"
  },
  {
    "country": "VN",
    "name": "Sa Rài",
    "lat": "10.87016",
    "lng": "105.46583"
  },
  {
    "country": "VN",
    "name": "Long Hồ",
    "lat": "10.19281",
    "lng": "106.01229"
  },
  {
    "country": "VN",
    "name": "Duyên Hải",
    "lat": "9.63497",
    "lng": "106.49237"
  },
  {
    "country": "VN",
    "name": "Châu Thành",
    "lat": "10.30122",
    "lng": "106.35701"
  },
  {
    "country": "VN",
    "name": "Vĩnh Thạnh",
    "lat": "10.22263",
    "lng": "105.39841"
  },
  {
    "country": "VN",
    "name": "Nàng Mau",
    "lat": "9.75129",
    "lng": "105.53448"
  },
  {
    "country": "VN",
    "name": "Ngã Bảy",
    "lat": "9.81371",
    "lng": "105.82096"
  },
  {
    "country": "VN",
    "name": "Ngã Sáu",
    "lat": "9.92303",
    "lng": "105.80542"
  },
  {
    "country": "VN",
    "name": "Một Ngàn",
    "lat": "9.92402",
    "lng": "105.62964"
  },
  {
    "country": "VN",
    "name": "Cù Lao Dung",
    "lat": "9.67314",
    "lng": "106.14874"
  },
  {
    "country": "VN",
    "name": "Châu Thành",
    "lat": "9.7007",
    "lng": "105.90202"
  },
  {
    "country": "VN",
    "name": "Huỳnh Hữu Nghĩa",
    "lat": "9.63537",
    "lng": "105.81165"
  },
  {
    "country": "VN",
    "name": "U Minh",
    "lat": "9.41286",
    "lng": "104.97353"
  },
  {
    "country": "VN",
    "name": "Trần Văn Thời",
    "lat": "9.07713",
    "lng": "104.97914"
  },
  {
    "country": "VN",
    "name": "Ngọc Hiển",
    "lat": "8.65724",
    "lng": "105.06021"
  },
  {
    "country": "VN",
    "name": "Quận Hai",
    "lat": "10.79156",
    "lng": "106.74948"
  },
  {
    "country": "VN",
    "name": "Quận Chín",
    "lat": "10.8397",
    "lng": "106.77093"
  },
  {
    "country": "VN",
    "name": "Quận Bốn",
    "lat": "10.76684",
    "lng": "106.70574"
  },
  {
    "country": "VN",
    "name": "Quận Sáu",
    "lat": "10.7468",
    "lng": "106.64903"
  },
  {
    "country": "VN",
    "name": "Quận Năm",
    "lat": "10.75567",
    "lng": "106.66745"
  },
  {
    "country": "VN",
    "name": "Quận Một",
    "lat": "10.78069",
    "lng": "106.69944"
  },
  {
    "country": "VN",
    "name": "Quận Phú Nhuận",
    "lat": "10.79475",
    "lng": "106.6763"
  },
  {
    "country": "VN",
    "name": "Quận Tân Phú",
    "lat": "10.78379",
    "lng": "106.63704"
  },
  {
    "country": "VN",
    "name": "Quận Mười Một",
    "lat": "10.76383",
    "lng": "106.64355"
  },
  {
    "country": "VN",
    "name": "Quận Mười",
    "lat": "10.76823",
    "lng": "106.66632"
  },
  {
    "country": "VN",
    "name": "Quận Ba",
    "lat": "10.77494",
    "lng": "106.68628"
  },
  {
    "country": "VN",
    "name": "Quận Bình Thạnh",
    "lat": "10.80325",
    "lng": "106.69666"
  },
  {
    "country": "VN",
    "name": "Hoàng Sa",
    "lat": "16.66657",
    "lng": "112.72541"
  },
  {
    "country": "VU",
    "name": "Sola",
    "lat": "-13.87611",
    "lng": "167.55167"
  },
  {
    "country": "VU",
    "name": "Port-Vila",
    "lat": "-17.73381",
    "lng": "168.32188"
  },
  {
    "country": "VU",
    "name": "Port-Olry",
    "lat": "-15.04175",
    "lng": "167.07265"
  },
  {
    "country": "VU",
    "name": "Norsup",
    "lat": "-16.06536",
    "lng": "167.39714"
  },
  {
    "country": "VU",
    "name": "Luganville",
    "lat": "-15.51989",
    "lng": "167.16235"
  },
  {
    "country": "VU",
    "name": "Lakatoro",
    "lat": "-16.09992",
    "lng": "167.41636"
  },
  {
    "country": "VU",
    "name": "Isangel",
    "lat": "-19.54167",
    "lng": "169.28167"
  },
  {
    "country": "VU",
    "name": "Saratamata",
    "lat": "-15.29031",
    "lng": "167.96679"
  },
  {
    "country": "WF",
    "name": "Leava",
    "lat": "-14.29333",
    "lng": "-178.15833"
  },
  {
    "country": "WF",
    "name": "Mata-Utu",
    "lat": "-13.28163",
    "lng": "-176.17453"
  },
  {
    "country": "WF",
    "name": "Alo",
    "lat": "-14.31096",
    "lng": "-178.11094"
  },
  {
    "country": "WS",
    "name": "Vaiusu",
    "lat": "-13.82678",
    "lng": "-171.79333"
  },
  {
    "country": "WS",
    "name": "Vailima",
    "lat": "-13.86417",
    "lng": "-171.76126"
  },
  {
    "country": "WS",
    "name": "Vailoa",
    "lat": "-13.75551",
    "lng": "-172.30698"
  },
  {
    "country": "WS",
    "name": "Solosolo",
    "lat": "-13.87504",
    "lng": "-171.64181"
  },
  {
    "country": "WS",
    "name": "Siusega",
    "lat": "-13.84432",
    "lng": "-171.81397"
  },
  {
    "country": "WS",
    "name": "Satupa‘itea",
    "lat": "-13.76593",
    "lng": "-172.32686"
  },
  {
    "country": "WS",
    "name": "Satapuala",
    "lat": "-13.83535",
    "lng": "-171.97963"
  },
  {
    "country": "WS",
    "name": "Samamea",
    "lat": "-13.93375",
    "lng": "-171.53122"
  },
  {
    "country": "WS",
    "name": "Safotulafai",
    "lat": "-13.67147",
    "lng": "-172.17768"
  },
  {
    "country": "WS",
    "name": "Safotu",
    "lat": "-13.45132",
    "lng": "-172.40177"
  },
  {
    "country": "WS",
    "name": "Nofoali‘i",
    "lat": "-13.8217",
    "lng": "-171.95873"
  },
  {
    "country": "WS",
    "name": "Mulifanua",
    "lat": "-13.83183",
    "lng": "-172.03602"
  },
  {
    "country": "WS",
    "name": "Matavai",
    "lat": "-14.03208",
    "lng": "-171.64768"
  },
  {
    "country": "WS",
    "name": "Malie",
    "lat": "-13.80044",
    "lng": "-171.8469"
  },
  {
    "country": "WS",
    "name": "Lufilufi",
    "lat": "-13.87449",
    "lng": "-171.59857"
  },
  {
    "country": "WS",
    "name": "Lotofagā",
    "lat": "-13.97643",
    "lng": "-171.85781"
  },
  {
    "country": "WS",
    "name": "Leulumoega",
    "lat": "-13.82297",
    "lng": "-171.96127"
  },
  {
    "country": "WS",
    "name": "Gataivai",
    "lat": "-13.7736",
    "lng": "-172.38802"
  },
  {
    "country": "WS",
    "name": "Fasito‘outa",
    "lat": "-13.81163",
    "lng": "-171.94063"
  },
  {
    "country": "WS",
    "name": "Faleula",
    "lat": "-13.79457",
    "lng": "-171.83126"
  },
  {
    "country": "WS",
    "name": "Falefa",
    "lat": "-13.88695",
    "lng": "-171.58805"
  },
  {
    "country": "WS",
    "name": "Apia",
    "lat": "-13.83333",
    "lng": "-171.76666"
  },
  {
    "country": "WS",
    "name": "Afega",
    "lat": "-13.79726",
    "lng": "-171.85308"
  },
  {
    "country": "WS",
    "name": "Asau",
    "lat": "-13.51963",
    "lng": "-172.63784"
  },
  {
    "country": "XK",
    "name": "Zvečan",
    "lat": "42.9075",
    "lng": "20.84028"
  },
  {
    "country": "XK",
    "name": "Zubin Potok",
    "lat": "42.91444",
    "lng": "20.68972"
  },
  {
    "country": "XK",
    "name": "Vushtrri",
    "lat": "42.82306",
    "lng": "20.9675"
  },
  {
    "country": "XK",
    "name": "Vitina",
    "lat": "42.32139",
    "lng": "21.35833"
  },
  {
    "country": "XK",
    "name": "Ferizaj",
    "lat": "42.37056",
    "lng": "21.15528"
  },
  {
    "country": "XK",
    "name": "Suva Reka",
    "lat": "42.35861",
    "lng": "20.825"
  },
  {
    "country": "XK",
    "name": "Štrpce",
    "lat": "42.23944",
    "lng": "21.02722"
  },
  {
    "country": "XK",
    "name": "Shtime",
    "lat": "42.43306",
    "lng": "21.03972"
  },
  {
    "country": "XK",
    "name": "Srbica",
    "lat": "42.74667",
    "lng": "20.78861"
  },
  {
    "country": "XK",
    "name": "Irzniq",
    "lat": "42.52",
    "lng": "20.34722"
  },
  {
    "country": "XK",
    "name": "Ranilug",
    "lat": "42.49222",
    "lng": "21.59889"
  },
  {
    "country": "XK",
    "name": "Prizren",
    "lat": "42.21389",
    "lng": "20.73972"
  },
  {
    "country": "XK",
    "name": "Pristina",
    "lat": "42.67272",
    "lng": "21.16688"
  },
  {
    "country": "XK",
    "name": "Prilep",
    "lat": "42.5075",
    "lng": "20.31778"
  },
  {
    "country": "XK",
    "name": "Podujeva",
    "lat": "42.91056",
    "lng": "21.19306"
  },
  {
    "country": "XK",
    "name": "Peqan",
    "lat": "42.38361",
    "lng": "20.82194"
  },
  {
    "country": "XK",
    "name": "Peć",
    "lat": "42.65913",
    "lng": "20.28828"
  },
  {
    "country": "XK",
    "name": "Partesh",
    "lat": "42.40194",
    "lng": "21.43361"
  },
  {
    "country": "XK",
    "name": "Pagaruša",
    "lat": "42.42",
    "lng": "20.74222"
  },
  {
    "country": "XK",
    "name": "Orahovac",
    "lat": "42.39944",
    "lng": "20.65472"
  },
  {
    "country": "XK",
    "name": "Obiliq",
    "lat": "42.68694",
    "lng": "21.07028"
  },
  {
    "country": "XK",
    "name": "Novo Brdo",
    "lat": "42.6159",
    "lng": "21.43405"
  },
  {
    "country": "XK",
    "name": "Nishor",
    "lat": "42.42389",
    "lng": "20.80167"
  },
  {
    "country": "XK",
    "name": "Mamuša",
    "lat": "42.33083",
    "lng": "20.72694"
  },
  {
    "country": "XK",
    "name": "Mališevo",
    "lat": "42.48222",
    "lng": "20.74583"
  },
  {
    "country": "XK",
    "name": "Llazicë",
    "lat": "42.55528",
    "lng": "20.76333"
  },
  {
    "country": "XK",
    "name": "Lumbardhi",
    "lat": "42.54667",
    "lng": "20.34667"
  },
  {
    "country": "XK",
    "name": "Lëbushë",
    "lat": "42.56306",
    "lng": "20.29083"
  },
  {
    "country": "XK",
    "name": "Lipljan",
    "lat": "42.52167",
    "lng": "21.12583"
  },
  {
    "country": "XK",
    "name": "Leshan",
    "lat": "42.32778",
    "lng": "20.78111"
  },
  {
    "country": "XK",
    "name": "Leposaviq",
    "lat": "43.10389",
    "lng": "20.80278"
  },
  {
    "country": "XK",
    "name": "Kosuriq",
    "lat": "42.57028",
    "lng": "20.46472"
  },
  {
    "country": "XK",
    "name": "Mitrovicë",
    "lat": "42.88333",
    "lng": "20.86667"
  },
  {
    "country": "XK",
    "name": "Kamenica",
    "lat": "42.57806",
    "lng": "21.58028"
  },
  {
    "country": "XK",
    "name": "Kosovo Polje",
    "lat": "42.66394",
    "lng": "21.09611"
  },
  {
    "country": "XK",
    "name": "Klokot",
    "lat": "42.37139",
    "lng": "21.37444"
  },
  {
    "country": "XK",
    "name": "Klina",
    "lat": "42.62167",
    "lng": "20.57778"
  },
  {
    "country": "XK",
    "name": "Kačanik",
    "lat": "42.23194",
    "lng": "21.25944"
  },
  {
    "country": "XK",
    "name": "Junik",
    "lat": "42.47583",
    "lng": "20.27722"
  },
  {
    "country": "XK",
    "name": "Istok",
    "lat": "42.78083",
    "lng": "20.4875"
  },
  {
    "country": "XK",
    "name": "Isniq",
    "lat": "42.5575",
    "lng": "20.30278"
  },
  {
    "country": "XK",
    "name": "Strellc i Epërm",
    "lat": "42.57843",
    "lng": "20.29398"
  },
  {
    "country": "XK",
    "name": "Lluka e Eperme",
    "lat": "42.545",
    "lng": "20.30778"
  },
  {
    "country": "XK",
    "name": "Gjilan",
    "lat": "42.46045",
    "lng": "21.46986"
  },
  {
    "country": "XK",
    "name": "Glogovac",
    "lat": "42.62833",
    "lng": "20.89389"
  },
  {
    "country": "XK",
    "name": "Gllogjan",
    "lat": "42.50722",
    "lng": "20.36278"
  },
  {
    "country": "XK",
    "name": "Dubova (Driloni)",
    "lat": "42.71194",
    "lng": "20.36972"
  },
  {
    "country": "XK",
    "name": "Dranoc",
    "lat": "42.51556",
    "lng": "20.29222"
  },
  {
    "country": "XK",
    "name": "Dragash",
    "lat": "42.0265",
    "lng": "20.65333"
  },
  {
    "country": "XK",
    "name": "Strellc i Ulët",
    "lat": "42.58063",
    "lng": "20.31619"
  },
  {
    "country": "XK",
    "name": "Gjinoc",
    "lat": "42.31833",
    "lng": "20.81861"
  },
  {
    "country": "XK",
    "name": "Hani i Elezit",
    "lat": "42.15",
    "lng": "21.29667"
  },
  {
    "country": "XK",
    "name": "Deçan",
    "lat": "42.54018",
    "lng": "20.28793"
  },
  {
    "country": "XK",
    "name": "Gjakovë",
    "lat": "42.38028",
    "lng": "20.43083"
  },
  {
    "country": "XK",
    "name": "Budakovo",
    "lat": "42.355",
    "lng": "20.925"
  },
  {
    "country": "XK",
    "name": "Papraqan",
    "lat": "42.55278",
    "lng": "20.33111"
  },
  {
    "country": "XK",
    "name": "Glanica",
    "lat": "42.54933",
    "lng": "21.06336"
  },
  {
    "country": "XK",
    "name": "Lloqan",
    "lat": "42.52444",
    "lng": "20.28083"
  },
  {
    "country": "YE",
    "name": "Daḩasuways",
    "lat": "15.72389",
    "lng": "50.72944"
  },
  {
    "country": "YE",
    "name": "Ash Shiḩr",
    "lat": "14.76026",
    "lng": "49.60537"
  },
  {
    "country": "YE",
    "name": "Al Ghaylah",
    "lat": "14.59583",
    "lng": "45.58333"
  },
  {
    "country": "YE",
    "name": "Judaydah",
    "lat": "15.07512",
    "lng": "45.29962"
  },
  {
    "country": "YE",
    "name": "Ḑawrān",
    "lat": "13.77436",
    "lng": "44.44196"
  },
  {
    "country": "YE",
    "name": "Najd al Jumā‘ī",
    "lat": "13.91581",
    "lng": "44.32414"
  },
  {
    "country": "YE",
    "name": "Z̧almah al ‘Ulyā",
    "lat": "14.1023",
    "lng": "44.09404"
  },
  {
    "country": "YE",
    "name": "Sūq ar Rubū‘",
    "lat": "14.51155",
    "lng": "44.01511"
  },
  {
    "country": "YE",
    "name": "Ash Shuqayrah",
    "lat": "13.13452",
    "lng": "43.78636"
  },
  {
    "country": "YE",
    "name": "Al Masālīyah",
    "lat": "13.53201",
    "lng": "43.99564"
  },
  {
    "country": "YE",
    "name": "Ar Rawnah",
    "lat": "13.75638",
    "lng": "43.80286"
  },
  {
    "country": "YE",
    "name": "Ar Ramādī",
    "lat": "13.95641",
    "lng": "43.78457"
  },
  {
    "country": "YE",
    "name": "Al Aḩad",
    "lat": "14.25833",
    "lng": "43.64167"
  },
  {
    "country": "YE",
    "name": "Aḑ Ḑil‘",
    "lat": "14.67199",
    "lng": "43.81827"
  },
  {
    "country": "YE",
    "name": "Sūq Şirwāḩ",
    "lat": "15.44933",
    "lng": "45.01891"
  },
  {
    "country": "YE",
    "name": "Majzar",
    "lat": "15.85",
    "lng": "44.775"
  },
  {
    "country": "YE",
    "name": "Bidbadah",
    "lat": "15.425",
    "lng": "44.7"
  },
  {
    "country": "YE",
    "name": "Matwaḩ",
    "lat": "15.0676",
    "lng": "43.64213"
  },
  {
    "country": "YE",
    "name": "Şuwayr",
    "lat": "16.1818",
    "lng": "43.60986"
  },
  {
    "country": "YE",
    "name": "Waḑarah",
    "lat": "15.71073",
    "lng": "43.48321"
  },
  {
    "country": "YE",
    "name": "Al Mirwāḩ",
    "lat": "15.47223",
    "lng": "43.42939"
  },
  {
    "country": "YE",
    "name": "Sūq Shamar",
    "lat": "15.885",
    "lng": "43.36806"
  },
  {
    "country": "YE",
    "name": "Mustabā’",
    "lat": "16.22816",
    "lng": "43.24895"
  },
  {
    "country": "YE",
    "name": "An Naz̧īr",
    "lat": "16.90916",
    "lng": "43.26226"
  },
  {
    "country": "YE",
    "name": "Aţ Ţawīlah",
    "lat": "15.49389",
    "lng": "43.74778"
  },
  {
    "country": "YE",
    "name": "Zinjibār",
    "lat": "13.12871",
    "lng": "45.38073"
  },
  {
    "country": "YE",
    "name": "Zarājah",
    "lat": "14.86692",
    "lng": "44.37868"
  },
  {
    "country": "YE",
    "name": "Az Zāhir",
    "lat": "13.96667",
    "lng": "45.48333"
  },
  {
    "country": "YE",
    "name": "Zabīd",
    "lat": "14.1951",
    "lng": "43.31518"
  },
  {
    "country": "YE",
    "name": "Yufrus",
    "lat": "13.45529",
    "lng": "43.94704"
  },
  {
    "country": "YE",
    "name": "Yarīm",
    "lat": "14.29804",
    "lng": "44.37795"
  },
  {
    "country": "YE",
    "name": "Washḩah",
    "lat": "16.30774",
    "lng": "43.41066"
  },
  {
    "country": "YE",
    "name": "Wa‘lān",
    "lat": "15.07021",
    "lng": "44.27641"
  },
  {
    "country": "YE",
    "name": "Dhī Jalāl",
    "lat": "13.62378",
    "lng": "44.70754"
  },
  {
    "country": "YE",
    "name": "‘Usaylān",
    "lat": "15.03201",
    "lng": "45.82832"
  },
  {
    "country": "YE",
    "name": "‘Ubāl",
    "lat": "14.98808",
    "lng": "43.54444"
  },
  {
    "country": "YE",
    "name": "Thamūd",
    "lat": "17.29245",
    "lng": "49.91947"
  },
  {
    "country": "YE",
    "name": "Tarīm",
    "lat": "16.05694",
    "lng": "48.99889"
  },
  {
    "country": "YE",
    "name": "Ta‘izz",
    "lat": "13.57952",
    "lng": "44.02091"
  },
  {
    "country": "YE",
    "name": "As Suwaydā",
    "lat": "13.78694",
    "lng": "45.2304"
  },
  {
    "country": "YE",
    "name": "Al ‘Inān",
    "lat": "16.72189",
    "lng": "44.31252"
  },
  {
    "country": "YE",
    "name": "Abs",
    "lat": "16.00295",
    "lng": "43.19725"
  },
  {
    "country": "YE",
    "name": "Şīf",
    "lat": "15.31389",
    "lng": "48.33"
  },
  {
    "country": "YE",
    "name": "Shiḩan as Suflá",
    "lat": "17.76999",
    "lng": "52.48925"
  },
  {
    "country": "YE",
    "name": "Shibām",
    "lat": "15.50943",
    "lng": "43.90445"
  },
  {
    "country": "YE",
    "name": "Ash Sharyah",
    "lat": "14.35659",
    "lng": "45.02244"
  },
  {
    "country": "YE",
    "name": "Sharas",
    "lat": "15.71233",
    "lng": "43.64925"
  },
  {
    "country": "YE",
    "name": "Shahārat al Ghīs",
    "lat": "16.18411",
    "lng": "43.70228"
  },
  {
    "country": "YE",
    "name": "Sayyān",
    "lat": "15.17177",
    "lng": "44.32442"
  },
  {
    "country": "YE",
    "name": "Sayḩūt",
    "lat": "15.21056",
    "lng": "51.24556"
  },
  {
    "country": "YE",
    "name": "Şanā’",
    "lat": "15.4",
    "lng": "47.76667"
  },
  {
    "country": "YE",
    "name": "Sanaa",
    "lat": "15.35472",
    "lng": "44.20667"
  },
  {
    "country": "YE",
    "name": "Saḩar",
    "lat": "15.31586",
    "lng": "44.30858"
  },
  {
    "country": "YE",
    "name": "Sāh",
    "lat": "15.57722",
    "lng": "48.85056"
  },
  {
    "country": "YE",
    "name": "Sa'dah",
    "lat": "16.94021",
    "lng": "43.76393"
  },
  {
    "country": "YE",
    "name": "Riḩāb",
    "lat": "14.22762",
    "lng": "44.18814"
  },
  {
    "country": "YE",
    "name": "Radā‘",
    "lat": "14.4151",
    "lng": "44.83709"
  },
  {
    "country": "YE",
    "name": "Ar Raydah",
    "lat": "15.035",
    "lng": "50.47917"
  },
  {
    "country": "YE",
    "name": "Raydah",
    "lat": "15.81421",
    "lng": "44.04085"
  },
  {
    "country": "YE",
    "name": "Ruḑūm",
    "lat": "14.0851",
    "lng": "47.74314"
  },
  {
    "country": "YE",
    "name": "Qalansīyah",
    "lat": "12.68958",
    "lng": "53.48709"
  },
  {
    "country": "YE",
    "name": "Qishn",
    "lat": "15.42409",
    "lng": "51.67836"
  },
  {
    "country": "YE",
    "name": "Qa‘ţabah",
    "lat": "13.85493",
    "lng": "44.7058"
  },
  {
    "country": "YE",
    "name": "Nişāb",
    "lat": "14.50743",
    "lng": "46.49349"
  },
  {
    "country": "YE",
    "name": "Al Musaymīr",
    "lat": "13.44389",
    "lng": "44.61528"
  },
  {
    "country": "YE",
    "name": "Mukayrās",
    "lat": "13.94427",
    "lng": "45.67074"
  },
  {
    "country": "YE",
    "name": "Mūdīyah",
    "lat": "13.9284",
    "lng": "46.08254"
  },
  {
    "country": "YE",
    "name": "Markaz Mudhaykirah",
    "lat": "13.88953",
    "lng": "43.9688"
  },
  {
    "country": "YE",
    "name": "Minwakh",
    "lat": "16.80035",
    "lng": "48.10854"
  },
  {
    "country": "YE",
    "name": "Mayfa‘ah",
    "lat": "14.27533",
    "lng": "47.58414"
  },
  {
    "country": "YE",
    "name": "Maidi",
    "lat": "16.32101",
    "lng": "42.81299"
  },
  {
    "country": "YE",
    "name": "Mawza‘",
    "lat": "13.26831",
    "lng": "43.50993"
  },
  {
    "country": "YE",
    "name": "Māwiyah",
    "lat": "13.58295",
    "lng": "44.34768"
  },
  {
    "country": "YE",
    "name": "Al Jawl",
    "lat": "14.45625",
    "lng": "48.28066"
  },
  {
    "country": "YE",
    "name": "Ma'rib",
    "lat": "15.46253",
    "lng": "45.32581"
  },
  {
    "country": "YE",
    "name": "Manākhah",
    "lat": "15.07422",
    "lng": "43.74156"
  },
  {
    "country": "YE",
    "name": "Milāḩ",
    "lat": "14.41617",
    "lng": "44.78622"
  },
  {
    "country": "YE",
    "name": "Al Malāḩīţ",
    "lat": "16.76848",
    "lng": "43.27582"
  },
  {
    "country": "YE",
    "name": "Al Māfūd",
    "lat": "15.34264",
    "lng": "47.25217"
  },
  {
    "country": "YE",
    "name": "Mafḩaq",
    "lat": "15.10162",
    "lng": "43.90304"
  },
  {
    "country": "YE",
    "name": "Al Madīd",
    "lat": "15.64453",
    "lng": "44.47337"
  },
  {
    "country": "YE",
    "name": "Ma‘bar",
    "lat": "14.79395",
    "lng": "44.29354"
  },
  {
    "country": "YE",
    "name": "Al Ma‘allā’",
    "lat": "12.78987",
    "lng": "45.00244"
  },
  {
    "country": "YE",
    "name": "Lawdar",
    "lat": "13.88282",
    "lng": "45.86859"
  },
  {
    "country": "YE",
    "name": "Laḩij",
    "lat": "13.05667",
    "lng": "44.88194"
  },
  {
    "country": "YE",
    "name": "Kuḩlān ‘Affār",
    "lat": "15.73309",
    "lng": "43.71902"
  },
  {
    "country": "YE",
    "name": "Ku‘aydinah",
    "lat": "15.82104",
    "lng": "43.3372"
  },
  {
    "country": "YE",
    "name": "Crater",
    "lat": "12.77522",
    "lng": "45.03862"
  },
  {
    "country": "YE",
    "name": "Kitāf",
    "lat": "17.03165",
    "lng": "44.10905"
  },
  {
    "country": "YE",
    "name": "Kilmia",
    "lat": "12.18576",
    "lng": "52.23332"
  },
  {
    "country": "YE",
    "name": "Khawr Maksar",
    "lat": "12.81227",
    "lng": "45.03337"
  },
  {
    "country": "YE",
    "name": "Khawrah",
    "lat": "14.43201",
    "lng": "46.15435"
  },
  {
    "country": "YE",
    "name": "Khamir",
    "lat": "15.98792",
    "lng": "43.95362"
  },
  {
    "country": "YE",
    "name": "Juban",
    "lat": "14.01164",
    "lng": "44.8746"
  },
  {
    "country": "YE",
    "name": "Jiḩānah",
    "lat": "15.22628",
    "lng": "44.48244"
  },
  {
    "country": "YE",
    "name": "Jiblah",
    "lat": "13.92162",
    "lng": "44.14668"
  },
  {
    "country": "YE",
    "name": "Jawf al Maqbābah",
    "lat": "13.83783",
    "lng": "45.83488"
  },
  {
    "country": "YE",
    "name": "Ja‘ār",
    "lat": "13.223",
    "lng": "45.30559"
  },
  {
    "country": "YE",
    "name": "Ibb",
    "lat": "13.96667",
    "lng": "44.18333"
  },
  {
    "country": "YE",
    "name": "Ḩūth",
    "lat": "16.23114",
    "lng": "43.96854"
  },
  {
    "country": "YE",
    "name": "As Salāsil",
    "lat": "16.47959",
    "lng": "48.83153"
  },
  {
    "country": "YE",
    "name": "Al ‘Abr",
    "lat": "16.1377",
    "lng": "47.23545"
  },
  {
    "country": "YE",
    "name": "Ḩays",
    "lat": "13.9317",
    "lng": "43.4831"
  },
  {
    "country": "YE",
    "name": "Ḩayfān",
    "lat": "13.31778",
    "lng": "44.28011"
  },
  {
    "country": "YE",
    "name": "Ḩawf",
    "lat": "16.63383",
    "lng": "53.03368"
  },
  {
    "country": "YE",
    "name": "Ḩaşwayn",
    "lat": "15.59049",
    "lng": "52.10077"
  },
  {
    "country": "YE",
    "name": "Ḩarīb",
    "lat": "14.93156",
    "lng": "45.50356"
  },
  {
    "country": "YE",
    "name": "Ḩaraḑ",
    "lat": "16.40965",
    "lng": "43.05883"
  },
  {
    "country": "YE",
    "name": "Ḩammām ‘Alī",
    "lat": "14.66371",
    "lng": "44.14763"
  },
  {
    "country": "YE",
    "name": "Ḩajjah",
    "lat": "15.69425",
    "lng": "43.60582"
  },
  {
    "country": "YE",
    "name": "Madīnat Lab‘ūs",
    "lat": "13.86667",
    "lng": "45.25"
  },
  {
    "country": "YE",
    "name": "Hadibu",
    "lat": "12.64881",
    "lng": "54.01895"
  },
  {
    "country": "YE",
    "name": "Ḩabīl al Jabr",
    "lat": "13.60422",
    "lng": "44.98578"
  },
  {
    "country": "YE",
    "name": "Al Ḩabīlayn",
    "lat": "13.52002",
    "lng": "44.85076"
  },
  {
    "country": "YE",
    "name": "Ḩabbān",
    "lat": "14.35411",
    "lng": "47.07649"
  },
  {
    "country": "YE",
    "name": "Ḩabābah",
    "lat": "15.54418",
    "lng": "43.87563"
  },
  {
    "country": "YE",
    "name": "Ghayl Bā Wazīr",
    "lat": "14.77611",
    "lng": "49.36611"
  },
  {
    "country": "YE",
    "name": "Dhubāb",
    "lat": "12.94305",
    "lng": "43.41025"
  },
  {
    "country": "YE",
    "name": "Dhī Nā‘im",
    "lat": "14.10574",
    "lng": "45.44807"
  },
  {
    "country": "YE",
    "name": "Dhaybīn",
    "lat": "15.97712",
    "lng": "44.12917"
  },
  {
    "country": "YE",
    "name": "Dhī as Sufāl",
    "lat": "13.83446",
    "lng": "44.11469"
  },
  {
    "country": "YE",
    "name": "Dhamār",
    "lat": "14.54274",
    "lng": "44.40514"
  },
  {
    "country": "YE",
    "name": "Ḑawrān ad Daydah",
    "lat": "14.73927",
    "lng": "44.20664"
  },
  {
    "country": "YE",
    "name": "Dār an Naşr",
    "lat": "13.55821",
    "lng": "44.01635"
  },
  {
    "country": "YE",
    "name": "Burūm",
    "lat": "14.36361",
    "lng": "48.97972"
  },
  {
    "country": "YE",
    "name": "Bayt ‘Adhāqah",
    "lat": "15.61576",
    "lng": "43.70228"
  },
  {
    "country": "YE",
    "name": "As Sūq al Jadīd",
    "lat": "15.82496",
    "lng": "44.06204"
  },
  {
    "country": "YE",
    "name": "Bayt al Faqīh",
    "lat": "14.51635",
    "lng": "43.32446"
  },
  {
    "country": "YE",
    "name": "Bayḩān",
    "lat": "14.80067",
    "lng": "45.71889"
  },
  {
    "country": "YE",
    "name": "Banī Ḩujjāj",
    "lat": "15.41683",
    "lng": "43.3193"
  },
  {
    "country": "YE",
    "name": "Banī Bakr",
    "lat": "13.93333",
    "lng": "45.26667"
  },
  {
    "country": "YE",
    "name": "Bājil",
    "lat": "15.05898",
    "lng": "43.28731"
  },
  {
    "country": "YE",
    "name": "Az Zuhrah",
    "lat": "15.72377",
    "lng": "42.99582"
  },
  {
    "country": "YE",
    "name": "Az Zaydīyah",
    "lat": "15.33049",
    "lng": "43.00633"
  },
  {
    "country": "YE",
    "name": "Az Zāhir",
    "lat": "16.31733",
    "lng": "44.49505"
  },
  {
    "country": "YE",
    "name": "Al Ḩajab",
    "lat": "14.85192",
    "lng": "45.52904"
  },
  {
    "country": "YE",
    "name": "Al ‘Awābil",
    "lat": "13.83755",
    "lng": "44.86431"
  },
  {
    "country": "YE",
    "name": "At Turbah",
    "lat": "13.2127",
    "lng": "44.12415"
  },
  {
    "country": "YE",
    "name": "At Tuḩaytā’",
    "lat": "14.18356",
    "lng": "43.22637"
  },
  {
    "country": "YE",
    "name": "At Tawāhī",
    "lat": "12.78471",
    "lng": "44.9802"
  },
  {
    "country": "YE",
    "name": "Ataq",
    "lat": "14.53767",
    "lng": "46.83187"
  },
  {
    "country": "YE",
    "name": "As Sūdah",
    "lat": "15.95861",
    "lng": "43.78083"
  },
  {
    "country": "YE",
    "name": "As Sayyānī",
    "lat": "13.84266",
    "lng": "44.17395"
  },
  {
    "country": "YE",
    "name": "Aş Şawma‘ah",
    "lat": "14.08505",
    "lng": "45.80101"
  },
  {
    "country": "YE",
    "name": "Al Bilād",
    "lat": "16.13806",
    "lng": "49.29167"
  },
  {
    "country": "YE",
    "name": "As Sawādīyah",
    "lat": "14.30113",
    "lng": "45.22148"
  },
  {
    "country": "YE",
    "name": "Aş Şalīf",
    "lat": "15.30755",
    "lng": "42.67107"
  },
  {
    "country": "YE",
    "name": "Said",
    "lat": "14.33011",
    "lng": "46.87292"
  },
  {
    "country": "YE",
    "name": "Aş Şafaqayn",
    "lat": "15.37922",
    "lng": "43.42046"
  },
  {
    "country": "YE",
    "name": "As Saddah",
    "lat": "14.1221",
    "lng": "44.42139"
  },
  {
    "country": "YE",
    "name": "Ash Shaykh ‘Uthmān",
    "lat": "12.87678",
    "lng": "44.99309"
  },
  {
    "country": "YE",
    "name": "Ash Shaţţ",
    "lat": "12.89357",
    "lng": "44.03571"
  },
  {
    "country": "YE",
    "name": "Ash Shāhil",
    "lat": "15.86656",
    "lng": "43.40495"
  },
  {
    "country": "YE",
    "name": "Ash Shaghādirah",
    "lat": "15.62",
    "lng": "43.52056"
  },
  {
    "country": "YE",
    "name": "Asdās",
    "lat": "15.76601",
    "lng": "45.08151"
  },
  {
    "country": "YE",
    "name": "Marbāţ",
    "lat": "14.20567",
    "lng": "46.38811"
  },
  {
    "country": "YE",
    "name": "Ar Rawḑah",
    "lat": "15.43251",
    "lng": "44.22399"
  },
  {
    "country": "YE",
    "name": "Ar Rawḑah",
    "lat": "14.46725",
    "lng": "47.27638"
  },
  {
    "country": "YE",
    "name": "An Nādirah",
    "lat": "14.09628",
    "lng": "44.47559"
  },
  {
    "country": "YE",
    "name": "‘Amrān",
    "lat": "15.6594",
    "lng": "43.94385"
  },
  {
    "country": "YE",
    "name": "‘Amd",
    "lat": "15.3",
    "lng": "47.98333"
  },
  {
    "country": "YE",
    "name": "Al Wuday‘",
    "lat": "13.7721",
    "lng": "46.01785"
  },
  {
    "country": "YE",
    "name": "Al ‘Udayn",
    "lat": "13.96918",
    "lng": "43.99673"
  },
  {
    "country": "YE",
    "name": "Al Qurḩ",
    "lat": "16.73333",
    "lng": "51.48333"
  },
  {
    "country": "YE",
    "name": "Al Qanāwiş",
    "lat": "15.49285",
    "lng": "43.1343"
  },
  {
    "country": "YE",
    "name": "Al Qaflah",
    "lat": "16.31897",
    "lng": "43.76792"
  },
  {
    "country": "YE",
    "name": "Qaryat al Qābil",
    "lat": "15.45033",
    "lng": "44.12768"
  },
  {
    "country": "YE",
    "name": "Āl Ma‘ūdah",
    "lat": "14.21055",
    "lng": "45.38732"
  },
  {
    "country": "YE",
    "name": "Al Munīrah",
    "lat": "15.32251",
    "lng": "42.93005"
  },
  {
    "country": "YE",
    "name": "Mukalla",
    "lat": "14.54248",
    "lng": "49.12424"
  },
  {
    "country": "YE",
    "name": "Al Misrākh",
    "lat": "13.46059",
    "lng": "44.02043"
  },
  {
    "country": "YE",
    "name": "Al Milāḩ",
    "lat": "13.42611",
    "lng": "44.82556"
  },
  {
    "country": "YE",
    "name": "Al Mighlāf",
    "lat": "15.28772",
    "lng": "43.1891"
  },
  {
    "country": "YE",
    "name": "Markaz al Marīr",
    "lat": "13.98178",
    "lng": "43.59547"
  },
  {
    "country": "YE",
    "name": "Al Marāwi‘ah",
    "lat": "14.83069",
    "lng": "43.15391"
  },
  {
    "country": "YE",
    "name": "Al Manşūrīyah",
    "lat": "14.6856",
    "lng": "43.29922"
  },
  {
    "country": "YE",
    "name": "Al Manşūrah",
    "lat": "12.86019",
    "lng": "44.98166"
  },
  {
    "country": "YE",
    "name": "Al Makhādir",
    "lat": "14.12224",
    "lng": "44.19797"
  },
  {
    "country": "YE",
    "name": "Al Maḩwīt",
    "lat": "15.47007",
    "lng": "43.54481"
  },
  {
    "country": "YE",
    "name": "Al Maḩfid",
    "lat": "14.05847",
    "lng": "46.91329"
  },
  {
    "country": "YE",
    "name": "Al Maḩābishah",
    "lat": "15.94758",
    "lng": "43.43587"
  },
  {
    "country": "YE",
    "name": "Al Madu",
    "lat": "13.85668",
    "lng": "44.8184"
  },
  {
    "country": "YE",
    "name": "Al Luḩayyah",
    "lat": "15.70309",
    "lng": "42.69093"
  },
  {
    "country": "YE",
    "name": "Kirsh",
    "lat": "13.36473",
    "lng": "44.49046"
  },
  {
    "country": "YE",
    "name": "Al Khawkhah",
    "lat": "13.8071",
    "lng": "43.2493"
  },
  {
    "country": "YE",
    "name": "Al Jurbah",
    "lat": "13.7915",
    "lng": "45.15894"
  },
  {
    "country": "YE",
    "name": "Al Jarrāḩī",
    "lat": "14.13254",
    "lng": "43.38845"
  },
  {
    "country": "YE",
    "name": "Al Ḩusayn",
    "lat": "13.79199",
    "lng": "44.76886"
  },
  {
    "country": "YE",
    "name": "Ḩurayḑah",
    "lat": "15.59861",
    "lng": "48.18278"
  },
  {
    "country": "YE",
    "name": "Al Ḩudaydah",
    "lat": "14.79781",
    "lng": "42.95452"
  },
  {
    "country": "YE",
    "name": "Al Ḩazm",
    "lat": "16.16406",
    "lng": "44.77692"
  },
  {
    "country": "YE",
    "name": "Al Qaţan",
    "lat": "15.84056",
    "lng": "48.45556"
  },
  {
    "country": "YE",
    "name": "Al Ḩarf",
    "lat": "16.36395",
    "lng": "44.09421"
  },
  {
    "country": "YE",
    "name": "Ḩajar al Mashā’ikh",
    "lat": "16.13951",
    "lng": "47.8323"
  },
  {
    "country": "YE",
    "name": "Al Ghayz̧ah",
    "lat": "16.20787",
    "lng": "52.17605"
  },
  {
    "country": "YE",
    "name": "Al Burayqah",
    "lat": "12.73944",
    "lng": "44.88417"
  },
  {
    "country": "YE",
    "name": "Al Bayda",
    "lat": "13.98523",
    "lng": "45.57272"
  },
  {
    "country": "YE",
    "name": "Al Bāţinah",
    "lat": "15.48333",
    "lng": "48.43333"
  },
  {
    "country": "YE",
    "name": "Al ‘Āqir",
    "lat": "14.56816",
    "lng": "45.91156"
  },
  {
    "country": "YE",
    "name": "Aḩwar",
    "lat": "13.52019",
    "lng": "46.71367"
  },
  {
    "country": "YE",
    "name": "Ad Durayhimī",
    "lat": "14.63702",
    "lng": "43.05505"
  },
  {
    "country": "YE",
    "name": "Ad Dīs ash Sharqīyah",
    "lat": "14.9084",
    "lng": "49.94847"
  },
  {
    "country": "YE",
    "name": "Ad Dimnah",
    "lat": "13.45398",
    "lng": "44.18168"
  },
  {
    "country": "YE",
    "name": "Ad Dann",
    "lat": "14.3518",
    "lng": "43.85275"
  },
  {
    "country": "YE",
    "name": "Az̧ Z̧alī‘ah",
    "lat": "15.01667",
    "lng": "48.01667"
  },
  {
    "country": "YE",
    "name": "Dhalie",
    "lat": "13.69572",
    "lng": "44.73137"
  },
  {
    "country": "YE",
    "name": "Dhahi",
    "lat": "15.21518",
    "lng": "43.0702"
  },
  {
    "country": "YE",
    "name": "Markaz Bilād aţ Ţa‘ām",
    "lat": "14.83361",
    "lng": "43.53639"
  },
  {
    "country": "YE",
    "name": "Al Jum‘ah",
    "lat": "14.73779",
    "lng": "43.96489"
  },
  {
    "country": "YE",
    "name": "Al Ḩadīyah",
    "lat": "14.52638",
    "lng": "43.57045"
  },
  {
    "country": "YE",
    "name": "Kusmah",
    "lat": "14.58175",
    "lng": "43.63676"
  },
  {
    "country": "YE",
    "name": "Al Jabīn",
    "lat": "14.70389",
    "lng": "43.59917"
  },
  {
    "country": "YE",
    "name": "Riqāb",
    "lat": "14.88597",
    "lng": "43.46491"
  },
  {
    "country": "YE",
    "name": "As Sukhnah",
    "lat": "14.79408",
    "lng": "43.4362"
  },
  {
    "country": "YE",
    "name": "Ar Rujum",
    "lat": "15.45776",
    "lng": "43.63226"
  },
  {
    "country": "YE",
    "name": "Al Khamīs",
    "lat": "15.18533",
    "lng": "43.51122"
  },
  {
    "country": "YE",
    "name": "Al ‘Urr",
    "lat": "15.24648",
    "lng": "43.88836"
  },
  {
    "country": "YE",
    "name": "Al Maghrabah",
    "lat": "15.87722",
    "lng": "43.66667"
  },
  {
    "country": "YE",
    "name": "Aş Şarārah",
    "lat": "15.79449",
    "lng": "43.86997"
  },
  {
    "country": "YE",
    "name": "An Nāşirah",
    "lat": "15.77277",
    "lng": "43.80902"
  },
  {
    "country": "YE",
    "name": "Mabyan",
    "lat": "15.73773",
    "lng": "43.55701"
  },
  {
    "country": "YE",
    "name": "Matnah",
    "lat": "15.25333",
    "lng": "44.02472"
  },
  {
    "country": "YE",
    "name": "Al Ḩayfah",
    "lat": "15.73494",
    "lng": "44.23788"
  },
  {
    "country": "YE",
    "name": "Bayt Marrān",
    "lat": "15.69312",
    "lng": "44.2053"
  },
  {
    "country": "YE",
    "name": "Al Nashmah",
    "lat": "13.39028",
    "lng": "43.96833"
  },
  {
    "country": "YE",
    "name": "Al Ḩashwah",
    "lat": "16.90641",
    "lng": "44.27622"
  },
  {
    "country": "YE",
    "name": "Sāqayn",
    "lat": "16.877",
    "lng": "43.52499"
  },
  {
    "country": "YE",
    "name": "Al Maḩjal",
    "lat": "16.71169",
    "lng": "44.84769"
  },
  {
    "country": "YE",
    "name": "Rajūzah",
    "lat": "16.70056",
    "lng": "44.41454"
  },
  {
    "country": "YE",
    "name": "Al Khirāb",
    "lat": "16.5544",
    "lng": "44.29048"
  },
  {
    "country": "YE",
    "name": "Al Ḩumaydāt",
    "lat": "16.4844",
    "lng": "44.42934"
  },
  {
    "country": "YE",
    "name": "Al Madān",
    "lat": "16.22413",
    "lng": "43.64383"
  },
  {
    "country": "YE",
    "name": "Al ‘Ashshah",
    "lat": "16.25652",
    "lng": "43.85476"
  },
  {
    "country": "YE",
    "name": "Ḩişn Banī Sa‘d",
    "lat": "16.27293",
    "lng": "44.47728"
  },
  {
    "country": "YE",
    "name": "Al Matūn",
    "lat": "16.23063",
    "lng": "44.58476"
  },
  {
    "country": "YE",
    "name": "Al Maşlūb",
    "lat": "16.18271",
    "lng": "44.62613"
  },
  {
    "country": "YE",
    "name": "Al Ghayl",
    "lat": "16.10774",
    "lng": "44.68005"
  },
  {
    "country": "YE",
    "name": "Al Jamīmah",
    "lat": "16.01787",
    "lng": "43.59647"
  },
  {
    "country": "YE",
    "name": "Ḩabūr",
    "lat": "16.05097",
    "lng": "43.70699"
  },
  {
    "country": "YE",
    "name": "Ar Rawḑ",
    "lat": "16.06145",
    "lng": "44.81012"
  },
  {
    "country": "YE",
    "name": "Ar Rubū‘",
    "lat": "13.78024",
    "lng": "43.86901"
  },
  {
    "country": "YE",
    "name": "Maqbanah",
    "lat": "13.66394",
    "lng": "43.6873"
  },
  {
    "country": "YE",
    "name": "Ḑubāh",
    "lat": "14.49052",
    "lng": "44.13108"
  },
  {
    "country": "YE",
    "name": "Ar Riḑā’ī",
    "lat": "14.01712",
    "lng": "44.39409"
  },
  {
    "country": "YE",
    "name": "Al Mayfa’ah",
    "lat": "14.46392",
    "lng": "44.54866"
  },
  {
    "country": "YE",
    "name": "Ar Raḑmah",
    "lat": "14.21973",
    "lng": "44.58657"
  },
  {
    "country": "YE",
    "name": "Ḩammām Damt",
    "lat": "14.09031",
    "lng": "44.67006"
  },
  {
    "country": "YE",
    "name": "Zakhim",
    "lat": "14.29496",
    "lng": "44.68504"
  },
  {
    "country": "YE",
    "name": "Maswarah",
    "lat": "14.34399",
    "lng": "45.72623"
  },
  {
    "country": "YE",
    "name": "Ţawr al Bāḩah",
    "lat": "13.18179",
    "lng": "44.29966"
  },
  {
    "country": "YE",
    "name": "Kushar",
    "lat": "16.15523",
    "lng": "43.42102"
  },
  {
    "country": "YE",
    "name": "Aslam",
    "lat": "16.05961",
    "lng": "43.32745"
  },
  {
    "country": "YE",
    "name": "Ḩaydān",
    "lat": "16.77899",
    "lng": "43.43372"
  },
  {
    "country": "YE",
    "name": "Al Miftāḩ",
    "lat": "15.97431",
    "lng": "43.46381"
  },
  {
    "country": "YE",
    "name": "Aden",
    "lat": "12.77944",
    "lng": "45.03667"
  },
  {
    "country": "YE",
    "name": "Madghil",
    "lat": "15.59858",
    "lng": "45.04013"
  },
  {
    "country": "YE",
    "name": "Al Ḩarjah",
    "lat": "15.48869",
    "lng": "44.66573"
  },
  {
    "country": "YE",
    "name": "Banī al ‘Awwām",
    "lat": "15.58119",
    "lng": "43.58727"
  },
  {
    "country": "YE",
    "name": "Banī an Nahārī",
    "lat": "15.63981",
    "lng": "43.55633"
  },
  {
    "country": "YE",
    "name": "Al Hijrah",
    "lat": "17.29788",
    "lng": "43.38718"
  },
  {
    "country": "YE",
    "name": "Sūq al Khamīs",
    "lat": "17.18126",
    "lng": "43.28811"
  },
  {
    "country": "YE",
    "name": "Al Mashāf",
    "lat": "16.85836",
    "lng": "43.19781"
  },
  {
    "country": "YE",
    "name": "Al Kharāb",
    "lat": "16.99129",
    "lng": "43.33888"
  },
  {
    "country": "YE",
    "name": "Al ‘Ayn",
    "lat": "13.33005",
    "lng": "44.09208"
  },
  {
    "country": "YE",
    "name": "Qaryat ad Da‘īs",
    "lat": "13.9877",
    "lng": "44.2749"
  },
  {
    "country": "YE",
    "name": "Ḩazm al ‘Udayn",
    "lat": "14.02743",
    "lng": "44.00526"
  },
  {
    "country": "YE",
    "name": "An Najd",
    "lat": "14.42152",
    "lng": "45.29596"
  },
  {
    "country": "YE",
    "name": "Raḩbah (Al Kawlah)",
    "lat": "14.8953",
    "lng": "44.98893"
  },
  {
    "country": "YE",
    "name": "Al ‘Amūd",
    "lat": "14.72103",
    "lng": "45.20676"
  },
  {
    "country": "YE",
    "name": "Al ‘Aqabah",
    "lat": "14.27179",
    "lng": "44.78699"
  },
  {
    "country": "YE",
    "name": "Al Qurayshīyah",
    "lat": "14.5122",
    "lng": "44.85358"
  },
  {
    "country": "YE",
    "name": "Ḩawrah",
    "lat": "13.35751",
    "lng": "44.1458"
  },
  {
    "country": "YE",
    "name": "Ash Shawātī",
    "lat": "16.78314",
    "lng": "43.81265"
  },
  {
    "country": "YE",
    "name": "Al Ḩamdī",
    "lat": "15.94727",
    "lng": "48.77965"
  },
  {
    "country": "YE",
    "name": "At Taḩāluf",
    "lat": "15.93786",
    "lng": "48.78641"
  },
  {
    "country": "YE",
    "name": "Suḩayl Shibām",
    "lat": "15.91448",
    "lng": "48.63864"
  },
  {
    "country": "YE",
    "name": "Al Khāniq",
    "lat": "15.50253",
    "lng": "44.18158"
  },
  {
    "country": "YE",
    "name": "Bi’r Ḩāt",
    "lat": "17.32197",
    "lng": "52.09566"
  },
  {
    "country": "YE",
    "name": "Ḩadādah",
    "lat": "13.17535",
    "lng": "44.27461"
  },
  {
    "country": "YE",
    "name": "Rumāh",
    "lat": "17.45532",
    "lng": "50.57789"
  },
  {
    "country": "YE",
    "name": "Al Shirūj",
    "lat": "14.68526",
    "lng": "47.76926"
  },
  {
    "country": "YE",
    "name": "Jawl al Majma‘",
    "lat": "14.93278",
    "lng": "47.02763"
  },
  {
    "country": "YE",
    "name": "Sūq Sibāḩ",
    "lat": "13.81436",
    "lng": "45.39229"
  },
  {
    "country": "YE",
    "name": "Al Ḩazm",
    "lat": "14.68919",
    "lng": "45.60962"
  },
  {
    "country": "YE",
    "name": "Al Aqţa‘",
    "lat": "14.66217",
    "lng": "45.35123"
  },
  {
    "country": "YE",
    "name": "Bāqim as Sūq",
    "lat": "17.39713",
    "lng": "43.47743"
  },
  {
    "country": "YE",
    "name": "Maţarah",
    "lat": "15.52591",
    "lng": "47.63339"
  },
  {
    "country": "YE",
    "name": "Khimār",
    "lat": "14.3198",
    "lng": "46.73922"
  },
  {
    "country": "YE",
    "name": "Ḩabīl ar Raydah",
    "lat": "13.6444",
    "lng": "44.85097"
  },
  {
    "country": "YE",
    "name": "Al ‘Ulayb",
    "lat": "15.14747",
    "lng": "49.07325"
  },
  {
    "country": "YE",
    "name": "Aţ Ţalḩ",
    "lat": "15.156",
    "lng": "47.39903"
  },
  {
    "country": "YE",
    "name": "Sirār",
    "lat": "13.63778",
    "lng": "45.31371"
  },
  {
    "country": "YE",
    "name": "Khayrān",
    "lat": "16.02191",
    "lng": "43.37859"
  },
  {
    "country": "YE",
    "name": "Al Ḩuşūn",
    "lat": "15.4739",
    "lng": "45.36691"
  },
  {
    "country": "YE",
    "name": "Jayshān",
    "lat": "14.25204",
    "lng": "46.17905"
  },
  {
    "country": "YE",
    "name": "Aş Şalw",
    "lat": "13.32887",
    "lng": "44.21708"
  },
  {
    "country": "YE",
    "name": "Raşad",
    "lat": "13.71215",
    "lng": "45.30318"
  },
  {
    "country": "YE",
    "name": "Saḩḩab",
    "lat": "15.60223",
    "lng": "44.0242"
  },
  {
    "country": "YE",
    "name": "Majz",
    "lat": "17.06939",
    "lng": "43.57507"
  },
  {
    "country": "YE",
    "name": "AL-khashā upper",
    "lat": "14.34044",
    "lng": "46.71365"
  },
  {
    "country": "YE",
    "name": "Al-Medy Village, قرية المدي",
    "lat": "14.40152",
    "lng": "43.79178"
  },
  {
    "country": "YE",
    "name": "Village of ALAMRAH",
    "lat": "13.74318",
    "lng": "43.72992"
  },
  {
    "country": "YE",
    "name": "Jadder Cemetery",
    "lat": "15.467",
    "lng": "44.17787"
  },
  {
    "country": "YT",
    "name": "Pamandzi",
    "lat": "-12.79674",
    "lng": "45.27938"
  },
  {
    "country": "YT",
    "name": "Mamoudzou",
    "lat": "-12.78234",
    "lng": "45.22878"
  },
  {
    "country": "YT",
    "name": "Dzaoudzi",
    "lat": "-12.78339",
    "lng": "45.25693"
  },
  {
    "country": "YT",
    "name": "Dembeni",
    "lat": "-12.8436",
    "lng": "45.18436"
  },
  {
    "country": "YT",
    "name": "Acoua",
    "lat": "-12.72391",
    "lng": "45.05819"
  },
  {
    "country": "YT",
    "name": "Bandraboua",
    "lat": "-12.7044",
    "lng": "45.12231"
  },
  {
    "country": "YT",
    "name": "Mtsamboro",
    "lat": "-12.69982",
    "lng": "45.06894"
  },
  {
    "country": "YT",
    "name": "M'Tsangamouji",
    "lat": "-12.75944",
    "lng": "45.08361"
  },
  {
    "country": "YT",
    "name": "Tsingoni",
    "lat": "-12.78722",
    "lng": "45.10278"
  },
  {
    "country": "YT",
    "name": "Koungou",
    "lat": "-12.73361",
    "lng": "45.20417"
  },
  {
    "country": "YT",
    "name": "Ouangani",
    "lat": "-12.84639",
    "lng": "45.13611"
  },
  {
    "country": "YT",
    "name": "Chiconi",
    "lat": "-12.83333",
    "lng": "45.11056"
  },
  {
    "country": "YT",
    "name": "Sada",
    "lat": "-12.85055",
    "lng": "45.10205"
  },
  {
    "country": "YT",
    "name": "Bandrélé",
    "lat": "-12.91276",
    "lng": "45.19256"
  },
  {
    "country": "YT",
    "name": "Chirongui",
    "lat": "-12.93194",
    "lng": "45.14833"
  },
  {
    "country": "YT",
    "name": "Bouéni",
    "lat": "-12.9025",
    "lng": "45.07611"
  },
  {
    "country": "YT",
    "name": "Kani Kéli",
    "lat": "-12.95361",
    "lng": "45.10333"
  },
  {
    "country": "ZA",
    "name": "Roodepoort",
    "lat": "-26.1625",
    "lng": "27.8725"
  },
  {
    "country": "ZA",
    "name": "Zoar",
    "lat": "-33.4956",
    "lng": "21.44373"
  },
  {
    "country": "ZA",
    "name": "Zeerust",
    "lat": "-25.53695",
    "lng": "26.07512"
  },
  {
    "country": "ZA",
    "name": "Zastron",
    "lat": "-30.30225",
    "lng": "27.08395"
  },
  {
    "country": "ZA",
    "name": "Wolmaransstad",
    "lat": "-27.1974",
    "lng": "25.98311"
  },
  {
    "country": "ZA",
    "name": "White River",
    "lat": "-25.33177",
    "lng": "31.01166"
  },
  {
    "country": "ZA",
    "name": "Witbank",
    "lat": "-25.87133",
    "lng": "29.23323"
  },
  {
    "country": "ZA",
    "name": "Winburg",
    "lat": "-28.51805",
    "lng": "27.00933"
  },
  {
    "country": "ZA",
    "name": "Willowmore",
    "lat": "-33.29265",
    "lng": "23.48954"
  },
  {
    "country": "ZA",
    "name": "Williston",
    "lat": "-31.34048",
    "lng": "20.91544"
  },
  {
    "country": "ZA",
    "name": "Whittlesea",
    "lat": "-32.17588",
    "lng": "26.82437"
  },
  {
    "country": "ZA",
    "name": "Westonaria",
    "lat": "-26.31905",
    "lng": "27.6486"
  },
  {
    "country": "ZA",
    "name": "Wesselsbron",
    "lat": "-27.8549",
    "lng": "26.36583"
  },
  {
    "country": "ZA",
    "name": "Welkom",
    "lat": "-27.97742",
    "lng": "26.73506"
  },
  {
    "country": "ZA",
    "name": "Wartburg",
    "lat": "-29.43184",
    "lng": "30.57567"
  },
  {
    "country": "ZA",
    "name": "Warrenton",
    "lat": "-28.11396",
    "lng": "24.84753"
  },
  {
    "country": "ZA",
    "name": "Warmbaths",
    "lat": "-24.88333",
    "lng": "28.28333"
  },
  {
    "country": "ZA",
    "name": "Arniston",
    "lat": "-34.66739",
    "lng": "20.23086"
  },
  {
    "country": "ZA",
    "name": "Vryheid",
    "lat": "-27.76952",
    "lng": "30.79165"
  },
  {
    "country": "ZA",
    "name": "Vryburg",
    "lat": "-26.95659",
    "lng": "24.7284"
  },
  {
    "country": "ZA",
    "name": "Vredefort",
    "lat": "-27.00805",
    "lng": "27.3646"
  },
  {
    "country": "ZA",
    "name": "Vrede",
    "lat": "-27.42573",
    "lng": "29.16585"
  },
  {
    "country": "ZA",
    "name": "Volksrust",
    "lat": "-27.36541",
    "lng": "29.88175"
  },
  {
    "country": "ZA",
    "name": "Virginia",
    "lat": "-28.10391",
    "lng": "26.86593"
  },
  {
    "country": "ZA",
    "name": "Villiers",
    "lat": "-27.03026",
    "lng": "28.60061"
  },
  {
    "country": "ZA",
    "name": "Viljoenskroon",
    "lat": "-27.20841",
    "lng": "26.94855"
  },
  {
    "country": "ZA",
    "name": "Victoria West",
    "lat": "-31.40364",
    "lng": "23.11461"
  },
  {
    "country": "ZA",
    "name": "Vereeniging",
    "lat": "-26.67313",
    "lng": "27.92615"
  },
  {
    "country": "ZA",
    "name": "Ventersdorp",
    "lat": "-26.31401",
    "lng": "26.82223"
  },
  {
    "country": "ZA",
    "name": "Ventersburg",
    "lat": "-28.08561",
    "lng": "27.13814"
  },
  {
    "country": "ZA",
    "name": "Van Wyksvlei",
    "lat": "-30.35101",
    "lng": "21.82498"
  },
  {
    "country": "ZA",
    "name": "Vanderbijlpark",
    "lat": "-26.71171",
    "lng": "27.83795"
  },
  {
    "country": "ZA",
    "name": "Utrecht",
    "lat": "-27.65862",
    "lng": "30.32166"
  },
  {
    "country": "ZA",
    "name": "Upington",
    "lat": "-28.44776",
    "lng": "21.25612"
  },
  {
    "country": "ZA",
    "name": "Mthatha",
    "lat": "-31.58893",
    "lng": "28.78443"
  },
  {
    "country": "ZA",
    "name": "eMkhomazi",
    "lat": "-30.20674",
    "lng": "30.79776"
  },
  {
    "country": "ZA",
    "name": "Ulundi",
    "lat": "-28.33523",
    "lng": "31.41617"
  },
  {
    "country": "ZA",
    "name": "Uitenhage",
    "lat": "-33.75757",
    "lng": "25.3971"
  },
  {
    "country": "ZA",
    "name": "Tzaneen",
    "lat": "-23.83322",
    "lng": "30.16351"
  },
  {
    "country": "ZA",
    "name": "Tugela Ferry",
    "lat": "-28.74649",
    "lng": "30.45126"
  },
  {
    "country": "ZA",
    "name": "Trompsburg",
    "lat": "-30.03363",
    "lng": "25.78041"
  },
  {
    "country": "ZA",
    "name": "Thulamahashi",
    "lat": "-24.72459",
    "lng": "31.19939"
  },
  {
    "country": "ZA",
    "name": "Thohoyandou",
    "lat": "-22.94564",
    "lng": "30.48497"
  },
  {
    "country": "ZA",
    "name": "Theunissen",
    "lat": "-28.41098",
    "lng": "26.70107"
  },
  {
    "country": "ZA",
    "name": "Thabazimbi",
    "lat": "-24.59165",
    "lng": "27.41155"
  },
  {
    "country": "ZA",
    "name": "Thaba Nchu",
    "lat": "-29.20932",
    "lng": "26.83898"
  },
  {
    "country": "ZA",
    "name": "Tembisa",
    "lat": "-25.99636",
    "lng": "28.2268"
  },
  {
    "country": "ZA",
    "name": "Taung",
    "lat": "-27.53113",
    "lng": "24.78659"
  },
  {
    "country": "ZA",
    "name": "Tarkastad",
    "lat": "-32.00893",
    "lng": "26.25935"
  },
  {
    "country": "ZA",
    "name": "Swellendam",
    "lat": "-34.02262",
    "lng": "20.44171"
  },
  {
    "country": "ZA",
    "name": "Sundumbili",
    "lat": "-29.13371",
    "lng": "31.39752"
  },
  {
    "country": "ZA",
    "name": "Stutterheim",
    "lat": "-32.57076",
    "lng": "27.42396"
  },
  {
    "country": "ZA",
    "name": "Stilfontein",
    "lat": "-26.84493",
    "lng": "26.76829"
  },
  {
    "country": "ZA",
    "name": "KwaDukuza",
    "lat": "-29.32816",
    "lng": "31.28954"
  },
  {
    "country": "ZA",
    "name": "Standerton",
    "lat": "-26.93366",
    "lng": "29.24152"
  },
  {
    "country": "ZA",
    "name": "Springs",
    "lat": "-26.25",
    "lng": "28.4"
  },
  {
    "country": "ZA",
    "name": "Soweto",
    "lat": "-26.26781",
    "lng": "27.85849"
  },
  {
    "country": "ZA",
    "name": "Somerset East",
    "lat": "-32.72173",
    "lng": "25.58804"
  },
  {
    "country": "ZA",
    "name": "Siyabuswa",
    "lat": "-25.11319",
    "lng": "29.04454"
  },
  {
    "country": "ZA",
    "name": "Senekal",
    "lat": "-28.31971",
    "lng": "27.62082"
  },
  {
    "country": "ZA",
    "name": "Secunda",
    "lat": "-26.55",
    "lng": "29.16667"
  },
  {
    "country": "ZA",
    "name": "Scottburgh",
    "lat": "-30.28666",
    "lng": "30.75316"
  },
  {
    "country": "ZA",
    "name": "Schweizer-Reneke",
    "lat": "-27.18871",
    "lng": "25.32931"
  },
  {
    "country": "ZA",
    "name": "Sasolburg",
    "lat": "-26.81358",
    "lng": "27.81695"
  },
  {
    "country": "ZA",
    "name": "Rustenburg",
    "lat": "-25.66756",
    "lng": "27.24208"
  },
  {
    "country": "ZA",
    "name": "Riversdale",
    "lat": "-34.09345",
    "lng": "21.25725"
  },
  {
    "country": "ZA",
    "name": "Ritchie",
    "lat": "-29.03801",
    "lng": "24.60278"
  },
  {
    "country": "ZA",
    "name": "Richmond",
    "lat": "-29.87196",
    "lng": "30.27235"
  },
  {
    "country": "ZA",
    "name": "Richards Bay",
    "lat": "-28.78301",
    "lng": "32.03768"
  },
  {
    "country": "ZA",
    "name": "Reitz",
    "lat": "-27.80138",
    "lng": "28.42726"
  },
  {
    "country": "ZA",
    "name": "Randfontein",
    "lat": "-26.1844",
    "lng": "27.70203"
  },
  {
    "country": "ZA",
    "name": "Randburg",
    "lat": "-26.0941",
    "lng": "28.00123"
  },
  {
    "country": "ZA",
    "name": "Qumbu",
    "lat": "-31.16304",
    "lng": "28.87056"
  },
  {
    "country": "ZA",
    "name": "Queenstown",
    "lat": "-31.89756",
    "lng": "26.87533"
  },
  {
    "country": "ZA",
    "name": "Queensdale",
    "lat": "-31.87101",
    "lng": "26.97862"
  },
  {
    "country": "ZA",
    "name": "Prince Albert",
    "lat": "-33.22476",
    "lng": "22.02673"
  },
  {
    "country": "ZA",
    "name": "Prieska",
    "lat": "-29.66803",
    "lng": "22.74251"
  },
  {
    "country": "ZA",
    "name": "Pretoria",
    "lat": "-25.74486",
    "lng": "28.18783"
  },
  {
    "country": "ZA",
    "name": "Mokopane",
    "lat": "-24.19436",
    "lng": "29.00974"
  },
  {
    "country": "ZA",
    "name": "Potchefstroom",
    "lat": "-26.71667",
    "lng": "27.1"
  },
  {
    "country": "ZA",
    "name": "Postmasburg",
    "lat": "-28.33392",
    "lng": "23.06541"
  },
  {
    "country": "ZA",
    "name": "Port Shepstone",
    "lat": "-30.74137",
    "lng": "30.45499"
  },
  {
    "country": "ZA",
    "name": "Port Saint John’s",
    "lat": "-31.62291",
    "lng": "29.54477"
  },
  {
    "country": "ZA",
    "name": "Port Elizabeth",
    "lat": "-33.96109",
    "lng": "25.61494"
  },
  {
    "country": "ZA",
    "name": "Port Alfred",
    "lat": "-33.58601",
    "lng": "26.88329"
  },
  {
    "country": "ZA",
    "name": "Pongola",
    "lat": "-27.37808",
    "lng": "31.61904"
  },
  {
    "country": "ZA",
    "name": "Plettenberg Bay",
    "lat": "-34.05274",
    "lng": "23.3716"
  },
  {
    "country": "ZA",
    "name": "Piet Retief",
    "lat": "-27.00706",
    "lng": "30.81323"
  },
  {
    "country": "ZA",
    "name": "Polokwane",
    "lat": "-23.90449",
    "lng": "29.46885"
  },
  {
    "country": "ZA",
    "name": "Pietermaritzburg",
    "lat": "-29.61679",
    "lng": "30.39278"
  },
  {
    "country": "ZA",
    "name": "Phuthaditjhaba",
    "lat": "-28.52423",
    "lng": "28.81582"
  },
  {
    "country": "ZA",
    "name": "Phalaborwa",
    "lat": "-23.94299",
    "lng": "31.14107"
  },
  {
    "country": "ZA",
    "name": "Petrusville",
    "lat": "-30.08113",
    "lng": "24.6593"
  },
  {
    "country": "ZA",
    "name": "Peddie",
    "lat": "-33.20059",
    "lng": "27.11385"
  },
  {
    "country": "ZA",
    "name": "Paulpietersburg",
    "lat": "-27.42426",
    "lng": "30.81689"
  },
  {
    "country": "ZA",
    "name": "Parys",
    "lat": "-26.9033",
    "lng": "27.45727"
  },
  {
    "country": "ZA",
    "name": "Pampierstad",
    "lat": "-27.78324",
    "lng": "24.68768"
  },
  {
    "country": "ZA",
    "name": "Oudtshoorn",
    "lat": "-33.60047",
    "lng": "22.19955"
  },
  {
    "country": "ZA",
    "name": "Orkney",
    "lat": "-26.98023",
    "lng": "26.67272"
  },
  {
    "country": "ZA",
    "name": "Orania",
    "lat": "-29.81381",
    "lng": "24.41205"
  },
  {
    "country": "ZA",
    "name": "Orange Farm",
    "lat": "-26.48333",
    "lng": "27.86667"
  },
  {
    "country": "ZA",
    "name": "Modimolle",
    "lat": "-24.7",
    "lng": "28.4"
  },
  {
    "country": "ZA",
    "name": "Noupoort",
    "lat": "-31.18736",
    "lng": "24.94991"
  },
  {
    "country": "ZA",
    "name": "Nongoma",
    "lat": "-27.90968",
    "lng": "31.64817"
  },
  {
    "country": "ZA",
    "name": "Nkowakowa",
    "lat": "-23.88782",
    "lng": "30.28708"
  },
  {
    "country": "ZA",
    "name": "Nkandla",
    "lat": "-28.6207",
    "lng": "31.09067"
  },
  {
    "country": "ZA",
    "name": "Nigel",
    "lat": "-26.43138",
    "lng": "28.47713"
  },
  {
    "country": "ZA",
    "name": "Newcastle",
    "lat": "-27.75796",
    "lng": "29.9318"
  },
  {
    "country": "ZA",
    "name": "Nelspruit",
    "lat": "-25.47448",
    "lng": "30.97033"
  },
  {
    "country": "ZA",
    "name": "Ndwedwe",
    "lat": "-29.51686",
    "lng": "30.92687"
  },
  {
    "country": "ZA",
    "name": "Mutale",
    "lat": "-22.46972",
    "lng": "30.87533"
  },
  {
    "country": "ZA",
    "name": "Muldersdriseloop",
    "lat": "-26.03673",
    "lng": "27.83798"
  },
  {
    "country": "ZA",
    "name": "Mtubatuba",
    "lat": "-28.41789",
    "lng": "32.18483"
  },
  {
    "country": "ZA",
    "name": "Mpumalanga",
    "lat": "-29.81292",
    "lng": "30.63646"
  },
  {
    "country": "ZA",
    "name": "Mpophomeni",
    "lat": "-29.56822",
    "lng": "30.18618"
  },
  {
    "country": "ZA",
    "name": "Mount Frere",
    "lat": "-30.90173",
    "lng": "28.99238"
  },
  {
    "country": "ZA",
    "name": "Mount Ayliff",
    "lat": "-30.80821",
    "lng": "29.36644"
  },
  {
    "country": "ZA",
    "name": "Mossel Bay",
    "lat": "-34.18307",
    "lng": "22.14605"
  },
  {
    "country": "ZA",
    "name": "Mooirivier",
    "lat": "-29.20824",
    "lng": "29.9946"
  },
  {
    "country": "ZA",
    "name": "Montagu",
    "lat": "-33.78664",
    "lng": "20.12106"
  },
  {
    "country": "ZA",
    "name": "Mondlo",
    "lat": "-27.98299",
    "lng": "30.71769"
  },
  {
    "country": "ZA",
    "name": "Molteno",
    "lat": "-31.39675",
    "lng": "26.36246"
  },
  {
    "country": "ZA",
    "name": "Mogwase",
    "lat": "-25.27748",
    "lng": "27.21605"
  },
  {
    "country": "ZA",
    "name": "Modderfontein",
    "lat": "-26.08909",
    "lng": "28.16534"
  },
  {
    "country": "ZA",
    "name": "Mmabatho",
    "lat": "-25.85",
    "lng": "25.63333"
  },
  {
    "country": "ZA",
    "name": "Mkuze",
    "lat": "-27.61641",
    "lng": "32.03861"
  },
  {
    "country": "ZA",
    "name": "Middelburg",
    "lat": "-31.49285",
    "lng": "25.00633"
  },
  {
    "country": "ZA",
    "name": "Middelburg",
    "lat": "-25.77507",
    "lng": "29.46482"
  },
  {
    "country": "ZA",
    "name": "Meyerton",
    "lat": "-26.55987",
    "lng": "28.0195"
  },
  {
    "country": "ZA",
    "name": "Melmoth",
    "lat": "-28.58664",
    "lng": "31.39783"
  },
  {
    "country": "ZA",
    "name": "Matatiele",
    "lat": "-30.34357",
    "lng": "28.81161"
  },
  {
    "country": "ZA",
    "name": "Marquard",
    "lat": "-28.66449",
    "lng": "27.43048"
  },
  {
    "country": "ZA",
    "name": "Margate",
    "lat": "-30.8636",
    "lng": "30.37052"
  },
  {
    "country": "ZA",
    "name": "Marble Hall",
    "lat": "-24.96627",
    "lng": "29.29068"
  },
  {
    "country": "ZA",
    "name": "Mankoeng",
    "lat": "-23.9",
    "lng": "29.81667"
  },
  {
    "country": "ZA",
    "name": "Makapanstad",
    "lat": "-25.24373",
    "lng": "28.1262"
  },
  {
    "country": "ZA",
    "name": "Maile",
    "lat": "-25.44152",
    "lng": "27.28165"
  },
  {
    "country": "ZA",
    "name": "Mahikeng",
    "lat": "-25.86522",
    "lng": "25.64421"
  },
  {
    "country": "ZA",
    "name": "Maclear",
    "lat": "-31.07104",
    "lng": "28.35183"
  },
  {
    "country": "ZA",
    "name": "Mabopane",
    "lat": "-25.49768",
    "lng": "28.10065"
  },
  {
    "country": "ZA",
    "name": "Lydenburg",
    "lat": "-25.09598",
    "lng": "30.44393"
  },
  {
    "country": "ZA",
    "name": "Louis Trichardt",
    "lat": "-23.04385",
    "lng": "29.90319"
  },
  {
    "country": "ZA",
    "name": "Lindley",
    "lat": "-27.8791",
    "lng": "27.91348"
  },
  {
    "country": "ZA",
    "name": "Lichtenburg",
    "lat": "-26.152",
    "lng": "26.15968"
  },
  {
    "country": "ZA",
    "name": "Libode",
    "lat": "-31.54331",
    "lng": "29.0164"
  },
  {
    "country": "ZA",
    "name": "Lebowakgomo",
    "lat": "-24.2",
    "lng": "29.5"
  },
  {
    "country": "ZA",
    "name": "Laingsburg",
    "lat": "-33.19495",
    "lng": "20.85872"
  },
  {
    "country": "ZA",
    "name": "Ladysmith",
    "lat": "-28.55874",
    "lng": "29.77896"
  },
  {
    "country": "ZA",
    "name": "Lady Grey",
    "lat": "-30.71084",
    "lng": "27.21613"
  },
  {
    "country": "ZA",
    "name": "Lady Frere",
    "lat": "-31.70312",
    "lng": "27.2329"
  },
  {
    "country": "ZA",
    "name": "Ladybrand",
    "lat": "-29.19448",
    "lng": "27.45739"
  },
  {
    "country": "ZA",
    "name": "Ladismith",
    "lat": "-33.49331",
    "lng": "21.26755"
  },
  {
    "country": "ZA",
    "name": "KwaMbonambi",
    "lat": "-28.59827",
    "lng": "32.0894"
  },
  {
    "country": "ZA",
    "name": "Kutloanong",
    "lat": "-27.83333",
    "lng": "26.75"
  },
  {
    "country": "ZA",
    "name": "Kuruman",
    "lat": "-27.4524",
    "lng": "23.43246"
  },
  {
    "country": "ZA",
    "name": "Kruisfontein",
    "lat": "-34.00333",
    "lng": "24.73142"
  },
  {
    "country": "ZA",
    "name": "Krugersdorp",
    "lat": "-26.08577",
    "lng": "27.77515"
  },
  {
    "country": "ZA",
    "name": "Kroonstad",
    "lat": "-27.65036",
    "lng": "27.23488"
  },
  {
    "country": "ZA",
    "name": "Kriel",
    "lat": "-26.27391",
    "lng": "29.2253"
  },
  {
    "country": "ZA",
    "name": "Koster",
    "lat": "-25.86301",
    "lng": "26.89756"
  },
  {
    "country": "ZA",
    "name": "Koppies",
    "lat": "-27.24179",
    "lng": "27.57422"
  },
  {
    "country": "ZA",
    "name": "Komga",
    "lat": "-32.57704",
    "lng": "27.892"
  },
  {
    "country": "ZA",
    "name": "Komatipoort",
    "lat": "-25.43321",
    "lng": "31.95478"
  },
  {
    "country": "ZA",
    "name": "Kokstad",
    "lat": "-30.54723",
    "lng": "29.42412"
  },
  {
    "country": "ZA",
    "name": "Koffiefontein",
    "lat": "-29.40661",
    "lng": "25.00309"
  },
  {
    "country": "ZA",
    "name": "Knysna",
    "lat": "-34.03627",
    "lng": "23.04713"
  },
  {
    "country": "ZA",
    "name": "Klerksdorp",
    "lat": "-26.85213",
    "lng": "26.66672"
  },
  {
    "country": "ZA",
    "name": "Kirkwood",
    "lat": "-33.39829",
    "lng": "25.44279"
  },
  {
    "country": "ZA",
    "name": "Kimberley",
    "lat": "-28.73226",
    "lng": "24.76232"
  },
  {
    "country": "ZA",
    "name": "Kenhardt",
    "lat": "-29.34574",
    "lng": "21.15786"
  },
  {
    "country": "ZA",
    "name": "Kathu",
    "lat": "-27.69569",
    "lng": "23.04929"
  },
  {
    "country": "ZA",
    "name": "Kareedouw",
    "lat": "-33.9528",
    "lng": "24.29053"
  },
  {
    "country": "ZA",
    "name": "Kakamas",
    "lat": "-28.77341",
    "lng": "20.6147"
  },
  {
    "country": "ZA",
    "name": "Jozini",
    "lat": "-27.4296",
    "lng": "32.06658"
  },
  {
    "country": "ZA",
    "name": "Johannesburg",
    "lat": "-26.20227",
    "lng": "28.04363"
  },
  {
    "country": "ZA",
    "name": "Jeffrey’s Bay",
    "lat": "-34.05045",
    "lng": "24.90768"
  },
  {
    "country": "ZA",
    "name": "Jansenville",
    "lat": "-32.94306",
    "lng": "24.67218"
  },
  {
    "country": "ZA",
    "name": "Jan Kempdorp",
    "lat": "-27.92246",
    "lng": "24.83051"
  },
  {
    "country": "ZA",
    "name": "Jane Furse",
    "lat": "-24.76021",
    "lng": "29.86993"
  },
  {
    "country": "ZA",
    "name": "Izingolweni",
    "lat": "-30.78409",
    "lng": "30.12294"
  },
  {
    "country": "ZA",
    "name": "Ixopo",
    "lat": "-30.15",
    "lng": "30.08333"
  },
  {
    "country": "ZA",
    "name": "Impendle",
    "lat": "-29.60049",
    "lng": "29.86561"
  },
  {
    "country": "ZA",
    "name": "Ilinge",
    "lat": "-31.97676",
    "lng": "27.04267"
  },
  {
    "country": "ZA",
    "name": "Howick",
    "lat": "-29.47795",
    "lng": "30.23057"
  },
  {
    "country": "ZA",
    "name": "Hopetown",
    "lat": "-29.62464",
    "lng": "24.08518"
  },
  {
    "country": "ZA",
    "name": "Hoopstad",
    "lat": "-27.83273",
    "lng": "25.90833"
  },
  {
    "country": "ZA",
    "name": "Hoedspruit",
    "lat": "-24.35122",
    "lng": "30.95332"
  },
  {
    "country": "ZA",
    "name": "Hluhluwe",
    "lat": "-28.01895",
    "lng": "32.26762"
  },
  {
    "country": "ZA",
    "name": "Hlabisa",
    "lat": "-28.14519",
    "lng": "31.87719"
  },
  {
    "country": "ZA",
    "name": "Himeville",
    "lat": "-29.74675",
    "lng": "29.51361"
  },
  {
    "country": "ZA",
    "name": "Hennenman",
    "lat": "-27.97654",
    "lng": "27.02423"
  },
  {
    "country": "ZA",
    "name": "Hendrina",
    "lat": "-26.15881",
    "lng": "29.71528"
  },
  {
    "country": "ZA",
    "name": "Heilbron",
    "lat": "-27.28115",
    "lng": "27.9709"
  },
  {
    "country": "ZA",
    "name": "Heidelberg",
    "lat": "-26.50476",
    "lng": "28.35921"
  },
  {
    "country": "ZA",
    "name": "Hartswater",
    "lat": "-27.74964",
    "lng": "24.79712"
  },
  {
    "country": "ZA",
    "name": "Harrismith",
    "lat": "-28.27276",
    "lng": "29.12946"
  },
  {
    "country": "ZA",
    "name": "Harding",
    "lat": "-30.57643",
    "lng": "29.88401"
  },
  {
    "country": "ZA",
    "name": "Groblershoop",
    "lat": "-28.89531",
    "lng": "21.98378"
  },
  {
    "country": "ZA",
    "name": "Groblersdal",
    "lat": "-25.16843",
    "lng": "29.39412"
  },
  {
    "country": "ZA",
    "name": "Greytown",
    "lat": "-29.06415",
    "lng": "30.59279"
  },
  {
    "country": "ZA",
    "name": "Grahamstown",
    "lat": "-33.30422",
    "lng": "26.53276"
  },
  {
    "country": "ZA",
    "name": "Graaff-Reinet",
    "lat": "-32.25215",
    "lng": "24.53075"
  },
  {
    "country": "ZA",
    "name": "Glencoe",
    "lat": "-28.17827",
    "lng": "30.14702"
  },
  {
    "country": "ZA",
    "name": "Giyani",
    "lat": "-23.30246",
    "lng": "30.71868"
  },
  {
    "country": "ZA",
    "name": "Germiston",
    "lat": "-26.23481",
    "lng": "28.17665"
  },
  {
    "country": "ZA",
    "name": "George",
    "lat": "-33.963",
    "lng": "22.46173"
  },
  {
    "country": "ZA",
    "name": "Ga-Rankuwa",
    "lat": "-25.61692",
    "lng": "27.99471"
  },
  {
    "country": "ZA",
    "name": "Ganyesa",
    "lat": "-26.59613",
    "lng": "24.17612"
  },
  {
    "country": "ZA",
    "name": "Ga-Kgapane",
    "lat": "-23.64378",
    "lng": "30.22324"
  },
  {
    "country": "ZA",
    "name": "Fraserburg",
    "lat": "-31.91566",
    "lng": "21.51335"
  },
  {
    "country": "ZA",
    "name": "Frankfort",
    "lat": "-27.27888",
    "lng": "28.49696"
  },
  {
    "country": "ZA",
    "name": "Fort Beaufort",
    "lat": "-32.77477",
    "lng": "26.63376"
  },
  {
    "country": "ZA",
    "name": "Fochville",
    "lat": "-26.48862",
    "lng": "27.49387"
  },
  {
    "country": "ZA",
    "name": "Flagstaff",
    "lat": "-31.08042",
    "lng": "29.49522"
  },
  {
    "country": "ZA",
    "name": "Ficksburg",
    "lat": "-28.872",
    "lng": "27.87506"
  },
  {
    "country": "ZA",
    "name": "Estcourt",
    "lat": "-29.01269",
    "lng": "29.86619"
  },
  {
    "country": "ZA",
    "name": "eSikhaleni",
    "lat": "-28.87097",
    "lng": "31.89961"
  },
  {
    "country": "ZA",
    "name": "Eshowe",
    "lat": "-28.88649",
    "lng": "31.4699"
  },
  {
    "country": "ZA",
    "name": "Ermelo",
    "lat": "-26.53333",
    "lng": "29.98333"
  },
  {
    "country": "ZA",
    "name": "Empangeni",
    "lat": "-28.76197",
    "lng": "31.89329"
  },
  {
    "country": "ZA",
    "name": "eMbalenhle",
    "lat": "-26.53333",
    "lng": "29.06667"
  },
  {
    "country": "ZA",
    "name": "Elliot",
    "lat": "-31.33333",
    "lng": "27.85"
  },
  {
    "country": "ZA",
    "name": "Ekuvukeni",
    "lat": "-28.46752",
    "lng": "30.15513"
  },
  {
    "country": "ZA",
    "name": "Edenvale",
    "lat": "-26.14095",
    "lng": "28.15247"
  },
  {
    "country": "ZA",
    "name": "East London",
    "lat": "-33.01529",
    "lng": "27.91162"
  },
  {
    "country": "ZA",
    "name": "Durban",
    "lat": "-29.8579",
    "lng": "31.0292"
  },
  {
    "country": "ZA",
    "name": "Dundee",
    "lat": "-28.16678",
    "lng": "30.23371"
  },
  {
    "country": "ZA",
    "name": "Duiwelskloof",
    "lat": "-23.69339",
    "lng": "30.14002"
  },
  {
    "country": "ZA",
    "name": "Driefontein",
    "lat": "-27.0177",
    "lng": "30.44979"
  },
  {
    "country": "ZA",
    "name": "Douglas",
    "lat": "-29.05531",
    "lng": "23.7743"
  },
  {
    "country": "ZA",
    "name": "Dordrecht",
    "lat": "-31.372",
    "lng": "27.04878"
  },
  {
    "country": "ZA",
    "name": "Dewetsdorp",
    "lat": "-29.58274",
    "lng": "26.66511"
  },
  {
    "country": "ZA",
    "name": "De Rust",
    "lat": "-33.49035",
    "lng": "22.53523"
  },
  {
    "country": "ZA",
    "name": "Deneysville",
    "lat": "-26.8908",
    "lng": "28.09707"
  },
  {
    "country": "ZA",
    "name": "Dendron",
    "lat": "-23.36669",
    "lng": "29.32371"
  },
  {
    "country": "ZA",
    "name": "Delmas",
    "lat": "-26.1466",
    "lng": "28.68322"
  },
  {
    "country": "ZA",
    "name": "Delareyville",
    "lat": "-26.68638",
    "lng": "25.45907"
  },
  {
    "country": "ZA",
    "name": "De Aar",
    "lat": "-30.64966",
    "lng": "24.0123"
  },
  {
    "country": "ZA",
    "name": "Dannhauser",
    "lat": "-28.0151",
    "lng": "30.05658"
  },
  {
    "country": "ZA",
    "name": "Daniëlskuil",
    "lat": "-28.18873",
    "lng": "23.53951"
  },
  {
    "country": "ZA",
    "name": "Cullinan",
    "lat": "-25.67088",
    "lng": "28.52364"
  },
  {
    "country": "ZA",
    "name": "Creighton",
    "lat": "-30.0272",
    "lng": "29.83955"
  },
  {
    "country": "ZA",
    "name": "Cradock",
    "lat": "-32.16422",
    "lng": "25.61918"
  },
  {
    "country": "ZA",
    "name": "Colesberg",
    "lat": "-30.71999",
    "lng": "25.09718"
  },
  {
    "country": "ZA",
    "name": "Cofimvaba",
    "lat": "-32.00115",
    "lng": "27.58045"
  },
  {
    "country": "ZA",
    "name": "Clocolan",
    "lat": "-28.91367",
    "lng": "27.56555"
  },
  {
    "country": "ZA",
    "name": "Christiana",
    "lat": "-27.91402",
    "lng": "25.16111"
  },
  {
    "country": "ZA",
    "name": "Carolina",
    "lat": "-26.06927",
    "lng": "30.11489"
  },
  {
    "country": "ZA",
    "name": "Carnarvon",
    "lat": "-30.96827",
    "lng": "22.13303"
  },
  {
    "country": "ZA",
    "name": "Carletonville",
    "lat": "-26.36094",
    "lng": "27.39767"
  },
  {
    "country": "ZA",
    "name": "Camperdown",
    "lat": "-29.72868",
    "lng": "30.54256"
  },
  {
    "country": "ZA",
    "name": "Calitzdorp",
    "lat": "-33.52755",
    "lng": "21.6762"
  },
  {
    "country": "ZA",
    "name": "Cala",
    "lat": "-31.52356",
    "lng": "27.6952"
  },
  {
    "country": "ZA",
    "name": "Butterworth",
    "lat": "-32.33083",
    "lng": "28.14981"
  },
  {
    "country": "ZA",
    "name": "Burgersfort",
    "lat": "-24.67554",
    "lng": "30.32877"
  },
  {
    "country": "ZA",
    "name": "Burgersdorp",
    "lat": "-30.99766",
    "lng": "26.32862"
  },
  {
    "country": "ZA",
    "name": "Bultfontein",
    "lat": "-28.28756",
    "lng": "26.14996"
  },
  {
    "country": "ZA",
    "name": "Bronkhorstspruit",
    "lat": "-25.81015",
    "lng": "28.74248"
  },
  {
    "country": "ZA",
    "name": "Brits",
    "lat": "-25.63473",
    "lng": "27.78022"
  },
  {
    "country": "ZA",
    "name": "Breyten",
    "lat": "-26.30176",
    "lng": "29.98696"
  },
  {
    "country": "ZA",
    "name": "Bredasdorp",
    "lat": "-34.53215",
    "lng": "20.04031"
  },
  {
    "country": "ZA",
    "name": "Brandvlei",
    "lat": "-30.46532",
    "lng": "20.48659"
  },
  {
    "country": "ZA",
    "name": "Brandfort",
    "lat": "-28.70008",
    "lng": "26.45968"
  },
  {
    "country": "ZA",
    "name": "Brakpan",
    "lat": "-26.23656",
    "lng": "28.36938"
  },
  {
    "country": "ZA",
    "name": "Botshabelo",
    "lat": "-29.26737",
    "lng": "26.72595"
  },
  {
    "country": "ZA",
    "name": "Bothaville",
    "lat": "-27.3887",
    "lng": "26.61701"
  },
  {
    "country": "ZA",
    "name": "Boshof",
    "lat": "-28.53914",
    "lng": "25.23965"
  },
  {
    "country": "ZA",
    "name": "Boksburg",
    "lat": "-26.21197",
    "lng": "28.25958"
  },
  {
    "country": "ZA",
    "name": "Bloemhof",
    "lat": "-27.64685",
    "lng": "25.60697"
  },
  {
    "country": "ZA",
    "name": "Bloemfontein",
    "lat": "-29.12107",
    "lng": "26.214"
  },
  {
    "country": "ZA",
    "name": "Bizana",
    "lat": "-30.85907",
    "lng": "29.85384"
  },
  {
    "country": "ZA",
    "name": "Bhisho",
    "lat": "-32.84721",
    "lng": "27.44218"
  },
  {
    "country": "ZA",
    "name": "Bethlehem",
    "lat": "-28.23078",
    "lng": "28.30707"
  },
  {
    "country": "ZA",
    "name": "Bethal",
    "lat": "-26.45794",
    "lng": "29.46553"
  },
  {
    "country": "ZA",
    "name": "Bergville",
    "lat": "-28.73122",
    "lng": "29.35187"
  },
  {
    "country": "ZA",
    "name": "Berea",
    "lat": "-29.85185",
    "lng": "30.99337"
  },
  {
    "country": "ZA",
    "name": "Benoni",
    "lat": "-26.18848",
    "lng": "28.32078"
  },
  {
    "country": "ZA",
    "name": "Belfast",
    "lat": "-25.68991",
    "lng": "30.03504"
  },
  {
    "country": "ZA",
    "name": "Beaufort West",
    "lat": "-32.35671",
    "lng": "22.58295"
  },
  {
    "country": "ZA",
    "name": "Barkly West",
    "lat": "-28.53537",
    "lng": "24.52151"
  },
  {
    "country": "ZA",
    "name": "Barkly East",
    "lat": "-30.9683",
    "lng": "27.59567"
  },
  {
    "country": "ZA",
    "name": "Barberton",
    "lat": "-25.78842",
    "lng": "31.05319"
  },
  {
    "country": "ZA",
    "name": "Ballito",
    "lat": "-29.53897",
    "lng": "31.21439"
  },
  {
    "country": "ZA",
    "name": "Balfour",
    "lat": "-26.66331",
    "lng": "28.59016"
  },
  {
    "country": "ZA",
    "name": "Ashton",
    "lat": "-33.83136",
    "lng": "20.05595"
  },
  {
    "country": "ZA",
    "name": "Apel",
    "lat": "-24.41445",
    "lng": "29.74991"
  },
  {
    "country": "ZA",
    "name": "Allanridge",
    "lat": "-27.75431",
    "lng": "26.64382"
  },
  {
    "country": "ZA",
    "name": "Aliwal North",
    "lat": "-30.69366",
    "lng": "26.71141"
  },
  {
    "country": "ZA",
    "name": "Alice",
    "lat": "-32.78749",
    "lng": "26.8344"
  },
  {
    "country": "ZA",
    "name": "Alberton",
    "lat": "-26.26786",
    "lng": "28.12225"
  },
  {
    "country": "ZA",
    "name": "Albertina",
    "lat": "-34.20544",
    "lng": "21.58001"
  },
  {
    "country": "ZA",
    "name": "Adelaide",
    "lat": "-32.70747",
    "lng": "26.29564"
  },
  {
    "country": "ZA",
    "name": "Ekangala",
    "lat": "-25.69619",
    "lng": "28.74918"
  },
  {
    "country": "ZA",
    "name": "Midrand",
    "lat": "-25.98953",
    "lng": "28.12843"
  },
  {
    "country": "ZA",
    "name": "Centurion",
    "lat": "-25.85891",
    "lng": "28.18577"
  },
  {
    "country": "ZA",
    "name": "Worcester",
    "lat": "-33.64651",
    "lng": "19.44852"
  },
  {
    "country": "ZA",
    "name": "Wellington",
    "lat": "-33.63981",
    "lng": "19.0112"
  },
  {
    "country": "ZA",
    "name": "Vredendal",
    "lat": "-31.66833",
    "lng": "18.50119"
  },
  {
    "country": "ZA",
    "name": "Vredenburg",
    "lat": "-32.90719",
    "lng": "17.98997"
  },
  {
    "country": "ZA",
    "name": "Stellenbosch",
    "lat": "-33.93462",
    "lng": "18.86676"
  },
  {
    "country": "ZA",
    "name": "Springbok",
    "lat": "-29.66434",
    "lng": "17.8865"
  },
  {
    "country": "ZA",
    "name": "Saldanha",
    "lat": "-33.01167",
    "lng": "17.9442"
  },
  {
    "country": "ZA",
    "name": "Rosebank",
    "lat": "-33.95556",
    "lng": "18.47417"
  },
  {
    "country": "ZA",
    "name": "Robertson",
    "lat": "-33.80342",
    "lng": "19.88537"
  },
  {
    "country": "ZA",
    "name": "Port Nolloth",
    "lat": "-29.25188",
    "lng": "16.8697"
  },
  {
    "country": "ZA",
    "name": "Pofadder",
    "lat": "-29.1283",
    "lng": "19.39492"
  },
  {
    "country": "ZA",
    "name": "Piketberg",
    "lat": "-32.90323",
    "lng": "18.75704"
  },
  {
    "country": "ZA",
    "name": "Paarl",
    "lat": "-33.73378",
    "lng": "18.97523"
  },
  {
    "country": "ZA",
    "name": "Moorreesburg",
    "lat": "-33.15388",
    "lng": "18.66031"
  },
  {
    "country": "ZA",
    "name": "Malmesbury",
    "lat": "-33.4608",
    "lng": "18.72714"
  },
  {
    "country": "ZA",
    "name": "Lansdowne",
    "lat": "-33.98735",
    "lng": "18.49746"
  },
  {
    "country": "ZA",
    "name": "Kraaifontein",
    "lat": "-33.84808",
    "lng": "18.71723"
  },
  {
    "country": "ZA",
    "name": "Hermanus",
    "lat": "-34.4187",
    "lng": "19.23446"
  },
  {
    "country": "ZA",
    "name": "Grabouw",
    "lat": "-34.15152",
    "lng": "19.01509"
  },
  {
    "country": "ZA",
    "name": "Garies",
    "lat": "-30.56223",
    "lng": "17.98905"
  },
  {
    "country": "ZA",
    "name": "Constantia",
    "lat": "-34.03139",
    "lng": "18.41833"
  },
  {
    "country": "ZA",
    "name": "Claremont",
    "lat": "-33.98056",
    "lng": "18.46528"
  },
  {
    "country": "ZA",
    "name": "Clanwilliam",
    "lat": "-32.18173",
    "lng": "18.89217"
  },
  {
    "country": "ZA",
    "name": "Ceres",
    "lat": "-33.36889",
    "lng": "19.31095"
  },
  {
    "country": "ZA",
    "name": "Cape Town",
    "lat": "-33.92584",
    "lng": "18.42322"
  },
  {
    "country": "ZA",
    "name": "Calvinia",
    "lat": "-31.47069",
    "lng": "19.77601"
  },
  {
    "country": "ZA",
    "name": "Caledon",
    "lat": "-34.22997",
    "lng": "19.4265"
  },
  {
    "country": "ZA",
    "name": "Bergvliet",
    "lat": "-34.04746",
    "lng": "18.4525"
  },
  {
    "country": "ZA",
    "name": "Atlantis",
    "lat": "-33.56668",
    "lng": "18.48335"
  },
  {
    "country": "ZA",
    "name": "Sunset Beach",
    "lat": "-33.85395",
    "lng": "18.49231"
  },
  {
    "country": "ZA",
    "name": "Eden Glen",
    "lat": "-26.1323",
    "lng": "28.16859"
  },
  {
    "country": "ZA",
    "name": "Rondebosch",
    "lat": "-33.96333",
    "lng": "18.47639"
  },
  {
    "country": "ZA",
    "name": "Newlands",
    "lat": "-33.97846",
    "lng": "18.4481"
  },
  {
    "country": "ZA",
    "name": "Bela-Bela",
    "lat": "-24.885",
    "lng": "28.29417"
  },
  {
    "country": "ZA",
    "name": "Lephalale",
    "lat": "-23.66607",
    "lng": "27.74477"
  },
  {
    "country": "ZA",
    "name": "Musina",
    "lat": "-22.34881",
    "lng": "30.04074"
  },
  {
    "country": "ZA",
    "name": "Midstream",
    "lat": "-25.91849",
    "lng": "28.19881"
  },
  {
    "country": "ZA",
    "name": "Mandeni",
    "lat": "-29.14691",
    "lng": "31.41403"
  },
  {
    "country": "ZA",
    "name": "Retreat",
    "lat": "-34.05515",
    "lng": "18.47617"
  },
  {
    "country": "ZA",
    "name": "Graskop",
    "lat": "-24.93174",
    "lng": "30.84008"
  },
  {
    "country": "ZA",
    "name": "Diepsloot",
    "lat": "-25.93312",
    "lng": "28.01213"
  },
  {
    "country": "ZA",
    "name": "Hardys Memories of Africa",
    "lat": "-33.90539",
    "lng": "20.7169"
  },
  {
    "country": "ZA",
    "name": "Eastleigh",
    "lat": "-26.12965",
    "lng": "28.15541"
  },
  {
    "country": "ZA",
    "name": "Riverlea",
    "lat": "-26.2119",
    "lng": "27.97322"
  },
  {
    "country": "ZA",
    "name": "Eden Glen Ext 60",
    "lat": "-26.12593",
    "lng": "28.165"
  },
  {
    "country": "ZM",
    "name": "Nchelenge",
    "lat": "-9.34506",
    "lng": "28.73396"
  },
  {
    "country": "ZM",
    "name": "Nakonde",
    "lat": "-9.34213",
    "lng": "32.745"
  },
  {
    "country": "ZM",
    "name": "Mpulungu",
    "lat": "-8.76234",
    "lng": "31.11405"
  },
  {
    "country": "ZM",
    "name": "Mporokoso",
    "lat": "-9.37273",
    "lng": "30.12501"
  },
  {
    "country": "ZM",
    "name": "Mbala",
    "lat": "-8.84024",
    "lng": "31.36587"
  },
  {
    "country": "ZM",
    "name": "Kawambwa",
    "lat": "-9.7915",
    "lng": "29.07913"
  },
  {
    "country": "ZM",
    "name": "Kaputa",
    "lat": "-8.46887",
    "lng": "29.66193"
  },
  {
    "country": "ZM",
    "name": "Zambezi",
    "lat": "-13.54323",
    "lng": "23.10467"
  },
  {
    "country": "ZM",
    "name": "Solwezi",
    "lat": "-12.1688",
    "lng": "26.38938"
  },
  {
    "country": "ZM",
    "name": "Sinazongwe",
    "lat": "-17.2614",
    "lng": "27.46179"
  },
  {
    "country": "ZM",
    "name": "Siavonga",
    "lat": "-16.53818",
    "lng": "28.70876"
  },
  {
    "country": "ZM",
    "name": "Sesheke",
    "lat": "-17.47593",
    "lng": "24.29684"
  },
  {
    "country": "ZM",
    "name": "Serenje",
    "lat": "-13.23251",
    "lng": "30.23522"
  },
  {
    "country": "ZM",
    "name": "Senanga",
    "lat": "-16.11667",
    "lng": "23.26667"
  },
  {
    "country": "ZM",
    "name": "Samfya",
    "lat": "-11.36491",
    "lng": "29.55652"
  },
  {
    "country": "ZM",
    "name": "Petauke",
    "lat": "-14.24117",
    "lng": "31.31975"
  },
  {
    "country": "ZM",
    "name": "Nyimba",
    "lat": "-14.55656",
    "lng": "30.8149"
  },
  {
    "country": "ZM",
    "name": "Ndola",
    "lat": "-12.95867",
    "lng": "28.63659"
  },
  {
    "country": "ZM",
    "name": "Namwala",
    "lat": "-15.75042",
    "lng": "26.43839"
  },
  {
    "country": "ZM",
    "name": "Nakambala",
    "lat": "-15.83244",
    "lng": "27.77994"
  },
  {
    "country": "ZM",
    "name": "Mwinilunga",
    "lat": "-11.73584",
    "lng": "24.42926"
  },
  {
    "country": "ZM",
    "name": "Mwense",
    "lat": "-10.38447",
    "lng": "28.698"
  },
  {
    "country": "ZM",
    "name": "Mungwi",
    "lat": "-10.1732",
    "lng": "31.36942"
  },
  {
    "country": "ZM",
    "name": "Mumbwa",
    "lat": "-14.98293",
    "lng": "27.0619"
  },
  {
    "country": "ZM",
    "name": "Mufumbwe",
    "lat": "-13.68333",
    "lng": "24.8"
  },
  {
    "country": "ZM",
    "name": "Mufulira",
    "lat": "-12.54982",
    "lng": "28.24071"
  },
  {
    "country": "ZM",
    "name": "Mpongwe",
    "lat": "-13.50914",
    "lng": "28.15504"
  },
  {
    "country": "ZM",
    "name": "Mpika",
    "lat": "-11.83431",
    "lng": "31.45287"
  },
  {
    "country": "ZM",
    "name": "Monze",
    "lat": "-16.28333",
    "lng": "27.48333"
  },
  {
    "country": "ZM",
    "name": "Mongu",
    "lat": "-15.24835",
    "lng": "23.12741"
  },
  {
    "country": "ZM",
    "name": "Mkushi",
    "lat": "-13.62015",
    "lng": "29.3939"
  },
  {
    "country": "ZM",
    "name": "Mazabuka",
    "lat": "-15.85601",
    "lng": "27.748"
  },
  {
    "country": "ZM",
    "name": "Mansa",
    "lat": "-11.19976",
    "lng": "28.89431"
  },
  {
    "country": "ZM",
    "name": "Maamba",
    "lat": "-17.36667",
    "lng": "27.15"
  },
  {
    "country": "ZM",
    "name": "Luwingu",
    "lat": "-10.2621",
    "lng": "29.92712"
  },
  {
    "country": "ZM",
    "name": "Lusaka",
    "lat": "-15.40669",
    "lng": "28.28713"
  },
  {
    "country": "ZM",
    "name": "Lundazi",
    "lat": "-12.29292",
    "lng": "33.1782"
  },
  {
    "country": "ZM",
    "name": "Lukulu",
    "lat": "-14.37067",
    "lng": "23.24196"
  },
  {
    "country": "ZM",
    "name": "Luanshya",
    "lat": "-13.13667",
    "lng": "28.41661"
  },
  {
    "country": "ZM",
    "name": "Luangwa",
    "lat": "-15.61667",
    "lng": "30.41667"
  },
  {
    "country": "ZM",
    "name": "Livingstone",
    "lat": "-17.84194",
    "lng": "25.85425"
  },
  {
    "country": "ZM",
    "name": "Limulunga",
    "lat": "-15.09691",
    "lng": "23.13757"
  },
  {
    "country": "ZM",
    "name": "Kitwe",
    "lat": "-12.80243",
    "lng": "28.21323"
  },
  {
    "country": "ZM",
    "name": "Kataba",
    "lat": "-11.88333",
    "lng": "29.78333"
  },
  {
    "country": "ZM",
    "name": "Kasempa",
    "lat": "-13.45836",
    "lng": "25.8338"
  },
  {
    "country": "ZM",
    "name": "Kasama",
    "lat": "-10.21289",
    "lng": "31.18084"
  },
  {
    "country": "ZM",
    "name": "Kapiri Mposhi",
    "lat": "-13.97147",
    "lng": "28.66985"
  },
  {
    "country": "ZM",
    "name": "Kaoma",
    "lat": "-14.78333",
    "lng": "24.8"
  },
  {
    "country": "ZM",
    "name": "Kansanshi",
    "lat": "-12.09514",
    "lng": "26.42727"
  },
  {
    "country": "ZM",
    "name": "Kalulushi",
    "lat": "-12.84151",
    "lng": "28.09479"
  },
  {
    "country": "ZM",
    "name": "Kalengwa",
    "lat": "-13.46586",
    "lng": "25.00271"
  },
  {
    "country": "ZM",
    "name": "Kalabo",
    "lat": "-14.99307",
    "lng": "22.67926"
  },
  {
    "country": "ZM",
    "name": "Kafue",
    "lat": "-15.76911",
    "lng": "28.18136"
  },
  {
    "country": "ZM",
    "name": "Kabwe",
    "lat": "-14.4469",
    "lng": "28.44644"
  },
  {
    "country": "ZM",
    "name": "Kabompo",
    "lat": "-13.59268",
    "lng": "24.20081"
  },
  {
    "country": "ZM",
    "name": "Isoka",
    "lat": "-10.16062",
    "lng": "32.63353"
  },
  {
    "country": "ZM",
    "name": "Gwembe",
    "lat": "-16.49755",
    "lng": "27.60691"
  },
  {
    "country": "ZM",
    "name": "Chongwe",
    "lat": "-15.32916",
    "lng": "28.68204"
  },
  {
    "country": "ZM",
    "name": "Choma",
    "lat": "-16.80889",
    "lng": "26.9875"
  },
  {
    "country": "ZM",
    "name": "Chipata",
    "lat": "-13.63333",
    "lng": "32.65"
  },
  {
    "country": "ZM",
    "name": "Chinsali",
    "lat": "-10.54142",
    "lng": "32.08162"
  },
  {
    "country": "ZM",
    "name": "Chingola",
    "lat": "-12.52897",
    "lng": "27.88382"
  },
  {
    "country": "ZM",
    "name": "Chililabombwe",
    "lat": "-12.36475",
    "lng": "27.82286"
  },
  {
    "country": "ZM",
    "name": "Chibombo",
    "lat": "-14.65685",
    "lng": "28.07057"
  },
  {
    "country": "ZM",
    "name": "Chambishi",
    "lat": "-12.63247",
    "lng": "28.05367"
  },
  {
    "country": "ZM",
    "name": "Chama",
    "lat": "-11.21303",
    "lng": "33.1521"
  },
  {
    "country": "ZM",
    "name": "Chadiza",
    "lat": "-14.06779",
    "lng": "32.43917"
  },
  {
    "country": "ZW",
    "name": "Zvishavane",
    "lat": "-20.32674",
    "lng": "30.06648"
  },
  {
    "country": "ZW",
    "name": "Victoria Falls",
    "lat": "-17.93285",
    "lng": "25.83066"
  },
  {
    "country": "ZW",
    "name": "Shurugwi",
    "lat": "-19.67016",
    "lng": "30.00589"
  },
  {
    "country": "ZW",
    "name": "Shangani",
    "lat": "-19.78333",
    "lng": "29.36667"
  },
  {
    "country": "ZW",
    "name": "Shamva",
    "lat": "-17.31159",
    "lng": "31.57561"
  },
  {
    "country": "ZW",
    "name": "Rusape",
    "lat": "-18.52785",
    "lng": "32.12843"
  },
  {
    "country": "ZW",
    "name": "Redcliff",
    "lat": "-19.03333",
    "lng": "29.78333"
  },
  {
    "country": "ZW",
    "name": "Raffingora",
    "lat": "-17.03333",
    "lng": "30.43333"
  },
  {
    "country": "ZW",
    "name": "Plumtree",
    "lat": "-20.48333",
    "lng": "27.81667"
  },
  {
    "country": "ZW",
    "name": "Penhalonga",
    "lat": "-18.89112",
    "lng": "32.69781"
  },
  {
    "country": "ZW",
    "name": "Odzi",
    "lat": "-18.96167",
    "lng": "32.40557"
  },
  {
    "country": "ZW",
    "name": "Nyazura",
    "lat": "-18.70587",
    "lng": "32.16796"
  },
  {
    "country": "ZW",
    "name": "Nyanga",
    "lat": "-18.21667",
    "lng": "32.75"
  },
  {
    "country": "ZW",
    "name": "Norton",
    "lat": "-17.88333",
    "lng": "30.7"
  },
  {
    "country": "ZW",
    "name": "Mvurwi",
    "lat": "-17.03333",
    "lng": "30.85"
  },
  {
    "country": "ZW",
    "name": "Mvuma",
    "lat": "-19.27924",
    "lng": "30.52828"
  },
  {
    "country": "ZW",
    "name": "Mutoko",
    "lat": "-17.39699",
    "lng": "32.22677"
  },
  {
    "country": "ZW",
    "name": "Mutare",
    "lat": "-18.9707",
    "lng": "32.67086"
  },
  {
    "country": "ZW",
    "name": "Murehwa",
    "lat": "-17.64322",
    "lng": "31.784"
  },
  {
    "country": "ZW",
    "name": "Mount Darwin",
    "lat": "-16.77251",
    "lng": "31.58381"
  },
  {
    "country": "ZW",
    "name": "Mhangura",
    "lat": "-16.89387",
    "lng": "30.16828"
  },
  {
    "country": "ZW",
    "name": "Mazowe",
    "lat": "-17.50404",
    "lng": "30.97388"
  },
  {
    "country": "ZW",
    "name": "Masvingo",
    "lat": "-20.06373",
    "lng": "30.82766"
  },
  {
    "country": "ZW",
    "name": "Mashava",
    "lat": "-20.03665",
    "lng": "30.48225"
  },
  {
    "country": "ZW",
    "name": "Marondera",
    "lat": "-18.18527",
    "lng": "31.55193"
  },
  {
    "country": "ZW",
    "name": "Macheke",
    "lat": "-18.13901",
    "lng": "31.84933"
  },
  {
    "country": "ZW",
    "name": "Lupane",
    "lat": "-18.93149",
    "lng": "27.80696"
  },
  {
    "country": "ZW",
    "name": "Lalapanzi",
    "lat": "-19.33225",
    "lng": "30.17768"
  },
  {
    "country": "ZW",
    "name": "Kwekwe",
    "lat": "-18.92809",
    "lng": "29.81486"
  },
  {
    "country": "ZW",
    "name": "Karoi",
    "lat": "-16.80993",
    "lng": "29.69247"
  },
  {
    "country": "ZW",
    "name": "Kariba",
    "lat": "-16.51667",
    "lng": "28.8"
  },
  {
    "country": "ZW",
    "name": "Kamativi Mine",
    "lat": "-18.31563",
    "lng": "27.05729"
  },
  {
    "country": "ZW",
    "name": "Kadoma",
    "lat": "-18.33328",
    "lng": "29.91534"
  },
  {
    "country": "ZW",
    "name": "Inyati",
    "lat": "-19.67563",
    "lng": "28.84687"
  },
  {
    "country": "ZW",
    "name": "Insiza",
    "lat": "-19.78333",
    "lng": "29.2"
  },
  {
    "country": "ZW",
    "name": "Hwange",
    "lat": "-18.36446",
    "lng": "26.49877"
  },
  {
    "country": "ZW",
    "name": "Headlands",
    "lat": "-18.27733",
    "lng": "32.0515"
  },
  {
    "country": "ZW",
    "name": "Harare",
    "lat": "-17.82772",
    "lng": "31.05337"
  },
  {
    "country": "ZW",
    "name": "Gweru",
    "lat": "-19.45",
    "lng": "29.81667"
  },
  {
    "country": "ZW",
    "name": "Gwanda",
    "lat": "-20.93622",
    "lng": "29.00698"
  },
  {
    "country": "ZW",
    "name": "Gokwe",
    "lat": "-18.20476",
    "lng": "28.9349"
  },
  {
    "country": "ZW",
    "name": "Glendale",
    "lat": "-17.35514",
    "lng": "31.06718"
  },
  {
    "country": "ZW",
    "name": "Filabusi",
    "lat": "-20.53333",
    "lng": "29.28502"
  },
  {
    "country": "ZW",
    "name": "Esigodini",
    "lat": "-20.28979",
    "lng": "28.92261"
  },
  {
    "country": "ZW",
    "name": "Dorowa Mining Lease",
    "lat": "-19.06667",
    "lng": "31.75"
  },
  {
    "country": "ZW",
    "name": "Dete",
    "lat": "-18.61667",
    "lng": "26.86667"
  },
  {
    "country": "ZW",
    "name": "Concession",
    "lat": "-17.38333",
    "lng": "30.95"
  },
  {
    "country": "ZW",
    "name": "Chivhu",
    "lat": "-19.02112",
    "lng": "30.89218"
  },
  {
    "country": "ZW",
    "name": "Chirundu",
    "lat": "-16.03333",
    "lng": "28.85"
  },
  {
    "country": "ZW",
    "name": "Chiredzi",
    "lat": "-21.05",
    "lng": "31.66667"
  },
  {
    "country": "ZW",
    "name": "Chipinge",
    "lat": "-20.18833",
    "lng": "32.62365"
  },
  {
    "country": "ZW",
    "name": "Chinhoyi",
    "lat": "-17.36667",
    "lng": "30.2"
  },
  {
    "country": "ZW",
    "name": "Chimanimani",
    "lat": "-19.8",
    "lng": "32.86667"
  },
  {
    "country": "ZW",
    "name": "Chegutu",
    "lat": "-18.13021",
    "lng": "30.14074"
  },
  {
    "country": "ZW",
    "name": "Chakari",
    "lat": "-18.06294",
    "lng": "29.89246"
  },
  {
    "country": "ZW",
    "name": "Centenary",
    "lat": "-16.72289",
    "lng": "31.11462"
  },
  {
    "country": "ZW",
    "name": "Bulawayo",
    "lat": "-20.15",
    "lng": "28.58333"
  },
  {
    "country": "ZW",
    "name": "Binga",
    "lat": "-17.62027",
    "lng": "27.34139"
  },
  {
    "country": "ZW",
    "name": "Bindura",
    "lat": "-17.30192",
    "lng": "31.33056"
  },
  {
    "country": "ZW",
    "name": "Beitbridge",
    "lat": "-22.21667",
    "lng": "30"
  },
  {
    "country": "ZW",
    "name": "Beatrice",
    "lat": "-18.25283",
    "lng": "30.8473"
  },
  {
    "country": "ZW",
    "name": "Banket",
    "lat": "-17.38333",
    "lng": "30.4"
  },
  {
    "country": "ZW",
    "name": "Epworth",
    "lat": "-17.89",
    "lng": "31.1475"
  },
  {
    "country": "ZW",
    "name": "Chitungwiza",
    "lat": "-18.01274",
    "lng": "31.07555"
  }
]
